#http://bbci.de/competition/iv/
#Dataset 3: ‹hand movement direction in MEG›
#provided by the Brain Machine Interfacing Initiative, Albert-Ludwigs-University Freiburg, the Bernstein Center for Computational Neuroscience Freiburg and the Institute of Medical Psychology and Behavioral Neurobiology, University of Tübingen (Stephan Waldert, Carsten Mehring, HubertPreissl, Christoph Braun)
#
#In short: 2 subjects were recorded moving a joystick with their hand and wrist only in one of four directions (right, up, down, left) of their choice after hearing a prompt, using Magnetoencephalography (MEG). The task is to classify the direction of movement from the MEG data.
#The train/test split given corresponds to the exact split provided in the original competition, with the trails for the two subjects merged, however. Data remains split by subject in the folders Subject1 and Subject2.
#
#From the file 'desc_3.pdf'; a description of the data from the original formatters at the above website
#
#'Title: Directionally modulated MEG activity
#
#Short description:
#The data set contains directionally modulated MEG activity that was recorded while
#subjects performed wrist movements in four different directions.
#
#Detailed Description:
#Brain activity during wrist movements was recorded with MEG at 625 Hz from two
#healthy, right-handed subjects. The subject sat relaxed in an MEG chair, the elbow
#rested on a pillow to prevent upper arm and shoulder movements, and the head was
#stabilized by small pillows. The task was to move a joystick from a center position
#toward one of four targets located radially at 90° intervals (four-class center-out
#paradigm) using exclusively the right hand and wrist. Movement amplitude was 4.5 cm.
#In each trial, the target was self-chosen by the subject. Targets were arranged in the
#form of a rhombus in the horizontal plane with corners pointing left, right, away from
#and toward the subject's body.
#Visual trigger signals were presented on a screen to start a trial or to indicate possible
#time violations. A trial started with the joystick in the center position and the appearance
#of a gray circle. After a variable delay (1-2 s), the disappearance of the circle indicated
#the “go” signal (cued movements). Then, within 0.75 s the subject had to start the
#movement and reach the target. For a trial to be valid, the subject also had to rest at the
#target for at least 1 s. These time constraints allowed for temporal consistency across
#trails and the hold period at the target prevented interference of in- and outward
#movements. A red cross was presented continuously for fixation.
#The trials were cut to contain data from 0.4 s before to 0.6 s after movement onset and
#the signals were band pass filtered (0.5 to 100 Hz) and resampled at 400 Hz, whereas in
#Waldert et al. (JNeurosci 28(4), 2008) we showed that especially the low-frequency
#activity (<8 Hz) contains information about movement direction. The data are composed
#of signals from ten MEG channels which were located above the motor areas. We will
#evaluate the competitor's submissions with respect to the percentage of correct
#classifications (decoding accuracy). Please note that classification using cross-validation
#on the provided training data does not necessarily yield the average decoding accuracy
#reported in our original study because of the reduced number of channels (approx. one
#quarter), inter-subject variability and the reduced number of trials in the training set due
#to separation of data into training and test set. The data are provided as mat-files
#(Matlab), detailed description is provided along with the files. Predicted class labels for
#the test sets must be submitted as a single mat-file containing two variables (vectors):
#PredictedLabelsS1 and PredictedLabelsS2, e.g. PredictedLabelsS1=[3 2 4 1 ...]. The
#name of this mat-file must identify the competitor.'
#
@problemName HandMovementDirection
@timeStamps false
@missing false
@univariate false
@dimensions 10
@equalLength true
@seriesLength 400
@classLabel true right forward left backward
@data
152.472131,151.149948,133.185425,105.026618,96.332784,84.042392,92.75814,148.356448,172.008408,144.247889,64.959811,16.707942,-90.433318,-104.88999,-23.367039,47.816074,157.748728,84.59741,-17.796622,-216.593288,-245.072468,-110.608017,-6.647322,137.48481,212.101203,217.481317,181.108778,166.104407,158.941757,147.359306,53.591802,6.74957,42.800243,97.909643,68.486113,-52.683411,-109.447088,-128.727852,-96.488721,-37.18507,-22.833092,-27.858732,-33.944719,-34.962049,-33.174199,-5.569941,113.99207,168.456625,177.514673,115.003774,114.183233,118.055785,79.918363,-32.741252,-70.901846,-49.955249,79.944235,107.293617,21.523678,-49.239828,-143.090812,-142.768608,-109.052894,-121.849242,-186.236079,-254.153289,-284.244153,-303.604549,-283.191715,-211.181699,-191.787476,-187.139614,-104.825397,-42.197137,-10.122515,-48.021549,-107.724365,-98.849827,-72.74816,-75.014084,-34.051791,8.417942,-41.981344,-208.155945,-239.350142,-217.020875,-231.348274,-273.596341,-199.471538,-163.231609,-176.073445,-220.017316,-342.503417,-394.35444,-446.176818,-443.083842,-388.552442,-353.56805,-344.915358,-298.798799,-285.105242,-300.410487,-284.337804,-135.04721,26.424775,39.945569,-28.094383,-64.391561,-102.836114,-87.851032,23.957846,84.931317,133.020489,99.531205,86.493967,40.881217,-17.377783,-84.308672,-52.8874,68.748839,124.737973,88.458647,-22.823327,-64.908926,-166.260337,-214.204037,-220.774174,-165.85545,6.198392,91.744248,87.014757,20.078237,-30.382333,-96.702629,-97.373417,-53.445504,-20.557439,-24.688881,-4.846368,35.869363,80.083813,52.850932,-31.18872,-43.616179,22.520511,100.941569,97.626255,53.009699,43.450232,33.123494,12.956685,-28.455079,26.197456,68.642155,76.767727,27.304914,-132.262231,-194.402104,-218.066636,-191.860709,-88.429796,-29.828488,-54.148589,-148.841361,-189.366119,-200.055857,-165.89758,-114.238329,-167.168644,-201.643708,-212.932123,-187.765579,-81.17845,-4.390445,113.94664,130.50992,114.233826,75.401733,59.108845,20.538578,-31.007388,-169.154251,-201.274171,-159.143876,-110.412815,-106.246796,-82.563486,-72.944997,-90.86104,-94.230285,-70.595873,-52.167518,14.094432,33.811815,-16.995946,-205.994518,-301.337297,-369.294595,-335.079839,-214.201209,-123.382105,-115.683566,-153.510188,-173.5132,-188.503323,-179.468444,-109.351143,-55.764593,24.102815,-32.375369,-90.383286,-121.093248,-93.168755,-19.688894,26.211725,133.794575,205.748742,199.61232,155.037251,151.577269,152.88041,150.27286,184.687975,236.187521,347.419588,297.616847,218.718154,86.170083,67.063155,118.199772,146.013457,137.290857,136.425592,150.024976,170.555928,163.434318,107.239516,101.518234,138.251015,119.208385,-7.310087,-75.722769,-59.906806,15.873592,46.086168,56.280417,35.013804,-10.161741,8.287902,25.525525,45.647658,48.843466,56.34513,58.500777,28.111328,16.066809,38.902809,19.872485,-9.967966,-50.625064,-69.240271,-118.943072,-140.557798,-154.357562,-112.476034,-89.118174,-55.727706,-49.560926,-84.111027,-105.869034,-130.388249,-134.138374,-102.018091,-95.306468,-111.736047,-99.711606,-94.822474,-133.743061,-133.596479,-78.662558,-26.12349,-1.440001,3.080819,-31.342278,-81.57481,-56.213198,15.394236,13.474132,-11.703765,-0.137769,-26.246591,-133.740215,-152.531974,-68.579936,-19.498679,31.575257,83.133097,71.523446,-27.702771,-63.896584,-105.321001,-143.747416,-267.771847,-300.835168,-232.711441,-206.589993,-222.964753,-157.845263,-101.467247,-61.220895,-62.385036,-7.229985,95.733618,99.574376,34.121369,13.842836,-3.039675,-27.079889,-126.846583,-176.358232,-174.22864,-52.756657,1.452897,13.392897,-22.376865,-56.592525,-24.026088,98.167155,183.117799,170.839746,135.399504,149.073478,144.017002,113.079782,43.435011,11.957598,-7.1043,-42.992673,-99.121554,-185.748018,-179.301922,-58.861154,13.40515,74.588381,102.927823,98.830537,40.430262,51.317498,174.940535,230.326254,272.125776,279.69846,285.484029,125.421392,-10.432904,-165.151395,-153.688706,-117.380343,-135.844356,-122.783663,6.365745,34.452574,-13.867802,-60.966115,-170.123158,-194.221942,-119.643041,-47.310203,64.963813,76.967368,66.419318,36.451286,-8.386504,-138.811334,-161.038327,-57.405814,12.287843,-47.233137,-203.4707,-237.441079,-273.246363,-273.993614,-218.151118,-211.648165,-257.663977,-246.789645,-224.364582,-189.193892,-176.5831,-155.721457,-140.469239,-51.292832,98.999745,146.925262,132.063724,80.41247,-7.083205,2.807625,53.909876,28.78894:12.392351,77.166998,75.533099,78.709435,90.910153,102.599228,104.953825,120.922936,120.10202,108.492274,67.25145,30.767418,-39.812981,-49.2825,-10.132392,37.445891,145.453352,160.960716,113.699649,-14.09439,-31.691623,18.589171,50.487959,147.479529,253.574919,266.179329,256.725547,253.58133,191.448271,139.402722,72.797166,67.275939,60.735874,4.662334,-7.488298,-2.920219,-15.393013,-36.708787,-25.036675,29.121228,40.508628,5.421609,-78.609551,-95.199221,-55.161822,-2.484018,118.849178,154.84322,140.875772,85.242995,71.218407,53.697883,56.182977,76.894291,59.557259,-7.087451,-4.088365,10.892459,0.373753,-39.40577,-131.737915,-136.871222,-99.530197,-110.803333,-158.278078,-124.233241,-90.847532,-47.578954,-53.32675,-127.172841,-164.448156,-121.769245,-50.987777,-104.58325,-266.632943,-301.001399,-272.524828,-227.911458,-141.120383,-113.382851,-80.379173,-102.690141,-152.524009,-237.625358,-240.52564,-239.005292,-258.619672,-310.119719,-298.339704,-253.180838,-192.610609,-216.611211,-294.388718,-319.997246,-382.568801,-410.937905,-408.033383,-408.05355,-433.665488,-505.609099,-516.597494,-421.330845,-353.723193,-242.227531,-83.015225,-13.836359,21.577509,-35.064148,-226.069211,-254.459109,-67.840218,53.31953,101.97735,-8.293755,-47.872645,-104.570726,-111.886637,-51.655101,-11.022538,71.250901,137.916346,139.214982,60.033592,1.906216,-97.469861,-138.670006,-184.27673,-152.643177,7.442159,74.218353,57.802421,33.078266,34.041151,25.936645,22.495842,60.04818,70.480576,39.869756,-16.207514,-23.572922,5.76851,48.630882,142.574905,167.070818,157.0907,39.430924,-28.602127,-52.68387,-20.497857,38.897451,72.708025,188.896688,209.601715,142.710988,4.328378,-26.994588,-42.52744,-42.077653,-60.8811,-81.38837,-128.682015,-191.112975,-231.622443,-280.283774,-243.642566,-83.143372,-44.234056,-101.202514,-152.776648,-157.738107,-147.460473,-138.820329,-126.782705,-95.946389,22.574251,69.690123,103.268305,97.806702,87.476123,11.989001,-47.460827,-134.495581,-145.212864,-97.039131,-67.292112,-97.121973,-166.997799,-184.024773,-188.18624,-155.325485,7.982151,98.361175,153.218812,29.703552,-62.27139,-230.674956,-258.546262,-196.461084,-166.28374,-118.523955,-12.935786,9.455741,-95.83795,-174.217285,-220.303787,-198.078962,-147.865154,-114.317363,-37.398726,-6.235387,-15.880429,-104.291476,-150.932077,-102.484404,-14.511071,102.187197,66.329856,53.269527,113.755597,138.56616,111.166495,91.489482,123.714919,187.530517,276.583806,190.69858,136.139127,60.439261,26.329379,3.175664,27.772123,96.425938,98.022322,67.168344,53.861876,82.991019,109.342243,99.263973,117.574694,143.314341,115.277841,40.342611,34.828947,28.450947,24.203485,70.239604,107.704038,134.777254,77.769872,48.313333,34.601653,17.554425,-76.687467,-112.278358,-64.526386,2.035651,80.32426,9.728406,-58.229057,-180.235553,-207.152791,-161.425108,-116.431254,-89.469549,-122.994278,-124.043916,-109.047346,-112.994892,-131.583213,-125.265144,-68.701838,-42.337956,-47.869556,-97.936067,-107.222731,-44.654384,8.095977,10.010596,-41.821248,-78.632036,52.857067,140.037511,197.774021,138.793127,-31.841914,-72.767082,-24.668909,34.991975,142.136495,166.078228,134.769231,7.408671,-43.693324,6.371031,92.299173,222.538519,199.307981,161.850281,123.567715,104.777506,11.130938,-36.021527,-56.1128,-24.651351,73.796424,44.342138,-10.441707,-4.724188,71.478385,190.476933,178.51585,115.156505,116.705521,115.996971,97.317292,91.75249,54.426263,16.061181,-47.797302,-63.957947,-86.249075,-97.500586,-79.932381,10.528643,55.707992,94.880653,89.784722,99.073292,184.121779,200.864868,125.511356,75.563823,53.456954,75.984075,78.621434,41.056066,-50.200301,-133.054829,-165.098066,-159.793026,-129.498034,-70.862882,-57.849902,-33.502167,27.353777,32.689723,9.436022,31.077385,112.323868,121.132524,103.290536,123.107624,173.944629,52.029136,-40.44759,-113.330953,-96.869135,-60.501022,-55.509065,-47.291683,-46.945124,-55.860434,-62.436586,-84.900165,-197.893813,-218.313946,-92.557066,-3.16576,97.099748,77.934226,38.047429,-51.935851,-84.142909,-107.292975,-110.821026,-96.426862,-92.893556,-143.163864,-246.444346,-250.312823,-232.059603,-224.542742,-183.963475,-161.078437,-113.289499,-60.27703,-67.420411,-174.840544,-228.534645,-198.310214,-110.385797,81.817818,129.457028,101.626719,74.194715,82.059898,77.194399,69.785583,64.461769,68.651276:18.801367,7.669297,20.021506,-8.449302,-62.002411,-151.82816,-136.895332,10.618465,99.970259,90.119399,36.207086,12.961397,23.450546,58.890318,136.184548,158.414171,117.612083,49.256148,58.45466,82.122842,75.683967,90.001177,123.716698,208.586258,241.04842,225.497079,189.630955,191.922795,212.303689,214.760334,189.457773,156.981919,81.051116,56.142576,44.113368,10.39273,18.474014,61.813073,67.98458,59.030773,52.168127,42.970977,35.109929,37.946184,-3.31194,-26.430189,42.893256,106.973985,141.740837,96.49892,69.867259,3.417604,-3.909604,51.859488,68.212929,46.708972,-8.39877,-37.317152,-77.056441,-99.191321,-121.514869,-113.93979,-123.239124,-139.730612,-136.492828,-114.241107,-119.045323,-136.960994,-131.848822,-88.518514,-66.163229,-59.099707,-112.014156,-162.472391,-281.024381,-322.068232,-317.476263,-274.765666,-187.225743,-164.225132,-168.616666,-207.998531,-223.785176,-258.340841,-269.768687,-278.025687,-296.072105,-337.181975,-295.054615,-248.589997,-219.146521,-251.136853,-299.005216,-305.047239,-378.81116,-439.153957,-496.824355,-506.406757,-531.966189,-560.782086,-530.452689,-423.38906,-372.608667,-230.473717,-103.75931,-95.168174,-105.014668,-118.398566,-197.632264,-216.509516,-121.154259,-47.714013,10.307962,-77.496248,-136.363411,-199.602436,-179.535356,-54.969327,2.739268,83.27969,181.883752,204.072584,80.366649,-29.865937,-121.85561,-98.265192,-66.116697,-51.980887,32.886831,114.831189,115.93238,34.66951,2.705502,21.857094,36.407908,14.049315,-48.930946,-73.276247,-38.669134,12.717207,96.360614,107.33233,106.538268,114.404735,122.354927,69.38324,25.053924,-10.298613,12.705595,70.340159,91.622193,129.210713,88.234847,28.789264,-63.028989,-85.542623,-135.287629,-151.954605,-119.70302,-82.439892,-51.745145,-129.235558,-197.856672,-287.521456,-252.886259,-64.965736,12.773043,60.294941,24.747134,-4.793142,-85.993127,-136.166649,-178.717292,-146.740778,-38.076819,11.244707,76.486724,54.346371,22.176078,-32.048136,-40.108396,4.206397,24.039202,-21.729243,-76.507527,-73.47041,-73.408968,-112.871496,-232.446857,-248.726926,-127.318162,-34.506895,92.444406,109.024579,63.499493,-102.900246,-151.92759,-75.327986,5.149031,91.084714,27.218322,-25.545724,-78.321279,-62.854509,13.222114,24.636214,-42.512115,-62.451032,1.231908,32.82392,-14.956669,-144.249155,-166.171748,-120.717929,-90.767626,-55.382608,-48.463076,-43.506222,-30.264736,-24.468505,32.259344,80.452218,145.878996,154.96383,134.809662,89.751743,74.216738,2.551038,-50.75954,-63.072597,-9.750832,96.699368,75.027065,23.58751,-81.046948,-108.520405,-67.352333,-12.820393,51.918699,39.682384,-32.506871,-52.915073,-29.357184,29.814964,45.26796,46.090678,54.834374,114.566716,97.566242,45.649862,-23.790919,-34.266097,-64.782993,-68.869965,-17.324435,21.88524,47.090827,-55.753979,-123.398014,-190.86239,-168.548417,-58.227596,-25.126698,-83.232794,-166.858966,-150.018297,-43.86552,-5.377122,-28.927128,-66.572769,-68.872772,-22.080049,36.347407,-43.083089,-70.938793,-35.268411,-3.290527,43.311183,74.504019,169.353002,216.371479,205.407086,147.592081,104.263369,33.012428,36.639237,68.339191,58.431375,56.411493,112.891142,117.097708,39.986716,2.336055,54.2673,119.250213,226.544049,254.583295,211.444356,69.550875,31.899063,27.428381,16.859232,6.958212,38.379786,89.603683,26.954425,3.017573,95.434204,190.95233,347.173588,377.771194,348.647568,281.600321,247.125339,183.896804,153.572031,95.511814,76.276814,17.601687,-31.98624,-98.835006,-98.039619,-101.740523,-107.219355,-76.510828,30.023754,73.013343,153.085024,223.617828,233.427734,173.5521,97.465362,-34.519022,-47.502178,-47.559452,-52.674147,-35.457938,-56.618106,-83.572506,-103.46422,-100.247681,-92.015454,-76.046003,-16.71919,-11.920738,-32.921222,-41.884083,-14.12259,82.711543,122.1684,134.055169,108.929805,26.84854,-51.2447,-88.096369,-166.515763,-178.091117,-139.435425,-120.307169,-76.792349,-46.539316,-61.25679,-112.194334,-138.910072,-188.985382,-181.468291,-75.7381,-3.68718,103.779297,88.512325,51.702027,3.22836,-1.320982,3.947322,13.994511,54.443066,22.068105,-31.636796,-118.312026,-159.743338,-278.721478,-308.851182,-245.25405,-183.878014,-99.818871,-94.850262,-118.82462,-170.653324,-150.802444,-3.193913,69.531479,149.581415,182.796699,185.92224,157.935872,116.302152,37.192708,47.910957,159.136337,204.255729:119.067984,92.37896,50.618334,-24.030543,-36.308074,-22.390507,-7.71859,39.400218,107.501816,141.559923,162.564249,115.795811,-21.951858,-44.095273,4.103549,31.628382,45.663637,61.428425,68.417889,-11.038347,-61.400606,-26.196966,36.166141,131.481291,169.86573,168.301124,174.495377,187.342022,151.46603,107.223433,69.820588,81.713459,78.519488,33.768322,31.082959,0.46478,-51.263454,-117.562428,-92.771792,5.550748,57.236014,74.959654,78.205639,40.88875,-48.455386,-42.045984,92.210671,170.588114,220.659714,141.163991,109.989289,61.328494,30.381576,16.44534,21.460206,-1.836349,4.398615,-2.827339,-91.242739,-137.803561,-177.050206,-173.122776,-168.114164,-180.014269,-185.409363,-203.182951,-239.129044,-271.114076,-232.649411,-110.229676,-78.81915,-54.713852,-1.937782,5.516735,-71.456522,-141.140858,-220.414475,-196.098931,-112.045958,-106.722741,-110.207608,-90.634652,-131.756196,-277.750959,-301.520874,-252.306368,-255.365769,-319.883793,-316.848217,-297.574288,-283.841561,-304.096911,-384.163999,-423.757285,-466.155821,-462.166025,-449.09209,-485.260818,-494.399754,-462.711845,-444.776434,-397.22511,-347.184301,-164.041848,17.664525,33.597971,-20.242388,-43.64274,-84.020892,-79.386801,12.782114,53.700875,66.993708,68.162246,46.873574,-116.721679,-202.208387,-189.592824,-99.976527,109.843857,176.295623,122.614925,-45.857269,-98.688344,-134.586067,-145.460323,-128.861365,-73.908934,81.677816,115.00598,85.500751,10.405688,-25.41081,-51.707456,-43.313852,-4.922305,-1.639137,-41.708624,-59.030323,-2.817898,70.760161,60.978957,93.518979,147.383066,176.983781,82.321903,49.515486,42.429949,43.231443,33.694452,41.997805,114.826225,118.198365,68.186586,8.077131,2.241042,-71.673941,-119.858929,-120.344611,-84.748643,-62.983543,-140.343206,-167.224783,-133.811222,-99.225959,-56.388954,-49.105567,-48.848141,-70.559474,-84.959469,-99.573229,-109.671851,-127.5051,-96.868856,63.988969,148.109821,215.599283,172.889418,149.535422,80.925959,-2.237011,-193.645824,-225.54722,-170.452553,-111.528445,-91.103423,-76.733828,-98.763366,-171.030994,-177.234233,-111.036527,-63.649624,40.558102,96.068131,74.7488,-50.126867,-109.433166,-125.501126,-105.125679,-49.961695,23.241697,19.814544,-46.858431,-58.057952,-23.982418,3.203427,59.786797,80.243441,90.61988,62.363326,36.075808,-41.816081,-82.52792,-109.656507,-87.28137,-13.196895,21.346454,15.768231,37.318547,87.624122,196.374924,223.206837,215.125275,203.25835,199.238463,146.26653,93.661508,5.811795,-21.420305,-43.918715,-18.247837,96.333774,134.675887,99.52506,41.786531,47.927637,43.92576,14.228465,-44.036722,-53.845529,-50.230293,-60.550133,-68.42447,-93.96852,-106.594033,-77.035245,-50.295859,-4.953575,54.619284,63.583096,42.890343,25.423731,-42.575868,-69.174901,-28.785578,9.532432,33.711999,-9.011965,-37.529786,-103.679655,-133.619712,-136.788681,-124.443973,-133.018504,-116.649157,-90.517112,-71.776102,-75.911481,-80.508289,-86.819252,-109.28647,-109.239975,-89.849205,-114.584656,-116.109392,-49.839784,-31.970527,-71.581424,-86.034134,-42.943892,51.389801,96.925158,142.94359,111.169119,-41.669549,-91.236962,-72.829249,-39.671679,43.925838,105.744304,108.456035,59.779184,5.693335,-63.892346,-36.436826,89.570157,198.050953,211.433679,119.959296,56.761212,-0.906589,-19.779352,-93.197623,-101.454644,-25.838403,-35.108382,-72.66024,-66.768683,-15.045728,123.759491,171.488395,184.747495,192.183459,206.066287,178.472756,121.042091,-9.536685,-47.757523,-87.260479,-105.324181,-111.606777,-77.359864,-70.91985,-73.029395,-67.362416,-56.268641,-52.968543,17.154299,149.472909,184.287994,139.678023,84.015671,35.462655,54.654164,52.88465,18.816052,-9.346099,1.619293,-0.881972,-13.236961,-28.006003,-43.926449,-35.321561,-35.6156,-67.836206,-90.260189,-123.735393,-117.313231,-89.283295,-74.957734,15.40417,81.005343,124.750749,-12.772397,-102.843956,-228.45884,-259.402896,-270.373189,-261.782139,-202.220255,-148.122735,-183.036386,-263.066747,-252.979543,-215.214393,-205.352735,-139.270848,-70.356593,97.503642,170.732197,141.149285,42.358865,10.597795,-23.218153,-20.222843,30.35411,9.261286,-56.710931,-175.300482,-206.03553,-257.9701,-251.398422,-151.722625,-117.912992,-127.853591,-128.311387,-117.320027,-88.64384,-73.76726,-32.482511,4.284571,114.312275,183.893692,172.254672,137.461862,143.701011,164.599614,169.682685,171.225051,163.93257:9.371185,28.596053,33.54072,-80.624318,-163.957234,-192.933555,-135.084658,15.99921,86.788282,85.488335,45.652886,12.487183,-14.590666,3.311838,27.97781,33.21958,75.498201,129.717314,120.459152,-16.608586,-91.289311,-115.918443,-63.419521,148.801369,335.297315,339.090819,235.66215,188.726211,133.396113,126.059226,165.901222,181.218677,121.525383,40.819166,20.971509,-24.739636,-48.162038,-58.134713,-34.378884,52.258111,39.226988,-8.231326,-71.980249,-84.675711,-90.047622,-56.549931,97.917339,175.603691,199.562664,55.817512,-9.454061,-58.980839,-66.0189,-83.634263,-71.1543,15.509842,35.390787,-11.235207,-116.268332,-137.026756,-119.578448,-112.778028,-147.344608,-147.010396,-49.258056,-25.64956,-80.022577,-173.074813,-162.352784,-93.414615,-77.800493,-60.398775,-56.327514,-106.538803,-267.376372,-302.342124,-240.126616,-186.78181,-102.562914,-67.164522,-27.736076,-86.19502,-135.470509,-251.089174,-296.670944,-289.557591,-272.274463,-280.424019,-257.29901,-238.640022,-246.985829,-289.772535,-426.859234,-464.018272,-394.994747,-338.502793,-334.57704,-443.338708,-490.008918,-530.619435,-519.498316,-444.719555,-388.884088,-211.748825,-61.059461,-63.45432,-152.349126,-192.526429,-244.724766,-239.057532,-120.408953,-37.768714,53.966057,12.790048,-50.361617,-225.354072,-271.07022,-192.045045,-113.548753,52.925388,156.261565,135.240901,-26.217311,-111.910292,-175.295511,-148.047897,-40.625076,15.621572,77.754685,47.728024,43.202091,68.290766,60.123032,6.387241,-12.979178,-20.240629,-59.189439,-86.907297,-61.328307,-22.271594,19.891088,36.241026,118.591943,164.76018,191.46716,128.970904,84.295305,8.189581,-3.597339,36.323585,58.733681,74.433558,71.58221,49.504018,-34.752341,-82.463664,-132.276731,-127.902114,-116.692805,-112.788881,-99.403544,-142.223577,-180.750779,-200.321646,-157.444018,-24.662983,15.575767,9.077552,-42.889493,-81.948432,-144.904701,-150.322526,-120.311045,-85.511389,11.147973,67.181385,171.686859,184.998391,146.407242,35.689635,-10.864285,-35.146299,-14.407112,-2.004678,-48.010758,-46.297662,-49.174578,-102.959991,-208.793281,-201.905965,-109.457287,-49.162982,75.397044,135.709863,137.789291,65.298285,-6.709497,-69.210154,-22.33202,128.69371,150.760161,92.333978,4.694249,6.721964,50.345553,78.837702,100.527296,92.193319,99.517627,122.230284,112.104063,20.006504,-43.179662,-81.623778,-39.915464,59.534663,6.447364,-64.855817,-109.775119,-57.184889,85.633309,125.662513,149.408216,174.896572,218.553281,129.786422,66.198777,-20.771232,-42.022806,-30.633757,-0.117283,89.88503,141.03359,128.34772,83.623766,59.796431,-0.972326,-20.357249,-2.02941,29.558099,76.880657,8.176785,-63.628259,-161.587008,-153.900347,-72.795099,-26.771323,80.317453,111.13603,78.967599,40.451189,37.416547,-1.843787,-16.846284,33.933278,96.948885,174.96442,36.615617,-52.027385,-118.71652,-109.649998,-67.189609,-49.215099,-52.317705,-111.414955,-134.832203,-115.024911,-94.28436,-78.140734,-74.219412,-60.051405,-33.100887,44.572401,-1.780754,-58.711033,-99.70721,-91.289047,-71.752782,-48.691059,34.39064,81.404829,86.747388,88.319741,56.802441,-86.616944,-155.159157,-188.743834,-142.347625,12.943129,85.707581,83.040195,41.864537,9.664698,-3.358054,41.431055,200.25967,223.236688,142.706774,7.946773,0.484797,20.25243,34.557994,85.269985,118.311893,152.426102,47.933523,-14.565872,-17.038378,38.891434,178.947496,230.507044,291.564107,349.814313,344.276096,227.521883,149.221259,34.599251,-4.831702,-103.897052,-141.577115,-144.532794,-148.760646,-167.235959,-192.345351,-179.393152,-104.670573,-58.194346,61.212879,161.415401,149.399392,40.338204,-13.776816,-60.740287,-36.987364,36.298055,46.297383,16.332053,-34.833363,-56.6827,-82.555593,-81.064006,-58.645917,-49.497784,-4.287873,30.201733,-12.388765,-145.568075,-179.209816,-128.155415,-69.748726,0.278375,13.577425,28.658678,-53.919481,-134.001352,-304.58159,-349.638072,-283.10951,-219.342282,-178.809071,-225.13823,-236.616609,-199.336976,-193.845451,-265.923464,-274.423992,-139.356835,-45.032797,117.838826,224.074682,214.509983,104.768914,73.832625,93.921921,105.127534,105.168454,38.122711,-39.293272,-164.918399,-175.297849,-166.204866,-171.083199,-146.325844,-104.791838,-42.623814,-39.693787,-33.888092,-47.4763,-63.458521,-7.429954,52.700469,139.764237,201.703448,227.225968,203.094016,149.977083,88.485339,124.986183,243.573642,265.382454:176.87829,134.774572,77.921054,8.10086,14.436097,15.281629,6.679703,30.866367,116.843497,147.890768,119.815014,67.560725,-40.238091,-71.343894,-45.483959,20.170377,160.17617,136.897562,52.751794,-125.946291,-156.197081,-85.963879,-27.336594,85.618208,153.000144,159.731588,199.465294,230.977103,213.453599,164.89828,67.776344,44.733625,42.56994,8.705757,-19.591963,-75.961118,-90.522526,-67.994234,-49.296026,-5.278293,24.845507,-0.104726,-52.26377,-29.852411,59.820662,97.867753,151.346481,168.135624,210.285572,232.927464,218.022388,128.653187,73.591241,38.844954,51.608453,59.338921,53.356494,40.564791,-23.322439,-68.248653,-144.211818,-155.478154,-153.505649,-164.990099,-204.814719,-277.408479,-331.92663,-399.404657,-380.957656,-271.938862,-225.421367,-178.807947,-87.801227,-17.962013,86.247408,75.380911,-55.259192,-100.62783,-50.515422,18.224538,158.93074,122.588313,8.727383,-191.173474,-198.726466,-117.856366,-112.344418,-150.463209,-133.615695,-148.663083,-251.307616,-297.72998,-348.046796,-374.527848,-436.221872,-455.154043,-463.823386,-437.846463,-385.688828,-258.344639,-253.859643,-311.603421,-286.238128,-149.572615,-93.070105,-97.580022,-115.652499,-124.055017,-102.401357,-66.081828,-29.326038,-31.297114,29.622431,111.131477,95.57322,-78.746769,-182.839472,-208.281778,-125.091697,56.454148,69.487501,6.524671,-120.228916,-156.964529,-225.998042,-251.75588,-203.847466,-123.697999,25.96515,-12.581017,-60.284574,-69.282799,-43.027665,-27.379111,-59.606889,-147.54556,-150.022027,-133.934739,-70.601701,-15.739693,46.057257,12.930451,-95.98692,-91.205226,44.805895,73.696608,15.645061,-81.806711,-69.349306,43.58036,72.11788,17.638982,-16.912077,-20.627736,-24.252113,-9.546178,13.073567,-3.747392,-78.784027,-121.14032,-132.842652,-30.520085,-1.34137,-53.530938,-90.81142,-53.749659,-3.605681,7.069918,-111.657601,-156.621405,-114.543516,-73.29391,-74.70437,-65.807405,70.939714,153.303137,274.165269,274.396112,218.302129,78.767246,20.023213,-48.119051,-51.552593,-16.023977,4.038718,8.914326,22.420538,-1.365207,-110.761739,-140.75229,-79.306636,-19.761285,58.494861,81.068464,72.738118,-42.112989,-139.673757,-240.57825,-215.641215,-116.017348,-35.648825,-34.688574,-84.651476,-84.367753,10.176166,72.729583,127.054461,119.421261,135.441058,194.487465,201.556149,132.465475,69.536069,11.084426,40.946209,122.753124,153.998992,178.01153,245.972729,250.275472,185.157555,174.495272,246.188946,283.092727,305.133559,214.714894,138.26727,30.211964,9.357356,33.727886,81.560613,168.704695,147.299888,112.745137,68.91243,66.506094,84.675732,115.250685,181.045149,159.754763,-12.361386,-158.744366,-162.806424,-53.705759,7.695946,22.179302,-5.567474,37.405285,132.285367,117.943304,43.294289,44.021635,87.565479,83.992894,26.500431,11.255745,68.866904,75.917252,13.396618,-106.26945,-114.608916,-53.986935,-30.642804,-33.062516,14.371498,55.001458,96.451531,81.718441,-20.055445,-72.543237,-137.053566,-152.86326,-118.508327,-93.243443,-115.576917,-151.0109,-161.929672,-190.799611,-182.299353,-97.057257,-22.447624,-13.143353,-60.514845,-109.545425,-167.251387,-150.262885,-133.395027,-162.224573,-162.827595,-138.678343,-161.609092,-162.291108,-133.714887,-88.00598,-71.325566,-45.167788,-4.005242,-0.401445,-86.728242,-134.517199,-166.128475,-172.219415,-252.279721,-319.877188,-357.08719,-285.715726,-268.356864,-245.501743,-220.594856,-127.452667,-75.430306,-38.928329,-23.454611,5.519267,1.789591,-56.523932,-159.888891,-157.442735,-136.14401,-169.482533,-245.126706,-144.630486,-61.794389,-34.162516,-98.837967,-212.716317,-199.581072,-66.535936,-11.043333,-16.840812,40.124179,77.601984,67.74866,61.967394,69.231554,35.74691,-26.857072,4.421523,8.385023,-5.856867,-26.729895,-96.948916,-105.773421,-37.052778,13.335613,-16.24262,-101.720888,-102.801187,-51.225042,-32.592607,-0.54626,28.947705,79.092447,-20.717624,-120.694436,-259.254717,-281.941861,-334.97624,-368.498346,-315.420213,-156.751511,-128.676993,-168.081127,-192.556654,-199.57174,-165.508955,-73.930545,-39.366269,74.737948,181.730178,182.80299,108.638117,50.380017,-6.75361,16.943531,55.401662,6.99435,-30.28817,-99.145935,-128.993625,-178.947245,-180.571216,-85.469366,-23.339484,-15.205592,-109.916227,-143.093641,-191.58452,-213.730004,-162.939031,-83.008408,53.398249,70.921125,75.431808,149.653945,174.24093,131.01372,103.773737,83.975318,72.371509:187.217536,181.612639,143.941572,-8.680976,-63.609558,-35.066822,18.040952,153.822815,284.117818,303.216592,223.443695,140.050247,-12.606951,-38.927454,1.713864,52.007426,157.576338,145.367307,98.816968,13.198954,-0.051847,56.684067,114.786611,219.270663,254.529938,263.29768,252.538376,221.440337,170.399653,156.75935,114.804087,106.020521,148.450132,135.587903,79.983548,-36.707781,-68.516369,-93.228397,-84.36822,5.080484,57.746847,25.952638,-58.979464,-81.625516,-87.235315,-57.64001,59.655593,122.451041,197.447642,143.470868,82.694861,-27.402385,-54.15944,-43.595164,-33.355439,-12.517513,40.994638,37.29442,-97.771653,-197.041737,-307.988399,-278.660598,-146.277754,-113.60224,-124.395452,-138.994271,-148.992184,-173.561106,-161.108937,-82.755895,-36.688451,60.663794,127.839958,121.458897,35.013883,-18.601183,-102.648437,-129.709854,-119.420324,-76.07149,39.119694,88.256931,39.267536,-184.736193,-274.226625,-278.288912,-240.58811,-195.669394,-196.441541,-226.654491,-328.05209,-369.623863,-399.538301,-401.046402,-432.761281,-451.313963,-441.484387,-460.779849,-497.44353,-546.54442,-547.041319,-506.373503,-455.982714,-273.200979,-122.462816,-132.174757,-243.910021,-278.305151,-284.86626,-267.515203,-161.61093,-89.016876,-18.44536,-54.065226,-105.519973,-298.900264,-383.631991,-385.389926,-307.558748,-64.079341,45.598048,-11.493379,-217.048245,-290.569637,-296.348983,-251.201995,-158.427472,-112.761083,5.778834,52.92779,16.434925,-88.749245,-109.791302,-73.762203,-56.685198,-58.882538,-64.752615,-64.425801,-22.755625,-7.729761,-55.099991,-81.539643,-45.60897,16.407561,150.326491,137.990687,83.023026,19.471338,25.649672,44.820925,25.373594,-10.130004,72.837951,96.013742,32.12968,0.329778,-3.947794,-2.435124,-11.968542,-25.610682,-79.458016,-76.236005,-39.395133,10.245173,7.565832,16.130815,25.572837,-3.604197,-21.22737,-21.421169,-51.268099,-69.471885,-67.866502,-25.917494,133.066134,214.562405,297.111943,213.929411,156.731696,107.633712,86.587902,33.946936,43.817982,135.750169,154.193589,124.796007,58.825584,8.729888,-120.73911,-148.177008,-71.376305,9.954363,147.780212,171.250278,150.643445,62.679621,14.569152,-4.424871,23.993563,135.384666,233.517477,201.54961,47.12694,6.498017,47.942254,109.213291,233.121362,262.423608,267.673193,263.669671,246.03674,137.20577,74.763275,36.562771,55.76797,122.078565,177.609825,175.69998,141.727623,137.881398,189.290382,238.298064,323.96884,359.3115,409.776179,306.314235,219.93018,119.140754,108.961365,126.032276,150.467355,232.858789,274.453606,253.957164,174.804883,139.0246,114.381816,123.035464,131.502026,138.537702,149.708783,60.324605,-15.078359,-155.92512,-177.386129,-49.015421,55.893299,181.477576,162.763519,143.767484,143.495729,130.959825,49.355204,27.666679,94.619118,145.899111,154.269625,35.977855,-22.73002,-87.873788,-95.993856,-47.230295,2.690887,87.099653,83.311004,53.428299,12.497882,7.59593,-15.186314,-28.5446,-58.96153,-68.952005,-48.452661,-41.731312,-58.309589,-142.398907,-203.237291,-253.871516,-218.205469,-63.084741,84.473948,88.515251,-40.268638,-122.153697,-235.496856,-263.67273,-275.361069,-235.670975,-56.146046,52.429488,30.779293,-83.54649,-133.055335,-169.415896,-155.391255,-53.064347,53.402884,37.250079,-85.047486,-117.11963,-81.972662,-57.923763,-109.504524,-155.376925,-114.549415,-95.955351,-177.724252,-313.794108,-283.842108,-98.156992,-22.663696,65.440568,143.323778,141.898377,10.301302,-91.955825,-245.47873,-271.732239,-260.137842,-242.532032,-220.41402,-198.330408,-185.215155,-237.451074,-290.351651,-322.597237,-286.539527,-133.910253,29.675899,62.312696,19.998005,-28.894599,-102.663094,-110.993027,-99.874345,-82.739409,-34.408378,2.724734,21.749901,11.361576,-40.497999,-162.06223,-194.753576,-194.606415,-127.218565,-125.784265,-231.120649,-286.344008,-320.890107,-298.127299,-215.761465,-173.024712,-93.13656,-162.67387,-279.901604,-488.354343,-532.233378,-571.155622,-571.23984,-439.876816,-257.293069,-240.249431,-289.270924,-295.653874,-282.20201,-284.133133,-302.925525,-274.557263,-52.348531,168.991363,205.475816,141.059474,62.268293,-52.172083,-52.234878,4.888972,44.835501,35.608555,-68.157163,-149.441257,-253.204793,-235.522922,-130.177957,-99.778417,-110.45788,-148.667663,-168.380917,-180.232567,-169.153322,-123.680663,-76.741042,64.042493,149.453725,143.800637,105.285335,88.558964,26.735034,-1.776012,5.845512,24.867822:148.597142,-7.859846,-75.591813,-132.255432,-136.074317,-81.115817,-40.778874,-24.666653,18.968369,65.806071,61.158382,-14.301753,-141.388686,-133.814825,-57.580737,-13.806529,114.188045,152.883737,106.283997,4.054231,-11.847651,40.53115,80.979662,123.090084,117.986864,100.529456,113.397119,163.875473,223.920945,190.784724,138.563816,176.082079,232.368395,42.337017,-78.289827,-119.420541,-49.148779,18.215696,-46.112904,-192.327106,-159.81844,-133.324046,-120.363342,-107.947359,-78.646369,-54.817521,90.964755,187.63051,266.576659,201.687921,178.349366,175.274453,179.779226,200.651293,207.169275,192.170513,198.122043,214.494003,194.518965,144.642702,38.750117,5.845552,-58.228384,-92.030716,-115.752548,-135.047177,-169.729765,-267.036592,-281.4116,-201.220697,-162.062952,-84.293306,116.832053,209.856609,269.546838,245.093255,106.904324,24.94602,-41.277581,-13.955229,95.817248,121.028766,78.949025,-34.233491,-70.406609,-49.112712,-16.410331,-6.147742,-44.376016,-73.710592,-136.028231,-176.527318,-299.687129,-340.472207,-310.234718,-267.462931,-200.154684,-184.419919,-184.410077,-156.327022,-135.210447,-102.942906,-100.885656,-172.32127,-228.526996,-209.418146,-154.227262,-141.837091,-132.807723,-120.414854,-81.809164,-53.687328,28.33809,56.328427,38.534989,-58.338076,-144.431736,-311.969675,-345.289732,-282.685699,-208.880001,-206.488656,-168.547834,-142.565591,-200.67283,-251.15435,-247.206759,-203.038316,-130.766971,-147.753481,-161.319301,-106.869848,-69.779786,-109.992216,-182.228413,-293.216042,-283.971285,-257.593928,-135.387583,-64.734337,-84.322593,-173.43611,-305.823614,-291.782514,-200.813959,-215.17094,-227.790225,-193.415222,-173.266836,-142.023982,-129.360784,-92.900691,5.191389,41.115753,42.312552,27.448404,-14.062727,-44.32792,-137.866714,-182.572404,-132.998839,12.799911,40.791841,63.819342,87.925193,92.93965,54.745325,-18.253229,-10.608711,7.714491,19.528822,-7.285525,-62.908785,-29.063652,153.353318,232.42855,297.250844,246.722748,172.618658,44.399634,38.68208,56.363773,30.433755,-40.198829,-14.380955,37.328078,146.838988,151.989809,15.47393,-59.402588,-73.808384,-35.641886,21.941703,43.153248,45.525854,-36.956434,-103.208483,-76.153174,19.710417,153.910961,179.557603,177.998483,124.207388,84.270625,55.466921,90.08675,190.564631,200.020461,118.443292,42.414141,58.89139,164.657673,196.665015,179.531463,157.500717,122.828454,113.770849,128.758943,193.688576,217.047271,208.133336,197.701569,202.41989,218.885701,271.982074,279.080597,239.724658,105.98584,50.909432,53.899619,108.857132,214.968282,220.650037,208.911431,244.499766,281.104229,306.036315,301.800156,271.535834,227.244913,116.172558,8.108156,-42.897308,-76.662691,-39.216166,99.215021,137.075838,88.860719,57.680397,76.297704,122.793065,147.074924,162.750503,138.706748,52.228486,11.25221,-5.885472,43.311898,62.574081,-1.028269,-103.608692,-248.828236,-196.826995,35.238605,141.875063,136.938057,83.560351,59.171991,44.940916,46.627041,3.588384,-39.736206,-72.429499,-38.67417,-24.170613,-54.535794,-118.405667,-204.944081,-168.640939,-7.59585,93.719233,90.396414,-8.598439,-70.993322,-105.006087,-80.151542,-54.878005,-53.334624,-50.988105,-117.519812,-146.742821,-160.043265,-177.091981,-214.340878,-205.919263,-156.281378,-124.744545,-134.662884,-149.185587,-135.422503,-144.012198,-176.118696,-249.803561,-277.117835,-293.064721,-326.465845,-347.77964,-342.035403,-326.341149,-267.853256,-214.298116,-116.815114,-88.641833,-96.248364,-157.331809,-206.640537,-275.191744,-264.595069,-219.218395,-216.459218,-207.721671,-156.740616,-132.422225,-135.463076,-174.886042,-282.370522,-310.042534,-237.219313,-93.960816,-48.588111,45.05389,91.944554,95.986879,70.393618,42.610988,19.661823,-51.099541,-62.343121,-40.044838,33.377113,52.970284,7.714826,-34.213115,-26.602113,87.984657,88.902968,-45.326993,-90.696427,-27.880655,18.324157,-9.667139,-50.364574,-45.324505,-31.294665,-83.355982,-240.522055,-298.805142,-338.973487,-332.858101,-256.458839,-45.429041,37.758494,9.334824,-37.972051,-59.980888,-66.365633,-82.968627,-71.634124,-27.486218,51.85227,96.0451,86.466515,11.096854,-125.443554,-119.986429,-44.152396,-84.379954,-149.941228,-228.32733,-208.028863,-146.063286,-141.616049,-111.871699,-74.265985,-32.72672,-70.265118,-101.908347,-157.614791,-164.796253,-98.548691,-63.652571,-91.275857,-79.606889,-30.913966,43.133935,49.839847,44.854365,55.114327,76.080619,57.70346:192.406885,123.777559,37.682789,-1.438948,84.123071,314.018814,348.808377,205.395333,82.957999,72.990431,34.115093,-18.798917,-66.915588,-24.818291,80.259736,120.04938,218.98624,202.306022,115.352641,-36.277903,-46.644414,27.607331,81.70256,172.511568,184.040983,167.297404,195.234502,239.710575,275.322582,234.71134,98.694706,74.855812,163.46303,147.711865,60.614773,-72.322496,-82.947384,-51.3468,-39.367151,-86.722574,-191.437242,-215.879762,-183.061119,-138.464298,-42.200581,-7.433147,51.698495,80.940679,92.644332,50.669186,52.080268,121.083852,150.778303,109.854281,57.842792,12.086969,95.432259,147.054572,128.423099,47.409965,-97.400761,-102.834639,-47.733808,-48.54774,-171.579694,-369.453473,-410.540623,-333.931852,-266.462556,-170.053229,-150.128667,-121.510383,-31.315533,38.335735,159.252884,174.118288,76.20591,-11.902395,-115.371084,-72.423929,131.6346,151.795618,56.314996,-116.102273,-117.704885,-41.769823,-44.960315,-120.315661,-155.482662,-157.845557,-113.550262,-97.937387,-196.945417,-282.151745,-370.614053,-358.253972,-293.105585,-248.143916,-213.30197,-157.882617,-186.595903,-266.8719,-251.289793,-145.766123,-89.024984,-93.406969,-133.778455,-169.964343,-224.770922,-201.200676,-106.125301,-72.834559,7.526241,53.552259,20.503006,-128.903319,-195.435485,-185.676378,-121.994158,-28.111976,-46.260183,-64.111796,-55.835031,-48.697413,-108.440332,-173.483047,-277.617066,-269.380865,-139.173861,-61.523315,-55.035076,-43.566706,-61.588425,-144.410871,-172.416661,-182.490231,-167.252209,-157.242428,-125.37667,-101.201686,-73.951227,-94.970885,-168.592488,-167.988322,-75.714099,-33.576943,-60.608038,-152.765885,-182.277748,-133.9151,-86.483192,-71.742473,-58.296855,-28.563562,13.115289,17.234841,-23.975009,-59.557644,-107.183263,-111.098443,-72.620262,-5.007979,16.224116,13.098819,8.829744,53.37126,64.745462,-34.019441,-187.514592,-231.109735,-190.275802,-128.097206,6.93772,76.423165,170.334862,192.354108,247.454589,207.48419,125.281091,-27.118152,-70.750912,-126.122743,-133.295778,-130.385222,-146.745526,-113.973289,46.248268,94.547312,24.189952,-36.941194,-91.354162,-76.456796,25.753385,65.212557,12.400202,-180.470735,-260.791059,-256.642756,-182.221493,-53.522345,-68.408903,-109.283913,-125.483314,-89.212942,-21.715418,-9.905369,-36.112992,-47.392779,27.161038,75.47186,20.089946,-122.842525,-137.056608,-32.394597,37.224996,134.988008,205.656513,221.981683,228.261072,228.833929,196.925845,177.470593,206.823378,253.731886,358.716261,357.9511,302.337205,177.827451,134.933468,127.624347,169.320306,288.147572,355.754467,349.884269,296.05269,274.715423,295.771358,334.424232,327.173655,252.294498,101.668179,66.502962,59.443723,29.712133,26.458073,54.703348,56.22095,13.018099,71.216192,130.69032,177.494731,171.561439,170.731167,173.192265,134.145194,107.714145,156.385066,231.864295,193.249702,-7.502559,-99.740277,-157.563419,-133.261573,-69.344133,-17.609714,5.480069,-10.74598,-42.643945,-43.139102,-21.157267,-74.884756,-139.423546,-180.892312,-92.972134,-56.448356,-54.894953,-80.582551,-138.472137,-160.188422,-135.606456,-14.300652,15.529124,2.259369,0.662384,18.277318,16.148699,-42.929635,-76.667733,-69.62435,-61.40406,-94.899174,-187.108622,-221.501018,-192.347103,-143.871871,-108.591236,-113.498254,-89.945742,-55.852972,-72.247896,-142.515286,-189.641756,-337.827196,-416.36322,-467.038302,-406.328247,-360.317341,-239.164686,-201.39672,-230.714812,-252.932958,-215.778897,-107.219946,-58.7652,-10.259746,-23.288971,-125.725244,-176.013693,-247.380079,-281.549184,-281.135114,-141.472767,-80.885918,-131.138306,-208.1013,-252.13936,-215.810517,-151.782199,-87.702822,-38.135123,97.517214,154.383817,122.391364,42.178255,-105.590451,-133.395581,-89.357583,-49.045588,-64.881977,-50.689372,-4.579769,52.472517,47.965294,56.328941,167.746342,210.761788,196.387795,188.068998,217.98538,233.695474,236.835633,223.173753,206.899128,172.250272,117.271903,7.161338,-32.10289,-136.875217,-185.63288,-111.8085,140.007518,203.679264,156.615396,107.518301,44.876255,43.844396,26.980015,-20.674952,-67.531168,37.300899,75.151512,46.226651,-13.295507,-131.919378,-128.164528,13.256283,71.496768,9.068454,-159.413287,-207.121311,-205.068126,-167.276763,-85.652353,-75.591231,-103.76762,-102.981315,-98.593825,-128.26807,-146.167591,-128.957911,-114.814192,-115.939651,-48.305185,7.110582,25.405587,-16.595466,-83.893735,-75.552993,-12.035299,3.162765:125.757108,-38.720199,-86.323079,-37.793645,-3.151767,-25.46898,-58.556812,-42.540775,86.685768,118.889715,43.660808,-31.402688,-133.339674,-114.462712,29.941516,93.078391,144.204904,112.754856,67.027707,-37.154615,-63.303553,-54.278862,-34.65985,68.995628,214.499596,227.192031,153.75851,130.037327,99.226519,64.386145,62.888234,114.968991,133.702996,-10.421088,-74.815504,-114.991383,-104.344461,-109.391186,-134.302971,-128.39329,-81.236194,-104.333393,-151.134234,-154.380954,-188.328878,-171.764148,-12.894168,49.864799,63.164677,58.611406,45.362917,-25.305848,-38.352441,36.755076,88.117952,129.678483,121.283611,110.535231,27.94373,-37.407453,-99.104695,-71.838657,-17.984558,-50.626303,-171.266189,-167.130676,-139.596112,-149.109838,-166.605528,-155.227233,-139.839549,-101.365169,19.445243,101.534041,196.930579,178.191384,56.041985,6.826305,-18.902909,-7.909795,67.968945,86.37984,36.983511,-97.375496,-149.30228,-163.754028,-131.836261,-55.19094,-17.471728,-39.965994,-152.462416,-202.463888,-239.078272,-242.709191,-262.799548,-264.548234,-272.232691,-368.413494,-387.4718,-242.673128,-162.715634,-181.562838,-231.418261,-251.205435,-226.532383,-224.452844,-155.583283,-105.169957,-92.062775,-104.354408,-96.6176,-83.659285,6.221107,83.372503,38.364594,-160.018281,-238.502952,-278.509901,-269.686634,-220.569022,-112.427315,-79.078081,-144.008629,-219.823029,-276.585459,-220.877164,-75.3534,-48.97006,-74.093007,-104.570988,-119.627907,-140.698937,-135.144385,-84.50436,-58.725448,-80.157745,-112.403137,-91.336371,-23.663295,0.93056,3.76518,-38.004133,-165.703818,-178.935778,-38.983007,82.671807,86.098867,69.673415,70.15961,32.39691,-25.910909,-96.390459,40.920271,107.078982,77.065784,31.274875,17.687994,30.698861,-1.210563,-47.287156,-59.069855,-7.3927,-27.507819,-52.206057,-3.735066,130.915523,147.329684,80.463607,59.468301,62.02866,9.824789,-19.225602,-20.681794,9.564374,114.85446,162.904666,224.964531,211.545035,169.568038,94.801051,88.37049,98.726464,88.447951,75.561753,127.930457,148.520585,174.022895,168.645165,55.651649,-7.202793,-25.983119,-13.725298,8.933184,94.560183,127.706757,67.554589,-4.861094,-63.991102,-33.250493,51.532781,90.263887,74.933624,61.500668,83.041744,95.207081,92.491464,147.870861,189.389803,231.860235,199.140025,168.649349,155.639298,169.583767,152.694435,115.711395,94.79325,199.204546,233.096256,224.313986,217.562023,211.700417,190.13455,135.626677,149.395022,260.410703,272.15124,214.701539,73.719088,11.894305,-55.325751,-35.849459,85.461459,181.375531,182.515237,129.467498,114.973411,130.85592,138.473238,107.453079,73.788001,5.591932,-68.657105,-85.415531,-38.805729,-7.305859,24.784618,25.284443,8.309946,49.946493,77.180534,85.881369,92.483988,88.7524,49.540158,-36.153551,-31.798564,65.427977,28.329381,-79.760414,-251.664964,-241.42128,-129.163013,-93.551762,-35.419216,64.129221,87.838222,110.803273,136.770172,117.547449,58.246639,-50.826087,-69.894693,-47.963653,-49.823,-66.807193,-112.890871,-149.850446,-202.087025,-187.640672,-107.809647,-62.92619,-81.723925,-188.160664,-239.834269,-253.833429,-218.522635,-192.054335,-218.18512,-208.779065,-88.394584,-30.53264,4.256184,-39.113261,-143.524519,-142.644161,-60.70519,-74.336385,-117.262297,-142.061164,-137.207878,-175.782482,-201.184498,-234.598196,-255.340736,-286.626005,-287.45079,-286.594951,-264.057709,-238.659171,-182.794565,-141.141699,-14.755549,15.820327,-50.780416,-190.238519,-201.037339,-170.468506,-165.157607,-192.439654,-232.054863,-278.485674,-161.699607,-94.742145,-92.991459,-156.276389,-240.84149,-205.144689,-73.710492,-20.104834,-19.478497,-11.633645,22.716519,78.335009,55.602097,8.224001,23.745354,74.092841,111.066757,125.693073,106.562852,61.730232,-52.590356,-90.132054,-94.435368,-79.483175,-95.627029,-132.576246,-140.383755,-167.510773,-174.416312,-173.027545,-165.797151,-62.274995,-31.559988,-124.819711,-369.213758,-447.832987,-477.275121,-423.047061,-260.24353,-196.401996,-183.702841,-107.599715,-65.337078,-56.493011,-77.167685,-82.063844,-63.471219,29.171445,186.733364,247.62521,226.727598,126.011228,-68.9478,-73.121332,19.167756,40.702364,32.930179,13.260402,-21.211541,-128.555087,-145.47425,-58.237651,-15.977073,-56.300603,-151.657687,-157.104036,-97.798008,-68.960984,-50.684974,-59.957345,-61.101335,39.778003,110.907158,194.685417,181.574241,114.547815,100.830107,82.004036,60.707564:right
-13.040644,12.830811,-3.273809,20.664705,66.323637,117.394023,113.276108,72.98333,36.538898,68.059422,168.640312,164.096188,51.349464,12.921997,34.06098,47.827104,3.773667,-67.582687,-88.898987,-81.327761,-62.814429,-58.24292,-76.924034,-120.17017,-133.518911,-114.492249,-34.233552,-1.541045,-14.3711,-56.67981,-110.757045,-83.845443,45.703352,98.093573,73.485394,34.30227,55.976679,139.527473,160.007446,121.504756,51.052771,49.263765,65.972846,56.743394,33.457486,28.849428,33.003402,30.660335,38.869291,162.43523,213.506345,177.224827,116.614372,-14.509831,-51.015258,-30.316445,20.822345,36.552525,44.252544,32.888161,-4.652625,-17.932413,-9.825558,12.398704,112.634954,316.282509,400.331787,438.192465,423.401544,369.702726,334.139428,298.010508,265.567166,230.79605,153.678356,123.835758,59.110733,1.134746,-137.636176,-197.331183,-268.487507,-200.676829,-135.618796,-56.475882,-56.554878,-112.80854,-131.029026,-85.325908,-46.352859,-69.151174,-168.690712,-226.652815,-323.580193,-339.358264,-277.112927,-208.439732,-69.240313,18.099978,61.018707,154.555697,178.402434,140.974036,82.97108,-108.905548,-216.933536,-191.247985,-150.09771,-174.404136,-225.651308,-214.452034,-142.774949,-132.396262,-168.284078,-140.412588,-126.340877,-175.998863,-214.579422,-265.168744,-274.699083,-268.420672,-226.041409,-187.874155,-111.477632,-92.58177,-114.057456,-134.844152,-105.534775,-54.037114,27.758066,28.212358,3.641633,-63.06239,-99.902192,-187.232759,-210.671449,-186.882703,-153.496627,-143.897551,-143.795497,-149.459714,-184.076127,-214.004335,-197.059123,-151.734265,-116.992495,-189.205244,-253.437963,-348.684688,-357.917294,-343.281857,-322.633735,-284.105572,-250.002801,-199.61612,-141.264316,-174.654042,-250.533263,-238.504423,-125.04056,-67.070013,-7.28779,19.185808,20.186651,22.042931,25.4052,-50.711737,-123.901171,-228.641786,-207.795815,-154.03178,-89.286366,-103.635722,-147.394276,-159.270498,-187.365202,-212.042343,-251.942818,-287.413221,-334.681265,-414.277245,-401.634698,-275.167754,-184.471823,-57.396521,-69.877558,-93.996805,-124.387736,-122.062889,-106.933446,-107.247846,-114.784565,-125.792905,-72.47833,132.687492,189.772845,137.426506,82.232798,-35.168865,-84.009246,-83.516284,-13.406327,-7.735888,-37.506091,-43.059251,-75.448053,-105.280165,-95.67971,-67.427431,-79.690293,-179.056971,-238.384839,-320.778528,-328.261488,-316.609482,-304.725825,-259.390772,-219.677868,-177.945275,-52.468558,-5.695194,33.438454,35.093327,37.623333,45.602246,77.571924,103.903794,86.639878,-22.927727,-88.643242,-133.0969,-91.4696,37.440382,134.868332,174.384456,180.692844,150.907942,138.269857,162.976282,235.87369,269.286262,329.167282,460.338018,525.805496,536.425758,492.884951,421.674522,433.881226,522.008826,536.167153,515.616944,462.843449,448.76355,464.495629,478.296076,497.244369,493.698085,480.437776,492.176071,474.913848,382.660618,319.721445,202.856069,180.094176,205.788372,244.618231,246.139639,183.708301,123.657636,3.032192,-19.645027,75.952829,149.864674,181.311799,124.449225,109.637306,110.552634,106.704594,37.532385,-8.183931,-52.16137,-37.811763,-22.087852,-17.870719,-24.882428,-32.550875,-40.425871,-39.002653,-11.567814,63.058884,94.428079,99.405791,102.860561,64.011571,-134.799321,-214.325695,-153.072792,20.562576,72.312873,118.064912,112.278642,29.585007,-21.094499,-47.790696,-21.457528,68.667884,138.191416,133.4537,49.283865,-37.048994,-255.309243,-313.999512,-286.168044,-202.525949,-161.171673,-104.887143,-93.790371,-94.715549,-108.261342,-143.8999,-147.891259,-133.981576,-83.035328,-26.716936,51.779464,28.360824,-103.418347,-152.835865,-145.499067,-49.728932,5.857058,98.229789,122.967933,104.947709,77.593481,97.01898,148.633926,238.795455,229.968971,194.861108,165.658305,172.898173,114.858182,50.830106,-29.22271,1.919197,18.231024,-7.836708,-9.240801,17.796639,-2.107404,-74.747991,-91.932523,-69.197393,43.497469,84.10196,1.059328,-96.493216,-204.690851,-162.353509,43.678957,159.630493,140.650071,55.293123,48.619257,34.910685,-31.105942,-132.366072,-100.58459,-1.415146,3.662708,-6.989066,-27.298872,-22.88523,49.708488,96.265365,126.876027,125.590997,144.801692,154.273496,124.7403,36.633015,5.89951,4.471921,13.699771,-7.520839,-56.742635,-81.817877,-122.77584,-132.743653,-126.866872,-108.971933,-31.188687,88.885706,143.388888,218.357216,223.028681,136.282157,79.065404,46.416332,69.340381:19.233769,-4.991483,-16.260585,-22.932064,-28.732049,-29.374709,4.880993,96.007703,126.826229,135.188398,132.803408,113.74049,72.380811,66.788558,115.290573,158.152934,166.544207,29.800435,-71.99746,-225.168468,-217.478975,-74.258757,-26.746268,-46.252932,-50.613548,-40.027138,-5.42776,25.039087,15.527202,-33.799798,-95.012186,-83.28296,6.757569,36.762888,2.993166,-7.704991,27.795267,73.653139,91.520071,168.207652,218.051547,205.914036,139.98331,108.353019,68.837113,79.824339,189.492522,251.24872,323.216802,330.604698,311.637059,252.461675,206.024428,83.160924,57.027012,103.25699,150.843001,172.538074,160.208024,87.845787,-106.352138,-150.842659,-99.482484,-38.170213,125.490981,276.831362,322.300601,372.319525,363.029452,274.789896,237.535639,223.443587,234.940833,207.753183,50.824783,-42.582405,-177.725549,-209.005,-177.874336,-127.339379,-16.272269,71.966315,96.738639,90.719004,62.459227,8.660931,11.50725,60.130723,90.814214,92.631018,39.664358,-21.628391,-179.384285,-254.020379,-312.56245,-269.445496,-78.015612,74.258801,101.868601,81.439269,35.024223,-75.972865,-105.124254,-153.016014,-213.654319,-219.917027,-198.751877,-184.079348,-182.495078,-190.21702,-163.578986,-141.371894,-94.892818,-55.848753,-68.601768,-130.004428,-172.702917,-282.668108,-311.517812,-267.456004,-177.321537,-141.116394,-115.387404,-127.140126,-167.737028,-183.786932,-168.474175,-132.51192,-51.357412,-61.330536,-101.276997,-155.374956,-172.178835,-251.162733,-300.598813,-333.725726,-225.09137,-140.785244,-68.377354,-102.515194,-218.941326,-247.742642,-159.912353,-65.542685,54.134924,-19.639477,-109.227376,-273.625244,-306.781543,-274.073207,-249.99436,-243.176172,-213.893109,-183.278311,-173.806505,-210.267586,-301.613406,-335.738076,-329.097616,-262.072171,-92.294349,-44.082893,-35.154777,-13.694747,-52.976779,-215.778558,-245.145442,-124.457935,-22.298974,-18.755954,-45.416178,-72.432177,-159.7142,-194.103161,-206.096989,-204.764678,-208.112294,-212.372908,-240.151819,-303.270019,-301.148382,-215.883002,-153.829781,-82.340313,-66.407716,-34.227896,30.267216,20.312725,-52.316077,-83.336243,-113.982202,-122.634131,-123.451932,-79.745571,-68.178018,-88.93668,-105.438647,-147.829194,-158.453454,-68.115574,70.083898,76.295726,-28.625043,-93.172724,-204.939799,-241.016034,-201.134695,-139.926121,-110.054291,-261.152304,-316.76778,-279.353211,-251.330696,-286.889779,-306.325428,-237.6351,-94.931918,-55.273243,-77.163996,-109.211704,-98.747851,-49.8786,37.207571,55.484948,61.765468,22.524638,4.465887,-25.664749,-63.056033,-168.645887,-201.034278,-127.51318,74.770409,143.278376,181.135014,178.239859,134.742642,112.736073,169.228263,235.308354,348.027661,407.76871,410.151043,385.282957,383.312794,402.57203,412.049731,423.751568,413.127095,400.075047,368.071994,370.533666,414.600574,418.28986,403.736656,415.243263,462.899392,467.773689,444.925744,370.863008,309.065217,185.471789,172.896104,254.508295,378.669304,401.346974,297.626137,215.072376,121.136814,122.545062,223.024426,290.494704,343.022995,265.017791,206.817909,139.971559,125.192984,82.607005,60.030942,27.161577,69.520242,124.559364,219.241155,226.924754,140.828735,78.328941,38.339801,57.241602,61.703687,33.212586,40.386387,57.081074,19.705753,-134.691398,-177.55376,-128.244331,-84.110169,-104.423567,-133.850572,-106.332424,-60.957762,-94.606235,-180.072541,-165.613636,-42.464333,13.122836,-21.300607,-146.51221,-214.703745,-318.49648,-311.109168,-201.296381,-103.274668,-69.38154,-45.971344,-64.543294,-127.725435,-145.324124,-100.975797,-31.617156,132.241494,148.192852,100.456139,27.830239,17.05979,-21.349465,-58.564637,-119.835054,-73.801791,-17.508359,70.036596,106.229997,169.146805,173.500638,158.253455,158.90274,184.865348,246.529119,266.475981,248.11406,214.475962,147.474728,142.380152,162.235673,120.254503,78.408534,40.761998,59.629932,55.349962,-5.071777,-142.644948,-162.97078,-72.723244,51.86436,57.025775,-57.212465,-140.35781,-185.121671,-103.737229,101.918155,123.573407,91.140588,50.249682,30.837848,-62.62751,-105.111623,-73.11308,-16.012179,68.60108,29.597979,-12.131856,-40.833279,-25.324163,52.263861,96.948892,104.659977,48.744027,51.996891,117.71527,137.945051,70.938738,10.813412,-40.89907,-37.657294,-33.038181,-4.967754,5.857002,-47.328001,-107.207463,-191.676983,-181.117915,-90.79297,34.387558,103.269717,182.496129,173.542286,103.512865,69.901627,35.139236,30.820945:66.933527,124.618288,98.814302,3.84975,-12.817661,7.342063,22.513385,42.390911,72.457956,110.526222,152.81319,123.49635,-3.777048,-52.278997,7.660148,99.999312,204.385275,76.620138,-27.791687,-197.860195,-236.705121,-228.718317,-210.696067,-177.360222,-108.707175,-58.185165,33.824835,42.370868,-58.13152,-117.476956,-121.719892,-77.786144,67.324934,182.83585,163.988659,51.543065,18.83513,55.688568,124.043419,249.368152,246.265603,206.477288,77.136196,9.264493,-39.259143,10.310502,187.092956,264.042206,379.034837,403.917229,362.801806,267.753718,232.524899,137.912457,107.374806,163.370796,259.025799,266.481934,200.102279,154.355586,59.455287,8.471172,-35.008777,-4.433769,154.517578,322.968918,345.078099,269.182223,210.92938,125.586931,104.260874,96.454789,145.303434,164.551624,79.127809,-3.22578,-115.418938,-133.983204,-72.911525,-2.98706,67.057122,-8.157693,-57.365675,-94.20473,-72.286318,-17.193928,-5.071088,0.925532,25.380047,59.531165,105.838157,81.788107,-67.414885,-147.48812,-190.682806,-157.809279,-55.867053,24.065036,23.888884,-43.958932,-84.754246,-136.878462,-140.696657,-106.798539,-93.381965,-134.732702,-242.502328,-254.49966,-229.731379,-223.64798,-194.925398,-173.867965,-129.311214,-120.306557,-155.352542,-235.144649,-267.807905,-340.317133,-359.54788,-328.891191,-233.914973,-180.076336,-133.888458,-157.342107,-227.752875,-244.290389,-239.473127,-225.604152,-161.285231,-97.581622,-114.499436,-235.327758,-300.084099,-377.931888,-384.636131,-308.861307,-141.59631,-76.611906,-43.861653,-67.554726,-155.148032,-172.526982,-79.089367,-5.530682,78.058646,-14.547757,-102.734251,-200.258193,-217.88514,-268.615388,-283.005818,-232.932532,-111.529788,-80.659393,-141.844136,-187.821313,-220.798653,-225.476116,-220.632077,-180.565988,-24.102353,43.883611,11.992809,-106.057634,-152.588977,-162.312852,-142.119508,-113.888101,-54.148266,-10.826075,2.266588,-23.625519,-73.435011,-110.021577,-183.587045,-185.686892,-137.875937,-138.76927,-169.230934,-232.195477,-248.729298,-213.261484,-154.698871,-26.586497,6.250914,-24.221796,-121.345877,-156.827172,-199.166221,-200.038241,-137.068095,-86.673536,7.438999,-18.818343,-102.651712,-272.687043,-302.462684,-277.130368,-257.94281,-198.427259,-73.699469,-39.87104,-60.780301,-71.944869,-112.219591,-149.25083,-146.951207,-104.031359,-55.88767,-118.513894,-158.846018,-192.503617,-206.249323,-243.839354,-235.355856,-140.554857,-20.597651,15.39158,-19.746449,-80.113986,-131.442155,-77.682792,110.347771,177.783813,170.085422,17.546401,-45.455974,-69.131278,-84.678871,-196.567009,-237.062421,-184.482766,-42.028252,10.17896,44.340075,18.843522,-75.207185,-69.585836,70.390114,131.328017,231.979162,346.002885,363.235271,337.820079,322.688477,296.637444,294.701444,336.431715,303.747763,231.994644,158.200933,192.746578,292.027906,325.233277,373.034963,378.411592,361.011887,337.952725,316.348848,266.533597,235.16313,182.762113,186.12451,226.731476,294.879013,338.689501,346.716196,292.693853,145.080401,109.501069,194.241302,283.735361,405.267195,334.442741,279.281442,286.656415,301.59518,230.083093,188.157491,183.992589,231.193758,245.832481,222.499435,191.464645,142.885088,135.371465,111.840368,84.980798,47.23005,4.352615,-41.01528,-103.757261,-113.265213,-161.236939,-186.386412,-149.423165,-71.656592,-86.073687,-195.949431,-217.611659,-164.179577,-146.967665,-138.683299,-114.326319,-47.488295,-20.198743,-38.244776,-141.183154,-200.632028,-225.089565,-190.269303,-134.116932,-51.130279,1.162966,-16.980385,-94.453835,-214.654564,-197.099752,-30.286565,64.929815,152.592216,84.668777,31.239513,-52.533395,-75.935011,-84.897625,-72.885277,6.52757,127.380462,149.892846,129.896028,135.254762,169.970915,179.159139,216.272309,255.281542,355.687332,439.05482,446.162569,375.919238,320.296406,219.535146,188.488559,169.806905,159.257287,139.380625,94.642938,90.474366,60.220684,8.333461,-84.388832,-89.713907,1.868722,89.260068,51.777531,-113.980688,-163.424108,-134.999368,-78.059508,31.188254,47.747491,16.304665,-63.416278,-71.511123,-61.907689,-79.189829,-97.538823,-72.983071,-20.014853,-51.477414,-78.025404,-73.221641,-50.445667,24.476238,76.711748,155.295926,151.646933,110.25673,17.283964,-1.543995,-46.247883,-88.756522,-128.895693,-109.019525,-31.722388,-36.884477,-96.792959,-191.405846,-185.727698,-150.827946,-142.6184,-61.183283,90.163322,142.93014,146.995664,100.123947,11.871584,19.802035,108.305964,135.513834:-35.137874,1.701522,25.733488,115.577964,161.295696,141.141633,108.92573,92.542762,95.212922,113.174731,142.28822,120.890287,29.620514,-10.128361,-4.162231,30.466552,35.639718,-25.3846,-48.993703,-105.490101,-149.682766,-247.334134,-261.817403,-158.536302,-17.715086,26.495141,70.042384,60.569077,-17.543882,-63.536591,-96.195628,-64.979726,68.628323,171.626383,159.113609,65.309126,58.269286,147.004171,181.453289,171.03716,176.803331,195.54167,160.130017,94.652997,-53.945605,-101.710594,-65.266391,26.011357,204.871099,244.593435,244.860198,220.24654,173.716223,47.351194,16.838092,42.061176,98.78068,149.91673,240.847772,218.34072,85.608362,56.1939,103.820222,137.543937,241.729942,454.845082,552.400918,637.727775,608.694833,423.550085,324.136748,253.445065,247.123409,204.490962,71.810086,2.46356,-137.099992,-197.95837,-246.503692,-226.141161,-185.570352,-228.988192,-239.566207,-171.901057,-151.296807,-228.696427,-254.164546,-166.486776,-91.650155,-96.352898,-131.029953,-153.984944,-229.882141,-260.551733,-191.888129,-95.932058,77.593023,160.515065,183.96222,228.286418,239.149442,144.017059,47.489185,-108.787773,-117.118285,-97.993773,-159.150252,-213.576386,-228.690894,-209.247104,-191.368755,-190.358403,-169.140751,-176.610502,-247.478575,-411.912406,-428.04061,-392.820361,-393.572742,-383.606909,-304.383338,-268.469647,-226.744852,-204.39164,-179.074221,-196.848005,-203.259944,-151.711785,-22.819072,50.876083,77.401832,62.721671,-0.694858,-154.985503,-188.040369,-155.373765,-79.701093,-68.266779,-117.312929,-135.967333,-144.716071,-155.391691,-133.237399,-97.654328,-65.073957,-75.951492,-117.401625,-300.547565,-383.253898,-404.75906,-347.54182,-231.635103,-218.307469,-213.622767,-177.973464,-169.201959,-211.787358,-236.443823,-147.580369,-48.296018,65.647666,7.373113,-41.941277,-53.905922,-5.938987,42.298721,-4.606326,-127.29823,-73.024874,-6.449359,-14.465401,-82.670971,-155.123962,-144.622215,-110.047865,-104.713863,-101.313347,-87.966499,-121.842776,-257.943398,-304.073221,-274.29213,-208.672519,-78.153716,-14.012789,-4.192142,-13.342705,-20.0621,-91.324039,-158.604577,-193.695212,-134.750303,-33.413005,-68.008259,-79.765969,-28.47058,-6.894667,-80.801861,-141.095143,-127.463391,-14.472077,8.568179,-9.203385,-39.42041,-111.102144,-117.778288,-75.065708,-66.506936,-103.824874,-177.442871,-229.67044,-293.109173,-280.477573,-233.583733,-220.087515,-196.899738,-126.703453,-61.615388,38.048407,43.325215,35.4927,60.570657,137.493731,146.497392,83.026308,17.742769,8.343324,-37.599382,-91.591575,-168.588889,-159.221698,-50.104736,71.590598,84.370063,15.207647,-13.287631,13.190894,39.599336,83.377839,116.20338,238.998092,379.560633,400.536266,343.054575,307.253078,269.081044,263.361386,279.303783,324.444237,319.908803,230.16061,211.516002,299.017814,347.788862,364.567811,339.465831,298.875507,324.703518,328.305022,263.338534,209.276162,127.263251,121.19545,146.096053,128.622582,108.960504,77.048792,56.403547,-2.213309,-7.021682,87.752234,131.01752,94.662909,55.815386,69.750778,119.790482,117.220533,10.489427,-43.916453,-30.815217,78.485334,124.113298,157.889676,131.021895,28.563498,5.019149,66.041394,115.467713,144.583607,82.772251,45.579431,2.197612,-26.361204,-152.396149,-196.653921,-144.234499,-20.243792,17.622799,17.370961,2.512504,8.272544,40.365242,114.767528,117.797575,95.842656,124.517532,104.21941,-31.571832,-90.726641,-133.91288,-133.810707,-121.025668,-58.277384,-19.104459,-12.78926,-34.675881,-53.499722,-50.778308,-24.956207,0.489262,62.065186,74.435025,58.687163,29.434335,10.515284,-77.814146,-129.840134,-151.730594,-18.169414,49.614867,67.066377,58.574058,107.092126,144.336015,218.708039,254.625659,300.342093,326.790622,322.400445,271.283145,228.246443,101.669784,52.882371,58.376009,112.260996,116.622747,52.248005,17.124608,-7.969839,-28.636128,-64.779267,-39.463271,89.245769,159.552334,120.11687,-31.620296,-92.510013,-128.376237,-86.078567,58.323679,69.318613,19.077936,-22.329105,7.024503,2.239805,-54.84566,-85.861819,-16.203609,133.792634,107.541242,59.543164,37.981642,55.368724,52.510558,33.123857,20.257735,121.912538,174.596562,146.783321,83.051941,-41.620571,-79.115065,-92.447576,-89.981622,-94.849512,-108.038684,-134.905744,-202.624706,-224.948075,-240.800431,-226.479516,-140.311071,-28.991428,14.555777,57.306934,60.280166,59.524287,73.698229,144.156362,168.225437:50.79149,221.224243,252.280214,219.060656,178.469479,95.869744,86.635881,102.416301,91.448344,86.399193,82.004531,67.525788,-30.475201,-89.699351,-87.82622,-29.937644,68.072403,59.27827,6.114679,-161.686015,-233.113493,-256.926971,-219.95078,-139.756362,-21.838544,48.959063,72.926395,8.368461,-159.52619,-194.750402,-111.716247,-36.270671,86.812459,142.194968,136.78682,67.896167,21.903705,-11.395567,15.376205,81.535149,131.179657,156.045501,135.980101,84.50958,-25.43405,-48.197459,7.167088,80.938941,233.236635,238.071918,195.504428,97.938957,47.016412,-24.33938,-21.911555,66.783427,180.84083,195.871501,114.977963,45.977661,-30.668209,-13.731325,85.276806,150.49659,311.663262,430.557398,441.659648,417.888294,391.57204,317.959141,293.305459,290.36771,242.000777,184.80479,66.424764,-1.009282,-178.898851,-252.106897,-247.713783,-180.655036,-95.651504,-188.135263,-223.613253,-173.940235,-153.387608,-196.446276,-211.277742,-140.292698,0.231582,39.485406,24.055466,-7.680562,-97.863894,-137.970925,-105.134255,-20.016527,181.04635,242.103917,213.764865,121.919734,73.085815,-15.703911,-52.957178,-129.694578,-124.798705,-85.476097,-119.308754,-200.985762,-341.814664,-362.948964,-296.436484,-241.790607,-156.574336,-180.111832,-247.828225,-365.285586,-397.149581,-460.745957,-469.831214,-380.163522,-221.978956,-167.000555,-166.610294,-213.238789,-305.927387,-315.223281,-248.423554,-190.401648,-13.507149,215.62816,269.831222,120.462298,-56.786805,-293.198488,-260.05779,-86.623009,-30.09661,-16.256129,22.507035,23.740657,-33.356221,-69.243458,-92.674372,-72.120712,-2.376664,-38.524926,-108.108717,-258.813076,-321.029032,-347.533653,-282.582192,-94.556988,-24.831058,-48.023329,-106.213925,-104.877639,-121.649176,-178.32437,-237.543635,-155.169459,136.773979,225.900619,174.89409,48.387261,-6.85609,-103.13847,-132.556165,-120.700051,44.079779,132.954392,111.463957,14.762697,-139.295732,-165.714627,-166.463527,-142.665818,-59.233852,-33.640461,-62.323238,-165.237651,-217.919285,-253.578343,-208.69436,-56.894517,-14.228085,-51.642359,-137.221426,-153.453276,-186.941684,-203.63382,-148.659027,-81.025026,23.056994,-36.13572,-104.410401,-172.2734,-170.563397,-182.883452,-193.504783,-138.877651,-8.777804,22.24971,-4.755009,-37.186011,-127.996644,-159.828923,-109.024026,-48.449921,22.415952,-52.468158,-125.368932,-257.68863,-307.427907,-325.576559,-293.764435,-225.433962,-94.534588,-3.375918,87.063481,70.298209,-7.118939,-22.620632,46.827634,97.755893,159.519022,149.166628,103.122559,-50.186489,-128.870421,-239.484679,-260.333405,-186.044274,8.02401,58.134712,-28.365731,-82.628106,-92.885245,-90.632311,-84.631561,-30.971676,185.911437,307.058898,289.792549,196.573002,161.474339,174.617821,211.789312,253.964785,239.190892,210.807833,103.687934,58.761842,83.604538,146.400454,265.739261,284.144264,259.815784,222.698594,204.78138,162.319468,119.624504,55.914679,88.004811,229.859096,313.807569,324.909333,267.393592,199.473045,57.933261,28.270248,124.783699,215.678079,313.703235,267.876665,249.291818,256.798504,233.711463,146.881888,142.320743,220.417009,296.024337,303.563729,254.193314,220.421345,169.146238,157.436597,177.287085,194.478117,191.516601,125.545504,75.322079,-41.819583,-102.178464,-184.924841,-174.14822,-23.759726,110.994953,109.217956,42.105824,10.633847,-45.063944,-47.442132,25.301132,49.449662,39.60989,64.391086,65.947226,-56.403337,-148.192683,-195.414569,-144.137088,-71.709784,-71.198734,-66.022099,-72.136301,-95.750921,-167.334662,-182.953227,-116.760064,-56.689852,53.78774,73.348735,27.748035,-83.203193,-113.809569,-143.27741,-160.416833,-162.766887,-48.352722,7.543043,24.778341,13.720849,-5.735836,-10.862945,63.802837,135.31269,257.990287,337.076385,337.521651,229.79001,133.797289,-25.812462,-32.700267,64.736102,115.50062,87.321013,-3.694336,-38.610609,-100.078265,-127.264622,-126.423441,-95.418942,25.830828,147.674628,136.734465,-7.837041,-64.428298,-43.851876,12.350568,93.731349,54.873584,16.540471,-57.356101,-90.334981,-152.514374,-173.35463,-148.768148,-109.222804,-18.692893,24.328383,17.699699,-18.520218,-46.420827,-94.032167,-82.344164,27.478307,187.202275,244.071586,213.394192,122.996588,-124.598599,-223.609958,-236.723117,-157.302567,15.071936,33.065695,-14.211036,-149.056434,-219.215091,-260.813506,-205.050929,-40.307451,64.879862,87.648103,101.081532,95.924155,59.341397,54.932702,128.977812,178.238073:-154.184133,-26.774156,45.315441,154.518585,165.388668,110.859401,100.455741,122.168336,45.376729,11.79379,79.053754,134.993644,113.677829,34.828345,-89.305999,-91.366613,-50.422112,-25.121746,-20.218443,-74.986901,-133.808958,-264.010067,-314.237755,-323.098102,-207.546646,-137.159952,-73.908633,-93.564817,-176.564343,-195.704419,-124.257167,-68.953052,-23.654116,-44.567451,-48.470194,-20.414307,-1.576494,15.000978,12.855868,9.023907,12.158937,10.177057,-13.851752,-29.708388,-43.992373,-63.345667,-143.655352,-161.117386,-71.463961,89.959754,125.18963,89.002107,40.631319,-130.894881,-228.692987,-283.074071,-120.504072,-22.277214,54.773376,29.186483,-37.343571,-45.225862,-14.304025,16.994464,159.541942,375.102998,456.546314,524.400888,511.213723,431.17629,398.826482,374.965499,318.317587,250.111968,47.184,-40.141504,-76.619885,-50.927787,-70.928561,-140.93972,-301.186205,-320.033353,-281.999929,-191.887261,-162.055407,-210.789122,-264.384889,-266.322406,-145.4057,-85.726433,-62.052188,-97.650258,-132.677009,-107.71003,-47.56213,-20.29296,94.533586,236.250339,269.187043,281.789286,270.722565,182.899515,121.513429,39.663969,11.163113,-17.342574,-122.698636,-162.243871,-193.064583,-208.937227,-230.095344,-239.171172,-270.153033,-250.173455,-236.997829,-263.626029,-297.583679,-355.090569,-356.448079,-269.116152,-157.17952,-142.298559,-124.153929,-100.159085,-100.364696,-139.730392,-132.98037,-28.599761,195.441236,224.901845,198.699525,148.545182,131.969469,34.10884,-45.595299,-87.176502,17.192893,23.661486,-79.297991,-120.479461,-146.716363,-154.808962,-110.082087,-68.21995,-51.400603,-82.493015,-126.365996,-290.787633,-361.718992,-405.061378,-368.717361,-187.383215,-74.100601,-92.963187,-175.077373,-202.290919,-211.362882,-171.898656,10.445012,100.678458,202.72418,237.69408,227.170527,190.018936,192.531888,183.243414,134.301982,-3.357377,-2.038121,41.933223,12.947413,-46.905988,-77.712919,-72.00563,-109.359953,-123.436705,-103.859386,-61.632511,-71.192833,-196.197622,-244.325434,-152.761595,-51.23003,50.102298,-20.90816,-45.619671,-41.196522,-41.262485,-76.914254,-106.435882,-130.421776,-108.956635,-5.405344,77.170225,83.575913,78.886897,74.533812,36.284996,15.502412,-15.431299,-34.873349,-19.548789,18.679104,8.504925,-88.729779,-162.585668,-229.206977,-179.29891,-35.163289,-69.178662,-156.472348,-288.185212,-293.9413,-257.178375,-230.335702,-175.290205,-123.840094,-72.652721,58.835315,109.368643,141.079758,129.398255,112.364861,117.925727,146.080192,130.535566,82.107267,-6.353506,-7.600152,4.839831,11.920941,135.542183,278.184723,275.065405,199.569921,184.670496,164.442213,127.696354,93.6341,135.916467,271.869098,366.96464,388.840402,390.800139,379.090767,352.834585,348.352244,352.368157,361.028687,337.896162,210.756498,186.887588,325.659009,411.916849,456.500407,429.421463,361.731539,325.227031,315.193035,279.676089,242.013877,129.109663,90.509513,124.680827,214.868648,218.451626,80.859118,-19.57759,-126.813336,-110.478175,16.993827,79.930252,108.273098,56.307635,28.503869,-8.83045,-23.571401,-54.401807,-52.541957,-6.480386,11.42523,-9.993004,-82.996129,-90.124008,-31.668507,3.609848,82.232072,113.029101,112.249199,104.898686,115.000445,109.647857,63.92409,-96.900792,-148.22254,-85.502278,42.403883,68.547382,73.142553,81.528087,115.372757,109.914281,29.528617,4.355804,102.557194,251.642596,246.397544,37.427126,-106.402573,-277.826946,-271.653113,-199.076859,-172.510996,-155.35512,-104.744099,-83.884974,-85.250572,-114.330192,-178.19473,-193.785345,-185.1648,-118.587494,-77.38886,-34.021743,-58.830661,-205.092087,-254.237022,-153.267749,2.122198,18.127344,32.710592,59.309923,48.349329,2.177397,-6.479531,58.543888,212.663986,250.100907,198.896342,53.393864,19.773577,-4.208808,-39.807484,-109.629721,-101.344345,-106.161141,-155.192379,-162.854639,-114.6252,-92.013869,-103.83932,-99.086126,39.818965,183.370882,176.653511,56.097812,-14.829758,-114.784464,-115.457003,-0.117726,106.732495,119.925323,124.094137,116.205354,5.251033,-61.416403,-49.086508,-2.599022,32.504461,30.444233,19.606214,-53.024421,-92.084396,-104.745173,-88.730286,-47.105601,33.940831,77.372289,76.734603,40.502778,-17.769094,-36.679808,-44.195504,-19.942074,37.746564,35.088525,-6.315061,-142.094758,-198.486831,-188.385199,-121.794944,3.857487,43.351475,58.514466,118.608417,152.803049,198.761715,210.203772,218.066651,237.265068:30.970773,148.602671,160.091749,180.512542,187.603808,148.14366,115.091071,76.622283,114.164696,154.435211,193.485672,164.573671,15.957287,-64.851205,-88.866706,-22.389568,110.867323,91.88501,10.163571,-226.680232,-319.00085,-342.645287,-280.203258,-135.350184,-45.025949,-1.165221,37.828599,10.72962,-112.762592,-187.602876,-243.031614,-176.590816,63.751084,172.64902,147.732442,67.366263,38.659815,-8.326151,-12.034901,57.170063,157.443434,171.26763,101.217444,41.478566,-77.391483,-128.818668,-130.254054,-59.304099,133.220338,208.501808,180.978999,71.163934,0.474404,-131.379631,-136.783478,-36.274169,19.155929,26.893999,60.847044,70.348978,4.487565,-44.005519,-33.940187,32.129679,244.491239,474.842838,531.483621,492.370974,440.598815,356.878671,333.924447,338.21025,338.432274,281.067888,32.699793,-103.728229,-293.841114,-336.991827,-299.236616,-237.392025,-167.490233,-204.138757,-206.619991,-177.032763,-202.049176,-328.574291,-348.963767,-213.356776,-13.220733,45.620186,32.584788,-32.792724,-174.758951,-182.556205,-46.692985,40.522045,193.043942,333.510441,361.629329,287.494308,213.683386,61.882867,3.001693,-50.781317,1.06602,31.943585,-44.846107,-136.320237,-297.388357,-349.927714,-377.93022,-362.590455,-303.176035,-239.573555,-253.780102,-364.120183,-421.113877,-496.048713,-490.650812,-367.057547,-204.009284,-163.592987,-199.020345,-226.547279,-218.057401,-205.632441,-144.638965,-54.070263,189.737354,320.550295,327.18488,246.614281,167.32536,9.65324,-25.373509,-1.111544,84.848274,122.540832,98.792007,43.829036,-70.965845,-105.167645,-81.965342,-42.707718,15.899435,-4.718426,-67.559544,-266.765599,-365.204785,-450.645356,-397.170522,-165.824456,-49.026042,-67.503233,-133.196206,-150.594982,-183.121157,-184.891974,-71.743861,35.195394,246.224789,306.067379,249.038672,83.816265,43.130505,41.999818,30.609038,-43.836406,-13.659446,40.751492,30.091192,-42.588435,-179.532926,-213.562376,-176.53076,-113.968761,-20.94078,-68.276488,-138.273615,-259.216428,-263.873072,-168.769817,-114.16071,-96.0855,-136.676824,-146.848638,-206.159589,-240.383661,-249.039695,-243.315844,-211.801962,-155.475101,28.154462,126.655418,108.649329,48.204728,15.147909,-98.151536,-128.896761,-46.912023,94.84013,135.006409,113.415638,43.413486,-149.511938,-198.802502,-100.903905,-4.633359,61.725486,-102.194052,-193.700266,-274.833358,-286.874627,-291.578172,-272.995667,-191.483646,-37.487972,44.303059,112.774784,100.063616,36.713523,18.565827,80.354701,137.483995,200.117221,163.452783,104.672755,-70.57143,-156.646394,-207.631341,-143.868281,60.463864,176.740276,175.098155,91.600037,47.616903,-15.348479,-49.574545,-58.660962,4.933428,211.253666,313.424373,286.728033,164.43995,109.150948,70.25226,98.417982,224.921965,350.463646,346.725994,186.764057,115.436265,137.870663,197.279013,293.528869,309.911891,300.438337,263.103071,222.058715,140.057129,111.652846,42.897951,35.240151,161.459156,264.403772,234.420669,84.660789,5.6042,-125.070065,-145.42649,-23.864088,63.490008,116.772119,77.252998,66.486506,75.719179,73.062427,24.466233,20.285575,113.469609,223.733161,239.068003,191.217212,153.791386,76.795267,58.361284,130.423301,187.160305,229.048685,191.341162,153.113493,48.185238,-24.437444,-151.795789,-140.51902,28.930796,150.825356,155.222013,106.007268,67.241216,-19.769942,-29.954733,23.673808,40.207088,76.297672,133.508151,101.774283,-86.700528,-193.56824,-335.170872,-330.122573,-195.882771,-116.517562,-132.822794,-200.502248,-208.025621,-183.59836,-193.129966,-196.833036,-146.399523,-50.760261,-89.668731,-120.789935,-167.43068,-212.133688,-322.359929,-321.491337,-188.533303,-80.91813,-53.488117,-14.906926,-20.732506,-101.8131,-147.715481,-144.68482,-83.20071,79.625324,134.089557,87.727923,-41.066128,-71.713917,-134.525328,-191.815741,-238.120316,-117.197122,-72.112671,-118.415572,-171.606556,-260.521452,-282.655214,-236.878652,-176.660604,-24.479131,91.649177,93.626841,-54.081405,-162.842534,-251.055877,-193.607446,-8.851572,18.315593,-26.893111,-68.781708,-46.027491,-38.324489,-76.654426,-162.443095,-165.8706,-57.048564,18.277627,-1.391703,-48.805192,-58.540018,-78.213054,-77.266872,-9.385766,100.393867,119.413486,45.907305,-22.971451,-176.220296,-233.872813,-215.16631,-149.189417,-11.348708,34.799014,-16.709575,-185.592184,-231.645158,-186.51495,-104.912379,99.528154,209.437697,214.551978,144.997768,92.335767,50.638782,76.023231,176.437939,235.824648:-208.111167,-192.617816,-181.882131,-76.717084,-5.423345,7.977851,-38.695619,-76.880013,-80.122215,-96.605941,-88.392169,-50.310033,-22.454375,-72.176498,-179.746814,-182.552239,-136.570934,-131.824097,-156.231523,-258.271354,-334.006014,-524.027177,-604.267378,-638.180997,-535.029969,-465.361686,-373.742139,-378.847298,-418.113946,-409.896706,-341.126836,-305.319394,-267.487004,-232.596869,-227.862411,-250.062912,-245.565441,-210.669075,-209.277369,-248.409091,-232.966134,-189.942284,-135.724099,-130.893417,-121.115384,-135.496608,-221.195975,-252.832075,-199.120554,-82.469394,-87.266034,-198.689304,-258.956283,-411.062935,-486.61761,-511.589136,-360.393243,-272.168601,-194.984578,-196.530783,-205.693402,-204.42891,-140.010775,-64.865132,98.954548,211.400598,253.071861,315.381253,326.013692,310.328034,312.522946,340.541514,284.803902,236.537113,121.426618,41.488825,-70.617916,-66.090971,-65.871592,-141.508536,-337.868305,-303.528003,-225.034629,-145.362353,-147.930194,-165.69939,-170.147064,-126.127578,-14.927552,12.127338,-26.529136,-32.842907,52.625031,97.689421,107.913087,88.807211,56.831839,94.140121,148.935145,299.828785,335.373278,194.927557,70.013999,-52.931856,5.465934,29.375273,-25.671217,-77.82523,-104.920889,-94.944014,-177.576645,-258.504297,-312.07546,-157.478119,-81.606121,-75.257803,-106.153268,-87.829807,-41.337748,23.237923,42.78347,66.59313,149.732594,204.805263,274.758289,262.055956,270.544715,346.700516,524.291734,522.373001,462.916729,384.314543,381.586006,325.87223,286.226224,306.952717,351.613214,315.226372,101.542988,-18.998196,-156.452519,-183.110331,-175.567265,-131.920023,-23.829631,28.589946,15.81208,-70.21044,-105.307656,-112.1503,-82.356783,32.563746,166.412358,220.601575,218.142691,169.762931,158.325576,233.365242,434.287674,489.765869,494.129043,526.433709,561.8924,591.301747,571.502725,469.9872,400.183608,219.443196,54.32459,22.547954,0.943843,-12.469666,-3.647999,19.905435,21.764296,-8.874877,-20.907539,45.389755,20.43657,-119.985266,-142.257145,-49.602109,-4.5462,-45.299151,-98.663264,-61.42667,21.765747,11.805367,-76.417945,-117.590782,-146.565772,-138.506218,-55.097916,140.790167,223.031853,250.793991,208.543178,81.368847,21.052755,-32.56698,62.317946,145.763738,213.726175,169.243355,25.846514,-14.622742,38.577842,94.754101,128.363953,46.611963,-21.240746,-175.586519,-212.006894,-131.917696,-55.791059,15.637683,31.654481,85.231163,185.895638,178.54912,121.541647,132.328031,253.922511,307.707764,323.137228,291.664655,255.705434,173.814919,148.085239,104.468102,98.392442,174.000607,269.793851,279.69379,242.013752,218.660909,192.886803,173.433631,107.603533,108.677186,220.457266,281.013226,268.988141,256.076916,257.707486,231.198684,219.637943,236.471726,282.792731,295.305927,227.383956,176.725621,172.406508,207.350119,233.54825,209.764751,156.696626,142.750267,139.977204,156.2393,171.566023,170.466791,156.282818,164.834421,198.178401,186.168476,109.837142,78.142933,98.414294,140.847359,230.696702,257.718541,212.576305,57.587095,-11.024247,-49.681855,-42.666393,-68.309091,-85.76244,-79.739314,-27.673525,21.859565,57.136774,12.739635,-63.589202,-46.578336,78.359866,134.795814,120.555211,8.617404,-33.79866,-95.957086,-134.137103,-158.039726,-107.416172,37.999677,97.648676,104.437467,87.531298,69.598404,34.49012,-5.444501,-111.949471,-130.964136,-53.45707,88.944186,106.863002,-16.40073,-111.235738,-255.159143,-290.427784,-326.533259,-346.5555,-345.835023,-330.634257,-310.248096,-275.576876,-278.32983,-250.167765,-209.727471,-162.403348,-142.917505,-129.690015,-127.732362,-141.639113,-162.843394,-155.070917,-120.085782,-72.804428,-55.009798,-114.882388,-173.763522,-228.737542,-217.89289,-160.715365,-135.364255,-106.007495,-70.457868,-76.396655,-131.67323,-148.428403,-197.240805,-248.148853,-293.579002,-238.221969,-231.440365,-281.207351,-297.082622,-269.339405,-246.652676,-189.191293,-135.652165,25.470501,117.110155,103.816397,64.439069,50.02814,-20.10807,-51.166562,-41.144302,-7.923496,-4.04983,0.007599,8.400816,20.311598,6.078099,-51.939816,-67.446305,-56.595329,-67.529576,-108.356846,-192.068249,-187.736278,-165.96964,-197.800889,-235.92739,-134.967775,-76.838154,-28.796205,-33.310676,-43.61945,-34.103387,32.083074,76.487371,119.095723,63.017091,9.016963,-55.289004,-38.597544,39.301207,61.471431,68.064036,163.552098,238.889499,274.840599,236.71619,225.382101,261.648432,305.504094,309.680927:-130.6649,-63.905838,-15.73284,121.804928,175.680443,172.93345,141.929081,74.185042,-26.813952,-53.814944,-7.98629,26.072969,6.954355,-31.03671,-62.739665,-63.577115,-93.94542,-108.07692,-103.705274,-109.522405,-137.592846,-282.226256,-366.398816,-459.466438,-402.788039,-322.526287,-211.708813,-224.72679,-317.347431,-357.312899,-367.498437,-331.980847,-223.60941,-148.543367,-144.40346,-182.403717,-197.033388,-184.180532,-160.318509,-130.487711,-171.253071,-189.212408,-198.643197,-204.57325,-221.904653,-234.360389,-245.251865,-236.207361,-189.692983,-93.270203,-66.216177,-100.707453,-137.232334,-244.697107,-310.518094,-351.340645,-205.360051,-108.120261,-10.268846,-13.876115,-34.280619,-42.845034,-34.249103,-1.100141,98.841443,226.139492,289.067663,366.358999,372.167277,308.81245,273.403855,292.516304,303.3424,257.20578,118.586759,63.765039,32.508797,27.053433,-77.091555,-158.788951,-249.006188,-201.469406,-170.104598,-170.957543,-198.525654,-264.567457,-277.19169,-204.439968,-102.644012,-91.232685,-180.617436,-249.203457,-280.777316,-241.953777,-169.183326,-148.24272,-123.78319,-70.914485,-20.574412,126.554705,204.384987,223.897625,154.360262,26.89324,-1.755483,-15.561214,-63.196921,-62.892149,-43.352646,-75.036139,-153.273291,-145.73479,-63.482726,44.810956,99.994815,122.073297,76.51638,11.909045,30.602262,52.191983,-24.34039,-36.325988,45.307005,114.376863,209.488434,189.581915,86.662312,92.759401,266.411428,350.806778,274.637665,81.432751,56.190082,80.869172,81.55394,44.047475,-32.411669,-55.623604,-98.505731,-145.523547,-240.52276,-257.493086,-210.975186,-155.473206,-56.963064,-45.341478,-84.507573,-190.82882,-207.602521,-175.967923,-164.74156,-128.069486,50.110195,162.368281,202.292805,124.31481,35.454792,97.501568,303.787919,347.36614,298.335971,290.697494,326.397493,377.138124,354.676684,237.416595,186.548352,114.679742,21.736623,-3.214018,-32.947534,-68.508178,-122.651443,-113.585797,-71.068776,-75.29731,-124.212733,-134.494627,-157.454585,-263.989358,-293.455269,-225.892646,-152.135335,-74.06444,-126.648016,-121.663273,-38.822476,-17.828417,-51.390262,-94.888541,-178.739238,-172.231135,-27.176275,128.991754,154.483691,166.339799,181.276281,134.916078,58.937044,-55.909483,-10.846714,43.885241,116.201759,107.939672,0.942467,-53.101367,-34.043949,15.274457,52.932378,2.484981,-48.686139,-193.086646,-237.075618,-161.114469,-80.750913,-17.130299,-23.190912,23.783395,166.030629,210.986174,224.961733,216.344341,215.608411,225.408485,258.052198,239.818503,180.674244,40.662589,10.373697,33.649085,54.3252,66.086779,65.018184,90.38377,159.79998,162.023258,146.303004,176.172869,284.816292,319.206053,333.686279,382.467066,418.234938,427.56044,389.317142,276.675162,252.226405,332.040634,469.709214,498.932417,436.112336,388.651543,326.982788,293.703754,263.785866,285.295517,329.32443,357.491961,362.140204,260.104731,159.175174,10.737337,2.193317,41.865974,82.326444,126.586328,182.675636,151.524631,38.405652,9.710903,53.322713,104.376581,158.348964,107.258506,89.406276,130.09257,142.724823,30.439205,-48.041781,-77.777036,-25.612711,-19.521264,-32.986748,-33.281764,-24.899242,-37.425617,-60.026068,-47.729389,-63.11376,-132.196525,-121.090346,-39.385865,-31.208948,-151.381819,-227.909366,-219.178331,-23.366878,55.23152,81.025454,59.963207,15.954975,-26.861059,-144.952698,-165.649216,-40.52526,150.928184,175.588379,65.316727,-29.98529,-234.417234,-302.759639,-302.301567,-248.024972,-246.134186,-286.15723,-297.228476,-232.217064,-179.608699,-121.493414,-117.036814,-129.417916,-41.221826,50.448117,149.976038,111.28132,-81.190599,-158.517795,-153.423542,-8.300945,66.554879,114.422508,82.436945,2.304244,-14.52547,26.564129,78.425613,179.488283,146.188021,86.038865,27.974115,18.804796,-99.273322,-188.527365,-257.795103,-128.484311,-29.179416,69.397161,50.587741,-22.281194,-52.264026,-47.056594,4.49978,140.043102,179.137423,137.367976,29.344827,-5.956297,-51.609694,-50.835553,3.965472,112.381295,175.373957,184.636722,122.177129,-0.475178,-51.644134,-144.427436,-141.467964,-31.945045,10.229017,-34.180748,-164.312458,-180.401065,-48.91097,36.705501,80.824974,29.473249,31.81921,63.576237,67.841315,68.738647,77.824022,90.725824,83.232399,100.128077,124.995763,84.500204,-38.298543,-72.376117,-26.051812,47.093712,159.7731,189.534573,209.263816,295.103429,348.798037,344.671108,274.014523,174.331199,181.458704:-195.935521,-19.472038,56.399649,178.996388,221.965092,159.956738,67.892775,-24.774342,74.75116,121.210939,58.390305,-19.667661,-118.55263,-127.01881,-58.51081,-6.985005,27.95586,28.145969,-0.007139,-168.320583,-255.905673,-376.024732,-420.331079,-416.12286,-254.372098,-176.836501,-134.976123,-146.333829,-178.858251,-219.5042,-281.668961,-256.810843,-138.925024,-58.370822,-42.617381,-13.55008,0.437875,-22.403698,-51.880972,-112.825373,-137.663917,-106.321407,-4.450339,26.404555,3.365083,-49.871111,-126.489499,-97.08677,32.962279,83.893597,51.237234,-94.432101,-177.363,-330.922434,-378.19251,-368.691921,-241.850455,-149.059618,-23.569113,-24.28175,-72.684832,-84.470656,-53.63416,-12.007606,117.671522,294.051345,367.978084,426.307784,414.153146,354.375173,324.033088,290.00862,233.567275,186.397881,57.18227,-17.00295,-113.194843,-128.922083,-148.216638,-168.067624,-234.053709,-272.525613,-256.516922,-177.308825,-141.617456,-133.471267,-145.716036,-142.324221,-96.986481,-62.803205,-10.01471,8.946819,55.325562,82.710285,128.438246,142.487111,154.764722,173.92219,184.940778,194.952471,194.656098,168.239795,127.663474,10.653175,-37.462105,-28.693361,-65.276949,-129.646389,-269.113101,-310.736142,-326.483016,-327.616869,-357.614183,-332.470865,-272.591394,-185.105878,-203.169911,-265.250119,-250.545028,-153.667448,-75.997558,-39.373245,51.098097,95.804538,161.066688,178.963418,241.397802,297.514081,370.530942,355.182199,332.87307,280.167942,259.837612,217.9656,199.829658,193.744838,150.552897,123.451373,135.569051,150.984555,67.316715,-15.21623,-62.311145,-2.731114,108.435079,19.49562,-63.517997,-143.065326,-138.889697,-158.437466,-181.6807,-134.122497,-14.954216,19.855704,60.305534,78.343258,79.185086,75.549777,202.102905,308.648735,383.488151,310.484819,262.489451,195.643256,197.713361,224.195321,217.176918,100.620484,3.66661,53.758324,184.906171,184.696342,95.442083,37.134893,-35.558522,-30.78351,16.664308,28.640711,-9.604337,-115.718898,-114.720872,-8.507166,29.142245,-2.158269,-42.621265,-21.694493,19.721883,13.410935,-35.417182,-76.751378,-135.400702,-120.732659,7.173161,218.632954,285.960681,278.882841,247.849946,169.830797,121.112275,63.937849,85.584263,109.962768,142.715318,132.432773,41.730799,-21.588209,-55.783125,-9.763455,47.10176,-27.499418,-72.900438,-156.931767,-199.46761,-226.128441,-189.43676,-127.774847,-105.569232,-35.181904,169.663423,226.301617,193.129784,147.632264,128.053895,158.061025,207.546784,202.786514,191.668422,145.146222,105.43355,34.421041,35.014783,86.697818,152.287015,169.509644,54.579287,-39.65381,-81.917687,-37.132599,61.228501,108.104187,174.191375,157.412216,125.259041,85.77226,86.343832,66.196235,41.657033,29.765133,96.268003,112.442773,76.846543,57.320719,52.629958,71.151295,149.741227,171.616718,99.585543,12.446504,22.318688,98.70383,115.62577,76.315788,61.325262,93.010693,134.68186,127.300412,23.586676,-38.853599,-50.058137,-1.373444,52.795209,32.162602,-9.744725,-21.393994,-56.683986,-155.716395,-169.062006,-112.928333,-77.830949,-35.826989,43.31157,94.659817,74.474483,6.123466,-59.487746,-18.186177,115.602716,142.604955,71.77044,-17.676897,-32.650621,-21.146577,-8.423971,14.971985,37.174886,104.860078,139.880267,139.562772,139.138602,147.730659,133.96922,81.349397,-47.776677,-64.507987,1.821604,31.582229,-5.852676,-130.219669,-179.812804,-263.462014,-297.926178,-279.892994,-230.014038,-235.582681,-278.043738,-300.075181,-337.014839,-351.957815,-304.599332,-228.845964,-99.260716,-130.303807,-181.99932,-246.418499,-247.393751,-267.663475,-277.817682,-153.062505,18.531528,10.88202,-151.501748,-225.65122,-272.52791,-270.116336,-222.654587,-159.667144,-51.753391,-54.980583,-62.900593,-86.261093,-117.2113,-170.301808,-164.836463,-158.975712,-249.985278,-298.008859,-363.854499,-382.87609,-369.590789,-328.647298,-180.76579,-90.844942,56.433244,98.959051,75.625844,-5.975266,-38.996303,-91.5927,-95.705965,-1.03973,103.295787,88.343194,-70.332824,-134.611214,-106.741046,-73.572447,-81.153366,-107.720407,-160.55754,-122.036543,-88.59336,-86.516315,-111.004524,-176.186628,-205.353975,-194.611035,-87.197722,-44.734214,-44.870848,-82.990668,-173.008942,-185.616566,-111.591186,-49.727722,8.047877,-25.334809,-35.559779,-41.060537,-54.980436,-74.976929,-57.563748,41.453534,185.612842,231.301262,251.53149,246.318327,210.072951,190.9655,200.148697,221.656867:right
347.753571,283.267749,242.821124,133.118706,55.643211,-70.851031,-57.400375,111.263057,252.005772,291.323953,335.672018,324.826323,182.945495,82.971502,-4.85235,23.68235,144.493334,255.691403,255.293077,102.413197,1.99115,-81.107411,-45.375512,80.222115,128.989118,112.590637,45.289309,3.62449,-107.870472,-144.078019,-39.246576,62.7854,163.580068,162.00182,127.71055,-16.830741,-71.9201,-91.105046,-76.048934,-15.523668,102.029287,156.636362,151.738451,112.044519,97.175756,124.160189,176.328224,201.818727,306.837924,437.41691,448.708722,334.224298,245.212546,124.175336,125.640075,212.593047,282.792416,310.574645,360.47172,353.439605,219.970967,116.809226,-50.623898,-80.182525,25.214908,227.729045,273.549203,199.500371,113.069085,-33.050401,-59.629649,-30.796899,53.924882,85.464302,76.153162,55.735239,56.141142,67.953038,79.571821,70.914335,33.019794,53.220262,42.627726,-153.160105,-294.56808,-424.469276,-375.244009,-187.265113,-57.956133,-11.614492,34.609691,4.381965,-144.93002,-213.544779,-239.987098,-196.845718,-22.137559,147.373985,172.794914,107.53421,53.305667,46.680519,108.07514,219.289926,282.902479,328.840992,326.202209,235.183773,-27.415992,-130.839261,-203.716921,-192.925738,-125.508924,-33.975617,-10.473856,-16.05366,-35.66575,-60.979169,-57.46879,-72.410895,-52.16041,6.443608,136.046231,152.130823,12.558034,-93.556076,-159.112727,-111.692427,9.231218,70.775302,72.48149,3.081308,-77.709093,-256.737766,-300.752282,-284.89388,-170.381629,-96.18707,-89.415114,-178.434981,-321.069621,-310.101966,-212.863138,-170.475186,-83.940022,23.963307,55.657731,19.406457,-34.318547,-123.677229,-113.195549,10.900942,87.340634,88.200247,55.374646,13.765668,-131.396249,-179.785583,-120.42399,-45.737879,91.665503,179.717326,187.628218,146.827711,110.175033,24.677381,8.552221,12.108771,-45.108549,-78.961383,-132.358363,-173.955487,-273.142404,-293.780515,-269.128316,-253.583134,-198.310292,-62.157231,-0.300575,13.786319,-52.522065,-241.299489,-291.825463,-264.850823,-207.318223,-213.786259,-293.896544,-332.706957,-385.689662,-405.965849,-390.922789,-349.982067,-238.359219,-169.428151,-191.092923,-326.628347,-388.895148,-352.926291,-266.347672,-134.11399,-73.145011,-40.852096,-16.268053,-44.281048,-206.019387,-325.225342,-494.347603,-490.193331,-331.292705,-206.536943,-207.009455,-289.556077,-358.866316,-452.679536,-414.030325,-229.242212,-98.973802,-46.224322,61.737622,104.38986,131.141118,110.058308,22.009883,-25.668768,-68.899071,-24.273014,-0.459278,-18.284341,-71.8621,-192.786017,-205.140018,-118.900102,41.417647,110.906889,156.000048,131.183473,30.22327,-20.286297,-74.336473,-74.93877,-66.285704,-123.090366,-186.707393,-336.579366,-381.695112,-341.549658,-277.548988,-184.015726,-157.597219,-137.478669,-92.75732,-92.298444,-143.105644,-160.528628,-123.768397,-84.030268,2.693721,6.164816,-55.231922,-203.410611,-235.720456,-169.488926,-97.822152,2.851625,70.780889,99.859262,85.245257,52.183095,-49.600579,-131.794845,-239.001946,-205.644043,-51.185108,5.468218,-15.328413,-108.378313,-184.014911,-313.171345,-298.396768,-137.229737,-3.60944,24.758842,20.498726,10.313146,-52.178569,-114.04667,-142.745976,-59.8661,171.10873,240.5446,205.445924,91.916407,37.26733,-48.062376,-79.39395,-140.941314,-173.440285,-178.15794,-222.307626,-250.647587,-284.11183,-292.562447,-276.281834,-243.855371,-136.535809,-35.240139,-6.347355,24.476906,4.504038,-140.849929,-217.483121,-296.146226,-237.429612,-150.95019,-40.187346,-90.246938,-300.884994,-362.689939,-362.211058,-342.725907,-256.368373,-98.965045,-37.558997,4.464244,-28.078546,-145.987526,-167.113049,-85.471938,19.306815,33.728284,-6.882453,-47.237274,-151.006744,-196.190496,-215.224805,-186.648865,-54.008916,134.564867,197.657055,192.221397,147.599794,108.114084,129.349271,218.012851,375.193489,445.82397,454.353207,397.028699,258.085439,206.961882,168.296343,179.223117,224.128594,233.148726,236.716623,274.957602,272.013268,192.371905,167.709544,217.51,270.767782,252.852125,184.721389,154.310574,59.659601,23.195579,22.456096,20.536958,47.217747,152.941436,164.347208,59.715646,-35.758421,-217.934079,-251.929447,-188.2571,19.678088,121.744865,104.590031,-9.344705,-220.161406,-249.317604,-169.504534,-115.682811,-42.361321,53.535199,98.285904,132.117323,119.301604,29.478288,-9.69471,18.03992,76.098795,62.342158,34.623454,84.679587,250.940021,301.861893,347.576151,366.523782:197.774774,150.099303,117.579571,42.560665,9.242947,-20.609728,-27.595632,-17.396777,92.638453,151.872638,172.076287,132.679072,19.552911,-24.760223,-66.716783,-60.090064,4.89539,20.010869,-9.155986,-94.713919,-141.670909,-184.39944,-142.798589,34.831849,135.313691,117.787306,11.159599,-44.549696,-136.989205,-162.01529,-125.388628,-69.165998,46.54458,97.878632,96.891675,28.904146,-37.949003,-143.579784,-130.580474,28.224689,191.792808,219.84596,184.708832,156.073098,137.788567,154.774506,227.197812,269.05226,352.223066,387.39099,358.171904,247.174779,186.967138,96.52342,81.898716,109.474208,216.760842,287.250335,352.913818,315.043407,157.1685,86.209452,-2.919656,-21.371279,8.003575,85.124311,121.395619,168.337555,151.17035,35.419887,-10.992095,-6.791262,94.430451,143.87661,154.586564,113.831086,-2.219686,-44.506246,-41.109945,-3.815706,74.355688,55.873467,-0.369223,-161.1434,-237.093534,-283.027833,-246.810854,-131.740013,20.298781,89.729298,92.850428,28.497733,-99.315183,-139.009672,-190.328761,-178.826949,-38.2767,74.747082,71.327445,36.765941,21.30446,-10.074334,17.149446,208.750457,411.074404,442.742917,302.738812,160.746483,-120.217773,-213.611708,-260.294021,-223.154951,-87.855366,18.239018,44.420926,48.020415,6.058669,-94.40127,-80.298651,81.729506,207.682512,212.306709,148.637131,90.269702,-65.11579,-110.268161,-45.166994,30.318826,143.096372,152.766624,116.232531,22.859817,-7.097706,-50.398978,-73.615948,-99.013077,-15.553681,50.730434,61.114161,-18.469524,-187.038929,-215.555773,-187.659925,-167.987636,-105.391764,14.951157,61.980965,40.79755,-25.234104,-122.396686,-122.540467,-70.350758,100.292811,184.151475,112.405309,-21.412717,-212.398368,-218.568715,-135.886998,-87.555277,-1.998114,37.81121,27.685508,-54.771736,-107.236301,-148.489852,-129.424707,-124.513626,-257.549067,-323.690994,-347.555747,-327.619257,-346.201664,-390.731185,-424.256425,-360.672152,-98.342697,69.912128,64.513481,-7.136414,-41.249514,-126.189961,-181.838757,-258.838716,-221.824517,-182.867964,-140.929024,-169.5804,-328.731201,-390.340804,-384.288561,-350.303206,-244.660985,-127.465031,-128.922676,-291.807874,-387.622596,-373.249285,-256.748942,-26.975466,12.072204,-27.123171,-98.043407,-125.674343,-277.157557,-374.719626,-429.31348,-385.911051,-271.852059,-204.075007,-209.705775,-316.070751,-384.095552,-408.165455,-348.920065,-211.928425,-106.015735,-41.67746,104.691403,155.017507,111.213609,35.159133,-51.843834,-41.889329,-41.701747,-122.025117,-148.353263,-168.65009,-193.468089,-228.5735,-193.88766,-78.444972,27.817659,89.562102,114.565031,59.282928,-53.039953,-76.091803,-66.122483,-50.566866,-88.289258,-231.173251,-287.623768,-350.68115,-378.363685,-365.480542,-306.231287,-155.360629,-6.430013,43.807473,14.023449,-40.682427,-114.397388,-123.464715,-87.471986,-41.157092,39.158327,-2.947306,-62.455621,-199.230912,-273.01754,-340.253684,-283.183219,-68.02807,94.259795,148.842755,215.298333,197.924341,0.717656,-119.152001,-175.800342,-117.809962,16.468449,57.706661,23.684156,-91.225584,-134.942487,-166.214097,-164.481545,-164.431998,-117.73673,-64.445742,13.032099,-2.839747,-105.169681,-140.899002,-133.014982,-88.166204,65.044076,171.122152,164.590284,29.806026,-76.637805,-241.892503,-262.422826,-188.448125,-74.363516,-69.788557,-208.584385,-304.779835,-426.724968,-436.878873,-363.026607,-291.706405,-123.156674,16.273865,40.692138,-4.119551,-60.74145,-184.285387,-213.915117,-187.733612,-118.017298,-103.233038,-152.216004,-201.913089,-301.107537,-323.581579,-254.086081,-169.412801,-6.55381,66.457504,88.429835,97.505884,56.394704,-97.245591,-155.597323,-129.855264,4.185078,22.221049,-108.706429,-205.052987,-328.151955,-346.294858,-295.717206,-243.302085,-141.07191,34.187454,133.227235,161.929845,101.546378,44.732117,77.921467,193.576337,311.393676,357.520009,356.585847,293.137698,159.988927,144.51188,172.546984,174.109909,134.149397,111.606436,126.057247,180.299546,192.026588,182.166229,197.052153,306.439023,367.271565,320.508888,147.840678,81.135135,15.675428,-1.553106,11.461129,48.42952,130.282001,152.54942,135.738002,38.138562,-30.685497,-94.157826,-68.033377,72.461521,291.442052,358.662168,317.518055,237.125591,73.331287,45.233268,151.699054,238.914714,324.485546,276.624896,227.695932,118.56848,75.753227,59.020392,79.53863,111.098326,150.986177,179.027615,197.876532,196.736045,213.445216,248.728532,375.679401,420.90051:63.83866,63.82422,84.808133,45.692514,-44.124527,-237.56507,-271.185509,-153.282879,46.742094,99.780581,122.861467,100.628006,-47.251588,-130.299203,-173.085586,-140.012514,-68.784514,-87.204874,-135.712673,-276.274466,-341.378677,-376.544318,-320.072297,-87.272435,71.581357,53.88814,-94.745411,-165.515055,-228.913362,-221.692337,-163.713706,-114.933068,5.067002,46.152418,27.56271,-72.296479,-141.166635,-198.036353,-155.795688,21.19956,175.827724,200.358973,177.025771,148.893193,62.694669,42.543253,150.640527,239.913099,319.941849,262.71034,222.438052,166.266149,143.784007,68.930996,39.572623,76.616123,151.017822,161.286815,152.617546,127.716553,-5.646478,-79.675277,-138.45078,-124.362874,-30.749137,106.130007,140.054994,115.535697,91.038592,45.740723,27.745327,73.330753,206.797479,220.070414,84.059618,-1.358064,-99.288535,-90.139842,40.108094,93.777903,82.535656,26.220136,-0.564637,-115.815196,-213.226645,-345.548141,-332.209164,-197.708453,-47.492941,3.39156,29.621395,-5.946545,-133.180085,-169.150544,-158.12323,-138.875782,-54.723746,74.166609,108.81461,58.591544,3.461272,-14.280689,36.122993,162.570479,248.186425,256.314162,143.572458,20.581038,-208.632558,-245.903176,-203.683497,-158.159425,-44.396044,-8.760704,-30.879561,-88.342942,-105.976127,-88.324587,-49.851145,49.873578,101.116214,90.407442,37.308634,-1.063696,-114.88465,-153.811962,-118.939495,-58.640628,67.231846,75.537164,36.896681,-31.639534,-42.363046,-28.680832,-10.888192,49.756066,112.451729,119.556074,69.354804,21.434714,-86.737601,-134.71135,-179.604432,-148.722282,1.784027,102.366526,124.605361,160.821827,151.344361,78.548332,64.38798,136.256804,239.042482,247.90436,129.762137,26.221068,-111.689462,-94.522574,27.009497,64.945402,77.198903,27.302482,-11.439633,-64.084011,-66.834594,-33.635752,-25.772862,-94.732584,-190.847538,-216.343333,-268.339224,-306.289452,-379.625242,-392.388017,-337.590182,-278.088349,-93.826311,105.562598,146.435988,67.655138,-8.806597,-116.928104,-147.9468,-176.284999,-106.388081,-51.872484,-29.156427,-82.321105,-212.10634,-240.767734,-225.228418,-191.998667,-86.622935,-9.256148,-23.459347,-158.262083,-210.791525,-123.088541,-20.637813,100.279965,88.189965,60.132827,-33.129856,-96.389003,-243.77389,-305.563528,-290.132907,-210.859172,-96.708662,-165.813056,-205.916715,-190.175268,-167.190993,-168.850011,-159.836615,-58.47015,95.337004,152.12045,185.997672,164.343183,63.919235,21.18563,-2.641704,-11.542153,-51.4041,-40.770379,-27.447836,-111.410771,-198.348912,-232.968411,-151.979984,7.272406,91.388751,125.404311,97.661034,19.07298,-150.134717,-190.757623,-223.689115,-230.766152,-208.19031,-226.534066,-286.42346,-450.634187,-479.415212,-356.996497,-272.133076,-163.325877,-65.481544,-31.651135,-66.764712,-112.154159,-177.758222,-196.270257,-189.70553,-161.898741,-108.032746,-111.907854,-141.394083,-255.791636,-324.598671,-364.463245,-316.243252,-179.148152,-42.782841,26.337366,72.725432,26.457108,-66.663884,-64.25489,-42.580536,-41.308757,-5.720961,-49.89539,-102.73367,-114.189489,-106.281449,-183.461963,-224.419853,-198.161607,-98.753249,-59.711266,-24.498948,-38.626134,-117.256421,-138.070866,-72.210296,7.612267,180.093389,186.318474,122.722093,-33.271724,-115.516375,-248.910646,-267.94063,-225.762717,-222.410792,-253.461611,-310.377898,-343.132327,-452.921945,-472.151212,-345.353103,-242.153549,-49.30383,43.87726,42.949348,22.018885,19.490378,8.011688,-10.068281,-24.242034,40.972814,64.838929,-20.583907,-110.49209,-216.87495,-215.86693,-175.35365,-129.059239,44.826371,157.462159,159.793053,91.392997,23.522227,-88.73583,-98.819369,-63.242662,-8.325933,1.912802,-68.116538,-142.591024,-299.269925,-351.414531,-397.469675,-395.809827,-255.570136,20.861509,110.974769,123.385587,86.348586,82.044743,138.940264,293.277623,361.014254,326.91995,204.024459,172.074002,152.98731,130.685983,69.185251,53.652763,84.51494,139.610565,150.291832,131.79666,99.783549,31.407492,27.835321,140.992689,303.941369,324.664397,243.059685,159.705623,-63.969403,-149.300476,-184.13006,-155.813402,-27.006307,116.11742,128.875753,37.484019,-22.809989,-22.618918,54.126331,208.782677,297.048639,332.639111,294.710073,189.055785,-55.813174,-82.687761,100.173648,213.098279,278.043395,178.312666,132.358859,49.900149,4.58489,-5.005729,51.76861,174.366032,146.638606,102.173565,114.117367,157.528205,166.770052,152.630047,210.344949,271.087033:245.984713,162.896918,108.442899,-23.136756,-105.764668,-207.903706,-183.123297,-50.068207,79.915991,135.746972,164.105655,117.030348,-63.012926,-146.290395,-179.266591,-133.374094,5.494186,95.360824,74.934701,-124.209162,-257.0976,-375.373625,-311.392264,-70.858675,55.187723,46.115796,-44.407741,-85.583245,-152.717966,-185.082362,-143.632645,-58.075027,108.568854,169.804741,171.168673,114.284598,44.589225,-105.061694,-131.706526,-51.092308,80.639748,101.8316,58.236451,43.691146,48.728472,43.263997,37.599905,68.06905,212.329483,301.035998,278.236267,191.512266,148.70476,42.651425,5.188834,36.886344,163.27114,228.239425,268.26577,223.21154,61.170142,-19.733059,-131.911977,-145.755421,-66.145343,47.029112,78.46144,85.577373,68.020672,16.717071,-13.064524,-33.909513,80.085778,127.476844,36.035098,-60.642939,-140.147429,-102.016302,22.705321,67.375892,116.153486,122.002014,82.697085,-97.558479,-198.686084,-288.291833,-255.960715,-121.744296,-31.479769,-9.759672,-15.272881,-57.476591,-203.041493,-257.253292,-253.143478,-205.115098,-40.831094,97.052478,114.426754,96.935363,84.714676,63.924691,72.104411,168.957723,301.11543,320.087081,212.068958,111.065337,-113.429994,-197.867265,-237.032928,-216.457519,-142.933654,-68.348582,-68.699919,-94.580687,-98.508369,-107.449914,-111.099783,-95.328986,-10.356646,37.947356,32.723238,-36.316571,-209.515876,-244.830217,-170.558786,-114.624187,-36.27461,28.237861,33.275961,-52.166987,-110.502869,-155.228168,-153.241013,-136.317314,0.044616,67.941109,16.728522,-69.649384,-197.981936,-229.545683,-213.305777,-146.107913,56.605016,159.387314,156.345087,153.605874,150.143946,94.511469,76.410371,125.713386,262.555826,314.600025,267.538471,182.420681,9.737999,-26.293062,3.907502,19.880889,59.623252,170.696256,185.094378,76.123102,15.86775,-44.408063,-56.737648,-68.745167,-87.966443,-105.378485,-173.873904,-216.283051,-273.826539,-277.216965,-242.817901,-228.05738,-156.59308,40.332249,117.928365,115.374379,46.33495,-111.181405,-154.971457,-154.935547,-91.499035,-69.660745,-106.646705,-169.856505,-332.711931,-377.81344,-332.060528,-276.088489,-177.310871,-102.299765,-105.986512,-220.211112,-273.3423,-234.323483,-156.4021,-22.423867,50.776381,66.074621,18.001007,-32.807978,-177.777425,-257.464217,-339.503826,-327.809885,-186.888904,-46.724109,-57.9045,-166.617307,-206.889963,-214.139411,-183.102642,-101.128409,15.563112,106.638848,272.39162,300.29357,202.924594,114.588974,17.729166,22.360313,67.542439,69.438366,47.945645,-41.912219,-118.432172,-204.251278,-164.214223,-21.625073,96.907161,152.253353,192.892661,142.598387,-96.981784,-210.922506,-206.749299,-109.970786,7.478219,-109.30237,-223.921806,-455.49372,-510.730317,-420.619663,-331.438585,-206.503315,-80.140221,-47.928192,-128.000025,-177.557183,-224.939638,-242.374826,-213.481311,-166.957544,-74.500832,-20.559996,-43.196142,-198.589067,-291.070551,-379.442815,-344.001991,-138.105713,94.273034,140.857015,70.012036,4.991275,-122.222494,-184.212233,-230.437394,-181.991251,-5.05385,39.204621,-7.885977,-127.068161,-178.554108,-259.906178,-270.205041,-215.078434,-115.274833,-55.697026,38.398402,48.57104,-24.929847,-84.32646,-132.380106,-100.351656,55.392577,259.47624,300.130473,100.250506,-91.452967,-357.674527,-384.377462,-317.591517,-197.090051,-149.596853,-160.527624,-221.306472,-364.527386,-399.025754,-322.615417,-227.313058,-27.366178,60.063803,59.547456,49.526268,31.332941,-64.775213,-108.814182,-141.62822,-81.694733,-12.953914,41.35471,-14.74268,-202.050218,-268.73328,-261.058095,-209.090507,-70.491401,101.410776,162.793572,175.006904,120.537165,-69.573192,-151.910312,-165.109595,1.478792,53.97252,-38.074831,-141.344652,-315.499773,-350.10096,-310.307741,-265.544032,-133.918284,75.340013,154.368399,188.491989,169.515108,175.454177,220.65365,347.183646,471.864439,484.916801,372.378562,286.794334,132.947509,86.573398,96.385611,123.690874,148.907499,166.894359,188.497048,241.704137,244.420549,163.364466,122.727093,162.490683,280.66764,288.489056,180.133115,108.667654,-32.342755,-96.375603,-135.83806,-99.178599,41.399681,110.072203,81.902083,-9.728199,-49.494235,-110.917298,-123.171561,-77.93277,77.788947,141.540357,131.782771,58.140361,-171.83158,-253.685272,-188.403325,-88.698474,44.511811,115.539558,136.134857,89.813965,36.017466,-42.770385,-43.848641,-10.785354,15.742386,20.158128,21.816212,48.47204,159.365185,222.158831,321.822015,350.336876:210.905239,144.768204,94.269277,-48.323454,-172.858411,-359.911623,-321.701176,-79.089796,96.158557,127.88989,72.826139,-4.050058,-165.517818,-209.898049,-246.794988,-256.117471,-191.803491,-81.679022,-79.140967,-214.479519,-309.929243,-366.736662,-292.794007,-64.631288,51.38677,49.420333,-31.535773,-110.343409,-264.149394,-265.161383,-96.577093,2.6448,112.41776,103.37297,75.257855,-42.478569,-142.675068,-258.395133,-224.879237,-83.79683,72.023427,135.645295,121.302874,28.046847,-167.462758,-168.958369,39.009999,150.159038,224.171561,175.966197,138.517168,56.275261,24.964167,-1.72204,-8.234218,10.030568,122.50852,177.723444,156.042162,78.820845,-108.630569,-176.094063,-178.726146,-125.16261,18.970737,130.151246,133.178731,39.079511,-33.487217,-126.542738,-97.85707,111.442536,315.207673,326.183707,177.347178,76.791258,-96.28284,-129.259477,12.924973,142.680132,281.894889,186.092368,97.220678,-77.621326,-152.351371,-231.245813,-216.958721,-100.640383,58.357561,91.739012,-6.265601,-99.403078,-262.929585,-302.33996,-245.055273,-163.934402,41.710298,219.708622,242.128667,86.514546,-46.682428,-166.242935,-101.731278,151.809749,308.843791,291.350216,109.955287,-19.977052,-265.518537,-308.081113,-181.014204,-87.32248,3.211036,-19.080952,-64.769126,-163.354527,-164.699547,-67.451033,-25.635833,-21.335901,-17.194733,10.448596,42.84601,-2.342424,-190.241084,-246.820429,-169.988194,-80.726914,42.632648,21.107924,-20.132468,-93.609862,-105.324402,-79.223349,-63.286566,-34.514928,40.765231,74.571362,46.354336,-10.334993,-126.246722,-157.952499,-127.019461,-58.357347,123.517846,216.231754,216.319374,131.694431,64.778804,33.376481,87.270635,218.193441,356.62513,426.463388,387.988347,235.766199,-93.688833,-123.171238,53.261148,137.281538,206.895923,206.501719,159.978029,0.827195,-53.756941,-53.614124,-36.15655,-66.579629,-122.179312,-108.597468,-80.600779,-125.470483,-256.84597,-268.094363,-155.687453,-82.642796,22.482536,85.759109,85.460577,2.034356,-62.999834,-175.150885,-205.494983,-158.459303,2.992281,34.972398,-90.930118,-189.217968,-295.607952,-281.010987,-130.374351,-47.25448,-0.007812,-12.551006,-25.227811,-162.830215,-237.031368,-158.597701,-38.133534,130.103096,181.537801,177.606895,113.497824,72.739855,-41.048462,-112.752918,-182.893948,-147.226903,-6.938659,11.500665,-10.970043,-44.911518,-73.595084,-97.706406,-54.915997,92.247235,201.142208,221.824584,220.213132,201.452023,101.296569,53.604127,76.347278,131.835087,232.111866,234.992069,201.558444,59.784728,-52.740533,-170.228016,-105.717137,147.037409,310.769068,324.899844,261.774025,183.637085,-88.536091,-199.757184,-181.843678,-102.308307,11.898862,-22.643825,-98.463074,-296.617683,-356.001512,-296.017599,-212.413669,-40.750668,99.749624,109.594107,-19.805408,-102.90804,-187.475158,-182.474614,-134.863189,-104.965309,-0.306716,53.563731,7.321231,-153.628556,-221.975276,-257.844261,-215.796165,-53.4697,139.920006,172.162199,52.759982,-24.063225,-84.773169,-88.338066,-75.777495,-27.791149,147.219548,211.830613,168.39192,-30.289632,-145.7788,-253.961364,-231.941975,-133.606514,-44.476642,-2.927979,96.867696,121.304679,-10.106004,-117.744933,-140.36147,-35.25477,197.806868,228.081063,167.889408,-31.987389,-150.607994,-298.832707,-315.297003,-315.636905,-260.109881,-223.103625,-230.135651,-286.381734,-411.9003,-421.779895,-271.322203,-143.59173,73.511869,165.157463,163.09533,90.390381,49.400641,18.434126,19.417484,55.422314,155.817216,181.461565,89.144547,-7.360793,-228.4637,-319.848982,-332.405888,-245.041374,-1.958618,149.652075,156.953144,70.714077,1.380684,-116.4505,-136.846178,-78.618051,43.791913,73.543162,-2.180437,-95.257922,-289.427567,-355.153092,-405.834469,-371.955325,-128.081805,154.325407,203.619754,152.460972,117.733425,134.041749,176.084371,262.523343,339.100397,352.034551,264.080597,175.792056,12.950458,-19.757185,29.471578,78.532847,177.03839,233.345878,225.739458,154.442169,90.065336,-28.604901,-19.129122,162.352684,368.917679,400.795162,272.422613,143.895528,-110.439277,-181.699478,-175.397928,-124.402962,-17.74721,-61.545923,-124.690644,-170.792894,-155.823193,-137.559825,-135.04849,-80.596406,55.015763,98.395578,74.646448,12.187786,-165.921942,-208.345952,-82.451938,25.556516,158.467724,127.605568,59.175143,-116.293147,-186.049657,-180.730923,-107.31919,26.990198,55.96703,53.728533,65.045443,67.42563,0.079739,-36.332693,44.764313,148.661233:280.506386,206.246174,170.807136,8.448342,-105.510823,-238.691448,-200.967669,23.990082,208.421992,253.528277,296.903751,302.722439,251.724705,198.659968,122.541598,117.938269,165.912302,246.496203,255.969848,168.021868,82.288507,-78.807272,-96.082936,58.52785,255.616137,258.935364,122.802776,62.579301,-11.411765,-42.053615,-14.836059,57.269933,212.696289,212.250103,131.081733,-60.217815,-121.88639,-183.994634,-192.612683,-130.979797,43.764265,103.088529,7.301755,-99.827165,-161.204016,-94.974218,52.814797,86.52846,132.831157,190.300945,202.726772,207.674666,191.634225,110.108781,79.64888,118.612726,263.551135,318.957044,294.559637,226.649163,69.220921,11.842464,-65.139032,-111.73321,-134.153259,7.474762,62.773999,57.642201,-10.112721,-209.076534,-261.537252,-180.052535,-3.319622,35.041983,-30.956821,-79.439572,-113.641255,-113.354791,-108.894925,-105.598712,-76.989071,-24.466262,-39.848048,-198.135571,-306.384762,-436.472769,-419.67835,-289.425999,-148.933799,-86.698374,-29.517802,-71.453303,-296.509496,-394.551911,-386.215653,-304.883426,-97.739442,50.9634,40.516761,-128.934074,-198.301713,-123.651542,-10.577084,178.10242,247.416695,234.774098,116.795,19.322713,-203.203137,-274.259756,-270.00796,-241.433913,-184.797563,-111.899703,-118.429774,-207.096977,-244.461681,-294.792748,-308.297071,-275.438147,-184.406621,-131.062457,-49.983085,-57.721646,-205.393744,-288.550024,-301.210559,-244.801947,-138.927545,-122.26453,-144.384799,-177.88057,-193.924797,-270.36328,-309.630412,-300.70583,-118.037631,-32.5543,-88.469038,-193.869592,-340.082051,-356.066624,-316.608053,-274.748212,-132.754844,37.780971,77.145817,53.086809,10.756364,-116.619055,-162.731395,-94.827037,122.076056,216.251153,271.04525,207.366519,-42.830158,-138.703709,-137.414355,-70.282611,107.020798,227.056861,212.921776,87.888393,29.775043,-38.761004,-44.007831,-26.688822,-34.408298,-34.482534,-16.22265,-9.892683,-56.846055,-112.660828,-206.491876,-226.433412,-196.136385,-35.605595,51.778857,108.214919,51.130865,-165.133899,-242.086087,-207.768729,-77.214109,-71.668609,-237.444105,-346.769512,-407.826303,-348.856932,-213.145485,-185.353934,-150.332161,-65.308891,-43.604022,-90.65344,-128.166026,-157.61799,-141.656118,-78.888194,24.20614,76.165318,101.947634,74.213403,-57.894309,-147.663234,-242.448159,-217.256642,-77.573008,33.241476,28.340327,-105.886001,-207.196554,-323.721731,-283.430584,-98.23272,35.801064,104.228263,291.090378,354.957192,276.420224,185.376933,125.163047,136.5341,131.146539,178.91022,211.723181,161.563686,79.458725,-57.947075,-71.131032,-31.525168,97.268705,201.751914,278.598526,195.221949,-5.504396,-25.39041,47.00326,80.722743,123.553282,87.457667,6.628662,-178.409756,-221.846561,-203.962184,-173.776214,-108.154051,-3.607004,39.804551,10.083009,-45.339767,-118.699226,-111.087192,-7.986624,55.98323,140.3895,136.054543,79.345797,-118.233507,-209.924172,-218.933132,-131.640061,51.031753,172.304254,203.869566,123.515215,41.19942,-76.587255,-107.351138,-93.560226,-30.223603,156.114174,201.311903,125.568158,-73.813365,-137.846985,-183.18118,-164.112756,-71.100222,20.965484,64.450747,116.372334,121.586154,99.891945,60.091768,-50.081868,-59.378814,80.985012,230.177381,226.184831,68.526684,-32.389397,-162.352031,-168.504833,-137.840366,-151.438968,-157.399696,-131.265435,-121.521542,-209.431251,-279.058889,-283.167868,-213.399528,-54.597544,-3.317336,-15.874393,-21.567632,-25.609556,-125.12287,-215.58176,-360.280151,-233.603758,-87.821261,41.128024,-16.369014,-194.982775,-257.572361,-311.413926,-312.781163,-238.870758,-83.477097,-25.696975,-9.21426,-56.007246,-205.923803,-243.051709,-139.688609,18.158248,34.937794,-15.446129,-40.505106,-97.951093,-137.480816,-166.961124,-124.898841,55.745137,240.842368,295.883719,302.687965,265.567972,193.930665,206.483601,335.778849,430.128855,419.534462,337.764058,305.335578,236.32289,193.009184,157.324713,185.972776,317.266878,377.203334,355.907061,317.302058,304.420716,247.494243,222.4429,215.480988,273.906393,319.445376,356.560111,306.782537,63.725913,-45.816612,-62.896516,5.317202,162.977479,221.23177,195.108246,81.318459,4.066249,-127.845108,-137.748096,-38.182766,120.045125,168.627526,118.733318,29.145312,-207.336471,-292.865187,-274.9621,-212.538466,-72.932005,96.764341,144.756772,82.161859,6.161457,-79.291858,-63.434708,-1.098319,19.567091,32.158075,79.635431,113.891506,198.009888,234.010929,280.933065,303.114861:354.705629,262.01264,168.804104,-77.609614,-201.594963,-301.046243,-234.462375,28.172256,222.015218,268.5535,267.365941,200.674934,-31.362386,-116.150105,-105.839344,-44.759304,113.252816,211.979534,176.735102,-48.29101,-175.392133,-282.060816,-224.095804,33.827109,254.703142,287.170193,172.548899,62.898944,-134.906587,-178.217341,-89.945506,34.031908,299.04536,316.430825,219.365499,-22.30145,-135.990681,-289.151847,-274.837196,-47.727694,184.49137,205.883159,97.47668,14.770214,-165.671993,-236.549322,-228.723976,-138.075192,125.906771,214.654322,154.182636,21.915647,-16.067106,-84.47788,-99.086529,-12.258672,176.150737,232.012457,169.826365,69.191897,-159.019376,-236.060014,-243.153967,-187.578864,-26.309924,112.329063,125.343949,-7.535147,-117.54079,-231.851529,-199.048168,-48.32809,90.911481,123.836262,44.367144,-44.603825,-179.914722,-198.566714,-136.059586,-65.372063,97.334481,201.008652,185.857202,-32.568844,-181.937419,-333.642167,-304.42926,-110.307012,109.653324,141.863411,-23.160109,-162.397148,-375.576676,-395.291179,-250.837861,-137.092358,81.642398,208.667654,183.536007,-45.350332,-159.894936,-167.764524,-67.498435,176.251769,351.703301,373.803028,226.577466,75.421979,-232.089298,-304.196654,-237.820473,-157.575977,-1.089345,23.073923,-65.232406,-309.728728,-375.851001,-353.05034,-309.067844,-210.861603,-39.449475,40.837496,27.917161,-65.712468,-296.86785,-375.595118,-350.963459,-248.872107,-0.065994,74.919044,11.592396,-200.730923,-293.130555,-338.21683,-270.622739,-72.85515,66.582677,116.120216,127.068448,49.315189,-192.791886,-266.308,-260.118531,-208.368252,7.690053,246.688078,263.191873,115.484291,29.183632,-72.359606,-75.064134,34.429288,261.936564,359.26259,336.627868,194.112079,-175.512696,-267.772884,-118.382546,44.322114,295.400281,303.497381,212.57998,-33.512474,-128.861831,-201.928906,-174.915717,-56.881699,31.480017,57.013766,27.915924,-34.025922,-202.882603,-272.444414,-280.380132,-220.002545,-37.024775,115.412022,116.270941,-25.649178,-126.681099,-259.81415,-242.815767,-84.722187,40.785023,34.268797,-115.038464,-215.872174,-369.382536,-391.989402,-318.48884,-232.743185,17.896159,110.990837,18.108477,-254.705332,-331.804127,-267.014131,-163.708493,39.039925,162.827672,162.377095,32.777545,-58.991476,-256.892014,-347.251852,-349.554547,-226.549168,58.963724,92.626072,45.575771,-51.374994,-98.012662,-145.556018,-125.587293,0.742151,242.328044,376.851065,471.142021,397.831086,127.781609,7.68885,-13.743904,84.673419,304.735715,366.09814,323.505375,113.887266,-5.066398,-74.456633,-17.244523,147.481598,304.844784,352.756076,332.22204,246.358489,-63.710814,-193.344137,-178.7182,-59.310253,166.40894,127.006247,14.56282,-239.553081,-335.150139,-356.850813,-274.094527,-58.081886,72.090439,83.114974,-24.376286,-123.404579,-295.86931,-307.393144,-135.773611,-18.966251,123.600098,147.069926,116.092147,-83.994764,-231.666588,-375.363401,-294.896496,27.752723,230.662388,248.407996,159.000554,69.198755,-137.112283,-195.266536,-125.023965,-26.399633,184.567376,268.046149,218.656267,-33.285656,-174.949908,-302.383716,-267.278028,-96.656011,48.282692,76.324739,20.670406,-42.480651,-139.266026,-143.721908,-76.558371,-13.008532,194.492181,359.752677,339.04569,77.393962,-105.535416,-345.81079,-351.31202,-245.393125,-177.948693,-159.212966,-175.743168,-240.013303,-392.480779,-409.938874,-314.00469,-233.326084,-2.309469,150.945558,107.890981,-66.871337,-109.21558,-109.04359,-100.007857,-48.274598,123.851056,210.590617,177.748151,42.687303,-288.565329,-395.712308,-409.365504,-334.021718,-85.63033,80.265394,59.180258,-86.121062,-139.088378,-182.674647,-194.672482,-132.25424,89.424888,161.074869,73.992348,-37.750311,-218.563016,-262.376276,-259.053412,-196.190002,105.392758,393.500667,398.126007,212.823366,121.168192,68.018849,114.200622,282.621073,390.745901,373.23519,226.668657,146.212047,13.118188,-33.981367,-2.450817,71.957967,232.637591,315.908833,313.922322,218.911873,143.067324,57.356235,92.268443,290.568118,499.065791,543.951479,441.640353,306.474731,-10.923207,-112.988317,-99.197354,-12.359353,204.188297,259.071514,198.15156,21.73485,-78.240006,-234.330079,-240.565936,-113.825843,95.556484,157.48933,76.916687,-42.743113,-324.708715,-407.324234,-288.820444,-144.359366,85.609685,172.464664,150.470755,-9.440962,-111.407904,-228.045468,-199.07643,-32.511848,111.028776,150.76244,141.438942,98.694607,-13.705213,-53.848166,-2.516965,106.754996:223.814706,122.452679,65.533503,-123.388292,-224.71837,-284.826557,-218.899233,27.343428,288.495323,416.412937,613.6311,633.580028,507.283388,419.545858,342.024799,347.101695,360.913347,414.122918,463.03129,503.927832,450.123871,239.190602,169.750261,233.901624,425.737712,478.416652,443.044772,411.066117,372.015128,319.101253,167.077865,125.943328,115.262543,77.528756,31.792184,-64.649582,-106.902698,-208.894254,-238.037616,-153.272324,44.859178,125.610123,165.414101,115.944933,-52.605261,-117.060267,-116.038279,-58.015316,94.531873,203.699981,217.679612,175.448953,136.965324,49.320758,25.92156,69.277399,212.79065,289.372159,300.814366,223.795477,43.974302,-18.633423,-120.506795,-161.46981,-128.609356,24.938991,65.033011,-0.289455,-90.076257,-308.687567,-376.194682,-318.44779,-155.195382,-109.282388,-92.587789,-98.841608,-98.322763,-81.24479,-66.074119,-99.043394,-182.778597,-182.357574,-177.618565,-270.211664,-385.592387,-612.00211,-639.101258,-525.230917,-373.259888,-323.934765,-312.047081,-366.742242,-605.528971,-712.452161,-698.745516,-605.506114,-410.04701,-309.377982,-334.523403,-471.778145,-512.229654,-449.300874,-360.943345,-171.068628,-58.263286,-40.062823,-78.874057,-134.357359,-272.137099,-321.08149,-341.080724,-318.378211,-217.543334,-111.657264,-109.6022,-211.10077,-275.24431,-348.729943,-347.245003,-332.775485,-345.948132,-317.529249,-161.446164,-96.118544,-145.234765,-226.658496,-284.463464,-243.189496,-153.713313,-121.227309,-105.563257,-106.028394,-153.560802,-275.613481,-279.792472,-165.186819,-84.29713,-86.943123,-127.94334,-144.07592,-169.429513,-196.433653,-220.440657,-176.927096,-29.859445,41.109254,20.149707,-116.848778,-201.740682,-276.161972,-258.456577,-223.597582,-137.980244,-61.116668,28.787338,24.022286,-76.040155,-149.743201,-206.211504,-160.46708,43.273296,213.607084,210.6658,96.885351,51.04568,27.885404,37.247642,73.074168,86.961825,58.60562,-12.396726,-8.761665,-8.789574,-76.597792,-260.514039,-299.598757,-240.023865,-120.390151,-72.967887,-44.38604,-92.295191,-281.503607,-352.091785,-352.410609,-242.700426,-188.005141,-158.865542,-179.408458,-192.383026,-164.440095,-71.738614,-24.992829,64.656282,145.032523,162.733091,153.083063,140.168753,78.289021,29.504346,-8.59981,84.357965,138.45422,175.614441,150.071295,15.688721,-64.027996,-144.001986,-135.386157,-67.787859,-1.474947,0.111231,-70.88279,-111.575232,-126.081972,-101.606341,-42.125571,35.750035,96.574612,257.797569,327.799656,307.445325,212.838889,66.542276,68.803966,121.805522,152.378873,179.011363,264.185954,274.250866,132.416548,23.746987,-31.172343,228.708443,371.815515,473.535165,446.516202,321.529456,240.593158,158.441557,183.742442,257.224741,207.701853,136.406753,6.454823,-20.413275,-42.192636,-68.006444,-110.287798,-47.439502,-6.393372,61.715451,89.805259,55.817142,14.376136,19.52057,52.688241,98.858917,110.379,78.164512,-51.641623,-97.373435,-71.988494,-0.580883,166.996098,253.105359,261.673268,227.446358,184.012656,55.743483,7.42323,45.746646,118.257493,241.893574,234.082632,179.718328,18.062631,-71.595382,-193.769571,-195.425062,-109.789703,-10.706688,30.649815,75.053331,82.094118,79.746801,70.956398,89.865994,113.492768,156.486577,214.633589,210.588882,107.625973,51.230463,-4.553232,-19.710165,-105.4614,-167.853129,-118.854008,26.337609,29.914342,-99.676056,-149.039546,-143.264529,-133.546292,-108.133556,-28.859478,-20.689422,-75.472668,-99.429422,-177.239488,-243.982297,-302.739558,-102.385882,36.248918,102.827341,19.476795,-188.40871,-257.370664,-280.518881,-255.38092,-221.28894,-174.185439,-112.006963,17.776042,12.358592,-142.789088,-204.836868,-153.598995,8.221736,46.000215,-14.88424,-62.963255,-90.039789,-82.461379,-51.832064,-12.342726,127.428311,271.347298,294.092156,192.237632,114.58299,79.921647,137.473387,279.971882,349.866262,347.232276,271.801643,228.862545,183.686983,181.532583,192.516115,188.593223,228.28859,345.511685,355.239217,264.253603,214.336548,159.839913,150.716976,155.107449,191.886473,223.33141,240.757201,188.207094,-26.994677,-109.54042,-26.89178,97.037368,268.435766,267.474131,221.727201,88.786524,26.743543,6.04082,62.03605,141.329594,68.809451,52.602531,122.036372,133.28998,-24.318278,-138.372197,-218.051749,-171.463258,0.36098,159.13747,167.966042,33.444056,-46.989966,-99.312336,-58.215097,40.749807,50.428699,43.333335,12.678691,17.075993,118.472992,183.637626,263.00435,272.308522:207.523094,182.589754,126.11789,32.050472,-0.112212,-83.099033,-98.773151,8.452909,253.0236,381.979332,516.313186,505.736178,389.203905,312.948433,237.539359,268.350762,375.48304,403.975201,408.433009,409.867674,349.244242,111.596631,36.40086,100.668782,265.695263,301.852317,267.575473,234.624061,149.565079,102.069917,84.714449,104.571614,77.51095,11.32859,-8.687659,-49.835123,-71.529059,-121.70136,-137.070185,-56.72702,131.419609,169.48175,89.735932,38.741372,23.626798,52.267215,96.028556,98.663659,160.610989,310.201142,344.829036,286.027651,221.972594,105.404881,81.184621,101.660824,208.38484,278.091075,336.639201,312.838112,182.717444,88.191011,-89.738007,-138.393731,-68.022715,148.30437,206.855784,147.621393,64.352294,-124.698147,-193.776775,-201.63531,-63.454231,0.905328,46.958749,46.325237,25.852493,18.533581,25.625755,-3.976916,-125.752539,-135.433321,-130.844311,-257.662098,-364.962669,-490.658616,-484.953159,-451.407274,-410.377655,-336.71737,-166.619286,-159.97772,-396.548135,-556.492382,-639.432379,-541.583822,-308.300368,-211.569642,-189.312835,-191.995165,-237.792597,-299.069081,-252.133364,-84.863699,16.437571,40.108066,25.696116,-22.342409,-198.979761,-292.364533,-363.041489,-343.097307,-254.331361,-122.714773,-79.367709,-81.457834,-104.218172,-152.453714,-179.97958,-258.462263,-229.82872,-139.761538,16.35821,18.033309,-88.623031,-146.081132,-184.991736,-160.714986,-65.127753,36.502406,62.183515,41.722456,-6.037258,-161.861574,-234.064231,-290.421705,-199.116638,-128.777702,-102.007228,-152.507243,-246.433454,-261.789451,-243.295924,-225.137961,-134.096019,38.06689,75.068423,-14.117717,-85.656098,-178.357582,-202.224772,-225.515655,-181.825162,-132.658862,-36.680923,-20.363867,-65.825019,-85.872783,-30.507767,28.360094,139.585081,228.149321,245.258192,217.46224,190.039968,173.147289,199.574452,215.5733,103.561895,48.350089,13.106389,14.399812,-60.184422,-136.936412,-256.594766,-276.072999,-229.74496,-98.048824,-21.277613,53.750222,0.482219,-259.416417,-386.521352,-449.142698,-250.791721,-144.474267,-105.104208,-159.480402,-222.967272,-201.006741,-145.297115,-145.652444,-172.313047,-155.828611,-145.377388,-151.451401,-166.2426,-205.893007,-218.048388,-158.275311,35.419469,103.643252,110.349847,93.410375,-4.674504,-122.60294,-340.608288,-351.833433,-198.142399,-52.645501,-52.954021,-154.355078,-217.11621,-294.297156,-272.978282,-152.755652,-77.081942,-58.022394,11.087286,81.825108,194.894634,175.52584,24.219254,-28.570159,27.086976,156.958029,182.407779,140.815745,82.35789,-58.188547,-110.733919,-132.84164,8.760816,121.217891,274.252846,270.324651,159.826103,110.221742,71.556803,66.579254,59.574226,56.525372,44.086442,-17.931723,-56.994355,-100.276402,-91.923419,-63.501515,-68.160879,-64.952938,-31.766727,-12.645457,5.708388,21.047195,100.652491,140.832544,166.298244,106.12776,41.428883,-104.616687,-147.460125,-80.97258,19.502886,199.596199,246.845092,208.211844,63.147238,24.793397,19.654308,4.827876,-1.996232,38.977927,123.529812,110.835168,85.368985,-9.147989,-84.116041,-189.326913,-195.179209,-154.643119,-16.327047,67.082116,135.037268,134.728084,153.665341,145.047504,68.894638,58.145934,153.976882,260.008684,245.916254,103.132668,42.904517,-17.293035,-51.107812,-158.561411,-218.486061,-193.822279,-134.40005,-139.083901,-175.091358,-180.664327,-181.69442,-196.346688,-211.918062,-119.260157,-64.997945,-42.969196,-80.789302,-218.608605,-298.256521,-401.541576,-275.706337,-142.872186,32.48043,21.441384,-152.858123,-248.152284,-323.787083,-321.420566,-302.724358,-248.378171,-207.311929,-112.037014,-113.432971,-255.828947,-298.992129,-186.245721,-13.87522,19.108103,6.393688,-17.468482,-130.166198,-181.719916,-105.757029,-5.213676,158.53549,238.918709,242.261153,185.986308,145.726554,87.524074,95.753011,214.457224,390.995944,454.449542,499.18059,472.366064,297.08053,199.839098,167.770723,224.989777,339.689856,351.170029,336.199323,340.870623,343.617924,259.222719,182.377374,80.586085,142.981994,194.722748,201.927345,160.341815,11.08643,-80.502024,-167.974155,-134.398758,38.464469,167.79125,159.050708,-1.694015,-115.640993,-275.320584,-308.702483,-313.698511,-184.773595,-104.314155,-61.320349,-98.616539,-249.755051,-338.690517,-401.657839,-350.014825,-125.255533,86.888657,115.899155,64.080182,31.680694,-8.339391,-9.691008,-5.734065,-52.563271,-79.799753,-51.465407,23.120539,165.81484,194.440122,235.429328,258.112849:303.975308,168.434157,65.869865,-113.515174,-155.281365,-142.506719,-103.808454,34.264986,232.552872,311.425046,370.824337,351.228342,230.661853,174.11278,167.723991,197.353608,250.39787,288.378404,300.540288,232.426411,147.020998,31.762079,51.276979,195.205606,385.465839,450.913236,437.312773,381.174586,258.023708,198.542571,120.37711,130.762855,230.550734,230.985718,148.309209,-72.894205,-174.744104,-335.947375,-346.517521,-159.106874,64.734088,113.398109,90.604888,27.22226,-131.277561,-175.400691,-183.036975,-170.029387,-56.727901,162.649319,236.803698,215.918452,132.9573,-32.453738,-61.685254,-14.504236,142.820893,222.407239,195.412288,92.869533,-66.606571,-79.662054,-67.341937,-70.80756,-43.598138,23.169686,0.040787,-200.387977,-301.059904,-344.403137,-298.272709,-169.398351,-77.306923,-65.634415,-111.921445,-151.630678,-219.184916,-226.948022,-150.318149,-93.760619,-28.306712,-17.41707,-50.592474,-177.942817,-239.600073,-330.959279,-348.435166,-293.675933,-177.144798,-117.976312,-23.165272,-28.127392,-224.583893,-351.461045,-407.77742,-330.528022,-94.094565,60.188231,21.125543,-212.562709,-284.281938,-199.013777,-103.336973,27.908246,101.191161,113.168798,30.925429,-44.676808,-196.920271,-247.548564,-239.299827,-197.867851,-127.578754,-136.187904,-171.9167,-260.04402,-307.584702,-377.294473,-364.631897,-250.210011,-127.901405,-98.03206,-97.399891,-102.384471,-158.35156,-218.858941,-297.820135,-284.810069,-119.719377,51.579881,23.132678,-171.372604,-230.392223,-257.741355,-263.901846,-204.815552,1.09881,101.424149,133.848402,52.408896,-158.586639,-219.516857,-255.337026,-243.210725,-79.011268,131.611699,126.731957,-60.493276,-161.257975,-288.917605,-300.289057,-228.971909,-65.99853,9.49785,44.074866,-6.519605,-205.553046,-283.611784,-211.61388,-80.690777,175.572679,251.521789,198.709017,27.058641,-41.745472,-136.150277,-162.803177,-175.866539,-116.864438,-77.18121,-34.939783,-21.412826,-48.507569,-103.588372,-209.286157,-224.449132,-147.89753,-44.313248,-39.02723,-84.817621,-120.633559,-199.187928,-220.108874,-191.85467,-64.029045,-15.874573,-152.304586,-304.090034,-465.308126,-418.915051,-193.747197,-103.58833,-27.488147,-12.498019,-39.382505,-107.004994,-106.390603,-97.782202,-113.729632,-91.412069,56.782733,115.188649,115.690462,84.399801,-12.10986,-84.53989,-226.265646,-232.947776,-64.390671,61.533425,49.023633,-22.668496,-64.661619,-154.162382,-146.500851,14.631756,192.581018,261.072307,319.242587,286.808151,128.649211,63.785529,45.489395,58.233798,104.513499,172.690789,166.856312,99.004445,72.528517,24.224922,-0.538795,43.602761,244.483632,350.046021,418.473642,347.599917,113.650656,38.46326,14.941004,31.370708,62.418495,43.666921,-2.598839,-129.747839,-158.771331,-116.910443,-91.031032,-49.685328,41.480826,72.01029,23.15988,-38.227933,-158.365094,-201.919576,-218.849304,-167.896239,35.707665,157.024975,109.044275,-103.545091,-174.470424,-117.347347,-21.434522,100.89678,116.399332,119.704537,56.85451,-6.672959,-110.580953,-130.602871,-72.203109,-2.661879,144.316623,182.329355,137.668733,34.018053,-1.915083,-87.564438,-119.446945,-91.482232,-1.304639,30.881851,39.957712,25.735226,-10.643871,-19.503983,9.46393,55.782707,209.92882,258.008528,201.092676,50.483121,-6.983828,-67.096723,-76.984382,-128.841237,-185.837167,-166.735707,-89.200265,-76.395146,-121.427492,-153.447639,-183.155523,-186.970686,-100.321677,127.479535,164.733767,33.251072,-16.4819,-19.034047,-46.269237,-139.378095,-17.757836,99.938404,135.029426,38.926725,-155.654485,-204.326004,-242.290627,-253.268626,-215.895847,-62.338354,9.222857,-7.49983,-82.104266,-174.900432,-155.945516,-44.318989,-11.187683,-53.684021,-160.707611,-160.886876,-47.948488,-8.599519,-13.866464,-2.612054,131.96421,296.584533,322.05897,260.936628,213.712536,132.938328,108.329421,145.037496,274.033539,291.307742,178.324549,122.308901,73.327809,58.783846,83.984361,125.673572,230.373011,301.05672,291.517082,185.14567,117.847321,67.631977,102.843726,196.981747,264.376761,291.5444,270.311785,204.129501,55.224824,28.230259,65.165705,106.646172,225.641685,327.141647,309.421529,139.329178,58.960725,43.28516,81.573125,105.22322,140.813855,192.825438,209.326848,137.229299,-108.028355,-221.578338,-259.614293,-174.195369,68.233024,193.932728,171.307276,39.149384,-19.665315,-76.279046,-55.895584,57.980555,75.772484,28.163546,-40.241622,-17.24557,73.27124,92.912089,139.626886,213.312053:right
-233.910173,-263.752715,-250.43683,-196.367672,-150.330829,-81.198893,-92.019856,-190.531983,-258.748957,-271.234834,-314.513021,-329.741432,-282.991118,-242.80131,-236.271595,-283.383392,-369.245462,-346.675065,-300.764023,-128.75158,-44.510623,-4.648653,-35.823139,-107.927953,-112.945637,-97.235638,-79.176741,-59.37536,38.209156,109.434573,181.814329,115.169793,-101.686788,-27.206038,111.845384,320.87028,329.954211,231.987717,179.78543,79.949791,-68.031334,-127.861219,-91.58298,-14.336015,71.460214,53.04915,-33.81342,-74.289647,-119.278376,-158.839508,-197.322451,-277.080862,-302.106047,-288.723404,-260.928406,-242.544754,-240.21419,-213.088345,-106.040931,-60.387565,-71.302803,-91.193453,-62.254161,-53.407371,-99.434867,-44.260525,47.497768,246.471665,311.448793,338.347224,309.092436,210.821188,154.683496,156.143992,159.008797,135.256039,31.041486,0.982449,53.351293,72.157908,11.740768,5.448103,34.264601,75.291819,91.476154,109.676904,92.623822,-6.485409,-41.256563,-12.91267,16.724078,19.659688,84.705979,145.67572,207.024175,171.000837,85.223779,142.348246,206.028365,298.637185,298.026192,222.244453,148.874601,-60.217406,-168.999605,-157.410873,-113.838084,-107.598357,-116.5739,-127.0331,-173.468259,-194.012924,-146.261972,-44.652517,-35.950472,-79.562696,-86.881826,-60.484939,-62.25118,-101.573772,-1.45417,108.804838,280.576217,307.649034,296.822372,282.184873,187.691207,106.052588,25.648389,92.471731,123.102115,129.975532,88.480663,-86.914354,-185.757379,-319.418021,-339.735968,-332.115182,-323.590383,-300.518043,-155.566196,-60.750818,18.240737,-21.643283,-167.074937,-309.156039,-360.576141,-365.669592,-332.96918,-235.760594,-179.668716,-112.960443,-60.088109,-29.354673,-30.025896,-65.980785,-174.779328,-220.320065,-206.192363,-161.32659,-104.097133,-88.395962,-74.694549,-54.797101,-71.370893,-128.624805,-142.335019,-147.054198,-97.374054,-42.125087,36.421732,53.498608,85.398105,83.655149,31.72103,-0.318475,-50.372424,-44.857818,-5.05574,110.926389,132.722874,46.721523,-8.998319,-34.065918,-33.392758,-57.337509,-62.180486,-14.299583,48.510763,32.881779,-8.442643,-39.868733,-131.881118,-118.793845,-62.093799,14.219,-21.825988,-199.983178,-276.787244,-343.78514,-327.66519,-309.423317,-307.24677,-324.448869,-391.577687,-425.749281,-441.115136,-436.63241,-402.165993,-290.10403,-229.297218,-179.236384,-198.52731,-206.480017,-163.796382,-139.54258,-281.572174,-337.779161,-305.917894,-228.043593,-83.246138,-74.308513,-150.163364,-170.103747,-124.273654,-71.392463,-67.673206,-72.05348,-65.834091,-81.335591,-121.837086,-185.176148,-104.186628,-63.715909,-50.76503,-10.770579,129.032043,145.665588,74.828915,64.751956,174.938078,276.05808,269.439819,217.7372,212.394077,243.484079,234.098673,82.326279,-67.568458,-73.154173,23.847981,90.592447,156.141698,145.07698,83.587943,44.959636,12.27608,74.985294,125.538194,229.458994,247.987923,198.546633,172.806755,126.380984,83.489919,109.19455,185.879818,168.257077,47.837368,31.189618,116.502461,141.858789,112.435553,148.95658,204.211863,274.106697,252.39035,116.966604,51.574139,33.206688,150.010104,212.356985,265.772343,274.283042,311.630818,332.018719,322.299114,285.225075,217.334989,274.411767,353.028585,491.018222,513.665837,498.592999,474.763383,402.838029,350.27496,351.712336,398.215798,411.832259,319.267991,228.24445,95.011755,65.74229,114.310071,316.570746,397.714909,414.978759,376.034193,326.928308,319.990993,260.812204,256.970792,310.184623,428.937339,477.004507,553.601988,561.282492,480.48447,433.849842,439.815777,432.552707,378.799866,288.968581,259.934741,177.319208,152.742453,185.411088,231.434737,230.146615,207.412665,216.678232,243.83991,233.757628,204.574549,199.222963,183.400756,151.391342,118.398153,23.46301,-20.373448,-66.288315,-67.511912,-79.333128,-51.581723,-15.503719,39.076329,68.276799,100.21786,78.088667,-38.119678,-123.032871,-223.027496,-130.552892,-70.450542,18.114309,58.490649,81.376044,57.458409,-26.633633,-107.297969,-86.603655,103.773961,196.541882,195.390997,119.399771,-41.928266,-124.521362,-265.844133,-210.445387,-142.891042,-66.838005,-51.502686,-38.009239,-56.933492,-145.796196,-193.384125,-180.998478,-119.522987,-86.461339,-54.237113,-58.496037,-61.949922,-67.216655,-125.906477,-161.298056,-137.379829,-89.768457,-112.613964,-217.586525,-253.041748,-289.595448,-280.907038,-242.403589,-168.715896,-153.064066,-154.565407,-178.567071,-266.933241,-306.672991:-187.467394,-142.395013,-135.149756,-135.451935,-112.248372,-64.207894,-86.900178,-176.972574,-188.821073,-193.969494,-251.515011,-272.430935,-260.053696,-238.253434,-212.192626,-225.306351,-261.884731,-238.351857,-198.280306,-79.995204,-23.495718,-4.288203,-62.541626,-212.84627,-182.221344,-113.127752,-13.92264,10.850665,50.653926,64.498022,33.94985,-15.681929,-98.098934,-2.598939,98.680454,186.77583,143.517433,39.014147,19.709913,14.557199,9.279083,-14.285577,-64.914393,-54.057526,-20.164122,-40.379801,-130.142812,-169.769779,-231.311728,-255.854173,-257.053825,-284.440993,-290.360484,-213.715678,-154.027245,-132.798729,-240.142666,-245.82643,-84.816119,-5.178799,-0.050871,-39.17767,-108.017845,-115.64743,-66.242077,-33.256253,3.98825,180.66209,263.008678,292.023871,254.72687,184.858361,189.443362,212.689671,240.691501,218.67231,131.092263,112.363604,136.877259,124.829545,24.233574,-3.757277,40.18664,161.741732,182.379036,95.178919,44.450177,71.170203,124.207222,103.915503,55.451445,50.402011,82.494604,125.068247,152.711935,109.96781,51.99596,141.302468,221.003781,334.218554,331.695248,232.469444,152.382557,-6.9031,-54.273501,-49.558427,-55.321855,-68.207585,-100.822245,-113.58612,-156.129418,-182.543573,-180.512827,-123.009026,-82.603875,-37.557992,-77.393638,-208.429766,-234.317582,-166.386134,-32.119374,28.42187,155.051705,194.397473,161.275294,137.925289,159.806781,163.001953,137.566061,185.037564,212.487906,210.301272,179.795782,80.224341,18.483485,-104.508374,-163.048907,-168.314516,-145.168309,-112.263426,-11.145492,42.217076,70.441776,30.437417,-80.267326,-196.622841,-246.204275,-291.933136,-300.944426,-309.5301,-297.737404,-221.412645,-145.118522,-123.002947,-56.559768,-31.17316,-114.32664,-195.267178,-270.905215,-260.163834,-194.099159,-76.693798,-16.666125,17.82945,-22.008196,-156.883596,-216.288925,-269.709496,-253.680984,-225.538354,-119.477763,-58.615597,15.098706,13.288081,-52.115521,-85.927565,-94.317271,-46.856411,-1.961436,102.03566,114.010782,31.118111,-32.506672,-85.317845,65.034248,145.133411,136.904785,72.260728,-66.70189,-103.769629,-58.954443,-24.364214,-67.190268,-145.611837,-123.518154,-21.237338,-28.220831,-191.024842,-280.976408,-371.31521,-287.756754,-204.305248,-129.483846,-159.966353,-245.26806,-267.051678,-318.627819,-367.335198,-407.210214,-269.167391,-199.982212,-184.372799,-199.370089,-135.504613,-74.943372,-74.294568,-212.272039,-258.323137,-266.280335,-241.337447,-178.477855,-169.314939,-200.26695,-204.527163,-128.455367,-33.53971,-25.709082,-65.357854,-69.673857,-35.212541,-49.204716,-124.98521,-84.187045,-55.82696,-23.539678,14.159601,65.257176,52.251907,40.545636,79.781125,230.963757,324.349059,316.966569,260.888783,241.833669,240.348491,236.563679,179.318964,113.542079,106.455126,163.435329,184.647473,120.66873,88.744857,71.776919,29.805923,-53.718685,54.243456,132.565081,191.005121,178.56801,154.157568,146.377841,99.408874,104.109991,146.024674,185.958307,153.181296,59.349084,38.861412,41.771466,42.674186,51.127149,153.91746,210.819262,160.711185,71.867159,-18.024013,-15.137716,-22.212264,33.600424,86.541767,128.223123,139.653511,212.968434,244.274337,270.130249,275.514572,225.091142,173.491894,227.763583,422.558158,469.064915,448.284072,437.674908,412.970783,387.63336,414.228309,470.1935,438.326947,270.258362,205.34317,142.724837,101.676386,59.999939,188.223202,267.886363,332.896571,319.401899,285.359828,269.486737,184.92389,151.192569,195.22658,345.34735,429.149497,553.945598,572.281936,513.805741,446.700462,335.260556,321.629814,331.364381,328.758926,282.021264,142.806658,113.312969,153.92822,219.682312,244.222043,249.890625,231.105288,173.122932,130.143375,51.128835,51.974195,160.170894,218.529478,175.241582,61.885863,45.018077,93.671637,124.335375,158.788636,204.436265,210.452984,178.734025,181.842044,193.011209,150.337473,5.995026,-56.13099,-127.083353,-19.35916,93.578391,222.330618,201.172327,129.476451,132.729274,152.328677,61.879652,33.736219,159.261118,241.645271,220.87556,147.174199,29.608922,-17.671099,-112.474108,-92.773189,-36.735402,65.525588,60.074123,-74.957489,-144.585977,-176.644288,-100.374246,-46.588351,61.763257,82.663457,7.295244,-42.082899,-56.658131,-27.333732,25.322781,-37.956244,-83.010008,-100.831466,-103.876336,-191.08242,-252.319176,-318.3028,-240.415902,-153.807305,-38.760382,-45.023271,-101.87824,-133.675254,-265.536619,-360.827063:-86.571985,-47.182563,-6.081886,53.708922,58.749415,45.272429,31.563864,-1.724853,-41.159264,-72.747914,-149.097064,-178.287218,-182.788711,-170.849185,-171.881632,-179.812118,-181.231438,-193.69505,-191.209574,-91.694245,-13.361433,44.380066,-4.927285,-112.875163,-35.541691,9.415033,-23.468489,-69.113878,-122.840027,-122.840112,-114.184305,-130.276586,-176.809315,-137.650327,-95.156439,-78.452662,-111.8897,-154.085053,-146.930696,-126.480706,-116.316022,-114.819577,-74.780363,-42.362027,-41.651327,-80.309084,-169.669387,-197.447491,-203.132469,-168.565896,-154.69966,-193.398935,-225.856523,-175.828226,-119.07456,-107.366924,-116.744434,-67.736359,29.011026,27.057684,-5.953584,-0.435944,-35.801724,-89.159875,-129.360991,-48.811822,-7.269974,35.034154,63.46076,171.825133,195.943158,120.342744,110.636088,156.182036,178.452815,139.49876,100.602832,123.424623,119.814196,63.870841,-46.937197,-51.386524,-20.038176,36.151982,29.89968,-14.957353,-20.008539,39.163858,124.6318,140.094029,88.655042,36.344747,-4.582463,21.891649,70.85067,70.166183,39.042516,36.042417,66.494286,124.817122,125.751364,106.632452,83.863942,-3.142804,-27.157492,-9.515995,26.859451,25.49494,-74.051784,-152.405729,-260.195131,-260.955299,-139.052207,-7.274521,0.106618,-90.357208,-144.43421,-180.250046,-161.487663,-53.600139,29.815349,27.058924,64.203567,115.26436,162.891175,143.779312,96.854205,110.650348,215.000935,284.99913,291.604189,252.560626,197.419956,72.409322,23.345268,-40.294272,-11.67276,15.354757,31.270357,31.191756,15.897593,-7.315441,-43.566532,-39.328362,-40.863772,-138.200297,-179.703023,-181.030283,-168.269544,-166.697448,-171.118996,-171.793367,-154.845206,-128.900837,-70.181908,-67.100963,-126.187384,-175.472222,-278.894676,-290.391783,-179.642657,-59.787123,-36.625591,-60.885338,-99.673557,-147.822955,-150.865348,-167.425135,-163.738236,-156.809744,-150.579033,-136.36717,-114.561864,-122.416403,-130.420308,-107.489011,-34.511829,-21.671424,-10.976747,84.129123,126.685363,96.417851,28.065828,-33.357367,112.399416,176.609623,186.314627,144.435378,31.44647,14.115082,58.976572,47.652594,-44.352097,-39.790659,-15.894756,0.230706,-25.801331,-145.666292,-200.716129,-248.559161,-220.480985,-166.211478,-41.423391,-24.977023,-105.464523,-155.604615,-215.18852,-251.313228,-282.122798,-133.486194,-57.831834,-36.897943,-63.602607,-47.775531,3.901106,67.648587,-10.280672,-65.862734,-118.060525,-110.825637,-74.637845,-89.906802,-205.701011,-226.707153,-135.110899,-37.201569,-6.628119,-19.188118,-65.255019,-166.565541,-199.60009,-195.839803,-106.419197,-70.022972,1.826211,50.482405,38.911215,-26.633866,-89.426366,-55.555762,86.385735,204.618268,209.302101,104.269236,47.451272,25.918502,19.855997,-37.605593,-35.941742,-14.256896,68.365852,116.012033,124.943151,103.656825,73.995604,52.397951,36.833886,175.511656,280.004438,347.026571,283.455474,162.34193,156.922045,136.435868,145.876894,207.945758,263.416696,222.066352,135.480667,108.100997,67.515768,85.20553,183.163559,201.617945,178.068391,132.981738,116.265407,100.710435,110.632485,153.837131,190.713334,198.094616,182.90362,166.21815,175.00134,216.47725,295.79646,292.24379,226.805566,207.408987,230.495219,291.217198,311.604388,340.952835,357.42767,381.116909,366.43068,359.869126,357.893166,335.380301,223.949507,178.398662,147.433566,129.346141,72.146222,94.591185,161.576593,263.660877,234.01337,113.017763,89.272985,102.040175,101.145921,110.852351,230.194737,314.929871,381.933676,364.330136,347.674641,358.622788,357.196995,301.044532,273.053025,209.852047,164.681251,121.579159,129.014937,118.360994,110.920882,128.311578,210.949127,269.217267,299.596598,239.661911,79.330193,38.450016,65.344897,111.573337,109.308831,101.025767,118.074441,179.741795,183.354372,130.888691,137.74778,159.016786,223.621758,266.992527,259.699783,183.25052,-4.434031,-48.49284,-10.632599,42.4864,61.884901,126.857561,148.448846,110.791053,64.166918,-13.994162,48.52167,145.840163,319.417814,341.101962,278.280093,227.170618,92.808505,6.906598,-107.198619,-85.791609,-51.657282,24.711969,38.429225,-53.253571,-132.355154,-190.098522,-88.124462,-47.394439,-10.710842,2.590814,-39.5703,-97.550707,-174.440761,-163.829975,-119.859074,-116.665689,-98.092103,-33.839244,-31.19803,-81.481149,-105.909988,-155.686008,-177.283215,-154.693546,-87.051115,-85.332665,-154.190765,-193.229532,-238.560003,-242.546168:-184.676555,-195.306612,-141.310017,-4.011752,32.31737,11.19916,-29.215623,-99.890712,-114.99303,-130.258175,-187.546127,-210.225844,-240.833774,-243.40251,-214.497774,-205.282424,-209.812312,-242.73884,-243.875913,-127.953663,-48.694972,22.190453,6.47024,-89.320603,-154.287292,-152.004471,-84.594363,-53.295548,-78.593655,-113.090228,-203.623187,-272.451023,-339.461113,-198.77404,-104.946487,5.577139,6.029279,-84.250984,-147.153375,-269.052314,-345.088064,-351.783887,-298.720672,-245.785421,-186.812832,-204.594189,-257.939832,-265.478842,-259.106257,-242.828025,-224.990522,-169.288955,-153.201363,-146.382993,-140.482783,-136.018503,-92.737515,-45.266707,55.438858,77.754993,16.833772,-31.656953,-96.993528,-127.618006,-174.03159,-128.252928,-59.010598,120.071292,164.578539,147.886259,145.269739,147.620618,94.1512,61.558916,11.344328,-7.204534,-16.023376,4.872284,3.08327,-48.221122,-152.364642,-160.291886,-124.702004,0.140712,53.597978,76.009382,42.058955,-61.04864,-65.031837,-15.340952,82.167135,99.231114,108.729521,128.422495,129.326516,84.857779,25.982648,46.645851,74.760663,193.842016,238.094814,185.814997,100.772694,-85.348136,-139.395313,-133.811114,-170.097255,-206.259313,-248.203432,-250.55013,-264.988071,-281.649672,-249.288952,-112.3798,-50.80348,24.33499,35.853785,-0.839264,-18.895272,27.169991,104.115665,121.144281,155.482781,187.072168,246.415031,257.10326,216.614345,168.318487,99.204701,93.962196,108.745249,144.844215,126.530934,5.85827,-82.63602,-263.877797,-291.548664,-248.714255,-176.472424,-161.917667,-140.495657,-122.265736,-79.426376,-81.088022,-144.655131,-216.084728,-238.386072,-220.972217,-185.840534,-112.732325,-83.690835,-29.446457,18.37384,39.793428,72.369066,50.549057,-94.979293,-163.715094,-205.07356,-200.722214,-141.212581,-34.543037,1.57776,19.724179,-9.534954,-96.2522,-120.671377,-135.332522,-100.543357,-66.519748,12.18471,78.243536,213.816266,206.439057,13.14994,-78.867576,-69.032726,74.53469,125.738782,187.850534,202.216328,172.486362,136.674624,87.253737,123.058127,158.988708,227.596467,241.262662,170.316564,107.138148,15.933555,-16.334175,-37.169933,53.069083,102.258136,82.784887,7.481399,-132.210198,-152.73224,-176.511298,-195.81039,-155.697819,-7.839727,40.826032,-13.356043,-85.791534,-201.278263,-235.517053,-222.029744,-108.849939,-57.371346,5.552515,14.965945,-1.440926,-12.181515,-17.197027,-33.127682,-56.110405,-69.90101,-41.263782,-11.28532,-56.036813,-168.607243,-164.648716,-52.86991,4.82349,-7.467892,-40.359689,-58.882914,-131.462098,-182.570625,-293.716197,-268.776426,-188.925151,-14.04678,42.125796,30.233812,-18.689928,-115.23034,-142.602998,-61.642041,106.306565,121.202292,33.168686,7.127583,54.235133,68.631183,-31.914999,-121.672508,-119.516784,-58.399418,-7.297288,61.216334,59.740515,25.006562,-2.391668,-29.072867,100.973438,219.254502,401.325289,417.539237,380.981306,364.064727,278.846266,191.741878,217.636836,339.548406,345.428943,192.219278,119.310566,121.073837,151.063942,172.656038,212.064682,239.282044,281.039159,296.125113,263.288893,205.576802,87.67954,124.093511,186.886188,233.447541,192.719418,104.144703,120.879387,255.569324,308.533439,356.881562,393.587845,397.879112,398.879938,423.243717,489.797564,473.373011,352.924148,337.08451,375.921296,454.234501,452.062899,300.621083,202.125597,107.028712,101.822036,130.73833,178.505,191.943388,185.653069,167.757941,158.022679,163.44693,143.142519,180.938789,239.566179,350.643984,388.214851,438.953439,459.283143,439.761754,382.404421,258.979508,219.280044,230.795829,274.190533,259.553161,142.813919,86.423571,29.156438,76.897729,131.071844,190.312755,174.711699,123.353196,131.441352,189.399337,184.971683,90.304933,18.268083,22.576283,48.682261,35.913772,-11.266868,-24.311174,-52.971356,-12.657092,26.173717,44.772282,33.099317,-32.164847,-81.352856,-152.167216,-163.54174,-100.498677,-33.864536,-47.173833,-33.114116,8.856678,29.464432,-11.416376,-114.839017,-78.888403,4.917386,178.14967,207.092164,76.292328,-39.411691,-180.358121,-202.437904,-260.558184,-295.584013,-264.700057,-201.28424,-219.767457,-300.845077,-316.628644,-290.978884,-221.717384,-177.92821,-110.00985,-106.557407,-170.340856,-203.722325,-215.792435,-208.679086,-230.144701,-276.711677,-251.835043,-94.800345,-48.278248,-115.671084,-172.231403,-268.708289,-280.756078,-227.205571,-128.650023,-120.810115,-145.526416,-173.940906,-295.388187,-371.747763:-108.266154,124.377494,200.382642,171.622068,109.0072,5.328419,-24.893179,-26.589818,-24.316699,-62.218524,-141.515603,-164.720536,-220.588527,-235.503058,-208.768625,-189.037724,-163.472986,-127.629653,-90.51953,-0.440556,21.351952,-12.76314,-46.502155,-75.969206,-24.893327,3.478887,-2.237729,-44.473496,-178.354376,-235.235517,-305.297502,-335.486647,-348.314474,-219.369304,-127.226832,-70.879423,-123.042302,-207.047258,-212.849736,-240.376534,-238.945235,-203.903753,-128.153587,-114.920713,-155.39655,-196.01479,-287.685406,-306.511157,-206.186114,-54.035448,-13.989165,-4.764798,-18.199515,-5.095279,13.549056,9.339242,-13.231078,-8.939424,68.602037,114.498685,104.031695,55.59463,-86.161956,-165.404471,-239.312064,-138.331748,-54.022207,47.486889,58.396082,83.163886,82.687486,7.307569,-31.704116,-17.927151,17.09453,16.162487,-30.69763,-53.691419,-94.413726,-126.412643,-184.97643,-177.173905,-140.48338,-33.076497,19.458715,100.418583,114.572196,85.15736,81.573329,104.925048,127.252693,110.839787,71.37833,69.04581,86.6918,80.51027,9.481311,-24.905416,5.995579,68.599428,69.209702,44.161769,17.087747,-50.598673,-54.09044,-66.903992,-169.491464,-221.519602,-249.950679,-241.374563,-276.782316,-312.426947,-271.588901,-96.617953,-21.465305,17.619877,-5.514285,-32.010037,-28.007968,-11.972159,-3.304106,5.734789,95.827844,152.895723,172.476233,135.162751,39.991141,12.670557,41.782597,76.393819,91.973827,148.400135,128.698482,-55.832842,-151.144875,-195.062847,-86.033525,-36.986995,11.335655,22.375222,10.508406,-9.585511,-40.142219,-48.807593,-62.132808,-40.740278,-22.80853,-7.514296,0.733962,33.787332,30.753259,-25.464238,-22.220151,1.437601,36.362491,36.274128,-33.323157,-92.355739,-210.998585,-252.783515,-212.730536,-14.505064,74.370799,107.74774,58.230558,-102.373937,-181.064273,-253.218263,-195.677279,-162.259506,-67.404889,30.003933,156.795283,105.734032,-92.216525,-127.491253,-25.321747,66.723874,88.693997,160.913069,176.793804,118.615326,77.172696,36.968851,105.718992,163.600436,271.920146,298.828891,214.236088,125.505843,-8.137262,-38.251299,-47.032751,-35.326161,-29.772457,-41.063335,-82.943467,-196.671488,-232.424203,-245.272315,-164.975275,-109.899114,-29.984276,-2.321459,30.16809,10.641022,-137.443145,-214.575447,-176.816573,28.972095,102.907737,157.67759,142.589927,68.962503,38.246545,18.73083,20.97433,21.660516,55.733718,74.818441,38.658822,-5.645981,-107.736207,-146.442613,-111.264786,6.402458,57.131612,93.637043,49.948837,-108.185736,-171.537739,-204.127208,-102.593987,-57.729402,-15.776432,17.708475,56.391939,19.54566,-124.175908,-167.263099,-112.425354,6.10936,49.442451,62.412451,18.864809,-103.336661,-152.706522,-199.586836,-193.967669,-184.155155,-93.425869,-23.716675,49.036582,50.114907,18.981965,9.02677,85.466848,289.745425,405.23335,536.591711,514.661485,382.349226,336.665388,292.013729,273.740146,292.538707,377.499117,398.65948,317.437207,254.007682,196.127047,203.545376,236.533422,257.913902,281.82172,350.810724,360.25151,266.954372,182.576904,78.750174,165.884645,230.348628,267.914695,259.307597,269.085414,275.644142,253.282671,250.296122,318.835729,403.797922,425.844133,438.611008,440.39705,449.335272,432.600019,336.525682,300.563357,330.853808,408.449825,407.97347,269.600192,163.097532,-9.910003,-48.436502,17.352975,153.64934,198.547066,215.464515,180.815172,89.926517,52.309672,-9.161957,35.524565,102.431376,229.879883,256.921705,237.726635,218.998173,179.160607,161.621751,173.696446,188.112593,194.177881,220.002741,214.011962,155.230589,99.897405,-4.898981,10.083956,28.006955,64.732357,107.057502,144.778672,109.894855,46.182154,46.026225,65.977962,38.739391,9.53934,-4.60724,4.225988,-38.153759,-87.588212,-117.614171,-19.462316,25.697186,91.044365,110.022385,42.681273,-43.639161,-228.704793,-281.896527,-243.432967,-116.686485,-69.130767,-29.629414,-28.628792,-32.823873,-52.415884,-115.523286,-66.475028,4.159803,143.231365,176.121691,109.646371,28.932634,-118.833537,-172.012576,-254.537993,-275.1035,-237.207675,-128.586255,-118.665764,-220.368222,-291.634433,-344.786017,-242.80806,-186.127692,-132.143578,-128.988718,-134.572916,-128.072887,-167.147427,-225.163521,-261.694191,-130.63527,-52.742525,34.476525,22.109082,-66.938489,-120.899616,-283.418301,-349.182168,-268.626228,-73.454269,-51.738038,-123.194923,-172.606737,-285.609999,-336.247012:-231.688096,-179.703892,-97.369609,84.136722,110.609648,34.006225,-13.479371,-74.509995,-97.064743,-109.409201,-147.081647,-149.054993,-130.756283,-130.811423,-151.654176,-175.769665,-203.002885,-150.420294,-107.154013,-15.393321,7.361708,11.966419,11.401294,-49.192702,-187.472768,-221.102318,-155.454502,-98.400591,-60.723631,-72.497108,-96.281782,-121.597881,-197.839348,-213.882913,-169.33906,3.000197,65.227909,72.079577,34.994965,-130.058613,-298.7493,-316.131382,-238.701035,-185.029407,-119.801068,-105.493535,-74.132624,-70.284695,-121.59293,-193.169715,-211.564617,-206.390428,-195.759366,-112.125648,-32.479436,71.099259,60.611444,52.628317,66.794457,76.11663,43.840887,16.260972,-4.799331,-18.474484,-70.516258,-7.271646,82.341341,226.616429,244.689869,277.157445,309.673916,285.598668,192.330419,170.92857,129.600864,88.683897,3.123232,-26.698836,-63.415181,-61.837117,-11.768564,32.250356,48.046436,125.180625,167.342398,181.73675,154.776783,50.689682,-35.413772,-50.062921,-9.470197,30.118115,61.024978,62.643392,107.454223,139.772148,194.664934,243.45846,261.088119,262.050196,234.843836,106.441936,7.103117,-170.156608,-182.127631,-160.222043,-178.357938,-211.833632,-275.020435,-291.594438,-275.635995,-244.805635,-147.033291,-82.507813,-75.55604,-45.424771,-22.192357,12.934816,25.488907,43.243748,125.745101,206.852102,347.922896,358.759496,259.463765,200.414756,134.712668,97.251948,-30.809942,-119.557936,-114.566799,-93.593566,-125.015602,-252.72767,-331.198982,-473.180896,-484.739664,-458.633154,-411.419061,-379.105523,-276.210378,-211.628464,-112.678384,-103.880973,-163.243339,-230.751962,-224.101419,-181.033097,-203.141343,-241.520442,-178.583572,39.541674,120.74232,86.302745,-13.938622,-43.252716,-97.782567,-135.511202,-180.837159,-180.101855,-136.507039,-45.371515,-6.840693,29.886688,22.041869,-43.210778,-86.71951,-159.445004,-90.843195,-11.530174,85.800006,108.093549,168.574393,183.211935,112.611079,49.034378,-21.227058,-2.236612,13.280541,28.757975,17.375876,-44.865273,-71.843832,-82.769834,-59.915329,-50.515021,-26.693547,-2.461442,20.614975,7.072816,-55.914036,-120.504475,-225.311384,-124.770936,-48.067667,-22.046557,-82.298663,-193.642949,-196.407878,-213.899961,-303.681148,-307.193387,-198.932683,-135.590125,-92.861898,-115.433366,-178.267525,-180.447417,-87.195608,30.834412,67.163084,72.933,28.04129,-75.185809,-83.613644,-45.496182,-46.718721,-53.09749,-22.342265,6.675181,61.568113,84.639201,72.646301,36.018019,8.824832,31.408136,12.735521,-41.613521,-51.283671,-97.553577,-156.911045,-299.033294,-277.234382,-193.708228,-39.582873,-8.987387,-11.457002,-12.234146,-28.365791,-60.744867,-92.259886,-17.361024,25.731817,72.289558,90.011974,159.363267,167.47073,11.241802,-149.801047,-152.923228,-51.385638,32.997155,165.540235,165.60223,63.941069,20.385094,19.476285,79.154279,125.525782,265.102287,331.324766,368.37584,329.043129,206.938235,178.654114,212.032774,299.226569,315.81153,225.105679,157.670531,149.314719,195.993285,266.99197,289.167572,308.059815,347.299469,323.793751,190.081186,130.302626,109.786319,219.379967,284.513916,316.51607,276.466229,198.637554,199.992425,278.260052,319.532071,339.453411,355.043711,411.090905,577.404308,615.739356,517.661341,422.242414,286.053967,272.635387,305.289526,390.320048,385.326442,226.626862,149.946315,141.293641,170.404957,232.654103,294.913368,326.413466,400.33428,399.104987,291.847322,239.872117,190.087534,159.896047,162.871796,236.844523,282.493006,309.932235,299.942397,274.688149,266.695993,260.898519,228.228784,188.913551,127.493321,119.533867,112.757516,101.644734,45.375102,69.291896,130.143702,196.236574,188.799509,190.247868,198.111173,183.299889,165.805501,121.162989,56.926116,17.43343,-50.451497,-73.620529,-134.319144,-158.200136,-165.782596,-180.067501,-185.083271,-130.058709,-71.511061,-38.90687,-81.706357,-141.997248,-139.837326,-120.178526,-134.300389,-167.865616,-161.873579,-111.87741,-81.521261,-113.120718,-186.942658,-194.211847,-137.615963,60.158131,128.249165,67.698011,-25.096518,-162.573632,-206.727135,-336.332642,-431.605623,-417.035063,-325.565166,-296.025675,-273.578858,-256.458736,-197.62344,-142.129909,-137.567247,-158.866412,-179.125506,-252.595003,-276.546599,-264.909066,-274.458012,-341.250434,-302.04623,-228.194355,-71.080826,-50.267343,-183.511009,-283.060932,-390.595954,-327.83511,-255.249276,-161.287324,-163.387278,-185.158018,-200.076469,-295.052783,-366.346234:-262.399832,-32.974744,89.940397,216.308461,225.811654,156.779669,83.125863,-43.905772,-34.020834,-31.847314,-70.888965,-72.006048,-62.153519,-86.995242,-175.749272,-203.005438,-177.629112,-52.695269,14.811671,63.043688,47.512539,26.347219,16.700295,-64.562299,-152.364237,-164.498693,-130.414813,-111.697061,-128.493908,-160.879518,-285.780279,-368.432619,-405.681605,-194.080479,-75.801626,31.940027,22.939783,-57.855152,-118.165817,-247.975366,-290.287982,-261.988432,-131.653642,-70.009982,-64.771683,-106.836182,-189.52062,-215.518133,-198.466072,-56.764296,33.861339,142.090398,134.691773,82.307839,75.158659,58.197356,80.282092,139.547688,257.349209,264.38592,170.176219,113.665101,13.631238,-37.77812,-63.65416,42.167962,120.019697,259.698813,277.303194,198.940287,157.61142,159.535966,181.423802,169.219053,125.891263,92.871171,-14.911377,-61.865307,-83.720881,-77.259505,-81.848389,-63.561079,-13.392583,123.916836,159.880166,144.857444,121.225382,82.986257,73.511535,79.660069,115.337033,128.43986,116.553326,121.917617,178.320914,196.759394,192.764526,106.813149,65.378801,125.039605,187.784596,179.723972,87.10036,-114.842528,-147.871201,-141.951815,-185.09372,-216.414072,-278.200496,-332.59403,-483.070055,-516.949565,-389.639479,-178.215194,-110.713777,-1.22977,50.585476,38.812774,-27.446514,-96.530123,-17.535524,27.281092,117.693368,161.741085,156.982098,90.627346,-108.663704,-205.630979,-294.753665,-213.919681,-147.822856,-102.41136,-153.89486,-289.797319,-339.970822,-438.730465,-431.758219,-374.144921,-243.582831,-192.931101,-134.802306,-130.932336,-188.373055,-227.087627,-213.007618,-102.847301,-56.322996,-42.907541,-85.853775,-164.15917,-152.20902,-73.847743,-66.327465,-72.210898,2.137823,49.004719,-16.861923,-127.413659,-306.610477,-314.765415,-210.455497,-109.167233,-62.529547,-5.665974,-28.086309,-141.145191,-210.821671,-347.863934,-333.310137,-249.651403,-36.914812,58.136944,119.614657,63.59295,-123.394969,-188.402615,-144.391079,41.299126,91.287384,75.388832,51.280577,-1.881783,-40.416838,-85.863921,-27.957217,14.75317,93.458183,128.648847,141.889017,103.188454,-37.908314,-124.932851,-243.561336,-165.774781,-92.93665,-41.009228,-78.390905,-218.774996,-295.08405,-385.871107,-303.55556,-235.774012,-142.341932,-109.605113,-83.110285,-101.415294,-174.752471,-194.014643,-117.957964,27.026224,89.169768,161.422656,159.007883,85.040129,16.605106,-115.84794,-75.313698,-1.251298,141.544452,182.004546,126.515514,43.236601,-90.312132,-101.102511,-27.090788,74.482126,115.832805,161.29363,130.618286,-67.229446,-178.247208,-313.039499,-306.064465,-232.13193,5.032677,96.557859,65.600195,-28.257725,-174.595464,-193.53542,-148.366651,-57.055165,-13.65219,49.903841,68.506587,42.597678,-10.831238,-140.977036,-214.792474,-189.171208,42.558506,171.781235,219.285154,166.067364,96.96882,99.36573,146.91927,263.253507,361.80626,548.604437,583.161732,551.98012,511.511909,381.490198,306.80526,353.822511,563.715372,639.735123,561.686616,443.67754,315.354232,342.09187,417.223381,441.092436,472.062428,543.000472,545.610909,465.727241,402.661729,307.360814,339.810553,396.907607,509.830345,521.476582,436.611657,407.044171,477.254405,540.350838,634.021712,664.284685,665.89534,684.983375,704.653923,710.776316,665.065656,504.02101,457.87536,503.322649,628.7808,660.313187,562.744163,456.960865,294.248846,268.163219,361.311143,502.843865,514.324487,473.645276,441.30147,338.628893,295.097329,253.688246,225.926059,234.767286,359.477495,438.513526,432.909924,353.290494,234.814578,226.47091,244.289177,190.325374,163.513006,201.515502,226.007368,199.486767,155.369121,33.235881,-31.128019,-2.619597,149.265099,224.63926,251.699448,200.161583,62.099914,13.817513,-3.534027,33.29634,57.759207,96.898676,81.441079,-28.408561,-81.839808,-130.051246,-120.397411,-105.783941,-29.291749,33.335657,53.548511,-26.77518,-257.902271,-333.257652,-289.453785,-149.871561,-113.657263,-50.758301,-18.189639,-11.758823,-54.973635,-224.410566,-299.034299,-242.944413,-28.366213,47.579251,-12.678924,-95.720299,-207.389275,-272.578547,-435.453995,-451.572032,-392.44746,-231.003207,-182.239453,-235.083277,-316.782191,-467.480353,-430.490293,-318.862469,-120.660374,-132.019845,-295.656053,-357.564277,-406.065287,-426.845524,-464.394964,-372.846874,-271.547989,-105.867171,-97.134006,-210.735169,-292.790933,-434.783402,-415.346863,-350.162262,-256.594291,-234.742457,-242.591075,-297.346018,-464.127749,-531.48887:-105.677538,42.209137,118.575569,200.370833,219.111489,290.164791,327.057024,277.662147,174.311648,172.338258,190.294995,161.974642,51.036073,22.016421,61.425449,75.210803,14.121798,-33.978364,-22.872624,15.600681,18.59142,-6.694431,-30.108735,-109.324265,-158.785497,-141.656103,-99.284199,-118.052316,-170.179421,-151.557167,-78.1978,-70.615494,-84.609538,-80.332924,-76.573183,-28.504468,17.639472,52.447179,14.190429,-122.135828,-190.653911,-176.879896,-131.010208,-128.377136,-164.522814,-159.916906,-40.06935,12.435241,-43.740415,-183.531116,-216.137552,-211.728662,-222.203864,-269.849875,-237.578367,-51.765173,25.001829,-12.227142,-73.921101,-59.234611,-16.575267,11.487158,126.108267,156.288438,123.854413,204.466816,298.807599,467.197607,500.061864,459.506058,429.175098,414.173156,378.714754,333.626748,228.504568,181.379117,99.448929,73.649993,76.098519,74.06229,1.264987,-20.586585,40.561356,249.494915,320.385332,272.688712,186.995667,3.584055,-117.964454,-134.126455,-95.851359,-71.297198,-61.356146,-49.166495,42.416766,96.447953,194.637172,248.599773,235.825349,143.140634,76.80693,-10.055343,-20.967242,-81.382886,-160.870533,-172.992498,-154.856186,-141.781475,-169.528232,-190.89839,-170.941957,-155.781988,-156.425339,-131.247245,-108.265162,-67.029061,-41.521618,42.217352,67.247439,-5.112025,13.154402,112.926684,216.861749,165.601538,12.285545,-38.115959,-130.663273,-195.592508,-288.591741,-311.341232,-332.513016,-365.482233,-363.52433,-354.255147,-385.319889,-541.430649,-626.243727,-610.56564,-510.488804,-438.668216,-253.316996,-161.758681,-86.112012,-95.596548,-90.423336,-59.857824,-59.687397,-34.056008,-13.911333,21.505581,74.878456,236.095113,284.442988,245.784277,137.268349,99.976539,53.226088,45.527318,39.930926,-6.75009,-177.222045,-218.999451,-149.687099,51.707814,69.309887,-147.883985,-270.287589,-302.270159,-158.145625,-99.973872,-77.178335,-86.447371,-73.361895,-69.559053,-134.080376,-195.128498,-269.533227,-219.429472,-174.58828,-125.461898,-157.896733,-291.991697,-317.044155,-256.109347,-200.295716,-196.687384,-179.72045,-132.524351,-67.774702,-115.257322,-308.026237,-394.870824,-445.611743,-306.220499,-224.116054,-172.664833,-211.770126,-305.792832,-310.254839,-316.935324,-402.308025,-399.383715,-237.516907,-133.739111,-1.968919,41.836795,140.888688,175.210325,190.01544,202.925999,218.911576,232.754855,210.288724,135.910698,101.761116,50.859906,97.292356,142.809622,170.221775,158.405662,173.085107,205.027596,236.917163,198.368772,96.252584,90.274887,65.290459,-54.376345,-101.435622,-172.75693,-227.374904,-343.816391,-318.140775,-263.214033,-159.362245,-108.914407,-52.700045,-52.420685,-40.231585,-35.348656,-66.236206,-125.456642,-141.813088,-101.293843,-63.679356,10.471558,38.895856,-0.064936,-105.86755,-124.730642,-82.409728,-39.245716,-3.260047,-19.201522,-32.742528,-40.69863,-102.923294,-57.325045,36.044358,210.776982,223.603184,155.230195,140.437913,113.754219,26.116697,22.123508,132.736479,189.290211,169.922671,117.045957,89.335427,121.307319,148.903633,113.992877,131.889028,195.346612,161.600364,20.24004,11.154562,113.531126,204.706463,237.909128,241.833017,190.158507,18.306254,-37.342807,25.945249,94.293453,135.276356,153.226018,198.745051,275.95865,268.625274,138.677299,51.09115,-51.324317,-9.440477,41.313455,67.3393,36.13679,-2.666881,7.744168,19.665569,19.087111,118.379456,249.107721,249.930164,184.637903,165.063112,196.266922,218.225345,146.359853,7.963521,-20.150225,26.777584,80.411854,123.800717,92.355494,14.182206,0.682008,37.778246,101.193873,112.034463,108.996492,99.895509,53.828963,28.806639,27.113878,127.59445,179.54644,203.614766,205.784454,213.548685,189.363649,119.044628,89.276981,16.731049,-29.313183,-28.854428,-20.621182,-33.896314,-85.104036,-93.339819,-101.257701,-186.622573,-232.358443,-235.703109,-188.699819,-95.957898,-77.837918,-71.346824,-92.14925,-188.02178,-222.147563,-209.976343,-173.314828,-146.767287,-99.282931,-107.480257,-218.055816,-280.534112,-226.162727,0.444634,96.129114,113.650451,69.971099,19.725518,-7.747474,-166.076549,-292.307909,-272.309045,-147.268574,-110.935197,-142.288664,-175.742229,-191.245333,-82.263386,-16.48081,-15.601209,-80.452304,-216.970759,-244.800654,-211.16712,-195.403387,-227.581009,-223.507624,-170.216535,-5.938404,26.237587,-133.793626,-249.451382,-299.211658,-174.555025,-126.9029,-167.000126,-236.134843,-296.933327,-264.656117,-179.094903,-176.852178:-82.033333,-67.506163,-82.826054,-73.980344,-24.135417,100.539702,121.405335,38.169925,-48.839083,-52.176814,-58.793987,-77.942002,-77.51477,-38.343361,30.785472,12.04633,-87.734807,-164.584795,-162.325127,-23.50777,57.000982,102.436846,71.434088,-34.21498,-130.920051,-150.707415,-104.832663,-60.47411,43.843908,106.918035,200.291747,204.63483,158.543529,144.409805,172.584034,305.454963,368.579464,375.259165,325.486547,202.724957,74.286012,-6.539917,-84.319073,-30.842956,119.150165,138.936317,108.384021,106.425044,95.156632,-63.600478,-155.685972,-217.657543,-197.596905,-124.459497,-94.057803,-83.008565,-108.555793,-113.752709,-61.29079,-18.139388,22.484113,28.142285,46.523573,42.045175,25.529477,88.633359,144.820865,319.306312,429.662081,537.41259,500.522999,342.332846,219.251722,198.95537,222.278858,213.715166,91.880329,40.452745,69.506237,106.905956,104.876841,57.058533,73.171874,171.313004,195.739753,163.417322,138.256913,62.504625,-35.005405,-73.069209,-118.957804,-111.669919,-31.168994,35.672861,181.288655,211.786737,173.152615,170.009024,203.69511,219.857558,175.974145,65.714925,0.145431,-172.018617,-263.109307,-246.375722,-82.403245,17.378013,42.999976,-27.779273,-135.28511,-124.731063,-21.605509,-5.473865,-47.947046,-69.076855,-31.470787,42.829035,59.184787,54.291883,102.4246,149.285462,229.27264,257.851341,247.583771,200.305824,48.041416,-37.898748,-121.614894,-88.844973,-76.62546,-78.343732,-104.553879,-234.353233,-316.286239,-460.05152,-512.929856,-494.204346,-415.505289,-358.243491,-182.921388,-77.729341,61.509788,40.96263,-132.401323,-219.764598,-220.615406,-225.110038,-230.209663,-159.809849,-68.856272,97.399431,114.396504,81.849426,14.406872,-15.049718,-73.492696,-71.011038,-18.123042,-28.153146,-108.463869,-122.161863,-105.913935,-54.558236,-46.504437,-133.893963,-198.679148,-222.272604,-101.671187,-52.750356,-21.645821,-9.482366,11.55335,4.254086,-48.978384,-94.560174,-158.318164,-98.632892,-44.693392,9.360503,-10.846751,-85.749755,-107.407669,-138.912878,-205.955034,-251.729363,-297.343111,-273.278461,-221.732695,-226.177731,-295.436976,-360.490864,-425.576123,-294.965596,-213.579292,-138.605838,-161.176666,-305.541607,-392.988728,-516.647299,-506.804258,-463.539898,-403.461565,-393.125535,-372.02942,-353.752075,-258.448261,-186.611015,-81.130289,-57.456604,-62.928672,-93.473721,-114.279199,-108.041836,-69.079341,-42.531202,-134.424689,-176.887222,-165.636545,-101.604503,26.43831,48.297685,63.300592,89.013915,163.328356,152.087525,94.681045,-56.947139,-106.411462,-127.586707,-141.035117,-208.967483,-170.074149,-120.308957,-81.011317,-65.10778,8.126089,49.688865,89.287067,71.74744,48.150984,62.964998,57.399873,96.335585,142.721166,208.180462,208.556299,81.226624,-91.9578,-114.675274,-58.462638,-14.715575,15.163609,-4.575893,-18.230902,-24.418565,-121.618637,-119.452197,-18.184034,196.55103,227.08581,157.980417,117.198171,70.445026,18.566069,12.147243,66.041546,92.351725,83.233989,76.658991,106.293095,104.328177,60.087176,98.085424,154.062924,243.569316,244.100562,170.435765,134.260701,179.075456,342.346716,374.229978,314.94355,284.247851,238.900854,211.888875,211.78633,239.403026,251.706418,217.73721,233.702435,321.300183,351.294393,338.974243,306.730569,244.248981,205.651295,198.513249,214.760505,210.625912,143.492476,116.985225,151.344934,191.822625,265.180706,330.320041,349.868678,334.330239,301.534195,229.06645,203.968285,155.578394,144.598315,169.271287,243.325163,271.536635,269.92817,243.015381,152.255995,94.010979,56.872484,147.559427,177.538436,161.851416,129.545648,65.893562,50.639204,46.689847,98.440099,137.482914,178.415806,189.593498,223.339727,227.238116,196.99862,185.749465,174.972069,101.749002,43.314168,-35.015824,-46.804742,-79.35968,-103.025368,-129.509372,-160.865485,-199.161353,-217.323254,-144.507406,42.121193,69.815221,-9.371191,-65.494341,-107.475799,-110.881641,-142.7474,-166.129831,-129.421337,-77.712113,-108.476132,-245.81348,-284.269922,-230.540663,-38.139857,40.515107,32.868308,-19.149621,-107.165915,-158.187359,-267.283255,-275.44281,-230.808695,-110.981503,-77.686781,-99.166222,-123.419053,-117.542487,-54.67823,-35.672665,-34.739501,-39.851625,-52.543909,-57.201772,-48.955937,-52.951883,-101.712079,-149.426264,-144.972882,-90.037807,-90.532339,-205.650564,-282.222914,-363.917765,-275.867088,-197.283151,-137.675642,-176.190387,-267.045464,-264.454899,-179.627322,-147.955161:-140.012384,0.278821,71.807943,189.149649,213.905022,158.809775,96.67397,-0.060455,23.001156,47.618838,33.716299,9.433324,-2.633036,7.391996,-28.575273,-95.983057,-209.618794,-147.11027,-73.194446,22.490175,17.368986,-4.284554,-10.299184,-109.988727,-181.329973,-159.606939,-146.8532,-172.480803,-184.772404,-182.985705,-282.304253,-337.487464,-296.696813,-195.793275,-156.245023,-70.957998,-54.438113,-65.546771,-63.090333,-105.375692,-177.593461,-170.809178,-106.916739,-78.870226,-98.750719,-155.126765,-228.780628,-208.196287,-132.98136,-96.716473,-106.94296,-178.135251,-200.805225,-125.315042,-40.061293,73.062265,50.662665,34.47694,86.994115,140.998617,126.591976,56.389274,2.271021,17.607232,5.808787,64.898665,163.485925,332.178741,331.666042,251.659729,231.806483,204.324098,154.680878,133.422698,55.19725,5.794465,-40.235417,-40.04369,-29.072826,-27.177896,-69.286768,-120.081397,-85.410433,100.523039,182.52826,176.26205,113.275867,14.195573,-38.305906,-74.793211,-139.736555,-124.163221,12.130034,74.208849,100.380054,78.773604,29.591283,40.125766,63.774654,103.269019,109.825293,87.807216,48.325352,-113.976764,-221.521437,-222.579383,-224.626471,-230.174042,-243.798583,-253.19919,-249.603074,-251.574221,-259.283704,-168.724408,-102.032973,-3.432568,16.526349,-0.151836,-26.266557,-82.955631,-69.986712,-17.192032,111.23768,136.360136,68.255099,6.578759,-96.364169,-136.782483,-200.385962,-271.839674,-297.870174,-275.410843,-265.00293,-305.647658,-333.524654,-370.832168,-367.969402,-365.108786,-372.839528,-362.936077,-266.727651,-179.065833,-44.222473,-52.57822,-138.966739,-124.013651,-74.542157,27.889728,30.119143,-41.213707,-40.039942,83.759829,190.613851,179.423567,68.726643,22.664542,-11.463209,-22.608102,-111.335625,-185.973413,-212.650607,-69.849753,-45.457819,-72.699276,-69.188631,-89.213493,-135.282025,-226.471134,-200.079375,-158.73406,-86.739449,-17.630603,155.927323,166.856198,-7.833743,-95.565477,-82.048097,6.434355,1.763984,-42.110129,-63.68392,-128.193546,-148.342112,-119.229044,-111.917612,-137.154881,-139.574562,-98.478974,-19.688587,-14.637241,-88.129654,-148.21477,-196.350095,-128.464344,-89.123148,-31.127442,-28.348796,-113.141235,-182.676629,-265.593891,-229.880381,-196.771141,-153.821737,-138.567227,-75.316016,-35.284289,22.777352,56.646461,138.160304,144.460766,119.970998,101.523316,125.967326,195.763135,183.969398,55.773216,30.314375,84.423331,211.344663,240.239967,207.087295,168.226454,93.455627,68.246326,70.380703,84.361657,58.18193,-24.504493,-54.515533,-93.848185,-129.617971,-265.513335,-300.035038,-228.04774,-25.371352,30.3694,-2.706506,-35.514184,-12.843393,-0.188643,-60.463359,-60.635105,-16.283932,100.010914,136.968998,94.594502,27.960733,-131.618147,-195.568619,-173.164828,-68.082674,-3.773174,63.032582,64.756574,70.55994,70.881514,74.44978,161.45209,220.879936,324.49026,362.326387,380.952552,364.687414,290.540172,221.049119,238.240373,327.805536,360.339092,338.691187,279.82305,198.439643,207.72153,243.755941,255.149672,288.881579,425.199619,441.084102,317.36851,263.573047,215.493385,234.128723,283.519638,338.52163,307.931061,188.289323,159.218288,231.76144,283.739687,327.187812,349.727584,357.103975,387.550338,415.333571,377.194457,276.78958,34.166207,33.77345,124.876204,280.596301,288.272055,157.372699,86.597242,72.898424,99.67435,146.61528,231.143094,257.868468,212.565124,183.405521,202.114467,214.972275,119.720233,-31.971525,-44.630267,47.50182,93.200979,53.400311,1.519207,-3.914675,10.907542,-32.276903,-51.363906,-28.463823,18.547341,17.429476,-27.301218,-50.501274,-71.223674,-16.464527,21.125397,98.465649,148.334814,141.082991,51.90228,-144.774241,-195.041944,-179.410909,-121.660526,-127.351587,-149.276566,-145.571897,-181.047843,-229.210247,-335.031864,-368.772888,-344.750641,-240.6215,-184.459704,-153.656986,-176.227032,-209.26161,-205.930609,-168.161872,-171.876347,-193.231967,-199.284686,-193.179833,-206.238505,-241.554358,-374.896755,-371.349518,-288.931,-101.006269,-31.190346,1.57048,-30.78902,-117.028822,-155.098378,-230.964386,-354.37629,-419.425854,-401.200974,-319.07895,-233.418153,-266.522346,-322.90487,-244.82088,-200.87451,-178.736215,-207.691691,-332.130114,-367.266145,-299.391724,-271.502911,-351.293051,-388.654728,-319.623996,-146.672442,-127.584216,-234.088465,-312.874278,-413.910898,-328.536577,-240.719741,-158.287759,-167.833959,-200.268388,-240.943826,-395.294743,-456.610784:right
109.30434,64.749574,25.815362,-48.361975,-64.49922,-3.127806,47.568172,85.799282,49.955088,22.685305,-45.636215,-75.451727,-61.877488,-37.873908,-67.323109,-88.143857,-68.479652,-79.459885,-84.901716,-36.104379,-11.798435,-17.438354,-22.761233,15.949029,13.561054,-37.273341,-188.384607,-250.77448,-245.251209,-175.282562,-11.471102,68.642877,205.566641,176.525199,107.263974,23.563375,35.822647,57.179125,36.830513,21.63149,51.484188,58.31134,108.270311,153.951632,170.748633,125.018077,36.790205,33.496219,63.415761,-0.292947,-60.548986,-106.852693,-63.088151,62.484308,82.212981,87.570601,134.413804,128.626686,41.704991,-0.551588,-13.883191,-7.223818,-33.458074,-44.126062,-42.542139,-42.690853,-30.849789,-38.117938,-76.341768,-140.13131,-126.300826,-51.998621,-71.435893,-97.542644,-100.092393,-95.565667,-46.491749,25.720914,194.531906,252.462986,255.104821,155.225559,146.70946,256.236064,305.740806,240.606123,154.664032,75.058849,161.282667,185.702109,91.526396,28.545795,53.067866,129.717841,263.69719,280.383922,169.208296,30.718828,24.715052,70.213045,88.786004,96.45464,78.074626,-17.092316,-131.669004,-132.237827,-32.167818,-11.991297,-107.347312,-179.353856,-231.313019,-185.997578,-42.53545,-14.21747,-74.996413,-246.642793,-269.753152,-129.405727,-35.974096,23.30688,-59.633297,-93.538541,-116.051837,-112.044438,-57.849085,-7.812086,88.452005,118.021807,154.315436,175.171866,160.770324,84.888877,56.165273,64.949397,91.800306,145.190084,118.887135,88.665307,68.447458,75.27676,139.663264,190.293486,225.701569,182.54188,8.434506,-87.875987,-68.497717,-55.939092,-93.904908,-119.676686,-73.740916,61.889232,80.769066,36.578591,23.301673,91.966622,226.38755,232.617015,174.110695,136.049934,48.275933,104.031753,210.418072,363.206373,347.542434,261.656292,265.351048,373.34332,456.697405,460.09731,465.619737,479.93272,480.542769,462.80193,456.173052,493.461199,609.535238,584.386176,488.836161,277.498362,226.358866,218.111058,219.776909,199.576531,195.274895,190.896106,98.101821,24.031187,-40.312491,-21.366804,51.548431,89.437292,85.898813,-63.275233,-139.382811,-244.471417,-287.329604,-338.994615,-317.905686,-183.442896,-111.946373,-134.886472,-212.56745,-233.37009,-244.777744,-253.859062,-232.914883,-170.295489,-36.385004,-44.618548,-90.398109,-208.120622,-241.79094,-199.240724,-142.130098,4.57244,108.070189,103.368585,8.241458,-45.497608,-84.388004,-82.206649,-94.64171,-95.165733,-103.914909,-86.111481,-43.67667,-17.395204,-45.535729,-69.441779,-27.287121,120.179817,158.04198,122.44034,22.759361,-9.648132,15.125354,35.872169,-7.505019,-35.193268,-16.672228,21.40853,6.652885,-75.221465,-90.440188,-40.465697,-8.275638,64.322769,110.730063,92.018061,-34.264498,-136.103689,-284.547753,-267.584415,-79.092405,13.739427,-9.600137,-189.946695,-224.030114,-180.944041,-140.190187,-41.864495,6.818482,55.239606,-5.629785,-73.719913,-218.477097,-258.960097,-233.777262,-204.872616,-215.932716,-222.553624,-180.413961,-164.274864,-179.969689,-241.873021,-261.098547,-236.390876,-219.258264,-194.280397,-141.312575,-136.195844,-235.543547,-295.954742,-301.101978,-283.631148,-304.756968,-287.337766,-171.285733,-204.53581,-255.489298,-197.814172,-105.548592,-27.647979,-72.624634,-127.899468,-53.163515,-52.153866,-166.448905,-227.251586,-210.883973,-143.580317,-36.497457,-5.371359,75.711765,126.846387,102.019859,28.322432,30.847267,18.67114,-42.336659,-138.176783,-132.196753,-134.124239,-141.565921,-144.730464,-150.199361,-140.393775,-81.756741,-46.864318,-54.994646,-113.365477,-109.116035,-101.582937,-112.626225,-92.854511,-61.62575,19.84624,70.948309,52.822026,-21.131237,-59.484748,-129.890718,-125.859965,7.219395,85.380256,124.006266,50.516308,37.844124,-6.62082,-80.069491,-158.620562,-111.637358,12.56727,-9.580736,-56.28062,-124.670559,-142.422004,-112.697002,-58.878654,90.844463,180.805304,304.321709,296.817672,268.811464,177.024498,143.900712,176.325624,223.022717,290.793499,275.909174,255.149562,210.975147,173.554209,91.719448,88.665936,179.582999,217.059682,153.536481,46.116372,53.851068,143.192914,174.141113,163.608454,148.957053,203.342439,262.616441,220.7523,66.667782,16.84313,-6.50084,-18.11221,-63.075204,-59.099093,-22.157574,-59.824381,-87.393681,-86.46927,-54.647854,14.169825,27.042366,-19.785825,-100.534489,-97.230707,-15.376343,-7.942236,-82.059247,-74.120287,117.253865,211.203457:201.260745,50.19913,-39.037615,-110.034345,-95.391247,-46.801983,-29.246135,-34.786964,-47.516167,-23.126475,-17.966102,-65.080572,-98.803932,-57.004988,22.999537,30.435656,-40.27577,-137.069869,-155.11912,-140.824394,-110.689105,-21.964855,15.765504,3.007652,-83.029068,-104.015199,-164.591728,-236.213686,-325.20381,-278.51239,-62.843406,28.826909,86.670859,85.763733,76.085049,19.270177,11.249423,44.661777,55.227392,67.277073,17.57834,-21.901657,-14.596471,28.013138,79.180213,54.373168,-33.742263,-39.341052,8.443366,-59.520425,-114.573816,-92.840915,-23.892491,99.642384,146.157457,212.227407,126.034061,40.691696,-55.193757,-41.286553,21.486279,28.581873,-6.980579,-21.820604,-49.848156,-130.868048,-156.892753,-145.658531,-141.63996,-182.867725,-198.950954,-175.433607,-162.022887,-159.464303,-134.558531,-106.808838,47.885055,151.063511,250.623557,228.018001,110.937991,67.982105,89.718836,149.90393,167.671512,178.963768,183.10354,172.668805,150.429667,143.695348,80.020291,39.928117,77.023614,158.422576,335.433533,372.017881,237.350569,28.916619,1.989923,39.563962,65.378336,127.402046,150.129898,116.286314,-12.625638,-54.759072,-42.752392,-31.69759,-36.39737,-34.534149,5.75203,29.337869,23.318169,-41.360568,-107.669624,-250.358589,-251.550941,-147.969055,-127.323142,-150.890734,-120.238509,-107.160234,-186.140954,-242.955177,-209.998173,-112.392132,95.191453,162.405854,248.033107,255.440759,219.159938,136.948148,106.541311,60.169813,61.42509,132.320766,139.050108,117.32989,119.916228,130.142754,170.785647,203.057889,209.76391,184.733716,128.657833,48.935494,8.085929,-12.646044,0.123291,4.771458,19.279701,144.634859,169.32982,91.25489,-12.338986,27.990675,162.888027,187.422398,144.167965,104.098399,28.641853,72.00706,151.8521,280.708015,272.078551,178.917086,175.451136,276.848589,335.484468,333.664036,313.508229,305.657296,305.027872,306.633506,327.36546,363.276744,443.669528,385.667238,288.236009,75.616395,32.975773,91.358557,150.409321,230.682193,178.933129,129.68841,40.532634,4.461249,-1.771163,36.360753,138.667752,187.289676,215.174087,51.373946,-58.977123,-194.785309,-225.856677,-236.62282,-188.346642,-62.172545,-99.340732,-159.459237,-244.505647,-259.147305,-239.433882,-213.622802,-113.777762,-36.479379,34.622239,-77.619523,-133.588742,-200.645535,-233.896857,-271.006161,-241.91011,-111.575767,-45.083208,-39.265971,-45.939695,-75.009918,-151.37847,-182.431963,-227.708691,-226.414432,-190.749704,-133.554623,-99.992111,-112.318036,-170.027859,-218.915929,-153.127226,11.931825,-52.341685,-132.439148,-174.987882,-141.799749,-93.432514,-89.014867,-104.664146,-112.36981,-98.695677,-70.01201,-56.199732,-54.532583,-64.143901,-76.570814,-79.375165,-66.354271,-43.983544,-69.651596,-257.691799,-385.377418,-463.972238,-371.882337,-147.413866,-103.5123,-133.593716,-185.210329,-194.464125,-189.241541,-172.02438,-108.445294,-56.060602,34.420122,-99.392983,-226.186617,-349.727971,-308.792289,-127.583705,-68.6389,-93.605671,-117.680949,-105.237212,-120.824087,-172.537062,-314.345682,-342.690744,-256.062775,-174.187573,-6.112294,53.192713,4.544376,-188.949735,-267.447744,-280.921295,-236.985466,-173.753997,-165.701477,-122.106265,-68.340037,-84.112777,-146.80743,-152.079829,-120.472668,-99.052556,-63.509715,-82.172286,-105.687519,-189.899157,-242.411541,-236.561449,-171.922517,-50.846389,-18.935375,15.818291,33.030291,23.252878,-6.208704,-11.41326,-55.183633,-98.49197,-108.632497,-57.92505,-77.620653,-186.584321,-229.431362,-200.193429,-140.391132,-23.22521,18.276363,47.9973,5.661076,-32.632225,-95.703313,-98.31019,-22.49513,52.882119,210.885055,235.987788,180.430342,18.501185,-50.346975,-83.822484,-33.11593,104.151472,137.605803,100.793942,19.910993,9.266192,-14.578855,-49.372487,-70.812085,-47.490064,-6.942301,15.932038,23.795936,-23.401744,-65.990156,-75.502124,-32.128775,121.479636,214.528131,299.69028,245.615959,225.569322,186.983068,173.838404,231.345467,278.874347,307.886258,261.606178,229.792962,123.380459,84.50808,157.051552,226.923078,295.79749,297.682437,236.198681,134.102583,127.618083,193.19543,213.335433,208.702812,223.056352,283.917634,195.387635,91.606752,-18.864969,15.34604,88.945289,61.844278,-5.449707,4.013086,15.173866,-98.446585,-141.930644,-72.052293,0.457757,40.577015,-4.023492,-131.844279,-217.411213,-207.747924,-59.502804,16.238428,28.698891,6.60019,45.420292,85.619045:14.521665,-88.523783,-152.923954,-195.081773,-163.70872,-87.913957,-61.687111,-66.691922,-113.265094,-85.789976,6.635638,4.861144,-64.002143,-89.206589,-90.128331,-74.283504,-71.987139,-176.504783,-246.187428,-238.229664,-156.508939,-57.114817,-62.140995,-66.643881,-41.992786,-51.034601,-154.096673,-214.331766,-208.339112,-142.877627,-13.237921,11.19218,-7.741575,18.451,40.067868,69.071026,111.366743,220.649057,243.023229,197.548813,52.186888,-17.93724,-66.426938,-59.85295,-61.586679,-81.910602,-100.272763,-75.212417,-26.419047,-87.689748,-148.150142,-182.977299,-115.950697,40.788894,66.786374,90.39367,98.716582,35.214575,-146.723796,-166.091084,-41.727628,21.074894,42.059243,9.051298,-76.252457,-67.41753,-53.751828,-97.997528,-137.135479,-204.571629,-228.756447,-262.912598,-267.757993,-242.695398,-199.017574,-184.9277,-52.945496,46.924965,146.166127,147.481774,118.528674,44.235308,5.912969,-17.907116,10.486888,102.058314,131.621472,152.52626,111.276577,52.931556,-57.240082,-49.404168,107.916889,199.135499,297.584467,305.856986,244.080662,111.877207,54.234046,-0.928191,5.375697,43.986932,69.370836,109.846325,56.910024,29.104539,-18.608933,-74.3781,-178.153758,-173.551893,-64.109604,-15.01475,4.053944,-2.45877,-45.063899,-198.015208,-220.331863,-126.083163,-90.378026,-120.967709,-181.163661,-212.313975,-290.983131,-290.644765,-106.744831,11.367227,118.956457,121.476813,112.300916,152.829379,173.471044,139.412285,105.254088,94.146531,120.774854,148.168606,69.076955,33.973205,64.120996,106.884404,149.677473,123.84018,64.768917,95.788207,182.532635,66.980845,-25.127453,-124.612766,-122.610347,-29.649111,48.218723,161.390289,131.467126,90.460075,53.301627,82.453132,164.842845,167.375902,152.136483,151.07584,61.405287,-15.256565,7.821761,93.630858,121.223855,117.028355,101.82695,123.244094,214.606335,238.463093,178.576666,150.546003,200.639902,235.956331,249.482832,256.477124,270.078318,119.963063,-9.300828,-187.638315,-177.051746,-27.249145,41.122998,89.048252,-1.228165,-69.206568,-106.528398,-68.815275,33.812208,86.12915,195.50521,245.859597,265.869656,129.728384,46.292938,-66.18645,-96.036789,-90.78389,-48.189323,50.166983,50.894258,2.086187,-136.128725,-176.982118,-148.602638,-112.725551,-33.91587,5.905652,-23.492048,-181.201342,-228.81188,-236.964602,-253.179676,-323.36517,-318.606299,-206.49397,-176.420453,-199.554582,-228.485359,-248.596296,-257.158078,-230.108393,-200.397325,-208.814722,-240.873921,-218.952303,-188.162554,-219.015227,-280.990935,-302.078315,-212.38902,-1.383001,-26.058476,-107.715286,-244.835988,-262.833497,-204.016221,-172.71271,-171.208888,-169.44337,-149.840353,-156.867676,-142.723668,-65.680395,-36.830687,-23.28024,-8.363573,47.54859,-2.379663,-87.400849,-295.542621,-372.925645,-390.885859,-335.389415,-196.301837,-155.436214,-161.881148,-186.301855,-163.020209,-75.569879,-26.841036,51.107488,69.104883,43.058242,-135.696364,-231.311364,-239.502909,-163.00095,-37.81441,-46.406014,-129.422931,-135.825379,-121.273996,-191.838908,-234.14111,-254.79794,-227.603397,-132.171014,-63.430891,101.867311,130.36296,53.563389,-154.012893,-190.727629,-97.860925,-52.413289,-41.620465,-49.502666,-83.670163,-105.896213,-111.799244,-120.014957,-106.001919,-64.643236,-45.790887,-23.011772,-24.571855,-18.464059,-39.376957,-79.428384,-131.779365,-120.414754,-71.419366,-51.208973,16.278813,125.283568,127.297263,13.725535,-24.257864,38.792393,96.725035,108.002794,-5.40025,-30.488309,22.540676,38.30177,-26.390302,-56.017184,21.917695,91.571221,115.468364,68.56749,56.854799,45.567841,75.213936,221.333915,297.35295,376.967475,343.551332,292.24967,135.297989,48.564895,-24.412888,22.097283,211.505991,275.126354,225.866449,121.071303,131.954681,178.600746,157.28778,113.265516,129.487979,156.182234,83.916771,53.908024,62.436325,81.349839,89.291293,81.776034,173.461036,283.209767,409.371125,312.159618,242.125902,122.044499,106.023938,243.346265,339.854853,403.251023,338.771787,315.021511,258.18527,213.691371,180.881933,209.944387,292.930015,302.160944,207.98357,85.205027,60.867599,77.288472,97.984711,176.472892,240.813712,304.602723,163.317019,80.026218,39.930405,69.645667,116.428021,100.092251,23.087435,9.703152,30.147632,-38.06329,-84.998644,-56.424866,14.616719,118.389757,107.389009,-23.697027,-177.657832,-209.89688,-155.339401,-120.514349,-162.968298,-197.059933,-96.801746,10.363375:195.652441,196.864336,165.240407,66.451851,49.857102,119.173659,140.454475,75.150416,22.098208,23.55171,-19.842436,-86.404307,-224.207514,-234.981203,-108.050947,-26.24858,-0.265299,-139.780247,-206.950545,-192.50862,-102.86004,1.727634,-25.792785,-75.370603,-128.56812,-178.041397,-226.689579,-214.618563,-135.649824,-77.149404,54.00707,136.503444,312.678031,388.559558,365.195184,277.812606,264.353369,287.427156,287.696905,260.829555,180.828133,132.135201,84.450619,68.068367,4.16706,-25.03151,-9.577332,29.111686,54.417217,-48.640928,-122.245761,-237.7535,-236.880234,-115.101765,-44.837293,54.941666,73.788954,45.031881,-9.950958,-6.843155,47.222278,64.298793,45.780832,45.558761,69.317805,60.097789,55.685859,-14.113403,-90.271529,-157.657693,-108.035423,-23.68066,-103.563949,-135.22258,-146.43065,-153.200986,-83.061429,16.866323,230.90692,283.401065,205.118014,42.568538,16.100084,97.902966,164.05076,187.268964,152.883612,163.089799,229.920437,224.926554,137.226851,89.161388,113.191052,180.807591,283.715597,298.487079,271.022227,217.008731,196.838835,97.108064,23.886867,-36.592078,3.899663,126.83805,102.949509,39.740073,-95.891858,-153.544777,-185.478339,-159.035771,-92.38362,-64.380702,-55.629437,-139.392543,-216.48704,-344.053936,-330.928915,-178.693743,-108.76608,-95.597263,-203.63705,-242.963995,-237.48299,-206.907664,-105.446883,-34.339721,110.753501,167.403661,212.670739,157.477645,120.83751,48.415687,15.384381,22.562938,60.073718,102.263549,56.121619,48.566428,90.935075,104.317002,124.46824,150.562161,197.981044,212.182026,196.574706,104.238566,52.306403,-62.342543,-100.831732,-76.894225,-21.59807,143.734484,209.191855,167.612457,97.545138,112.987082,176.07604,193.336212,209.993435,204.665551,141.29094,127.241025,155.361383,173.931034,154.280674,161.189282,210.892564,314.457302,378.607823,406.811135,367.411918,303.386583,255.462325,298.220568,407.656693,438.394757,436.990774,354.117842,274.029949,75.358261,12.047572,3.911119,31.615614,74.299699,29.641631,-25.841696,-142.458835,-163.802151,-80.924728,-20.012102,52.254675,82.582003,93.477653,-39.2776,-111.523008,-190.858563,-209.522817,-235.641656,-228.646052,-157.528003,-98.131421,-90.073798,-102.927706,-134.662313,-244.038491,-283.879053,-226.364601,-147.572198,-67.6308,-121.857979,-167.515535,-267.780316,-292.704942,-273.860792,-240.616648,-117.054618,-75.453236,-129.849287,-271.995422,-330.211966,-366.978574,-335.734161,-238.470392,-192.14723,-175.855359,-202.409653,-179.485971,-170.805972,-214.454432,-239.30879,-165.160986,8.603508,0.428052,-45.008007,-138.009829,-174.903599,-203.605915,-204.778386,-163.528956,-101.202737,-6.533638,-47.962832,-72.149461,-74.912457,-69.49857,-39.780117,16.740755,156.55063,103.052385,12.780173,-176.62992,-263.103021,-337.616233,-301.459154,-171.290156,-124.98565,-143.076469,-200.400365,-180.994167,-139.787905,-130.367587,-55.171039,-11.175446,21.723752,-49.612404,-135.215277,-299.638716,-325.452726,-277.26002,-254.727138,-249.127522,-228.056758,-192.569665,-268.888564,-314.443918,-383.30216,-390.453913,-296.294453,-217.634676,-83.502014,-88.509073,-146.071599,-256.283391,-287.193909,-289.406293,-251.897136,-127.352063,-75.728717,-82.338531,-195.218309,-224.732968,-152.626194,-92.525764,-58.127462,-64.495636,-18.603827,1.928866,-20.94184,-65.997054,-84.800221,-110.328546,-110.844389,-111.196523,-95.7441,49.768233,202.365962,171.313878,-20.546593,-54.430174,33.281093,67.401954,69.505093,52.843365,29.276813,-39.586111,-77.208251,-109.999003,-70.324674,73.959369,103.133554,6.162508,-90.005342,-88.11794,-39.31753,-3.29702,111.074533,167.460716,202.822107,144.673389,104.16819,50.826762,21.780358,-31.145502,-4.944918,123.65668,169.14348,180.600081,127.870471,108.882455,101.891831,89.739035,39.876206,31.427004,86.99286,128.973036,97.951409,-29.742548,-72.416831,-35.126244,8.674704,104.788123,179.886817,280.519087,252.415932,233.559926,186.537664,183.387605,266.327176,316.099539,357.331471,288.883733,240.793582,186.794537,178.734257,209.304809,240.048999,269.650883,265.53668,244.709905,192.321345,155.611707,101.69142,112.445189,192.120899,221.566915,252.472774,213.101023,151.472392,81.054147,95.74424,111.352656,88.80784,50.667521,53.456883,44.269605,-59.482443,-97.825291,-42.756077,16.109493,53.234254,27.619159,-50.961422,-151.036606,-184.336491,-170.167847,-149.975161,-126.592305,-87.363962,97.560407,192.994716:125.077312,4.943108,-43.50596,-19.419412,34.780086,91.155091,83.938281,43.502798,-25.169706,-53.86414,-125.420173,-176.945298,-220.069619,-186.091034,-94.437016,-84.43478,-133.37843,-189.48548,-232.245548,-291.194327,-253.261505,-124.355083,-94.59925,-100.969711,-151.555492,-182.311047,-208.017109,-199.594558,-134.182705,-77.430724,42.583783,89.616146,142.294545,173.738094,190.659735,224.384809,248.786382,305.315177,329.016299,334.341743,213.777456,141.47664,13.206014,-41.733863,-29.275161,16.421285,38.367599,37.923772,74.376494,22.160516,-69.066604,-234.805218,-232.045256,-116.812029,-77.744978,-30.247458,11.449921,-5.697997,-101.278073,-126.608709,-36.10427,44.240146,142.119687,147.679503,81.958354,3.441532,-10.16639,-36.408911,-77.819464,-159.883404,-148.621197,-93.025054,-172.853801,-216.507109,-206.807838,-174.336202,-60.043464,25.090874,136.56983,127.243029,33.476925,-27.733128,-49.945174,-109.489682,-97.665716,60.754846,157.92158,265.355015,214.219287,158.61181,48.855466,20.163654,112.395005,228.109747,444.57956,481.045236,380.822801,246.41588,207.369885,99.066526,52.460793,89.085291,138.141486,163.203456,65.064608,-19.58395,-215.998246,-286.118288,-254.812851,-174.704304,-71.136151,-72.270212,-134.092952,-281.993114,-379.240719,-437.949272,-355.189688,-151.87575,-108.482979,-115.312632,-130.562068,-131.139475,-180.919561,-220.501109,-179.256784,-89.841405,99.993548,159.359641,176.651383,122.146351,88.895448,31.171472,19.731743,45.830311,89.116036,147.640184,3.923606,-82.084041,-104.91656,-56.640837,57.246536,84.665103,97.213583,128.826113,150.114366,8.096549,-56.716507,-106.997182,-84.969821,56.531598,138.578569,220.62104,190.789664,182.132242,208.621542,222.131112,198.139806,154.685978,133.478549,183.26205,258.888377,239.874526,205.150573,110.479406,91.824257,158.622041,213.165213,282.252707,292.310314,292.278202,233.855312,183.680871,149.393761,167.684939,236.948316,270.008904,261.919959,164.107973,79.049828,-150.113573,-221.511002,-147.945131,-50.769396,68.221128,-7.407087,-76.125575,-151.309977,-128.389612,19.892569,84.157058,159.072865,209.913132,265.057243,85.98595,-60.452115,-250.501212,-239.74954,-93.97062,-21.471201,68.096651,32.036837,-40.197835,-161.342251,-170.042357,-163.034968,-168.481016,-132.067952,-102.819912,-119.72267,-200.244215,-246.669312,-366.472425,-405.099384,-333.825835,-243.04642,-92.825606,-115.601163,-175.780028,-312.754139,-374.681936,-382.796285,-310.494249,-140.997893,-90.154305,-79.554979,-133.355443,-156.602273,-215.050179,-248.556166,-206.998737,-98.891129,123.400717,62.525723,-51.537629,-244.763673,-264.245044,-143.49435,-87.369446,-84.906452,-77.621189,-6.734201,2.347632,-10.522388,39.024162,91.140973,144.435175,166.90806,240.414817,152.232077,38.988697,-199.57938,-293.698916,-371.017078,-349.864645,-217.19887,-142.102199,-97.031628,-109.043714,-85.535156,-47.723472,-28.986511,82.224667,153.372935,195.125004,22.900807,-76.937998,-163.454047,-158.194619,-124.236358,-113.779178,-69.02556,-34.859907,-74.908777,-225.403467,-288.575465,-378.323616,-364.271356,-180.056541,-71.152749,51.0901,40.536815,10.52267,-85.255455,-137.554579,-154.066858,-113.486577,-5.286142,38.113296,-7.036961,-188.384921,-232.084935,-144.222598,-71.860909,0.704977,32.829596,123.937665,113.508377,73.068851,4.321225,-15.697277,-40.881374,-44.846388,-18.093038,-4.083011,38.410476,147.317382,150.102631,44.585611,17.807902,71.997616,123.658256,169.764568,84.382324,36.899553,-14.577004,-35.119785,-54.358496,-18.789873,162.78776,227.279768,123.947949,-18.544699,-14.359505,52.990568,93.286785,229.8404,308.810421,360.346757,263.533463,209.769798,109.941608,45.666222,-19.119159,29.886685,198.28931,244.452006,210.488294,120.208076,106.668952,177.587852,247.586169,346.245383,345.806592,309.113055,252.58424,185.090723,33.655323,13.534595,100.790108,143.910874,182.252875,229.2448,352.899749,341.16667,271.212514,116.0009,102.198988,222.728716,311.526661,421.219625,301.959995,212.631622,154.78964,177.87956,226.605808,228.5558,205.247992,191.109442,155.61691,117.32753,106.132557,129.322128,174.110951,273.039022,310.789916,331.280642,196.426604,110.299718,43.726885,69.241296,155.267705,167.446534,125.858519,107.939887,66.480965,-22.329941,-50.338665,-25.048297,11.2945,53.425162,53.536525,3.880346,-178.878072,-278.496872,-308.820871,-253.469868,-201.373278,-204.024973,-68.586078,56.946748:211.538165,184.857103,152.61195,132.681808,132.715749,136.571929,155.158393,212.240367,208.43367,173.680988,43.67798,-36.454748,-132.428326,-136.44208,-92.127314,-59.956857,-37.529618,-95.315003,-130.044422,-100.030408,-22.486906,89.891772,65.881659,-53.797539,-100.640635,-93.335779,-75.897334,-92.365431,-74.542167,18.783088,266.164502,345.925668,345.154148,209.232842,150.22306,117.662878,141.353763,212.781798,223.559439,171.732993,111.565336,100.101987,145.115721,189.006116,218.644534,192.318154,117.437902,101.213909,95.246194,32.255469,-15.963493,-96.547303,-107.410009,-105.604771,-121.070773,-84.293027,79.970001,117.445597,23.236261,-46.218791,-50.196046,11.002054,108.663109,131.999821,146.391804,96.608945,79.790134,79.839542,60.875587,-19.027728,-40.999372,-38.279444,-92.817786,-149.134382,-202.679876,-181.117296,-59.860023,24.269835,184.104567,249.172442,271.925468,116.489052,47.721218,60.217495,123.517746,193.21013,160.658082,80.756973,108.050042,114.481069,44.047832,18.51392,135.264326,247.424123,357.250148,336.079733,266.026481,217.027316,180.812806,81.736918,49.561369,15.70247,-13.724717,-78.017079,-109.309622,-127.034218,-164.123221,-167.619451,-147.841152,-154.913513,-185.066868,-166.403367,-124.576984,-215.15061,-296.199031,-390.248308,-333.094408,-73.249587,14.115519,-1.569776,-101.885672,-124.524179,-82.017484,-12.333934,148.797126,174.2349,101.417853,61.218858,54.978435,85.327342,75.906229,53.520694,82.383649,148.85574,145.684535,109.873154,36.692498,-7.188899,-37.206901,-12.306367,129.455595,195.873525,179.272596,132.589629,89.462688,94.007922,66.222263,-105.254524,-175.664216,-75.286945,61.06387,253.650562,181.421069,122.970823,170.654568,244.294031,305.940747,278.564035,188.480758,159.913059,131.476821,123.133123,143.236712,206.381662,215.410932,183.345294,181.368227,256.313716,336.501359,346.925007,344.124487,338.951754,326.034033,337.743824,423.999111,474.718296,465.539827,318.881272,258.637567,194.171665,176.196239,158.094558,146.829044,97.810143,24.869028,-12.931568,-85.336161,-121.663848,-128.242787,-86.89396,13.275086,50.002638,31.959563,-125.575668,-185.141167,-205.409287,-196.677858,-173.402878,-163.959825,-165.328705,-177.5765,-172.285904,-162.609751,-190.736683,-288.628302,-324.400554,-305.605951,-227.333375,-58.535831,-113.954541,-183.397051,-233.778646,-216.9469,-171.780452,-137.54122,-10.953024,51.175796,10.963155,-140.474737,-210.727826,-241.439218,-198.483729,-113.948098,-92.038266,-73.051778,-48.077457,-30.182778,-54.768843,-92.143207,-128.114519,-103.606844,31.183541,150.779008,158.548005,146.803793,155.542899,150.069657,115.376958,34.958323,35.667931,94.498935,80.214112,61.84209,76.208186,104.444205,145.041265,151.832667,211.818744,255.724727,201.793774,-18.520034,-139.583795,-302.544563,-300.999922,-120.459239,-5.123722,33.677629,-152.02426,-214.717158,-222.449342,-175.046221,-9.318393,50.31582,33.195973,-61.000179,-106.08674,-199.657168,-246.9904,-288.532972,-289.827922,-327.105237,-361.113018,-440.961786,-433.775675,-380.966518,-349.019452,-390.865186,-427.400594,-386.829311,-276.072958,-258.356206,-273.714467,-299.169916,-328.518499,-410.797075,-428.718532,-366.204754,-296.640205,-216.219264,-272.448918,-294.857825,-235.406638,-158.297198,-16.506195,5.407745,-6.109924,-27.710906,-57.425985,-108.811574,-131.767241,-177.225501,-167.203136,-65.405087,13.624366,142.597485,106.817818,41.77168,-51.28359,-36.348507,48.023694,56.776825,42.026246,32.258474,-3.701142,-47.148125,-22.302909,63.960083,95.338092,112.617857,112.880776,100.239598,56.539394,33.363341,-18.196292,-39.164998,-28.224931,13.541023,148.820403,158.223736,97.011761,11.4483,6.906137,-3.817687,-7.286533,23.636578,47.276241,60.145269,38.331781,44.784068,31.983817,-2.885428,-56.561396,-75.734184,-99.012818,-49.635868,-23.042017,-16.677645,-45.612762,-119.72385,-126.605981,-41.519735,48.861778,230.211233,284.601218,251.920653,122.482698,105.550452,230.636523,288.067686,278.763657,214.536826,193.435305,130.805214,74.509105,31.245346,73.62826,145.463177,146.332548,154.417199,162.189902,152.847398,115.374628,96.683686,128.29417,187.71212,306.46236,260.351719,203.243774,156.860764,133.694577,46.099991,25.476964,-2.356934,-51.547497,-162.086674,-129.257554,-72.109039,-37.057408,-51.782376,-25.290237,5.068419,5.043699,-61.138356,-90.658527,-154.126279,-207.807213,-231.19236,-142.918354,110.278189,194.80155:238.79121,170.498851,137.341632,115.400326,112.440385,118.701127,130.339062,149.422936,110.887552,69.270227,-39.59521,-93.346893,-158.530757,-165.413734,-92.004341,-21.957712,21.184942,-111.210314,-188.04296,-225.552693,-155.006393,23.475423,43.629116,-48.970655,-131.379992,-140.306329,-144.432536,-152.201206,-98.158331,-18.455174,177.493534,266.072627,355.330078,308.64013,270.919851,252.423471,276.336814,332.459457,339.778329,286.364186,172.127111,132.690816,99.950354,74.055369,36.14973,48.490694,106.959256,147.268001,188.365921,66.028404,-45.008422,-194.949346,-184.780785,-122.736947,-126.928051,-99.038066,34.144344,65.24465,-6.503005,-61.085422,-33.581624,56.465295,229.810916,265.803434,184.362822,20.751719,-2.102159,15.867577,6.278842,-39.441185,-44.23298,-44.104087,-146.042189,-193.536819,-187.642792,-160.390969,-87.864744,-33.917533,97.693271,151.377826,152.619208,49.138952,4.737636,-53.633849,-59.964249,12.203712,91.408747,247.734476,250.653751,204.790612,83.975011,37.768457,108.229063,232.818742,495.799274,554.743936,448.352233,244.18448,182.601111,82.487356,37.216281,18.909941,51.993548,133.897766,72.222398,-7.484718,-134.741014,-166.657193,-161.38016,-125.613672,-48.54555,-41.413187,-115.163111,-253.243157,-331.312903,-439.168451,-414.011482,-179.040103,-57.235737,-3.51468,-107.725815,-145.310259,-158.868837,-138.464383,-40.114499,16.101603,74.706745,81.87435,60.291354,-5.080613,-26.296665,-18.896266,12.892677,95.771154,111.960954,88.541369,23.635999,-26.319606,-91.347885,-80.999574,24.044636,85.866978,125.659373,123.623365,130.059983,85.461878,45.953452,-69.492091,-124.094898,-76.67982,31.578894,231.300547,230.07125,195.027854,174.675311,169.288877,151.423068,173.416571,276.683804,305.951745,260.92404,198.508904,178.463807,111.648481,79.875381,78.097855,110.874755,227.799423,361.733852,398.106702,356.787206,311.494541,271.155563,272.628013,316.80866,371.704608,437.989531,308.718476,199.947129,14.973681,-11.387383,82.078813,136.446243,155.551161,34.16591,-63.966627,-186.090776,-183.774561,-100.457737,-50.8781,32.228758,74.098491,75.326372,-95.713117,-185.86838,-253.996434,-225.782287,-164.688838,-164.116837,-166.596711,-182.412371,-216.689768,-291.38052,-300.75708,-259.762082,-240.283075,-227.348361,-214.397275,-176.2937,-186.152673,-236.762793,-367.406927,-377.390733,-261.349319,-178.284854,-11.530755,25.741786,-45.263444,-269.614956,-370.223086,-412.175935,-320.014783,-55.54928,12.016465,-42.7024,-108.661566,-123.680456,-215.472437,-259.914081,-195.483079,-85.668486,104.901236,95.480599,50.061194,-34.03841,-71.452038,-109.568784,-86.272472,26.534468,83.474409,142.666038,132.579144,117.535466,83.38157,69.604692,87.052405,133.007298,261.804145,277.807255,211.195877,-46.287853,-190.154202,-305.400569,-257.873675,-103.010579,-46.375855,-13.653741,-53.090794,-79.522002,-125.481124,-114.911154,16.434377,118.652718,265.508074,144.806774,10.009342,-201.849724,-241.187906,-216.734031,-188.67874,-143.172976,-115.340934,-131.45469,-310.542891,-397.538444,-450.156648,-398.480222,-203.40284,-113.955476,-20.070175,-84.862306,-156.831075,-300.8614,-341.685748,-281.728508,-203.071357,-74.402851,-36.277231,-80.895747,-309.338478,-376.905422,-284.076856,-169.39357,70.937502,151.113964,159.611199,53.469017,3.876808,-77.130506,-109.46981,-105.521302,-68.179644,-6.429785,-3.077074,-2.337691,19.651789,-2.037071,-72.730119,-55.890735,56.631061,87.933121,98.570954,75.67494,26.202561,-73.759189,-76.102887,42.346271,138.753602,256.182455,231.528151,74.185591,-52.395742,-66.614798,-8.305537,29.902684,96.559237,149.464468,269.187845,236.806254,157.040981,-27.767635,-81.034735,10.380035,112.670945,203.081614,192.92066,148.215282,92.607705,98.842625,180.412494,212.291058,222.406675,226.486315,243.059923,175.9204,115.662762,6.457393,-32.890007,-45.142957,-27.517555,27.966375,87.118632,198.842074,142.33706,78.753676,25.652946,73.005444,261.561014,331.08803,338.603951,219.283091,156.142283,51.290307,6.741362,13.229294,69.828512,196.586432,227.562113,148.262185,-21.081794,-46.361972,31.716724,76.137225,129.408381,180.289325,346.418251,333.323214,225.621262,43.914203,28.718565,90.755154,129.862924,157.163021,132.498784,17.40922,-99.381418,-112.482702,-47.862242,-6.740125,22.785234,16.367494,-4.381332,-102.714827,-178.773011,-260.979566,-250.161294,-171.696718,-110.698175,63.684549,147.655721:66.915634,147.337646,126.808441,9.631906,-39.560693,-28.625812,10.434208,59.669081,53.351262,35.129967,12.066414,14.060535,-10.309078,-31.430476,-11.70876,26.845556,76.041177,40.022981,9.088493,-35.292753,-29.446648,32.633534,58.768698,79.778781,80.109879,62.084984,-1.728441,-29.983064,14.727906,115.294484,339.651163,377.700599,261.816294,92.929955,56.236989,76.796154,110.364189,131.524745,82.696765,-79.997892,-108.959304,-38.984539,135.559168,187.276948,234.311505,231.553538,117.549619,29.409701,-66.30982,-60.173541,-69.94033,-93.382624,-69.983758,6.361687,8.603279,-54.680545,-81.389889,-81.542614,-98.008002,-119.797712,-137.395734,-109.520042,8.686907,92.492415,176.564829,41.401416,-16.366374,-3.728872,-10.632865,-169.888248,-238.390271,-195.125573,-143.382721,-170.44053,-210.437778,-191.147751,-103.757314,-73.393108,-111.518364,-146.187785,-144.080658,-130.473117,-149.362359,-182.42759,-164.475103,-93.456082,-82.865065,-84.639703,-23.638392,-3.894614,-27.763183,-40.285197,-15.034212,18.080038,93.633863,109.232803,79.268429,66.919416,55.161178,-46.365561,-99.813229,-120.498634,-112.418843,-152.255711,-268.573547,-305.264776,-234.787413,-171.389964,-133.457363,-150.489011,-181.123236,-162.823301,-56.413274,-59.796452,-126.8522,-204.485964,-161.952643,-23.880147,16.848021,54.731862,31.040237,17.094507,84.587579,141.452701,176.24002,124.349346,-71.281607,-147.989495,-153.742745,-30.337229,48.037302,144.631606,134.071653,66.546586,51.124687,80.473678,119.344789,117.360487,102.759613,101.490392,130.468614,164.371931,215.874024,209.345916,150.451787,138.157581,138.65291,57.614067,16.943814,69.15295,145.514785,291.727481,241.473073,152.356388,107.785441,162.349097,187.494043,133.905224,13.1899,-17.15784,3.7012,27.826916,34.788818,97.601157,137.351886,177.495979,173.56884,141.979933,155.294566,180.787396,225.078338,236.270297,251.620563,245.553652,178.534776,158.981472,211.201236,296.316515,316.588204,236.580655,164.213502,110.618021,122.500321,132.242327,79.001013,30.309623,-71.296593,-117.662016,-142.65265,-102.90644,20.146724,71.519788,114.317704,71.042263,55.353728,70.716276,76.877903,72.292315,68.241429,24.413694,-38.261671,-16.21275,114.509981,131.650992,-21.33595,-130.741184,-228.390139,-185.058251,2.022336,70.180526,15.48076,-99.717207,-94.18432,-23.60867,2.82965,66.712917,84.345539,31.750974,-66.765908,-59.139417,-7.722715,-5.413581,-6.267797,25.14007,117.553433,160.752361,157.721108,96.120356,69.806006,96.368438,139.519181,239.224814,245.061313,208.553326,186.93772,220.718211,282.355235,269.406346,165.949835,111.383914,72.662133,131.46033,166.000879,192.795628,186.635974,161.406123,157.068053,170.691963,172.071615,165.971485,134.580234,82.661867,-68.022718,-106.441921,-54.709808,-7.414907,-6.611548,-115.534596,-142.846637,-114.397233,-87.288707,-24.938225,9.724891,51.663817,14.429233,-32.506388,-139.292509,-190.027652,-277.748788,-303.918848,-331.326177,-364.704465,-451.125303,-383.96489,-309.096377,-314.50206,-401.397033,-462.34112,-397.57505,-294.01844,-286.744577,-252.879832,-199.868347,-233.363414,-302.575488,-284.09164,-218.952576,-196.821024,-158.38638,-172.082034,-164.916672,-47.197567,33.993959,142.463283,150.664637,128.363036,117.446048,108.987545,74.933295,41.535014,-4.464873,21.38854,142.810804,182.601581,148.551723,118.778869,138.231705,170.773789,180.575957,163.38384,128.353465,70.058229,50.003151,63.871058,163.517327,228.812223,345.179281,369.046624,289.10819,220.036819,134.531948,117.163231,110.922561,88.165898,82.026654,71.711237,66.918429,110.780761,146.663021,121.737415,87.466959,94.660432,98.531069,80.464836,3.599749,-29.356242,-75.304471,-93.22225,-55.166507,-0.088684,-28.39592,-129.274039,-158.63379,-79.332999,76.80304,91.827951,-14.598635,-106.546727,-295.5054,-356.176885,-339.963464,-245.464393,41.921252,190.215195,156.291839,-4.658611,-50.667324,-48.354923,-35.885589,18.562809,55.335445,12.852371,-140.189206,-207.719526,-269.208836,-248.060361,-138.150001,-93.77317,-114.558893,-206.934614,-202.807749,-72.877914,-15.028777,-33.695115,-71.382455,-85.306643,-104.507644,-132.806215,-135.578123,-111.401927,-98.999984,-115.450827,-166.811545,-203.139166,-286.867312,-328.390951,-325.172952,-324.324744,-307.424023,-188.027743,-140.094309,-122.275679,-126.544257,-136.713695,-172.673509,-186.076803,-176.978088,-160.123877,-101.130973,-48.708335:69.283736,88.357515,67.707179,-39.232822,-80.623794,-15.190993,51.054749,102.074985,64.86416,32.234205,-6.412306,-1.635201,15.92444,8.1499,-56.459974,-90.383624,-115.743421,-87.805263,-70.592469,-101.603803,-137.413693,-168.798006,-157.177808,-99.725682,-98.585231,-145.996232,-248.45374,-254.703639,-161.241939,-85.676322,75.255846,138.737561,146.809289,17.825719,-30.121153,-20.73821,11.284429,-2.264786,-61.820126,-130.819104,-73.950141,-34.691339,63.219393,131.026245,242.525032,235.645251,112.434725,68.932954,81.965268,69.833,32.372129,-32.595911,-37.502921,-6.597847,2.098361,-16.927675,-22.550396,6.952396,92.921727,95.816553,1.296983,-47.57839,-66.352998,-47.274707,-19.141155,8.155288,24.54654,23.748438,8.866466,-34.729123,-62.306371,-97.218298,-87.300841,-76.835808,-65.955744,-79.031194,-117.440337,-95.335816,38.809334,85.296196,40.90773,-28.66138,-15.40958,29.024054,24.012424,-13.712205,-31.645015,-50.022179,-20.285649,-2.193747,-4.01786,-1.983222,62.092507,103.936391,147.567243,139.748908,62.726869,-16.019695,-26.574711,-22.145496,-24.730138,-61.73854,-97.960921,-170.464598,-207.487477,-194.428403,-122.957015,-122.947757,-195.151782,-206.04622,-148.311112,-103.199493,-36.682139,-91.338337,-152.555748,-178.680162,-109.977845,62.01311,93.640561,61.586502,30.16863,18.882593,-21.556697,-30.068062,72.043484,140.954214,99.36491,13.999934,-61.454483,8.346646,31.893265,0.662837,-14.462953,33.051261,60.63209,45.158298,35.906261,69.760475,115.556108,72.633672,19.212837,109.170788,299.314744,246.46246,-24.542544,-39.849731,25.313474,-1.163697,-83.58911,-106.404287,-19.308511,145.985704,104.037087,54.827039,80.103142,130.278283,154.07749,125.459939,48.690446,23.451825,-5.455278,-31.814634,8.972338,208.315991,288.839862,288.906187,257.858849,285.157618,323.009185,322.407288,351.629818,364.904289,353.179344,343.977609,324.477402,318.321032,386.17415,491.189491,468.719932,296.77389,227.653912,179.032789,166.481941,180.055988,197.186287,158.646666,50.333199,9.989892,-8.972128,21.97055,126.798667,173.113354,183.422891,68.290394,12.882729,-23.140635,-20.338917,-41.88527,-85.904965,-157.188596,-104.989386,-70.133599,-33.214614,-25.763836,-27.602503,-55.217779,-129.776723,-113.086019,1.033211,-1.75526,-42.464092,-84.583366,-80.429036,-68.118974,-45.028005,76.357786,128.259848,89.597475,30.284772,47.657703,75.307991,29.550548,-70.913668,-37.776961,74.761747,40.31746,26.767906,48.072084,48.805993,57.49065,105.961806,264.342297,337.985077,335.74727,296.345465,264.599436,237.968611,236.107215,159.460112,103.081374,86.424801,150.225435,154.647838,115.118526,104.898191,131.162962,153.525618,201.097046,239.714625,247.974451,223.234253,156.784156,-27.502082,-57.730549,55.468967,126.330376,125.860642,41.546408,40.057558,58.128949,71.830886,176.154805,223.71796,167.936084,40.056679,2.030067,-58.276295,-86.780316,-116.24281,-125.223078,-168.207343,-188.373556,-209.811334,-179.852146,-140.625607,-144.73623,-199.966157,-252.814404,-212.472644,-98.080084,-96.455533,-127.902791,-183.182833,-204.305689,-243.684695,-271.80591,-310.299152,-265.426956,-69.507069,-19.208223,-52.974895,-38.023529,31.556332,147.069684,148.937519,147.0183,169.36843,123.724928,-39.070428,-89.634364,-26.180036,71.827078,247.379701,286.79647,288.090921,279.348851,271.552278,201.65293,152.379811,27.669831,-33.666378,-49.685738,-72.816332,-127.752909,-152.558185,-102.355351,-15.206542,-17.213624,-55.502574,-53.208987,-11.890912,1.165558,-13.324647,-86.365029,-129.03862,-151.030195,-109.980925,73.273488,181.645715,143.685822,4.067505,-44.354517,-47.784798,-19.687414,3.380888,-0.179864,-11.780692,-33.95247,-32.92952,-61.759901,-106.060569,-170.259977,-168.50349,-118.164323,-20.433273,27.993319,6.652367,-79.528484,-213.578612,-186.076459,-2.126083,99.613086,274.248883,351.412873,323.556354,173.17024,105.290571,73.085052,90.40913,133.088637,133.677365,98.280651,27.620873,34.703922,115.29085,138.968226,74.721885,21.942261,-2.654267,50.225191,84.001245,137.043042,129.710774,56.123917,37.830488,97.254553,126.112637,89.897706,-16.396482,-72.199199,-140.647413,-126.167187,-53.891185,-42.551236,-116.396199,-219.905268,-242.361585,-236.745534,-216.221726,-158.616369,-140.412586,-159.695109,-190.048798,-180.190165,-181.827023,-229.533932,-280.840415,-219.269676,-49.167068,-10.160133:160.787868,239.187795,229.319368,124.307974,75.413815,82.952202,125.54512,190.628629,199.607817,189.749269,75.366043,-13.156574,-63.324505,-18.128723,39.77528,17.163504,-62.034325,-26.419747,30.368542,67.273358,31.119309,-28.496392,-15.762606,50.936476,49.345952,-6.60055,-193.705799,-240.490365,-77.001941,84.722135,320.835499,349.059309,270.808236,184.524967,195.491301,285.482644,307.763752,247.451786,193.259246,109.278811,81.60886,96.689056,140.485917,130.801013,93.149221,108.731347,163.916234,171.138701,145.014253,63.052389,17.495999,2.375187,29.500455,12.852617,-48.245374,-94.031329,-6.226917,-3.20707,-93.309244,-136.020923,-126.136447,-79.327986,24.083485,65.534394,99.566318,73.234172,65.460307,83.737756,105.254704,95.309892,28.397983,-136.371513,-141.104129,-102.815235,-45.280335,-23.509466,54.186944,85.156127,46.735623,6.085849,-45.757529,-76.632202,-57.758088,10.567661,6.96046,-33.275851,-9.775498,142.689355,235.121061,213.797897,115.557354,81.092243,140.442042,208.821036,237.829913,191.949437,138.849734,192.036492,189.075021,37.498276,-56.556995,-75.238893,-15.417739,23.103128,-79.312046,-116.067836,-125.600515,-128.361226,-126.557755,-114.488526,-126.391991,-141.797639,-121.979898,-157.116558,-236.731468,-369.903522,-333.027152,-91.223143,8.999013,50.060208,-29.073107,-71.838567,-59.146794,12.832377,137.266754,126.038681,12.696231,-36.109414,-61.687391,-12.819275,-1.866517,-11.705612,24.470316,159.97252,167.109238,25.778909,-64.192434,-46.243491,27.873071,43.185936,60.774138,86.592196,141.884414,165.94107,155.858828,49.35484,20.50622,-32.758767,-88.106229,-96.386328,-18.315823,114.554546,72.535587,52.071557,106.4157,134.240537,115.420611,101.921499,121.962675,136.846599,144.540418,153.133706,160.969573,127.407559,84.648882,19.043679,12.176389,82.612524,215.641322,249.616084,250.76865,230.113045,197.3716,217.56828,289.230209,297.292893,248.660296,251.445199,265.461016,181.135369,111.834963,79.876635,99.243769,101.360961,75.451776,57.168971,-23.474887,-71.356105,-62.794318,2.697881,140.249145,163.155806,97.309543,10.479818,-11.090354,18.928439,65.448997,52.981102,-38.109804,-201.222689,-216.773371,-219.672949,-187.262999,-135.449923,-103.135654,-153.056732,-247.597474,-238.94958,-141.640542,-104.143211,-138.446029,-225.409164,-223.787642,-164.838759,-145.913162,-55.343895,47.949594,26.096405,-95.535138,-132.653761,-113.167644,-74.942007,9.417391,53.217918,111.927723,77.586191,36.175449,-29.064735,-46.159222,-40.179165,12.061248,182.654348,202.283185,142.642497,81.703958,108.029565,169.265683,162.532022,105.541325,105.674356,153.331132,125.182774,79.194552,8.322674,18.0623,114.194604,161.806156,215.941446,193.317247,124.960982,-103.477352,-217.675286,-285.751456,-232.426642,-131.825222,-112.849876,-109.510716,-157.872374,-180.599576,-174.746472,-128.497772,14.261563,61.797264,64.532061,8.792743,-21.814127,-113.116752,-183.429393,-291.042069,-309.123779,-306.900175,-274.279002,-195.699858,-259.43383,-325.515782,-408.747339,-399.354075,-318.161951,-282.445012,-250.295586,-257.998214,-273.535493,-335.672416,-387.224782,-433.657326,-396.561784,-301.919218,-270.3635,-247.713771,-296.409782,-305.011111,-215.815447,-160.182104,-116.616845,-96.002307,-36.997975,-76.032292,-111.219973,-95.515055,-88.152518,-143.545934,-140.18938,-70.651094,-71.839145,-120.839685,-72.204157,-39.86968,-61.66861,-76.883499,-14.569408,37.604578,100.119119,45.14034,-1.497628,15.498114,74.124138,162.032621,173.47794,149.762024,115.097008,26.908843,-2.256994,11.481021,55.044843,69.02115,97.032326,138.59381,240.685147,122.938691,11.591023,-34.829161,11.78305,73.684054,98.628969,139.567422,125.977433,48.364251,6.778655,31.22027,104.111147,111.053071,75.474824,49.740695,-2.106147,-65.71364,-81.949253,-5.462978,42.75458,-11.971938,-105.989039,-183.705069,-93.942347,127.924162,94.40311,26.596261,-49.361071,-32.210966,66.162343,86.937792,21.757195,-74.084006,-91.58415,-74.973479,-91.095697,-187.542284,-207.301972,-135.267926,-80.33419,-46.832454,-113.17264,-115.356614,-20.262258,28.757235,47.42436,23.330816,-4.698132,14.541901,5.012305,-48.938444,-60.900737,4.750011,61.544633,50.55055,-44.224304,-256.679746,-314.610951,-275.806232,-106.194992,-36.354502,-50.549584,-90.14359,-124.969185,-171.519665,-191.1599,-191.411582,-181.552065,-112.039275,-44.920589,113.857362,186.497352:right
-150.611189,-133.38112,-88.070453,-27.455,-59.37548,-158.686966,-151.075739,-31.281883,38.462163,19.858385,17.551827,72.956163,197.902618,226.266807,226.164965,230.445868,283.647659,313.912669,295.538714,205.314132,159.004477,144.541437,174.296696,240.098686,259.101464,222.202929,50.021695,-49.658938,-152.784854,-122.45361,14.771366,53.313784,51.864039,22.086013,-6.816411,-88.458031,-126.56319,-165.602626,-156.207847,-45.257824,107.935187,138.549551,113.842989,87.308646,44.349123,53.795398,128.424443,141.759909,75.274056,20.980936,24.792096,12.376883,-10.074235,7.354742,52.829911,183.345714,360.78112,417.055424,373.982048,290.586222,125.117577,88.42846,122.533233,165.444092,213.915263,198.460756,167.763836,16.218031,-84.974072,-216.48769,-218.481645,-112.126254,-8.58994,-20.570832,-106.148912,-118.430752,-73.534477,-44.214483,-14.50209,-22.730058,-65.72427,-96.565185,-94.758243,-108.068282,-143.548903,-170.193677,-130.181532,-31.276734,-38.136185,-91.323023,-207.268831,-225.303301,-149.779537,-80.543383,13.311114,47.953005,125.105163,41.347689,-41.404254,-105.422849,-77.138647,38.635065,96.361234,138.346153,87.159538,57.97075,21.719702,-10.589565,-86.967282,-75.381294,28.64572,59.243541,58.257067,23.379265,-11.670733,-126.875894,-196.074015,-243.788704,-201.732644,-88.342335,-72.970524,-113.313135,-235.354773,-283.64274,-271.581543,-207.57395,-82.018529,-63.421861,-89.869209,-111.160491,-88.257309,-18.808999,-26.300453,-130.191483,-176.430657,-173.695081,-117.434815,-127.724146,-161.362213,-153.594612,-147.130933,-128.226963,-1.592234,83.374627,270.999622,349.358358,292.159029,93.039556,30.87238,112.11294,239.197919,466.842228,501.034285,475.694587,388.344051,317.524924,230.498344,263.754415,372.414363,407.016115,528.20793,638.799205,633.970081,536.41062,461.18485,336.262044,306.382884,265.934483,227.621013,211.317833,179.843468,145.233741,78.085315,103.595171,202.916576,205.698834,170.61501,176.166257,184.006721,168.446336,137.148672,79.805195,69.807725,69.604602,144.140457,208.28197,291.033138,279.710669,172.440674,138.622209,179.450876,206.416204,181.031709,87.284985,70.305889,161.650964,232.575983,310.535462,299.946001,240.808152,247.27582,261.05586,227.474514,164.189596,11.108998,-3.320776,116.651741,166.604504,144.805976,141.126382,192.521259,234.072726,169.348617,27.636072,14.529911,54.588974,76.614531,46.883858,-54.275796,-68.826817,-45.27382,-54.335861,-76.608842,-26.135161,160.397269,186.278222,149.994387,112.359058,107.380696,99.948494,101.632769,140.926201,225.677379,220.740358,58.432753,-53.380955,-218.258409,-236.926199,-121.01782,9.725506,326.082251,354.58193,208.796468,-101.227308,-153.46759,-103.719615,-68.71696,23.10814,113.230248,93.223313,-1.460621,-9.927325,29.856719,49.698018,67.253268,81.52433,177.123782,212.045307,164.461947,17.178745,-67.3955,-180.318514,-163.336008,-20.927086,79.180744,77.341999,41.546022,16.790855,-81.933426,-111.601138,-42.593382,7.145222,21.26363,-47.117478,-73.971645,-122.135278,-174.144249,-298.485473,-318.324926,-256.959598,-166.124486,-118.230582,-17.972706,-11.55736,-107.376414,-131.948982,-89.829969,-73.687883,-50.6667,-14.252693,-5.695238,13.909912,25.440076,60.008017,102.838165,208.944729,214.727355,144.697954,-68.659885,-157.624846,-303.382316,-342.7351,-255.335667,-179.523383,-153.149744,-225.999226,-237.032453,-247.308772,-270.290401,-286.11248,-265.247252,-210.578942,-210.351525,-263.659945,-394.540868,-427.024709,-451.161041,-456.92267,-432.412594,-390.259323,-258.343747,-161.022019,-137.154769,-124.152963,-140.22972,-181.677042,-210.594248,-315.823345,-360.744252,-354.51702,-347.360667,-350.752348,-393.787272,-423.759792,-432.177704,-396.272162,-252.39363,-149.457049,-169.331066,-279.290369,-307.805538,-275.169236,-257.547035,-248.744645,-144.612541,-82.726857,-68.765848,-109.011906,-188.160461,-206.834055,-240.170039,-253.106328,-200.754892,-101.640679,-77.565188,-59.587386,-39.240093,30.410707,54.263163,77.931634,82.247641,40.63853,-64.793538,-94.572355,-187.821741,-247.287778,-235.984395,-163.624961,-74.864058,-140.582876,-160.383153,-82.287548,-39.563203,-59.492321,-85.65572,-41.969278,94.011812,122.444681,70.024219,33.927601,-3.573279,-19.412865,-109.127173,-176.755295,-229.404449,-112.095429,-32.03806,53.33356,67.032826,135.667164,162.292862,124.463067,100.15363,111.494004,94.954251,58.452719,34.816585,82.844206,227.648733,275.746962:-127.131671,-84.327946,-47.528458,10.651838,3.949686,-71.673538,-98.022194,-49.974649,54.834496,85.408536,112.222221,120.427007,124.676102,127.87139,174.191214,199.273013,187.009016,174.732918,182.799912,156.008993,135.360213,156.372,180.365708,192.599358,178.190513,158.462018,79.696837,27.378547,-66.42327,-85.392127,-44.246282,-2.469994,40.859576,-66.368997,-139.321666,-159.73304,-119.213896,-66.044571,-55.461488,16.027786,115.021124,118.366448,24.14286,-32.427565,-60.208492,-33.444216,1.207415,-5.482824,-11.994965,-2.383939,-4.014905,-31.905717,-47.659667,-14.64599,31.492748,126.020474,205.848041,242.400992,238.058182,177.97094,50.403171,28.646807,65.778718,115.861674,206.355432,163.533671,102.440418,-70.71699,-146.163593,-178.501511,-152.692316,-71.185328,-34.924438,-57.63503,-78.699578,-56.057702,-16.152234,-11.413766,-3.940605,29.547036,154.203671,135.538203,51.696043,-103.188294,-122.349112,-54.81051,-1.935925,86.633298,29.816875,-57.34367,-164.055909,-150.305374,-76.263606,-46.145389,11.157144,55.039024,98.807782,-15.215124,-69.314135,-99.258616,-80.578418,40.118499,102.565773,137.925603,100.264143,47.000801,-79.044071,-104.124337,-73.448982,-40.12255,28.378651,61.680374,83.997421,-3.496037,-53.661712,-118.80488,-151.929428,-199.290015,-178.899788,-92.062417,-126.037432,-185.955059,-255.452961,-255.731267,-218.898808,-179.534263,-98.261341,-66.444564,-50.753159,-128.033046,-152.825406,-124.144519,-102.631752,-97.561747,-104.253524,-64.748961,-30.582927,-74.124398,-175.161238,-177.470244,-127.563705,-94.638705,40.482892,163.383228,419.430065,434.929459,358.049157,211.306686,177.17235,221.841379,295.391876,430.39147,419.936269,377.422933,324.340845,321.839607,300.228268,268.704308,237.63834,267.831361,367.640478,334.364372,269.656809,157.289623,115.090397,69.916193,80.61954,131.874532,90.140607,29.468549,-49.555996,-54.357277,-69.36504,-90.101947,-96.368045,-54.570377,68.323435,95.344035,96.500781,102.277897,82.119436,30.395434,19.474199,66.004242,237.715131,310.264164,277.549366,179.005373,8.564256,4.137313,92.883545,120.724261,70.681183,-38.528208,-46.444274,40.254532,97.591719,196.653278,213.238123,161.277893,92.780341,69.000127,48.849828,41.45676,10.344745,14.278762,82.482128,121.288801,163.884519,158.162473,154.718687,115.964534,71.013122,57.935142,117.63199,214.393585,178.671129,115.478255,-102.712888,-186.161444,-158.674763,-105.422988,-77.431713,-58.430625,74.265024,116.392095,99.766197,122.73466,146.473578,175.20062,200.107242,246.427058,165.175515,87.492379,-40.521301,-79.791324,-105.021179,-85.123879,25.043674,107.519996,223.522551,173.148725,110.39768,-4.986492,-47.415048,-99.933783,-94.720209,0.985779,100.317527,81.791161,-44.018665,-95.341686,-139.40368,-125.206824,-73.331756,-62.359598,-9.585042,89.365602,96.507095,-28.053031,-97.933295,-89.509299,-21.646352,120.033586,102.550476,38.635819,-5.792398,21.854986,47.080158,41.069178,32.395123,34.059899,35.19655,-6.910882,-27.599132,-106.427073,-193.527869,-344.228302,-344.380831,-233.967915,-161.624489,-152.176367,-134.166884,-138.825597,-174.44196,-176.59284,-152.182305,-140.585595,-106.107032,-43.070069,-13.188327,23.962622,40.044009,87.995903,113.879662,203.834342,281.839888,242.110096,57.442866,-41.047575,-251.067372,-315.736247,-246.438698,-186.725035,-183.687223,-168.90179,-140.701766,-200.724638,-259.786867,-228.776775,-153.720668,-32.910616,-36.473511,-119.711642,-320.890595,-348.570418,-334.773551,-353.231022,-344.534903,-287.108605,-170.374283,-117.083285,-107.149731,-144.133064,-184.315287,-207.721324,-194.812679,-195.542704,-198.147412,-212.145767,-294.760556,-347.72382,-427.714752,-442.981442,-419.715378,-366.661552,-189.833716,-114.637988,-133.177505,-194.029815,-224.406642,-237.838795,-219.490143,-192.046712,-159.977951,-154.032599,-178.612909,-203.539661,-302.284898,-336.468878,-257.755211,-184.816,-129.844386,-152.383221,-136.417221,-32.400648,32.105909,135.796271,170.529445,195.122817,111.532819,34.504642,-59.112328,-60.235882,-120.740066,-186.60404,-185.183322,-105.770768,1.482346,-11.867774,-5.1917,31.845078,24.255589,-20.884935,-20.471109,70.396791,196.605258,202.133494,110.227697,68.503972,26.227561,-1.482279,-89.064083,-133.170088,-139.014228,-6.571727,47.304136,59.207436,72.050401,173.413266,203.972641,154.604526,105.863448,116.920023,122.600231,96.366652,99.645777,146.864904,223.32433,233.356641:-124.616193,-182.856164,-177.204144,-118.553133,-94.535184,-33.132937,4.949436,17.982291,-34.841365,-48.392428,-8.779061,10.24815,-24.003898,-56.086038,-45.661198,14.061161,117.398985,85.921865,63.364802,36.459333,19.226414,2.021127,6.460841,19.242668,6.953699,-8.450197,-69.827139,-121.836717,-154.797789,-111.456303,-37.087907,-27.58026,-2.036337,-11.420457,-47.981798,-128.179534,-131.352653,-43.630699,12.543169,83.275411,74.386351,34.656068,-28.372982,-21.817706,1.678284,-6.498021,-42.83362,-47.949179,-0.167329,32.714727,7.953641,-83.826333,-105.854247,-62.814872,-19.736549,71.816922,122.249778,113.806235,62.838966,42.023445,44.443043,64.497442,112.536129,136.241868,129.779971,23.892608,-35.671476,-134.811253,-164.786228,-196.725055,-196.830335,-117.95206,-9.444425,15.579511,33.350087,47.306422,57.178962,43.520695,31.959808,54.419079,121.618949,130.887433,99.494035,5.122777,-1.29335,105.605085,168.168678,221.083103,104.164009,5.608483,-102.454132,-84.542902,14.336665,41.697801,40.888279,59.653064,118.386699,57.782722,-5.658001,-89.398423,-87.285311,-30.18676,13.460658,123.306486,175.644165,158.274686,45.021867,-20.054027,-49.865789,-8.935612,78.254923,92.479979,45.21541,-51.232885,-70.678355,-57.860079,-74.351936,-134.074462,-119.28999,-31.611743,-42.677692,-60.164499,-55.315742,-74.36724,-166.332607,-178.393318,-77.416916,-8.597588,24.640201,-95.666088,-148.348627,-140.014025,-95.87393,-21.165037,-0.989385,43.777821,29.77929,-24.370495,-130.766819,-155.391909,-97.604101,-0.852712,177.992199,211.710052,268.261955,322.427904,285.500033,103.317668,33.535809,67.23135,147.384124,239.543076,154.691401,124.381767,178.969001,205.947293,174.51277,162.900215,233.197009,291.37361,347.945627,293.485028,244.142256,86.355892,-9.660978,-85.829446,-51.921535,33.14169,-11.813775,-84.015754,-206.120684,-241.996754,-249.547697,-213.523159,-143.029737,-125.608404,-111.082957,-120.207352,-107.137827,-48.571313,-18.864543,19.098273,15.178044,-2.978707,16.531335,22.925093,6.144381,-1.950609,11.101926,19.981321,8.29058,1.991966,-11.496586,-63.152395,-77.113834,-50.171862,-12.666034,72.869532,82.906511,17.830967,-35.743148,-32.701529,-49.334331,-83.142773,-51.604328,34.971348,166.227715,167.46974,107.711048,75.327882,77.662873,50.679186,18.108722,24.975827,81.082713,181.628805,149.38516,89.175725,-5.376294,-8.987235,22.715212,29.486545,41.07993,77.095294,189.7707,204.361408,174.593141,142.554286,164.132073,270.003993,310.827323,285.257501,168.057601,111.900735,39.478191,7.240572,-25.24062,1.207403,108.682315,163.105323,216.193811,140.930169,75.810588,-26.518507,-59.056289,-131.714722,-156.902462,-101.796799,0.058732,12.309349,-58.981451,-121.90637,-184.907765,-156.621022,-73.130743,-68.73677,-96.314735,-40.910938,-0.769856,-10.498514,-52.897851,-83.323865,-45.845978,34.694431,-23.936359,-49.558897,42.190187,85.555582,34.818425,11.719469,56.890478,77.910879,48.135093,-43.02863,-92.307337,-198.75589,-258.410218,-299.081054,-238.505941,-41.688185,18.309715,-9.117294,-19.994015,7.698485,26.095804,-1.456934,-62.256639,-49.17197,51.616679,58.659142,36.081306,92.53263,164.457908,262.511974,285.286189,371.510176,408.035378,340.461179,65.60224,-80.330928,-217.563692,-175.912466,3.867032,48.546865,-15.974404,-128.536149,-174.902021,-279.974457,-305.977626,-169.482181,-44.236235,40.351476,-132.270477,-223.411784,-313.867825,-322.352583,-309.072045,-282.070298,-191.821264,-167.191971,-176.587197,-101.886386,-53.489494,-95.437927,-148.153248,-147.996167,-116.761493,-128.060537,-260.366863,-330.14079,-374.472848,-381.440106,-466.592286,-490.729225,-356.91814,-238.382622,-97.229237,-124.71806,-162.007213,-263.762764,-297.266687,-247.354326,-195.439282,-146.670294,-198.095013,-237.442663,-273.321118,-272.910606,-279.538991,-286.229499,-272.696065,-254.121682,-229.026563,-179.165815,-125.155867,-20.914706,1.76751,61.502229,127.958008,256.537865,226.573039,151.470338,-12.12957,-80.775435,-139.936504,-98.66909,32.471981,68.760312,90.536681,61.323919,48.211476,53.433483,53.11998,68.144921,86.708257,116.529077,139.73316,135.175014,100.057635,79.901021,17.408336,-7.989085,19.780078,48.939084,28.370523,1.059364,28.89178,97.487283,122.740441,168.774454,187.242314,205.768082,197.846399,174.943336,96.293307,49.903018,28.250469,89.455924,261.148668,307.1418:-39.628876,-120.372957,-167.493583,-191.696384,-170.078373,-84.977065,-27.76028,48.329803,4.471274,-47.371102,-73.4868,-34.05278,26.483292,31.747614,64.752555,97.726569,148.813884,149.27903,129.226201,64.126752,36.321413,29.291932,46.785936,73.118397,51.672082,27.793673,-49.522522,-95.644986,-146.804131,-140.880565,-109.553429,-104.772426,-110.973698,-149.17681,-172.061796,-160.221997,-110.025856,35.52322,75.396394,64.343863,85.839934,104.687547,63.343287,-1.105766,-93.159591,-59.995135,68.242945,81.315086,42.846674,77.631551,87.979994,-15.130507,-77.529291,-49.0494,25.940625,186.903294,303.950449,310.22446,245.36847,215.024199,151.807011,107.991348,60.33575,72.224604,92.676887,64.530903,40.608628,-72.692059,-145.017364,-172.689734,-115.040515,26.239422,91.481695,90.640933,60.254627,65.611542,136.73592,161.820134,121.130886,94.109189,92.104293,35.170635,-1.347912,-35.116016,-56.245616,-68.506921,-27.115466,89.692565,51.465512,-21.607285,-89.346235,-80.36255,-73.452862,-57.593896,52.310279,110.61987,120.931677,-7.44013,-88.933131,-204.082717,-193.028663,-43.950453,25.842225,82.51015,85.601395,70.208323,41.127029,39.656663,39.233525,38.81709,38.092709,38.272894,57.373448,68.859764,49.416251,-36.81346,-81.986659,-103.182851,-84.506641,-57.379756,-84.85841,-129.945803,-248.870788,-296.399577,-337.746294,-328.325923,-237.885179,-161.113356,-35.052846,-51.163299,-77.25489,-84.238109,-78.172061,-77.098706,-63.714744,4.401962,31.608429,8.471586,-45.437519,-65.247197,-74.761709,-32.235148,105.175329,163.682831,269.683083,285.520602,232.973336,63.350158,-7.813069,31.764922,148.058355,343.798984,335.730448,320.921511,351.942559,356.042386,283.040621,259.471918,320.881316,381.967394,506.765248,557.558353,534.605119,395.850702,311.459319,225.497256,210.071343,163.999654,127.687849,95.364928,-51.808842,-136.065345,-167.13076,-104.451469,-10.166138,-17.022001,-20.916188,38.596802,61.118024,67.38658,46.819239,-40.881949,-69.17848,-2.414305,126.73459,160.753156,165.152653,154.120642,136.574216,148.857324,219.482708,247.660261,226.638069,167.349367,168.266524,191.769607,201.714551,242.004908,251.590576,252.429193,309.92745,324.694347,244.720167,180.870016,136.828273,169.463367,229.752916,224.592717,222.461114,275.593651,307.149164,316.190054,266.642009,135.116448,104.046893,141.479892,212.338724,184.684172,-2.657027,-87.770198,-117.310021,-84.575722,-22.560149,18.262749,157.027904,197.507219,164.236221,101.235694,78.739835,64.641593,90.052297,171.30691,177.217898,135.196694,-2.900433,-95.412291,-255.804284,-267.925953,-134.341335,-18.081064,196.492468,130.357896,-11.933465,-259.948234,-295.798763,-237.004313,-200.584147,-134.635046,-63.538466,-67.658137,-142.539243,-169.063846,-152.074212,-130.336348,-144.690308,-169.684428,-117.625644,19.263078,39.386392,-63.702881,-143.379904,-208.025623,-183.129172,-76.67024,22.395884,20.19505,-60.650119,-94.808584,-115.885596,-105.87326,-42.219212,15.721702,93.91631,-50.31002,-161.203252,-286.748227,-318.659151,-402.751054,-417.144139,-302.462567,-141.133054,-83.646335,-20.219405,-39.224347,-116.584594,-117.0786,-96.710267,-103.05775,-65.971606,-9.162262,3.817333,21.353071,13.379598,39.142484,106.445374,263.558058,291.754537,213.790008,-77.922439,-216.718264,-333.283711,-297.001166,-171.483326,-152.694572,-159.131389,-156.314626,-193.646688,-312.267794,-339.613451,-277.076626,-216.915992,-106.782949,-86.089708,-163.869888,-398.226402,-471.019166,-512.340763,-513.215241,-452.469039,-371.867014,-172.129345,-66.905828,-79.835114,-233.441491,-323.252372,-355.837712,-301.968777,-206.105323,-258.901528,-335.703154,-447.491632,-456.146863,-457.106414,-464.734727,-432.017434,-372.04845,-213.276403,-184.157192,-237.991163,-346.157198,-363.32016,-345.99012,-329.002803,-253.813784,-146.487064,-138.447774,-193.62062,-218.688631,-267.543434,-291.939078,-317.267499,-318.52153,-280.688484,-173.561035,-111.4968,-38.980593,-36.238415,13.900683,89.224283,249.286736,265.831853,201.901952,49.028099,-4.025146,-117.162294,-172.541434,-180.214349,-143.02532,-118.63698,-168.078583,-165.075323,-71.101809,-33.653274,-48.204355,-55.108425,41.115733,172.436738,168.941392,62.943779,16.401414,-44.24993,-64.216396,-93.808338,-115.292883,-112.109651,34.922433,115.216766,169.52992,152.683946,134.937899,147.747528,167.806735,133.79633,94.536275,29.855496,21.850909,72.262074,124.962237,198.958847,210.404881:34.667272,-18.432946,-56.159461,-149.967613,-164.317745,-98.334796,-38.571954,112.004678,180.650479,144.971308,-10.435521,-87.44274,-94.804742,-31.213123,55.862622,81.606789,130.170641,59.346397,5.275225,-45.130711,-45.364281,-24.112391,-9.842024,17.52295,5.800601,-32.825977,-127.827434,-172.702614,-232.904514,-216.841669,-121.839895,-81.486544,-31.508863,6.029436,0.989928,-62.912581,-66.241661,39.734532,102.467927,173.966708,166.894895,135.696991,40.721514,-22.456889,-101.588133,-78.694641,4.357478,21.012021,31.997234,1.462246,-45.320869,-142.71726,-159.683736,-110.382768,-46.796244,136.058003,238.00921,206.726332,74.733701,26.443963,-7.124566,7.141392,43.337463,34.303726,-26.082389,-90.331086,-120.837305,-206.624217,-235.476769,-197.082207,-148.406759,-25.234846,28.301455,10.387555,-50.441009,-82.760525,-90.46783,-41.383105,104.794528,156.589199,152.042511,67.40649,35.318719,-30.612308,-77.065671,-116.245,-75.270841,68.736322,104.098856,60.800677,-52.281113,-100.666966,-133.201797,-88.854316,88.126282,170.384287,178.867386,-33.332072,-147.156234,-257.285691,-238.189264,-130.793495,-84.805622,14.587436,123.014118,124.853821,36.850813,-11.856834,-56.650658,-31.560255,93.480372,162.251337,221.379004,148.353493,94.46353,-40.358094,-98.099299,-65.008177,12.957409,113.298467,18.868661,-62.265716,-167.701778,-196.605445,-241.635883,-250.135229,-235.812141,-200.249432,-92.196462,-102.191383,-144.524691,-183.988397,-160.264376,-56.181698,-11.770657,25.145563,33.313221,43.458686,42.990559,15.076722,7.856721,57.998177,169.557899,199.573912,247.283517,213.415545,132.22593,-48.474276,-86.1528,-13.594626,57.845317,164.264897,158.120115,127.983612,125.513265,137.357687,92.118623,91.885426,240.526949,329.138367,417.88801,413.802997,369.049476,193.676657,110.927702,31.263176,19.889429,39.752082,59.44057,13.409873,-203.430115,-325.180679,-428.79271,-378.73197,-172.57993,-89.636135,-80.589274,-146.549147,-139.017559,-114.777941,-129.937398,-168.972085,-158.268105,-56.463309,35.442952,46.047535,29.661904,3.76412,-31.894931,-11.657567,61.031727,102.883767,167.115436,110.561318,61.928292,-2.090445,2.787929,115.229221,179.280514,195.58591,145.856803,136.358372,115.091516,82.932893,-10.544286,-32.579686,70.898509,175.182839,278.458743,161.059533,87.551314,-5.673363,-15.517657,44.726298,89.220926,154.506793,149.161782,114.303577,25.079756,-12.709843,-36.024686,-14.730835,76.718326,138.150859,228.010095,173.87631,112.940044,39.437881,46.966872,115.971778,151.662042,216.571029,198.37307,114.581547,-79.282247,-128.817273,-139.670187,-127.422507,-57.487501,20.170254,187.23854,135.794572,14.521712,-227.355332,-280.686277,-247.845329,-201.099355,-110.712088,-63.783882,-54.31587,-33.796239,-46.308116,-144.610469,-185.163312,-151.70975,-94.538385,-6.108083,20.896648,24.008381,-24.754159,-69.93626,-78.799843,-23.483456,119.54396,162.339921,121.844442,-5.441384,-53.563311,-71.418282,-34.791123,82.72988,137.122771,183.44539,47.376784,-61.531604,-203.451102,-230.591633,-267.51933,-258.980298,-91.7085,113.854986,157.766405,139.108857,80.701541,-15.912167,6.203988,109.196092,132.838132,131.579994,157.349544,181.999199,199.165916,211.854001,312.716114,379.462497,471.528117,469.843072,412.464733,167.996436,23.800893,-138.855818,-116.999007,67.574034,151.627009,156.823492,0.403312,-72.598581,-171.761565,-187.551251,-99.740507,-35.103151,27.379459,-16.806481,-87.431908,-271.143463,-353.169504,-431.868614,-400.966233,-257.159072,-193.17335,-96.488749,-48.123865,-72.848775,-178.227866,-192.259313,-136.865323,-138.518727,-220.280466,-261.217194,-271.335513,-334.599201,-382.38814,-416.894871,-375.650529,-231.316621,-157.286009,-42.024019,-55.760064,-124.393407,-328.414255,-391.250652,-324.707378,-250.949752,-129.535384,-46.401751,-44.568665,-115.653465,-168.758248,-217.946565,-179.76247,-114.138704,-154.353127,-231.552536,-124.56892,-75.625745,-72.797755,-67.567344,57.424738,147.230402,270.825073,283.002777,234.133383,54.250388,-34.770263,-110.897339,-83.267533,13.477463,30.336834,-6.380887,-36.884554,-29.175923,-15.67521,-35.98177,-86.209449,-75.466765,54.001677,177.417253,160.034354,6.482575,-60.736963,-65.446212,-3.852801,153.252936,208.502088,239.780161,203.443978,180.608505,126.615874,117.348421,187.835152,242.755133,306.799769,287.751409,255.660606,170.184254,104.446317,22.663727,85.786003,317.253096,371.514303:-139.562182,-159.146491,-153.200818,-91.375509,-66.203825,-20.509983,7.933374,26.869573,38.437982,42.324531,28.087065,20.420186,39.534359,81.316052,219.842062,268.259184,220.775793,99.861463,74.620568,71.057957,59.525885,18.944003,-2.743331,-22.654912,-13.357519,-37.911378,-109.501756,-130.098139,-141.031751,-124.026928,-84.343867,-78.210114,-63.794171,-112.236714,-163.38814,-186.608596,-172.586274,-155.248054,-115.311002,34.803795,127.400229,132.33385,97.878771,45.048671,-94.320182,-107.797782,16.578778,92.019904,147.377763,78.093089,32.420934,-20.197417,-25.494591,7.824275,47.053792,165.010766,317.59042,364.838839,337.480945,277.404461,133.518999,86.704095,85.485401,101.348234,111.77972,118.953004,122.886095,84.410786,28.941525,-41.985929,-11.607888,103.575075,111.799544,76.331032,33.465157,32.30653,27.00232,32.628636,63.824814,70.231041,55.534432,30.599083,6.707317,-31.372863,-19.061704,28.969189,24.409314,-29.925991,-32.968781,-32.887226,-77.779043,-107.377681,-117.803325,-88.456409,-15.650058,26.80665,117.454011,-26.01428,-165.359324,-274.981768,-228.932305,-79.572465,-5.865038,104.707061,73.779514,28.303177,2.231547,3.300725,-25.69555,-24.637414,33.362551,59.770444,75.227215,34.647123,-9.344932,-90.663334,-105.753251,-76.509619,-45.029061,-5.719707,-48.300923,-103.514078,-209.184569,-231.177941,-239.754613,-225.92171,-108.809781,-33.525247,2.967665,-81.540006,-88.808888,-41.884624,-46.106901,-108.297634,-118.374865,-42.719083,44.230119,30.578183,-48.792954,-64.991492,-59.157798,-37.766409,32.577648,70.490843,171.553259,177.219273,114.989492,-19.325567,-55.555629,-23.327092,46.382563,198.752221,284.893173,313.704317,347.175925,326.847772,266.224829,296.076535,453.563087,519.599855,611.275396,671.919776,673.040822,590.331853,504.128643,342.729236,317.200145,332.700821,281.174031,211.297081,58.162881,-2.506598,-47.673988,-15.351575,49.56868,36.724841,-5.54923,-23.873737,-42.173432,-100.089867,-134.323782,-138.15688,-103.132225,-53.609731,-26.311704,-7.55482,53.983953,96.708168,104.616546,69.710465,100.501032,192.000724,364.15462,360.613976,336.163437,350.268435,382.22171,424.986732,400.902425,308.283239,342.453738,389.5275,435.322978,431.560102,378.700738,343.860601,275.550683,246.623269,257.66555,367.1059,419.036608,363.599048,240.899286,57.512218,83.539718,208.009398,175.622704,111.095429,18.518885,6.09904,-17.811277,-25.449383,27.039176,79.189539,169.477554,154.540112,109.098071,30.245319,14.609837,24.529365,34.105603,21.868136,49.492971,72.775134,-16.770313,-125.754259,-288.492779,-277.078009,-81.976987,44.220435,243.927404,187.645662,38.153708,-252.820334,-299.151586,-203.388846,-123.203377,-34.894191,-98.438324,-156.34365,-173.82894,-115.933756,-11.027165,-14.691498,-65.328796,-66.252936,12.278839,118.163762,126.698285,19.410768,-67.068582,-187.964055,-199.342861,-144.283706,-48.172613,-10.80053,35.496063,40.078098,-43.157142,-129.344848,-236.58542,-197.699157,-41.192338,-65.69529,-116.574375,-103.084923,-78.947462,-193.816873,-307.620375,-386.145874,-176.56896,-82.364509,-62.135077,-107.849,-208.752866,-218.366624,-146.540498,-95.945235,-11.58652,16.953688,33.977682,51.24909,21.947458,9.13211,75.371998,235.675854,243.630445,191.172609,15.950469,-88.810354,-234.319123,-239.273839,-181.16902,-164.18119,-139.332218,-173.926136,-217.388295,-246.025207,-224.782099,-202.288373,-219.474959,-236.47118,-152.521383,-133.655923,-254.952659,-344.608782,-425.11381,-424.606966,-413.552658,-386.995358,-255.94716,-144.547311,-145.275066,-252.577931,-327.252616,-394.283347,-382.410059,-375.47103,-399.814376,-403.287076,-342.213489,-304.815347,-362.540281,-429.673519,-451.710435,-404.390623,-335.441787,-370.223026,-368.211281,-294.333127,-285.95084,-355.562248,-383.205004,-334.197102,-176.18314,-122.353909,-142.857129,-201.121763,-322.264894,-339.830989,-272.215408,-227.548383,-142.289662,-76.037134,-67.691905,-54.3531,-36.868314,31.425783,76.469066,137.564134,143.234458,126.79702,80.739302,55.643449,-11.280056,-38.82922,-60.26576,-67.780492,-96.361776,-151.890998,-158.715929,-74.677268,-41.033601,-55.717822,-46.389469,60.3754,152.243546,160.81608,136.617986,116.19662,60.713048,32.772553,-12.844599,-31.669375,-14.365107,112.336147,184.358621,221.115484,186.746234,184.274246,249.251141,396.647051,405.098714,353.636921,218.442256,156.10024,107.694627,150.108901,331.967829,406.446959:91.451809,-46.632623,-108.720333,-77.413969,-16.929884,107.621347,161.987569,209.331006,129.961229,60.731722,-6.656903,2.456302,23.899292,37.324779,126.833832,192.281591,254.827182,164.580962,99.998269,17.892154,2.867202,23.196787,52.111428,113.822705,102.910749,37.664954,-146.404374,-215.407026,-229.820159,-180.598293,-86.308036,-57.495233,14.778586,7.609109,-44.957652,-113.735744,-99.764701,-0.872083,72.629724,218.745705,246.220261,200.646887,48.616568,-36.12603,-128.05611,-103.484757,3.556433,34.328182,44.165986,48.89023,42.288427,-49.576415,-101.38924,-39.998283,77.019807,319.601746,349.521702,271.088536,102.560577,67.872394,62.103728,52.917154,4.461638,-9.038698,0.628762,-1.668132,-18.586288,-111.355989,-159.738027,-132.307718,-57.160947,91.934598,110.322908,78.50967,4.666823,-23.057452,-6.485035,33.374744,78.293807,79.535856,67.040118,0.184133,-48.14152,-144.49176,-180.249517,-175.22768,-135.277069,-42.23267,-14.482749,-26.508676,-66.128453,-104.082629,-163.855168,-136.725939,21.920581,111.563441,145.573595,-105.286945,-234.790166,-329.938537,-315.14558,-231.431484,-187.970945,-122.350609,-59.945342,-52.911425,-81.158517,-100.631193,-97.872001,-56.272831,36.986352,71.085866,135.757788,78.88322,-5.49626,-128.52555,-129.19726,-59.576299,-24.121724,-6.142774,-52.155238,-96.579799,-212.399108,-257.623554,-307.284724,-309.906558,-207.739539,-107.923215,7.949101,-57.330034,-93.81647,-128.355053,-130.857097,-97.037561,-64.842704,11.556817,30.679642,-0.677834,-75.076399,-91.624225,-50.01369,17.472554,197.580213,260.721522,257.058882,133.665955,73.576045,-6.090026,-36.935534,-53.523685,-14.469436,145.746088,239.519721,222.845075,184.597945,186.557839,190.924769,207.221153,315.784166,397.259803,525.368181,505.589124,452.489957,323.750069,264.541332,174.243936,140.883222,105.266317,81.570259,33.304908,-166.757502,-281.635051,-356.056868,-276.376813,-61.621602,-8.694104,-2.880744,-72.020036,-113.448626,-132.056772,-116.524145,-92.037632,-74.933542,-8.778249,52.251621,55.86895,16.527414,-17.359847,-88.256064,-92.298209,36.981081,151.249693,277.504313,185.650879,149.199202,146.97535,150.238392,200.827756,260.522657,379.278721,399.311042,381.25671,330.437922,304.197079,298.39711,305.927117,295.604481,319.654274,417.065882,395.466176,352.339969,271.95809,232.802931,206.398726,232.843105,296.866815,308.904051,276.146169,160.035024,122.125752,109.693643,112.776005,162.386852,231.305855,368.330166,310.780257,221.674857,69.324848,28.631768,18.400857,58.700073,200.592529,256.833893,209.39217,17.182494,-100.125561,-254.185071,-224.295899,-7.809635,94.842718,203.523286,122.671331,6.059958,-206.134327,-236.517303,-184.045422,-149.307888,-76.216553,-29.878746,-40.251945,-46.077258,-34.004858,-65.783812,-96.272617,-77.244575,-19.410247,116.306378,145.740402,113.463314,14.254212,-19.434345,1.621615,20.12284,43.97396,134.491719,156.303176,61.78804,-17.680122,-116.772113,-124.874645,-55.085435,29.785171,165.230586,15.068778,-97.713621,-149.15559,-115.547317,-109.400649,-143.139707,-122.627412,65.865433,130.953702,59.370462,-45.75974,-154.886793,-105.496351,67.851867,117.969419,118.684379,74.255835,66.074361,75.13973,89.005109,172.523102,243.204145,387.690619,417.212119,343.026047,69.559904,-44.789807,-81.311465,-23.229591,62.18935,62.027006,68.878921,-11.386845,-124.863083,-297.505531,-280.896225,-145.924721,-103.095293,-64.075091,-97.782749,-182.863183,-371.558633,-420.969858,-454.402963,-436.992273,-309.19747,-241.264363,-164.773396,-76.532922,-65.369925,-203.622591,-279.057558,-291.966632,-263.479471,-235.71969,-289.690972,-330.963614,-356.833027,-352.007807,-339.754439,-307.121016,-189.208874,-142.436945,-128.662053,-202.259851,-253.02595,-361.996837,-414.304184,-422.983451,-369.006246,-236.91532,-155.351521,-157.417599,-237.694706,-284.788204,-341.232369,-334.156607,-229.740088,-161.104112,-81.879588,-66.221785,-64.227107,-77.512619,-74.9069,25.639928,100.545157,187.59402,197.210196,173.471232,17.865929,-85.06126,-172.950128,-153.149156,-78.879755,-43.275207,-30.76475,-99.03094,-119.34626,-137.241301,-164.081012,-200.240831,-158.985389,59.817675,252.330003,249.583002,83.494747,-8.759371,-76.857602,-39.638996,67.606858,90.201914,126.472607,233.249018,264.60688,188.03464,144.063695,229.067543,320.259972,439.071362,387.647551,301.16311,120.586611,60.34361,48.640205,114.135897,308.433916,369.202409:-237.990448,-185.937032,-156.66082,-118.413942,-122.671432,-138.296662,-122.14281,-71.761792,-73.32718,-106.629902,-118.859998,-76.490958,-46.053525,-53.199095,76.112512,193.479271,277.313245,173.565746,142.226588,72.187987,-4.356047,-102.810691,-81.344734,-13.524581,-42.301955,-99.059475,-244.727601,-284.938436,-234.883245,-193.962297,-209.086064,-217.909925,-106.471924,-37.568528,-71.921089,-132.495923,-145.358306,-164.877448,-150.845962,-56.384373,86.263043,136.220156,144.191432,105.261904,-55.155944,-138.71506,-148.722009,-80.744837,19.473907,-34.203251,-88.733434,-158.90626,-162.645074,-81.21728,9.303731,229.112951,350.257992,320.885378,155.566329,93.550807,64.749483,70.726275,80.751873,97.154323,181.41642,245.823252,260.751789,249.89561,188.548529,49.245025,56.469115,191.194864,288.081551,303.185529,265.638355,219.144777,176.12534,210.518883,265.878176,231.394901,123.255632,60.928537,31.009481,18.501253,52.82535,132.621524,136.532979,84.485261,74.169376,84.825887,118.519716,143.759816,119.290556,49.624384,-44.406123,-3.541639,114.257864,-8.139346,-103.51728,-140.359843,-87.373314,45.914677,92.638187,122.487653,80.023133,38.769891,9.209926,36.862052,81.422451,72.234375,16.480629,-9.581641,-14.785049,40.1323,72.401719,85.065464,66.642207,25.771096,-1.366086,-89.806769,-146.665754,-149.838175,-137.886232,-110.978339,-38.914409,-25.683258,-22.056433,-6.724512,54.949998,75.32282,54.024072,9.316244,7.213497,15.937022,-13.475971,-152.032329,-150.974085,-86.852498,-15.281205,-27.914783,-79.457072,-81.872511,-59.342217,-65.012638,-74.507185,-67.889379,-92.034713,-180.036278,-213.93131,-194.406222,-130.045897,7.351689,23.555153,17.125493,49.749089,59.065539,17.828687,14.049613,136.522138,242.42107,431.414004,488.874246,476.797265,430.96588,386.786683,265.946295,225.836493,168.839886,46.030063,-19.699717,-84.788025,-100.948371,-156.800014,-172.639571,-156.466863,-154.171692,-167.871248,-179.147513,-210.59758,-321.203259,-355.092389,-343.05272,-333.169264,-329.502923,-268.984521,-211.851131,-83.894552,-38.951428,-12.745994,1.393661,89.448944,154.382341,278.090816,353.724878,371.600195,377.112476,378.407899,383.884941,363.551231,301.048373,357.455077,408.538287,435.525613,411.146301,356.756359,346.314865,315.161161,266.26936,161.632607,183.882485,232.095388,279.026816,242.353797,115.018696,69.251143,23.171633,16.618148,25.865347,80.337442,107.299995,58.42474,3.954045,-23.127428,13.529616,77.913451,74.08165,80.592965,48.251348,-14.375311,-107.105462,-107.003055,-97.729844,-76.463282,-48.234262,-56.597518,-115.464383,-245.646952,-270.057192,-178.927018,-51.347642,214.488876,140.267871,5.751221,-164.493256,-200.097737,-249.950866,-238.960009,-170.128096,-169.126861,-194.441843,-184.806047,-136.691307,-59.549302,-51.606645,-65.884074,-78.835673,-84.775125,-61.265889,-49.553126,-87.495599,-140.179311,-216.570833,-225.152693,-201.040247,-83.219395,12.197935,137.693341,110.475812,-66.494228,-143.870158,-191.266878,-177.440293,-105.035474,5.737789,56.249343,93.330486,58.936433,-86.667891,-162.041211,-225.050601,-129.520519,-65.273183,-12.977484,-44.132124,-169.482247,-189.044342,-81.874032,-26.334211,-19.628213,-37.391424,-10.275814,47.651636,38.015811,8.618249,29.56091,91.748231,79.168261,51.077178,-5.728249,-41.036771,-147.091622,-192.850846,-216.548262,-194.680662,-89.079359,-12.394672,-4.494773,1.083869,-2.201489,-33.571299,-54.572852,-53.735867,-9.802209,-25.922842,-128.63936,-162.997687,-154.033513,-128.837277,-93.892249,-105.1222,-159.033608,-140.852351,-84.414312,9.572888,-11.841889,-129.567014,-173.972059,-235.339172,-274.06713,-270.089265,-205.528634,-171.940938,-202.664919,-256.458479,-297.755989,-268.640723,-209.073957,-229.352123,-254.653651,-282.027114,-272.989824,-224.273734,-204.664624,-134.905549,9.123943,32.347258,-97.004414,-182.16523,-213.814223,-163.864131,-75.994218,-73.264119,-67.563005,25.651183,75.50632,100.678759,69.409702,8.39471,-2.004374,-6.38731,53.359728,101.06021,161.051719,156.49567,73.016478,26.452867,-11.003071,-22.91005,-49.402732,-21.3765,12.083377,73.41759,76.523475,16.965145,-12.413661,3.714437,81.89815,109.544306,139.053492,151.678552,140.877599,109.011906,39.721133,25.934598,61.412625,164.036566,231.388917,334.509746,319.692085,204.188782,185.33237,256.349909,308.921674,302.424658,262.052842,229.217347,157.786148,154.930719,249.947957,297.249196:-186.952256,-88.279818,-44.390671,1.502573,-25.232679,-83.226958,-59.526559,18.091601,-11.668597,-58.307878,-63.081219,-11.043626,91.116922,131.897603,251.99037,333.009179,422.001493,329.188613,268.249995,202.066729,174.805731,119.231493,111.181121,160.114461,186.778669,130.597475,-61.869113,-153.474344,-286.214607,-299.8481,-200.107103,-127.011939,-44.848384,-104.363168,-152.946753,-210.967582,-226.659189,-238.500081,-229.640159,-163.431698,-2.485887,77.899532,107.594901,63.836074,-9.51517,-5.002674,49.412617,64.351644,26.004357,-98.939488,-134.790041,-76.26887,-24.697743,25.87755,43.398261,180.469573,381.619021,410.33906,310.988422,250.602361,174.719699,155.786708,158.82344,168.542612,181.414355,166.088286,159.14468,145.067124,114.737484,26.042696,12.015981,98.433042,194.943629,189.686461,105.844342,73.030204,70.921692,96.463514,165.538921,172.688718,76.0993,-91.166842,-127.475768,-64.858765,-23.305593,16.31089,32.266577,36.679851,-26.703621,-59.906701,-48.761749,-10.000248,39.090668,40.195876,33.086337,46.367217,85.702678,25.643386,-0.604012,51.129439,94.869386,143.014871,162.094849,231.510087,259.551611,234.494916,157.672708,120.674713,58.747183,56.34373,88.710378,78.071674,54.708469,91.14231,92.527042,58.49574,26.673453,-13.826599,-4.872383,-37.413099,-141.260913,-168.971628,-211.055543,-243.678491,-251.083955,-192.63757,-49.086217,-30.532882,-94.794619,-117.845707,-81.326382,-3.393387,2.172695,-36.610791,-85.371369,-247.283777,-279.161674,-222.103994,-105.74279,-78.820668,-75.202451,-60.765419,31.143585,81.426838,175.561196,204.342175,146.222082,-31.460107,-79.167476,-52.228378,18.426182,236.180762,408.158488,443.154424,398.02974,325.244734,175.039468,153.697775,265.641247,358.222819,501.50311,552.861722,555.155335,523.878218,476.707323,330.596169,261.056739,178.717661,167.008742,159.806566,91.488098,36.771281,-44.924559,-42.719289,-14.689045,-39.270395,-152.253288,-244.996834,-276.164657,-366.155742,-409.800893,-382.397859,-343.381044,-352.477227,-329.212894,-274.427594,-165.859141,-138.833389,-174.640096,-203.665852,-142.892609,-46.583606,113.532056,69.604713,42.526606,131.208869,188.497083,169.847461,116.174856,68.73664,146.053224,182.411486,168.248535,127.122631,80.776285,109.434405,178.333367,151.286715,30.493579,43.054023,95.160083,141.222139,117.112531,63.8693,53.41694,36.71632,53.132911,75.724847,108.672733,105.414591,65.030947,57.822701,110.842722,150.252019,195.998955,194.265842,194.23311,195.605806,168.54986,97.553097,96.541275,126.784216,154.290403,165.749453,126.068208,74.311176,-14.380541,-12.394854,111.662681,228.719767,500.706962,449.308907,262.152222,-44.780102,-64.786234,45.573939,100.295868,156.013768,194.790109,181.037625,112.398634,119.498465,208.862376,227.490727,190.399603,186.044755,232.333595,215.862149,170.514954,75.129296,28.489003,-63.802297,-95.655573,-106.310793,-17.759484,42.924575,97.239441,77.646078,-3.217275,-29.807756,-25.113317,-13.32391,13.316904,102.770443,171.935272,208.863266,133.399161,-88.568384,-159.298235,-157.198876,-60.328706,-37.12197,-25.852,-15.149123,-22.656974,-24.761974,24.692757,53.809982,96.781753,108.771034,108.243118,126.326646,112.686556,51.773768,66.994668,176.863748,190.757858,146.472309,46.605557,3.028487,-105.490726,-144.972832,-122.579256,-82.867935,-18.471004,-27.072439,-49.140954,-44.13378,-33.753284,-106.14844,-185.302072,-296.727791,-254.727645,-221.829737,-207.613916,-204.895125,-200.882771,-216.670968,-271.508328,-286.784964,-215.123957,-79.467151,-48.153975,-67.334293,-99.2792,-133.038573,-142.09627,-228.52529,-305.993523,-292.484878,-175.919031,-126.668165,-202.070603,-303.175359,-406.037364,-371.462274,-243.346179,-215.551207,-245.045059,-282.582324,-274.685832,-257.713187,-267.877919,-260.848395,-105.501997,-40.198007,-62.916949,-110.755927,-180.20959,-208.963534,-285.271814,-306.215522,-237.730328,-103.747443,-48.225357,6.803389,-7.748058,-63.959074,-74.225069,-54.278192,-22.489801,-36.66916,-121.245964,-152.001332,-169.731891,-176.359755,-204.694553,-222.595727,-213.387187,-159.943328,-148.690148,-128.579318,-110.278981,-89.716831,-92.841259,-73.596553,-3.750855,28.043258,111.22331,143.050912,42.315691,-69.689434,-213.018885,-212.72601,-130.870004,-6.766739,62.182385,138.813202,135.909775,145.853342,166.594214,161.262534,148.675387,161.16127,149.404952,121.462844,146.016224,218.337168,319.78361,302.984796:-200.477327,-176.670681,-137.864595,-19.000394,24.057892,34.375268,20.046672,28.092003,18.819552,-32.124253,-100.232337,-79.055197,-8.020722,26.79277,103.01536,129.46775,134.246757,49.179864,3.1269,-37.729968,-49.116763,-65.190165,-62.459758,-19.276585,-9.10653,-53.941306,-181.074163,-218.253363,-204.709027,-183.872103,-177.765787,-164.820564,-48.88176,27.00569,3.486459,-59.780715,-59.625258,13.121115,53.976276,121.251626,252.959144,297.304536,209.863905,104.355491,-71.719953,-97.083294,-40.113559,1.542441,46.417061,-31.903153,-87.226948,-86.499288,-54.112556,4.693267,67.76824,237.881052,304.104369,280.693587,177.956773,144.196495,154.373483,165.316042,115.169356,65.17445,31.489858,92.34849,109.576069,79.003391,30.321192,-55.629612,-54.628429,2.005793,31.808554,33.606551,80.896004,113.890045,78.581612,36.46871,54.974123,91.289099,101.278472,57.916861,17.671717,-102.821703,-141.883578,-124.068299,-99.231044,-43.108788,53.258911,72.331735,-7.033818,-67.383397,-104.813814,-62.526922,48.5851,71.136213,46.679198,-105.463464,-219.520412,-321.283375,-267.156701,-140.761248,-148.673186,-197.991745,-135.503979,-107.587242,-57.140729,-7.077205,45.299001,42.730431,71.52333,87.111777,72.692357,1.801594,-37.418824,-58.639368,-40.268442,4.567283,1.689955,-52.77437,-37.829891,-17.729689,-43.144043,-72.209163,-102.629761,-99.279253,-41.83855,9.657164,82.789667,49.696138,21.141169,0.99038,6.882368,14.858423,1.143069,-55.083678,-37.866781,-5.085432,26.62293,27.350034,4.788716,1.037709,93.044965,163.753169,213.75,139.072312,87.467787,-50.567722,-121.078972,-143.5739,-89.007318,21.070049,26.835196,5.586566,7.005755,36.694014,79.568242,92.494219,197.695343,307.217545,519.211691,529.944721,479.444388,355.243636,279.463712,150.812186,133.646479,161.97494,123.307427,48.735179,-149.468396,-227.061009,-267.118834,-223.823219,-97.804449,-66.660924,-68.860852,-47.434518,-42.255828,-110.953387,-160.165864,-218.573468,-228.289301,-180.058782,-83.488343,-67.944499,-56.800335,-15.863422,88.462801,93.361436,57.98846,108.712593,329.251419,391.725376,355.341957,316.481179,333.543293,332.302739,287.238731,236.447377,364.078249,451.513487,539.140454,514.714222,395.764474,344.888351,329.928166,364.545064,398.170546,339.465599,320.013797,251.926829,169.315417,24.150629,16.696954,76.537252,95.715299,71.824254,0.276471,-11.295018,26.268964,48.683734,64.838163,76.94606,121.98216,108.072805,70.571328,-32.990934,-78.401509,-102.566862,-90.372908,-60.799497,-12.050687,-8.711635,-84.679408,-130.067772,-187.666624,-208.634027,-182.521094,-107.167935,34.437016,-95.344875,-208.369304,-279.695721,-244.319085,-164.663192,-148.032491,-214.030143,-309.473179,-299.746509,-173.899114,-104.242906,-54.514999,-83.775407,-151.921945,-134.462483,-35.143219,-28.083845,-38.279613,-41.596732,-63.01151,-142.368536,-181.881616,-188.559645,-76.426489,-46.241351,-77.795954,-96.957675,-118.806071,-141.834675,-209.63651,-210.312838,-105.501292,-43.019034,-43.115557,-4.548795,-3.018049,-151.19611,-245.559733,-272.825529,-114.903787,-57.477199,-88.284396,-158.210837,-272.542954,-260.149975,-120.396289,-58.58688,-10.281984,-7.892534,-5.371372,17.770805,22.915446,14.731898,37.966143,146.133808,156.420207,99.693191,-61.26874,-137.250767,-248.578601,-275.503686,-255.76334,-208.751492,-91.539825,-75.520843,-98.746407,-89.32754,-65.032868,-87.972651,-121.248039,-115.518266,-89.723801,-115.660225,-160.728231,-175.675002,-279.103369,-328.145042,-311.804058,-274.352558,-169.877532,-78.367246,-97.697365,-200.234152,-232.662997,-276.025788,-302.915893,-332.684926,-317.051545,-317.948034,-270.407514,-194.323323,-93.686347,-110.707967,-151.723261,-141.167169,-128.637384,-186.971153,-222.126888,-294.57557,-325.578394,-317.268526,-280.910789,-179.280133,-84.94504,-82.032265,-168.734023,-238.590723,-348.375518,-328.77107,-174.269472,-116.533171,-35.519967,89.597866,134.403381,93.192472,26.247551,-12.614219,33.753437,98.986339,67.075627,64.9677,103.555242,99.939425,34.071795,13.069092,-7.766618,-33.733003,-110.42769,-141.895102,-102.261609,-8.434211,-34.691841,-188.940058,-211.294127,-41.738514,137.373791,138.489431,67.856924,65.10632,79.622871,67.111752,59.101571,59.304384,77.132934,199.252792,257.143832,282.61226,261.269194,220.920436,233.870854,316.180428,312.629738,249.784166,138.390596,136.141235,172.459194,181.794012,178.319581,160.27795:right
-29.07797,50.89185,48.327995,21.661783,21.325447,-24.207268,-61.51756,-96.224823,-109.370662,-114.447144,-156.099094,-193.152049,-264.646604,-311.434205,-439.184502,-489.247089,-491.348564,-426.258722,-413.859367,-430.529207,-440.656276,-425.717978,-383.367354,-253.513841,-179.231193,-165.378743,-152.83114,-165.658331,-284.639408,-372.46897,-438.683931,-402.291996,-332.785364,-305.470464,-284.827499,-248.95417,-261.470788,-344.961367,-356.727324,-228.29497,-48.702576,13.510312,55.033523,28.777556,-38.928985,-42.667776,-6.408715,12.201292,83.372101,232.781124,288.066363,251.362682,173.859331,45.925645,49.753629,185.548582,285.646484,281.577291,201.614813,160.648383,114.048894,69.377258,-80.387998,-116.746618,-33.675554,35.600231,-8.709963,-131.289817,-138.876581,-52.807773,-16.573631,-69.633363,-126.582316,-87.207092,2.833443,0.855187,-68.675218,-111.075948,-156.095247,-137.791127,-22.641914,178.060534,272.707556,320.161502,268.743578,137.824115,111.17783,103.137372,33.671544,-4.543765,-50.387992,-64.367843,-77.889771,-89.969223,-151.431962,-198.104583,-222.761407,-40.328601,66.825271,169.990672,170.066554,107.908018,61.646122,-23.61062,-13.982345,50.749248,155.417023,147.707054,68.466533,20.04672,-45.517483,-47.263495,12.199594,131.497416,186.279585,204.33668,163.491696,112.819201,147.572049,234.714417,213.531453,186.419153,105.671135,51.556846,-37.288165,-74.109659,-150.818155,-176.077325,-148.806256,-52.28622,-50.143437,-151.408335,-206.833311,-315.546259,-367.236131,-402.276074,-337.529913,-294.714921,-223.854404,-193.973618,-217.553214,-284.927825,-357.92671,-302.226766,-81.766106,107.940052,138.044779,63.264615,11.967807,-42.909347,-43.756542,-10.214694,57.463552,134.40483,349.942669,433.086322,426.313215,341.71769,177.941447,145.650683,165.630899,201.586212,181.688122,82.992466,43.758414,12.467414,9.703317,17.04483,12.113394,11.725962,2.05567,-20.544746,-73.869058,-96.640448,-86.925432,-27.343088,168.003869,326.680973,361.873541,361.184051,339.205882,277.803761,266.126574,278.911743,265.117174,273.702536,343.582619,370.721535,345.306842,294.697681,183.629894,150.355986,142.783248,231.872367,304.906452,400.831814,374.51475,212.858606,140.313826,86.624252,80.846744,73.028165,112.262298,150.301961,114.682495,26.367116,-157.357012,-208.063669,-220.349063,-153.797847,-111.461323,-42.235539,-30.914598,-84.781313,-140.17911,-189.376585,-70.761299,-11.413594,-16.362938,-57.324144,-166.07908,-234.834886,-318.578429,-306.957612,-189.728151,-18.129984,14.980591,-86.439813,-159.717356,-178.667386,-116.750132,30.688265,90.148272,95.504748,131.772027,172.24692,233.604048,222.64444,188.111448,211.052886,280.111713,206.553621,106.125532,-15.223528,17.042321,91.472053,80.652677,58.726311,82.766638,104.159047,155.8933,163.964974,126.099865,105.627126,139.042166,164.059477,124.911087,116.291301,162.005101,232.179495,191.909294,-23.573561,-103.058253,-91.963815,-26.836192,-14.370613,-80.40463,-164.844223,-307.899679,-328.560122,-314.875965,-296.55754,-244.570308,-137.429927,-66.056719,6.243905,-3.807933,-32.46919,-17.521264,39.938648,11.073127,-4.400073,16.495047,8.375031,-95.676058,-165.378857,-218.786306,-163.917864,17.846591,53.365637,-0.418867,-99.429471,-93.39274,-32.699309,-17.312078,11.571642,123.577024,199.787367,271.86164,255.346022,176.207849,110.109743,-63.17338,-126.363776,-142.004452,-55.704102,2.690675,75.498523,45.890843,-129.638981,-185.84276,-100.488397,84.771477,147.208829,161.180937,110.245022,-64.602692,-153.053189,-253.246813,-251.040329,-171.157834,-76.657063,-44.727711,-67.713186,-141.59894,-308.030397,-320.633544,-188.249766,-77.669187,-77.252514,-123.853437,-140.794044,-216.44866,-294.037799,-395.708387,-385.397514,-295.441101,-159.942236,-125.233357,-214.410287,-310.199791,-462.114657,-461.806536,-292.033927,-130.508674,-95.795493,-50.897082,-43.882745,-85.832504,-102.564165,-35.893282,20.74388,86.825172,92.541021,74.026421,86.433418,109.09312,-0.490238,-119.191316,-225.008733,-64.063194,29.928329,94.71613,84.30357,40.096498,0.01743,-18.547046,50.55772,262.237005,326.68748,276.646017,134.324705,84.382795,33.914698,30.324821,57.268471,71.605891,77.684155,93.687634,92.937687,10.036808,-82.209293,-189.883286,-153.570239,-30.786555,58.756291,93.217705,119.750864,112.213667,63.585042,30.562436,-45.862825,-59.545192,-5.397897,110.480532,116.289829,49.02969,-12.523115,-142.802904,-150.463617:-19.474456,-78.618932,-101.409556,-72.324388,-26.792822,21.880282,9.605003,-50.555416,-92.472786,-101.559543,-124.51365,-165.686731,-364.050634,-478.737694,-597.115636,-615.728326,-599.049687,-510.851824,-503.953144,-583.1511,-607.008677,-525.102834,-438.615902,-290.364434,-212.007676,-193.722293,-194.475477,-198.262862,-242.026437,-290.473464,-341.77208,-320.842206,-237.474105,-187.617095,-193.867556,-241.901852,-282.390139,-349.129358,-321.778147,-94.012605,154.526342,189.588861,70.449891,-11.645889,-78.935379,-78.721471,-70.145639,-46.298877,100.004283,251.902385,244.62586,102.018753,29.988434,-20.866271,26.738124,195.767571,236.245181,206.410343,118.364771,57.119635,-46.792391,-59.836383,-63.40678,-85.000833,-73.000811,50.708362,54.583751,-118.835744,-220.610323,-284.488298,-226.50059,-56.047354,-44.855751,-69.073832,-45.410642,-32.750582,-128.036135,-208.507353,-275.641032,-242.441305,-80.568088,89.0268,99.170916,-30.973085,-98.366086,-115.030052,-89.372688,-57.534736,-3.387261,28.242469,45.722922,28.180729,-69.677746,-118.993406,-104.317261,-68.975827,-52.020529,-53.367583,-45.441982,-13.416517,15.044285,46.867609,43.948251,44.985488,69.162031,81.999097,35.133293,-33.374476,-148.402403,-150.18925,-92.901981,-84.201253,-77.233292,16.20999,60.246578,70.086873,59.303194,58.335753,66.790148,78.124947,63.73203,41.691222,-17.449233,-28.431884,-86.355011,-171.93024,-294.773851,-286.661917,-238.523529,-193.185498,-173.493138,-178.93361,-212.894429,-331.159348,-361.885991,-284.701571,-151.458821,-116.424762,-146.630079,-187.809831,-254.062561,-281.688172,-297.413036,-253.611133,-51.666785,172.233658,226.53553,177.445343,101.237126,5.856949,43.390221,177.639059,237.790217,288.550274,439.240787,478.028621,383.971264,281.719466,160.324854,164.899169,187.172585,159.808435,144.219328,82.673604,15.475781,-89.635655,-72.19717,5.671562,-42.428701,-83.657152,-89.732752,-63.576143,-79.483403,-135.530641,-172.054338,-92.383895,138.139384,218.681931,214.939262,264.077463,325.031784,394.785395,381.998698,325.689696,301.964944,317.311602,351.202862,342.923441,300.383298,287.182392,274.155604,270.487107,285.126021,353.122192,384.58854,319.301715,205.914745,-8.065903,-25.57322,54.791313,102.73716,100.440876,60.169612,48.703851,14.140382,-41.385101,-162.946236,-194.31702,-170.854878,-99.890355,-98.233088,-124.95346,-140.629818,-190.691916,-197.345309,-168.801413,-153.176263,-133.012356,-92.152009,-95.448745,-141.284984,-175.803408,-230.430569,-221.357138,-117.235878,-9.161905,12.023373,-2.283229,-39.346852,-149.936439,-164.077622,-68.957331,15.761721,28.152727,28.567026,23.849355,35.317405,61.433857,110.157325,119.339519,140.316349,102.625258,26.718207,-114.695161,-126.910346,-84.717681,-56.969001,-2.753539,26.602846,39.937981,79.433824,98.52736,97.833292,85.026362,119.688833,168.035021,211.118534,162.253276,141.324535,118.320561,99.552758,29.056093,4.003162,11.72341,17.158756,9.191088,-18.095698,-46.975234,-109.456399,-125.46936,-174.956489,-218.466964,-240.985745,-99.4919,-18.337439,18.856694,-36.732634,-186.290521,-204.135955,-88.553909,11.249034,27.014219,27.898942,-4.964366,-148.568398,-209.329664,-186.348415,-127.939048,-57.011384,-66.401399,-87.164718,-109.647282,-100.843267,-65.157132,-30.506199,78.230006,186.249612,215.710284,210.592996,193.227976,116.561885,55.06206,-26.995644,-29.911663,4.854616,6.984003,-13.035355,-60.480277,-97.394633,-172.30777,-167.808262,-50.177423,68.85498,80.778376,-10.802693,-75.077285,-106.954433,-85.809227,-61.609742,-64.82066,-69.574623,-11.075013,15.286695,-36.652234,-108.506569,-225.783194,-224.950403,-136.120287,-50.477741,-21.963533,-17.985949,-45.724701,-150.120111,-211.519499,-260.992798,-246.975011,-220.194043,-171.531109,-140.12211,-179.863008,-249.409897,-368.601539,-384.618514,-313.823655,-192.243919,-143.546667,-54.624557,-7.919878,33.586507,18.734791,-3.318446,11.127305,128.303294,294.850876,306.560416,198.398197,148.63632,69.704765,24.177928,-7.717291,92.884761,153.959877,186.571531,149.839764,29.311008,0.119431,122.906008,233.843313,348.197258,322.662951,295.135959,188.963902,116.208652,44.579844,60.069122,81.592106,59.23428,65.063292,105.04946,129.847276,119.053581,53.698212,-106.298357,-136.835913,-61.0762,68.083406,96.760987,100.897587,90.896216,6.672645,-44.268903,-46.298878,44.336275,61.155487,18.135979,5.702973,-9.788522,-61.914889,-190.664341,-192.192844:-23.636576,-4.899706,-57.217508,-124.290057,-118.485955,-90.539043,-77.352132,-47.596402,-9.425949,-15.135863,-145.661699,-248.063394,-417.298915,-460.27787,-495.837115,-504.815789,-489.397501,-458.192983,-457.683852,-474.213132,-477.315286,-441.849143,-387.066527,-218.861792,-61.118474,-36.614294,-116.559449,-160.960685,-211.363027,-243.047662,-288.755973,-278.437516,-147.438811,-18.950849,-56.8735,-253.346318,-340.989656,-405.705342,-350.028595,-117.174607,65.90483,101.473715,63.164399,-0.533856,-143.68566,-174.042856,-80.375836,21.441986,192.194871,180.766716,114.628173,-11.673851,-48.311102,-65.516559,-44.827755,10.909255,66.319527,90.782846,54.96239,-13.45898,-156.100734,-182.782578,-132.008369,-96.324183,-49.909732,10.206144,16.310127,-66.939025,-129.973685,-219.637814,-219.93119,-132.227905,-32.532368,-14.590933,-68.581571,-120.848203,-200.536462,-211.546074,-210.450474,-223.439605,-184.851183,-24.75608,-8.772833,-166.449072,-259.957262,-329.91024,-297.79768,-130.26748,25.590985,35.611405,-53.801299,-109.322513,-170.699369,-157.358907,-74.513781,-63.39128,-137.056344,-164.888507,-160.332311,-138.05274,-97.159107,5.491527,47.322807,101.796907,60.942065,13.851062,-66.718806,-101.973232,-189.418001,-205.857396,-111.668362,-47.278998,30.905591,18.501074,-21.28651,-52.696258,-40.986897,-61.843399,-87.273737,-74.670078,27.491834,50.615826,-17.675295,-57.019793,-99.763933,-138.014092,-199.753757,-197.975062,-195.46398,-213.537371,-229.407422,-258.513186,-259.802376,-285.767665,-327.367056,-362.97843,-192.570167,-93.599057,-84.305554,-159.563561,-300.410609,-333.359796,-275.915786,-180.467685,44.524031,141.392162,125.546845,32.776051,-21.764332,-41.441662,26.826748,194.640378,244.092212,240.670341,259.500473,301.627444,357.377652,325.454991,211.282604,164.063283,121.548886,125.922761,115.736643,67.221574,25.205923,-46.313526,-43.325357,-10.067034,-13.554919,-14.280255,-41.991216,-93.132178,-191.617373,-174.13334,-17.065223,62.354865,153.489536,161.769794,159.314326,223.805985,286.992238,391.384195,414.888304,419.721185,412.223977,417.454027,432.398509,429.685199,390.525223,360.449433,327.911691,328.797633,343.836292,386.075854,389.982273,315.320797,240.083313,79.430085,49.96785,100.237837,142.116332,126.147092,49.518311,27.210954,19.641737,-2.922801,-75.006868,-89.124665,-52.064257,22.41155,38.103176,3.547624,-38.323698,-95.030236,-78.99318,-47.663612,-78.931613,-88.156156,-90.541356,-83.101315,-110.474738,-158.671065,-194.567222,-151.049034,-4.102928,87.887586,67.754757,-80.958459,-139.577499,-111.39239,-70.49973,-68.229374,-57.618706,-26.093175,-23.67496,-54.060582,-77.137706,-61.867564,-16.609652,-1.512047,9.432778,17.436437,4.160424,-60.10697,-83.411124,-69.912716,-47.019385,-0.619964,94.228604,137.809758,96.425653,21.95426,-72.341823,-45.673032,105.061998,156.589998,134.060988,106.554547,91.89932,-12.502541,-62.061594,-61.684644,-27.50492,17.391052,8.370047,12.848959,0.968922,-42.27239,-112.523583,-104.32369,-110.913693,-146.880957,-128.894424,19.01449,42.717414,-62.776002,-145.620006,-273.630268,-273.329569,-118.795493,-3.06129,1.549912,-19.636807,-54.34608,-187.485308,-235.340851,-203.03157,-165.249434,-144.445802,-139.90936,-133.971951,-129.502633,-132.959386,-112.746946,-66.806812,55.822998,160.511191,207.375565,265.440366,258.732291,133.305506,36.553657,-83.289776,-93.248123,-52.693086,0.126529,-24.17951,-121.724445,-134.461361,-99.646477,-78.673648,20.527391,182.925516,206.004578,82.030585,-7.579165,-122.542387,-132.812222,-74.885789,-40.850116,11.499906,66.309896,66.783319,-19.499553,-83.160118,-140.028108,-103.620208,2.071693,31.63352,40.733005,38.023443,-2.74973,-118.279916,-147.039352,-128.968303,-105.306242,-37.62509,14.310952,-28.114563,-203.531143,-260.243424,-278.65589,-256.127436,-164.182884,-88.022972,-58.933972,16.845038,48.472939,9.087889,-41.071628,-44.869923,21.022141,228.280232,329.789705,286.220337,190.686615,180.274777,77.609781,-22.386157,-121.396203,1.379887,77.703896,73.93751,4.748522,-143.371797,-182.113142,-78.992846,42.649379,226.233231,210.780998,146.64945,27.887547,7.684027,36.669129,60.043804,37.672289,-1.215748,17.749333,37.993929,11.678149,-32.358998,-26.869781,-32.636398,-71.387735,-114.626454,-0.880604,51.543294,21.707862,-35.973139,-116.039765,-123.651711,-92.279051,2.025125,43.536297,15.079612,-34.469226,-107.961385,-137.414173,-159.125165,-116.920822:-64.532757,-39.171391,-43.135215,-59.95489,-75.627246,-105.323047,-94.418546,-62.462692,-57.200939,-43.066716,-78.076242,-161.614758,-363.940068,-426.293886,-443.223037,-435.692324,-463.664344,-465.425897,-449.534883,-460.514141,-481.747025,-466.919674,-413.306874,-272.15182,-119.592082,-48.111773,-53.355102,-133.11053,-319.762978,-397.546471,-432.938545,-366.176141,-177.718993,-102.337063,-139.25445,-319.074618,-415.707832,-495.523258,-446.582557,-238.866652,-32.001218,23.43807,-25.973766,-82.808714,-129.242784,-120.483664,-82.202554,-64.548905,-15.227989,87.731372,118.102188,73.371635,31.695954,0.417773,19.592836,96.835399,159.979596,170.313648,135.336623,93.057288,-12.523677,-57.68248,-76.054279,-46.627923,-0.166686,-6.228918,-8.699885,-53.650876,-104.570511,-163.102725,-135.445123,-40.243649,5.084609,27.644132,76.844185,77.808055,16.158211,-31.953959,-112.900609,-114.428457,-12.938537,103.905563,117.656331,45.18801,-26.287047,-161.184403,-172.655284,-80.155528,-63.146255,-90.039718,-86.512031,-73.925367,-141.403868,-204.711623,-240.727071,-221.513774,-213.78532,-130.170149,-32.528084,162.378233,211.904774,156.099432,76.013705,-24.41377,56.432288,117.503705,105.264386,38.999056,-74.035937,-96.570564,-56.135491,-11.038326,37.384484,25.255163,10.175259,1.798149,23.182906,73.498618,79.713008,82.965033,148.637153,161.001544,50.991357,-25.951472,-122.728114,-160.446604,-216.016263,-200.084251,-96.637518,-51.30232,-81.713423,-187.466826,-223.650442,-278.897211,-315.632956,-342.612995,-258.376202,-213.225464,-157.682172,-137.997527,-172.283681,-242.706548,-366.381871,-355.668838,-174.034979,52.7113,96.957848,-12.531349,-98.998126,-115.713363,-35.579277,119.408528,181.286335,236.063495,364.521086,397.026573,380.8748,335.175502,233.669893,210.357669,245.462137,339.594802,356.661594,272.530727,196.439519,93.173687,92.177322,99.873363,53.247974,54.130139,74.696699,57.095457,-23.269812,-41.706195,57.416919,144.205095,263.550707,288.648802,297.488876,375.104334,423.400621,472.522874,482.559641,488.619055,481.082713,492.674558,525.351316,517.1428,442.947212,403.133618,370.664534,380.573086,450.521008,503.39108,482.050952,381.683709,319.210291,189.590181,152.322858,169.578469,254.57273,297.628463,286.269043,234.174026,99.874215,17.520292,-96.990796,-104.656149,-69.929903,-52.047553,-59.120753,-35.074303,1.952484,20.179044,-24.165722,-147.361206,-115.852697,-34.538088,26.103664,-35.043159,-209.773959,-261.901339,-245.472187,-189.550723,-39.304599,67.840862,70.286421,-20.609998,-83.087638,-157.604412,-143.745059,-69.582709,-74.387837,-82.210801,-43.9858,-18.995878,3.791815,3.898657,27.782105,50.481145,47.806235,-1.260631,-30.604237,-67.565188,-46.428289,28.14793,41.790094,45.660626,137.265639,188.112627,146.981036,84.684989,62.009857,108.343817,193.600089,179.67149,55.68473,42.779605,98.989175,159.129519,123.989341,12.375382,-27.633795,-72.039338,-45.035343,-13.6813,-32.679595,-98.382753,-206.296185,-206.289507,-161.267274,-145.569544,-92.805093,34.47287,92.435635,123.579166,82.717179,-68.37514,-107.858926,-25.762632,93.378974,106.992172,42.364502,-23.755438,-194.943248,-252.151654,-178.564967,-84.252724,19.244361,-46.05599,-104.389929,-166.902026,-144.033818,-19.439927,37.708175,65.521714,96.123519,147.672912,197.267991,164.378653,43.316509,-9.991801,-59.420938,-60.554586,-21.806167,65.833859,87.132016,11.731644,-64.522589,-190.679501,-195.874412,-51.247943,121.171652,160.34351,127.203452,70.748616,-31.125188,-63.233463,-112.783899,-112.593657,6.192371,138.615904,121.430485,-30.116239,-104.625091,-187.442411,-180.312408,-74.286666,27.260335,29.351231,-52.552152,-102.287172,-196.629322,-253.3091,-301.466252,-254.139728,-86.112943,-23.426968,-67.572404,-197.198618,-242.472768,-319.585115,-351.303445,-352.555624,-259.033396,-184.101858,-60.809466,-40.978306,-65.243151,-99.619465,-145.762885,-116.746873,39.202349,158.679178,132.804554,-23.693222,-78.015467,-157.298156,-215.890449,-287.982986,-203.523769,-138.535997,-113.245669,-160.141532,-247.360835,-250.057084,-150.848295,-62.070247,68.891557,33.479492,-21.29365,-87.663041,-89.761971,-87.879754,-83.421218,-68.874969,-41.257623,-6.804798,30.700742,-2.102638,-126.345671,-164.906511,-152.474624,-141.249182,-169.5954,-136.359846,-75.948122,10.359581,12.504651,-12.760882,-24.775993,-68.987314,-91.221096,-69.064451,-48.885233,-77.530995,-167.227044,-231.565199,-371.766777,-367.277834:-42.650189,40.485517,11.018062,-106.763562,-140.7301,-141.334479,-115.536767,-38.432868,15.524179,5.302001,-85.387592,-146.593956,-305.794353,-375.737149,-376.157557,-329.586479,-297.250221,-373.823637,-426.303877,-502.996071,-514.236008,-443.266876,-360.143389,-187.644433,-49.151375,-2.112414,-1.128486,-50.252738,-229.173956,-312.630821,-320.200533,-256.230526,-136.50886,-74.047732,-76.059544,-229.063004,-364.502819,-522.015507,-475.059749,-221.569771,23.242018,82.197676,3.212539,-100.57219,-277.667289,-308.767393,-230.089293,-151.961511,-16.150264,50.187212,36.981237,-70.295445,-130.122253,-183.716329,-160.810334,-46.816777,75.004352,114.274253,82.904604,14.626298,-123.937755,-144.438624,-78.143407,-36.27264,22.860684,71.810433,60.728989,-73.673769,-149.829939,-181.516093,-141.574894,-42.221366,64.987069,104.744167,65.922336,4.758998,-71.211307,-76.338731,-83.166991,-76.323032,16.943913,60.99299,-11.08093,-216.726322,-279.942055,-330.297611,-324.429533,-242.172319,-75.824726,-17.747726,-112.64326,-219.521565,-309.928841,-283.266001,-212.429356,-187.277095,-102.224453,-20.545515,-6.312913,61.56787,102.881629,64.264594,14.999298,-21.767068,-17.032877,-1.776526,-0.461081,-44.243124,-154.442875,-178.691311,-137.821409,-80.739584,59.450033,127.705498,100.628647,-28.9713,-76.299138,-86.861467,-72.852593,-26.850348,95.126729,146.195127,104.490997,47.404255,-24.860423,-44.306295,-48.411936,-34.021472,10.912046,66.101567,48.935527,-120.222904,-215.229944,-270.378124,-239.954385,-214.44323,-245.948175,-244.686302,-200.789535,-171.148982,-204.797258,-273.383844,-314.798983,-238.885013,-9.518623,116.224527,116.383895,-2.657877,-109.559477,-227.02665,-178.843346,10.62799,172.938886,216.579544,182.18668,145.366917,115.872516,116.471683,119.048196,110.220137,135.191719,221.210127,222.290074,152.537417,114.031329,48.183307,25.20696,-14.800022,-9.628349,28.252995,58.132955,17.929458,-79.117842,-80.015278,51.871978,148.65845,291.183787,293.142251,277.06967,333.332385,378.228497,397.279095,399.920463,484.863695,585.461145,589.678716,508.076252,450.404702,343.163487,308.797506,315.600434,345.636162,442.498192,502.535956,466.832583,307.870168,232.219317,147.724003,135.799504,138.853287,185.553699,212.958989,195.44459,159.036458,34.488939,-48.83506,-115.447849,-90.959011,-28.622947,31.32766,49.592581,41.430137,22.567014,-21.862857,-34.076572,-15.320644,62.138043,92.594989,63.442343,7.675089,-134.342638,-165.156962,-77.11535,-13.601534,91.020962,196.599555,213.826796,146.506866,78.981837,-69.607546,-106.091835,-32.657043,92.330888,102.331265,58.700084,54.196457,47.598563,25.931714,54.99073,121.398843,224.089279,188.69591,128.379386,15.075294,-2.596755,-4.889753,-7.291454,62.405953,250.012708,295.526482,155.538208,39.832691,-58.652593,-32.514898,113.229938,194.695862,274.357139,247.010957,194.29818,57.352219,9.799418,-22.252376,-14.1195,27.004499,63.591849,74.704629,82.112359,69.051589,6.618316,-11.390672,13.054943,34.781151,103.048442,176.606711,174.280528,120.174099,80.712348,-16.753504,-26.655127,92.967989,244.314604,269.573256,169.822899,74.169949,-70.428954,-95.935159,-78.928796,-46.383386,64.767884,118.533439,80.392017,14.218313,34.184557,88.138189,91.203839,98.390103,164.996215,221.062863,298.361959,268.860842,91.462552,12.654208,-20.118031,2.074016,51.114838,118.807445,126.82494,4.158704,-90.207411,-177.283639,-157.365357,-63.821628,51.017373,89.499053,92.985149,62.889139,-93.856025,-185.460371,-185.478309,-88.841973,109.01607,137.608596,73.86357,-92.665498,-141.06528,-147.481632,-117.685849,15.095624,200.967623,243.642583,153.842123,64.194859,-93.235401,-143.066879,-126.075751,-54.682021,98.531974,98.415898,33.093814,-99.606374,-137.965949,-204.566203,-225.271951,-185.477043,-47.98094,26.984457,85.72635,66.044939,-20.31042,-70.571954,-129.60508,-102.381269,108.889029,252.35723,190.970034,-12.620607,-62.222473,-150.642009,-225.425834,-288.758631,-134.264062,-46.842325,-38.633016,-114.030903,-290.045465,-325.743543,-208.800012,-88.169254,119.485547,134.843885,73.970196,-42.11196,-77.905578,-101.491972,-71.908666,-2.773734,-7.779492,-18.452954,-19.422947,-15.325172,-64.533267,-114.823098,-155.362298,-129.585668,-54.285482,-34.376024,-56.41536,-108.934122,-110.841467,-89.90854,-85.340619,-69.181418,-33.892174,-28.424752,-32.430079,-28.977562,-103.135253,-200.362505,-332.949756,-305.59197:-145.867958,-73.551987,-49.239829,-44.502939,-38.58788,-15.491568,-7.694778,-12.230275,-49.187412,-73.566191,-136.270148,-165.565846,-183.716022,-185.686059,-239.254566,-288.838625,-341.185637,-276.478034,-240.454652,-270.508529,-316.013941,-321.916307,-272.700082,-142.885325,-26.749993,8.913948,-17.21281,-62.449328,-158.067768,-227.781481,-358.947961,-365.327242,-241.307953,-114.853205,-137.465379,-285.313118,-341.476762,-402.691386,-399.96689,-255.711205,-72.486094,-31.13621,-53.388356,-97.340462,-159.755818,-147.168808,-49.154589,9.80475,121.104852,226.905155,241.65281,137.62964,73.327136,52.873472,95.567258,244.225447,316.530341,264.440734,105.346152,89.205097,132.719382,102.941627,-15.71298,-26.505735,47.158011,59.968057,0.523225,-143.885398,-168.422936,-125.430252,-70.231703,100.997855,210.295966,213.537719,198.809618,200.483539,159.283735,104.644671,45.316741,68.040945,153.780256,214.303674,200.941326,127.058002,109.2396,107.861174,114.979592,114.347559,56.587796,27.964334,-95.851742,-200.953887,-323.248495,-295.602633,-148.849784,-104.1063,-95.018968,31.243431,142.557403,304.368597,321.808956,231.22714,164.708936,78.417106,83.792918,139.557301,223.536844,182.526623,-5.130822,-79.623462,-75.769682,-4.283795,145.727956,197.113806,199.671841,205.209026,204.130817,194.681946,204.568004,257.055157,296.282649,287.719888,187.96633,124.33949,61.417278,48.710921,1.727562,-19.246144,-8.246822,86.779511,119.762651,56.860847,-15.023305,-156.93549,-220.276258,-300.805642,-236.825318,-159.338778,-36.004089,-21.152645,-93.567947,-160.431068,-242.274991,-227.959878,-77.527506,101.927788,114.448361,-2.535172,-69.458602,-110.983113,-84.29177,-42.829139,-11.565694,50.286765,235.202272,306.57381,307.289254,235.965832,96.215932,101.782412,274.878358,405.281674,367.050087,178.484068,117.743976,149.93491,172.691637,46.814049,-48.797659,35.426265,244.073039,233.099972,8.066482,-98.837258,-113.308338,-18.52146,234.91006,409.91188,432.848107,344.103451,274.087556,181.858862,170.42717,236.114793,338.650937,349.560765,304.722226,280.52283,230.364456,183.814735,108.165251,124.273995,247.172403,371.517476,402.009306,375.132034,299.199501,82.164823,28.562974,98.581577,182.408501,186.695531,157.783166,134.18481,67.716155,13.519046,-117.68151,-160.726713,-146.626476,-21.528069,26.009301,0.899545,-54.968088,-168.74737,-192.026525,-176.021294,-102.408898,-31.112694,27.345916,-25.221454,-149.329805,-176.4745,-165.361571,-139.205992,-84.366123,23.001666,78.786187,58.975004,-2.547701,-54.402514,-16.266951,73.447122,89.326422,94.649342,96.908548,105.226293,202.245446,250.976877,243.412845,206.785731,173.18966,214.394426,194.451127,83.552309,76.731473,168.722808,199.459771,183.88316,162.279393,183.295239,221.782327,195.867711,111.311811,99.92552,147.117443,158.100368,93.453632,133.698842,210.4381,244.003847,154.542154,-92.825286,-151.406527,-94.258158,-0.24206,18.363083,-9.219536,-53.38197,-160.572114,-195.585587,-193.122133,-164.450767,-80.743237,74.910255,169.846565,227.023345,155.951866,-18.835629,-33.954515,65.323033,101.59316,70.015867,3.535,-14.648483,-73.267781,-118.903537,-153.498444,-101.785219,98.107993,159.108258,89.292839,-64.613541,-69.937829,-4.466565,8.259281,-1.441953,41.565314,101.018337,191.647888,173.952311,26.467919,-64.629848,-162.553186,-151.629172,-76.946049,10.535725,37.52255,29.052674,-13.758374,-170.32652,-210.863632,-93.372332,100.794943,156.223099,110.621095,17.281718,-196.515222,-279.882701,-329.991353,-286.433928,-130.694389,-24.773648,-22.91076,-94.507213,-155.400286,-299.542224,-338.73258,-281.527463,-168.391425,-145.609794,-177.317735,-228.501007,-395.790861,-466.052509,-450.398158,-378.291752,-248.216727,-168.721875,-170.197062,-284.739222,-339.542854,-382.12295,-393.015702,-395.975079,-277.365218,-167.003556,-31.442062,-43.843339,-125.887651,-169.265252,-191.949797,-140.257742,-1.190173,20.968334,-11.023322,-74.468753,-104.774344,-254.468812,-361.548246,-445.771711,-276.853621,-175.428339,-64.490378,-54.150519,-125.459251,-182.702028,-198.518148,-144.746282,-21.592939,7.853884,-9.867122,-55.243179,-71.003476,-81.398051,-63.38797,4.345004,35.356975,43.297101,11.662167,-39.185142,-130.923619,-154.432111,-155.757529,-125.026864,-75.003818,-120.472401,-129.324542,-26.315392,44.778979,99.803541,101.452752,103.621163,128.788732,161.966952,148.835288,69.849343,-145.914733,-241.622791,-288.915996,-228.829924:-34.621269,49.786728,22.995137,-42.112111,-63.630174,-151.640119,-178.027135,-62.925764,99.027901,108.73408,-3.134629,-76.511179,-230.978623,-317.301926,-369.249009,-307.726674,-170.729697,-149.045728,-172.225613,-279.539551,-344.525891,-377.284111,-314.863112,-104.83895,89.205707,149.813752,92.222727,-28.146046,-314.310377,-402.998545,-358.65866,-256.253552,-38.597262,29.894368,-31.633151,-239.853528,-327.68597,-442.200689,-458.054995,-338.108596,-59.673566,17.293648,-109.451073,-217.833082,-321.503491,-329.532673,-267.65586,-182.705114,60.121018,188.058523,147.289771,-52.774998,-148.147425,-206.800009,-147.594159,64.051402,230.397317,249.356999,131.565554,37.688147,-120.901705,-177.848121,-166.38177,-84.757436,83.41318,83.082843,15.754236,-131.533597,-172.121161,-172.787303,-131.79569,2.113812,139.762292,185.203112,187.032428,148.138193,45.42242,5.69268,-2.64787,30.930179,123.522454,166.494978,130.627941,-28.6332,-107.923473,-186.435063,-159.282356,-18.928449,31.461606,0.19213,-102.48215,-160.469481,-275.892033,-308.157351,-260.467543,-196.682071,-45.712677,117.707278,164.187272,159.606241,140.745826,87.865195,58.320507,82.423424,207.32117,240.367592,169.489695,74.560627,-151.616278,-218.984401,-133.762058,-23.966543,145.447842,211.423335,194.613779,87.919027,38.158611,-1.702543,16.617616,127.790573,248.985905,263.477528,169.736652,93.309905,-51.861834,-102.824289,-83.105183,-17.178227,151.27437,310.577634,304.718294,68.334075,-60.823057,-185.314977,-205.851109,-205.781456,-106.048921,-38.36709,25.948574,3.298988,-131.29247,-201.222857,-239.207461,-192.588215,30.197053,204.710448,169.836716,-59.187626,-157.543622,-185.976672,-122.062245,36.002018,169.643199,240.309404,338.608456,338.108746,221.457468,146.613813,101.351243,134.817241,264.795924,367.476366,342.031613,147.740382,42.987606,-37.844109,-3.637849,106.828435,144.473575,145.822428,120.227592,82.332563,-35.161644,-81.016023,-15.905108,93.531437,331.38263,448.78723,438.854975,350.916266,312.483243,276.771993,299.642325,438.485507,523.116896,513.552782,433.094832,358.107075,172.814273,121.398665,193.96989,277.835812,400.408021,427.678058,404.034466,275.762459,176.174162,0.244813,-14.861653,78.986314,155.660071,187.056817,224.551299,202.165554,59.049527,-36.234449,-161.556158,-168.683372,-92.595495,-2.168064,1.88728,-49.787579,-71.242152,-67.85863,-46.06493,4.187143,102.276305,169.414333,156.928775,51.382521,-164.721405,-184.691631,-44.507854,46.263185,210.110961,337.465544,328.799721,138.621858,15.450595,-135.086524,-139.834518,-39.928189,95.508153,144.064337,179.813703,158.295794,70.170967,43.51157,89.124684,139.621365,223.354066,235.082533,180.232065,24.061623,-5.387842,58.605689,107.998832,175.104115,266.254939,311.814372,243.554473,137.363392,-10.758327,-6.798231,109.586476,161.622182,188.991602,250.196008,290.614434,224.785446,91.445007,-177.474633,-192.19339,-3.664973,131.46973,145.72962,133.807235,108.305265,30.691242,2.593071,14.998434,50.612101,150.62006,258.548255,298.330559,288.689095,220.862918,42.67527,7.518701,83.200828,172.746411,190.207784,162.674281,103.961709,-80.287348,-151.513582,-128.675761,-41.647154,182.834831,326.439625,304.821193,93.2681,-14.984109,-79.43253,-44.624866,76.006015,276.640798,376.385521,361.566954,228.085079,-53.490949,-102.135736,-36.762503,-0.295838,22.71429,80.730034,100.317581,28.220041,-44.248314,-144.621105,-154.026011,-111.561853,0.371688,80.644451,158.360759,100.949027,-126.707534,-207.122073,-178.565191,-111.350651,2.220746,94.511672,107.68931,-3.51693,-108.468575,-264.600211,-252.689376,-60.189819,129.279708,160.066292,68.225577,-29.219947,-208.737944,-253.059481,-179.440699,-80.526148,60.304517,45.746128,-0.914176,-149.02072,-227.695936,-371.047771,-415.740922,-359.399746,-165.736539,-75.827693,-1.20708,-35.877942,-215.788958,-296.706993,-279.008651,-193.067169,-0.395936,99.393254,80.792929,-66.174673,-167.439282,-394.607081,-474.166,-453.961282,-281.697723,-182.210732,-98.00222,-162.674519,-398.051389,-470.376068,-375.750788,-234.725095,34.965787,96.967944,34.015351,-127.876543,-160.289254,-145.764319,-124.692631,-62.840225,21.177886,62.509799,51.583711,-24.110383,-210.950011,-261.417534,-243.665065,-188.254842,-69.788342,-85.502101,-111.258684,-84.900765,-73.637957,-132.605252,-149.333007,-66.123076,91.000862,139.455363,72.333212,-27.444369,-264.79596,-368.415049,-438.629792,-379.789453:-370.328196,-194.148071,-85.349572,68.0331,101.39817,104.049846,106.953168,126.511142,101.545503,89.087107,84.014219,84.938745,55.875689,16.324066,-58.862957,-80.867246,-111.084275,-21.719563,63.981041,95.417567,16.117823,-124.222032,-91.140224,137.328615,270.788147,296.443599,379.070235,389.234569,220.160037,87.640378,-81.463452,-98.929464,-48.000013,13.490345,-4.970762,-130.58209,-203.711998,-313.277216,-314.95914,-202.678798,-67.52499,-32.420473,-46.656671,-54.953551,-30.235492,-34.68088,-85.909162,-83.486243,41.965047,197.756349,226.765316,181.527397,141.271306,84.760612,83.016704,148.038482,190.330594,160.312676,62.851674,45.794104,41.105311,4.867348,-97.303869,-130.833398,-149.342421,-89.51234,-63.706373,-59.454561,-51.217526,15.925893,73.915463,205.976912,300.178704,325.024551,299.749034,264.966897,207.514838,181.171222,159.13218,176.552334,234.377544,261.877196,263.186962,261.654106,242.51435,139.94739,90.787808,58.857948,33.584235,8.333033,-72.793236,-132.126507,-248.394458,-276.886988,-231.23461,-171.508403,-64.290618,5.569155,35.484825,80.608678,82.591352,0.143749,-60.997234,-114.360363,-93.525706,-73.821682,-35.281181,-24.709388,-23.226206,-24.359724,56.322423,137.430413,230.883814,217.869265,220.987869,241.056298,235.814985,180.35618,135.04155,98.796302,241.437341,321.119445,333.186987,300.973818,272.324507,264.310042,246.067831,257.937256,342.997042,398.908835,379.649003,279.45437,235.734934,186.893138,157.251606,80.349493,73.150956,110.853299,215.548085,238.991092,155.517155,76.259237,0.739956,24.179888,103.727893,155.363529,162.643805,105.529956,40.655204,-109.605218,-159.110033,-152.161618,-85.552394,-54.045462,53.315043,117.580745,128.916389,66.0244,-4.483694,30.269983,135.699048,195.152737,176.760668,53.339947,11.67126,33.768272,63.509279,46.473146,-9.739634,25.693471,135.747688,123.234196,-21.452016,-92.016687,-98.949727,-27.939497,136.688807,211.481487,201.089903,137.756418,121.560812,93.962812,56.467549,-16.548222,17.256604,56.309426,27.771399,-55.939978,-223.865311,-267.891939,-244.597033,-177.868887,-43.196989,20.612711,30.538618,25.068027,29.070105,30.112611,19.6048,20.45739,-12.733422,-40.75525,18.29899,85.483953,113.740399,66.5733,-4.225565,3.189839,49.285412,93.344501,124.335384,170.843468,158.821399,45.181949,-16.72628,-45.490107,-37.139725,-61.132701,-115.403381,-112.71716,-48.229888,-11.786963,17.714664,20.777749,51.455787,96.062464,109.624293,103.292459,82.662148,40.465541,54.424252,164.877927,217.705758,207.985958,214.050546,236.20692,233.421926,193.263072,131.193271,133.190305,112.202856,77.379772,82.780277,75.506897,57.297133,4.006281,-42.470057,-153.086968,-181.07079,-135.604062,-46.872108,-64.223303,-163.060751,-201.796602,-212.848335,-195.257507,-184.947938,-122.145451,-32.639454,106.563328,82.667242,-109.106719,-190.94473,-192.713724,-119.330279,-123.055837,-190.089895,-220.226007,-251.911336,-257.053355,-184.698748,-101.075754,31.048009,71.096386,88.739869,103.081547,94.767976,69.247166,47.272833,-30.379901,-119.137377,-122.148641,-57.715007,-51.588565,-129.712752,-187.709602,-262.528094,-233.796096,-41.441013,55.742839,17.947716,-31.009408,6.4327,23.274801,-50.300408,-149.168902,28.680342,139.30072,179.15889,107.420098,-51.877843,-90.373596,-73.689863,-38.670454,-7.368095,-17.921341,-12.779868,-28.104624,-86.691762,-247.518664,-268.350297,-172.20236,-73.780038,-52.408231,-74.441794,-124.943412,-270.644516,-348.142377,-449.897778,-438.311721,-317.556313,-218.20345,-215.730997,-274.972211,-301.756832,-333.504981,-342.386485,-296.594896,-167.175692,-114.461467,-111.441915,-174.201343,-380.960785,-463.848041,-468.558612,-404.575394,-271.021244,-237.471968,-255.761284,-303.089142,-320.294854,-364.643105,-376.295901,-296.96447,-97.920584,3.38354,123.207533,133.563791,81.114659,25.202417,-44.40595,-20.296031,33.540962,1.320728,-19.199833,-74.650065,-116.808413,-230.679101,-305.42736,-417.274293,-341.653985,-251.40837,-102.90038,-82.317635,-147.224326,-194.259241,-200.929419,-157.374883,-78.494023,-69.603839,-67.410646,-63.385821,-77.870458,-136.729802,-164.558701,-156.919366,-28.239389,53.722296,104.236579,36.575851,-176.760432,-231.832727,-179.084464,-141.153967,-173.837514,-215.309043,-181.648926,-88.665872,-67.783059,-64.844048,-52.947741,9.812263,39.606029,46.469602,35.020988,-19.816648,-197.12546,-250.673187,-219.337394,-184.726482:-254.926269,-99.888406,6.329718,142.808189,145.004736,71.747452,37.529012,-11.697338,-40.745515,-31.34143,-58.585529,-100.98998,-108.500358,-103.771091,-219.926414,-296.543116,-312.363791,-147.114367,-82.737868,-110.709175,-167.768838,-223.829487,-191.918089,-46.302177,62.365811,84.602156,100.27717,105.014873,67.516714,-18.148816,-268.768114,-352.32487,-357.638834,-258.679226,-228.44477,-233.783984,-260.374202,-347.154806,-365.327778,-291.516506,-189.613471,-134.616148,-65.825246,-69.532625,-45.295904,-4.929699,56.154625,74.08442,139.235473,237.697345,271.357319,264.499995,219.272929,69.982502,23.881231,126.151289,281.380262,275.162239,160.574233,126.622039,104.879385,58.64438,-61.37171,-70.208045,-12.089829,-14.486841,-53.536671,-85.098427,-57.089012,8.04273,32.213853,72.622959,112.040054,127.826465,115.336214,108.714807,142.255122,139.747774,34.208374,-9.812665,92.854407,367.726565,475.659774,532.393715,481.695598,300.340573,213.843747,93.109206,68.294741,84.138003,22.679738,-66.328905,-206.319554,-218.740951,-183.398736,-186.222453,-209.739292,-91.787893,-1.595904,118.400369,113.367386,-47.834077,-155.477899,-255.659002,-158.147364,-71.253734,42.809401,43.312179,-18.56549,-53.559819,-48.702608,-6.453726,69.758209,141.403874,199.780089,295.113749,289.042078,184.920827,147.065431,187.260651,248.512842,246.600514,217.338103,210.479927,206.638475,188.75682,129.746575,121.926205,168.362307,233.722455,240.358697,184.59155,146.025347,40.395812,-37.880407,-174.075181,-157.420532,-89.217799,53.936714,87.756749,20.068947,-69.734365,-149.23278,-87.139002,66.438807,119.673515,134.833499,124.721036,87.05567,-20.54688,-66.277568,-96.849937,-49.731671,-7.657781,93.817258,141.382718,173.249165,128.805302,-6.13922,-28.343412,75.967635,259.982087,296.379181,185.468907,94.575853,21.297601,48.74934,98.642848,75.757768,80.357298,121.164095,121.808896,33.282838,-36.458905,-93.432502,-47.481505,138.487068,251.856393,244.438803,177.49466,142.708273,63.427669,21.221437,-32.018011,12.564606,73.179555,147.558603,125.865275,29.965504,-7.071141,-28.087788,-25.221405,-26.528923,42.42957,104.407352,175.129321,162.824251,88.720462,52.472279,19.14339,39.775146,39.394792,8.633182,9.405728,35.72714,20.443954,-43.755425,-54.379257,-50.587948,8.739259,60.569671,102.488642,87.769817,15.209838,-34.043489,-85.089525,-12.514063,42.814344,89.528057,74.268951,-9.068681,-72.54882,-155.812768,-141.507083,-52.798135,-7.278579,-13.376054,-22.684521,-6.766557,62.657893,121.975032,263.451739,303.527378,275.775115,220.288585,222.421232,258.237186,261.53423,236.903562,232.804646,223.563758,146.64196,91.693369,12.983119,-0.519087,-47.200651,-90.02856,-123.42508,-69.996335,-42.109931,-31.543317,-42.883014,-51.284882,-57.619879,-77.219763,-74.198951,-73.282845,-38.075436,21.25157,107.540977,82.778965,-77.959853,-158.131857,-202.285493,-142.60495,-130.480268,-259.546172,-378.207872,-508.360118,-483.559044,-339.695357,-269.3638,-190.600071,-89.161171,-26.615113,19.130579,23.358897,45.677445,37.47906,-33.078938,-105.006642,-111.251316,-54.821019,-26.716767,-46.82326,-70.531121,-60.9712,-37.237668,19.175446,65.667182,64.370757,24.36541,5.505716,-33.763619,-56.725235,-53.784435,43.830546,96.444783,144.471696,143.255886,104.76444,55.102156,-70.31293,-101.984447,-89.606635,-14.087045,38.771546,75.068708,29.552483,-152.942728,-217.968169,-150.390757,33.602542,84.684528,33.361604,-53.091738,-243.442422,-316.41536,-379.948898,-363.934994,-224.248256,-77.624838,-79.993654,-157.811864,-164.467089,-140.262832,-147.846792,-179.14335,-152.786476,-109.790898,-61.609103,-104.033692,-310.981196,-432.354468,-543.624519,-495.322745,-319.313619,-229.096204,-243.707218,-342.799084,-379.086903,-356.504024,-298.973434,-174.93736,-87.300208,-21.408816,107.087317,124.986524,80.114499,34.377274,-52.673036,-67.985505,-48.355366,-39.711718,-59.914318,-129.317929,-179.21553,-327.335428,-401.052063,-431.77192,-301.192677,-225.738964,-128.044509,-110.720879,-111.38655,-117.654703,-112.697814,-86.511873,3.92827,34.459435,6.127086,-40.679383,-39.19524,-63.993518,-107.425645,-138.564301,-23.11639,26.08101,58.177971,62.970688,14.166156,-48.144382,-122.455664,-110.993152,-82.470256,-78.024032,-71.907371,-47.690414,-37.724931,-12.444936,3.834769,-11.681861,-25.267085,21.238507,105.26343,94.262044,41.211077,15.47315,-63.877297,-91.058279:-139.89133,-73.863317,-78.050405,-106.035309,-93.225025,-13.803498,16.049905,39.745975,80.328859,84.565793,23.189035,-13.41752,-68.43125,-93.940313,-103.690969,-84.112122,-47.586606,13.863582,21.409922,-143.674089,-252.504049,-269.78448,-166.468433,56.661175,116.269154,138.230003,191.934484,159.788942,-18.997251,-95.883333,-139.996498,-118.940288,-32.161272,59.761255,51.709502,-94.249157,-190.497499,-334.330449,-330.51578,-149.970815,21.327072,35.087456,-59.676474,-115.508828,-168.164666,-194.177668,-253.731409,-251.315702,-161.947466,-13.29379,44.712017,46.844885,10.039869,-41.723614,-27.972552,82.863216,160.153816,156.183694,94.593449,52.461646,-35.690954,-71.098381,-74.612242,-53.185042,-38.025716,-70.933006,-86.976472,-90.558157,-84.713449,-90.285281,-85.726112,-19.01961,70.763135,121.130383,203.266383,189.860178,61.944342,-3.394581,-34.263356,16.032555,153.247601,166.58104,120.929638,12.200688,-26.491865,-48.914714,-32.743321,7.108087,-2.641819,-21.518011,-83.315017,-143.191234,-312.781443,-376.329497,-326.69851,-222.492773,-14.059193,116.216409,162.032051,214.951614,214.491131,119.211777,38.93508,-49.484741,-10.319763,28.679045,97.486519,97.111948,-17.536683,-86.145079,-48.974465,59.043217,228.749448,194.563273,150.586151,103.29662,86.844012,29.734961,20.033949,95.868641,187.321722,197.457203,156.94756,133.668285,90.246037,54.950562,-4.177963,5.898053,151.786742,342.330493,344.674833,155.716717,64.555692,-3.643304,-21.952712,-59.300914,15.121026,89.060299,194.218173,194.524364,85.715123,-7.543356,-153.289591,-144.851312,32.498586,170.916343,140.983431,-35.439734,-89.459531,-102.863451,-120.348003,-146.82598,15.251935,148.187202,307.794346,301.307617,194.830144,131.049868,63.347257,72.086217,141.464894,258.89985,303.626635,238.557259,139.858625,-25.35462,-58.762356,-37.667911,61.735425,120.742367,166.567424,142.256807,69.532604,29.59324,-42.687279,-44.488841,54.033644,220.294196,267.931117,260.521672,242.785839,190.28916,156.061242,137.386152,169.519533,174.474423,140.734398,94.988836,-38.800461,-93.147313,-105.033212,-75.865131,9.902892,123.700361,156.830704,102.571176,40.367424,-47.945406,-61.145555,-53.652642,-9.792485,40.16977,142.687927,156.444964,83.758818,24.952243,-30.842706,-17.483688,15.073027,16.598012,27.706332,53.135062,41.212206,-28.470836,-36.379491,29.646858,14.22939,-18.041468,-56.119492,-78.977151,-111.511204,-90.255522,0.725377,32.126506,71.905906,193.240357,248.94538,196.302958,105.713137,-63.132203,-99.804084,-46.287367,31.011612,48.992683,115.594818,165.049746,218.961528,192.34833,77.9914,60.952487,118.541017,119.288534,88.906915,23.206035,7.331787,-1.676678,-14.459277,-39.661626,23.426513,82.08316,96.617977,23.758216,-134.865261,-163.971763,-134.682372,-108.589867,-45.949136,65.497714,105.884086,66.325183,-0.717833,-108.854005,-121.92542,-97.987539,-31.014417,4.313195,-18.962466,-63.412566,-66.423589,-21.230052,73.570837,112.771179,167.619568,203.170721,225.038883,229.842707,179.04827,20.31143,-18.563112,37.742087,82.767835,67.223329,0.154795,-41.007223,-104.401821,-130.937663,-168.579346,-140.865427,26.862935,155.004234,152.556712,35.928745,-21.584548,-42.688271,-31.003332,-3.000513,119.077532,217.965669,289.059912,199.226759,-53.795686,-99.708656,-40.922854,-21.700013,-22.390706,34.691836,44.36939,-60.886598,-161.139577,-321.456858,-309.009127,-129.158755,23.944612,66.726061,56.731234,-17.883554,-235.270825,-311.967006,-289.607608,-222.381705,-116.007726,-64.229798,-69.940944,-141.972557,-190.122846,-289.868148,-297.752687,-142.541657,39.354622,43.596345,-117.15357,-203.961495,-290.977205,-311.388518,-271.507941,-201.534606,-97.853701,-107.306151,-142.931208,-256.77641,-300.97635,-306.065984,-286.992667,-286.199897,-263.348219,-191.187434,-76.558856,-100.908838,-181.865838,-182.804872,-163.14795,-160.619492,-108.697811,-16.695011,-35.370179,-180.246626,-218.54092,-245.002029,-296.989015,-421.63537,-400.259092,-328.396019,-196.350297,-192.792002,-289.497069,-323.595556,-244.633333,-153.662535,-9.023864,-6.238456,-41.149905,-78.16886,-83.083724,-106.133689,-91.385201,37.489409,106.053173,79.038478,-1.343878,-46.812339,-167.217041,-209.042523,-166.737789,-106.006243,-51.727646,-86.604943,-93.257765,-97.99202,-109.952676,-122.755695,-92.449776,14.062488,39.246552,42.519865,14.338506,-72.398518,-311.57923,-377.285711,-330.276467,-247.822765:right
-183.283342,-120.745849,-61.426224,59.562887,65.369212,-60.486073,-151.643752,-253.614061,-201.258116,-165.849006,-142.055612,-145.626954,-156.998815,-164.424748,-203.657825,-231.9045,-268.202578,-233.718512,-179.236525,-54.849478,-18.771317,-41.797663,-108.871099,-270.73655,-275.331139,-234.68084,-199.006881,-217.59135,-291.575412,-314.738134,-336.897291,-357.182684,-365.13067,-326.696801,-312.664542,-265.530094,-234.210457,-170.735492,-140.146496,-166.249234,-299.161887,-314.494482,-194.995555,-128.099887,-75.208456,-89.225125,-208.957585,-274.843618,-284.169632,-246.771646,-247.060717,-193.628335,-125.775931,36.621738,82.136672,16.356263,-85.033553,-78.187422,8.469996,23.084601,-58.037487,-76.59502,6.284379,49.511693,102.751588,150.349988,164.920304,143.319929,85.847027,-80.807381,-128.885182,-75.410267,32.171093,51.272854,92.788106,131.90904,141.131182,89.8116,-41.445266,-57.142234,58.88457,108.79066,79.01178,54.488549,73.944255,121.221381,122.082743,94.551609,95.82624,107.055025,158.23001,173.939399,142.537091,133.289957,138.752264,122.81774,74.30887,60.229517,82.368799,196.544833,257.989117,299.761013,275.932967,206.843423,202.267781,224.66903,248.88396,218.593842,111.554624,88.809103,105.702034,96.378183,50.349465,94.655098,154.866009,250.226934,256.05235,269.400619,286.264386,197.016436,-6.902398,-60.73536,4.930914,94.530649,230.261597,232.185639,83.422596,-32.2538,-184.70295,-153.147128,-69.037295,135.2825,176.229868,98.190759,35.695451,-15.598456,22.881945,55.255165,153.782073,215.304367,311.567391,331.579955,330.643643,319.274897,266.476953,197.355964,204.465848,331.784202,383.211314,324.755712,243.460983,99.379388,66.623741,110.764374,266.597311,328.69029,318.837567,241.65751,61.388809,24.177488,68.376177,62.451952,67.871467,253.007666,369.964018,408.746001,320.482417,140.41159,160.341294,185.749849,171.060213,171.740483,224.801001,237.634972,158.839318,106.777559,126.297446,228.029033,274.561751,322.184547,301.852127,218.120712,171.927867,89.535239,102.652838,151.101803,265.309964,290.885261,261.483321,249.62327,224.208381,176.193793,111.367059,183.224628,209.09874,211.423527,218.052509,223.753405,201.268705,138.615635,119.563314,116.890304,117.10468,103.715991,52.612764,57.860632,75.313531,28.002113,-94.196741,-33.753437,50.340332,124.458987,71.934872,-67.026678,-94.674637,-120.070601,-129.698762,-123.89653,-127.862835,-139.425938,-168.088114,-173.974178,-211.534232,-260.230664,-306.382149,-240.309209,-185.552826,-51.342455,-6.651286,1.373617,-17.605336,-53.177418,-34.65367,-15.612082,32.751467,65.571447,78.862735,41.704748,-89.09583,-161.562455,-264.66571,-325.11218,-339.552558,-323.010103,-302.168386,-254.376056,-251.917731,-287.156119,-242.351661,-214.498278,-239.730576,-277.087015,-319.83858,-307.370746,-251.527024,-230.450329,-210.274642,-212.344297,-209.039725,-213.228161,-233.996765,-247.988325,-242.088959,-271.317626,-338.41708,-384.782232,-479.63576,-500.799691,-459.863379,-417.591584,-407.998362,-461.025707,-532.715369,-438.6317,-394.890916,-409.334982,-411.77517,-279.661495,-202.998992,-219.020112,-330.272527,-310.475281,-97.646195,3.963982,62.074683,59.215886,74.822946,92.896709,174.413587,195.565198,120.82902,-52.489076,-82.671054,-53.433041,-39.018615,-84.981708,-152.406325,-159.832125,-135.123993,-106.986042,-24.604416,14.062878,26.114934,2.785549,-27.486663,-12.158949,3.1866,23.452033,11.33197,-48.656734,-87.228452,-170.81813,-194.520746,-175.134234,-92.523866,-39.934922,10.507725,-2.379816,-60.937862,-103.62909,-215.613115,-259.560483,-223.107248,-136.960606,-130.02197,-140.433049,-153.736322,-250.334743,-341.402199,-354.092277,-309.371015,-250.903254,-134.706094,-108.058261,-160.148062,-227.188622,-287.733774,-194.861557,-176.054706,-287.407629,-359.85084,-368.256759,-326.955512,-302.854357,-252.060356,-170.662728,-51.994497,-64.328746,-131.783954,-139.711417,-169.854787,-221.908137,-303.061,-271.027224,-237.342693,-187.652116,-186.483492,-196.414797,-182.114122,-118.438681,-118.501542,-182.790466,-294.0535,-264.596211,-167.103175,-191.300819,-307.498911,-302.677213,-164.823481,-109.516907,-119.863127,-98.152146,-61.560886,20.590416,41.423323,10.782516,34.716623,110.937047,317.810698,393.479798,392.834131,331.880639,198.508763,157.59826,185.88685,290.343045,319.779131,346.527108,358.740625,380.081144,372.302154,271.099449,124.297054,75.724529,86.709581,131.373837,176.970797,166.220219,126.248996,104.715162:-191.833485,-104.100307,-31.529532,54.60075,41.305182,-61.153215,-144.532487,-292.145735,-246.38924,-187.418804,-88.34114,-46.646539,-32.114444,-86.571072,-259.290265,-309.78827,-304.103716,-264.974391,-227.525149,-119.970082,-83.447754,-115.736376,-169.567305,-256.045602,-259.988536,-217.185155,-81.175898,-52.968575,-162.425882,-250.461312,-316.033678,-283.955915,-164.985122,-55.220832,-37.779299,-107.972258,-157.718069,-128.404913,-71.092908,-68.239248,-127.627794,-103.82429,-35.96986,-46.184796,-146.393087,-240.120588,-424.664916,-419.389994,-231.875624,-117.999392,-121.682545,-151.757271,-152.62958,-138.502616,-132.040495,-111.285447,-101.760704,-108.125209,-85.299853,-64.767406,-66.768571,-70.370849,-73.350285,-81.680332,-27.148297,131.429375,184.603297,122.20376,27.284014,-125.850818,-160.66467,-161.770859,-73.667359,-13.353417,107.28763,134.773,56.727661,-9.193331,-62.914463,-47.441622,7.154456,40.366877,66.596398,127.111011,126.183299,87.614982,87.094907,93.140727,30.726031,17.384718,78.973572,108.827581,139.071277,170.181435,201.46857,164.852513,66.164775,16.330477,6.351663,43.055728,77.49652,112.721101,112.849702,136.566301,207.114405,236.396884,251.469052,230.80791,151.358512,116.897653,78.930404,67.703199,69.496052,106.496408,147.704015,255.834679,267.793081,160.933771,72.844898,-46.495479,32.707467,103.685763,207.450598,233.082968,229.077741,200.892148,86.367389,13.884079,-83.115319,-58.763802,9.248423,176.368457,222.154737,212.046449,175.464834,66.926383,-14.66291,-4.466211,84.651063,111.768391,100.927169,83.765233,61.891413,68.960613,46.616208,26.357933,91.513956,226.274085,224.267114,150.541409,112.952716,51.372658,86.264715,141.045759,256.969682,292.617631,280.339935,236.43568,112.219769,66.073079,77.99873,166.499572,212.858903,276.67495,284.253595,305.262495,313.791057,275.157373,273.281557,296.147452,309.005201,302.223023,289.554947,281.960638,256.755645,239.952181,210.59099,201.963903,234.259261,310.664166,293.806269,187.715114,152.170025,129.866252,159.763295,196.322059,303.796956,362.036119,388.070582,335.300627,183.632712,129.593146,148.074558,249.280328,245.528278,191.714527,204.639371,229.727924,194.50351,118.226503,147.921012,164.860294,120.451479,76.526014,35.802302,64.727123,126.413468,102.769402,29.698144,11.235334,-5.85176,-45.483198,-55.211792,-78.813036,-106.662171,-186.763832,-206.272788,-176.105296,-108.48818,-104.790624,-157.012991,-184.431428,-273.575968,-358.128479,-478.188194,-442.486365,-421.237117,-372.338946,-308.267189,-157.51963,-137.858213,-189.134851,-132.171315,-74.133871,-22.811649,-20.414777,9.793688,19.585155,-55.265943,-124.935296,-249.547862,-288.516994,-252.764279,-163.786375,-161.122683,-190.193697,-184.871592,-145.528081,-119.105192,-110.485177,-77.793526,-59.964612,-73.021225,-114.468894,-221.047209,-245.285026,-180.795778,-106.411193,-115.173724,-181.293121,-220.477308,-279.371635,-289.9159,-281.777902,-222.830043,-196.980483,-259.940699,-333.295188,-376.85596,-334.188944,-294.35148,-327.030126,-366.97879,-306.950992,-273.121687,-197.411509,-148.854523,-85.875542,-98.081657,-177.832823,-163.84288,-89.40472,146.750484,249.530396,286.862196,226.545171,111.331296,128.539832,269.090623,259.405803,191.769839,70.824511,21.207613,-60.930073,-71.043654,-17.901724,48.864684,63.316041,75.847848,77.001206,81.636774,91.30279,88.548144,78.562179,59.538413,13.296827,11.025356,55.053929,50.961647,-23.428936,-51.459959,-44.531848,-54.74483,-85.949487,-72.214041,-9.596667,71.651792,55.986683,-26.030823,-73.861833,-138.244029,-92.995616,-43.039037,-19.083229,-70.023975,-176.374497,-191.229594,-195.178249,-230.761972,-250.383504,-186.610401,-104.53131,-13.05569,-27.57293,-79.03781,-87.249398,-67.912284,-46.983232,-52.580876,-105.144167,-137.494938,-144.755795,-118.236653,-57.9073,20.950655,68.499335,133.527608,136.715225,89.581126,59.276517,-8.435265,-60.745532,-155.741028,-189.322139,-171.975057,-71.194983,-46.315805,-100.289082,-127.907658,-86.480822,16.927968,34.828795,-38.653788,-103.101758,-216.093216,-250.851597,-257.954194,-226.750317,-135.05443,-130.324008,-143.397812,-101.576431,-66.146271,-38.014666,-57.313322,-101.233677,16.823569,122.049413,315.169999,369.150441,342.856598,294.113812,198.156035,162.58975,220.401036,385.058307,420.465998,370.778895,312.260837,206.860711,169.525121,68.056572,-22.119534,-8.801136,94.224912,130.645421,126.122539,97.929899,30.593587,18.733728:-112.554226,-126.256063,-108.816637,-90.102574,-104.665084,-163.991453,-215.735254,-327.561829,-272.467776,-193.100053,-117.972114,-138.800574,-169.658241,-170.478359,-210.543994,-239.181567,-246.735155,-134.700651,-61.74806,-21.574694,-46.961389,-76.006449,-91.816601,-204.574647,-292.327783,-270.558088,-158.465833,-121.854794,-126.469056,-144.75882,-159.272048,-135.51498,-39.810804,2.169082,-0.586336,-20.634496,-38.684412,-73.815546,-83.521407,-95.697081,-95.086246,-78.545222,-53.412076,-89.925034,-217.264216,-266.319295,-362.417529,-396.153275,-335.843218,-209.41341,-188.251278,-195.709166,-180.095579,-153.147479,-169.267348,-158.728372,-116.389002,-134.627302,-134.465841,-110.329492,-144.018436,-185.140355,-225.367343,-222.30053,-136.448388,13.073155,39.064051,-59.831396,-138.648198,-240.956161,-263.617085,-259.508101,-178.693347,-136.012652,-73.047354,-48.389504,-25.263116,-41.296836,-79.556399,-61.002682,-14.646635,-49.908257,-62.670779,-46.545331,-18.577661,59.909396,88.192765,109.750413,75.654541,56.0092,127.854697,194.929091,259.714179,251.508818,159.821366,94.977937,9.150749,-10.935905,12.100828,119.806993,167.707567,177.443661,152.72328,161.788942,249.32596,270.722794,243.031038,204.552635,138.014807,130.171075,140.860207,148.79739,152.504654,120.3133,112.740757,124.296829,119.27916,80.494431,58.947853,9.369629,-0.674757,52.949452,220.683112,268.009245,240.685829,182.822504,65.103694,53.946946,109.50192,114.275353,106.82756,165.215822,207.811165,184.479937,134.47056,84.919278,110.798002,129.693631,147.922959,136.175806,98.713848,89.135632,85.365096,102.298343,160.235059,167.514102,158.268478,100.525387,71.192708,82.764907,91.051375,65.22095,73.520226,100.156392,170.640817,215.021106,287.099393,274.152867,119.496024,32.115569,-6.941082,88.704302,131.481331,169.402162,180.65677,195.70752,169.978512,81.529466,139.276734,218.892445,301.859591,278.613953,236.648982,258.778343,270.447677,226.712677,157.717729,184.725581,201.631823,194.26715,184.359829,183.88718,191.279319,222.848656,229.867128,242.143945,348.258633,397.760854,358.353156,279.418246,145.073367,133.092931,201.784975,285.681355,290.366237,230.429593,210.417713,229.406209,235.406363,225.808844,244.228265,250.951854,237.68932,225.373,239.106868,254.34679,162.555235,67.290168,2.20955,100.444921,113.972178,33.60206,1.211136,-14.984289,-49.270411,-140.582478,-77.926839,-22.026008,-7.744995,-42.327125,-100.419962,-120.53351,-221.884844,-274.762371,-252.962866,-207.331939,-233.869027,-298.661016,-289.583982,-194.709292,-147.912779,-97.975154,-54.037669,-38.063143,-18.194855,-11.570466,-13.952638,-17.0182,-43.14122,-79.981648,-194.01069,-207.767997,-145.676359,-44.59682,-48.191374,-111.451936,-127.187084,-84.223334,-38.503917,-24.682401,39.571995,70.899993,54.74977,6.300456,-120.840105,-154.473652,-75.167652,47.258222,56.935933,-9.560891,-59.800907,-146.147839,-181.951069,-227.444685,-206.669468,-209.874967,-280.843025,-301.159339,-259.048643,-246.341154,-292.505698,-301.802747,-257.519941,-215.163549,-171.756061,-39.851356,13.404415,28.672203,-23.011354,-149.058578,-85.604487,9.410745,183.037856,231.688876,262.312357,252.848173,169.679176,112.134025,90.186602,167.119651,190.333671,158.887276,101.111597,-1.208721,-11.369946,18.17667,56.49555,73.08943,94.683781,89.416664,63.253083,63.83432,58.495619,38.082734,10.576179,37.278547,71.77293,110.167156,84.678515,-7.569301,-55.453611,-124.810275,-89.486482,-47.463544,-0.859356,-3.06587,-12.948642,-23.494931,-93.886599,-121.749639,-77.059556,-65.036463,-111.230294,-189.10883,-184.745935,-129.729597,-130.311552,-207.10221,-231.018896,-190.920725,-44.300447,19.051322,51.383271,35.660624,-13.588665,-34.319488,-25.620589,13.632727,7.970109,-53.9375,-67.124089,-29.41527,-15.161396,28.035948,135.260058,153.00987,97.34202,74.009166,53.937566,40.220961,-6.439853,-53.509904,-172.516434,-213.566414,-183.244532,-101.96866,-89.210091,-102.309973,-115.36829,-122.360232,-80.250705,-73.746235,-116.901713,-143.768679,-197.99081,-240.672615,-308.064948,-287.912508,-185.253497,-158.779137,-136.456584,-46.982664,-33.239935,-67.771243,-68.440897,1.635215,64.934702,87.314366,211.483566,278.713547,270.282307,224.633981,144.773284,118.633417,188.149821,356.912997,395.150808,301.571851,195.693341,14.006024,-30.285348,-38.565769,1.870692,32.548477,131.701453,166.310532,114.241805,42.560371,-99.512335,-122.662522:-75.347861,-64.354648,-45.337992,-21.118102,-39.084131,-126.687277,-195.353068,-308.925164,-250.247402,-188.56368,-107.61445,-110.060127,-178.231246,-206.594213,-243.991734,-262.859477,-264.887046,-202.987382,-160.62248,-98.7338,-89.502718,-99.230772,-133.290683,-247.632695,-280.61623,-261.656001,-200.477659,-177.171602,-178.886234,-199.984395,-257.175556,-274.606223,-233.625165,-116.382488,-66.927233,-43.464436,-70.841827,-156.078177,-191.114821,-207.173073,-193.926744,-198.021843,-194.878493,-185.474747,-139.0454,-122.425171,-218.961492,-303.210086,-366.057612,-299.848621,-257.921838,-140.295613,-69.964203,13.669352,3.649208,-57.349213,-14.702467,23.445737,21.625426,-22.013569,-113.059026,-110.520551,-55.986303,-59.882256,-58.57068,28.360777,54.288968,13.954818,-45.059647,-167.684161,-206.657886,-206.456651,-88.541451,-24.188304,39.341819,41.195991,32.29358,28.399962,-8.179707,-29.792944,-56.793735,-75.576783,-44.346754,47.484883,44.562509,4.348978,32.934212,122.82991,91.918367,66.790319,132.922093,203.850571,268.34534,242.836387,138.034559,96.842385,80.020398,65.964374,50.715342,61.916769,86.023581,117.496996,120.353701,160.768004,272.78936,304.51704,268.892651,222.712125,128.9429,103.17999,93.944693,103.176435,142.850146,159.298912,171.722305,197.282716,191.562124,181.691488,171.983091,90.244472,39.642928,64.234592,158.420832,195.839054,208.59913,179.827541,52.089264,-4.080263,33.44185,96.293025,86.044124,123.545839,168.196483,164.816202,116.052248,50.052821,113.55713,174.066384,270.994072,286.292486,288.485028,301.960135,334.809067,335.743888,283.297838,191.449695,183.069923,255.342411,284.038612,254.683164,200.938454,66.556383,61.043682,142.261271,361.771628,425.710291,365.483002,274.498435,118.553952,74.28519,70.827186,145.792386,179.696235,232.851951,248.663321,236.931559,194.911474,74.325391,106.635706,167.494892,217.822229,223.815177,275.081208,292.061472,194.410421,105.325916,65.464093,216.996316,289.558205,328.699247,292.554276,207.615594,198.80368,234.324503,251.20694,253.906272,299.122832,334.433849,363.420126,352.442423,297.547777,257.604805,222.183506,246.205078,231.950119,200.695703,222.568282,255.379292,227.371082,183.005345,248.305262,263.02132,204.673618,178.402703,218.009118,259.202185,227.578285,149.375622,42.163641,97.689601,153.393561,220.839984,187.350661,35.340591,-15.679559,-50.637716,-60.566678,-51.265009,-2.90561,0.936298,-75.733083,-116.995899,-171.698994,-203.274881,-257.881831,-261.916766,-229.811206,-94.5588,-24.889636,42.625404,37.377616,-17.171543,-54.951796,-50.312661,-7.307378,18.464885,46.210378,34.909857,-80.831103,-178.193973,-324.993622,-336.646193,-321.069918,-300.552224,-293.168444,-265.886233,-264.405154,-308.569159,-311.667392,-281.79244,-208.392298,-173.831303,-121.152325,-104.026609,-91.318866,-105.216854,-136.942862,-117.310039,-105.448386,-119.832281,-158.013616,-255.758574,-285.945572,-285.40848,-225.543286,-230.614033,-339.169474,-371.175169,-321.657131,-293.92488,-339.869226,-401.415545,-467.679676,-427.414525,-397.265237,-283.785336,-202.534515,-122.108586,-160.623135,-309.368167,-310.39228,-216.161536,55.590286,161.444892,239.455057,232.20503,177.150485,145.609019,123.257776,133.664732,124.021906,32.732147,-21.032875,-6.39341,27.517033,-47.960421,-149.016111,-123.747541,-7.296766,38.415825,78.258448,74.368942,2.233437,-58.716793,-152.306792,-126.559238,-65.694023,40.728369,23.69003,-141.661812,-216.165849,-255.825401,-207.51855,-182.036574,-163.108746,-146.444144,-69.47466,-49.445696,-140.745641,-220.788764,-299.440162,-234.252396,-179.664071,-137.780155,-154.511794,-159.092669,-155.247906,-222.967726,-241.010389,-202.322057,-126.923459,-110.240756,-127.193249,-142.613505,-142.74817,-140.445161,-146.760622,-146.544096,-153.932324,-189.042305,-200.644173,-182.905902,-175.852931,-177.629082,-83.689537,-17.628816,1.499636,-51.474189,-177.076741,-212.885149,-258.867534,-308.968925,-434.263321,-422.234196,-344.38417,-161.043401,-133.747314,-233.371494,-284.791114,-251.947484,-164.815385,-183.937436,-282.489584,-284.222955,-208.69681,-198.579099,-241.67379,-237.917777,-174.907455,-200.5124,-225.891525,-161.933436,-85.217344,19.610294,18.635002,-29.720989,9.725916,77.131758,234.482909,275.816957,268.349434,262.965689,242.548874,207.979678,194.351817,282.975828,320.207035,319.157029,275.022016,175.020206,147.226113,101.09739,37.745056,18.871706,53.491287,106.038412,192.707691,188.848962,78.947992,11.972194:-51.541606,65.897685,102.923076,51.4607,-3.819373,-123.421688,-198.138589,-311.596467,-219.887409,-118.726894,0.910547,-14.739169,-120.183832,-180.977159,-293.757118,-310.154878,-218.524733,-48.626072,20.788563,36.286283,2.494796,-13.917864,-19.294614,-131.039684,-212.181982,-183.920169,-80.403791,-68.03878,-135.717258,-167.741825,-151.948711,-103.930818,28.73014,96.59926,94.882075,59.784214,36.65398,-12.218912,-33.366604,-24.957279,1.346732,-2.743281,-7.579066,-24.203085,-134.036674,-221.874094,-413.498493,-459.942481,-353.449878,-149.95108,-96.921901,-70.760134,-58.426513,-53.829954,-80.046955,-82.445239,17.757835,40.458427,-5.411724,-55.822419,-170.359836,-212.889727,-236.265231,-214.544974,-133.200523,-40.960559,6.828808,3.288079,-64.421718,-214.030905,-269.702981,-326.546853,-226.56391,-134.695078,-0.9663,19.535764,0.478003,-29.650336,-150.915197,-210.55306,-218.956436,-97.953575,-17.310984,41.443569,-3.242436,-117.908225,-129.408474,-26.400665,69.664791,80.481798,134.857824,177.184069,185.056282,132.397839,-32.500863,-84.769563,-36.517134,71.817356,84.856337,49.043773,23.850019,-36.369102,-55.988887,-8.67368,129.739467,198.503979,263.659323,230.478205,99.561531,68.259634,85.504325,98.473347,108.313613,144.682836,183.270978,211.937499,173.170419,70.489507,36.55091,-9.624671,-2.584231,44.40225,217.172758,285.709473,271.206321,212.825545,95.491554,65.944992,92.774984,132.510423,135.379874,133.702537,128.652499,104.072804,86.663987,68.273422,124.610974,180.518706,278.119335,270.131799,159.38592,132.929455,193.623503,234.675452,269.206969,301.250263,319.11465,261.236856,200.189671,142.503621,126.181631,72.378585,127.241893,198.307778,373.928359,457.942875,457.758289,347.251197,84.158657,16.211218,64.835777,191.878807,226.251986,223.761745,200.388698,147.93461,108.15282,25.366916,92.902222,170.424384,250.852827,238.816454,212.883038,214.943525,159.403016,86.592018,0.530155,112.457532,190.995724,257.922353,236.511011,153.793699,131.66307,172.894519,239.024906,276.081414,368.346114,367.071858,246.300781,191.672842,152.146089,155.845748,219.00288,279.051037,273.355122,241.247146,256.209705,303.077795,275.447591,175.430937,190.348319,217.209351,239.074039,251.790393,327.153121,343.431197,195.100693,92.30556,64.016939,173.219248,201.105654,179.398747,137.870396,42.496678,13.976623,9.961813,15.241049,9.236106,30.747111,52.114164,50.636741,11.397743,-154.836374,-234.669219,-210.770673,-70.162971,-62.25158,-113.239388,-101.678869,-32.917608,-29.354201,-54.535425,-12.25785,27.006858,102.10157,104.982903,3.571947,-70.010654,-207.75742,-262.730285,-291.985235,-208.715951,-166.501626,-159.052543,-188.213207,-239.810222,-242.519769,-205.001542,-116.492802,-79.546567,-57.859402,-56.62609,-7.214909,28.35667,-2.56788,-41.835372,-1.820759,76.500938,88.270432,66.228105,12.426867,-136.805074,-180.625831,-156.771355,-99.098899,-105.504791,-139.380944,-142.953076,-133.103946,-124.895379,-136.794868,-164.436508,-186.768797,-114.970172,-88.125735,-86.479548,-59.08191,48.369544,47.34597,-72.817799,-106.443277,-50.940594,171.321493,281.091975,355.476902,325.886885,230.033848,207.707501,263.152092,305.919368,273.965071,147.165478,86.34941,44.802607,51.030841,44.045672,75.62746,109.312337,151.204766,156.791984,142.850397,115.651506,-5.218102,-89.911131,-202.23323,-158.27672,-98.610269,-36.919055,-70.850434,-168.875098,-201.391692,-274.30784,-250.475441,-168.37041,-5.339479,12.713251,-85.269529,-135.71271,-138.999508,-132.80099,-174.064029,-192.013987,-175.976905,-163.287028,-157.724577,-99.128935,-84.258603,-114.925721,-110.463476,-88.836795,-24.43023,-10.586776,-75.740204,-118.269123,-147.479146,-145.32349,-111.168093,-54.980904,-34.982803,-42.93043,-56.414222,-50.210906,-60.978572,-138.491879,-143.375326,-114.166963,-75.781612,-78.268442,-140.202765,-203.62311,-351.373595,-406.648351,-453.54093,-398.334758,-309.54252,-112.017874,-82.653273,-174.036892,-231.285921,-262.312103,-178.898512,-140.428088,-156.518566,-183.666746,-208.379521,-232.909065,-336.978732,-349.4736,-215.354181,-122.901567,-128.109378,-135.733916,-128.229134,-103.13869,-74.467521,25.059674,95.318013,121.915481,233.20081,281.187208,280.515183,267.838284,214.610212,162.901669,175.840424,363.357089,429.517079,400.405531,322.331409,170.825739,110.992254,-11.904845,-34.780337,9.205386,108.340132,137.478941,169.312126,159.184821,-0.080029,-109.703592:-161.723974,-170.000038,-163.506724,-128.460959,-133.449483,-204.098106,-254.300373,-367.256039,-352.364207,-294.309799,-222.625343,-212.790815,-172.567481,-163.212386,-239.646451,-294.733957,-320.152254,-211.229177,-141.161165,-72.884454,-88.688693,-160.876732,-207.080862,-311.467504,-346.914102,-315.809575,-200.169467,-173.039751,-255.965978,-312.981226,-358.110285,-366.008194,-354.327086,-278.557935,-211.135775,-78.718251,-59.128909,-105.03976,-150.82774,-269.43361,-324.987219,-310.95583,-267.991152,-265.870845,-242.849398,-205.843565,-181.83385,-214.826969,-273.514038,-259.304679,-220.967177,-51.294945,48.622356,128.368746,90.324203,-24.490504,1.354453,58.989422,93.613859,29.711186,-145.643425,-162.452856,-37.721916,29.378208,63.09631,-17.904961,-42.367738,-22.57747,-34.790132,-120.416352,-140.195544,-104.09882,-33.439973,7.50173,95.501785,114.643281,57.829077,22.039768,3.717795,-10.922721,-70.587342,-75.476541,-46.521714,17.707189,42.124555,123.839855,162.752346,160.662853,157.553143,172.689766,170.772571,149.979065,164.61048,205.525108,209.509655,149.365376,2.447941,-45.469182,3.738828,186.392478,251.711972,301.846429,311.1544,271.014768,167.190522,141.381879,164.903852,177.28151,175.688478,167.716888,106.231508,77.460931,127.693134,228.346724,233.201248,165.579332,138.373682,173.74995,210.35254,182.427895,41.956372,12.477903,65.427755,98.617757,91.984115,57.435715,-34.812269,-81.57295,-128.408611,-97.532743,-66.174884,16.961662,61.59187,131.669613,161.659608,222.957471,252.280613,256.535261,311.595352,360.083215,437.762998,458.563172,446.826042,405.828973,300.730498,213.153323,195.104833,257.277659,297.762513,275.671827,205.751467,30.834643,10.885656,85.804948,260.791968,299.385248,256.061411,191.901204,35.748672,-20.556278,-31.472125,53.261492,104.365004,167.239669,174.327126,159.044725,123.508399,18.305353,1.511134,9.712534,38.692365,90.660374,206.373354,214.98581,116.78962,58.394486,37.755526,109.060839,167.20395,268.682013,250.937887,92.75119,40.535701,131.321861,258.785095,226.708033,105.176816,107.693157,173.057296,183.294883,149.44625,116.945743,91.066623,105.800066,98.750901,100.765637,137.39693,197.459816,154.414064,27.593908,68.33691,87.304835,45.836177,22.392985,32.180342,58.791565,40.08604,-16.917721,-106.36072,-74.471732,2.622058,178.897909,189.334266,29.628265,-57.042524,-118.27886,-40.609401,12.391675,10.189494,-36.389615,-61.768348,-11.10772,69.005878,33.23562,-84.837485,0.971276,113.96847,274.735917,293.858475,310.711433,311.108308,220.828632,111.235112,102.283624,150.359658,165.80565,135.649684,91.009734,-64.36381,-153.920651,-293.185864,-376.098623,-376.060779,-289.192956,-248.939709,-241.76792,-256.896217,-268.822321,-240.288219,-245.951957,-343.469543,-389.627913,-337.058642,-229.63166,-31.663766,-13.415569,-67.751087,-108.77691,-122.804009,-118.461904,-113.847328,-153.83348,-190.561243,-247.072276,-286.29087,-321.284661,-399.043222,-417.760864,-383.125772,-342.72604,-323.760227,-367.550273,-457.349016,-404.097965,-353.416747,-324.61866,-328.300799,-263.50281,-221.721506,-227.553929,-292.007757,-284.307121,-93.257089,46.308706,177.797132,148.041896,67.56964,91.483993,257.835045,247.573855,125.611777,-94.751298,-111.620609,-23.741577,6.01313,-26.696204,-59.058693,-65.032856,-104.101873,-111.501945,-22.407501,41.180566,28.216916,-51.383666,-185.621839,-190.670041,-164.452582,-78.916945,-51.054133,-131.464592,-200.946484,-199.089818,-79.797516,-66.924384,-67.756445,-14.657099,92.598202,56.547386,-171.798134,-272.860521,-307.512197,-192.40372,-137.765653,-122.692348,-136.1834,-96.631278,-74.770149,-171.317592,-288.464308,-267.16078,-143.423749,-108.389714,-134.578604,-149.775108,-146.754156,-177.928206,-276.571198,-270.997775,-243.612092,-195.957738,-195.545845,-219.680079,-218.823964,-230.722326,-256.657486,-236.51999,-145.461223,-125.583644,-236.159863,-324.334819,-406.002179,-402.023358,-358.357551,-295.577776,-247.7302,-106.833691,-69.090723,-142.705429,-206.130424,-244.920486,-227.858781,-271.021685,-332.665066,-262.301302,-100.382845,-116.558131,-190.733518,-145.32307,33.85309,56.787054,33.003108,120.335022,206.14295,256.240347,239.33719,247.73496,235.522853,217.181246,262.367157,317.565843,380.135531,366.495859,267.121487,220.969223,209.248845,241.946838,274.726183,346.352599,337.654158,271.390567,251.520905,177.701154,36.09141,-13.796455,-19.966622,17.184102,79.794917,77.561651,33.874847,4.715778:-58.205357,-55.81475,-75.356477,-143.037438,-177.203125,-264.073756,-342.676635,-482.466026,-414.452745,-317.653465,-107.257286,-42.139027,-90.950668,-190.106348,-381.014218,-397.749458,-254.037363,-124.874992,-106.867305,-90.322298,-76.945597,-100.110874,-163.3729,-298.314665,-290.777581,-255.46152,-201.724606,-187.498416,-188.033395,-215.937556,-332.906067,-374.268629,-290.364705,-80.408742,4.81835,59.08428,17.167954,-136.21149,-198.207307,-221.869347,-183.766518,-170.864016,-154.277632,-168.889042,-230.064964,-252.549133,-343.270572,-405.664727,-401.800932,-243.708452,-168.044297,-43.906997,6.21297,52.704548,35.035781,-67.636584,-109.55538,-79.519772,12.75662,20.317323,-73.710226,-110.671812,-91.652034,-70.503386,-43.273487,-51.248037,-57.542821,-38.802674,-40.860614,-154.857762,-244.929955,-313.614813,-164.730087,-59.0381,99.149409,123.686213,81.035792,50.146704,2.337963,-18.536611,-64.27579,-75.416877,-47.735321,17.210424,32.666303,39.326801,39.84991,66.19444,147.636224,186.63051,245.287178,251.264821,179.367648,122.338998,-5.309401,-63.612073,-77.359259,2.003886,18.828579,-28.043117,-46.891405,5.053568,38.073982,62.626542,114.905295,150.148406,211.798097,233.111945,189.260024,134.766211,73.459759,79.325998,149.10358,235.402328,266.415037,268.446524,233.841122,165.361706,140.882418,67.315262,18.847946,40.18504,148.705507,192.721696,177.062058,139.807267,88.046916,74.687682,38.358835,2.838423,24.727293,115.530884,129.17603,98.895258,97.721948,138.139896,207.712221,258.91987,383.905524,422.875205,413.380286,395.787749,370.912007,351.239677,289.331749,254.750588,278.351195,356.299778,371.038162,292.506467,198.802967,36.380231,138.729421,262.908723,408.326911,391.020498,290.732892,243.617704,131.984567,80.951586,35.534468,84.258527,157.165546,270.775403,255.233109,161.194409,118.597435,52.399316,128.615879,198.352637,231.638413,209.110314,191.073551,186.799511,94.30565,18.21343,-16.10273,114.066884,179.625509,250.792434,241.05859,136.914159,89.495642,120.377963,179.473023,164.58673,193.971193,256.384454,305.813393,266.377251,158.049441,124.934596,104.287019,74.163426,66.688331,130.740847,180.185147,199.646254,153.67505,59.31927,64.996639,68.010172,62.560845,86.300341,144.200677,141.762968,81.516097,39.907637,-35.6155,-19.60838,61.533008,260.358417,267.043074,88.134592,3.519248,-48.534419,26.238399,94.584377,146.288881,100.210403,6.688398,-3.055324,-48.734694,-98.292104,-126.36951,-4.624126,70.510758,164.207293,173.123994,140.591428,112.971387,63.194034,70.353852,95.614443,131.245423,122.114406,43.831143,-16.887905,-161.930563,-227.544728,-295.375594,-330.590689,-341.063839,-303.434794,-264.060003,-223.748376,-239.09337,-275.712026,-233.558883,-209.538604,-193.896973,-172.434808,-76.585237,-37.143866,-66.287815,-105.508585,-99.166212,-49.411744,-22.146922,32.094986,10.476636,-132.427693,-195.059661,-229.720139,-200.359671,-191.012989,-192.365982,-189.551785,-162.75178,-151.232717,-206.279164,-264.002756,-296.340672,-230.2529,-202.45233,-160.448446,-149.087079,-123.840304,-126.99475,-233.927226,-287.704791,-216.988331,58.721213,191.219358,296.81481,263.168632,143.633845,111.044059,143.938603,223.670208,233.737611,186.004174,141.079797,63.81444,50.404566,26.139955,-10.63414,2.09291,112.603291,172.133416,197.342399,161.848266,-9.095699,-123.83317,-227.034642,-135.964148,-100.860484,-106.181257,-127.495633,-165.13293,-176.820511,-194.300069,-186.999971,-176.271132,-136.557518,-88.096983,-25.188845,-75.451034,-282.74531,-350.08198,-345.854617,-266.030346,-214.303534,-129.794364,-120.01149,-143.65951,-173.276385,-261.399642,-236.370308,-177.76719,-73.612113,-47.145254,-72.836569,-112.855981,-182.70865,-197.3744,-158.699596,-76.234353,-56.383772,-65.086624,-68.971647,-94.086847,-141.131309,-223.23146,-148.836784,-96.677439,-75.214082,-101.933624,-177.565718,-204.043722,-266.556087,-329.147829,-429.633719,-341.558392,-236.020337,-78.545065,-96.756244,-272.054388,-327.895708,-288.328046,-224.495207,-214.211118,-196.522372,-188.285227,-199.899886,-207.394887,-189.851587,-157.902865,-53.399791,-7.379624,-14.263289,39.366359,98.983053,149.628538,130.93036,138.843584,242.369119,280.303394,351.280898,400.190011,455.677156,437.625571,298.396396,211.438769,188.156324,363.521992,440.649834,471.030988,413.638626,257.922093,229.127055,218.698358,145.231171,138.373626,216.210811,258.834646,293.529413,283.659914,186.394333,115.627194:-236.249363,-259.642117,-249.073348,-193.858451,-181.637083,-236.622115,-269.963142,-271.013957,-223.956615,-204.823233,-176.467203,-160.014363,-133.40539,-150.77737,-269.624419,-320.842264,-278.776987,-130.699569,-64.757634,-19.528594,-47.689077,-110.520776,-132.441907,-239.780925,-374.727278,-374.746824,-267.050645,-245.362802,-340.183001,-409.856032,-491.208905,-476.642861,-329.787377,-183.841758,-133.140073,-37.297205,8.008897,66.478495,58.613057,-3.817537,-64.45925,-91.954952,-114.348609,-120.076616,-159.190509,-175.605867,-206.707881,-236.873939,-247.325816,-173.32617,-140.561998,-49.434442,22.828954,130.690797,129.70221,39.974752,-76.534529,-135.053329,-215.026431,-215.314981,-179.042401,-153.103464,-99.611067,-109.319677,-161.547912,-112.06823,-68.900365,-1.513186,21.830472,38.768071,21.184656,-18.716675,127.511184,239.337049,334.079051,306.905584,178.498086,115.688462,40.832365,22.240618,30.074076,74.445158,82.769681,57.286415,43.249848,119.507971,202.08177,267.639645,156.125739,101.836941,58.242528,49.55622,-1.802486,-35.037196,-50.424119,-46.093356,-74.2705,-64.213198,1.209395,188.549448,248.871936,266.777132,245.91417,184.579671,148.964079,143.009662,94.243216,53.282798,29.716182,62.618971,100.233867,58.025627,-37.638217,17.099873,78.784861,175.934713,196.256535,226.592695,224.618373,107.331636,-53.717642,-92.386458,-81.04637,-66.026902,-95.618012,-126.629287,-141.879779,-137.201384,-148.431261,-158.335421,-148.022765,-112.272885,-98.790208,-41.586644,-9.72548,13.620915,149.572997,249.038254,361.80552,400.656476,484.757444,477.283025,306.13568,194.748304,65.237288,66.908453,81.696332,29.817954,-54.325946,-243.80254,-307.733252,-363.209444,-369.690466,-367.879841,-317.0817,-259.77277,-187.934696,-192.112766,-210.84736,-218.406043,-216.871724,-149.904484,-95.412258,-6.466548,18.077012,42.977291,28.887612,-30.195491,-33.567521,-32.595316,-27.797392,-7.438153,39.043854,38.237823,-52.438166,-116.227967,-151.257086,-53.950896,-3.212358,35.320883,18.983077,-25.68761,-24.375561,9.39065,52.401817,73.233951,76.932873,55.846399,37.075937,64.543752,107.098088,84.627164,7.263198,-58.514309,-78.22033,-66.071553,-31.6222,73.80547,85.810776,-21.429891,-24.057884,14.677082,-11.735689,-57.932771,-97.498811,-73.469735,-0.564402,4.88075,-70.072709,-125.20236,-88.059506,13.297735,21.871754,-19.491837,-43.802835,-97.689325,-114.027972,-93.773822,-26.692428,7.241348,61.634062,96.827656,187.499687,223.283423,249.586839,231.93804,245.802303,347.487023,406.564858,497.271637,509.025077,442.221235,383.000267,372.44192,376.798668,398.429971,390.541344,317.489395,96.31358,2.033783,-148.327037,-311.095008,-353.472493,-286.853262,-224.838741,-151.690423,-141.849759,-155.951305,-201.730193,-239.676791,-308.018647,-303.690835,-228.086829,-181.240577,-92.328445,-59.201427,-38.824005,-112.045573,-156.829689,-131.630802,-80.78722,-60.671868,-94.102901,-137.311685,-184.394588,-254.335433,-354.199495,-332.761363,-278.59277,-286.793763,-298.06424,-288.814643,-296.980027,-358.111576,-394.634125,-453.729966,-464.020841,-383.473078,-304.503597,-272.863997,-439.130039,-463.212512,-263.239768,-117.466372,57.844134,70.610349,25.149355,25.499766,154.29558,246.094199,208.757087,90.865311,61.212669,-0.137989,-60.724395,-127.399226,-38.333004,1.678372,1.329572,-22.132185,-54.649949,-33.064652,11.753089,-29.250177,-128.100445,-42.870738,20.049814,47.93696,4.041156,-92.537392,-92.948076,-55.416174,-77.488215,-81.34236,-57.555292,-51.008139,-39.018752,-25.284456,-41.020737,-88.987327,-195.738463,-184.140326,-129.522214,-33.604972,-28.992333,-65.236342,-85.021709,-126.887459,-106.615041,-89.101497,-102.227065,-113.514417,-79.979075,-31.196918,31.38105,-22.810024,-244.07097,-235.566551,-126.273594,39.867744,38.167438,-46.963801,-84.373036,-131.634731,-135.909039,-135.554592,-104.489593,-54.808962,-4.424969,-40.69759,-121.809236,-124.787146,-123.414223,-150.855792,-119.440431,9.700326,41.70917,28.052673,24.849745,28.679587,-17.306402,-45.714594,-13.270245,58.216752,144.694895,112.312666,30.740728,46.888484,159.947015,196.217774,191.163061,267.313422,320.532419,329.292611,298.303087,231.027146,206.540756,228.143145,282.102588,276.674423,209.089839,179.694065,116.51493,78.279966,100.154087,217.524998,245.467114,251.887224,254.847222,259.153048,232.102705,60.552907,-133.204642,-181.593037,-194.634722,-160.704036,-0.72581,68.370238,21.170192,-59.030854:-179.366922,-126.86351,-65.774578,27.409935,17.462769,-101.580257,-179.938569,-298.866791,-309.286904,-275.284451,-134.790153,-65.245474,-25.195229,-42.402866,-106.497123,-139.74754,-159.740011,-117.294748,-54.243098,107.252361,139.82497,62.934966,-25.628805,-210.552616,-186.773461,-117.208778,-79.983994,-120.838319,-210.155373,-250.802467,-344.474713,-358.66123,-249.460939,-142.353437,-141.024342,-150.498841,-137.637172,-102.110637,-72.81057,13.992534,-5.1759,-57.427605,-81.433662,-58.43594,-43.850043,-37.392105,-55.362908,-106.942849,-226.073096,-340.077388,-369.001717,-256.166927,-132.575581,84.767856,108.97552,-37.227227,-196.347266,-220.840582,-197.802909,-172.86794,-129.436759,-96.605894,-20.755321,-9.111768,-19.766071,25.945031,86.731678,176.452185,146.240777,-30.892524,-102.758265,-72.757723,143.332942,217.136051,169.316949,107.426387,64.699859,86.916008,122.876446,103.894905,78.992065,141.887846,161.222371,138.612853,123.211891,164.066839,205.537704,199.325658,97.764619,72.8942,93.258516,91.698681,35.630106,28.589554,47.098697,20.003246,-89.648838,-79.273275,7.326627,236.845641,306.816914,279.233587,204.593987,94.523503,181.504682,254.269433,296.749088,234.396421,43.279431,1.984646,61.109531,89.388854,72.687116,97.783185,159.612493,315.210204,366.135199,407.86034,413.023298,325.944605,137.662843,72.226219,64.850999,102.470194,104.45479,43.014908,-125.342289,-205.386604,-290.401777,-250.414356,-191.715941,-47.054209,10.08519,81.32584,89.068524,82.804785,173.422609,242.543768,352.346412,390.695108,419.471176,401.312467,311.568718,254.701523,168.029116,130.807655,146.56334,254.917267,284.984851,174.337735,52.673503,-171.738213,-223.454864,-204.456816,-171.95733,-151.049299,-74.518707,-53.239835,-88.415374,-91.606561,-12.327944,16.449692,32.499083,166.521901,224.959259,168.886069,94.043348,51.946691,123.513777,106.908179,12.652761,12.151671,106.250443,144.650188,95.483265,23.898977,-37.63146,91.532159,154.769556,144.445082,95.463183,43.80517,51.053202,61.967638,70.261842,80.113715,99.652283,97.924121,30.203146,-4.49983,11.183739,41.138236,51.96,-6.755364,-13.007817,65.62212,118.233714,141.162326,98.051036,-16.639792,-57.293459,-64.667964,-96.129104,-97.226002,-51.472518,-26.807871,-19.212124,-35.786445,-81.790568,-129.805119,-103.402373,57.402265,88.951931,-50.92871,-146.608727,-225.012353,-160.342423,-119.457442,-92.033251,-91.507212,-53.343172,-3.264281,113.524115,144.70348,125.443321,92.743864,120.033495,217.318205,232.273827,215.004218,221.60445,250.445378,263.653826,257.046398,288.668338,344.545383,383.587705,314.819942,98.56937,10.284607,-149.894391,-317.475531,-327.555404,-187.731897,-125.454228,-153.165289,-216.122207,-294.586148,-254.080397,-237.941622,-315.043491,-376.378793,-367.012797,-279.228597,-106.969542,-91.180154,-148.070883,-168.270541,-153.956079,-91.678261,-64.806065,-51.315842,-58.632393,-130.742602,-281.318807,-349.360628,-416.454548,-420.641596,-383.401676,-349.905415,-355.768576,-407.69967,-468.730475,-414.043535,-406.247152,-477.746178,-498.759323,-370.415062,-260.881862,-187.943533,-300.381159,-329.440177,-285.502571,-252.629456,-194.710675,-156.234287,-102.659179,-92.908938,1.141431,114.198904,104.393532,-4.545323,-70.725914,-186.201225,-220.275004,-224.489092,-198.057966,-203.401918,-192.894361,-145.111168,-8.500613,33.037702,-12.936373,-63.925206,-44.36651,47.78674,40.557697,4.000478,9.531295,7.284667,-6.075492,-45.440495,-121.66425,-151.378798,-134.685317,-112.948956,-128.650798,-154.167972,-169.375089,-160.053367,-172.531223,-198.015279,-171.127351,-118.320254,-135.993709,-183.736188,-193.707814,-258.630532,-353.547159,-379.522985,-332.010457,-253.881692,-122.524489,-117.056875,-213.436418,-292.069519,-388.316732,-361.56636,-360.462628,-383.065839,-368.236295,-279.932318,-254.873231,-285.053326,-237.256796,-184.672417,-141.205616,-153.752182,-240.157342,-302.582916,-364.771395,-337.064864,-221.933528,-134.194294,-114.977296,-117.763653,-126.928797,-155.671504,-177.390229,-185.387721,-152.236049,-169.010111,-217.101605,-176.866864,-38.058788,-35.715106,-141.716233,-160.465358,-84.255351,-45.900226,-35.059876,98.581884,180.288546,216.378237,193.833251,193.102793,252.662213,267.818391,252.578942,254.16524,312.441729,333.382937,259.233574,180.299377,112.975691,205.715992,253.248713,300.023639,294.295555,246.96805,224.596272,177.237179,55.160846,-26.626735,-112.394972,-100.201962,6.863151,79.376774,123.16043,68.62082:-166.734712,-201.435668,-207.693188,-232.703605,-282.324334,-384.031062,-384.767504,-313.546367,-253.020177,-231.611213,-164.434605,-125.019321,-106.700029,-130.193351,-202.354074,-221.27972,-164.338711,-93.6335,-80.254777,-39.959983,-13.709022,-52.886296,-143.10692,-357.804301,-411.998083,-350.296091,-170.069056,-124.731897,-180.560011,-254.49367,-363.852323,-341.226673,-176.906772,-87.83702,-64.337915,32.394062,82.446678,83.344264,27.252017,-91.345295,-141.880767,-166.554934,-206.691126,-199.157637,-129.130217,-101.207722,-143.724152,-188.741714,-174.026846,-101.482699,-81.241796,22.595521,115.952853,268.046375,255.640227,46.074477,-123.688373,-137.739187,-99.298058,-91.872819,-128.59906,-142.235048,-102.083479,-61.662252,-56.68929,-192.565412,-220.166098,-100.857264,-24.725479,11.188151,-29.701322,-123.790414,-4.110338,121.011545,254.479132,229.594446,134.982908,125.157281,101.35562,40.389432,-54.912831,-17.303281,9.574847,36.774338,57.43923,160.023216,200.079588,187.990471,191.78248,209.204561,225.058738,197.593516,80.605999,47.117923,29.491071,0.288221,-68.847964,-67.054496,-35.451927,54.724297,88.932119,103.379306,84.036608,38.943898,91.140968,148.597267,167.827791,109.726042,-4.294974,-20.442148,-22.4036,-22.344009,21.577472,94.971132,124.618126,128.241334,98.037008,77.939228,100.752274,123.725027,92.115893,56.807053,-41.909693,-75.669205,-75.816399,-50.116399,-11.987436,-29.856052,-106.696846,-136.751842,-121.209749,-86.694788,-85.109561,-26.502526,32.749391,121.771134,179.031617,201.800538,293.754396,365.670571,428.061458,408.873785,381.855693,364.06102,248.111528,163.161002,173.360995,174.556798,137.975366,74.455969,61.606303,-1.819315,-86.276885,-66.737947,73.722368,115.638213,56.703621,1.965161,-57.332894,-66.093248,-74.5701,-47.922396,-11.810942,55.433186,63.069677,40.160736,28.516943,23.272113,11.62622,7.194501,66.592996,115.546885,154.527576,128.944296,-0.801744,-76.866825,-138.406918,-26.286868,52.62496,89.781988,55.501415,41.641025,63.990461,79.661666,123.475833,165.399936,181.001647,159.820319,139.736513,137.058245,102.103579,79.347498,42.169391,-36.055587,-57.264583,-4.862533,38.729496,85.481715,73.969435,19.756472,47.529333,73.899805,54.674863,23.5252,1.699471,5.048241,-13.017146,-24.035177,-26.249314,-44.129807,-46.193113,-6.568565,12.181536,-5.995796,-36.201503,-74.356794,-34.933228,-17.873297,13.583399,57.708243,142.583691,145.370562,116.835596,120.120533,169.433275,222.337236,238.94784,267.503007,290.772883,340.882267,331.904843,224.46229,188.816598,224.34084,265.096493,241.427589,134.03203,67.448015,-41.457284,-76.19538,-171.828515,-328.979874,-365.871075,-269.534055,-183.927221,-105.259248,-133.787271,-248.50095,-341.296254,-355.74527,-257.634888,-156.961968,4.48222,39.182833,43.094993,14.835886,-19.169899,-22.278388,-49.485493,-57.565971,-16.80338,16.972735,-30.191955,-156.220409,-188.288878,-195.545029,-221.58376,-205.249806,-92.707186,-49.680349,-108.28646,-179.753957,-251.383646,-284.596737,-304.336498,-263.762798,-221.095376,-141.34513,-113.161584,-191.438016,-338.262905,-309.039947,-86.208144,18.231844,144.444287,164.909228,113.699459,77.800598,102.429372,176.860945,173.663482,72.858996,10.025308,-15.006717,19.281434,54.937103,68.520808,85.218987,56.473703,26.641142,50.594457,93.3939,44.512561,-84.189129,-300.9554,-224.968004,-164.911218,-162.284748,-196.641915,-219.095072,-195.229888,-198.753991,-275.075087,-268.715787,-154.906347,-82.216051,23.282306,35.700161,-78.608956,-194.548814,-342.47369,-272.730003,-208.922666,-126.949468,-114.725722,-104.833935,-106.952269,-138.794672,-132.749636,-107.878582,-55.730346,-39.939004,-41.754822,-39.539133,-55.281372,-120.069895,-281.687321,-247.368169,-167.380007,-26.064295,4.473184,-17.861126,-60.885176,-167.241758,-183.562823,-150.53928,-88.536354,-71.489265,-107.047781,-164.771821,-256.77318,-260.719412,-226.527491,-162.988789,-117.476515,-69.852263,-98.467743,-158.233094,-135.262525,-60.765435,-61.159648,-100.547965,-174.389064,-142.68991,1.753715,38.649725,63.652415,96.552754,137.214077,70.771729,69.012715,229.527707,314.385138,304.92273,248.957314,201.30617,199.644953,180.422717,205.823466,277.937489,361.600084,310.486338,145.651888,86.982339,36.521301,100.586741,168.086135,272.757926,277.202938,231.118821,197.416004,88.189563,-36.378725,-79.482464,-62.3753,20.326379,181.665671,178.711668,45.908228,-28.047319:right
274.12769,304.293805,305.413392,341.083665,356.865025,359.554653,356.489108,342.708535,344.89837,359.632641,445.122759,516.720422,574.717565,525.150969,413.666021,393.332929,335.209303,194.035066,132.261182,117.517084,160.195579,307.639809,391.842406,444.600046,292.637456,193.986489,67.21696,58.842961,120.478513,162.963875,196.041621,170.688909,101.801614,90.548477,87.470497,92.033249,114.848302,119.391191,69.795877,-62.488769,-148.222535,-183.167131,-263.954041,-281.269033,-222.629718,-171.800853,-83.335092,-53.074063,-52.231361,-141.430683,-175.651045,-106.928983,-40.673616,1.713319,-20.011361,-90.628363,-161.131471,-209.021835,-318.055446,-350.034562,-355.832543,-322.37047,-159.317944,-77.821581,-4.32464,65.645651,101.472997,119.392758,100.074848,36.547593,7.650692,-75.775898,-204.971023,-239.922637,-188.486327,-133.648867,-79.233813,-80.340753,-68.146785,-52.365484,-49.408483,-129.957509,-159.369312,-114.9902,-85.028344,-57.865619,-36.955517,-2.628409,-11.451784,-11.821178,24.00961,44.175648,4.555808,-35.170226,-57.240483,-80.274133,-249.308162,-395.452409,-411.308975,-429.729256,-449.872127,-392.308258,-299.0224,-160.877229,-214.460754,-280.215937,-340.805574,-308.746853,-218.921083,-172.408308,-55.186711,-34.71891,-141.086863,-334.668475,-404.940262,-373.881914,-283.205498,-123.077768,-110.380697,-187.286792,-207.267687,-177.279384,-96.998392,-53.882589,15.251093,42.8405,112.522832,112.315716,-60.266713,-319.405792,-385.183144,-279.383985,-184.204041,-113.46229,-107.379359,-97.284366,-206.184996,-304.544323,-415.608563,-368.392695,-159.691118,-67.658071,61.259497,107.469812,154.099073,78.964845,20.870589,17.943819,61.314403,136.025422,168.472676,187.505989,74.80173,8.326261,-21.06177,17.634631,108.306299,130.877428,118.526365,89.379223,19.769653,-78.567022,-131.563952,-93.878826,11.977416,229.794556,263.085935,117.147523,-67.483255,-89.636131,-65.469368,-58.589159,-41.694793,-7.445496,82.056249,82.743481,11.558486,32.648674,61.998616,81.718007,91.514648,144.337614,168.52064,153.779786,58.432098,4.869105,-30.467062,-9.837207,28.253186,28.375383,23.433536,26.75914,8.6257,-29.230761,-36.173718,24.035946,85.975482,194.733032,220.31744,202.072065,178.861396,160.200792,77.007781,46.95238,48.202029,72.304895,195.938446,274.29776,253.676845,-56.167622,-184.601952,-178.485354,-100.968957,-22.474487,-39.140915,-95.186713,-35.699304,22.345872,90.527791,122.253383,213.604662,241.770915,236.318173,217.246366,212.874129,225.603439,184.069432,68.096727,62.01362,208.638676,310.166269,371.350512,283.747467,244.533188,155.122295,101.623205,75.591358,125.057703,247.18919,265.813936,193.236928,47.172263,-18.129245,-37.947819,16.405292,137.192574,151.402931,91.197016,35.499754,22.315047,25.293527,50.738655,94.859636,92.422248,78.19445,77.796402,72.974631,33.926814,12.208498,5.77733,2.018276,-40.771272,-59.722319,-78.083957,-116.290131,-154.226158,-202.422388,-180.458203,-113.27044,-90.209735,-5.669967,57.890106,173.478571,151.375595,91.65464,53.196675,95.987815,187.868423,194.094613,102.456891,-28.645915,-54.193298,19.063417,107.343753,277.492874,336.721347,419.815274,402.925749,190.140499,-22.338165,-45.370953,53.173904,106.443683,119.169344,96.081184,35.021715,-38.383398,-86.626516,-132.823701,-91.905222,42.363132,82.942017,78.627583,37.274192,-55.847363,-70.448228,-71.93834,-74.360195,-56.21763,-1.620311,-1.164475,-100.630689,-198.162443,-207.509961,-198.8634,-188.051373,-160.822142,-136.746073,-39.621352,-3.989825,-7.480355,-24.823852,-38.725745,-49.111443,-29.527583,14.811824,24.304025,55.166633,101.229529,99.280148,62.046158,58.676178,87.842307,113.422362,214.289989,261.601215,215.317035,9.184034,-68.648792,-83.595738,-67.029096,-48.517114,-31.131324,-30.288712,-63.344442,-61.754881,-83.07831,-96.889294,-70.503748,-41.324577,-0.191932,-11.430829,-79.538309,-118.060945,-115.412626,-71.390198,-55.658101,-48.161751,-18.49642,49.462392,-42.797884,-142.208753,-292.051066,-303.976094,-263.313246,-228.014175,-120.972051,-82.16046,-95.261234,-151.686131,-188.476408,-276.956212,-303.850287,-275.376855,-227.963462,-186.346246,-273.874512,-320.290906,-338.2903,-294.110865,-188.201991,-190.830755,-294.178371,-340.378228,-384.842953,-461.967601,-494.970186,-449.816664,-397.293273,-366.41015,-401.19899,-471.411494,-411.857173,-355.846823,-300.548861,-295.585815,-241.714882,-187.581642,-144.18451,-192.494906:246.570574,237.210429,220.737221,276.953574,328.78111,379.0288,372.833422,352.079029,336.192225,305.460277,287.338794,336.716992,409.940151,396.004052,383.569609,398.912444,387.537313,262.159612,191.776535,135.241003,140.013009,193.123184,240.246559,283.207439,186.08595,125.630967,72.501413,88.075845,172.286492,222.312632,281.353313,275.724547,217.434334,144.588751,125.18755,149.455382,159.837646,98.178443,45.768839,-31.010664,-113.490361,-164.509681,-227.154701,-234.688642,-211.24643,-176.362522,-149.722137,-181.531403,-215.453369,-154.610684,-138.952349,-135.095287,-119.606601,-32.688618,10.109042,-50.234467,-268.060417,-347.121502,-359.437426,-323.456938,-252.445047,-206.339249,-85.506328,-61.28375,-110.85076,-69.716819,-14.657704,25.240443,15.271068,-2.158145,-17.257326,-132.021681,-299.236027,-334.765055,-283.804667,-241.510607,-193.933363,-160.803858,-52.850624,-27.242306,-62.456303,-133.698109,-149.574782,-54.426847,6.50867,18.93569,6.084781,-18.349149,-86.435182,-103.629462,-52.422854,4.031506,114.135266,145.293274,118.14856,50.174505,-125.128429,-234.663312,-293.767914,-415.034787,-423.396833,-299.412454,-215.271645,-149.49949,-254.468022,-336.159477,-406.69894,-369.368283,-284.541076,-269.92097,-220.944361,-193.096861,-214.920386,-329.425691,-385.757533,-383.668725,-332.428163,-240.976431,-220.884789,-230.819649,-198.324952,-161.231183,-131.466278,-133.101338,-130.60167,-124.038765,-87.076693,-76.361722,-181.851277,-408.774044,-471.711319,-369.184976,-272.250507,-195.972678,-201.006152,-219.028148,-304.434623,-366.160514,-417.555685,-378.896856,-213.970347,-121.204797,15.308565,37.014664,-17.259768,-122.713337,-121.615327,29.014447,113.801822,203.782927,215.730733,198.506781,82.649828,-12.678615,-103.935318,-49.904428,133.07713,178.301992,122.644596,42.138882,-133.1305,-212.459495,-214.030902,-161.736787,-115.300654,20.056943,76.566013,21.786918,-130.245202,-159.115208,-129.140825,-87.545558,24.10011,66.470905,43.777279,6.99236,16.38924,46.246741,22.515238,-25.064274,-14.107698,77.630248,110.730746,35.833346,-125.9191,-162.976677,-90.949866,-24.101109,30.261638,23.612187,-5.234263,-16.062197,-11.825196,-36.113018,-40.554768,60.04641,148.018128,288.05987,315.888666,300.10591,230.580642,168.00705,33.266608,12.17879,55.288058,91.119139,203.096131,253.24549,155.750355,-137.334029,-205.705077,-123.58106,-78.55391,-69.04649,-57.798971,-35.222626,-61.812496,-54.416888,53.251299,111.374416,156.031032,164.405041,148.466042,113.437676,92.647976,90.027955,45.432967,20.871493,81.846396,258.739667,321.94471,316.986877,206.460742,156.23118,135.227458,151.420248,151.084254,153.865362,220.59697,248.150622,215.772112,141.273537,104.911335,26.275793,19.708602,103.270425,138.343717,122.261636,103.946459,92.821078,48.251469,46.621144,116.058994,165.824077,176.623824,124.91328,37.913248,21.427314,9.642904,-25.78516,-33.196658,-8.492196,10.523143,27.746366,6.92596,-30.925216,-120.205333,-135.188136,-14.725864,132.760664,379.725921,378.655007,220.302152,114.15804,87.445476,36.66545,43.549364,165.154216,212.550729,164.313509,36.90304,-0.747702,63.32954,140.176316,222.268666,226.178432,232.354997,225.409311,146.086155,-6.023508,-72.968866,-93.523793,-46.912328,80.966679,113.799911,73.936603,2.493631,-19.442838,-33.559427,-31.187366,10.006825,65.273734,149.943165,131.88446,73.918081,77.201867,57.402298,27.562035,65.172484,150.640686,128.992556,-21.322683,-153.437508,-199.500619,-241.321678,-214.888935,-100.168335,-39.89285,82.687528,107.118069,26.82589,-60.850131,-60.315219,18.23269,44.339809,29.538802,38.899634,116.899568,112.963654,74.31829,75.25794,126.5576,199.244519,202.344637,212.019891,215.082663,198.648342,197.418465,181.947965,87.152494,36.45805,32.996469,71.215682,59.500392,-56.629043,-81.580512,-55.141009,-34.350419,-32.830641,-36.468343,-15.730397,-15.725473,-64.742904,-98.490854,-98.298132,-85.331607,-71.707969,-14.727121,24.707066,67.943059,-20.627456,-109.459119,-198.007201,-159.317515,-45.364325,-11.386278,25.85034,23.320872,-36.129257,-103.096001,-125.380312,-166.011191,-189.460226,-194.65361,-167.642683,-162.985988,-237.209206,-257.062989,-243.934484,-213.643123,-83.193646,-0.463474,9.831892,-83.122231,-266.72562,-360.047422,-390.367488,-377.128136,-352.913992,-369.322838,-397.067449,-367.500378,-234.037725,-193.123457,-164.948609,-140.192212,-66.954859,-43.099789,-76.659761,-128.248424:332.156808,273.205838,285.761488,305.38726,278.937833,250.849066,282.479385,357.348153,314.367664,257.518036,194.194433,199.577269,229.156608,252.049605,313.764091,325.337772,277.69886,182.205665,131.747617,62.513454,55.670791,93.017885,110.78347,114.054736,102.463338,79.560345,44.538837,50.657867,116.981238,189.297416,311.1932,306.40907,265.243246,333.030161,338.70043,189.053323,110.809889,113.322795,151.979967,130.930156,-18.610547,-87.893261,-99.681026,-44.842911,39.208877,30.403223,-67.483832,-119.696567,-148.591153,-90.840589,-47.803843,15.980593,25.324223,49.68015,79.93482,92.114753,-72.974414,-168.421389,-209.664826,-163.035071,-79.505195,-68.453014,-48.727006,-25.665025,0.057172,-16.53523,-15.388521,4.002862,-0.90661,-11.899386,6.628213,-14.533584,-213.961935,-298.49055,-261.890444,-179.27504,-98.565269,-96.906719,-38.421706,-3.138305,-56.007699,-205.124233,-235.444571,-139.174332,-62.143463,3.416463,-8.205356,-46.051213,-49.809112,-40.745916,27.280594,92.917405,204.70406,234.10052,251.292244,212.861027,-4.975888,-242.60071,-281.20982,-200.584521,-153.343201,-117.214735,-107.419989,-128.192857,-241.935145,-294.494546,-265.516258,-199.935093,-119.980409,-106.54999,-69.763655,-80.036846,-178.645929,-222.049083,-218.318687,-188.972486,-150.008938,-44.129933,-16.902384,-58.987528,-143.963728,-168.317289,-135.58402,-102.54958,-93.051544,-88.097397,-3.085343,23.869261,-112.462231,-346.514121,-384.120121,-293.00219,-248.942456,-253.025221,-262.892631,-276.051078,-370.471861,-428.451733,-458.897243,-419.783131,-284.323978,-206.491212,-89.700679,-65.680808,-64.959284,-138.746617,-136.217228,88.617839,218.105575,247.538823,186.584471,139.755883,128.037228,82.046895,-12.081477,-12.873186,110.380227,197.038045,223.99766,126.580001,-121.888345,-176.572982,-127.165865,-19.117858,8.763488,81.801446,120.366478,51.429709,-141.82404,-184.840317,-98.170903,-13.469776,94.84457,100.386719,28.387023,-31.457379,-101.89211,-63.694528,-36.614307,27.069213,74.965286,161.814853,164.502367,91.811461,14.560216,-27.019537,-77.372858,-82.648225,-123.354284,-129.692616,-30.382571,21.160315,-19.135076,-125.260584,-113.538037,45.546236,136.412272,260.213493,284.891634,248.601793,127.023821,61.349826,22.583304,47.912851,92.712305,126.405636,267.603739,313.668829,192.681553,-60.050941,-124.498341,-114.583877,-109.979274,-132.218642,-129.796531,-100.121235,-77.225735,-79.603852,-55.55128,-13.0914,96.280056,135.617412,122.68669,82.377652,1.269313,-44.277052,-39.805611,-7.035176,18.236491,151.969671,228.748736,238.19743,102.153756,42.140312,-17.385416,-13.244437,62.53487,125.129513,231.906916,243.130544,207.964311,134.944857,73.783444,-20.600558,-24.249289,40.215261,77.570237,98.36652,60.276309,38.973422,36.422398,36.748383,2.000723,11.548427,88.686565,80.072853,-44.646119,-54.112782,-10.564673,23.412715,-2.066547,-51.027033,-41.175569,11.288218,-31.463612,-86.493918,-124.807264,-83.789588,84.857914,197.240163,370.586708,377.438443,281.043996,186.742171,135.314107,54.349924,78.075161,252.797944,304.157011,172.947956,-37.312186,-51.399494,65.148735,103.863198,93.940054,99.988279,128.885755,106.446082,17.688154,-24.590334,-19.710929,39.916326,70.356238,85.74703,95.786419,151.524513,117.279905,30.572944,-137.839196,-150.618803,-28.566332,63.709763,140.631168,86.525995,-90.199773,-170.424805,-160.536376,-82.829976,-44.498709,2.249648,19.819885,-3.283477,-165.146119,-255.785151,-351.432075,-349.17359,-219.465629,-104.703801,35.558494,15.527147,-71.265217,-74.518177,-41.789919,15.574379,12.526881,29.066388,58.569059,50.119895,23.814504,37.4671,68.807542,79.805593,135.835173,201.279304,338.0314,359.016801,269.05106,96.557145,42.25391,40.160055,62.937838,89.661397,88.964888,58.898562,38.164653,46.378925,86.588562,94.434337,52.089583,53.512828,133.152851,138.89813,45.181586,-11.660266,-5.962921,14.621862,25.823847,81.11903,106.22427,83.178098,20.267145,-18.816776,-108.318349,-124.999582,-57.607033,19.489602,172.407344,194.868747,99.591843,-66.898068,-142.195238,-241.820824,-226.845597,-53.908844,24.568768,4.282771,-124.325409,-168.086982,-180.596165,-147.694988,-10.106045,65.390221,55.364289,-29.106573,-153.770403,-242.699458,-305.839399,-341.71597,-295.766003,-227.478674,-240.077941,-313.851786,-362.288537,-343.707162,-222.216727,-145.79228,-48.937828,-53.918759,-106.53239,-105.501941:294.16947,284.708539,300.905342,373.223047,395.740381,370.7505,354.16962,374.888804,421.908351,432.061017,422.650814,421.507179,432.546306,428.911591,389.293927,347.317542,242.02572,165.516009,139.810774,118.668114,124.760967,181.123389,227.521295,282.940058,223.910373,162.33583,60.043801,49.613483,96.534721,142.878252,237.04718,239.715064,169.981646,197.743192,249.724444,331.826878,346.282029,328.216053,307.245102,244.529147,154.134481,107.6938,35.849884,25.686101,77.741279,113.867723,94.388809,41.005952,-36.222652,-53.958745,-57.562551,-14.084929,27.953873,112.386949,146.741009,102.507467,-52.867913,-109.906352,-186.096907,-204.712055,-162.88743,-103.677394,12.535587,35.862287,25.838743,0.0513,0.978385,66.284851,96.676577,83.888027,73.073444,29.629685,-138.31675,-217.494323,-212.705391,-137.255728,-25.885696,-39.117581,-115.550078,-123.808048,-88.605751,-131.323954,-165.912594,-126.618597,-74.380737,7.940393,36.790444,47.161611,20.296345,17.133903,69.766533,117.754784,166.229347,160.800437,122.319637,77.86055,-64.976151,-208.270537,-252.510458,-261.489956,-230.582045,-104.718546,-36.861054,-5.162214,-90.305705,-133.64055,-175.175598,-177.780558,-194.383758,-197.790453,-166.34799,-163.749021,-227.228803,-332.067318,-389.030848,-407.826265,-336.906863,-167.929898,-138.472416,-169.438978,-143.201138,-113.099705,-117.162187,-137.774403,-149.590973,-132.104658,-35.718409,7.008306,-66.129325,-289.422966,-347.626088,-232.354035,-141.97314,-110.172228,-139.735219,-177.387947,-282.344589,-369.321194,-430.20139,-366.310449,-192.38494,-128.629838,-9.605102,46.157182,87.604983,4.921824,-25.731348,72.713193,157.294053,244.584621,249.562523,214.05107,134.856874,93.458782,50.296735,70.462528,176.98573,224.483787,225.602452,171.43029,44.68243,12.179239,28.091911,73.768688,91.852134,167.268488,213.223735,162.644043,-27.705777,-79.503563,-67.721129,-48.364447,-16.419947,19.085797,96.84768,94.021126,25.520259,39.066703,74.291321,143.456062,181.785017,271.700193,293.902573,204.909828,11.025259,-74.61675,-110.555391,-62.116992,-8.408229,-22.412273,-21.857036,1.433236,15.141281,-63.049081,-84.548006,26.688954,131.17734,261.849664,248.020698,153.213129,155.026734,158.942488,77.529321,34.574244,42.090411,93.81185,251.006926,299.366862,188.032602,-82.049519,-152.190788,-105.849307,-66.690681,-54.023051,-60.012097,-70.33945,-56.889001,-51.071076,-53.046674,-21.965125,119.441229,186.868098,228.04928,190.00099,62.979026,-12.724044,-13.056482,52.845835,110.516955,255.404596,301.713703,226.128731,51.978184,1.516308,-23.819391,-16.335374,26.51763,69.110469,179.795019,213.48238,177.058757,46.429245,-11.411009,-37.588125,-10.423168,37.511988,34.302646,17.002282,24.463631,17.436338,-17.554321,-29.72394,-28.90384,-14.991067,14.022151,10.671093,-40.724686,-104.803214,-120.271867,-126.430957,-127.568916,-92.820019,-67.135613,-89.231278,-162.800252,-205.308318,-250.169549,-209.627032,-39.708254,41.052008,131.1902,142.101124,160.849883,140.562054,91.914957,50.474996,80.635358,114.447492,87.570042,7.827839,-55.269072,-85.351554,-70.608079,-13.728791,91.906649,117.104189,135.609852,104.366478,-64.487591,-159.122951,-138.848461,-52.219148,-17.072659,39.229028,73.146851,109.979038,-9.272761,-124.338891,-298.060121,-296.27257,-136.572377,-44.304722,22.236411,-15.506565,-142.390561,-212.220251,-230.844104,-234.555919,-213.145007,-121.297185,-65.216336,-58.771453,-208.867937,-282.307418,-334.71491,-307.178706,-185.939216,-107.556641,21.617744,27.985096,-68.32477,-121.2379,-104.640677,-40.219881,-9.369175,-0.015643,-22.317752,-50.328674,-10.8412,15.065862,45.688034,62.972728,136.861909,189.383983,267.196481,263.709073,180.225402,105.19199,78.325894,28.360962,17.67386,57.823077,86.698068,72.93337,14.933077,-5.148692,-27.56866,-23.682893,-1.514072,21.335602,73.849253,50.147197,-84.94172,-118.923151,-80.883966,7.306111,21.275239,-4.861194,-20.848181,-55.810401,-110.955728,-138.587629,-165.819837,-166.512724,-140.578059,-91.367759,27.388075,29.77669,-66.881101,-148.725155,-200.762121,-303.029424,-317.840028,-278.552573,-243.793209,-176.446086,-157.922036,-188.406597,-266.575125,-259.751966,-166.311714,-121.765858,-110.873679,-159.192409,-292.637384,-416.496334,-466.292389,-426.437086,-358.682905,-321.970239,-360.631078,-453.89631,-483.399097,-464.825977,-381.598787,-323.907899,-223.175365,-192.565239,-126.955476,-91.512762:274.865732,167.323996,196.595598,299.20559,319.391651,318.082269,332.634431,405.681101,443.974031,411.156624,299.324392,270.881599,286.760638,316.190805,368.655009,347.329951,191.994474,21.177272,-21.710546,51.360843,139.023679,273.578302,289.35284,220.94969,93.751894,35.07001,-6.99191,13.03055,91.18646,142.534421,250.651679,280.662,258.927336,184.612819,157.667608,157.01181,188.853423,311.08309,364.939551,346.771444,219.867999,182.971747,200.917482,227.919167,244.977315,222.993828,107.596048,31.597084,-57.29382,-22.713815,13.677348,100.800324,157.463995,265.549007,274.637052,143.086125,-18.195448,-45.866783,-71.420044,-90.685799,-33.578299,51.733926,146.4407,104.811926,-41.043302,-78.558446,-43.702551,41.040635,47.898641,54.5672,93.716389,124.841104,-31.190361,-111.248975,-73.451334,36.065249,201.750417,203.549337,111.130348,48.426748,-88.869306,-205.630872,-211.412048,-79.830968,5.736103,103.342229,100.491871,-0.020436,-95.796782,-100.400805,-28.976305,25.183978,131.585124,164.60843,86.566362,-27.333795,-230.108099,-241.482509,-198.188038,-124.53826,-115.562872,-46.832852,35.094839,77.64259,-166.447511,-279.177868,-285.748949,-217.184018,-118.635133,-98.22257,-86.929468,-119.500305,-266.693817,-433.018662,-470.31702,-370.632013,-271.887341,-131.456186,-103.705724,-84.089469,-122.406921,-164.410415,-199.947509,-174.577162,-124.132112,-115.848867,-101.349357,-102.141677,-132.261199,-214.819483,-257.565048,-250.855756,-213.025232,-156.873998,-147.906251,-192.431806,-346.782691,-433.863867,-519.11087,-482.876499,-278.189405,-176.643817,-116.096252,-139.806747,-170.509918,-161.666054,-132.052668,16.146478,96.813865,152.727406,118.148856,14.630675,-35.536735,-54.166607,-63.953724,-34.600783,54.844485,95.00781,149.646696,138.731004,28.502142,-107.711786,-134.878105,-84.96571,-35.933722,96.13084,133.384114,-6.345231,-267.482308,-342.918363,-314.785651,-230.094836,-63.136316,-22.605246,-25.563012,-48.606062,-81.878144,-111.250912,-140.798763,-132.886899,-61.492869,122.11338,162.960309,65.186679,-149.610212,-222.174817,-195.644816,-135.084488,-63.502744,-54.993772,-64.572005,-74.360201,-90.219479,-138.043301,-139.067165,-1.684553,89.223595,163.563993,157.509589,139.449938,81.034752,17.436236,-108.279557,-121.573047,-20.780901,71.505711,235.4891,243.702605,56.176948,-203.918085,-257.278225,-171.517061,-94.553836,5.175708,8.27715,-41.991927,-81.784906,-120.738793,-174.627061,-130.120242,49.560522,116.550567,123.533808,78.429241,-16.780647,-64.134674,-66.533992,-3.941893,64.820761,238.293469,299.27334,260.788739,77.029334,2.254267,-40.754338,-15.218109,93.143725,161.319038,280.93327,297.031899,180.776027,-24.316321,-91.535748,-61.871313,18.421014,156.137068,160.83971,72.352391,21.522355,16.797755,-11.14586,-23.931814,8.708598,39.884772,42.751469,12.928263,-44.524282,-87.617137,-96.138873,-56.417525,-20.787258,51.204436,71.15004,26.554861,-56.590628,-68.332637,-33.321634,1.082518,130.627708,224.302511,362.153307,379.701501,343.308027,272.219402,259.310374,300.734736,319.328757,325.501838,321.954594,277.737723,179.197429,135.650349,116.035391,133.103246,173.210977,193.231624,189.862294,151.188871,44.459117,-42.60638,-47.056473,62.98751,138.820383,220.894078,213.122818,135.250768,14.040217,-67.893758,-168.043986,-137.273053,32.419254,124.947842,210.225892,170.666738,-17.119764,-199.402754,-238.144839,-195.82756,-157.577718,-93.217523,-64.959982,-98.889825,-280.895934,-372.902136,-424.253244,-378.698685,-228.742342,-142.933737,-12.87618,-12.072298,-122.061618,-173.203181,-137.857892,-56.091357,-51.340322,-64.470384,-59.307323,-51.594102,-43.770409,-58.670611,-84.315278,-38.081889,126.409377,188.788795,232.518693,217.359402,156.23408,79.923335,32.44557,-13.164384,10.35634,86.915314,98.554062,58.663812,16.88877,-7.101776,-17.891245,11.085836,70.052846,91.689316,137.50075,132.960097,2.440567,-141.103875,-148.135872,-85.30787,-47.663231,17.022546,36.296156,43.344382,5.959385,-33.084017,-107.813535,-94.253497,68.031343,169.651692,273.807393,245.446687,80.709923,-83.895318,-128.864543,-109.314588,-73.942207,-19.597655,7.106279,32.038597,-74.299639,-161.200912,-241.843137,-203.603038,-28.538001,69.439519,150.401876,90.1696,-135.649546,-286.669502,-302.630087,-232.290614,-179.132696,-105.261982,-88.362675,-116.046286,-213.262011,-241.426014,-184.182568,-107.141868,19.895818,22.997489,-23.623007,-24.858451:218.184824,174.311897,199.772129,313.04499,357.638483,350.641858,320.277179,281.645579,287.389369,295.318443,320.248139,340.937381,361.770462,338.019845,214.053673,131.554844,-4.493752,-37.327902,-32.33544,17.511718,77.029103,186.035435,195.026353,163.998246,146.98565,99.444574,-68.225271,-86.653979,60.162566,126.441274,109.888951,50.917771,-57.570909,-56.936011,-30.871297,33.828983,91.398477,186.03294,159.390834,7.41965,-12.558147,27.314873,13.37405,-35.892182,-74.584425,-43.830952,44.892428,59.962063,29.995942,12.272666,38.926663,156.17296,191.510541,149.597291,103.839843,2.133087,-86.330174,-133.762946,-287.833489,-366.713344,-358.611522,-260.51478,-86.694241,-60.090302,-16.317229,64.019914,74.471929,51.445592,49.706999,85.610217,91.977196,4.189658,-78.727773,-76.645378,-105.283341,-151.967604,-196.646474,-160.062231,-66.320386,-81.177476,-169.210324,-213.908142,-249.615977,-292.938191,-271.815121,-171.116943,-110.139793,-38.071889,-44.515776,-43.634267,-16.555141,-5.956767,-53.526458,-106.797098,-189.296339,-206.562967,-227.835208,-287.267037,-317.676735,-329.599231,-321.470567,-242.891654,-146.806855,19.475052,-66.438024,-153.811472,-223.765009,-202.985965,-145.384542,-122.083319,-82.793786,-101.807015,-250.142493,-415.434673,-450.344238,-345.734873,-241.621722,-93.327556,-72.753687,-89.086739,-80.307144,-69.934793,-58.359755,-32.957058,44.787692,69.710015,127.955032,162.318944,98.504538,-179.457339,-290.546895,-291.60157,-227.66243,-118.891899,-80.711646,-44.142131,-94.192949,-175.402799,-361.24203,-360.003909,-169.537048,-85.039731,10.805723,70.259095,175.317885,125.406871,54.34598,-48.702056,-25.811124,155.934354,240.934337,259.940433,157.583843,123.73222,136.635837,173.790059,241.42455,256.430053,273.642388,273.468069,207.847047,68.459144,21.266991,96.955307,205.38095,376.497976,395.857961,318.774329,159.645932,75.532548,-35.670238,-40.675435,30.869945,97.333373,235.187798,233.077593,74.891622,63.110986,147.584288,310.511537,349.510677,328.742364,280.704594,178.473407,95.316276,50.030701,12.279447,46.099382,112.363514,106.798558,71.053823,44.236633,-36.8258,-55.344008,-45.303178,6.367595,60.576501,205.320612,261.984886,228.431614,130.141769,117.223398,75.083596,49.137082,100.869028,161.916788,258.185443,284.665329,234.617967,13.674472,-83.019961,-96.69439,-54.922325,-0.891079,17.820824,25.878258,10.793425,25.49891,107.28385,175.762454,317.000362,359.802394,408.48224,424.609749,369.256979,193.955976,135.586674,170.830794,222.764348,329.762505,386.066696,393.270713,302.375497,284.408373,193.564359,101.055828,60.16138,167.380846,407.574732,420.587659,237.945859,63.611288,42.501185,94.190443,130.974543,185.694554,207.300744,236.13754,231.973158,224.472759,193.702061,170.352146,134.095094,137.472325,198.486475,221.083027,209.646286,154.124641,121.266854,139.163596,166.810766,119.591102,80.210127,49.694279,-64.240356,-160.12089,-268.152435,-227.636438,-24.461199,88.542785,278.544216,320.616082,263.876742,104.217512,37.358022,45.474616,123.957013,280.929176,285.397932,141.150941,48.943577,50.225472,53.753375,72.051391,175.482359,236.682101,313.313408,302.677951,195.379147,86.00507,67.055002,148.775244,211.407029,256.55579,243.381224,133.830569,-46.475684,-105.057702,-137.291421,-122.883018,-39.046737,20.004772,46.903374,-18.089225,-167.536145,-215.21756,-234.55521,-276.856592,-269.085006,-157.157591,-89.683676,-55.259157,-142.130636,-197.944778,-238.717992,-208.665302,-147.783695,-133.7362,-75.256758,-43.93734,-34.94904,-44.936084,-55.924736,-108.167065,-139.631294,-148.857297,-123.128131,-102.089207,-83.16933,-43.204045,-2.920415,-22.62892,-37.609547,12.812988,182.078623,222.311137,132.746975,-48.004274,-127.774118,-176.617983,-143.488466,-74.862505,-53.614185,-22.583213,-29.444987,-54.368677,-115.791855,-134.106157,-159.900157,-161.725862,-100.217001,-65.621081,-85.178913,-157.818478,-168.600416,-153.537762,-154.29191,-138.273899,-89.71255,-15.957612,-165.276854,-283.091385,-396.294657,-357.943709,-228.664487,-205.40796,-222.99367,-222.015838,-200.234385,-240.507151,-286.168301,-364.954659,-390.170381,-376.136728,-316.203124,-175.109874,-167.630335,-233.56008,-381.534398,-377.899267,-229.307967,-161.51471,-124.041816,-137.30255,-200.685667,-336.025543,-404.42746,-423.15276,-386.840452,-341.009274,-342.719113,-391.449613,-412.350596,-388.554435,-342.581737,-321.114936,-217.031383,-141.054005,-41.331289,-55.089862:73.264618,61.442318,113.507704,258.858836,318.095839,373.44214,370.303712,296.557168,233.713007,252.344897,329.143729,345.972948,306.636709,277.599434,249.105981,224.644385,99.071243,-90.260952,-135.886328,-40.803215,43.02672,155.898116,178.637349,160.109839,90.603706,27.032527,-77.201505,-53.311032,75.353368,121.791293,167.154591,150.788483,24.993246,-69.816789,-64.91622,56.695509,163.116817,335.838376,344.374778,228.607896,153.774192,151.267824,131.369469,115.846118,102.267567,114.761538,131.782095,89.192312,-53.719349,-120.250879,-103.316071,48.639959,148.155443,267.138036,274.380801,185.122867,19.069833,-73.335483,-251.141399,-278.239996,-147.552802,-53.750782,40.29244,48.477925,41.30357,-27.293998,-62.109786,-23.436886,25.934439,68.147756,64.898171,27.505259,-91.827257,-161.923144,-200.095211,-146.544468,-2.172835,25.366596,-18.933441,-62.266689,-162.399357,-290.970907,-337.469554,-295.963533,-229.555127,-95.118587,-45.765335,-31.145475,-98.799741,-144.973252,-180.420759,-132.004823,5.742349,36.066123,-8.741389,-69.361053,-191.469002,-242.595633,-245.497826,-222.161511,-184.384552,-45.455835,24.404688,67.035605,-56.768982,-140.122044,-203.074775,-179.718056,-126.938517,-108.799434,-73.897744,-85.371203,-195.590482,-330.900163,-370.687209,-309.700458,-225.624216,-84.271462,-42.853438,-9.104706,-63.337648,-123.626004,-246.10301,-247.644993,-96.716271,2.980293,139.078692,139.42213,-18.360339,-249.980175,-312.505437,-221.311398,-111.531236,38.729952,56.227325,-12.097108,-233.730602,-360.463647,-462.993472,-424.430106,-260.369807,-156.133941,40.329203,89.484635,54.398974,-68.704596,-97.661007,-1.73066,82.324303,202.848,229.757947,203.243603,106.753834,45.799955,-46.692759,-29.696189,109.136022,175.692946,269.846917,282.222483,143.599288,-67.690706,-75.894648,119.357563,229.214893,348.450241,365.200347,249.886115,-35.169508,-137.321911,-165.820934,-124.266825,36.338528,133.678645,191.867999,125.47788,-44.006024,-49.871834,5.679,140.043639,202.581392,292.745539,294.40831,191.921659,46.880666,-23.534725,-84.523401,-49.734982,22.659989,29.05584,43.17338,30.535615,-70.197567,-99.912251,-61.531717,68.203646,140.584426,293.046177,348.838576,297.534283,140.291644,93.440125,34.081381,22.416608,93.827874,174.115506,332.81193,349.090917,190.904549,-46.365961,-107.506207,-62.613616,-3.682343,87.891736,109.361068,44.994073,-32.041494,-18.362408,56.974721,107.602049,235.339409,304.800096,375.959578,346.956453,233.693921,155.224997,133.687123,192.170993,291.90196,527.925009,574.659608,440.253856,265.174212,225.840351,180.040291,181.108024,259.839017,314.514241,405.416123,416.784665,305.18277,112.828029,59.221238,88.733415,146.901918,267.666568,304.707304,313.130075,268.956068,215.03875,116.558485,131.740921,243.970664,277.383731,254.059154,215.7433,106.791093,-22.249115,-52.415587,25.402736,101.6092,191.119203,191.746825,127.487964,-20.934918,-102.215249,-146.774992,-86.512401,149.393997,289.179671,461.10433,446.114844,291.282724,127.017764,86.458419,158.689229,232.155421,314.088497,302.370733,193.320265,85.136587,47.936479,33.885756,84.258807,258.265984,332.402653,384.136685,344.706141,161.212702,46.837055,70.207381,186.11077,226.595517,292.023787,318.425512,249.02847,14.331976,-106.248185,-186.386984,-128.331454,26.403671,74.30059,107.288753,81.43748,-62.093159,-259.806568,-320.245869,-284.485258,-228.778123,-100.201438,-41.404466,-61.460095,-226.289949,-292.905041,-350.951842,-352.239647,-308.828448,-240.573946,-52.981689,-18.406047,-104.429551,-173.443714,-179.628328,-192.275465,-177.907693,-60.342148,-9.105296,-57.191961,-184.873136,-224.527762,-232.843856,-182.487192,-14.329264,57.027627,131.839805,139.073658,90.636139,-67.476665,-148.113788,-156.086137,-97.337098,21.990445,58.886614,41.132892,-89.741866,-165.248086,-232.066128,-192.46346,-53.716537,-1.247802,62.014113,50.394761,-92.264341,-243.165396,-283.150011,-290.932275,-264.540337,-169.6406,-117.043196,-103.032734,-225.620618,-302.709602,-374.639604,-329.345385,-167.768585,-107.378867,-57.774206,-72.866028,-174.639842,-288.302319,-329.912042,-386.664229,-396.592318,-291.231258,-176.991347,-53.847163,-208.698804,-319.956657,-414.962194,-373.503586,-207.830987,-117.511124,-20.250612,-67.998215,-287.655062,-428.76176,-446.499086,-405.83439,-347.325222,-182.231313,-130.427752,-212.226709,-358.780154,-386.534209,-373.351881,-319.889946,-145.843169,-90.43809,-96.431553,-126.859291:250.189573,173.440206,129.670981,184.544406,230.979127,228.992991,210.443781,192.392516,174.72315,152.524547,85.262444,56.882265,-9.830616,-55.96633,-141.874206,-185.549422,-286.067,-332.086814,-303.492854,-186.003654,-132.091963,-21.878694,31.807466,46.249178,-37.386377,-85.017644,-143.809489,-112.947607,23.957078,62.653007,41.15484,16.073723,-10.112011,-50.536362,-60.730257,23.111302,103.363919,204.595503,198.23771,98.470387,-33.125225,-68.641804,-89.404013,-102.593166,-126.569031,-117.292195,-79.850184,-79.718465,-98.391797,-62.505234,-29.713394,50.667909,88.196277,78.370044,17.083302,-140.096226,-180.312079,-158.319339,-127.122685,-116.61231,-67.590916,-47.93987,-89.413032,-123.066087,-48.557872,168.74081,227.755936,209.294866,176.820643,129.270049,121.203676,109.346284,103.411619,104.719064,61.152968,45.701098,85.456008,77.49105,-109.898245,-235.280987,-342.609034,-292.163919,-288.697992,-321.25865,-308.867338,-201.145362,-129.421075,-18.234911,17.760113,13.891922,-41.440071,-75.034827,-119.328663,-141.7307,-178.842226,-180.165823,-179.478866,-203.826099,-209.406087,-182.609342,-153.064399,-75.328209,-22.527872,81.397118,68.317784,16.39782,-30.635503,-3.787992,25.812723,12.873107,19.942772,28.79451,-50.645115,-193.257973,-222.775255,-128.443313,-19.376322,189.863769,233.314468,197.127092,150.922247,127.838253,74.50697,94.747105,224.319255,271.987024,311.493707,325.644401,282.288588,107.505967,47.034645,109.970765,171.735136,188.457616,175.322923,154.575373,44.547384,-66.158468,-307.211241,-337.250415,-219.170808,-187.84393,-175.363994,-106.774957,74.348905,46.358058,-40.424544,-167.556477,-160.37613,-44.745624,34.493838,150.247559,131.199746,102.160844,100.792833,136.018265,158.043505,124.116566,123.848284,180.272313,246.780165,129.594522,73.561579,113.086964,184.634135,336.079789,382.329191,348.566538,221.599704,160.883702,27.477077,-38.637558,-61.02,9.928492,178.834319,186.89794,62.846407,19.280123,54.441762,140.435421,163.93419,165.190026,160.277033,167.488858,130.804315,72.060386,-58.87268,-82.601663,-19.285113,37.084402,86.617049,55.960825,-33.294356,-39.867384,-30.702639,-18.132857,12.802259,150.91835,205.802495,161.328098,63.976479,34.905653,-78.218995,-130.651732,-70.322393,10.232786,99.86983,104.286455,79.855213,-17.744662,-84.200687,-95.890149,-22.722453,111.883453,139.424932,162.266854,168.894282,173.577393,206.385455,239.126848,295.48197,318.192927,375.870895,385.551653,347.322696,278.927649,217.955997,59.568576,19.765339,144.272265,275.766468,420.691863,312.080538,221.817939,15.138806,-74.882626,-68.260911,33.808305,233.622053,254.910359,154.523148,54.116781,34.450844,55.60544,81.404064,114.987348,124.885308,156.230111,215.71195,223.211041,136.893742,87.131018,89.381527,136.965373,293.587628,357.995729,347.820205,280.881609,264.907594,260.200183,255.872663,213.187074,197.226332,170.009069,42.971284,-50.823104,-175.673899,-176.465854,-118.390536,-65.593335,118.162453,203.009892,204.308805,36.620769,-36.841923,-66.126759,-13.641439,143.126708,184.278887,129.428924,80.871545,99.979154,133.79386,157.64935,323.014121,443.312881,559.476392,506.142531,267.932848,111.361213,124.700985,256.909943,292.161904,227.288978,185.509915,128.923752,23.582215,-28.423151,-56.542111,-24.11397,29.025593,14.157991,-21.837923,-31.858563,-93.363413,-158.678705,-175.594607,-169.528763,-133.113007,-28.268562,1.245333,5.953155,13.828785,6.808464,-55.810524,-78.543879,-75.088108,-67.617163,-58.830826,-53.286473,3.692985,77.180688,59.611828,-44.610722,-99.199747,-182.515998,-200.156548,-228.25074,-235.174752,-209.514539,-172.34811,-179.142158,-184.549912,-150.042605,-19.394378,18.677345,-22.025939,-130.805137,-186.423229,-259.899469,-272.676666,-230.40443,-168.13413,-61.347625,-51.142086,-59.946038,-80.725111,-91.02556,-139.837441,-172.484245,-173.068458,-135.237873,-44.596364,-30.866782,-64.920322,-138.623033,-149.103317,-142.605079,-150.066104,-190.502095,-234.818811,-264.378567,-353.082529,-376.890469,-308.907975,-253.029484,-190.562743,-179.640315,-195.123351,-256.965439,-276.522618,-265.535578,-257.095316,-229.462765,-196.69046,-147.92842,-187.940686,-238.127661,-287.143014,-241.183296,-96.030433,-63.449127,-56.409062,-51.895943,-79.415065,-161.976356,-195.914213,-165.76898,-121.255376,-137.359877,-189.331156,-204.434283,-123.081915,-122.953055,-169.398558,-161.208755,-105.69033,-77.30997,5.634481,36.677317:96.387851,71.427392,58.88384,108.263434,168.531011,241.926396,237.151604,222.747254,247.294482,227.566996,134.966355,128.301126,208.959843,246.876748,248.147037,202.362188,73.614837,1.360703,-6.749475,35.472927,75.418904,163.360986,204.759743,222.531377,103.676808,21.26008,-97.933428,-106.686471,-7.899282,54.976656,103.482953,95.356333,39.796111,-52.87765,-72.538392,17.722895,90.803633,111.938527,40.358749,-125.33544,-175.669308,-192.96938,-297.850936,-357.812854,-375.997602,-310.442756,-107.791245,-38.214333,-31.503156,-116.401619,-127.81557,-22.801258,45.678726,81.109363,32.658951,-146.267404,-205.21438,-171.093389,-110.063319,-107.027144,-195.267831,-256.729663,-215.649023,-105.839723,130.821087,234.980047,220.702268,165.005087,167.051353,202.922223,185.966727,66.855737,25.150054,43.959134,68.153119,70.938527,65.783127,64.337699,100.772818,101.389168,-28.032911,-178.446191,-204.76773,-201.296176,-186.80605,-95.313454,-28.797232,29.200623,-21.018709,-28.539307,13.981234,13.031119,-89.046918,-151.453704,-204.458584,-198.06689,-201.334476,-301.913123,-371.984357,-434.554453,-414.723009,-347.249171,-306.107229,-198.040064,-139.791024,-146.545374,-143.309856,-115.088916,-59.449207,-42.659721,-39.612577,-65.081139,-161.117239,-280.993312,-309.611718,-213.780044,-130.745672,-4.105936,39.417466,48.396768,-8.063684,-8.652525,47.743045,97.911802,209.528937,235.990729,206.58648,158.491515,10.348656,-128.481163,-161.474425,-94.541482,-21.703449,31.980909,25.013832,81.264712,99.005439,24.718628,-147.454524,-151.448649,-0.375216,88.524492,230.238287,282.593638,312.861915,219.762086,159.08034,82.773487,62.419851,71.236797,123.477705,239.682087,192.655762,121.365149,25.407094,47.678281,143.041098,143.881641,112.574979,121.822629,129.517396,44.973639,-5.983534,5.127805,79.715797,254.883395,289.006836,193.591355,40.561901,-3.921519,-10.754419,19.416808,84.058824,108.738615,145.332062,129.522606,33.904963,13.690615,51.743871,170.641726,216.778472,232.513118,222.796516,229.967535,207.991292,149.380472,37.263508,47.138913,126.963844,124.788333,56.212876,22.572299,-47.020485,-100.914037,-99.373145,3.804562,82.632808,212.607337,258.324086,276.874829,236.592643,212.042408,96.142343,20.632068,-34.984281,1.910594,149.402539,217.978069,190.694582,-87.718525,-220.581493,-234.870706,-129.973002,52.998562,64.468699,-12.655081,-2.907101,42.403666,101.637842,119.323574,172.112618,201.013787,267.811474,293.510332,294.577458,224.543242,144.362069,-9.328229,-13.500312,158.262744,271.728766,367.306088,332.366211,283.454838,48.181064,-84.591278,-114.316033,-5.615459,213.633919,248.875875,171.564133,30.316186,-19.651264,-28.042312,13.125753,128.366012,171.592153,153.840746,54.38454,20.370683,-0.947636,5.041529,29.103709,46.584943,65.696521,56.12015,101.013195,203.074849,193.864677,127.846205,130.389226,155.477329,138.543893,34.8124,-94.857035,-138.562196,-195.633552,-212.28078,-201.627337,-165.147088,-22.328349,54.10816,123.42968,53.210194,-0.201292,-10.596259,43.730093,170.422128,189.102339,101.491103,17.390448,6.905433,9.299071,44.730818,182.592181,255.860978,364.571245,349.03877,134.091125,-47.939372,-67.555603,-54.985952,-55.527435,-21.356117,14.551226,-7.551349,-120.335462,-153.190814,-131.005245,-95.955987,-80.102464,-87.767615,-60.749511,-59.800727,-88.248062,-43.645548,-27.453506,-83.82819,-130.35,-134.749591,-93.857699,-46.299135,-90.523471,-110.806785,-75.541406,-32.347903,-22.446313,-57.589129,-56.03349,-10.68859,48.368632,-19.823784,-78.951652,-145.786278,-145.592645,-69.405239,-0.166306,60.091709,35.696612,36.049842,26.990692,33.63627,77.271848,93.099527,149.272739,180.733363,135.088912,-59.68911,-141.458793,-202.837907,-210.441061,-177.906224,-133.621987,-75.803426,-91.099109,-103.293884,-129.704388,-144.009011,-160.630647,-149.19381,-53.712779,0.949349,-3.858481,-150.075517,-228.40308,-285.610755,-254.834694,-142.835647,-89.724874,-56.930108,-129.254761,-193.744108,-342.77237,-372.706249,-295.775066,-232.775891,-127.707493,-99.620071,-110.672318,-185.969329,-238.317678,-322.411362,-353.80373,-377.306209,-353.656321,-297.509113,-304.682781,-316.247003,-290.769077,-239.949982,-136.392398,-134.573286,-200.415324,-219.342805,-228.019552,-295.583948,-342.3206,-350.268899,-328.048604,-337.710494,-351.917054,-340.675787,-312.218222,-310.89801,-304.793606,-270.438495,-155.631886,-112.502981,-127.20152,-184.250025:171.083625,199.430991,208.51297,212.743458,220.765749,259.709403,280.601041,259.655423,162.253901,127.049133,124.183098,139.670969,123.681818,79.088618,-26.08452,-62.392645,-123.405245,-184.27453,-174.741631,-19.66323,78.880985,127.667576,70.038548,-38.116176,0.243791,7.006032,-96.61318,-117.011513,40.808942,130.951989,140.098773,86.397421,0.62024,3.50703,12.615597,60.216107,126.746307,291.521235,332.254454,270.696338,160.028154,131.593656,104.408404,104.241845,90.709155,58.120858,-28.257341,-67.882024,-88.379096,4.718808,65.939907,183.697704,228.151046,214.840981,162.745534,72.084217,6.044279,-57.782762,-180.353964,-171.964236,-61.70558,-15.057699,43.05562,44.472175,14.33605,77.620224,134.636915,186.300345,170.464363,115.774673,92.527553,54.555231,32.837878,18.511901,-9.200318,-11.242391,-11.626501,-37.767453,-163.07992,-233.566053,-301.500684,-287.737133,-293.530178,-298.47395,-259.610868,-121.031603,-66.342076,-83.618792,-159.686424,-164.168451,-167.100704,-158.046407,-57.339844,-25.066205,-90.922869,-110.527438,-34.278497,-76.080454,-150.642057,-181.917713,-133.357713,-24.199757,41.792565,193.277699,224.110276,170.996964,9.828789,-43.277884,-74.678422,-73.072789,-35.888634,-37.781922,-159.661261,-268.958809,-273.748829,-210.837002,-154.61258,-33.003892,9.601386,19.432132,-7.809151,-12.798944,-7.252971,9.329441,45.600356,66.631161,164.381324,211.016916,165.963223,-14.037422,-77.773782,-37.740569,39.876244,130.910341,116.145824,24.508941,-98.053792,-186.949117,-332.703236,-326.955959,-230.422569,-187.316492,-84.08736,-46.847011,-82.064974,-138.103118,-141.658182,-112.072585,-66.452907,65.893572,103.590535,42.158556,-75.375409,-78.90077,27.321513,85.140832,101.313939,92.756702,193.041807,251.836394,198.456655,103.120177,125.539732,239.193252,289.622484,352.705305,365.503553,330.754832,170.420361,65.284884,-100.160526,-146.559712,-136.911572,-56.191968,135.028591,145.273217,10.241597,3.263413,76.651926,182.359443,176.177144,131.847004,133.951324,153.489312,50.271765,-36.216724,-130.791417,-113.381913,-44.963896,-33.366607,-35.429593,-40.066263,-67.740744,-62.194622,-25.453028,57.041241,80.196717,117.950118,156.581318,216.502005,120.6022,37.414234,-68.734054,-60.127159,13.419428,31.655016,22.974334,23.692917,69.569644,12.232964,-87.608113,-182.665176,-111.238951,92.606812,141.712507,121.090749,85.070941,102.989725,169.667212,205.137295,237.715176,229.389041,288.285722,342.948372,311.21534,139.148699,79.271082,96.29692,159.650024,317.520017,376.988817,353.756085,198.515592,128.126444,7.025961,-33.360729,28.569955,136.436556,298.186002,250.354003,-18.616151,-155.535028,-150.609118,-75.050236,-17.513237,106.955204,156.766568,207.026025,213.179196,196.828024,108.050183,74.089318,127.926727,188.488532,219.876799,180.114092,122.22939,166.482655,181.197435,128.04578,89.709745,79.943572,86.123605,31.255578,-14.695675,-38.90444,-157.72895,-192.570334,-62.173768,59.310332,236.121471,260.835612,166.701774,-2.32712,-50.071045,-48.233063,-15.352601,56.642418,70.463242,62.501142,53.16092,33.741355,0.05185,37.085337,213.363,299.800161,374.551987,333.021863,144.478228,44.573209,48.21016,98.719406,137.89461,243.758347,280.85084,203.76425,4.818041,-71.23637,-166.350454,-182.143071,-119.073827,-65.120015,-40.796495,-82.743181,-164.35024,-190.930475,-217.489584,-281.798319,-295.2603,-275.016275,-239.785915,-147.56281,-158.25041,-220.345754,-286.42953,-252.528619,-201.067537,-202.908504,-138.487608,-84.163174,-40.24587,-60.734074,-81.122293,-135.195131,-161.872006,-176.113929,-155.26615,-153.351133,-249.218543,-274.858374,-244.724128,-195.764717,-38.400466,30.701919,68.147499,49.122873,-4.825315,-58.507031,-85.310799,-93.740471,-74.226525,-55.103491,-52.470847,-35.23578,-17.463841,-13.008706,-23.646509,-31.553729,-55.963863,-77.771237,-108.583869,-109.109946,-83.424853,-92.59763,-149.66395,-223.642405,-184.522246,-36.997556,20.119478,-33.909567,-262.090249,-337.630578,-353.049752,-322.867199,-234.577234,-187.134674,-127.359479,-133.366077,-206.202128,-294.514347,-324.374009,-358.349777,-374.70213,-333.544461,-263.683547,-186.258995,-253.71546,-289.771034,-305.587177,-274.833305,-152.811768,-85.890394,-24.703731,-52.402291,-147.456629,-185.929179,-194.456348,-166.57637,-134.297021,-118.497701,-138.002517,-189.699056,-205.366484,-215.141252,-250.187481,-235.858493,-119.20629,-47.693747,46.330918,46.797898:right
-132.534802,-90.665695,-71.234558,-110.236505,-157.285716,-181.982917,-151.160425,-107.465727,-129.144959,-125.868501,-17.853388,34.7367,-6.640892,-53.585772,-82.111036,-85.221791,-87.034747,-67.774619,-59.883701,-83.877653,-116.932173,-143.509505,-123.09534,-82.290066,-81.080188,-86.405813,-96.790508,-102.358312,-88.750852,-59.078029,2.732178,20.825523,17.336752,-78.872971,-149.44178,-264.853176,-291.613783,-255.738121,-188.070068,-2.629341,73.480814,49.550477,0.981725,2.558697,25.911163,57.362616,208.708261,294.209755,323.588369,180.192133,121.055236,72.966186,62.690809,31.924957,8.213357,37.960254,175.684775,190.918723,28.780781,-91.314575,-201.738898,-150.402292,88.468973,205.316267,315.058404,273.85481,254.918561,286.008562,300.072241,269.360273,260.103193,300.605089,311.601623,286.742116,222.291207,203.924421,232.773948,282.144262,404.48332,444.527713,446.685013,362.061962,301.377969,152.006822,76.805528,9.633823,24.547231,93.491455,126.138397,107.662953,29.27792,-28.810358,-148.470968,-176.790832,-167.695784,-143.51986,-99.974192,-158.256071,-228.209478,-380.120072,-432.664117,-453.245858,-427.054715,-323.734054,-173.835348,-108.266221,-67.43717,-96.375214,-159.256294,-150.913323,-70.968719,-28.405298,-10.23449,-123.459431,-182.473287,-214.399856,-177.081617,-27.48451,24.696446,18.738344,55.04269,118.810899,272.287683,323.070404,290.723873,237.573648,197.100899,220.824353,234.970425,93.486878,8.601408,-84.626624,-98.628255,-88.941634,-57.422255,10.576052,-61.118574,-128.725204,-180.022583,-156.98193,-80.097213,-45.658679,-36.002252,-58.669373,-111.206567,-139.035215,-123.299689,-91.911812,-97.723527,-55.701977,6.019544,116.780699,176.12908,183.281259,130.236949,67.430309,-49.409796,-49.910187,33.023597,60.665443,70.333505,116.059933,138.031015,96.631365,47.347825,19.80336,63.865575,170.424253,128.255858,57.605124,-28.668094,-28.634117,-29.524777,-53.141672,-91.398734,-67.424852,-6.580618,-91.161943,-139.784779,-117.101234,-77.638181,-81.951936,-117.730992,-119.927006,-46.637496,-29.434693,-22.829271,-19.999195,6.358244,23.098836,-7.568777,-35.906418,-1.102302,104.54796,131.16431,95.840569,66.833227,89.138651,116.468365,96.307275,18.502243,-2.25144,14.959354,21.997616,-9.190555,-17.819686,9.811481,31.920135,47.442072,-43.74552,-118.808571,-207.262854,-195.254595,-133.835648,-133.669775,-189.723803,-176.819232,-133.026496,-74.195335,-88.687177,-136.949785,-143.33428,-154.14695,-163.665218,-152.445097,-150.625663,-179.551214,-291.532992,-364.320034,-439.075879,-405.407802,-293.329566,-285.430311,-292.327618,-227.09395,-173.672379,-87.899051,-65.757662,-98.295757,-135.900363,-200.08343,-270.226073,-293.043649,-330.401512,-352.837983,-344.792217,-303.656949,-176.885233,-58.314272,-34.694901,-74.100017,-120.14158,-163.430912,-120.246792,13.605243,31.239656,-58.306626,-141.425899,-145.199317,-167.123953,-205.125616,-237.104909,-210.266307,-126.263748,-29.525208,8.047823,32.739623,26.952325,14.206901,17.542868,29.368193,33.417403,21.833981,-44.416206,-84.205913,-202.22702,-275.124838,-294.085633,-220.965307,-65.909179,-33.750725,-40.037803,-68.907331,-125.329076,-277.310655,-295.250362,-209.736246,-163.787558,-96.740847,-87.620104,-124.31478,-229.522589,-259.154413,-209.249144,-147.840618,-52.679888,-45.980931,-61.841293,-54.773149,-28.802731,9.408471,19.956355,81.979426,144.716686,270.949107,296.314725,281.312877,198.890243,131.251732,67.743864,100.103614,193.222662,206.623428,176.505751,57.286413,-8.931468,-55.311668,-8.989775,133.919621,179.55328,186.161429,104.948375,53.975152,-49.254208,-88.900274,-101.941984,-80.538009,-25.336417,-14.610796,-34.990984,-91.914379,-119.873523,-146.805123,-134.888637,-114.058404,-126.153962,-156.763296,-153.116226,-158.711089,-212.675881,-241.132186,-248.293534,-219.117509,-111.311705,-40.063375,-45.971854,-117.935008,-177.627533,-273.43621,-257.162073,-128.273921,-70.060393,-35.947582,-67.894938,-67.21915,-59.665091,-56.575028,10.052505,48.108909,31.519573,-37.235073,-42.479489,22.629592,48.321809,23.882813,18.002292,98.309075,168.958933,310.233779,370.739889,347.283073,228.322687,188.317514,216.502196,241.966523,264.38455,283.164242,274.005016,192.270645,122.076189,5.898407,-2.154043,58.755377,114.059595,242.99708,216.925324,139.695386,21.933813,9.090073,51.861418,87.598671,148.328845,153.212825,105.558538,-99.665948,-223.620072,-405.564288,-428.40174,-329.318338,-249.658541:-230.262375,-185.46335,-149.339043,-141.201558,-167.011583,-166.813796,-140.154298,-145.204998,-194.132803,-183.438181,-99.88907,-74.213661,-104.418826,-123.031962,-125.402294,-119.67331,-95.702972,-108.709954,-144.95528,-226.626552,-243.780899,-187.933352,-130.532348,-65.522887,-91.397155,-104.327662,-97.664097,-104.966154,-159.043967,-150.692,-15.908366,51.513739,30.088547,-118.282221,-156.748686,-206.100991,-248.692918,-237.410314,-147.00571,51.253716,84.214616,58.487509,28.281584,28.292337,56.572789,80.748939,115.386451,137.235106,189.178576,152.306918,100.169896,-11.593332,-38.744093,-16.985999,15.194605,96.271125,130.585855,117.877393,24.402014,-45.746525,-104.524326,-71.007374,70.967367,160.62769,267.705009,230.245263,220.554545,223.147625,189.993404,89.854442,73.429266,148.408978,210.929882,187.014929,115.844674,102.507673,160.880423,229.42426,339.842082,352.874211,337.553791,308.394505,266.600168,89.495905,0.12323,-42.713054,-12.080257,56.809967,44.474426,10.009326,-32.315922,-44.482418,-67.796826,-69.695763,-94.377966,-109.125264,-63.223171,-42.548068,-110.391304,-331.281812,-396.69057,-327.567798,-241.97413,-138.303733,-120.760762,-85.164751,-9.974194,-55.180959,-245.568983,-254.366848,-47.620279,37.401497,-13.673072,-121.116071,-129.332663,-116.715123,-95.643369,24.767521,86.371234,92.072508,74.742466,112.044981,182.461626,173.337793,122.214016,140.052245,257.241145,292.241845,235.095482,74.913932,9.307059,-45.019539,-42.092265,11.26019,52.582209,108.862065,36.261931,-48.281941,-170.510331,-175.147746,-113.491726,-64.698234,19.614165,32.823134,-5.998718,-63.89648,-80.938999,-101.812965,-102.073466,-45.628691,1.30728,64.729079,94.634226,101.087257,20.393345,-63.195575,-99.137584,-15.872201,133.323989,141.980567,91.333999,47.719812,38.633939,-8.68057,-43.560669,-70.470584,-47.123756,66.559021,97.033523,56.089407,-35.019772,-70.05442,-96.738206,-84.316569,-66.836573,-86.70558,-188.221315,-258.309595,-246.499628,-208.164749,-203.050113,-192.734952,-187.277776,-134.467785,-25.241793,2.1226,-56.921587,-119.608744,-174.493952,-148.755119,-83.9286,-58.061411,15.411585,81.301812,90.984707,61.456528,43.863168,61.566928,85.431235,91.656135,66.362054,72.673945,65.24001,18.058734,-52.504858,-23.964865,69.59086,95.120206,112.616481,74.16594,50.031498,7.411644,-23.275203,-74.278643,-74.853093,-30.21902,44.964794,51.218218,-34.40629,-80.874901,-129.199946,-148.648355,-139.594938,-102.770784,-83.763111,-192.328273,-264.2145,-425.731902,-482.728097,-449.510217,-378.575864,-272.511457,-291.187795,-306.265116,-293.109434,-288.965355,-292.32049,-275.547272,-268.236857,-307.315375,-393.335696,-434.559971,-451.924945,-485.503664,-474.524077,-343.017763,-250.665654,-107.633242,-89.740003,-131.053048,-230.903901,-259.732661,-192.362403,-94.987456,33.075321,10.370719,-115.743591,-179.468208,-167.698035,-115.213393,-93.963924,-65.333295,-64.399183,-38.443858,99.490622,142.700199,58.53827,-14.412193,-19.324786,53.073453,141.333758,123.54893,73.020577,33.500312,19.80316,-26.798403,-65.515167,-74.299785,-41.04894,9.761967,20.939717,7.775369,-85.435127,-148.607224,-210.798763,-185.830616,-72.380216,-40.646115,-67.563281,-71.354797,-58.964392,-102.981339,-141.511157,-133.671806,-106.693356,-96.620384,-138.878432,-143.541527,-87.420312,-51.946818,36.423166,101.696737,210.696404,228.239327,236.670032,306.713984,334.36239,241.2236,151.281972,99.319064,158.364325,300.627022,303.058475,234.126805,63.010775,1.031955,-58.124586,-41.890601,89.579248,157.605294,170.668413,95.207988,71.032894,27.716513,-5.87666,-55.279904,-37.145308,77.432508,124.812508,83.17832,-63.46972,-114.091455,-91.307938,-42.165252,22.897628,25.370605,5.703339,-47.298675,-72.451901,-82.184942,-78.377452,-66.476115,-70.872081,-109.334571,-132.321926,-150.342143,-196.680493,-201.913227,-177.114595,-155.379678,-59.949335,2.971541,49.065104,4.239974,-7.750245,-38.276168,-67.054915,-42.689578,21.882986,88.04444,-6.754399,-43.841592,-13.627953,7.703907,7.150656,30.395814,187.082477,281.036585,408.84321,461.076181,440.552314,307.309028,248.449712,212.15113,218.809426,263.188281,262.541256,239.14762,173.469748,124.263522,46.448013,35.767523,60.759367,96.885182,176.948508,149.794909,85.34052,6.858083,39.991867,128.050941,147.350211,189.901817,205.247421,178.702627,33.74175,-93.503124,-320.041435,-337.2733,-190.020507,-101.006404:-213.339122,-200.6338,-169.649751,-138.985312,-148.720019,-151.724716,-137.22935,-129.681859,-133.498169,-125.220082,-104.432349,-113.040165,-154.339367,-140.361046,-42.19312,-12.534967,-47.05343,-33.642262,0.645055,-31.478705,-77.87579,-72.122331,-25.479562,43.569446,1.032124,-45.414406,-122.610121,-166.800483,-214.546328,-164.712237,21.623542,86.253998,63.355286,-75.431802,-124.734775,-169.963566,-177.604634,-113.431076,-26.687202,145.262392,141.370097,88.219582,32.118259,44.093786,96.833181,127.019341,186.660704,216.91286,238.05767,189.426527,144.819748,45.604343,34.072799,78.371287,89.977707,95.213506,110.444853,112.655341,57.958583,-5.809324,-100.734131,-73.154355,86.843075,135.252827,111.531807,165.078554,231.251907,224.624538,163.464763,139.256381,178.289175,204.276884,136.014593,113.449036,99.574249,87.064335,98.625618,151.356772,283.478795,312.221798,235.386987,121.348396,102.443009,42.734312,-6.641431,-26.214104,10.933032,78.53645,41.733272,-8.781095,-119.044541,-165.548751,-192.768425,-172.169441,-134.559743,-113.455676,-41.82508,-70.155502,-151.611135,-370.238802,-439.431544,-415.644473,-352.634606,-204.46675,-96.96191,-80.78295,-125.792671,-158.685595,-166.200367,-133.881495,-62.733564,-52.715837,-81.787303,-101.763777,-93.739015,-81.162835,-81.442179,-49.290805,-8.66522,34.329068,-22.080626,-48.212961,-53.752144,-30.458325,41.463289,72.077278,125.331431,149.227365,136.01192,23.672822,-26.679213,-66.557954,-56.938274,14.016478,64.190412,126.43694,43.272429,-36.410766,-176.898421,-216.308846,-191.073594,-140.71735,-63.694981,-41.54056,21.31606,69.598606,55.917835,-31.946841,-45.244673,93.009271,168.00702,152.189924,85.76994,72.947914,32.709055,21.230286,76.20996,117.69002,109.62524,75.463578,66.18881,66.829644,40.119919,-43.165763,-74.406808,-39.757701,30.676049,177.495079,164.226942,107.073836,-44.780109,-149.870833,-304.925241,-284.645066,-135.02714,-98.5488,-174.709708,-274.515149,-283.138407,-271.310962,-266.869371,-264.34425,-251.844584,-139.50315,-32.386215,-34.079494,-115.381597,-167.409996,-185.841161,-143.309948,-63.275479,-37.740827,42.801252,138.737641,149.294606,87.000904,56.963002,75.004663,117.301112,159.280034,73.528027,24.092963,-33.910502,-60.45931,-102.560347,-81.998002,37.471351,92.079267,91.282893,-7.160795,-48.81753,-96.444198,-90.948235,-28.553858,2.935335,55.838742,100.537052,88.084881,-42.861562,-124.829823,-168.137527,-122.396778,-32.47751,-25.042975,-65.970519,-116.723559,-140.787996,-235.084542,-294.802027,-351.705861,-330.606398,-232.035502,-239.790496,-289.020925,-344.615867,-347.709929,-361.713225,-374.751857,-384.546558,-362.484508,-306.88187,-351.179568,-401.095831,-485.604967,-493.751521,-419.093403,-359.343189,-246.908166,-168.984128,-163.487,-222.206385,-267.980174,-279.959204,-212.539555,-48.54939,-25.138105,-94.655444,-120.134717,-98.63371,-87.669297,-101.038489,-122.476374,-122.617378,-104.273367,-51.214953,-13.865795,2.087392,-22.875273,2.644441,60.980462,100.719076,63.461846,-11.255414,10.851032,36.284347,45.870136,46.795839,90.496641,123.192263,174.120182,121.705578,42.338725,-114.090975,-150.830958,-139.276131,-109.458718,-15.492281,20.746425,-11.58112,-53.051578,-55.282269,-101.617723,-131.517475,-105.561441,-52.129252,2.261479,-115.524015,-173.16574,-130.353936,-52.148747,81.177078,114.237382,182.742849,235.116364,276.407823,259.330641,267.011297,211.974144,159.806451,132.037011,143.923659,190.572224,239.79977,222.974306,128.521359,80.141105,42.01735,71.560891,159.084753,174.282376,164.516627,155.235524,138.29831,55.685005,14.8357,-16.54671,-0.426675,83.949016,81.194215,37.296175,-7.445894,-10.115161,-54.620855,-75.423165,-11.258586,58.702187,143.785524,67.026216,-23.958699,-177.444868,-190.428354,-146.298432,-132.294577,-138.661479,-147.69736,-125.150411,-61.272517,-66.266646,-143.879648,-155.6125,-44.823886,40.907576,115.408746,66.22916,53.268453,35.400249,23.815564,56.986264,85.936878,102.766195,100.788466,97.287066,61.925685,36.058133,39.614191,75.6599,144.082136,183.648911,315.126967,395.258722,379.620163,282.980796,257.213432,296.347509,333.920314,374.818715,276.516836,187.911663,50.64164,19.412865,51.511847,100.221564,154.296549,165.515615,176.357131,128.996037,107.225989,65.162132,49.754538,108.765646,182.6371,283.172451,182.556166,99.058101,-14.107054,-45.747321,-127.618346,-186.373717,-213.711505,-145.767425:-217.66075,-255.076647,-228.91912,-150.640126,-122.433987,-85.737994,-81.472167,-90.701224,-123.156464,-150.372915,-127.92774,-66.185683,37.770528,38.482275,-26.30912,-34.525357,48.990126,139.895552,141.255689,10.129972,-68.294396,-50.808831,15.409952,76.931584,33.393181,-14.251094,-103.927246,-118.897423,-109.161601,-109.769069,-123.367735,-96.875389,22.234237,2.495095,-67.130187,-164.696129,-169.378674,-91.311914,-15.580649,132.384363,190.128154,176.068247,111.328125,80.294186,49.278217,75.732462,175.47895,200.217746,185.011955,168.056333,169.302762,118.664603,75.260502,81.151898,119.128098,146.857595,178.298088,208.333977,158.908648,58.893532,-115.637489,-110.190458,47.606254,119.300975,144.55883,113.633498,113.685051,151.260378,182.073058,206.274224,191.535755,205.969917,248.129691,226.280697,147.40341,116.16992,100.625303,137.096395,253.093393,274.975319,236.648718,252.806375,272.597153,174.309401,55.87321,-96.838895,-69.59488,60.425963,13.504314,-55.658152,-159.762308,-214.426517,-291.415418,-270.511868,-207.065691,-196.999713,-151.40955,-163.589086,-230.28687,-398.024631,-444.935971,-389.295961,-311.966806,-171.426301,-103.029033,-82.864208,-55.204537,-88.108648,-247.635951,-275.297094,-111.479454,-10.583732,29.877083,-53.261416,-86.606481,-126.890478,-131.503675,-55.433253,13.280067,90.201406,92.384984,103.146324,132.803245,137.268314,126.770172,130.435645,183.511449,223.963183,248.075225,110.569557,39.654552,14.727275,25.748899,29.657175,42.057163,92.905027,87.903989,48.581445,-38.60175,-67.115577,-55.183854,-13.615681,47.191984,43.276946,36.993617,118.484727,150.614467,110.998406,90.851477,197.151788,278.992857,345.373784,322.752263,296.059765,206.001274,157.469726,162.263608,207.81496,213.837725,166.846193,146.644926,295.417661,353.255273,243.499835,110.101231,9.549248,93.246806,287.220658,249.603783,178.992203,52.441174,8.662064,-23.672825,-18.849315,-0.79006,18.67158,56.843975,-5.345455,-51.653097,-91.234918,-84.681207,-94.514456,-117.100669,-91.831622,0.02535,11.436835,-25.418776,-43.492526,-43.800959,-30.013737,1.099842,22.234597,101.277126,234.506632,278.767565,198.920711,131.9467,130.925833,157.613243,160.953869,138.42813,118.697391,45.912536,-4.525509,-94.55774,-113.565261,-71.051097,-32.506779,-10.563629,-41.387303,-51.755418,-76.749293,-85.399807,-45.388408,-19.432893,1.425986,38.200881,34.261053,-58.527541,-110.800945,-130.085849,-95.427441,-31.150139,-34.058674,-65.964666,-47.685594,-57.308619,-227.854538,-347.904094,-412.799093,-341.685242,-180.9245,-177.547342,-229.556961,-307.29516,-294.898956,-181.133454,-128.011244,-154.051072,-206.604756,-259.305072,-248.510913,-245.617288,-330.778805,-401.315327,-433.747015,-383.443586,-249.936698,-190.363277,-199.261327,-229.517029,-235.530384,-225.597903,-196.752397,-117.926928,-107.100146,-181.237448,-238.704533,-205.752912,-133.879293,-154.530271,-246.246595,-273.02519,-270.741738,-203.890288,-174.436114,-157.300209,-153.644709,-122.345977,-96.699924,-52.860172,-53.912998,-104.370612,-80.283863,-42.840178,-54.919234,-89.228694,-46.827964,19.76499,84.930389,47.912199,7.647063,-109.212268,-177.343844,-260.861294,-247.517034,-156.803605,-115.296829,-87.715369,-145.280642,-157.587651,-105.240084,-112.102935,-245.922552,-286.504831,-224.85512,-151.476738,-137.919973,-104.471477,-66.39913,40.360263,97.667534,210.08149,240.925733,211.393526,200.166189,231.768465,201.713442,124.759938,28.520177,41.058668,118.59972,144.074768,98.447487,-47.85053,-93.995836,-75.405291,-23.11318,68.947429,93.133859,120.470315,107.973647,94.580861,23.625975,-31.741937,-89.661496,-96.656307,-110.654196,-66.184872,-28.281377,-23.660306,-62.945022,-91.244332,-49.244061,41.603524,43.491205,-28.351971,-111.163001,-125.654286,-125.473249,-137.36229,-191.448567,-229.309728,-259.725628,-152.528477,-101.386477,-124.928681,-179.995623,-259.378586,-261.089924,-194.97449,-131.417275,-15.802179,-57.114846,-108.73261,-150.155094,-130.251672,-27.62916,17.373733,4.852195,-59.409465,-56.22526,7.023562,6.676395,-77.84253,-99.419976,-33.899603,49.607735,270.921055,388.020301,367.599838,241.527281,198.868641,215.015589,246.518203,282.147696,240.185794,189.324407,74.648183,35.703497,11.112378,27.524874,113.484471,159.186299,179.325806,83.320374,29.705776,-2.040652,22.689429,117.679522,156.739837,179.97989,187.377921,173.950114,22.220908,-108.993059,-283.667706,-268.833292,-135.813021,-76.355074:-156.539263,-176.400619,-181.290086,-209.959624,-218.396579,-155.498581,-107.489497,-61.828929,-72.521946,-75.47799,-63.341445,-60.110481,-40.04254,-14.76034,46.205874,81.604168,129.462951,108.599697,94.501709,71.744414,55.007121,4.99745,-15.74673,-11.30337,24.121754,25.407241,-72.028775,-162.773129,-250.454321,-197.963807,-44.994175,-13.954761,-21.866669,-63.518039,-96.410557,-161.001562,-173.891508,-84.304674,25.447891,242.452122,276.223266,228.853062,102.557041,57.682799,59.891697,97.168268,170.525268,194.523047,193.014513,113.658194,62.720011,15.592768,49.413432,158.781261,179.595292,183.618432,221.588906,221.048535,121.537681,39.704542,-75.436588,-62.832567,90.529555,158.484916,140.680925,68.364928,60.289895,49.856665,46.110039,70.761929,95.762397,158.629243,182.688589,173.035179,135.435409,103.671731,80.633137,127.97514,263.744187,277.422545,159.827266,59.585373,40.991176,-11.661364,-44.082951,-65.813347,-29.160804,111.795334,116.186892,32.691273,-155.63348,-210.956477,-250.90488,-230.418003,-119.099038,-81.638977,-101.57558,-112.708085,-130.672718,-322.861823,-438.417031,-449.89189,-342.330651,-97.53343,-21.725708,-46.018038,-138.900466,-204.633836,-301.938703,-279.68677,-113.307947,-29.994817,18.907257,-95.731116,-162.820246,-189.110308,-136.965386,-22.799026,1.699612,51.746448,74.6479,55.264544,11.215255,-9.016173,-5.149031,41.885996,142.124976,152.274816,126.685615,66.548127,19.318055,-23.048246,-3.859801,44.140156,64.095938,91.418959,39.015844,-5.078257,-83.880243,-115.332012,-114.805676,-83.629084,-30.288157,-10.570003,32.172608,89.022676,107.339097,74.771257,63.435488,151.235615,220.380962,303.260457,307.625517,281.555411,146.323306,67.757575,51.193335,107.941162,173.282437,168.838455,196.209944,239.611034,208.168183,43.925551,-8.022027,89.663695,181.630847,277.956735,281.172301,242.974231,60.224907,-35.724015,-84.880226,-50.057169,36.307998,75.14348,51.278002,-110.1528,-152.012723,-129.010575,-113.104263,-115.317902,-106.229312,4.601691,124.189858,110.004186,-59.219963,-138.71203,-101.657583,-13.472645,98.518192,126.193407,193.694191,240.650527,242.659708,169.887769,128.75701,162.053661,227.919654,312.440665,209.201673,128.922117,27.189212,-7.863707,-52.68039,-42.663908,22.437232,60.832501,89.137923,34.248439,-0.192033,-75.668578,-92.427462,-13.423173,55.51344,140.612242,142.814265,127.097077,14.325833,-69.465556,-108.988511,-47.959136,92.88027,135.657167,154.070086,100.929748,41.732936,-153.67155,-247.162263,-310.739762,-273.370616,-140.492513,-151.661538,-219.067873,-310.465017,-314.804956,-272.486445,-230.810577,-137.555537,-109.177703,-184.083498,-343.99858,-371.26653,-388.203975,-419.514189,-434.706338,-374.456184,-197.493699,-168.575571,-208.570349,-282.741485,-307.106485,-275.909026,-204.884589,-43.5391,10.446381,7.272752,-78.321332,-102.159149,-151.154949,-182.533193,-203.400294,-193.664391,-171.84543,-128.499351,-102.24985,-104.470554,-137.069341,-156.009158,-115.791792,-5.950419,24.655107,-4.896555,-37.584698,-24.614522,-14.792786,-13.195937,86.652395,159.164338,190.748554,116.988445,87.817833,-1.540656,-86.866911,-215.141092,-201.953198,-73.160959,-4.104632,64.06471,48.113704,28.503306,-63.63469,-115.05155,-101.49694,-49.180579,16.815268,-16.381158,-45.547206,-80.503838,-79.639747,4.040611,93.166556,274.91957,319.258162,265.390378,172.33147,154.497473,68.471677,18.924314,57.635397,118.97839,171.907663,109.938928,61.683401,-32.431226,-65.154274,-68.235395,-32.513918,79.437819,122.7022,108.232602,0.798263,-48.764298,-121.199293,-128.192194,-82.972914,-63.626482,-39.894599,-35.014418,-51.294698,-64.019959,-58.203517,-82.625557,-112.394521,-135.269004,-118.979758,-74.467737,-88.491841,-143.696043,-296.411942,-342.940106,-340.332395,-307.699473,-178.037228,-75.408173,-101.434322,-251.927622,-301.292709,-260.34641,-212.35812,-144.721869,-103.314827,-9.109477,-25.580939,-59.811083,-93.349359,-88.172671,-45.958763,-25.961386,-21.9456,-33.08499,-27.648734,-24.334543,-40.776079,-77.601686,-70.840543,7.050216,62.641973,206.432121,312.911092,289.5468,153.319876,129.841109,223.405593,280.209764,328.291298,265.651165,189.391387,27.251153,-25.490726,-28.674896,14.529179,112.718249,159.367643,220.865145,128.159527,53.003813,-6.501428,24.640412,115.213676,136.207766,166.799411,212.497361,206.091969,67.154661,-41.77066,-174.028037,-171.133947,-107.182993,-59.073623:-122.617776,-78.723387,-91.541602,-68.45825,-30.089099,25.566122,25.464755,-29.722392,-69.415297,-62.35029,-27.510025,-21.88967,-26.582287,-8.093195,69.796328,114.822888,207.544504,266.9616,265.086864,157.679439,79.026194,46.085169,94.262837,137.797451,59.160491,30.908568,39.431686,26.673912,-45.809231,-50.246155,-32.748769,-48.723065,-64.670761,-83.24342,-129.10321,-220.165966,-225.648979,-119.030674,-37.025614,94.614647,176.11008,171.075602,47.041874,-22.379122,-16.381809,72.118956,255.948694,277.428102,210.885004,95.641169,27.941511,-25.883168,1.0978,45.039556,37.803326,53.072829,109.039808,97.682379,4.069132,-48.622286,-107.912124,-88.519234,34.169664,110.01303,238.660223,268.738823,260.783161,236.607037,214.351497,198.358548,226.643297,272.990533,205.850471,179.66136,189.841481,184.149089,150.000316,161.429684,240.14764,281.265276,336.058577,300.07362,244.07279,98.168191,38.75508,47.70512,102.194838,197.921361,174.866462,109.891755,-31.418452,-81.750206,-140.67698,-161.991482,-190.726805,-171.05532,-105.812719,-179.312922,-250.623304,-363.742159,-380.650841,-252.644789,-141.790594,-44.33859,-112.221083,-133.642282,-123.532375,-134.145001,-213.227457,-239.736964,-152.319407,-44.507045,71.60696,-59.489222,-114.997713,-90.966465,-62.384463,-45.234708,-22.856481,66.774316,87.789661,67.005732,66.391088,100.769207,139.608516,130.972539,138.173938,164.838161,168.590873,41.595139,-14.296041,-42.451861,-46.403672,-45.747966,-13.742348,38.716399,-27.215964,-53.978648,-74.949305,-99.982662,-127.11488,-105.358561,-32.981267,-6.984575,29.389152,84.11585,118.723027,138.499689,115.828518,120.219305,158.256908,216.503109,233.852432,223.81763,152.424448,101.822122,13.064015,4.037232,60.862676,90.595989,118.694505,193.501952,256.594005,273.410829,205.019889,142.802235,194.839281,276.265497,219.527211,191.142588,160.646777,123.154096,13.272489,-6.49482,48.159356,81.350626,62.940863,0.460883,24.994204,99.750049,82.917645,5.221534,-5.330466,57.436991,128.16215,110.479708,10.325323,-25.028752,18.70409,81.72989,115.373253,80.012765,66.236665,122.847368,138.484461,147.941232,149.124061,166.469537,178.514549,142.162429,30.743527,10.895491,54.077592,48.435516,-11.055139,7.729065,111.191847,120.352946,39.987749,-45.970394,-62.339654,-20.882888,6.387086,-13.316887,-61.246547,-158.51891,-157.549362,-123.504736,-31.188123,15.560934,50.959542,16.264512,-83.404907,-81.893409,32.770852,130.415109,130.942,-42.601399,-186.188224,-277.694663,-198.056522,-93.431847,-214.454439,-265.607827,-197.370719,-96.504421,88.023675,111.863658,-1.360564,-74.189761,-136.068676,-162.814264,-177.867485,-217.176913,-250.817693,-297.855361,-270.696911,-114.657739,-7.377363,-19.060993,-108.396168,-158.379119,-237.505502,-234.762082,-131.478287,-77.791407,-69.849159,-179.274622,-214.025317,-252.465449,-295.064046,-369.585641,-373.70017,-330.884405,-230.162178,-188.47913,-150.065548,-126.159288,-75.445464,-81.609972,-139.904693,-147.144261,-120.97496,-139.705667,-158.999712,-233.797637,-290.926535,-305.493508,-227.708598,-27.989033,-29.431031,-111.487843,-250.438843,-291.433248,-369.212347,-363.092278,-212.387834,-148.106949,-182.83286,-282.759579,-306.713838,-296.846165,-274.045014,-229.150773,-218.668056,-196.4729,-122.034753,-100.470678,-157.924613,-186.929811,-116.074907,-32.809258,128.523049,184.338205,202.43656,117.533072,82.848295,28.521067,6.079972,39.590339,73.350934,92.581475,105.898305,95.59733,-3.915651,-75.388866,-146.580888,-109.143596,16.680381,60.14261,117.83,106.48015,51.708215,-97.023366,-139.16573,-114.617823,-76.032175,-31.203906,-24.777764,-35.994434,-109.405391,-148.616974,-122.368592,-51.202782,32.058586,6.775113,-67.122294,-132.428141,-175.164644,-232.851813,-231.206413,-215.911147,-226.799907,-252.564344,-248.824796,-237.181796,-198.548146,-197.812082,-247.2297,-256.141238,-216.628815,-197.487354,-191.50922,-184.210582,-155.011428,-78.193746,-48.764291,13.370579,37.950805,22.947818,-70.798489,-106.923569,-97.713076,-87.420517,-109.672471,-93.862837,68.761098,185.683227,369.450176,354.971188,280.021782,129.667617,102.664275,175.025268,245.078207,336.423618,218.615737,98.975395,-64.46863,-83.007624,-69.673815,-51.452389,20.113984,69.869377,144.631188,103.162747,49.56341,-20.349328,-31.415804,-10.402144,26.007019,113.378796,141.549332,96.587409,-115.649796,-248.7787,-414.097428,-393.899803,-237.531824,-185.968405:-90.788577,-158.201104,-161.825834,-137.05821,-129.666886,-60.314136,-14.314305,-30.551372,-91.117598,-85.305158,-57.776328,-47.341331,33.183318,92.605678,137.84535,134.376523,175.859776,223.401723,207.569661,84.758899,27.733855,47.285669,91.074823,137.036352,108.217765,58.565723,-61.049869,-111.695507,-144.317633,-108.803609,-47.039739,-65.343017,-122.85407,-128.899626,-132.191425,-172.100378,-184.880977,-92.63588,4.725866,156.937541,126.16886,59.029089,-48.757352,-56.00307,-1.682167,52.393037,219.473685,287.457175,239.881499,18.793158,-62.619938,-88.931073,-47.092492,90.789724,148.10539,177.429017,155.73019,136.918051,70.336103,23.642567,-48.466532,-37.752047,72.047718,127.311418,163.325826,124.056594,103.505799,97.985531,117.806756,214.502246,279.703278,354.23009,276.214515,220.277311,178.303118,167.580315,123.579454,133.3444,267.47829,338.53322,336.57965,264.325784,258.744393,177.648316,80.193646,-40.455729,-12.567814,120.443256,126.787046,50.221417,-145.282685,-207.753558,-206.117187,-168.493224,-144.475108,-152.889064,-146.25815,-183.918037,-229.357298,-364.734696,-425.529486,-365.136492,-243.202404,-19.104992,-6.770609,-60.678313,-136.632339,-163.819003,-287.617858,-334.004394,-212.374514,-77.574814,46.233599,-94.775948,-170.364736,-209.342375,-157.270896,69.662517,178.554461,222.765625,124.611588,83.953445,53.439109,63.62391,107.898453,135.167867,184.299643,202.159637,191.456183,103.726308,50.140262,-50.162815,-71.893677,-12.245745,46.005394,110.144507,42.908027,-4.570588,-17.464125,-12.963532,-63.079815,-58.19572,73.136303,127.481765,144.40615,159.734665,171.4099,161.065066,157.6396,192.100511,207.449806,224.133023,258.667741,253.700537,168.963999,115.892849,62.453438,74.212306,157.531092,203.661709,245.101665,268.116327,271.830481,200.747719,158.039893,194.630455,264.624553,374.978049,333.942285,262.82227,130.900806,83.069024,-10.815744,-31.051233,20.966666,68.96948,123.594995,33.160455,-23.849618,-42.684157,-11.99154,26.537812,20.759668,95.471949,223.198839,199.546262,35.111891,-23.95066,3.706272,76.018642,194.302029,206.400426,191.708031,197.283745,190.667295,117.305937,101.231754,211.667668,280.560869,297.044807,176.258322,115.217996,20.224808,-34.930374,-71.2385,-16.173301,117.367843,145.04614,111.463334,-19.001784,-73.475138,-71.728033,-36.940572,24.507072,33.885141,-5.963366,-36.041184,-23.328191,4.444151,5.94123,14.515137,33.055707,88.868247,118.857103,176.649786,183.984025,132.722874,-75.277366,-185.996654,-260.754573,-201.118904,-35.758879,-45.179613,-103.931025,-194.344706,-202.955663,-129.295156,-48.377892,79.73933,72.563975,-66.394209,-178.563804,-180.262565,-203.890327,-257.287856,-298.287877,-235.981835,-61.717152,-72.794934,-138.842505,-221.742505,-223.384132,-169.970549,-110.869602,22.02877,64.505885,37.734985,-119.572938,-195.869001,-253.928774,-235.651034,-180.024689,-177.174533,-206.529759,-186.460738,-181.349082,-224.095265,-234.467156,-172.790126,-132.003314,-84.525421,-62.357546,-30.663281,-35.45829,-39.976418,-57.177587,-54.963693,4.375994,42.878826,79.272362,39.414253,-5.417355,-125.898773,-188.311702,-224.067617,-173.187149,-29.19358,11.477214,-39.105703,-177.080778,-205.380171,-208.908154,-216.05063,-163.731557,-103.844487,-34.420348,-57.949091,-104.453935,-217.070462,-227.954948,-96.166822,12.353604,201.747869,269.914431,281.574227,146.005538,96.429105,18.712646,-15.499361,16.398571,64.594002,100.879286,68.452879,31.175488,-70.896124,-112.629106,-147.376762,-130.907892,-42.758741,8.984653,56.158886,-9.232574,-64.390096,-188.622391,-224.838516,-177.364595,-126.454318,-74.236795,-81.494906,-94.351098,-138.889115,-164.713289,-176.038815,-144.730241,-50.109706,-26.648092,-83.557437,-205.731023,-259.168974,-328.372289,-321.661545,-257.19938,-253.921144,-279.196858,-225.212412,-208.89325,-298.42695,-375.208432,-429.453317,-389.839289,-280.078253,-232.407332,-144.176453,-115.569728,-142.412812,-211.801173,-204.289675,-108.767269,-71.459152,-78.953936,-149.638018,-180.4008,-230.495998,-249.549879,-223.376718,-172.164398,-36.850506,33.642605,184.679774,241.226883,182.347072,15.824499,5.34,163.511946,250.078618,258.76054,92.350824,17.72593,-21.273689,6.02071,74.36061,91.809621,110.593953,140.382679,218.705637,139.712075,49.411874,-57.423644,-42.238084,72.221752,125.732358,186.425916,215.759318,186.795596,-30.642531,-178.974325,-326.301352,-286.67251,-125.997181,-68.662252:-27.81887,45.226498,97.535009,131.619591,105.557655,77.908954,99.42201,141.990358,143.326851,146.392257,131.070596,103.090362,109.641433,153.33543,189.767612,181.427236,237.937789,353.570142,368.642582,303.511296,264.675845,258.474715,281.251553,282.725861,197.256762,147.808244,84.003587,60.534904,19.078757,7.712852,-44.730032,-91.788515,-124.580058,-70.218426,-84.027153,-191.395734,-211.890416,-168.164253,-151.406138,-106.720894,-15.321491,-10.564127,-131.457436,-221.012642,-292.168079,-233.554909,-41.973391,18.517234,16.728085,-72.42041,-96.457195,-100.62468,-113.633171,-133.918312,-119.38569,-73.543176,-25.876256,1.374721,30.864254,22.08261,-26.02586,-23.726906,58.776559,98.102919,158.677344,170.48746,139.904337,82.402544,80.589603,94.5414,94.99217,131.854848,237.967598,265.922558,190.186039,125.041222,127.072344,200.972124,304.579602,290.498641,219.967731,207.100187,223.006067,225.128808,193.472152,143.766599,148.434058,181.005482,211.05544,217.460829,197.892337,154.631624,13.231435,-56.0565,-148.488288,-150.983165,-81.468613,-76.600267,-120.418672,-215.481488,-228.851625,-144.044478,-84.600464,-76.36444,-186.508656,-226.602346,-208.981567,-178.035124,-184.633616,-214.830625,-195.91055,-125.54849,-13.625608,-118.389537,-176.980774,-131.084776,-63.069815,26.08301,38.434492,14.405964,-40.614786,-50.111215,-20.628072,-10.362173,-6.80033,16.597164,88.271676,109.437519,115.163445,76.976141,40.399486,-55.626513,-104.903822,-138.572047,-100.788908,6.946429,23.878336,-13.988292,-117.887508,-127.728196,-56.978992,-25.257679,-14.150375,-36.717279,-134.038953,-136.623525,-51.836953,155.664246,200.619954,151.985362,105.428506,72.462297,93.393209,79.728696,14.054855,-18.111106,-100.639689,-134.510529,-111.386767,-73.550668,-40.077491,-71.867916,-73.099679,-48.868582,-41.554526,12.618809,62.874326,121.544045,69.778228,37.495258,38.231707,59.211308,94.798366,105.609533,81.216692,56.38226,51.037191,48.079308,41.616543,77.9445,109.451027,130.302239,114.338185,76.005381,72.190579,69.79908,18.711183,-20.898018,-78.979801,-94.390826,-98.619169,-89.086614,-68.496536,-89.608485,-118.577374,-167.730373,-166.212534,-87.059728,-40.718147,-42.512674,-107.709613,-118.803749,-88.577706,-68.096036,-58.910415,-58.601359,-59.517778,-58.093311,-12.076897,-17.247154,-52.692271,-60.16493,-25.259349,24.022822,11.735211,-73.540711,-130.086215,-104.46481,72.662289,161.901124,173.184004,108.151504,-21.93477,-43.08964,14.265673,125.071826,163.447699,115.566735,35.417783,-58.301435,-25.931747,81.028483,96.206318,88.138576,137.155817,187.62255,255.634122,263.266185,215.423602,168.965104,113.405048,108.703613,96.483697,-1.843462,-74.797795,-114.468012,-58.32262,79.193745,100.766025,53.982787,-33.413019,-39.217756,-62.35922,-93.596259,-117.967718,-88.610441,1.52845,-16.843412,-54.095219,-92.656757,-101.936547,-151.904012,-190.036543,-207.638977,-131.429201,-121.448527,-131.868478,-96.898799,-17.607473,-30.650675,-98.338266,-89.77524,-4.885866,-14.847223,-67.047512,-204.794167,-257.54398,-232.672789,-176.000858,-103.154069,-105.026859,-117.263652,-151.616277,-194.060595,-330.840945,-371.786492,-329.433855,-280.527064,-216.009337,-223.711527,-231.20573,-217.450957,-199.296207,-116.492006,-77.811816,-64.090968,1.250296,37.890877,18.907305,-22.729325,-82.029514,-54.457188,74.200381,107.860606,93.224322,36.745107,1.40063,-34.125458,-14.588126,37.237821,23.285539,-9.212802,40.067446,30.146293,-95.433032,-153.626856,-126.891787,-51.382814,41.246492,26.188822,-18.467139,-28.24554,-38.880959,-81.751759,-100.440369,-101.410424,-100.910591,-107.653637,-46.660029,-19.421393,-27.266855,-44.160054,-37.645233,2.933248,47.006736,-4.120315,-170.954302,-204.282958,-170.359365,-117.527852,-102.764877,-100.430166,-131.02138,-199.85821,-192.117686,-173.069231,-178.741132,-221.357245,-322.566168,-329.760902,-248.845967,-201.725818,-181.542232,-203.517069,-175.747474,-110.589472,-105.399209,-98.422951,-87.097573,-52.707632,-30.259358,-46.719111,-133.992298,-192.042494,-287.452166,-279.682849,-111.736832,-13.037251,91.033431,128.001412,114.299402,-16.940368,-75.747579,-38.202573,21.235111,71.229959,11.962262,-30.297479,-42.955274,-21.459271,-33.84917,-48.70652,4.728729,47.356427,48.470408,-44.227349,-79.640315,-139.313271,-178.394167,-152.259943,-78.441452,38.440685,11.041171,-55.454541,-199.177331,-246.492506,-275.636492,-250.149196,-154.952121,-105.338822:-60.142476,93.881505,137.424718,115.885188,63.902626,-33.638396,-29.129897,47.646976,52.787448,35.535156,40.366018,59.014757,59.080178,33.050596,-23.284476,-26.913643,60.659336,184.134144,185.268422,45.76174,-29.957814,-33.88246,22.876392,94.98518,58.516728,22.304801,-27.704049,-28.792536,-1.787892,0.171402,-61.030278,-102.166313,-131.422143,-119.877692,-127.435643,-201.083712,-248.868017,-268.968761,-225.910723,-73.099388,29.581992,25.779328,-49.238887,-90.833098,-130.652804,-106.535476,48.317936,146.14185,242.248051,168.009939,134.123526,122.242721,118.744212,131.085737,134.037559,89.683841,123.443136,170.160656,127.339929,21.136631,-117.100777,-76.771548,78.699491,142.240797,275.635085,325.563311,296.143919,216.030154,165.954028,70.964012,66.338116,128.707964,191.192621,207.923616,212.938887,211.018517,259.122996,329.020063,461.629179,461.098242,353.769677,280.360379,256.872993,105.582569,10.085336,23.152173,129.174157,316.058644,345.93548,303.152893,143.332924,68.714842,11.682731,12.008652,-16.050316,-45.181344,-92.703708,-144.365084,-180.243861,-261.700376,-296.142637,-284.06148,-237.809875,-151.435971,-114.249274,-124.744807,-166.601897,-168.172499,-138.747636,-117.680986,-67.378385,-44.698527,-32.967185,-116.790556,-169.604377,-203.301409,-173.169227,-47.489606,6.223751,10.109752,-20.820338,8.386155,130.580523,173.001062,151.785592,108.521909,43.25297,49.993107,111.801422,68.07397,14.776206,-54.611399,-64.014182,-14.32846,25.278241,25.499816,-7.489883,-17.389979,-108.913576,-169.219422,-173.812858,-106.07181,17.348966,7.094669,-105.047055,-129.292595,-90.067452,-28.16966,-36.30774,-35.149476,1.450029,85.791189,155.258422,165.291067,82.780865,18.645011,-70.149464,-93.639674,-103.290842,-76.559733,11.597873,-22.832264,-88.150054,-147.998055,-116.071961,-28.688991,-11.347866,3.826461,24.037487,10.216928,-36.34364,-47.307315,-49.137782,-46.747244,-58.094563,-66.268376,-70.410444,-76.144465,-60.514859,-14.573697,-20.55007,-53.799466,-41.876486,57.961848,141.549198,118.566386,-2.428558,-33.182086,3.960211,27.802037,-15.108595,-56.317121,-54.010168,20.750744,50.012578,33.301551,-17.953958,-108.37446,-119.399083,-96.20469,-87.192563,-104.23211,-147.787449,-167.916289,-185.108204,-173.184235,-144.647285,-133.13626,-104.645257,-149.091179,-196.445116,-228.171257,-208.219153,-185.503872,-204.262809,-262.46688,-229.318632,-163.218064,-13.768966,19.997869,-17.683073,-50.089077,-103.294855,-134.818287,-162.415287,-77.837902,-30.531128,-79.501982,-162.661411,-248.708129,-224.525632,-120.131803,-45.64448,-34.832104,10.352109,58.047954,123.865674,114.387447,9.684332,-50.879209,-100.381031,-73.034323,-51.722496,-92.524654,-161.205871,-227.369248,-182.58415,20.489948,174.973503,142.204706,-42.473643,-100.808895,-111.885713,-88.502544,-30.643011,-18.488427,-42.094613,-81.142475,-91.721419,-131.967607,-174.466163,-235.291519,-223.021669,-123.688155,-23.180529,-5.688881,-6.060092,2.135289,34.494306,37.573175,-9.168721,-43.621693,-69.640525,-48.257135,-54.204801,-203.553981,-312.4163,-353.881603,-279.193497,-117.414451,-51.593032,-53.708663,-104.495311,-160.882571,-340.631292,-399.708777,-316.296075,-223.102513,-145.378587,-233.021395,-258.416591,-178.655245,-120.44961,-88.439808,-93.857566,-47.195375,20.895132,23.026515,9.719394,13.634771,33.211869,65.201893,169.156255,201.405072,195.707619,152.277644,129.271639,64.637813,43.381524,75.124903,94.444006,121.560261,155.406771,123.327403,-2.540997,-38.065163,-26.867344,0.350438,57.709478,75.388928,86.986241,101.292113,97.052469,-22.783016,-111.703453,-150.267134,-88.30733,50.016586,64.374054,19.163256,-92.135632,-127.42495,-135.090882,-115.138262,-128.890259,-186.225596,-280.358508,-232.96954,-205.392194,-237.225674,-271.6676,-267.639229,-223.046146,-125.631157,-71.797596,-64.185792,-121.848574,-192.116427,-297.467554,-270.649363,-123.585532,-70.409113,-17.173555,13.100401,15.839332,-0.494047,-4.076452,26.756806,39.746162,20.35735,14.509512,15.903915,-23.323442,-61.091642,-117.862965,-115.619433,-54.64992,4.77502,174.637186,270.015029,253.433684,133.094883,81.109243,88.415628,113.666032,113.695665,111.697074,124.056193,120.872139,84.550332,-11.067187,-25.684935,7.856275,35.318629,84.85558,28.692724,-32.124987,-109.590616,-105.868819,-57.259725,-41.131479,-32.849777,-80.672335,-135.316871,-269.896347,-345.474218,-479.298026,-503.526778,-450.961933,-391.491279:-60.428701,-100.767044,-95.342568,-25.11953,2.023729,51.710723,71.071305,-3.648539,-93.424388,-67.567161,63.874774,101.549683,113.521453,148.885402,241.198254,230.126056,160.128547,202.371565,227.273001,175.98738,126.106434,124.398762,162.04228,182.058194,122.033043,88.753718,50.477527,47.468748,54.584172,37.83381,-98.420885,-171.921488,-174.295569,-133.069739,-161.75968,-216.836403,-175.213679,15.694666,77.481878,90.067461,108.999004,93.07802,-36.635904,-106.817785,-122.347681,-47.559115,97.086384,103.138118,50.63861,-57.856219,-136.51376,-199.903708,-145.704579,31.918586,93.218569,96.887771,-17.312853,-57.228164,-25.116687,7.22364,21.94324,41.483933,171.58071,227.251874,223.511726,173.1576,147.186253,104.376622,117.218459,186.726898,200.128852,183.431683,194.867974,221.04653,259.901591,241.90471,186.477003,190.944381,214.822153,206.60556,192.918884,186.184203,170.931339,112.715098,73.185036,40.501953,68.312403,173.840884,184.338679,127.14552,24.048608,15.156549,57.619647,75.564717,9.689173,-49.686143,-73.030875,-41.235614,-60.761693,-151.285935,-196.672214,-184.441234,-109.47092,26.714918,-2.483487,-47.651937,-141.263792,-191.684302,-269.524553,-281.48185,-228.94341,-154.328364,36.760023,44.904667,-24.806281,-100.872505,-75.775021,42.124882,103.045853,125.2769,-20.88925,-77.446109,19.777754,126.59296,196.317908,144.420796,8.431182,-15.835027,75.500984,178.534343,159.606997,0.086621,-76.937423,-84.646256,-12.897289,109.756555,28.309191,-50.374088,-135.426352,-133.794633,-122.874092,-112.61666,-34.913095,6.751248,17.075809,13.602828,63.615132,178.968345,184.963372,128.790851,110.994146,158.190584,218.820517,190.271389,82.482831,48.953334,-5.341114,-25.338283,-10.234211,4.475404,14.966678,86.891692,144.541815,165.291107,135.301917,148.860884,194.461671,263.68891,179.534202,111.651219,114.542836,141.83358,67.416059,16.284266,55.114805,136.471221,231.275737,100.114855,22.769676,-27.876144,-9.492091,50.169442,51.022314,16.063363,48.826309,77.377761,84.153866,49.044008,-28.607774,-31.967724,15.830178,44.180332,103.838169,104.433423,75.851767,44.001577,64.831681,139.893414,158.121719,143.415632,90.889276,81.251329,100.443087,81.48782,-0.228191,11.31392,135.767046,166.249202,95.180185,-4.56499,-19.686455,-16.591183,-9.119351,23.807488,19.819527,-66.713383,-95.761299,-68.243647,-30.855097,-21.92477,24.739856,54.776111,80.831474,79.531679,90.075527,124.435904,116.729474,-21.002713,-111.884823,-156.763577,-115.30773,-55.041818,-62.149871,-72.399034,-40.595792,22.934064,162.519209,182.840146,131.494563,108.975036,66.985076,-12.883599,-37.610187,-92.89998,-139.095482,-199.503327,-195.372358,-144.631364,-86.059681,-71.390921,-75.692412,-86.400552,-102.961048,-90.36383,-1.674134,44.146833,34.951242,-92.263637,-140.599268,-144.981407,-127.52556,-164.224483,-220.85919,-274.320847,-180.843231,-143.749734,-172.861823,-196.61633,-168.4083,-143.2499,-128.302186,-116.583038,-52.525571,16.748762,19.271066,-90.072771,-152.141315,-103.526664,-27.735152,-1.241045,-107.423181,-146.246995,-177.974388,-195.441454,-235.495576,-226.970654,-175.139968,-177.567129,-242.453878,-222.724356,-153.869517,-54.294007,-71.356531,-149.632012,-176.472731,-195.470513,-72.181659,-0.175362,-36.943879,-114.172818,-164.256361,-101.662063,81.273818,147.831584,180.675234,63.253191,-6.152576,-52.639748,-26.279497,31.025893,24.146766,9.341806,54.015231,24.976609,-132.695897,-175.486846,-108.780378,-41.075372,35.184924,33.200956,-14.347067,-102.134648,-139.247434,-149.98874,-117.929106,-56.594497,-64.956008,-64.732221,-0.528273,-0.655102,-50.772001,-67.890543,-59.977482,-36.265602,23.993426,29.685249,-71.620791,-223.972715,-261.126642,-237.332913,-208.206851,-176.475132,-179.441387,-196.803647,-206.794347,-218.543735,-216.020227,-198.951601,-201.329276,-229.122299,-281.916783,-275.91865,-205.021884,-204.713316,-216.106358,-155.742086,-120.767379,-131.569595,-141.017286,-99.367103,-8.802796,21.308514,-57.317733,-161.463581,-288.899273,-247.979889,-56.278454,30.010484,124.349391,62.260609,1.757299,-25.147563,2.774971,28.230885,29.175587,81.032273,70.900184,19.523046,-27.626562,-20.656852,-28.14031,-37.227012,-35.313545,-6.322247,112.381071,87.830303,-3.084182,-161.2351,-190.660132,-166.759067,-118.641286,37.154025,142.106917,122.367415,-19.017995,-102.797216,-199.616551,-181.312142,-74.281054,-45.443585:right
-297.024968,-213.04542,-172.615769,-212.26265,-226.320504,-154.836542,-125.351779,-96.275983,46.170126,123.003714,115.744031,39.427281,-51.727553,-23.342791,57.407848,65.820448,9.219505,-80.955489,-89.271737,-40.860584,-16.348986,-23.477906,-42.728032,-17.271657,-17.998735,-63.570923,-131.47828,-138.092459,-149.804229,-173.017577,-235.807401,-237.118374,-151.783357,-67.809416,-59.987611,-77.729116,-65.513061,-4.351173,15.838532,20.512612,9.276692,-0.215792,-89.557707,-163.848641,-222.385853,-186.784711,-103.541107,-74.335744,-14.762667,18.410653,16.850213,18.873704,56.000805,205.334459,277.873002,292.005338,87.04421,-28.678479,-118.269378,-89.010128,11.707659,43.3788,58.516555,67.793857,57.914144,-59.196313,-127.803903,-220.475802,-234.1413,-189.463202,-153.940527,-159.119549,-223.35348,-229.018694,-225.111531,-227.342693,-131.30004,-22.745923,154.480429,179.196664,145.618668,104.782535,82.639296,58.708366,85.215295,166.865635,179.970707,160.82265,120.127631,97.376706,110.849503,139.505221,144.549048,102.918113,23.162363,29.250013,66.809119,65.559158,50.69961,-55.687465,-91.634591,16.169148,119.230105,275.594411,333.900059,343.149788,285.726306,213.273912,133.942483,162.434249,245.739806,265.939076,263.597589,228.427304,184.287577,81.474706,83.490636,191.433322,254.166673,365.528523,387.497224,352.127549,224.309335,175.058922,217.246767,270.974985,295.566745,279.980576,262.849489,218.970636,175.228774,115.254179,134.201412,247.456799,302.821626,369.742325,329.029494,289.600978,259.835223,245.587354,182.533776,159.832476,176.729095,209.820955,222.149051,123.068693,64.285394,-46.379122,-77.11877,-75.222386,-49.475708,69.257249,100.206979,43.51487,-85.060281,-136.054203,-210.127411,-216.457871,-155.05883,-100.345719,12.334002,67.101279,49.057735,-36.832427,-68.24062,-85.803317,-60.263801,107.763637,282.51106,289.026245,133.911032,34.824211,-8.916033,44.397271,166.747025,230.409376,342.15676,354.631016,316.697513,188.376944,152.106598,168.347928,180.16599,194.411733,209.606469,205.474552,212.455489,224.491665,234.509079,242.909542,305.618473,356.582376,411.860038,316.566327,226.254656,78.721549,55.162385,57.907853,51.898443,16.581489,-16.313713,-15.601739,-7.758549,-27.067827,-113.657325,-148.37824,-119.406797,-58.698935,57.535282,104.989562,109.645479,75.814169,52.533397,77.026214,133.139912,222.89838,167.681619,119.623623,58.838371,36.510201,-18.051699,-46.641911,-99.920967,-127.279444,-192.668016,-239.324637,-259.274528,-304.726445,-301.971797,-248.74093,-226.661952,-183.268837,-124.434296,-111.977837,-143.400207,-160.593201,-119.604226,-65.501442,41.010261,84.265603,162.113709,183.998051,152.30618,80.456908,91.152912,173.449892,197.644817,196.88973,224.391125,269.350403,292.946598,238.038085,171.285048,207.122649,325.866007,376.485988,416.335751,362.236083,298.125619,140.347256,112.416194,207.432546,273.402664,323.037656,231.562216,151.871751,20.370882,14.25344,135.06707,190.747497,177.138293,152.456252,89.110782,-59.636795,-111.373082,-104.527864,-72.200636,5.964385,33.373726,29.950684,41.547949,67.511795,35.974915,-47.751574,-203.521447,-216.081677,-174.278969,-167.90093,-168.463741,-123.129846,-115.355909,-207.419423,-262.850843,-270.031882,-232.165179,-122.079653,-69.834681,-113.518696,-289.729585,-333.032888,-207.199368,-99.370414,37.271272,74.893904,124.838077,70.954542,-10.090315,-162.282503,-174.94446,-154.293123,-166.127895,-187.135385,-180.100655,-152.54632,-92.639166,-123.327715,-258.425717,-281.696429,-206.063304,-160.309777,-138.262685,-208.359958,-256.690615,-302.952344,-280.913663,-155.980072,-91.638555,-97.393073,-265.287303,-325.071341,-326.468645,-303.764717,-251.16202,-218.06355,-127.97871,-45.403577,105.044731,13.143917,-77.632028,-199.288198,-232.425576,-242.302802,-206.928182,-120.528656,-158.59125,-191.387211,-186.585314,-157.588913,-54.05096,9.070544,91.862025,97.356514,44.056692,-31.518332,-52.182286,-56.992936,-57.104091,-73.583799,-77.173747,-86.447969,-160.21726,-195.459547,-241.480941,-258.672295,-195.630295,-110.392318,33.926056,54.736474,12.922411,-59.91432,-103.254128,-200.503675,-221.334205,-186.463065,-153.180243,-64.786964,-56.650604,-115.295065,-263.262664,-305.668237,-241.320788,-150.454945,27.364698,83.537266,102.594763,53.068856,27.720503,21.039764,57.957168,153.250288,183.258103,211.431251,231.043296,249.00289,275.806385,260.277784,193.442258,167.583736,158.942569,172.06556:-172.596696,-166.295206,-177.625929,-226.564092,-228.152663,-112.40086,-19.347589,81.201592,-0.862693,-50.577968,-119.347604,-142.778703,-107.684162,-62.343833,-22.610266,-28.035295,-29.008025,-33.738367,-50.033667,-54.024343,-19.241033,45.372508,41.181816,31.647175,42.877745,19.634251,-92.366796,-166.646011,-280.20987,-289.722227,-217.000635,-162.44852,-82.45905,-70.324326,-107.328828,-227.97891,-246.657025,-151.553994,-90.37608,-58.867175,-70.257535,-50.387111,-92.130186,-184.979691,-316.59668,-298.638784,-184.126485,-128.759253,-83.381064,-81.125174,-53.493236,8.647316,37.862716,164.469323,237.099257,238.017248,59.322106,-18.939223,-72.345441,-51.49711,55.279984,113.837934,209.94662,246.12894,224.712217,75.642996,0.720704,-89.934034,-106.083164,-65.34611,-17.439422,11.121738,-116.798837,-186.063682,-232.3894,-187.623175,18.716925,116.012642,186.888885,169.568438,91.757332,18.398113,-12.578835,-43.329004,-33.969103,36.359247,95.609306,185.494373,133.868619,74.683378,-14.889495,-20.605041,20.6741,41.627228,77.772886,105.521077,167.113706,126.529116,35.429135,-139.498422,-135.871345,34.883123,126.651101,237.334932,264.441379,238.755373,128.76366,99.731759,166.707047,221.476388,271.68775,257.107384,177.282834,116.480816,81.53632,19.251728,45.988393,179.564276,220.055269,220.082332,231.108831,228.716724,131.25407,66.047093,24.392077,49.480014,127.923807,161.65632,162.450408,40.231923,-44.273432,-108.730678,-54.348338,96.684868,153.213676,219.957164,157.027092,111.187672,83.389924,93.496854,143.891285,162.158272,128.955551,86.308717,-15.587199,-118.733299,-164.694361,-192.53278,-176.582829,-161.810598,-150.22223,-82.00405,-81.801686,-102.940292,-123.448442,-133.06989,-155.133117,-151.916542,-88.03535,-38.495308,34.113733,20.071934,-19.655658,-68.031669,-39.497237,70.377828,131.167223,247.336782,277.94183,249.308495,117.491146,40.659843,-34.243073,-16.159511,116.750427,201.606146,246.24369,107.59032,30.219587,-81.22128,-109.527872,-133.708413,-141.974173,-157.830124,-170.651451,-150.338512,-44.729716,5.439791,72.257632,93.578375,118.730337,139.009548,186.360223,157.819027,108.472219,-5.163751,-46.090598,-40.139891,1.786164,28.258219,-136.16718,-221.965958,-270.449066,-258.310571,-233.118932,-213.94728,-156.394276,-136.444941,-113.348147,-61.021451,-50.374025,-99.884742,-112.691509,-35.844747,14.765132,36.045071,5.275228,-7.82656,-57.845065,-74.835768,-31.193511,8.204619,37.676765,11.972051,-126.39201,-267.337944,-298.435761,-292.048249,-248.317274,-121.931594,-92.295966,-99.041515,-52.009868,-31.474025,-60.565455,-73.610766,3.295226,72.538909,173.033451,199.530131,202.622007,136.01165,84.152034,4.274933,7.092315,67.377269,90.971587,128.632831,209.603424,235.999335,144.285129,65.914839,57.921183,119.24328,250.891855,302.428498,278.322598,140.730607,80.752116,22.421745,69.945057,277.95267,363.316397,406.76103,267.478986,162.438037,46.591909,75.141289,226.350971,270.640573,254.410687,253.449843,259.261968,131.403965,70.919494,89.206792,133.037861,183.033223,209.149046,291.468867,268.145117,224.185915,207.803712,215.178113,163.770982,120.903788,36.856513,7.411208,25.465876,67.721801,41.912785,-47.270873,-45.052801,57.717999,111.768894,140.376412,36.086198,-52.137076,-246.650326,-287.997834,-124.072865,29.018227,243.936896,259.568271,146.781457,15.807166,-47.201387,-181.182996,-213.22511,-169.12991,-115.894377,-37.221039,-47.360414,-62.017125,-72.958431,-81.793278,-146.782634,-178.049205,-149.943644,-125.800684,-167.671182,-197.655067,-194.165208,-235.143391,-238.872571,-121.918304,-60.394552,-50.14736,-113.55426,-138.723745,-137.490618,-109.330317,-25.428428,12.986039,77.990366,123.897786,188.363123,73.362314,-15.0161,-103.968805,-90.159546,-17.919343,6.602849,12.748184,-40.726139,-78.631621,-159.837065,-199.338232,-175.192994,-102.688383,25.309947,42.993683,-14.065954,-71.57482,-64.027569,-21.06443,0.585101,33.420983,51.760839,103.376796,46.811737,-36.597934,-210.777259,-254.231364,-157.818021,-46.834292,106.540097,124.964921,144.255228,131.57946,59.135043,-108.655435,-118.698681,-49.545634,-39.225476,-63.690779,-117.238846,-159.171725,-213.868291,-204.165564,-135.118357,-113.406348,-94.149824,-62.896079,7.448016,2.685172,-20.183562,-1.926132,72.671943,250.916389,302.617689,322.438685,308.090949,314.720057,295.488359,250.464602,161.711538,140.470062,143.496617,160.789405:8.811179,-80.160686,-125.519774,-186.212284,-182.450154,-105.152325,-36.013831,71.010972,31.05713,-25.497193,-147.925544,-183.359669,-167.23473,-134.976747,-68.529245,-54.019029,-101.094154,-140.325275,-111.921816,-6.482799,39.248583,83.80267,92.067083,105.79042,53.556486,-4.778903,-114.164955,-140.814612,-142.668042,-137.706107,-140.501194,-138.102736,-138.156681,-194.560307,-241.920665,-274.632879,-232.417189,-96.200802,-35.408489,-6.838933,-88.40716,-122.518994,-224.803713,-303.422475,-376.939791,-321.814205,-93.215372,-4.862347,4.473013,-56.790376,-47.502135,33.335709,86.381487,205.70824,254.995791,224.012819,46.976255,-13.276581,-22.999686,20.391544,186.837418,256.778446,262.044159,224.570492,120.458689,-29.494708,-92.5055,-139.732112,-132.525164,-56.103829,12.555004,89.345032,-21.610623,-98.194955,-148.703407,-92.624561,87.059501,130.412033,86.621745,48.707597,-25.836088,-145.186346,-191.437677,-169.12549,-119.13918,-5.63926,69.90377,203.93499,133.064881,48.939031,-22.228558,-20.374067,-39.71421,-38.636811,31.290082,72.219732,88.547105,14.461548,-47.116185,-138.743468,-136.741893,-49.554126,15.444299,133.507341,143.679621,93.282209,-10.391311,-6.71646,92.727852,137.656898,189.799915,191.199686,100.367245,-13.952099,-50.886843,-103.059196,-111.714867,-64.108098,-9.881982,106.660367,111.084998,60.807077,-46.213739,-70.204419,-32.641748,32.802164,189.171636,228.750208,168.220369,-5.721272,-67.683149,-65.71575,-28.7028,60.845326,119.584346,187.932852,109.127642,75.623062,113.981804,154.059087,147.165938,106.416129,102.318526,136.234666,103.407812,-36.290092,-86.288103,-134.689313,-147.72682,-143.462116,-112.496538,-36.843277,-29.756931,-66.740761,-170.997291,-170.706421,-43.625678,6.846329,-10.233464,-34.427263,4.791492,45.720199,1.834404,-47.07476,27.307771,237.25173,301.69634,364.237541,325.461683,256.175483,112.200913,89.418124,117.947762,122.448741,132.446267,148.733509,90.416337,-81.764746,-148.342957,-215.683194,-242.174394,-298.272483,-300.606502,-242.800808,-182.01939,-160.141605,-117.75181,-90.356715,-8.908974,29.072355,84.490988,115.905025,162.56776,143.809819,94.777882,-22.240659,-30.085995,33.835359,42.672839,-35.873167,-177.872916,-248.062973,-358.348112,-376.274616,-299.946277,-224.457631,-109.283965,-95.924646,-95.299881,-51.120011,-42.890025,-83.752118,-97.819508,-60.47116,-21.76273,44.087306,44.64763,9.086748,-116.871887,-155.668767,-84.065128,-0.286677,84.492359,31.557812,-154.580179,-218.383451,-208.774333,-169.896298,-155.794812,-156.493964,-152.200675,-118.773811,-52.646112,-2.709214,34.491043,11.159576,20.755923,89.700104,252.547114,282.069761,196.48419,89.353607,68.051851,47.309665,53.204516,120.447015,163.954167,215.603239,202.223426,153.615855,-29.05851,-107.01541,-96.810172,-23.543409,154.077408,228.400097,248.840534,102.137242,17.748454,-79.307655,-57.204344,127.121601,238.366153,312.940969,122.666038,9.913366,-76.229661,-27.718323,170.268577,237.531913,227.046988,200.790095,180.571772,143.657722,121.068756,118.761839,133.04546,170.65557,193.482421,195.24501,115.71857,84.199826,104.998938,154.05728,273.077098,296.898637,232.351362,187.935031,128.495702,52.19514,15.625012,12.472743,52.875362,150.920907,188.833868,193.934086,46.306591,-34.638908,-141.142375,-162.053625,-65.471698,42.334167,207.368139,212.5695,117.936325,22.500731,-19.186746,-89.82865,-118.683285,-171.060003,-170.193966,-97.990674,-25.263753,0.975127,-4.236547,-59.207658,-219.220191,-261.4112,-191.872706,-126.228112,-94.917294,-204.260547,-253.699597,-238.215665,-185.297103,-89.877998,-56.360027,4.466836,24.661041,-2.394169,-75.842129,-70.726051,21.571146,57.059735,71.638769,80.182186,99.183531,77.546902,71.022615,42.025048,0.775459,-23.830446,34.898696,176.750771,137.747898,48.479466,-127.988819,-155.01114,-72.062742,-16.291427,38.022799,41.411303,7.651982,-9.805828,16.266931,68.083248,54.103167,-3.069332,8.925645,97.288971,69.057516,0.088976,-119.098913,-140.155061,-122.993286,-90.625757,37.937401,106.342497,146.425324,60.00968,-13.09984,-110.086542,-92.161164,-0.26536,28.258243,29.749748,-77.456234,-159.44142,-261.012242,-247.882398,-140.758767,-103.421105,-85.650448,-65.143028,8.687143,53.43455,54.035316,40.024993,52.245116,166.464493,253.340054,319.263111,225.440678,204.786782,211.338821,204.830768,206.746497,227.681864,254.171801,225.689049:-146.26552,-180.748888,-206.58055,-246.716931,-230.000413,-96.816988,-11.485289,130.837817,196.675173,184.489395,83.510673,21.021486,-16.221731,18.302376,96.406475,106.27276,19.891989,-106.098129,-114.79366,-21.207164,36.359424,82.494217,75.802732,31.443376,-55.18279,-91.337159,-168.790479,-231.72063,-319.875605,-314.599184,-255.866298,-228.820783,-192.848801,-167.939258,-185.192612,-241.136188,-218.42256,-103.270942,-64.719777,-51.221217,-76.548833,-87.117023,-138.757432,-180.114704,-243.632897,-246.585513,-143.74957,-68.240546,-12.529671,-45.676972,-57.518281,-57.668287,-32.741608,100.313701,183.440325,200.261912,-19.845575,-103.887741,-123.527625,-90.507679,38.889125,102.588222,134.030436,125.823304,85.248849,-51.063422,-137.667253,-263.021392,-276.963215,-180.892339,-86.541842,45.471533,-11.078683,-55.95332,-78.4984,-60.308248,26.263989,82.111316,139.012175,113.521903,-14.950336,-67.785617,-36.198257,38.685114,52.832988,80.254058,121.15055,247.088702,234.204992,145.280292,-9.548506,-17.350019,69.047121,110.225907,137.523616,148.519765,148.529527,44.310255,-24.033851,-147.974831,-176.020436,-73.568464,38.789789,216.411433,226.486512,201.841724,138.321614,117.17465,174.768201,224.452321,258.329993,268.49271,316.509378,258.652758,164.896939,27.349738,56.267386,202.171689,238.105279,243.974928,251.52344,251.193443,202.357124,163.08676,143.776403,176.119779,326.37947,421.130551,479.902173,335.901138,266.763271,223.380736,244.232248,346.408568,406.073983,439.439361,326.856977,283.16604,263.893586,233.767587,124.160087,99.523886,133.658361,157.437559,132.281747,16.731243,-49.390966,-163.712435,-195.28223,-201.22274,-170.603664,-71.643913,-28.281551,-32.458913,-95.041659,-137.695929,-163.371678,-139.792379,-38.260409,33.610462,117.216677,36.274851,-13.52547,6.956457,71.93872,157.411064,170.089405,230.671668,266.532556,245.215828,163.69729,136.571814,142.082247,151.838126,202.380591,267.570766,353.158923,257.238803,187.933099,87.303731,73.087246,106.865834,133.877769,187.01112,175.142554,152.627925,174.316268,210.329678,291.537975,352.3912,478.979083,506.658525,475.037163,382.923476,307.205443,157.5537,142.541442,182.795769,175.155602,73.776374,-86.859083,-132.964775,-104.631574,-72.534753,-28.672547,-10.284565,2.294525,-2.470163,33.953595,130.145225,137.222035,45.048032,12.073247,68.013126,132.479023,245.825196,242.396219,193.472638,68.053499,12.903064,-40.535483,-43.174557,-64.553651,-95.949729,-186.769852,-259.994914,-291.152119,-352.890971,-351.919805,-274.2591,-229.042994,-138.312036,-28.299166,8.533119,-9.838898,-33.09179,16.762003,72.848004,157.091809,187.269252,210.114685,206.559154,205.253514,147.009499,120.02916,174.301104,232.661589,319.905568,371.631328,398.319291,359.430038,269.828476,112.238516,104.008039,210.465774,289.458005,362.078353,263.503106,185.198203,61.4962,55.085815,164.540819,226.741808,244.205444,77.443742,-54.96615,-248.681441,-237.030441,2.489467,130.681714,139.873566,48.070107,-94.208959,-136.699853,-136.808329,-124.622846,-116.702532,-54.24494,3.482736,72.237141,29.969528,17.278429,23.542867,9.351429,-17.581111,-7.172041,-11.843924,-45.008017,-146.751724,-238.390864,-261.99561,-241.276399,-177.875318,-9.467167,26.625065,-42.737988,-155.60629,-189.042148,-244.784584,-256.53434,-138.128524,-29.016851,142.595384,193.608937,223.03559,137.944255,59.049102,-113.522058,-180.235881,-231.986833,-193.522989,-70.748986,-48.595914,-44.391152,-59.652239,-120.142348,-285.21441,-326.569388,-261.054833,-177.553838,-50.425144,-139.240188,-240.509523,-350.297325,-310.64911,-166.200958,-137.769146,-172.031886,-229.601606,-253.655394,-274.397235,-269.347948,-211.873889,-177.077029,-127.432865,-81.981693,17.636901,-11.374573,-55.624235,-120.958277,-140.031325,-129.699964,-79.307307,43.466481,-18.446169,-104.916814,-235.580175,-248.616846,-154.147638,-91.639525,-60.537231,-76.883845,-94.129565,-85.977522,-78.678329,-91.189747,-111.253383,-130.273913,-120.273745,-71.126603,-36.001532,-66.062733,-254.114168,-354.35677,-370.318589,-281.191617,-100.678533,-68.472639,-72.722774,-127.25022,-186.083064,-261.642728,-242.977603,-215.325979,-225.031185,-185.766732,-189.205658,-260.380234,-434.178316,-453.965597,-302.64362,-210.838025,-99.635288,-45.689244,0.586034,-92.363657,-122.857536,-57.296664,33.121834,220.991619,271.194636,259.87671,194.919859,179.086894,163.557524,156.781363,163.396386,166.864219,129.542321,82.993506:-154.158074,-225.721605,-240.449791,-221.496745,-174.570282,-25.263783,40.961042,141.111034,199.864656,167.356897,-24.033996,-114.122692,-165.236382,-143.736568,-50.521248,-8.187375,-76.506685,-221.848215,-212.200796,-36.870582,49.00404,107.985539,96.283443,-5.389111,-183.061282,-236.096377,-251.910403,-258.826305,-288.951841,-279.640321,-193.023434,-155.761246,-182.278709,-283.879077,-327.824317,-350.538788,-323.591432,-215.167191,-139.38109,-27.679675,-60.319169,-98.286328,-203.565937,-262.638568,-288.262417,-241.866302,-89.579891,-31.263239,-55.637558,-115.388394,-99.121436,-49.879134,-13.475625,102.484384,139.454495,110.024087,1.798518,-58.395019,-144.833797,-136.499475,28.948801,132.484954,197.025936,152.650367,18.353315,-137.763706,-234.380121,-329.553746,-278.011391,-64.502334,29.721788,79.87192,-72.079666,-149.102942,-188.301463,-161.828456,-50.106771,10.636822,67.583478,53.362155,-48.598138,-178.999515,-225.417405,-224.525653,-170.122131,-15.315696,60.106987,122.169672,-12.021892,-87.39167,-111.658861,-85.296806,-73.591758,-72.911949,18.653051,81.178779,94.19424,-20.778459,-104.026146,-255.648153,-253.379123,-86.613976,9.399595,125.954058,89.484997,41.28583,4.266695,33.636856,166.813779,230.233272,278.731595,269.19082,191.55182,28.459135,-79.047133,-189.214608,-127.270214,103.629339,172.359693,143.075815,13.968462,-30.302964,-31.623094,-1.778463,68.551221,103.262663,221.37274,291.480543,301.179928,152.846283,101.984601,106.391957,133.951188,215.624863,265.543275,306.398658,239.906852,196.502109,90.160127,39.98467,-3.353387,-9.937392,26.201101,67.965586,55.555946,-91.715117,-148.263091,-209.347179,-223.036108,-182.127863,-120.782957,2.730235,37.420117,40.210162,-2.858797,-38.523669,-6.984582,56.306205,153.878152,183.411674,221.977294,158.745785,96.920052,59.811817,113.973913,259.518304,307.632647,321.522792,240.137581,190.591085,80.664041,45.183125,93.041866,145.047626,224.555313,236.607705,130.961051,-52.378548,-112.572851,-169.737087,-175.037974,-151.238995,-129.577265,-68.022037,-45.592428,-65.73638,-62.688119,-15.981272,94.029686,149.209517,293.28757,348.454407,320.437628,225.868846,179.824611,37.427949,-20.772399,-33.844,-23.460419,-51.467579,-139.060411,-188.40201,-270.545871,-278.959185,-195.739626,-139.66783,-63.940053,-35.247005,-21.791108,-27.314179,-20.104765,-61.601836,-94.185312,-60.510236,8.013406,137.35969,72.921469,-40.194246,-234.885868,-250.097752,-161.443525,-109.865757,-62.175043,-79.455247,-174.667155,-242.623743,-254.845256,-273.149873,-273.930882,-197.038358,-114.883478,47.691216,107.331643,97.426822,25.843479,-2.242846,51.139483,124.128739,283.00497,346.052833,363.315232,209.770329,122.232681,71.976637,125.285456,275.82887,335.649947,394.892424,316.284918,237.408752,66.495202,11.154895,55.35908,143.263202,310.233073,343.540703,305.912765,202.964474,137.784606,81.893057,121.101908,228.742554,274.242892,349.104727,260.574383,161.027559,28.337964,32.167433,144.332323,222.236939,360.830289,392.042551,333.949005,201.159652,153.263116,127.350237,129.72144,185.016142,269.010947,402.532792,317.522596,252.95881,178.764665,175.262372,245.209744,292.572606,328.050247,303.604086,165.234486,-2.421377,-52.006172,-27.09425,49.668919,224.577301,275.500255,260.754561,111.382143,35.954245,-31.207094,-14.919543,90.581597,158.716202,294.178126,334.409697,298.808043,160.766676,82.494319,-58.01138,-101.480413,-88.613972,-34.921177,53.067651,15.157563,-4.279296,-11.915845,-38.598332,-123.68117,-129.565488,-10.144308,64.512338,86.48225,-55.941406,-141.655295,-220.268585,-181.57705,-10.961415,69.350552,134.504615,43.044342,-24.725944,-143.72294,-178.126369,-117.010495,-56.11,-12.461221,-3.489755,69.009785,86.176672,32.296963,-99.405304,-114.622375,-27.955453,46.692075,151.239761,52.357256,-42.36594,-194.748394,-229.00217,-171.099969,-101.031191,19.610483,42.99699,-32.537714,-154.150514,-171.498288,-153.77402,-151.120954,-150.721479,-135.650783,-85.39841,-64.571892,-101.543434,-272.960238,-331.215791,-269.01674,-187.464265,-2.874869,63.991258,7.199243,-184.391021,-240.777152,-202.74063,-139.712601,-87.211397,-87.228768,-67.544588,-156.642588,-237.661893,-322.724217,-319.923361,-284.812598,-242.544666,-85.369069,-20.183038,-28.329062,-88.322763,-98.026904,-62.763954,-1.156167,166.510603,233.147388,281.261317,220.955483,168.255291,81.040529,74.630676,135.181918,176.263435,232.109927,216.550023:-271.175652,-230.638945,-197.684217,-230.836846,-245.315559,-162.44263,-86.508077,76.90007,194.5491,207.241438,110.181369,22.253361,-76.865304,-65.328699,-27.362834,-23.782255,-48.724612,-117.519519,-141.630054,-146.408879,-132.180644,-97.437236,-87.593636,-75.209417,-75.589278,-77.348606,-153.157669,-246.205355,-371.246089,-350.179407,-252.35424,-218.653008,-177.353314,-184.946156,-196.607388,-165.879655,-118.746138,-38.405913,-35.968889,-41.920262,19.219413,34.356707,-39.65635,-92.319968,-131.418193,-151.123775,-212.296367,-210.418005,-200.92805,-241.611774,-243.449593,-165.237695,-84.878425,69.544469,105.361388,75.534153,-78.817898,-160.346694,-202.241868,-165.602513,-60.738708,-11.039144,39.783305,22.476052,-80.126974,-198.86088,-259.981121,-347.196764,-339.962804,-237.531447,-189.191027,-184.096151,-235.696837,-242.923358,-226.295694,-201.274035,-83.308272,-16.340106,35.42652,29.849504,26.823325,33.067117,18.316858,-20.915737,-14.994409,50.703464,86.216675,151.620463,162.590542,125.362376,56.640628,46.315678,38.272794,19.131432,-2.881442,36.696207,117.808837,34.894029,-40.410029,-186.689254,-209.30356,-86.969311,3.753051,103.33685,75.100755,37.619604,-10.89002,3.926004,122.136994,180.80325,195.43142,186.865546,215.981229,183.491957,119.503244,7.055927,28.505943,207.162554,282.747663,287.918098,190.880065,157.786599,134.567248,146.576925,225.556775,265.992475,319.646207,353.892325,433.290029,394.15084,330.770989,268.338414,297.622365,412.875029,459.019269,436.644215,257.218241,179.436138,154.606659,183.778802,252.984616,263.630782,237.636672,246.111614,272.015636,214.069241,168.763235,63.853581,19.163701,-8.855218,3.041617,8.953554,-64.988068,-104.354413,-181.789134,-237.770461,-289.560006,-256.631839,-160.014173,-124.50601,-94.500455,-130.289497,-151.827405,-129.08735,-94.346674,-61.026594,-43.399437,75.704513,155.949661,146.732722,70.812453,10.961659,-58.152196,-37.704181,90.728698,170.266081,236.13698,214.453115,211.831301,223.988938,252.708482,329.885459,351.75984,360.556304,334.309273,323.296935,353.578354,364.469447,320.797457,321.071994,434.697258,481.688927,454.351779,361.052349,307.781377,177.427332,137.287463,147.287835,147.080152,48.679643,-139.889028,-193.819376,-121.271936,-60.472044,-60.531071,-79.044903,-15.809048,36.144534,106.428724,156.035886,152.240669,85.1943,71.855072,140.128543,189.358987,258.972284,250.286476,208.472136,66.40724,-4.545764,-69.589096,-75.29598,-83.627336,-104.120205,-239.697831,-379.631314,-385.357965,-328.46291,-308.101726,-324.267882,-343.583754,-288.925672,-121.999704,-66.200734,-88.820731,-124.588614,-111.390204,-70.986818,26.334343,93.73645,213.533788,221.78269,193.894939,113.924647,100.731921,197.388059,286.656448,412.192239,324.382547,255.097999,207.227186,215.09827,267.80186,315.933643,422.887913,465.557559,475.728471,357.011685,265.567482,120.262932,114.905814,204.423794,252.484063,299.891198,217.538734,120.669792,-57.863757,-84.249453,13.803588,99.716466,192.33322,168.473726,13.267014,-148.183946,-203.897488,-275.677854,-282.842798,-206.37058,-127.860058,28.104718,70.018728,56.331092,-33.952683,-105.225901,-127.968441,-60.779476,11.877193,-17.546275,-63.494122,-46.437331,-91.809534,-235.108153,-211.659697,-22.418452,8.632589,-61.310024,-82.242255,-84.007548,-95.508748,-73.25468,59.517029,133.789484,228.806944,267.664461,325.496067,247.915113,158.34461,4.460387,-30.493191,-114.266774,-179.491284,-202.626486,-77.512482,-37.869413,-64.520822,-107.411231,-169.64464,-182.931177,-167.41525,-124.760238,-20.757547,-59.692977,-147.906404,-294.172987,-282.260318,-146.223242,-93.878925,-90.781413,-216.056964,-296.530033,-387.02126,-391.707808,-341.164314,-290.275482,-153.323701,-74.180216,34.075062,24.087553,-14.391778,-124.623631,-159.469276,-133.809129,-86.93307,28.291941,40.318323,-14.806213,-121.929545,-118.068532,-5.699852,39.656344,50.724202,52.378952,53.21283,26.209247,24.936445,52.061242,62.297311,56.177411,51.974128,41.583043,-26.939956,-92.621731,-247.73996,-293.456456,-257.297106,-186.648001,-5.290257,52.001135,19.555856,-105.407313,-174.439379,-281.693235,-287.857156,-207.318269,-142.583422,-43.792893,-116.431002,-184.055762,-267.669745,-287.871386,-254.531744,-184.175748,14.007115,96.509391,133.90891,72.090612,41.938147,30.666586,65.717292,187.693205,261.600883,375.942752,295.762085,199.924851,105.082033,131.168623,223.779756,243.750072,179.978619,125.69597:-166.35329,-155.391601,-197.087146,-343.134694,-343.974027,-110.642347,45.742867,212.259867,162.828832,92.237218,-94.888818,-152.823803,-73.0073,12.736874,89.192563,68.72093,-54.892224,-193.215043,-225.789054,-181.195129,-112.150391,18.11049,35.06633,-34.466795,-159.611568,-222.120039,-360.617792,-425.871146,-408.962815,-308.867867,-126.659458,-116.560681,-217.556947,-298.132455,-322.651562,-366.689565,-338.043968,-148.77356,-46.527235,56.119473,8.753377,-36.174389,-148.506826,-213.153175,-252.468613,-201.884904,-59.220319,-27.839333,-91.178217,-170.910923,-174.244854,-151.02001,-112.281698,39.074106,103.766943,99.05399,-48.625241,-145.131399,-292.583217,-279.09618,-60.620046,66.839283,209.962394,211.552796,61.072893,-187.610402,-291.166927,-369.157897,-338.663739,-197.962789,-107.666483,6.304439,-96.936426,-190.61487,-282.005146,-241.422885,-53.283993,19.0669,15.587857,-27.975782,-82.129748,-115.527337,-155.350904,-194.552975,-153.955398,17.79056,117.439438,244.889652,113.90503,-24.091158,-185.093824,-164.657614,-25.137188,35.438521,111.082816,138.946417,110.616237,-98.761538,-238.112232,-378.59995,-308.7721,-35.443993,57.080616,114.402003,84.136604,37.329408,-76.640589,-84.730962,63.313482,161.186382,287.878396,321.495474,283.430343,76.058057,-43.273518,-171.220319,-122.050913,153.036337,275.415615,346.79835,215.324264,118.133719,-10.463465,0.987457,179.710324,291.216547,442.207268,467.589008,403.759871,259.498793,188.754819,125.844238,177.992853,382.782426,455.325012,458.822861,338.107193,253.948799,42.438111,-34.333249,-8.217059,44.754223,103.293667,114.122103,61.305439,-60.083991,-106.769442,-169.052818,-188.076104,-189.881866,-154.96452,-26.784789,23.788943,-20.467246,-202.790146,-270.657407,-212.655974,-114.451223,64.921791,121.999334,131.676549,4.085138,-66.020811,-93.097344,-35.068858,133.55017,214.906179,311.794382,225.830705,143.942154,14.592606,0.144334,81.442649,128.752541,183.27528,201.60375,149.431811,21.141637,-14.876892,-15.523071,30.763379,189.627862,247.983075,291.095421,291.044765,257.777877,151.271977,133.389631,229.073867,306.657784,448.28513,504.478594,506.810475,316.416519,200.665677,77.527142,91.26218,199.692447,247.070444,216.992469,30.161033,-52.416274,-132.394969,-148.731153,-102.622896,-19.038911,175.518589,224.99428,197.063299,104.816853,53.226367,-4.653642,25.610914,173.581986,246.061538,318.77887,226.042149,116.881549,-112.120293,-169.493174,-113.145158,-53.242314,8.146649,3.227015,-113.435291,-306.560434,-359.345675,-324.498295,-260.191496,-129.325296,-84.048151,-14.593143,31.030306,28.7606,-24.077261,-41.070399,1.058587,57.057375,250.717859,358.588939,410.880589,262.721324,185.290609,76.775706,76.896601,239.036866,343.764613,435.912986,395.256542,337.639924,156.443924,76.502358,64.203894,137.98841,340.01355,404.701774,340.047615,112.119261,13.661423,-60.150829,-13.17952,174.603226,263.931375,367.901552,275.069064,146.360664,-101.737104,-129.250335,31.450736,139.995554,258.806612,260.203016,132.382711,-83.779884,-140.036153,-99.707618,-57.983602,32.037545,120.724862,290.366146,254.093644,181.803497,36.657281,-1.253015,75.211898,171.101936,284.425476,245.72515,45.026555,-106.869297,-146.960034,-172.228557,-142.696903,-17.262703,50.270748,113.422804,63.07654,32.368839,-19.846144,-29.164844,58.422949,145.525829,320.004816,375.668862,342.828817,125.678396,0.547079,-136.256748,-129.985653,-70.66253,-35.521655,42.055924,28.587759,-3.520045,-108.067023,-178.376208,-241.418544,-214.395556,-75.958426,16.867307,109.188594,-46.041962,-172.417987,-331.404703,-310.829081,-124.137312,-30.810845,34.839982,-56.52996,-138.645715,-309.280459,-362.131399,-316.328197,-236.933724,-84.306948,-24.34126,8.812954,-58.570835,-84.343059,-127.401621,-128.060658,-10.727914,88.299119,187.85112,11.310997,-111.288109,-261.492893,-282.345324,-201.197128,-125.644708,-25.332579,-15.575596,-47.209139,-83.818662,-102.206454,-122.840932,-115.524503,-96.361674,-87.073921,-70.672855,-124.91686,-185.466351,-346.945868,-413.200363,-387.23625,-289.996717,-54.986418,8.499464,-60.328106,-224.629888,-282.288021,-359.607403,-374.189912,-295.772289,-209.237983,-79.656494,-187.431892,-310.078522,-494.961962,-490.018245,-261.130064,-101.099476,120.181034,160.959664,90.581621,-123.208217,-191.132996,-125.604862,-17.814563,195.519794,278.056349,399.403789,316.610718,187.417939,-26.884014,-31.299243,147.540758,242.698857,262.191983,195.037763:-127.344002,-1.915735,31.384951,-67.512737,-119.715048,-57.145151,9.323208,74.922102,74.531433,56.328992,-18.659247,-64.63182,-106.034799,-86.545204,-47.197568,-46.161709,-36.507697,-27.753031,-47.207623,-96.587927,-95.105275,-85.756407,-105.373366,-100.099244,-20.785883,-24.135104,-143.252665,-219.722537,-296.926079,-282.046336,-220.789214,-199.256513,-175.834883,-162.532537,-138.471752,-56.005178,-25.175302,-65.704363,-116.961522,-95.808619,80.558578,128.655135,75.838124,23.461226,-54.628717,-108.270174,-220.469806,-202.222128,-56.481368,-77.406648,-120.499565,-103.497223,-66.140498,-0.039105,31.015539,77.008514,37.088778,-13.700043,-78.364731,-77.528763,-62.135589,-58.691528,-21.069968,25.118531,99.250978,26.488094,-48.691321,-158.595538,-152.796717,-75.552452,-62.018417,-105.167206,-204.377473,-245.595689,-241.680393,-207.119896,-100.611858,-36.944266,50.141376,70.763051,125.95453,145.276766,109.479398,11.863991,7.55308,124.721348,189.287547,231.844229,189.103821,158.220654,125.260669,109.996449,58.549056,42.003301,70.488967,115.397924,159.918286,10.408232,-99.32209,-267.097128,-276.43999,-109.453535,0.456062,139.020163,111.064506,39.412635,-71.560305,-72.176927,-5.326562,21.150968,31.870448,38.781195,73.014544,106.405796,114.614231,75.177869,48.790506,46.697042,60.061256,90.987585,67.522726,23.943401,-53.806059,-65.557807,-26.316493,17.84095,96.684174,118.664194,135.998039,141.933806,146.028442,142.105539,148.35265,195.222573,217.402437,222.418296,174.615014,160.822352,167.328835,181.73077,275.418607,330.087403,357.771287,348.528354,340.069447,348.15601,354.443952,310.599267,264.843918,224.464143,234.337764,220.437765,86.127555,18.089076,-28.213654,-16.6625,29.109982,45.135467,44.418828,43.849498,46.766237,59.095185,68.071638,9.187179,-40.0152,-61.984774,-27.143578,67.135803,61.435377,45.255179,40.071906,28.655982,50.293006,102.369207,198.756348,220.823988,219.237927,202.902223,203.807577,232.685599,277.698379,391.48683,429.4536,526.122668,643.897584,648.539135,519.865176,420.349373,274.889039,272.358474,398.346451,451.33795,384.115679,271.585573,257.628638,184.424405,122.797977,91.360886,108.830511,85.473714,10.379241,-30.917186,-113.965789,-126.96466,-84.633991,-59.238456,-22.344274,9.061402,114.798899,133.253888,89.508208,7.014415,12.264974,104.406103,153.046346,224.59769,204.388738,147.411531,0.71186,-68.059343,-152.85212,-170.961852,-213.117367,-227.988818,-193.834847,-153.308562,-178.35021,-277.859227,-299.421035,-261.452276,-236.611132,-196.730586,-142.009433,-135.748716,-204.429165,-261.222898,-347.884975,-342.876338,-196.606769,-85.27988,53.720357,-22.632986,-95.337281,-165.500043,-144.370412,-40.291208,23.646668,117.010141,56.161413,2.026617,7.097136,74.571228,224.278552,256.833266,268.047251,280.259967,271.945495,221.744011,204.648211,88.400285,-12.683255,-116.255374,-71.732786,98.733233,86.558732,-2.990427,-156.509527,-176.331564,-120.46947,-62.697438,3.658087,-33.036315,-180.036443,-242.397285,-242.215819,-219.919342,-196.989413,-179.607468,-186.137206,-171.243932,-144.257994,-137.59323,-154.209543,-182.573754,-235.686293,-247.265418,-214.200664,-166.925096,-110.340134,-157.85079,-182.845517,-167.009637,-122.457048,-52.336674,-65.359416,-109.309558,-41.745269,13.801843,58.986227,36.557779,21.767211,50.936591,80.252547,87.615441,111.972404,51.336561,15.715662,-44.002899,-79.565498,-145.454438,-163.660476,-104.205853,62.863594,105.795459,18.798119,-61.608444,-133.89567,-94.72065,101.373818,197.665065,235.100233,117.661704,76.61705,58.964423,57.005676,42.94648,34.733766,-9.327289,-147.630937,-225.538312,-310.263304,-302.493763,-204.000903,-158.443573,-104.667263,-72.888246,-58.485013,-150.449602,-190.135769,-215.320918,-207.123302,-190.366729,-184.103971,-84.602043,-17.9923,-87.845172,-271.89081,-276.452329,-124.491012,-73.76682,-93.405814,-93.285672,-42.434452,-47.931386,-73.045692,-137.091728,-141.222416,-32.543469,23.625054,-21.282604,-140.280371,-145.286482,-109.971472,-106.146144,-52.726801,7.877726,80.576877,78.008978,44.899122,-24.787404,-71.024615,-159.397023,-182.73334,-141.951821,-100.341326,-64.92009,-65.946596,-50.415746,-43.03997,-73.146729,-82.553868,-37.432235,77.786051,135.629151,178.190907,97.211256,59.976488,29.844763,39.644028,96.259815,132.266958,221.751697,248.311751,199.553264,77.041695,69.618587,181.152729,238.056874,229.100712,183.266351:-133.920296,-102.739577,-87.044456,-78.34398,-56.114763,3.668125,-2.565154,-29.291119,55.329514,117.653501,173.721926,155.305853,92.903795,60.369673,-30.78814,-72.901985,-79.33606,-21.583333,-9.747522,-53.805073,-88.90875,-144.714262,-166.46785,-146.385034,-88.814765,-91.189614,-163.482326,-217.689575,-287.238528,-281.991208,-199.976129,-143.453233,-73.098817,-62.125137,-50.343486,-14.377821,-5.365373,-40.762916,-80.184234,-76.74517,63.373851,107.606019,96.175754,73.376052,8.192286,-45.598359,-105.786556,-65.613695,60.886071,77.298606,59.671765,28.180757,33.02484,115.599795,151.231197,119.312465,24.257367,-23.302402,-97.329004,-99.156943,-30.856116,-4.124857,-10.844246,-8.932707,24.954149,3.924166,-39.083952,-142.028646,-182.214079,-235.724733,-244.978188,-237.284261,-274.969455,-290.922451,-235.318713,-179.853864,-83.592934,-39.014508,77.370506,143.457887,206.790867,160.354907,141.883494,159.694983,189.06932,256.578414,277.558483,256.566249,181.415003,165.681885,210.042728,229.137495,201.718696,171.855346,146.940928,158.059576,129.739641,30.534338,-4.421341,-86.27521,-122.895021,-86.735941,-11.582297,179.33095,241.41738,195.241121,58.549879,27.860533,105.404105,153.250105,106.378244,68.896829,123.327587,154.306294,114.437877,52.431937,53.208146,70.127454,93.596726,188.953992,173.490452,106.658361,-14.496609,-42.779633,-35.156133,-13.532676,24.271354,43.993783,74.94465,22.93748,-17.787297,-45.800755,-8.753822,148.044895,204.646341,156.108831,56.201238,85.700862,230.069304,250.086698,179.780455,161.373272,207.456418,238.937363,263.832708,263.437632,258.046752,180.409053,115.027405,44.251207,67.160863,196.296481,237.522489,175.065088,-6.420869,-65.65944,-91.177429,-103.612712,-162.27582,-164.92999,-95.359035,10.660559,51.021313,14.465218,-58.081766,-159.898172,-135.161842,47.094749,159.76249,149.078564,120.476792,118.11754,85.706283,54.061324,31.028654,82.398613,255.444575,332.704857,318.552053,253.767049,254.797912,332.591183,370.242118,420.872883,446.148797,433.511601,367.070579,315.735582,231.885822,241.768912,332.636381,351.026802,272.808917,193.275935,176.213269,106.046782,51.135905,-12.202008,-8.194539,-23.320059,-109.896912,-123.872697,-89.907373,-92.43744,-147.172318,-154.449514,-92.26314,-33.938927,114.669153,162.261755,118.706499,28.01792,33.684475,115.279342,138.791198,141.382494,188.857399,206.383734,139.616602,62.579987,-92.065552,-144.247325,-198.533825,-208.559987,-205.048147,-183.952671,-184.541216,-244.971959,-293.995448,-359.347249,-357.015149,-275.740721,-222.693785,-234.328066,-256.962566,-268.129606,-299.100529,-277.817729,-130.916852,-41.276236,70.364316,47.976208,20.60455,8.736873,41.077281,141.189339,173.980759,186.096256,120.286079,87.557098,107.888801,148.742342,249.708201,299.1685,361.371487,382.585177,468.776205,539.631604,502.106631,275.263341,165.894364,124.084181,170.260874,241.803945,182.338394,119.051265,-4.274645,-36.537533,15.819152,83.677143,188.948931,192.792153,75.936412,-70.766183,-109.563532,-161.636216,-184.462338,-168.385817,-131.915471,-95.871854,-93.081282,-89.406585,-149.737943,-218.672359,-294.531158,-276.753946,-248.754741,-246.385909,-207.882544,-200.235695,-237.612056,-344.306462,-360.992115,-278.789891,-213.155308,-106.312451,-106.894357,-128.223849,-131.128695,-127.367361,-126.619437,-118.828085,-53.133087,27.510568,180.541676,157.130876,108.856544,17.000759,-11.533311,-40.142632,-63.980941,-110.339444,-91.855238,-55.903554,4.719593,-8.49435,-64.695516,-56.764278,7.048617,33.152648,71.852554,67.188946,27.629021,-74.60779,-93.428723,-50.188074,-20.444215,-49.704815,-208.675879,-281.01237,-328.044518,-328.599662,-335.026631,-327.073117,-218.153436,-115.17788,11.84983,-75.837565,-130.17664,-220.258366,-271.480526,-309.440362,-279.379262,-186.900056,-140.748281,-136.20858,-139.12753,-146.009661,-132.070939,-105.782874,-66.637461,-68.694808,-103.773471,-137.170333,-142.217182,-134.514902,-119.723989,-73.961393,-61.378887,-89.857688,-123.407289,-96.82931,-27.566007,-31.28162,-45.009644,-28.23123,5.223215,16.828828,30.090165,-26.799576,-96.986353,-244.335969,-270.646751,-236.394381,-193.76481,-53.928361,-19.895307,-68.431787,-131.512514,-135.136315,-137.24096,-119.604599,0.280543,71.385192,96.594846,-29.154972,-104.876504,-176.619228,-140.533555,-16.341971,24.381184,79.473079,114.298031,132.525661,182.528629,205.553565,249.205744,247.075074,140.902015,87.615691:-271.096086,-203.83822,-168.425468,-182.103697,-194.667913,-106.773154,-24.078368,90.738414,98.380393,65.378063,-32.944155,-79.578873,-113.223348,-87.107833,-60.533374,-97.053694,-177.696372,-186.096392,-191.342353,-195.238631,-166.332299,-72.304564,-34.848741,5.079795,-61.087888,-143.438639,-290.750178,-327.161478,-329.863695,-311.219309,-255.773157,-212.535609,-170.771304,-263.959122,-292.425591,-217.112226,-159.785501,-102.342685,-91.328685,-74.098504,-13.798278,45.603671,84.790341,21.651856,-122.72293,-141.314393,-102.463064,-78.709357,-130.64791,-257.629464,-281.156513,-248.565986,-206.682309,-92.773562,-43.297294,-2.136193,-44.452149,-80.796151,-153.795141,-199.526508,-224.687528,-177.778981,-70.156977,-36.444258,-10.976088,-128.848195,-238.556421,-382.48411,-350.17145,-139.23835,-50.860889,-23.328754,-161.251909,-227.615277,-216.905807,-170.137087,-109.440772,-98.84956,-92.663679,-82.081842,-36.15867,-18.708352,-33.79348,-69.195371,-66.485454,-4.926831,44.868848,144.787706,112.117828,44.991699,-32.035785,-24.80325,18.159244,21.994642,-10.537848,1.080935,40.769624,-82.650163,-157.774223,-210.640772,-195.163993,-100.417531,-24.935095,102.274167,32.892922,-52.709651,-153.438673,-138.700443,24.80475,122.195006,204.316309,200.914566,157.056817,87.501442,56.151024,-3.545799,-6.818236,79.385329,134.789353,223.584356,205.656684,125.894295,-19.276214,-13.033872,143.98406,231.588305,316.710543,345.707499,430.909608,370.80973,280.853811,154.073868,156.995554,279.729873,356.791335,418.575509,313.738785,227.518909,99.839175,93.652481,225.216076,318.340899,382.572272,343.116406,216.832697,164.53018,176.77588,193.841072,169.71273,62.514367,27.982827,81.552431,74.275735,9.288782,-74.784151,-67.80147,3.509983,42.202568,95.08111,115.684285,114.657997,14.45048,-42.369453,-88.33429,-77.827169,-55.636195,-42.989217,34.766745,66.30762,48.318021,55.489755,85.066245,156.672097,181.579175,197.716776,200.125851,166.193063,129.063619,149.64181,227.580549,269.048879,340.129212,359.052378,416.450242,475.482244,457.497727,356.007874,309.869312,301.619548,361.680219,526.573845,562.283754,490.13362,344.341474,290.997395,233.77247,225.140819,228.880852,219.249327,151.731877,27.590985,-32.065407,-64.597907,-38.1364,65.517051,115.661549,133.03268,122.662036,148.782461,156.218305,138.420835,140.121199,183.016719,290.873794,327.06729,350.070582,264.05792,189.901733,4.759916,-84.287572,-138.116029,-114.671782,-102.820904,-115.513455,-148.168173,-253.901064,-292.193174,-219.802232,-164.41404,-149.866487,-146.780344,-79.313988,-79.757788,-103.919679,-150.015981,-169.959281,-98.847778,-5.466013,138.796293,167.869269,161.717459,85.595222,46.742431,3.729053,20.713957,130.271859,183.222192,238.269956,213.573709,174.730016,95.524392,68.420249,113.675436,182.049907,269.504606,264.687455,206.871331,136.201669,91.152856,-31.808117,-77.232527,-62.765908,-0.442689,156.134548,107.646746,0.719222,-140.85415,-129.68343,-53.953628,-34.505066,9.375611,26.307504,-89.505459,-241.421336,-226.876343,-134.774949,-132.328571,-162.579327,-131.763989,-3.128967,38.243482,16.004384,-78.111895,-126.129572,-113.819753,-46.979093,56.653065,42.737611,-37.967928,-89.407332,-134.300584,-238.717508,-233.597242,-96.266022,-33.862152,9.741105,18.125216,30.796542,44.63223,40.681419,91.458581,138.428156,205.935555,231.846496,216.710773,37.763657,-54.729089,-128.982778,-121.562125,-112.766191,-112.046313,-49.339512,-42.730075,-90.320256,-199.091053,-252.046395,-233.782658,-118.438192,105.347003,118.84946,35.887667,-36.288167,-85.75296,-191.14608,-199.703423,-103.801534,-53.922612,-73.563671,-221.011815,-290.381304,-363.274226,-379.639564,-355.181933,-313.455209,-222.918515,-195.409142,-195.583476,-192.196395,-184.400766,-226.151638,-244.727991,-179.684445,-114.355638,-18.275861,-82.908438,-148.1511,-218.371353,-237.597934,-266.275914,-231.473471,-96.312036,-56.467744,-26.509302,-24.173481,-44.438473,-88.764982,-103.246089,-105.719507,-74.612812,-23.534464,-166.746581,-267.141289,-329.663831,-287.00803,-182.339751,-160.154705,-160.570471,-130.6378,-10.310788,-38.934062,-104.278143,-187.682519,-208.324022,-217.184661,-167.376244,-11.291192,-56.848429,-134.649809,-168.283062,-135.288728,-93.344725,-72.99316,26.164709,97.893505,184.911324,123.71985,82.048476,81.869424,114.545479,157.98899,184.302064,313.711614,322.701687,222.755162,28.509107,14.313417,125.747272,198.162623,255.702451,226.684449:right
251.167257,292.457066,327.921651,412.589112,431.383891,378.926402,320.245827,183.124792,103.198095,95.311965,156.514001,217.578865,285.210506,265.989307,164.000328,112.801511,87.345679,119.458629,122.828034,122.948983,120.31507,77.989954,22.874214,-131.574686,-236.946808,-248.432609,-143.217303,-43.819506,48.930812,3.089791,-148.712036,-201.6037,-237.317932,-201.372587,-169.54632,-62.002711,17.471053,140.405619,144.295636,67.699772,66.451838,97.578935,116.275695,107.159172,91.240313,92.084527,99.400891,76.771113,-36.425782,-125.778392,-116.923663,-32.062677,-6.963237,-1.835967,-6.673651,-68.931691,-59.264137,25.396129,173.585311,170.871544,45.60803,-33.821705,-132.324705,-140.919913,-102.28595,-60.588213,-47.961021,7.635315,47.913978,91.666545,69.957736,-59.356693,-138.267459,-113.403496,9.241993,71.040763,131.588694,110.791091,-0.962987,-41.376755,-25.39632,4.966522,-10.539322,-84.975453,-130.388146,-173.407835,-162.199203,-118.833875,-53.784675,-4.104779,112.230899,147.814913,155.869709,158.88492,137.752344,93.481576,43.161148,112.131508,173.627859,310.920352,331.272034,242.995244,194.082182,150.385043,141.374845,133.68286,73.003056,27.45117,-35.367942,-42.737984,-68.350567,-102.402651,-126.290756,-38.674059,18.44131,95.788664,97.75067,16.979264,-56.512797,-197.313531,-208.831346,-151.698003,19.18708,64.686431,-20.330612,-93.389149,-141.326572,-141.783909,-159.792146,-108.982918,-65.88546,-17.281244,-9.252556,-22.067525,-64.698773,-210.94493,-244.884139,-200.65192,-120.023268,-97.768471,-50.223313,-23.164284,3.779619,-2.473366,-11.436297,2.015439,10.578609,42.878543,59.052755,92.973294,115.426525,130.698262,105.790294,103.916531,131.075292,140.41728,138.356988,143.125691,192.61328,222.092183,241.975692,288.742609,335.772712,378.076364,359.589372,296.564991,251.367857,120.239575,71.644248,104.665372,177.821617,198.982824,244.013277,271.128754,321.667453,325.133031,259.48039,172.45679,150.868515,150.410119,126.296385,11.121798,-8.604207,69.222979,62.525514,4.09407,-28.041034,23.103668,119.022564,133.130364,149.792662,169.477901,179.779871,91.736844,42.459868,-53.806048,-127.242264,-233.455983,-230.33729,-212.368067,-190.212321,-138.112291,-1.037283,53.308281,107.701075,114.298773,83.61399,43.801385,22.374153,73.816691,79.209809,73.177835,58.955539,-35.279086,-107.176691,-205.311064,-146.057832,-97.492554,-78.10294,-101.748081,-108.987774,-56.573633,78.019472,103.86058,116.893029,164.563293,174.236669,162.394003,151.359401,90.419228,34.695405,-68.53263,-67.592526,-75.609282,-208.352348,-295.195932,-422.191886,-444.632959,-389.518386,-335.084321,-234.30778,-182.064169,-133.530357,48.059283,102.493278,47.721062,6.444251,-5.222482,-2.579631,-6.749982,29.798944,95.54938,252.260052,290.563178,255.671307,207.738023,177.775333,310.848886,381.047646,369.300019,276.533931,47.160011,-10.460541,9.655168,-10.760125,-60.899928,-56.218207,23.344658,137.008212,104.382873,-75.839386,-167.21979,-256.890401,-220.0032,-192.716598,-116.981015,-67.832226,1.747446,22.390108,17.781495,-17.61405,10.184898,185.545686,291.456273,367.578063,298.414171,64.872685,-16.72929,-76.530757,-112.37322,-113.276306,-80.594987,-84.920025,-114.916625,-115.415804,-138.473878,-131.570531,-64.729695,65.848638,84.88001,95.137556,101.519549,24.876306,-85.963918,-307.841198,-297.885524,-232.291477,-157.357367,-170.758415,-280.717966,-365.319812,-500.350316,-463.051327,-404.258148,-323.123927,-316.238094,-331.367152,-314.295129,-183.449348,-101.101747,-3.428142,1.683807,13.31817,74.008189,70.637674,-48.801461,-110.872561,-180.976385,-212.910517,-207.967643,-170.758602,-160.859162,-156.937276,-137.200571,-119.326867,-166.412437,-257.65606,-172.53153,-120.898597,-104.431899,-128.730809,-232.48614,-306.000156,-438.712475,-462.257864,-430.674505,-338.432874,-297.906349,-308.651514,-347.49166,-335.992876,-291.662171,-228.688468,-149.620568,-92.13389,11.035859,39.390256,43.695174,20.90793,-50.877654,-37.574414,15.438004,129.754193,160.752952,87.914758,-7.078312,-176.740256,-236.470748,-309.159068,-250.781376,-195.968623,-129.178315,-114.57348,-105.353132,-123.277291,-188.351951,-161.670609,-116.326773,-47.839982,-13.358693,73.266464,98.526169,54.337896,-3.823893,-86.959659,-77.005593,-51.046903,10.530477,13.702905,-97.051921,-194.614821,-368.99312,-386.486204,-339.130629,-226.325647,-209.57041,-293.270851,-335.355228,-293.610924,-255.017749:165.055494,224.829353,231.756178,254.424301,279.111033,247.078379,184.674033,120.604544,162.149195,153.187557,115.904187,129.163102,165.210138,159.340251,95.471625,50.189577,27.811887,128.580421,161.742074,84.106065,5.618991,-94.159613,-116.426553,-173.665518,-241.979346,-244.600189,-136.236947,-78.637618,-72.190381,-84.495034,-107.178259,-147.330322,-232.63236,-226.960501,-203.662281,-132.702691,-89.930114,-32.666605,-26.926099,-34.517955,8.043272,49.365505,121.575691,123.323718,17.080611,-51.619227,-111.730489,-109.101993,-107.259017,-93.237964,-41.180163,38.471084,2.993417,-114.000766,-132.285039,-120.628722,-105.403848,-70.476113,31.664597,72.533275,101.376484,70.370263,-67.377732,-113.490009,-58.836031,55.433378,99.557117,172.597726,181.526606,124.261856,61.32785,-92.572588,-97.679187,-23.097913,116.030183,131.186727,58.730762,2.711112,-38.593853,0.284736,108.9763,83.258128,37.464222,-34.693353,-76.151244,-151.572265,-152.499269,-115.87227,-58.136583,7.481335,163.869265,175.582943,50.277508,6.731191,-0.005842,-15.495879,-20.660432,91.313012,163.4097,271.474431,280.005942,197.333503,124.605009,-23.064326,-3.14475,91.596859,265.195803,264.692771,105.722587,18.177416,-95.838495,-125.681821,-95.890724,-9.523045,5.221254,14.845775,21.724923,-52.11003,-140.018466,-269.074804,-180.636878,-97.963037,-12.211505,-23.15232,-131.850273,-191.472363,-222.262847,-201.349773,-171.179734,-147.11215,-108.187851,-60.69437,-82.883016,-169.081318,-229.132156,-316.770361,-207.80428,-144.709666,-159.317461,-188.388348,-146.182943,-93.982842,-59.512227,-86.320228,-100.33151,32.582261,98.840612,95.001729,31.772036,-84.613901,-100.590076,-75.201321,-22.190039,7.302833,48.631014,55.555985,66.707771,93.621157,179.791946,219.775449,273.653201,269.377456,264.410834,274.254013,275.177409,259.803943,240.439911,159.482895,88.562319,99.518195,224.69784,293.887725,304.164953,252.605654,156.653553,126.241544,101.677086,134.664599,167.32448,204.624957,183.310458,86.02999,49.586062,71.909413,127.148902,112.297206,5.973698,-36.924079,-19.697304,9.576753,-2.346209,-26.819029,-62.962919,-147.913187,-194.15616,-262.791398,-308.14797,-406.383106,-425.638144,-362.456295,-250.830116,-211.304288,-131.72607,-102.55267,-106.71615,-120.067747,-156.400811,-179.051862,-156.992499,-58.525741,-23.422921,-14.763906,-54.800379,-190.939787,-246.550064,-297.330151,-273.747821,-229.37598,-127.89068,-117.317615,-180.918567,-189.904849,-88.027838,-26.573258,3.611981,-22.077379,-3.491006,46.461128,34.63875,-78.708708,-150.125411,-214.063144,-190.930415,-209.98064,-324.106238,-373.099825,-420.983829,-418.277413,-371.104568,-357.298699,-275.921411,-51.454873,36.928397,97.092811,99.989952,120.324026,137.758872,140.700225,101.824871,87.389519,116.428464,156.494154,185.691093,159.524467,94.212549,68.488322,88.961584,237.088279,288.141304,267.900205,226.569515,118.727074,51.973173,-35.28531,-6.251659,21.920326,65.148245,84.319787,110.310438,96.995328,-30.460646,-105.39476,-154.538876,-120.632068,-107.214888,-111.868451,-109.428509,-41.126662,6.041506,26.53481,-3.008075,18.025107,152.710684,244.002374,308.751373,257.873371,127.172904,85.695454,38.823622,-43.76587,-86.008467,-86.344621,-58.652786,-43.804244,-66.151506,-87.23636,-15.451321,34.568841,83.22635,80.719772,95.900224,103.974358,35.764847,-22.70302,-92.943598,-133.938368,-151.200009,-146.556956,-140.820892,-166.45274,-203.570533,-292.007265,-248.281018,-177.067473,-40.912339,-7.759573,-54.274887,-88.472821,-50.989995,-1.292644,59.30451,77.631622,96.625584,114.295269,83.389568,-22.61412,-79.313242,-187.109617,-166.074989,-105.608947,-16.366608,-21.958735,-113.816882,-141.585469,-133.677176,-152.796802,-212.336684,-131.702517,-56.552225,12.093273,-9.1027,-111.423239,-194.40395,-376.183068,-377.838335,-314.076883,-221.147383,-218.640592,-258.746879,-275.55326,-258.229648,-211.634026,-84.607429,-13.820026,19.939343,122.08225,165.686769,162.093081,97.454488,-43.409582,17.267362,106.123549,264.00662,302.709965,252.326546,174.111217,2.101798,-68.388322,-114.611797,-12.847413,42.761378,98.394801,96.127594,31.342491,-15.693183,-69.198989,-71.429281,-57.048758,61.039936,143.578148,197.365936,157.157818,64.11885,38.492324,10.797675,30.378562,67.38999,127.695081,99.308217,-53.932947,-126.454986,-221.994613,-224.692886,-199.286501,-157.22118,-159.737708,-221.019991,-232.424158,-152.463775,-120.879121:131.994578,205.077216,187.127652,122.448626,109.954295,121.873223,125.465742,114.848295,121.341654,132.098937,160.814467,162.559259,118.144614,91.76689,47.336776,40.043631,127.531575,235.12645,215.117661,50.833403,-27.636295,-96.163071,-108.198702,-157.968418,-233.356002,-246.697656,-210.082919,-187.478864,-170.57495,-188.754042,-295.303877,-358.117534,-440.399154,-414.013616,-338.860497,-157.8856,-102.669544,-71.650929,-99.20157,-221.66682,-184.072004,-83.785066,31.230427,11.956568,-57.187618,-71.936481,-69.269985,-60.841244,-58.908641,-66.220219,-44.056022,-2.302126,-5.04453,-0.68682,8.787621,-10.758911,-39.551963,-30.148067,-0.745039,7.069308,26.70159,20.429013,-71.016927,-126.647853,-138.63953,-2.898128,74.805752,140.453224,113.283597,31.151511,14.476005,-21.258941,-78.358261,-57.480825,51.062629,67.257208,0.970998,-25.252972,-26.849065,-32.116377,-26.617913,99.395499,162.239231,108.148057,-12.158933,-224.899022,-238.488839,-126.399754,-6.014027,40.937444,105.130514,103.316587,34.399597,4.378819,-17.457617,-29.761709,-61.068729,-20.863523,32.508506,110.087696,102.31988,25.489377,-13.541508,-57.657182,11.297275,89.615783,212.597285,227.229665,167.454324,115.504443,20.383784,-12.607781,-19.112299,20.418734,40.344348,78.465926,69.993601,-58.544299,-148.18621,-232.169477,-132.346676,-63.326447,-8.521732,-39.265778,-143.864607,-172.122101,-155.097804,-127.539144,-101.641171,-87.33686,-55.756728,-69.379086,-150.62855,-287.83206,-286.624319,-234.384039,-209.046421,-187.534359,-111.68852,-76.528886,-9.679739,36.671046,94.751998,78.412056,53.630932,144.01991,173.071612,100.797738,33.063016,-72.680816,-101.618221,-78.955865,23.693,70.905847,142.86473,159.721418,140.910905,124.498264,98.106297,103.508721,208.226716,289.122365,276.790403,220.567538,202.646356,216.278521,239.494643,256.071919,210.93325,196.93067,246.654413,283.058365,277.520435,249.252007,193.462022,162.64799,134.882396,176.478044,194.445907,149.748849,102.330281,59.579631,51.890177,45.348299,108.170959,124.243729,45.26102,-8.144606,-24.568131,-2.564157,11.490187,7.751491,-21.845846,-122.738954,-162.626139,-233.393603,-291.920307,-415.521713,-442.979098,-381.07944,-268.157132,-217.686354,-112.943296,-85.627626,-123.031058,-157.782575,-237.414304,-286.387695,-336.758429,-268.078838,-185.507617,-33.416455,-43.084408,-236.744557,-332.449638,-347.337133,-211.008518,-164.33447,-167.198276,-182.827081,-145.672364,-100.432258,-43.14406,-37.884632,-16.996825,35.695656,54.802238,37.078117,-1.537409,-101.228599,-147.8984,-194.246941,-193.397316,-218.555074,-300.521345,-332.439205,-378.807647,-374.397403,-281.971397,-216.096255,-36.26881,147.446689,170.162854,110.367764,98.47095,179.30164,227.646043,191.328018,56.609689,39.581488,102.181864,135.639038,143.177648,111.980898,13.153955,-11.244588,82.09979,266.104983,327.217849,326.669359,269.85209,118.889958,62.454896,74.343179,166.745314,161.267365,82.822393,64.875363,46.674012,-3.817525,-173.664695,-217.718527,-138.585434,-31.532108,-24.268197,-67.792672,-77.334878,-23.350256,12.853784,47.38007,71.18287,93.014403,178.306494,231.990733,285.608606,273.981928,155.487466,62.947314,-23.362449,75.854765,111.872274,59.126597,17.265427,10.705541,32.508209,69.308989,111.770725,148.249364,205.756126,209.375215,199.872954,194.527781,98.263437,10.661837,-97.147765,-82.38074,-51.404606,13.041265,16.499219,-17.54741,-35.504589,-83.15396,-96.439167,-64.689039,56.081325,88.850633,6.531108,-48.987898,-28.565358,26.180845,111.707631,153.702875,171.716701,136.674661,75.527212,9.262937,26.17436,51.624294,33.597883,36.286588,82.952404,84.332987,-15.413212,-79.822377,-181.242155,-206.932243,-154.113503,-46.444743,-17.435695,-5.546103,-20.467694,-100.063088,-159.335208,-273.700971,-282.041048,-241.010154,-158.525072,-138.317412,-119.328361,-118.206479,-148.116009,-167.073893,-181.83329,-160.459269,-119.905243,19.367578,77.480132,68.102728,3.74134,-71.894231,70.057669,187.352171,382.770433,390.916605,204.442083,103.08868,32.977258,27.503382,5.050525,44.081392,83.67098,95.358706,53.506678,-52.452754,-73.859596,10.392455,96.619449,70.508765,32.618793,66.479444,119.285941,109.870038,49.790029,4.727375,-61.754445,-15.915299,28.108178,75.09375,57.005369,-24.859055,-69.289881,-149.462208,-171.806913,-163.98891,-106.490818,-72.483028,-77.471312,-104.633794,-133.239752,-147.674854:270.483133,264.066311,243.83649,255.421676,284.787968,264.164814,199.02729,66.107382,28.388978,37.010886,111.087315,168.193693,236.867195,228.397451,140.026742,87.021053,73.945773,157.277284,178.544524,116.424147,38.821043,-81.933751,-105.080382,-175.080459,-275.828966,-299.950543,-271.247486,-238.008359,-198.95364,-195.103221,-227.068822,-270.90411,-362.917538,-353.858048,-303.256755,-159.420527,-89.292701,-21.994415,-45.516636,-136.216722,-89.624909,-23.769807,49.51352,40.035389,-38.716626,-77.193373,-126.985112,-157.714885,-193.73217,-127.042339,-77.068932,-19.224636,-12.664029,-10.964275,-26.299991,-84.14376,-14.798358,67.405238,169.672699,173.519685,106.947763,33.133962,-118.536415,-140.714848,-52.506403,55.621178,76.402525,82.472609,85.283137,93.857436,73.906299,-50.19486,-131.495634,-94.811341,78.527027,138.587333,58.611713,-34.426257,-116.235613,-105.230332,-52.64793,27.324656,73.534043,81.201685,-7.082867,-185.484726,-175.501602,-99.585618,-116.164639,-83.32596,109.919491,189.801217,154.444768,89.661863,20.514082,4.310995,-17.64292,19.250541,75.028087,184.942214,176.762422,98.890818,90.730159,113.103458,158.052769,190.528942,230.592606,234.136831,198.407104,163.106887,98.114968,80.30045,113.302576,207.920157,240.390464,234.917115,195.064299,71.884883,28.880563,26.3661,53.098652,68.762235,120.401293,124.355959,24.05157,-32.150684,-60.511717,-67.15852,-106.103921,-121.530956,-117.917889,-120.591672,-131.371747,-138.513551,-150.418825,-261.52788,-350.769162,-319.032027,-153.696376,-75.142916,15.299795,35.2231,5.009303,-45.907519,-74.838397,41.456936,87.08635,119.02709,117.919591,87.782977,62.540254,27.864463,96.78742,157.07234,207.867223,183.775394,130.696484,142.922779,195.999907,192.68837,170.624545,216.033276,249.047875,347.053624,392.392849,352.965302,279.772735,170.28099,120.68396,119.501218,210.773173,262.282866,272.384172,244.990701,187.987703,163.67535,97.685427,22.884188,27.466213,122.272976,139.735592,40.761953,-20.282552,-75.276108,-65.603607,-51.65268,-37.401264,-36.421192,-26.767904,-20.161867,-6.766693,-4.863913,-52.176629,-159.99812,-212.764983,-280.507282,-294.532924,-317.066981,-334.780143,-352.502434,-277.548389,-207.561106,-81.024649,-48.625219,-53.807402,-68.208898,-94.284678,-121.359152,-164.512917,-119.579003,-66.23309,27.934364,16.211139,-134.306109,-208.347392,-256.565999,-216.45289,-176.040189,-76.521259,-33.269676,31.331031,51.989994,49.411563,36.750597,53.759541,114.041721,144.345296,172.52252,137.284181,-3.335126,-62.166265,-159.757216,-247.574766,-273.273011,-293.737273,-297.280864,-333.752584,-348.037439,-281.327777,-225.557346,-151.393256,-97.718375,-56.512993,61.859068,103.911877,85.399303,44.665796,-21.719938,-30.252864,-27.77605,-24.410638,-2.372298,58.200842,72.335717,68.009183,40.520831,-2.596564,117.187847,208.073253,279.864916,230.457765,74.288851,29.218095,35.739827,109.133372,120.444545,105.339888,129.601407,169.694242,123.330549,-89.234455,-205.124899,-329.147874,-296.439611,-248.94264,-147.322064,-118.560414,-103.154051,-88.878383,-41.830683,-26.650907,-11.35525,81.851104,142.416151,196.885173,173.260625,81.166331,30.48053,-81.10763,-149.910111,-149.621349,-110.633317,-79.283358,-0.439599,17.248427,-36.537637,-36.620084,16.174192,104.270227,110.814034,114.517743,132.24139,74.885283,-26.416994,-183.192216,-135.056555,-79.267285,-10.44782,-27.789156,-155.417252,-230.972996,-341.430167,-312.724317,-241.595542,-130.163245,-138.840546,-207.355692,-211.563959,-151.115852,-118.239455,-71.829438,-28.545019,13.291007,147.17305,192.348883,133.093694,51.941584,-45.177374,3.926408,31.009718,64.547109,74.473843,-26.801578,-118.855547,-170.465483,-136.329722,-76.202598,-23.675931,4.10626,25.68362,-1.071134,-145.609436,-240.336836,-363.507374,-306.023058,-252.718278,-223.993727,-234.908021,-264.730014,-296.126671,-338.0671,-317.143545,-228.060682,-115.510655,-40.201743,84.763299,85.617247,8.823062,-13.734973,-22.920331,-6.521378,31.060364,193.519757,270.877649,224.942005,116.460537,-61.845045,-107.933369,-156.107663,-137.808319,-96.816381,20.89682,56.896891,33.265394,6.406267,13.461779,55.501128,70.763202,102.987259,111.838291,113.587306,112.699647,63.327568,-4.449611,-104.922353,-10.586585,35.892227,19.4632,-21.334828,-132.839025,-196.456935,-282.987091,-251.983859,-220.168041,-183.664787,-184.5957,-223.944855,-236.757875,-216.367778,-212.6921:145.969512,258.635711,313.174204,371.356899,354.509929,229.177732,147.330693,15.062593,22.602024,84.609206,203.333565,209.076456,138.008793,100.466124,14.495482,-20.841534,20.075083,138.207017,176.551671,150.842655,94.814617,-19.228026,-72.127534,-164.144949,-198.218994,-200.394712,-154.801592,-122.122081,-154.918036,-230.716409,-386.258826,-421.658862,-432.661019,-438.644029,-409.109715,-263.54545,-190.85413,-129.899766,-138.553926,-172.810443,-166.329944,-135.188507,-17.167009,30.220614,-10.891346,-77.382358,-147.374194,-126.698327,-79.921894,-64.284211,-11.698316,81.068296,65.276343,-33.767446,-86.702466,-182.351144,-176.719009,-93.425809,132.861222,178.311723,66.651477,-23.521443,-119.335679,-116.819275,-47.167645,83.948607,144.466002,156.03169,119.455385,35.441036,-23.46625,-146.46638,-127.627586,-70.620773,33.028924,56.569649,-9.966115,-100.13429,-254.153395,-254.918913,-94.9138,96.063958,143.37279,103.832605,25.524118,-144.177388,-190.784677,-167.322266,-42.098107,33.266484,180.221012,212.426773,128.169425,70.55268,52.228181,70.504135,93.160786,83.580862,110.794841,239.972328,252.24542,90.572526,-5.410481,-50.213244,81.033768,152.479323,228.604251,239.598089,230.822101,205.712664,117.158542,80.850855,94.483938,195.715126,250.344142,297.173799,251.236883,51.735953,-21.647363,-16.035484,38.238501,45.567301,43.787916,13.692839,-117.271924,-163.251785,-169.520557,-169.10096,-176.273467,-116.922278,-75.082264,-78.681369,-139.714236,-268.813846,-300.365755,-322.326344,-297.60934,-254.293484,-103.115987,-35.730382,24.828993,53.885863,91.821041,64.986729,29.912832,122.901035,160.729166,140.546668,107.50727,70.848805,47.343531,-36.057631,-0.467938,65.914031,172.038866,185.83703,141.88544,109.765847,35.220599,2.419488,49.962654,170.230998,189.580074,173.17848,169.626522,178.188993,166.315492,106.414026,104.02366,136.602184,225.861059,254.342549,207.712926,133.088098,-47.778702,-100.925754,-78.972055,-30.831393,-16.69993,-6.966818,-33.717694,-119.477514,-146.870259,-107.333297,41.158557,78.600015,15.339624,-38.446602,-83.447428,-73.687938,-68.335868,-77.869083,-46.672417,-11.429573,-29.520389,-118.032209,-171.729323,-260.953633,-295.195138,-288.219003,-123.303675,-43.116136,3.113692,-9.191238,-62.139781,-92.969149,-148.397837,-183.854581,-198.420306,-33.572702,72.259513,120.927109,20.333858,-268.14567,-354.717985,-345.332157,-187.405071,-119.505647,-48.462441,-19.782599,17.811359,5.810615,-68.753395,-83.492143,8.811834,155.271768,207.119269,216.919432,162.447134,-15.929664,-101.440624,-185.270115,-194.216428,-218.992276,-277.577108,-284.515293,-305.269061,-333.611719,-299.683796,-204.890448,9.698806,105.46923,126.711023,161.935606,175.40371,186.761156,149.669923,-38.966631,-116.095902,-45.567805,114.135671,120.64312,23.604052,-20.167505,-54.789203,-54.650663,40.439092,265.679851,360.755579,355.267482,254.43855,91.17043,91.068907,139.724009,119.567135,91.762443,78.779121,105.491589,96.049428,7.907789,-251.389086,-323.728042,-232.183107,-90.749622,-73.475634,-49.583975,-38.114048,-84.751155,-133.226932,-132.173565,69.875045,167.692603,222.018304,217.030402,227.888817,211.453752,80.980038,0.518165,-78.4687,-48.969239,-24.257183,18.580079,30.816944,2.237899,-35.092496,-48.050801,124.378143,238.140601,381.295905,387.956873,318.855848,278.97531,167.195833,89.147674,16.880836,112.236257,168.677739,180.140692,126.104871,-11.25683,-57.429435,-98.660198,-101.839483,-81.173661,-7.233041,15.004021,12.358149,-6.590145,-94.865966,-128.956298,-31.465544,143.501219,175.964267,199.057024,226.875906,246.513047,195.01354,46.603057,22.785621,50.568321,136.599479,180.800433,158.058318,83.314568,-62.83877,-92.256753,-45.127124,23.269402,43.799238,68.900806,40.597735,-103.556347,-190.627636,-339.556507,-305.934988,-240.622499,-160.886732,-142.434153,-150.573162,-200.914452,-347.026978,-373.114778,-260.725227,-125.794146,-79.842846,28.445757,68.756198,30.202137,-34.25068,-99.874123,-13.170686,65.508009,284.378853,344.875625,189.256718,54.381213,-73.816533,-77.02385,-52.455079,28.016137,81.353972,112.3218,61.168034,-71.497997,-94.865116,-56.604729,-5.163229,14.965838,84.317735,122.663167,131.538587,117.344842,92.081964,51.668611,-65.180846,-37.175202,48.217218,174.931575,142.566873,-69.341726,-179.303897,-291.657778,-213.612209,-145.6889,-76.03999,-86.164448,-164.675355,-197.480401,-211.589204,-212.494814:175.30003,207.349404,265.121438,328.146651,291.442832,167.51494,136.320675,115.035083,69.758047,36.725075,34.241816,80.439299,168.823633,169.900594,96.322883,67.104591,103.308668,144.962218,124.198893,67.749602,57.235044,52.081948,31.558385,-88.742032,-220.430054,-251.338953,-227.535338,-190.62007,-134.333913,-114.934872,-116.358589,-156.574733,-252.177163,-279.74347,-275.636085,-167.262492,-52.375306,133.338476,157.703077,122.216069,126.08451,154.45357,204.349039,197.538825,76.994206,0.802522,-69.189528,-73.702277,-99.801379,-135.301286,-104.692578,25.928562,54.092959,1.185374,-57.674017,-188.479849,-92.291241,56.016658,231.264152,195.859269,16.044214,-75.717776,-205.280406,-217.764892,-127.258514,-65.110524,-70.687267,-54.764426,-40.674023,-45.065107,-64.021174,-147.822211,-175.476216,-133.691685,-23.629727,12.289829,7.748984,-41.094023,-165.888081,-201.350785,-183.694494,-117.380509,-103.616085,-141.869035,-173.172374,-174.274662,-158.891374,-190.950426,-204.750379,-161.472808,-37.688889,13.000292,91.860782,118.954637,104.828108,72.699668,36.735979,73.037923,115.926286,213.405656,215.769268,132.122977,120.926003,203.966801,274.379841,250.034166,115.962551,70.407718,9.128823,-37.095867,-65.723741,-37.517794,-4.969883,37.014735,114.942863,282.328216,275.23245,84.802028,15.088664,20.644815,23.507177,19.649707,82.749744,146.091476,211.749811,172.423074,12.36354,-60.530084,-138.526291,-151.544351,-132.308896,-52.547917,-41.921096,-114.832869,-156.969667,-247.115143,-310.089384,-298.638472,-209.388816,-146.544728,-35.864944,-0.927479,15.704928,-8.114987,-41.940675,-3.490515,11.787494,86.049883,152.72264,202.295851,159.667701,83.188731,188.998694,246.208733,180.551003,109.998898,88.141872,128.838888,183.571997,167.07403,114.096434,164.775169,223.477063,346.772048,370.735147,279.408168,192.537157,51.203917,27.76678,40.99208,53.178559,67.408178,159.884032,206.975719,178.549422,122.679032,67.146779,27.185764,-16.191915,-79.836668,-94.25412,-138.274517,-165.543607,-165.82798,-88.589008,-76.995777,-141.59878,-159.82202,-85.59385,-31.299555,7.958471,2.99681,1.857049,-47.490158,-97.974128,-189.474472,-211.774544,-166.897516,-131.768457,-134.174758,-121.373945,-79.637571,8.72678,30.067257,35.575581,37.781528,30.690398,12.718399,-23.726025,-34.27624,-16.330116,72.94194,97.190798,35.690156,-2.563833,0.281025,22.650555,3.284196,-68.762738,-85.533117,-45.908085,0.900486,99.06578,128.425071,190.541937,271.782556,268.666411,179.617504,136.751122,78.053126,52.551877,20.072961,-23.337709,-82.45816,-235.243469,-280.391605,-322.282151,-350.659363,-385.733146,-371.600565,-295.015561,-205.835997,-173.992839,-137.870728,-128.858365,-86.6459,-61.740984,-69.332156,-105.857305,-110.821675,-40.221694,54.426289,204.173672,200.763179,118.369277,62.730506,-3.75384,148.335419,247.755432,267.73349,186.679375,23.801348,-16.356344,-60.413713,-52.263031,-31.769802,43.729937,100.954316,99.985008,14.394882,-162.063074,-224.213836,-306.032073,-236.227838,-165.289567,-90.81761,-100.822225,-175.39035,-215.869491,-217.800017,-105.326193,-57.771588,-33.884912,-11.331541,100.262243,124.700629,17.491621,-65.323009,-164.143859,-232.402942,-250.40661,-192.066436,-168.690994,-202.89267,-210.627241,-175.777072,-128.743815,-85.909375,4.215161,8.297696,-87.269416,-140.623134,-210.016329,-270.942961,-375.502179,-241.139623,-149.322162,-84.992019,-119.853086,-322.157055,-447.687277,-569.704604,-511.977335,-469.021213,-412.337885,-399.681711,-411.718007,-413.367156,-325.902703,-254.719655,-126.367916,-36.210135,-7.703323,52.708651,77.40698,65.870953,43.008665,-1.146528,-22.017623,-5.455085,70.614467,94.409738,46.336573,5.179585,-4.031724,3.001308,-29.632655,-29.555082,-0.338993,35.968136,2.12782,-146.26145,-216.51615,-319.226063,-343.979394,-323.243236,-267.757403,-252.441319,-276.302537,-293.428443,-279.676075,-246.114184,-168.965324,-173.403704,-178.68835,-74.534075,3.608171,63.1008,46.260731,-24.51779,-99.369577,-99.306834,35.060922,129.611398,174.518052,92.826591,-166.845224,-273.862685,-322.680867,-217.326037,-165.818866,-71.818904,-19.111063,56.075227,48.262058,-59.206407,-53.892214,35.380599,177.427907,180.422111,138.970327,142.070391,147.464982,96.532723,-30.932581,-20.69806,7.635122,24.574175,17.961291,-13.610125,-66.205618,-244.296601,-319.57754,-291.343716,-215.889314,-228.20559,-377.053438,-429.692559,-349.092811,-279.21893:276.218525,340.23157,328.721826,274.449369,246.060455,186.945817,149.749728,47.046571,-23.298522,-18.387758,70.033131,124.073248,156.473271,120.029487,-17.770454,-65.385655,-28.885996,66.985064,111.83509,157.183362,120.824287,-27.510176,-101.287407,-208.502074,-225.586577,-216.646308,-177.812186,-142.098281,-137.307912,-191.79617,-319.539954,-353.629858,-327.658018,-248.946523,-206.660432,-55.364926,23.404666,27.242207,-41.573612,-134.04283,-41.070489,21.741576,80.823211,65.626067,-76.787445,-163.318636,-245.310261,-257.742342,-274.277018,-218.766353,-151.504732,-28.569768,-21.96915,-128.804694,-213.360036,-337.617368,-249.855123,-141.615547,49.830997,79.538197,-38.267089,-149.979629,-331.659456,-360.845167,-253.249864,-73.989914,-29.50222,-35.239437,-67.116382,-139.852071,-166.050533,-218.553789,-238.6552,-212.15993,-98.831734,-34.407707,-2.296536,-65.914399,-257.110666,-306.952803,-227.94516,-61.288665,-11.442297,-24.715927,-93.287222,-256.460387,-295.181814,-259.333949,-120.522034,-25.621598,167.567576,223.581802,177.777415,113.559256,18.313165,-12.933905,-28.938918,62.568581,128.198906,196.147262,171.466271,78.095198,56.296394,74.627096,157.148074,200.28457,220.922247,211.806166,173.256733,128.715957,2.975226,-41.289253,-7.028599,155.291848,254.008919,367.234837,335.782655,137.778171,29.975378,-68.064682,11.02094,67.295934,144.519232,161.622919,152.135959,118.738782,-27.034403,-125.873805,-227.520344,-105.73597,-41.284305,-51.537497,-101.39927,-223.272653,-290.89249,-367.428107,-299.32266,-233.981978,-92.708503,-29.859781,1.763941,-32.543279,-103.644279,-116.95186,-61.319133,69.347663,124.143154,183.35458,168.293065,58.66335,3.179777,-19.823823,124.585707,201.801368,225.156138,192.706408,146.249328,139.961652,106.67223,65.124246,7.050797,70.724945,135.032488,307.142417,382.893073,361.747463,254.778276,42.13445,17.531891,69.745539,230.320352,294.957089,295.973026,244.019304,135.987229,95.725164,11.235642,-46.147586,-9.733832,132.380019,154.157079,62.487939,-5.577936,-94.226247,-28.54547,35.439342,99.446716,100.711028,96.137681,84.089394,32.613327,14.657483,-2.918381,-56.795822,-77.477972,-85.329963,-106.520898,-185.730532,-221.948708,-251.152245,-164.152321,-84.872673,51.274209,76.698517,37.586431,0.220455,-79.307104,-125.53362,-142.24841,10.002185,97.45556,160.934687,123.145788,-40.136209,-128.475076,-187.911822,-102.988608,-72.560486,-18.550174,22.355579,35.179162,0.94729,-40.161183,-28.695765,41.755669,141.221388,190.74639,214.932306,167.019021,37.313844,-4.839478,-35.38427,-35.279234,-56.069744,-143.564651,-184.667258,-259.957138,-305.211684,-347.431128,-313.461483,-183.089629,-91.912467,-58.360936,-2.475217,0.364439,-30.615796,-50.08142,-109.853082,-143.195657,-124.708121,-38.998795,11.119631,75.202168,73.628344,-13.14409,-82.224101,-99.998982,116.736481,205.079938,178.091525,91.555567,-86.924499,-139.06224,-128.038786,-36.118224,-11.475969,10.522488,36.330945,39.9234,-19.577429,-220.328507,-305.906595,-343.689923,-308.354447,-275.51054,-151.543055,-112.842128,-191.066719,-278.023875,-368.292588,-270.953375,-190.990887,-22.238858,54.987297,124.549582,92.778813,-45.272385,-109.927005,-205.216597,-237.402479,-209.344658,-101.119814,-78.909879,-151.390679,-206.616205,-268.357525,-186.872163,-79.269205,122.375085,155.129294,106.735046,48.389835,-103.894197,-164.428301,-151.1623,-7.458268,34.705642,43.449839,30.701361,-92.213572,-204.234056,-401.244513,-432.350901,-386.011734,-285.530492,-285.732622,-372.947549,-399.864673,-356.927967,-316.027086,-224.30634,-86.626996,-11.082703,77.881953,78.265941,33.305412,-10.537691,-137.331737,-141.970836,-57.721479,152.696482,192.657636,86.34282,9.462245,-69.030974,-91.050704,-99.378959,-54.602931,-45.369948,-46.162043,-68.806833,-214.256665,-311.99947,-452.233952,-445.001662,-393.068206,-267.154673,-225.790982,-266.075159,-337.63685,-468.700889,-488.30888,-391.361093,-230.770511,-177.63176,-112.187988,-106.20548,-162.666858,-197.32833,-238.491358,-151.865299,-49.853382,131.956688,156.910091,40.894128,-59.453147,-213.231198,-250.194264,-230.563233,-108.090266,-32.779327,76.340533,78.553095,13.939582,-19.413955,-80.04996,-53.177966,26.049973,210.569329,248.58173,185.52885,134.24237,70.538634,43.510231,-3.018446,32.939208,83.078928,137.685901,99.772309,-51.308418,-130.729252,-270.428992,-296.352018,-243.050778,-73.625777,-25.581834,-106.846632,-183.828154,-252.028738,-253.469725:64.375032,157.692114,168.893034,141.113579,114.881054,30.928019,-17.044922,-93.27911,-136.405418,-168.544622,-194.792908,-145.358476,-26.206231,-18.45268,-85.083566,-109.159995,-32.672574,131.700759,175.349528,158.606878,134.355048,129.71075,138.855767,100.797769,-34.207203,-109.704995,-185.000694,-168.669544,-92.569305,-59.845665,-29.445286,-24.304076,-8.24775,-36.367519,-45.499028,44.103899,109.397595,170.792624,189.23319,227.040012,209.210266,199.127201,192.03804,180.14061,115.93815,78.864048,-9.197035,-77.637291,-192.539171,-167.929972,-100.930237,58.564721,90.804136,32.173495,-13.141652,-19.227635,144.499989,239.048124,285.189875,240.111052,110.605876,35.628372,-120.245908,-157.083447,-70.650282,23.648208,21.068984,0.304575,-5.276816,18.861113,47.976945,48.78733,10.8495,10.486196,5.525628,-8.27424,-40.301715,-55.871277,-110.160974,-158.57056,-233.781621,-216.686596,-188.065236,-155.418653,-177.927118,-243.798356,-245.942762,-232.599854,-283.847755,-303.925079,-240.927946,-165.412984,-5.538393,69.958796,172.123928,167.276313,82.660552,74.401561,108.861891,168.997174,176.170671,138.535216,113.005662,128.344213,220.9858,232.321963,131.214377,58.818061,-68.350249,-121.66123,-174.277211,-165.319663,-105.124202,-37.118853,10.514956,70.650532,33.981139,-80.921291,-101.240268,-119.507476,-113.605404,-66.465609,56.870113,115.047228,235.662982,279.233025,255.910717,186.633137,18.516054,-64.90318,-50.236727,65.255013,110.964938,116.318412,93.337018,-12.729437,-168.314754,-241.659497,-325.330784,-306.188745,-160.627662,-65.014757,88.086418,106.219158,-9.850166,-199.76891,-235.443145,-98.997256,2.128572,50.053978,25.326906,43.320803,138.326889,159.876948,55.195098,-30.067906,-90.398103,-56.478694,61.487247,106.257343,98.822009,57.590205,75.701123,155.379675,163.265624,111.722113,85.811886,9.440246,-74.564998,-88.194634,-64.64652,-19.177952,136.757562,213.654965,229.720071,137.066548,-101.811455,-148.372183,-106.120907,-56.668992,-75.893119,-127.863663,-137.592898,-132.483728,-95.169484,-78.966895,-51.450748,-21.374643,35.958466,52.606265,81.321216,82.671798,47.5786,14.359749,-0.933901,-36.525068,-42.698658,-20.879075,-7.902845,12.791581,53.186661,55.507269,18.965547,23.559649,79.292222,73.922085,-54.089467,-132.184054,-202.159304,-198.405325,-188.160624,-122.891991,-89.378003,-76.25437,-82.315963,-85.449842,-99.411296,-115.381713,-142.904734,-138.4883,-73.142863,-19.004688,86.501307,106.823142,94.995215,79.033652,45.14607,-42.893099,-44.207931,46.069734,73.606663,-20.602493,-172.279725,-210.414635,-257.422593,-286.831103,-340.641616,-360.365023,-389.932368,-410.508456,-443.162755,-413.317763,-380.376419,-286.401283,-244.028625,-230.85178,-250.363351,-284.181266,-265.651507,-241.25067,-190.258317,-146.62088,-30.051326,10.780211,13.75442,-23.870382,-104.600702,-50.611365,9.675246,52.416896,2.546542,-188.858486,-258.782835,-248.740243,-145.740963,-112.067881,-45.374641,10.266313,57.701908,12.721445,-144.920012,-233.605654,-411.152562,-467.257166,-423.74899,-306.251328,-286.564614,-347.572443,-404.100704,-510.3477,-495.183934,-429.653368,-305.876982,-281.195582,-292.011358,-313.574046,-375.066664,-412.184326,-457.144713,-421.333926,-394.200834,-364.329783,-362.692544,-369.873277,-366.947028,-370.395378,-392.156489,-384.010399,-344.151269,-317.920827,-248.515786,-232.416678,-294.642042,-345.892015,-321.245511,-153.998562,-107.48679,-82.366205,-83.212893,-165.12142,-242.507444,-364.664521,-346.912492,-290.906676,-205.40182,-211.805475,-215.425302,-156.718957,18.160315,87.857726,182.204989,207.821061,209.989239,233.157455,245.818461,239.206391,196.17535,46.873659,58.684162,156.313015,309.543155,309.054999,212.881073,177.896951,218.738465,245.17691,184.191133,128.319425,156.686705,246.278878,249.345198,118.541936,25.545693,-81.45752,-67.254787,-56.101305,-30.138108,-5.062462,5.344101,-8.706233,-33.02689,-45.33962,-33.03555,24.058595,49.670052,108.708945,133.804179,146.072929,125.868911,-19.697841,-144.409145,-105.401485,58.269987,96.821467,35.546917,-34.0399,-149.136137,-174.209927,-176.868188,-194.197683,-207.946055,-144.664198,-62.304383,60.678779,39.465368,-108.626045,-114.887405,-44.135394,59.780909,66.543856,50.880436,28.675351,-12.342008,-2.742279,29.303032,-3.38904,-27.953133,-14.747045,4.550667,-56.358291,-125.006516,-203.391274,-129.569039,-64.767549,13.702076,-9.678545,-170.571696,-241.055607,-248.910795,-218.571858:260.204755,240.904478,213.874364,254.887925,302.48365,302.62725,237.110755,37.66047,-75.753718,-66.428469,18.880098,68.921361,142.982183,159.855845,121.14991,69.928334,66.893664,188.185339,212.508905,199.497735,193.445233,150.500214,99.687782,-16.028815,-96.6754,-121.278499,-96.745804,-48.059657,21.383687,17.976012,-28.089524,-41.843464,-59.368441,-151.050654,-181.654108,-82.639337,9.574824,134.390857,146.080076,84.172388,143.445165,232.52932,278.966107,209.376692,71.442714,65.185429,90.240148,48.428068,-103.57665,-135.911842,-100.211372,-24.296674,-8.670049,32.295977,60.199613,28.706719,-7.828869,46.358226,177.923151,181.799689,80.46732,6.272001,-154.473183,-201.358636,-153.774103,-70.264735,-63.64333,-55.779144,-35.9359,42.708838,76.473474,25.07783,-34.487047,-1.186272,93.687597,121.213707,136.317239,114.991215,15.671008,-31.721084,-73.09454,-123.622609,-153.514287,-145.894295,-119.994722,-94.042767,-117.169991,-244.93954,-331.714018,-312.853972,-172.138498,-90.576005,32.872541,97.200482,214.056786,212.14632,112.231185,98.99079,153.527002,308.144874,353.421101,311.517947,254.887157,183.183721,207.842252,195.308882,28.630847,-62.929217,-126.419573,-126.883789,-146.882682,-169.781097,-244.72183,-255.781155,-172.13871,60.291392,86.717101,-65.290108,-138.979717,-152.786892,-109.617536,-98.195265,-25.848483,36.026028,79.067408,40.651834,-65.601298,-114.693263,-181.185496,-105.924463,-32.524869,62.125088,74.372304,67.558361,39.643661,-72.618502,-116.910871,-97.427411,-79.209057,-91.482046,-89.019484,-69.597338,-35.08276,-4.635337,85.502238,39.374842,-22.863317,-18.852253,40.944946,135.559857,173.626897,242.080876,255.243743,241.201712,141.452277,81.272974,89.311475,163.709161,313.28886,339.685706,350.007747,364.262177,324.752774,183.58835,156.090484,244.250339,286.334908,182.363569,-41.545877,-102.188823,-80.842231,-17.25316,172.06298,278.404901,386.892682,349.9175,187.639898,80.641936,56.158336,13.450043,-29.716747,-111.68541,-96.727935,10.117288,65.944785,77.900447,140.169487,191.528423,247.358242,258.633754,327.93365,351.377021,298.985338,234.018856,209.390344,116.796113,67.892838,46.613369,54.629177,51.699257,68.64037,84.077084,96.994666,107.282258,167.328102,201.141483,218.248285,193.122422,120.547035,57.073302,30.419812,7.176719,-3.880104,-64.549115,-93.768701,-85.509728,-14.738258,11.798731,0.986458,-32.746049,-53.869301,-1.635691,160.633447,221.505598,303.001311,319.277678,280.56337,194.291403,168.034935,106.140976,66.151431,-4.987814,-58.524635,-84.93508,-151.18806,-198.639941,-341.254097,-402.156101,-409.485612,-379.959915,-289.236754,-162.087158,-116.813791,-81.000352,-78.034335,-67.294823,-51.447157,-41.485939,-71.287516,-66.496011,2.573691,64.033748,189.417585,222.581367,215.810278,184.206252,114.77187,143.0139,171.497168,116.945464,16.615789,-211.210605,-261.455851,-223.450518,-143.965326,-102.516264,-19.820364,17.413571,2.668081,-67.123089,-238.93557,-327.595979,-493.281967,-485.838832,-410.168611,-222.322325,-161.937534,-178.635215,-230.213663,-289.645119,-188.992338,-102.073382,35.434431,75.659765,75.593702,17.250362,-143.725551,-198.627731,-247.843874,-243.710825,-228.663823,-240.293617,-268.584304,-247.448156,-176.338388,-64.929013,-117.836202,-147.368039,-88.624289,-26.876384,-22.78742,-89.641867,-209.598072,-248.458342,-313.713704,-275.055662,-226.529815,-163.067642,-172.215825,-310.285834,-416.421765,-530.515445,-383.653128,-288.842562,-223.621029,-224.053932,-215.161125,-210.596326,-155.673003,-103.90546,-36.365032,5.842057,51.790689,115.92262,80.391116,-75.415641,-124.107566,-133.475319,-136.616745,-132.878036,-89.092869,-78.822525,-110.71812,-121.961479,-103.221447,-97.446307,-137.349307,-185.982117,-172.871289,-112.384989,-129.195347,-219.410705,-237.933054,-291.708586,-385.309856,-403.074468,-348.655387,-303.721629,-329.931569,-377.582383,-354.939899,-311.495273,-300.926013,-283.463934,-223.080332,-75.344218,-39.721265,-51.014186,-73.790668,-150.108875,-224.901908,-219.11752,-130.997859,-80.734994,-64.958418,-123.01079,-292.104888,-354.959382,-393.314072,-379.176215,-375.027731,-299.367839,-215.364084,-112.204799,-151.839953,-310.66961,-275.237477,-191.310635,-115.459031,-115.461014,-35.751329,25.546865,75.007361,64.082078,17.103504,-23.774501,-28.487251,-29.882938,-36.926762,-54.084942,-82.282414,-179.641547,-181.910219,-150.887954,-129.056938,-146.632834,-209.907796,-235.583083,-240.015286,-238.104017:104.310973,163.855866,186.825984,182.359078,175.35715,172.931103,152.482231,18.024415,-130.536945,-158.948887,-109.592844,-28.589368,119.892694,114.927073,12.814703,-10.198924,38.304134,48.493524,29.857966,61.646499,97.130061,93.913849,44.389338,-93.127138,-176.960547,-172.636366,-93.141788,-65.705152,-100.546366,-127.201516,-118.689941,-90.495841,-84.624428,-177.188287,-166.248428,39.795992,133.743415,136.033282,99.489802,69.032474,81.599076,94.833014,137.744617,156.275372,94.625542,30.807085,-63.637433,-124.928865,-282.555117,-262.664942,-169.617005,-23.062447,-45.256049,-161.957712,-166.618864,-94.562526,-5.692998,51.053197,158.161526,177.7212,67.768234,-45.446789,-190.835659,-187.630169,-129.512554,-78.047354,-50.886607,2.441804,11.447551,-35.047769,-75.184262,-125.891949,-116.971285,-117.76084,-137.753763,-119.807423,-57.246009,-89.490607,-293.119876,-363.070717,-290.187108,-145.075991,-108.097849,-100.949385,-143.801683,-202.806888,-169.165216,-110.446652,-125.884692,-110.989531,-57.768098,-36.381428,19.196102,55.544585,114.475909,123.333188,106.817233,83.936033,74.593245,96.335106,124.432619,148.736908,138.438556,129.603683,233.534241,290.998474,240.925237,162.099434,71.147643,49.375492,-9.032822,-15.754134,51.736298,138.799309,181.217856,251.443377,235.877832,68.007174,-24.124602,-59.551998,42.467192,72.173112,92.02583,114.230288,175.897182,186.283754,99.339288,11.376735,-116.76668,-118.353923,-97.904672,-54.287085,-49.98185,-56.544559,-38.246676,-55.89301,-228.200231,-268.413825,-119.208708,-8.96643,66.107369,60.384446,71.764791,72.391595,56.48717,31.261335,23.715305,72.209281,110.94852,138.24227,119.07015,73.287496,155.130853,211.874675,195.052283,131.967688,35.133631,23.398146,-11.184322,-50.160136,-41.633573,90.361247,138.725984,199.327696,210.859366,175.055552,156.071296,120.940306,50.522186,25.092258,21.186831,48.571437,138.283207,164.190393,98.911612,24.757844,-65.117672,-63.260765,-57.210688,-29.285139,-26.274434,-82.099554,-117.078125,-160.112489,-180.820951,-187.906491,-180.612501,-145.533476,-56.718797,-48.31944,-71.856441,-70.836326,-83.864349,-144.486112,-157.133376,-161.004264,-174.353245,-163.818849,-135.014884,-102.276949,-79.932406,-60.798962,-6.27206,20.760877,17.215483,-4.898318,-16.960366,-15.742577,-61.233528,-98.084415,-76.406063,23.203825,64.5769,31.724899,-26.616612,-72.472383,10.61549,33.33363,-26.397296,-75.732137,-119.296421,-97.647159,-23.514386,-5.431579,7.670903,68.213019,110.078796,167.677715,163.465298,110.569403,70.868069,-54.699256,-124.509254,-119.387393,-113.44742,-125.691208,-209.050652,-290.427897,-413.77327,-404.427028,-294.501019,-227.928107,-221.792528,-216.047812,-209.725676,-190.466357,-183.646837,-130.751295,-35.63603,-27.344784,-83.431632,-85.223832,7.2452,46.500221,27.910583,-13.80777,-83.71322,-34.937483,28.343354,103.239543,62.251104,-124.169184,-172.948614,-104.637032,-21.101483,-34.196474,-69.440326,-44.755914,10.508933,-4.30802,-136.902968,-223.216542,-320.420696,-324.097357,-310.71931,-218.38279,-179.803434,-257.137598,-329.859786,-354.466081,-251.485608,-232.448104,-250.035759,-209.205942,-66.254978,-43.758462,-104.13964,-160.569918,-307.018456,-410.203236,-399.46891,-272.421989,-217.709764,-232.435963,-293.683478,-429.203415,-392.456853,-282.640158,-57.558204,-19.662256,-89.686508,-134.752264,-154.081544,-151.541321,-152.369897,-61.39228,17.208895,85.599573,32.307067,-197.370212,-307.768908,-420.800984,-399.102103,-361.796139,-313.29458,-315.770294,-368.477603,-385.957376,-281.794016,-177.572358,-25.999196,-0.915945,11.581504,67.42694,67.619774,-10.131385,-48.617379,-91.734992,-60.336095,-0.638795,129.401088,159.691795,114.743326,73.268453,43.719942,53.172676,64.572996,-17.092572,-63.341025,-54.199019,-46.641406,-139.888326,-189.899058,-208.10152,-177.7506,-160.815448,-137.500705,-135.731396,-180.235187,-217.426192,-241.174619,-222.68072,-154.363757,-70.206391,-34.254956,38.514337,55.789574,35.951979,33.840192,16.255131,-55.717165,-71.543461,-46.247172,-33.126016,-55.969425,-83.570221,-153.525458,-197.353852,-214.34009,-113.689334,-62.817332,30.006504,65.44251,85.041453,82.811964,76.890449,116.392365,159.072233,194.967007,175.345338,165.727495,199.176828,214.657952,157.314103,8.702991,-45.550823,-34.672218,-6.53731,-6.648067,-21.379406,-59.025393,-212.945498,-204.851903,-121.754873,-36.964933,-65.860561,-184.297716,-235.033616,-250.044741,-221.622997:right
88.874999,6.589662,69.778728,321.44049,461.342564,628.239111,605.920176,432.712394,314.531849,316.706622,394.549604,422.675186,431.808294,436.507776,434.105364,381.320103,142.365302,32.498447,77.344444,194.680485,233.769358,295.487753,333.773661,403.017675,369.678596,313.103535,172.989202,127.693629,177.849233,247.479747,316.866825,300.060385,216.399429,170.459427,173.75785,164.648289,170.977838,250.243597,293.269756,293.330246,227.459045,236.608884,279.810616,264.253785,229.912817,240.631203,251.984353,214.138549,51.127495,-59.132666,-45.748324,61.9033,105.810083,111.114102,104.58114,157.388139,160.968983,137.000702,173.798519,227.338637,292.899247,277.577022,169.488145,116.0652,32.750206,29.262408,98.875026,251.697447,277.513002,226.706641,168.909614,72.111746,53.090057,81.521001,184.990052,221.190804,207.553519,153.105715,-17.220083,-92.299624,-128.916962,-62.85796,-45.079606,-25.701756,20.764843,167.203467,203.364819,119.024478,-32.694979,-47.01954,-9.782581,-21.975707,-57.935564,-57.961068,-104.262939,-154.297521,-220.359745,-117.517982,-11.802276,172.349192,230.19381,276.535413,268.411758,246.835999,247.873482,253.380282,262.657737,259.84305,259.040107,236.014895,74.034662,-19.851946,-112.346967,-90.807952,-51.251782,27.580113,50.981885,82.446524,112.114985,174.87865,81.705296,2.380843,-27.269943,16.466186,38.928634,-6.01349,-33.385527,19.03442,54.482399,-63.498205,-81.164345,-18.690923,9.794734,36.141636,35.406385,-61.040534,-259.894451,-303.723394,-186.064866,-93.864889,-38.859294,-81.745272,-183.172921,-211.171073,-226.146816,-205.137029,-192.686221,-165.598167,-151.084611,-135.508649,-144.251435,-206.933919,-303.194243,-321.416613,-242.196953,-180.407301,-67.607713,-17.839262,18.995933,-1.976261,-94.14667,-120.243171,-70.429598,59.993145,90.441525,51.109074,-2.521212,-155.995389,-330.812945,-357.354346,-191.075198,-54.568723,55.892663,-4.557602,-142.310619,-140.829734,-105.927496,-153.892806,-171.297239,-159.819444,-130.071331,-69.519518,-67.829076,-118.284637,-242.816376,-301.668331,-295.001217,-246.888993,-149.810099,-115.357859,-98.973549,-130.373455,-260.533471,-333.589283,-321.577653,-231.535463,-171.565594,-118.919231,-144.050284,-218.599762,-299.67204,-359.699478,-455.339305,-438.79425,-268.400051,-188.784212,-178.956992,-227.892059,-308.573582,-239.301329,-141.009536,39.299878,73.146285,96.117785,129.948933,170.616268,45.833317,1.047624,112.267073,215.89567,328.213307,305.78681,175.860061,133.780915,112.390983,80.180489,60.610218,25.491534,22.162193,47.168779,63.70198,100.463995,97.303871,78.503178,58.377536,61.202272,68.904489,71.942404,52.069999,5.991721,-147.266061,-193.178098,-154.179747,-113.360098,-121.189071,-108.518024,-114.807869,-193.018803,-281.68711,-323.085978,-382.542262,-387.509633,-337.136443,-300.104897,-237.662854,-210.070306,-195.774775,-215.221996,-215.44877,-205.356534,-181.807135,-97.900143,-74.593001,-172.576808,-371.4397,-394.553996,-240.671378,-125.692975,49.938153,81.900776,68.806722,71.854443,138.13489,175.372939,134.171248,-0.501876,-17.00645,76.872092,127.09543,115.972715,-59.777674,-130.645172,-20.121959,134.361842,374.946784,402.282467,339.661401,299.557717,235.63547,192.523556,182.81825,223.627713,286.861513,381.700193,375.151807,308.922599,226.559969,195.456038,182.49992,182.168844,133.184916,92.76869,12.685717,-25.852041,-102.149761,-150.721323,-132.000564,-56.217757,-54.900558,-143.020099,-190.170342,-262.424406,-357.589512,-390.938905,-377.458928,-337.517243,-222.843936,-164.266406,-103.705878,-110.412138,-135.552896,-93.3115,-66.544277,-75.47165,-103.248113,-140.774299,-151.43113,-224.572468,-363.751164,-386.311435,-285.167822,-229.524813,-195.126006,-155.859305,34.378024,118.423922,128.485914,35.103912,8.777717,-4.525659,10.409272,81.725148,96.315191,49.288313,-32.391225,-64.43338,-41.164754,18.143326,167.82862,206.298971,155.313118,98.077774,-36.818191,-98.715383,-57.611038,74.361964,100.107184,27.227623,-53.403922,-250.469299,-377.761687,-355.827332,-171.124669,-89.03257,-35.120739,-31.823638,-28.831311,-39.814957,-96.307922,-76.946235,-9.16919,112.559365,135.968783,135.623103,122.643874,106.101038,71.282836,43.781883,62.433491,96.547006,99.51536,55.297231,-94.409941,-168.558992,-240.456023,-221.230415,-194.963546,-113.524987,-67.494326,-41.395263,-69.760492,-151.881095,-187.074373,-156.374797,-29.561829,35.386037,143.353937,162.783842,63.842659,-23.164086:67.53014,-15.141737,48.894413,304.216281,415.035928,443.947622,382.011931,253.407327,224.890295,260.351922,343.597273,361.670291,366.779594,381.308861,440.875349,424.783629,224.176618,65.35811,88.571113,232.95806,270.931952,273.705561,303.524115,390.308635,318.600314,251.286795,164.204705,158.699532,251.791497,305.533821,271.527255,209.189151,113.836319,60.834911,60.835205,140.860487,192.019844,194.545678,149.101311,67.959856,37.74624,43.041731,109.691072,158.982433,224.460262,220.41753,164.741253,126.633482,-4.125911,-76.309555,-23.213159,148.845446,198.778453,185.699336,151.152369,72.520961,-9.98559,-1.033936,184.137555,286.106607,338.152279,310.322034,249.548135,221.089759,146.086106,121.376731,156.115863,310.224664,385.396462,371.517096,284.633131,116.126217,27.676674,9.987159,68.675053,132.94888,183.919846,126.768095,-50.632098,-98.53734,-87.369989,-16.358035,32.062528,107.665925,112.62939,116.485557,127.205424,36.795628,-165.154851,-198.512858,-125.191507,-85.237828,-54.091161,-62.434849,-102.003738,-117.708794,-138.685639,-64.412697,16.396445,181.539928,252.052599,320.831728,308.711454,234.393722,165.5411,153.038103,171.520861,180.526252,184.797721,189.015152,154.129428,96.236372,-67.165016,-155.098468,-136.636758,-40.894597,12.888956,96.849201,107.529877,65.741021,-9.688324,-44.174497,-79.390146,-60.385385,15.069787,24.16535,-17.173662,-39.291926,-65.08524,-16.380171,31.5906,55.012048,9.166089,-130.058634,-178.952077,-229.158832,-291.167938,-291.235441,-191.611735,-140.110217,-129.483737,-159.498916,-195.600052,-189.302748,-203.862008,-275.258128,-296.144301,-269.020817,-251.690951,-267.105112,-275.887283,-293.735418,-377.387505,-402.459236,-325.98728,-248.301102,-106.77102,-65.275889,-56.748587,-88.427116,-178.495625,-104.329344,0.447937,138.222333,123.247405,25.512604,-2.557108,-83.399986,-277.21704,-331.406236,-237.333266,-132.024521,20.782843,23.576025,-80.152756,-142.458522,-244.698241,-278.62135,-259.9976,-184.231888,-137.899401,-106.854943,-136.142036,-215.593339,-292.475465,-326.390714,-308.161384,-264.144962,-206.724555,-181.783575,-110.306149,-120.751828,-270.626747,-302.09195,-245.643663,-153.268158,-127.863396,-114.373708,-148.220176,-276.824459,-405.439539,-442.543227,-437.242781,-396.928303,-314.479311,-294.666115,-247.829334,-228.497011,-271.126463,-297.87641,-246.198057,-65.555619,18.088296,84.726961,45.561053,-100.312056,-127.039407,-80.22433,50.642631,104.056,146.912017,150.640884,175.789029,169.627432,51.884458,-45.806622,-40.824885,-5.563042,6.769567,47.498176,63.930426,37.006409,-3.351323,16.575812,63.551253,48.699312,14.647651,25.636504,14.418814,-38.125863,-134.237854,-126.738502,-127.307054,-134.520139,-113.284527,-75.393596,-78.174441,-121.352955,-220.203775,-253.34788,-231.085207,-184.585906,-34.526615,26.626439,7.977542,-33.034312,-81.222247,-123.102329,-127.468051,-89.391528,-64.111532,-8.227174,8.702416,-86.288675,-236.602421,-212.248185,-23.555301,33.826984,17.981151,-10.925386,-25.152262,-4.600889,29.316897,0.280865,-21.842325,-36.469577,-25.657621,-13.437046,-21.726036,-48.117816,-84.448759,-76.083241,50.182739,144.432598,326.714607,385.538865,350.098335,269.614609,160.449478,202.500547,222.556242,247.521225,286.818727,374.184695,382.970915,301.264364,169.729076,145.066929,232.60578,304.938412,313.086959,226.611717,72.014301,57.263475,65.343405,90.0815,111.812206,116.567876,95.38528,20.359235,-38.800534,-196.310489,-338.683112,-349.935448,-210.949924,-122.075951,-26.258359,-3.967957,13.813435,-7.827022,-51.70753,35.670037,86.273908,87.154329,48.096608,-31.923604,-57.131099,-143.163001,-276.829011,-300.721089,-303.46013,-307.18511,-242.496858,-163.073045,24.409719,84.387899,66.637385,49.180327,69.735525,36.358409,-9.383005,-70.705424,-81.43004,-65.220465,-65.303383,-78.056211,-48.089832,6.888898,137.502528,176.455058,158.248098,106.82554,-32.548133,-58.125245,-1.80594,109.108505,116.715577,15.864354,-72.168369,-196.415744,-205.71776,-190.094054,-104.774799,-43.519683,47.890048,69.765035,46.011466,-4.508519,-105.913301,-41.952806,39.425728,141.556831,147.565698,148.205367,154.829936,136.068681,67.36604,41.9067,76.261249,122.462554,165.290071,139.835964,24.693714,-43.316588,-152.42573,-136.252819,-85.068735,22.879587,66.145062,117.744681,113.568856,32.634429,-48.6113,-29.531629,136.032225,221.949357,289.39989,263.389451,185.146388,176.913157:-19.800043,23.836332,89.201197,218.290904,296.752111,417.293548,392.253045,207.637111,174.479756,245.729825,312.831593,273.322103,217.318265,222.85619,197.045765,150.85518,45.230053,36.96308,77.785494,156.389033,172.766724,207.1006,235.625547,211.47615,42.595646,-5.403724,83.162662,170.252867,261.821227,240.416515,139.604913,92.469664,-4.23661,-41.798149,-19.420315,80.005013,137.801875,158.536106,121.086392,66.229243,40.643719,32.626964,47.441028,66.051476,129.707298,149.128949,91.869622,50.255636,25.026244,41.429092,71.288597,177.784009,222.146466,238.245453,225.521761,167.329251,78.224438,75.449898,175.133744,234.69053,307.462971,331.070444,336.725742,287.914408,155.998976,160.534614,188.631811,238.57797,279.119319,309.92729,245.915349,18.010888,-113.457112,-104.551531,16.132166,86.514778,140.454662,106.144434,-8.980519,-46.06517,-62.834493,-12.878791,36.862691,100.638396,106.515108,166.372798,214.732741,166.735577,-42.992759,-85.929092,-21.280225,22.74999,93.57825,101.992766,10.804796,-48.239768,-70.043031,17.444473,74.021303,203.220416,280.822202,398.443278,395.236387,239.870629,113.799196,142.539262,252.872235,276.893635,307.854312,319.583787,206.101882,81.594285,-103.233058,-84.446997,-26.428391,92.273405,122.061701,109.026696,89.572423,37.70599,-65.809776,-118.7936,-143.929154,-78.223108,107.610675,123.98245,-10.623167,-75.734145,-108.036406,-78.826395,-48.914423,45.175756,86.065511,52.45504,-14.026004,-127.6264,-171.253529,-176.737984,-175.56168,-152.140918,-81.028234,-86.381409,-195.18337,-256.06642,-336.371057,-327.094732,-292.540997,-235.547088,-227.425484,-273.396095,-326.629794,-442.219671,-465.538888,-412.064525,-216.976143,-116.530919,35.033018,62.527724,-12.852916,-74.497966,-72.942447,106.189021,177.887288,212.757798,209.049291,200.134095,170.33794,-10.081995,-204.056951,-220.070008,-131.037468,-72.87761,15.831897,20.556357,-87.155134,-193.063417,-384.373828,-344.186212,-280.645039,-229.130572,-218.641549,-203.437461,-227.471383,-324.508394,-402.296839,-407.079336,-323.546964,-264.988947,-188.571241,-165.985245,-132.839218,-138.321319,-223.133758,-262.446654,-234.490931,-155.065633,-112.897396,-57.942796,-83.132995,-255.823704,-401.708616,-398.251378,-327.278797,-313.711506,-328.754668,-325.047243,-272.25444,-266.595553,-332.352702,-329.090876,-258.096715,-28.017338,49.310473,-12.432463,-98.352226,-193.197904,-207.051655,-200.357842,-155.389782,-129.556793,-24.743879,58.866069,140.81853,97.636475,-78.950266,-148.730226,-112.630085,-5.788544,23.247172,25.140274,12.802063,-45.966428,-79.73742,-43.951549,63.811015,111.279427,196.710009,194.989908,54.156373,-30.711256,-99.465904,-28.226382,18.04133,47.871032,43.727453,25.920276,-6.834737,-85.237519,-84.305809,-61.292044,7.692999,43.605629,98.878828,119.867768,111.609351,79.066095,26.49721,1.078029,-6.244499,14.679989,32.533473,52.621744,43.752853,-45.885826,-92.251919,-54.869275,-2.930889,-10.497423,27.484207,67.038079,55.053663,-3.584702,-117.514888,-67.705204,10.912363,101.434533,86.397216,77.449008,110.567309,78.927495,-90.048081,-117.056526,-14.569046,67.798967,254.335096,328.647118,294.945161,197.453152,18.657694,0.23104,50.086749,196.376736,247.621809,245.860743,221.608983,219.058323,215.206726,197.791541,251.118023,330.376655,395.929538,331.335175,194.112219,177.340747,159.468516,151.627075,148.655254,123.561091,146.105866,217.800494,181.929884,-26.046258,-177.063384,-195.178029,-135.467199,-71.895623,70.872384,116.157705,72.305559,-11.989931,-98.500719,148.0001,277.318732,252.394951,159.94066,62.627983,35.803461,-138.582287,-289.054224,-269.15173,-225.634082,-242.060956,-182.629827,-103.625797,-57.023142,-103.818968,-171.29516,-136.781946,-112.777635,-85.655156,-82.221756,-79.289126,-60.531913,-26.468312,-114.617284,-145.301093,-48.504502,43.397501,167.910334,162.94899,73.442816,25.27255,-101.933486,-135.297881,-56.045003,119.863403,119.695615,-42.79734,-121.768928,-177.365667,-181.160978,-181.319834,-166.120618,-139.935806,-22.98755,34.044255,32.271097,-22.71833,-121.985764,-39.428719,60.388549,205.933684,219.073083,192.722717,177.951966,114.436221,8.993238,-17.970554,41.247615,115.117562,225.449423,221.732449,116.11267,38.617564,-85.084329,-47.693482,23.733133,154.113871,185.24143,198.530148,182.111289,52.097973,-107.65944,-108.2288,78.30717,186.944369,276.22168,263.690221,200.296248,145.849221:-61.916783,-35.112576,21.961883,191.416777,303.130967,471.787492,466.183358,319.023845,213.394898,225.260545,309.202079,334.446992,345.043185,340.190496,288.518654,242.19966,115.163388,17.622523,35.522632,190.308932,263.81205,307.360818,301.643435,287.308734,206.149089,146.122545,66.686606,60.763039,142.373715,204.312055,222.814387,179.028168,103.877379,109.306795,109.153371,72.194511,80.609922,152.797107,173.506246,185.702171,191.333838,190.184798,172.150409,157.743867,156.457048,156.383077,118.64423,104.222759,96.385286,23.496178,-21.891393,-27.250916,19.738805,124.15821,154.510378,181.891037,145.781002,131.468269,192.427452,247.849573,344.116337,366.677214,324.075364,265.885858,131.571371,81.028329,104.138198,206.747645,259.098486,250.731987,184.772594,63.996685,-5.412175,-34.970999,21.259312,113.455316,211.297805,152.42065,-74.322936,-156.510647,-169.416124,-51.217894,0.871874,57.873554,100.320689,202.168496,201.059626,74.693982,-51.270381,-75.182406,-63.37868,-49.927812,-35.108584,-49.004821,-120.15965,-136.944662,-110.477911,-45.219254,19.055591,232.792792,352.471599,477.825938,476.039431,424.190971,370.996021,366.537784,379.170121,359.111543,261.648157,214.441419,131.838023,85.031491,-1.416447,-16.662569,5.095004,120.578662,204.002693,267.916819,221.888979,110.101701,79.717286,62.29804,-11.734876,-26.484793,30.269327,52.001642,37.954583,16.343174,-65.884661,-56.644161,12.366498,128.150641,134.591316,32.643865,-49.360352,-161.564929,-182.495535,-174.952412,-143.495321,-122.776025,-87.470489,-99.343117,-207.127219,-259.287872,-261.502077,-196.011108,-186.791763,-223.232339,-219.666382,-139.620478,-123.178982,-194.755876,-230.284215,-200.995465,-116.294628,-81.635428,-12.802058,25.544056,58.810552,44.949048,18.892391,67.171779,122.076365,211.050025,208.191929,142.495742,117.997087,42.327736,-148.527363,-211.353018,-145.461168,-63.207153,1.054524,-51.527077,-185.998697,-202.542244,-215.783701,-278.178831,-290.887839,-279.719299,-260.573319,-171.468895,-129.708773,-166.949012,-291.829719,-305.077286,-195.387355,-143.611049,-178.627967,-227.466626,-272.247363,-286.118704,-373.558273,-375.910695,-310.010609,-179.838041,-138.858388,-129.286236,-167.96545,-248.35498,-276.72889,-280.057878,-253.658654,-220.075317,-175.13131,-196.230436,-268.159069,-279.426189,-272.787759,-225.767169,-172.788719,-55.431292,-15.863739,-16.68477,-39.375105,-49.06125,-83.906601,-91.830537,27.722378,126.991342,270.227322,282.792687,217.371877,183.890174,140.326698,91.383538,79.732966,83.17116,87.111739,102.928489,114.261721,114.303671,104.738086,106.138477,81.892407,60.298043,58.752085,66.776589,18.593569,-41.02383,-162.769529,-145.537133,-92.377428,-34.271734,-32.179288,-29.353506,-44.159234,-173.830796,-340.867686,-356.786502,-257.73581,-203.930194,-105.241255,-37.705789,61.508605,55.623136,-25.798261,-18.685993,15.782113,-13.435663,-54.549295,-6.130218,44.140953,-23.260386,-199.330878,-212.67309,-66.175475,27.418758,146.081076,163.849074,108.90074,48.58999,-29.709161,44.490586,92.905094,95.706082,67.691362,66.052128,91.488982,75.963474,-76.436799,-137.989734,-76.000028,35.802769,272.685935,335.507071,282.103136,199.861089,75.032816,70.680941,95.046504,162.486294,204.043723,273.958285,294.875851,311.915844,224.549767,158.275817,128.006407,182.055618,302.33562,297.162756,168.496014,106.646459,57.954477,113.999327,136.61887,95.458474,73.787007,56.549797,23.241973,-112.668215,-232.267478,-243.676082,-151.369258,-78.596921,30.713168,58.481324,61.056601,27.792321,-55.658998,-14.711753,35.165753,40.581806,-7.207309,-79.626855,-83.529488,-131.110788,-304.56661,-360.115011,-296.591383,-225.223055,-101.55204,-39.277027,75.106601,88.831161,0.827067,-62.546054,-50.901619,-31.093272,-26.842999,13.875442,38.149164,22.983306,-86.834498,-116.693106,-62.388434,-10.181898,81.395809,99.823523,59.98318,12.562637,-114.047112,-165.178129,-128.401748,-9.778867,20.939424,-46.428641,-137.375153,-324.768612,-361.805294,-309.191801,-170.272446,-136.381602,-105.672071,-73.728055,-40.262509,-67.483521,-140.781057,-83.511251,-5.121169,101.011092,105.265311,117.690379,128.828385,58.113635,-27.590324,-1.529632,122.620119,155.109423,141.825415,123.33937,36.779211,-51.223539,-239.961667,-293.608885,-254.418221,-108.895337,-52.110301,-36.118359,-61.297971,-152.524242,-252.501344,-240.577452,-55.008626,37.776541,62.225784,23.235997,-34.499605,-58.635651:5.691143,-37.14805,-22.094038,156.22351,289.144434,420.072132,370.611199,140.964581,0.353287,27.490794,206.214131,289.702797,307.311587,242.824746,109.02922,72.056958,-7.022767,-63.175746,-39.145267,91.726916,161.13488,231.64436,236.279564,190.507812,42.860445,-26.629909,-31.574338,17.889841,104.966493,114.564372,74.275674,42.432053,-2.020632,13.346518,40.634831,75.171815,69.001418,82.122728,113.023817,121.720567,33.806859,1.029906,9.466128,44.315117,125.224236,139.109931,77.496701,16.12288,-96.1102,-56.113554,28.558582,153.538361,154.517037,129.396346,148.258474,192.665941,101.156586,48.920071,70.02659,129.917917,272.73945,320.567139,263.06322,165.515086,12.896086,83.896808,154.998701,208.6949,182.40814,107.540071,104.776304,107.189364,-37.178738,-113.943844,-106.321068,-23.624942,144.853508,162.678225,49.148527,-33.935835,-161.351788,-134.181916,-49.927309,130.044652,173.212281,132.552241,69.746889,-72.088709,-132.06643,-95.48353,19.482043,42.107994,25.682123,14.044971,-11.09263,-46.866481,-137.0269,-33.572841,94.834589,296.370536,339.614792,358.680742,343.337144,298.891673,288.11062,290.499435,289.533072,286.342481,286.984086,269.59805,130.816615,26.513215,-127.377122,-51.204812,42.078299,168.479972,202.306625,233.489328,209.734442,90.786118,-9.741208,-35.726207,-64.93067,-55.812424,25.139556,58.010838,13.263632,-56.612301,-171.153615,-109.384462,-40.189201,67.826343,98.363974,81.576358,36.055301,-94.457892,-216.328213,-231.134532,-187.199396,-155.386378,-75.011681,-51.12165,-142.557139,-243.438096,-374.506898,-316.670227,-273.085713,-237.911309,-229.664295,-213.042352,-230.765003,-340.949767,-408.680637,-387.238193,-283.188474,-207.598726,-51.896443,-33.304996,-129.239199,-180.65895,-169.068131,-5.990616,83.095998,185.388468,195.444269,147.895758,97.394028,-55.567681,-200.159344,-222.582454,-158.815085,-90.300909,-0.527272,-31.137631,-209.316784,-304.698622,-445.436455,-445.56611,-384.69895,-224.661576,-159.81757,-128.449356,-172.618961,-323.416637,-394.399284,-365.850364,-227.404835,-151.494339,-76.955594,-101.072194,-226.933068,-298.235269,-400.257234,-350.047283,-282.185873,-158.190802,-105.656311,-83.408241,-141.101199,-285.300032,-305.1627,-271.705686,-202.332483,-182.160852,-199.917927,-245.436594,-348.729592,-383.657421,-397.526076,-254.003308,-151.481177,-36.619875,-38.50803,-129.331578,-184.6474,-222.140881,-184.828557,-154.896872,-52.69783,34.061151,210.403876,233.51018,155.386085,109.434845,21.941528,20.801394,87.572442,228.528116,257.711003,231.810044,200.584248,134.635353,59.301887,31.075595,34.615342,77.057089,142.066451,106.72022,-27.023442,-71.156612,-92.567132,-6.422691,58.169717,148.259792,159.27169,105.668639,46.013557,-95.650195,-170.936168,-158.619816,-49.506601,22.982248,168.67451,213.862999,167.444366,103.345614,39.914366,127.816552,180.828192,225.436131,226.543481,179.235094,127.246467,6.514646,-44.34028,-19.015843,119.292949,213.933699,339.302452,330.256468,224.653836,176.430705,150.479738,206.733401,225.504166,214.855651,206.627805,181.210251,147.639726,21.778312,-131.45855,-151.173303,5.471527,132.897464,304.679187,331.93632,300.996768,233.800573,59.742239,25.301588,82.512324,280.661111,352.5822,322.031325,266.490949,224.222726,213.345893,208.83916,276.530067,334.309874,391.017641,378.975892,326.194032,292.505356,224.541745,233.645225,230.870419,193.026095,209.502486,228.514644,182.89109,86.66248,13.317449,-31.087139,-44.599654,12.442423,178.226844,220.208658,169.092827,109.152963,28.058374,78.490845,114.982765,127.133262,128.247454,122.864864,77.543267,-115.795224,-299.624363,-315.007897,-213.9675,-145.505427,-31.126921,4.624119,34.072784,14.904374,-108.325658,-144.425763,-101.91977,-19.228171,1.784217,32.894251,45.723374,-11.141186,-162.503711,-192.648289,-118.437673,-61.499096,-1.726521,0.491433,-11.95693,-35.752443,-155.770847,-210.776302,-157.399986,31.039944,94.009621,34.368266,-67.442115,-273.63561,-381.482588,-363.942408,-193.311,-104.091093,-9.995044,5.823265,-20.463524,-70.804522,-163.937893,-35.211721,90.214022,256.35982,269.185173,198.81572,144.586295,29.088461,-44.040669,-20.63822,74.068109,105.93163,175.626439,201.096839,131.724245,32.212208,-184.673885,-185.472394,-96.328144,77.460945,121.409878,113.914894,52.679347,-145.616691,-259.571412,-229.590564,-29.186404,80.9807,180.522818,158.836326,70.469804,23.591535:0.238469,-45.558894,-12.31834,184.894088,297.302844,400.638988,386.271441,288.210075,173.447534,175.446706,333.710671,409.273041,425.397031,401.15686,330.810857,260.09203,57.03181,-49.628398,-13.672218,168.498461,251.752039,295.851786,276.012411,230.192103,140.865273,76.697979,-2.897017,17.51715,182.502011,264.041554,247.673562,169.884898,53.389888,54.165511,78.729667,136.642531,170.563258,245.340602,274.248169,284.235634,235.501706,233.463626,280.155879,293.600945,270.624335,240.546798,180.468311,163.584134,72.61926,-130.611725,-187.2852,-106.630309,-11.506175,126.009412,158.39436,196.217261,120.578485,83.389421,175.014406,254.102096,282.206891,227.500718,83.69186,31.009591,-10.465221,60.476755,125.798715,223.000788,225.079173,113.328723,50.410237,47.821917,74.650208,56.800283,42.251614,56.286429,48.4215,5.513077,-87.982415,-101.278882,-74.094475,-12.104284,22.06211,92.596041,132.37498,187.882004,196.558514,167.489657,54.227629,-10.691266,-63.293001,-40.118403,22.392684,4.340957,-136.556136,-194.342882,-170.665752,-18.203146,62.54192,208.84625,267.671525,314.037032,324.120784,380.134813,370.502044,334.58413,304.190386,315.141223,292.756806,230.270764,75.370098,30.226637,-6.374018,-5.672718,25.242319,116.62904,154.911627,170.311811,149.318344,81.390001,-2.176364,-20.305317,12.786817,31.554827,7.074087,-27.124831,-76.352783,-87.360721,-106.191655,-44.838879,19.619018,90.437558,88.725851,65.459111,32.068048,-107.130812,-241.911426,-267.190918,-235.18786,-199.635645,-176.625666,-202.595912,-251.250798,-247.9362,-214.053752,-156.272161,-135.942166,-191.309635,-225.98836,-159.893335,-107.33751,-151.74911,-279.039089,-279.38239,-120.085396,-34.927706,46.822215,77.438017,104.443298,64.976356,-68.834734,-113.541791,-83.028825,16.912456,50.416466,18.780041,-42.596147,-181.606459,-275.569692,-270.429034,-150.095157,-76.767443,16.860767,17.287527,-94.389488,-160.232694,-189.487275,-183.671311,-202.343774,-197.090533,-146.73957,-51.134025,-41.697751,-96.437488,-218.85344,-223.285696,-85.957775,-34.651103,-60.26665,-112.86087,-224.95898,-265.457956,-304.926221,-259.435451,-240.142027,-252.894565,-240.626976,-183.520189,-179.791711,-206.006442,-219.668585,-217.21676,-210.488788,-197.914881,-95.520203,-41.862906,-76.955701,-158.069196,-273.774372,-154.960265,-50.177479,72.323685,88.241778,117.101485,129.145028,94.629834,-8.581616,-17.209067,140.125841,251.823359,388.53826,375.974749,235.865204,186.050991,201.409867,231.751761,223.807313,196.588932,200.16112,261.365248,292.250249,245.791172,108.955272,90.834935,129.146746,130.459833,104.211086,87.842448,3.44857,-61.850777,-163.877875,-136.62614,-76.123076,39.031387,69.448547,62.694308,22.462446,-145.432219,-355.66409,-408.282572,-349.953541,-293.565864,-232.611123,-208.491432,-140.814677,-112.451087,-105.940633,-88.15985,-46.39648,12.812352,25.075534,80.299369,99.321678,-15.093687,-257.426182,-297.592042,-111.644838,43.801442,268.255106,284.667154,160.657985,106.497051,123.362509,155.155255,145.631991,140.223874,151.045781,151.179899,136.448179,89.455257,10.098607,-19.660863,35.410434,126.059544,328.05542,375.732124,305.942171,221.30744,71.376993,83.976621,136.485272,200.795008,212.948655,252.794368,276.103613,297.818382,242.17268,190.029574,125.664795,119.211932,102.859389,81.561308,18.70797,-3.90678,13.838426,81.894635,110.099604,112.429565,83.205197,6.934894,-22.806633,-70.04582,-173.178624,-237.20424,-248.04759,-160.851746,64.223313,113.281223,55.934632,0.024719,-88.269455,-101.680661,-80.189297,-36.275653,-19.979146,-22.922993,-53.303876,-134.401941,-205.096683,-209.193096,-152.8297,-129.436543,-101.699481,-66.613552,55.979782,106.021491,90.745201,0.798632,-12.20838,1.434024,8.46119,38.473307,59.56432,79.883972,4.177086,-43.700551,-19.299586,44.433146,174.566625,197.82294,70.94213,-55.700199,-283.479587,-253.757407,-148.355328,-0.305749,3.526906,-96.928035,-188.250424,-366.700456,-451.441757,-423.781959,-237.383497,-145.493527,-49.804055,-50.096777,-149.159148,-209.795851,-258.407311,-165.895777,-81.985262,60.586574,104.955191,134.439327,102.812073,5.240211,-32.695022,-44.027011,-24.087108,20.263082,86.203719,51.718588,-150.383173,-235.325898,-274.141916,-258.293384,-247.315779,-225.63293,-210.640401,-177.074422,-185.763977,-251.780028,-285.44266,-265.366611,-167.053708,-118.349894,-67.763454,-67.16119,-120.918632,-166.82114:-54.147752,-80.282227,-5.112051,268.576096,389.537755,458.75242,403.795642,199.314675,64.875986,96.324055,263.960105,325.275863,368.399673,355.310675,248.666999,162.241346,-26.084991,-57.256024,14.655665,176.701592,225.348786,257.255856,241.724327,152.008295,-0.268677,-59.151364,-79.860725,-48.515335,74.174851,125.704111,99.435366,44.372233,-19.823506,12.916074,44.816101,106.960684,128.266935,168.37545,201.936355,228.447898,110.401489,56.763468,69.457552,111.213758,181.561003,183.944527,108.400506,45.581848,-102.072811,-204.997026,-189.543411,-7.010762,91.12961,128.666562,89.771922,39.664446,15.121635,22.83105,142.563809,220.025009,297.209395,284.1401,167.380011,82.630983,-69.693702,-46.716988,46.369091,202.357868,191.081804,38.192865,-22.722305,-47.609742,-76.531132,-88.411647,-2.661105,75.278159,144.107745,104.251704,-46.842507,-118.899516,-211.72562,-122.871384,-25.052615,131.933962,177.452952,195.200681,158.446791,47.273096,-49.576703,-87.438437,-106.005054,-71.342836,36.985842,43.803496,-120.33997,-229.591205,-278.938631,-78.995619,33.446049,213.967269,296.589664,370.458042,346.463953,258.495527,185.836041,174.811337,192.214386,206.809788,235.591605,224.354999,91.612519,-6.362723,-137.025477,-96.871104,-35.534197,102.668894,166.76704,185.640858,119.883126,-25.060322,-75.244527,-75.44937,-54.255886,-30.67428,13.738877,3.891021,-77.907615,-122.517467,-183.871123,-85.043309,16.344626,101.509745,74.576833,2.174201,-33.080912,-150.67833,-264.912603,-271.250016,-201.38195,-148.388468,-73.984216,-85.564713,-190.460368,-244.459542,-292.414922,-224.220328,-165.836906,-102.176726,-97.262019,-115.657982,-161.907106,-308.270751,-364.98252,-347.19314,-261.938639,-185.012385,6.605622,59.992439,23.870493,-26.444969,-107.345408,-95.92904,-38.409717,95.492738,118.173482,62.076164,16.677695,-115.49206,-287.756344,-305.409204,-160.661825,-63.075169,-0.31565,-70.999286,-291.348023,-360.279034,-413.691819,-374.605985,-298.170463,-129.601059,-87.380355,-93.69495,-117.524219,-199.250474,-306.584761,-298.335965,-144.154699,-78.820999,-56.625033,-81.099657,-194.059547,-287.739123,-486.16264,-454.577299,-341.561419,-171.565249,-157.10092,-212.819445,-264.574134,-362.575163,-378.464046,-332.447616,-181.583469,-119.014802,-70.848411,-96.006244,-255.142633,-354.816688,-400.818663,-163.1387,-41.992849,49.706656,68.608412,106.396546,91.334681,-14.116819,-101.181078,-81.120481,109.282915,229.03329,348.052799,318.846177,216.381749,205.329087,190.653958,147.547784,178.055618,312.759408,353.788381,336.007059,305.245102,229.290448,139.5889,118.728014,133.259926,152.330018,199.956215,204.338361,125.071666,50.159705,-95.661882,-76.416974,-14.77892,90.905763,114.868142,66.877829,6.046197,-146.269113,-304.684067,-316.190247,-168.184494,-80.740723,7.121666,17.556197,44.537668,61.536699,31.579368,45.165739,107.849026,205.228234,215.161914,223.099446,205.511831,38.089539,-166.262298,-177.545071,29.7073,183.424552,395.461819,407.991293,272.492911,180.538924,75.835265,122.744058,179.089869,274.099648,299.416093,281.576215,231.335303,75.424021,-56.748011,-69.045303,30.243794,121.746857,321.63321,382.093997,345.33948,274.542029,145.88476,146.105007,187.122665,247.577142,255.11337,283.376956,315.335717,333.966401,218.726558,169.314203,214.554816,289.539713,411.973823,396.311444,220.727038,140.899289,111.25784,193.950705,223.831929,230.405224,237.54697,248.223001,224.829475,133.058811,-1.797509,-71.374768,-75.735666,35.320769,342.361161,411.151202,286.489485,175.150006,48.327295,26.161079,21.64619,61.052201,97.495559,99.103078,52.646377,-74.572466,-212.506019,-250.325744,-171.6489,-85.733118,68.454225,104.629464,52.848954,-12.481448,-131.650825,-99.80875,-33.028629,55.798924,68.164009,56.187583,20.265494,-93.319752,-192.304349,-200.153516,-73.551396,14.309115,111.439367,108.541725,-27.783104,-128.589754,-231.282183,-165.294643,-114.95017,-48.395968,-32.329227,-71.688454,-147.880866,-332.881026,-378.581353,-338.013122,-194.66562,-118.046578,0.80184,25.335145,-8.062779,-58.693741,-187.417853,-198.619755,-139.225239,9.038569,76.119735,165.584697,159.227218,36.496,-73.51192,-62.771841,39.952408,76.79715,134.646966,172.480789,119.693017,-12.743584,-311.944264,-334.346646,-242.736147,-57.623459,-9.791284,-18.568862,-77.533161,-258.583034,-381.595855,-356.455767,-127.904991,-14.717002,32.520934,-7.039616,-96.736683,-152.71775:39.355684,22.451366,32.697402,92.576334,162.662211,326.251248,361.221442,288.919465,117.156873,79.433538,177.543223,248.898762,274.324755,226.761052,129.002303,92.686349,-63.836056,-161.059848,-93.964153,93.945338,136.215929,148.446622,136.878613,62.10438,-16.450746,-24.508165,35.18769,72.116587,90.924865,84.147715,78.223896,76.832498,49.178012,17.761124,25.670285,46.3425,65.44257,178.029694,237.379983,270.785818,220.631403,196.69863,211.750712,242.514127,245.643886,199.34126,82.062633,35.967935,-84.387633,-249.294069,-292.953802,-328.29723,-346.128496,-308.524573,-229.542426,-52.034184,-41.660996,-51.609624,53.816345,119.805665,148.203024,123.322162,32.310949,-19.721142,-77.080045,-50.582505,-7.270244,100.699382,146.051507,141.429735,77.729463,9.91391,124.32145,174.452418,203.946304,191.170334,95.466392,27.158831,-40.416787,-14.400361,69.334072,82.559287,91.247284,167.69883,219.646464,292.008754,301.965418,277.998592,188.811291,125.928342,28.965531,17.336822,32.782464,21.888347,-70.711423,-111.693205,-72.520378,53.360493,114.153913,225.659547,271.566772,344.930708,376.178939,377.26896,285.125203,257.356538,217.983872,158.027198,42.254536,31.82219,14.563609,-11.085982,1.110806,92.765327,119.23041,113.472659,104.779589,77.866655,61.985848,60.512582,11.24914,-33.635968,-62.439068,-53.250014,-64.701402,-82.484366,-106.518011,-115.433757,-124.160244,-53.66064,-6.910742,-10.923972,-43.819721,-56.3791,-65.123599,-203.471268,-374.32636,-405.427681,-341.926285,-277.915219,-161.796852,-141.103854,-213.620555,-252.905711,-203.260506,-97.453744,-80.951997,-106.774681,-125.425776,-174.21621,-204.241861,-213.233657,-188.064925,-180.839499,-177.625795,-178.747717,-142.08152,-124.54762,-155.001275,-187.082715,-272.19704,-334.698293,-314.540783,-228.416842,-199.735201,-207.276445,-245.312834,-359.693618,-464.095473,-476.27867,-393.091411,-342.0631,-312.136416,-327.029814,-313.776861,-246.795866,-118.126444,-164.331122,-182.10033,-105.507247,-64.841847,-68.795225,-74.319256,-66.146596,-149.976061,-174.791476,-38.990225,56.254508,77.121062,22.172508,-62.278416,-86.382775,-179.89107,-245.022543,-219.266073,-180.822357,-206.477278,-292.207943,-325.02829,-335.31765,-271.771162,-221.609148,-169.3059,-160.180439,-32.533461,54.88848,70.045584,19.530408,-41.124954,-35.953331,-8.040037,120.465147,209.260829,312.047599,293.87119,204.295374,129.385783,113.329419,206.267556,300.309467,430.329404,424.905454,318.82689,265.70645,209.15167,240.223287,251.617937,169.030934,132.357275,198.36105,253.163621,237.37092,91.534209,54.107591,98.899603,131.925414,146.979781,140.575684,122.836498,107.322124,64.915782,71.729826,94.394149,96.596125,74.415996,57.879229,63.121139,19.613441,-128.120783,-199.546763,-247.55355,-219.69997,-112.02689,-62.968486,-27.641824,-34.707963,-27.310322,53.660294,99.455875,146.256487,139.448336,42.403659,-25.865553,-104.153356,-118.988134,-90.532459,53.975276,130.066454,239.566748,271.38044,270.302112,248.327347,227.799394,208.799048,164.185792,43.288023,9.333173,14.308257,40.340511,97.37335,50.472454,0.201001,-19.413078,20.960876,115.894645,129.046661,76.064922,34.360222,-46.088095,-41.586616,5.025619,59.320584,40.818367,24.210047,55.662874,122.077511,131.597002,126.47415,100.059777,88.395257,78.296081,54.107309,-51.564575,-83.730813,-23.77902,109.705282,140.779602,63.088874,3.881455,22.549351,100.854289,207.224847,38.261375,-71.73109,-91.804021,-16.988814,168.583246,247.154352,243.759416,163.535368,42.847811,15.458621,11.499843,70.515288,112.670291,98.965449,59.443713,-3.514433,-137.855602,-220.29828,-272.927407,-229.062549,-84.556545,-29.203883,15.491687,18.666009,-12.890365,-75.080738,-84.698632,-85.047086,-102.517858,-138.719484,-133.320508,-84.284704,-94.985604,-132.20894,-127.06703,-59.474995,87.035451,114.384346,68.372789,8.430958,-149.834103,-186.01467,-137.099579,-35.835927,-6.625189,-43.873942,-136.454955,-351.920559,-396.980812,-350.359988,-222.340794,-173.41056,-80.441079,-44.473996,-117.976129,-198.172437,-245.588444,-173.87419,-148.105874,-139.463298,-124.599071,-27.294854,23.271788,43.652896,-53.790477,-127.325138,-192.656981,-149.529427,-13.27837,3.148376,-131.67395,-226.615112,-328.615522,-318.736624,-307.026985,-324.647695,-331.70601,-284.485815,-245.339634,-202.717389,-246.410307,-262.562363,-179.824356,-101.587108,30.589737,60.872371,5.623157,-77.186352:28.662611,-40.990435,-0.193059,139.251486,213.465351,364.66955,406.985325,390.478958,300.845039,251.557944,255.591667,313.919213,394.018832,381.991767,287.364618,210.544624,15.29019,-72.741199,-22.208787,159.049483,212.481659,217.720979,214.76526,240.844994,170.283839,95.195652,47.141232,86.653612,155.618814,155.564382,138.863661,141.018627,108.154308,38.180959,46.603254,117.775975,141.976094,176.674796,208.708126,299.691015,292.150374,261.548169,271.604412,291.196042,265.70853,227.053491,155.24503,119.082384,-18.723257,-177.547533,-209.697547,-177.537236,-132.090152,-48.495184,-23.353635,19.72308,21.225005,37.909695,185.83563,255.047752,240.971181,188.148597,90.606967,43.803049,-69.574036,-67.451037,2.169918,151.896261,201.578795,207.486238,158.294099,74.316472,93.027372,125.941519,206.53025,215.591739,135.439647,103.389321,121.36652,118.850434,52.823352,40.314922,74.174771,170.591157,210.174503,260.962022,273.246855,253.711027,133.493335,58.43795,-26.525968,-21.63786,41.231837,53.090296,-24.028855,-76.674115,-97.228203,-10.834364,58.166968,206.888945,255.233258,278.834851,283.489563,317.886329,310.881107,277.697797,176.836543,117.886311,54.545816,50.901586,0.306791,-45.541542,-74.044441,-6.832937,49.956215,167.903733,195.573645,171.11356,142.074677,83.293338,29.967502,31.093614,75.395572,66.083441,-6.852771,-5.547806,95.667284,126.496299,30.273143,-107.989679,-140.552424,-146.218909,-110.758337,11.759786,38.285324,-85.785265,-283.698056,-312.575134,-212.539645,-149.443631,-95.830863,-87.950906,-54.279685,-24.4267,20.394566,22.079539,2.217663,-66.123128,-76.784903,-44.383656,-41.495987,-85.568068,-178.879863,-235.950118,-290.416915,-270.294192,-134.540678,-57.452217,-43.871864,-113.054712,-275.391378,-332.089831,-313.33873,-198.890792,-123.140042,-69.725178,-117.19787,-241.642145,-291.93344,-304.213418,-250.899022,-193.801599,-143.271107,-146.042249,-131.926041,-100.273867,-43.241083,-71.573154,-97.424557,-92.985463,-50.67734,12.586877,7.581389,-21.825887,-104.057482,-145.003085,-109.086692,-55.215732,-6.523888,-18.032062,-81.50451,-131.589195,-245.681211,-285.222751,-261.526723,-166.390006,-123.675123,-139.229774,-192.256667,-245.262202,-255.131444,-293.43638,-377.6164,-365.99625,-172.904978,-53.859349,17.77089,-27.840478,-120.550674,-63.277043,11.148514,135.676487,175.357163,245.266558,273.807851,276.523743,140.351186,76.597441,149.058912,256.246066,422.788693,431.329118,287.270199,186.38389,46.684565,25.374868,30.770347,4.73273,-13.885024,-14.353034,6.885396,65.149263,43.279098,20.146382,45.494583,77.678692,112.434754,97.126857,5.456998,-33.837239,-59.611731,-41.733804,-22.24526,-15.607055,-33.691266,-77.381135,-100.656432,-183.036713,-309.433863,-347.080088,-357.001104,-377.720521,-445.080213,-425.047979,-264.133756,-200.334044,-180.519151,-143.143725,-109.706953,-90.973649,-88.714995,-54.739087,-48.618845,-156.565717,-333.556952,-336.408996,-112.325469,33.602272,234.288627,273.078506,246.902921,223.777865,236.479823,260.644259,237.652724,130.133829,72.346159,16.414958,31.518093,84.581421,28.51699,-17.267396,5.598353,78.724672,216.713342,230.264131,160.384786,126.547936,124.070359,121.036483,89.21726,52.300113,73.06226,91.471846,80.34233,99.066093,130.111083,126.682086,77.502132,36.24234,-33.042737,-53.731488,-86.954848,-103.926287,-162.617901,-192.623603,-163.509928,-103.818617,-111.193309,-151.981395,-152.573232,-164.179926,-284.235095,-336.815545,-280.741024,-177.679053,42.425024,100.77566,65.503092,14.281805,-41.960885,-55.917621,-55.202353,-2.503052,28.228891,-47.551725,-139.301333,-221.220871,-213.382519,-231.814217,-249.307898,-230.709851,-113.626817,-6.02403,195.255028,232.128281,163.35455,14.747441,-45.551826,-95.802038,-77.733936,-1.017116,23.392458,22.588592,-40.646126,-94.280513,-138.39322,-88.288836,66.248262,94.949116,23.162507,-31.901897,-154.217073,-245.046366,-213.073845,-43.605721,11.642349,-33.229678,-105.407129,-257.153676,-368.801174,-370.022143,-286.247735,-253.83505,-192.448309,-149.24273,-154.646919,-207.564652,-238.174852,-115.176155,-55.803546,-21.456809,-27.78704,-6.155011,20.818499,47.968665,-38.017977,-83.030835,-15.80355,57.94177,73.419291,-3.355366,-165.778739,-185.500115,-181.739072,-255.859729,-291.830846,-299.540415,-265.731332,-180.261686,-158.667857,-138.158958,-141.736409,-144.738634,-87.956527,-38.86207,65.116093,86.844861,-20.11397,-111.064929:-38.766556,-29.193394,31.530552,197.700384,267.983871,338.537998,311.240864,194.673644,111.282413,64.830829,65.367935,145.024712,277.991894,268.494458,156.766669,77.879028,-116.627397,-164.019991,-74.740676,159.453987,225.587355,228.604837,206.606028,165.460393,62.309082,19.466486,15.129925,17.095213,-9.144199,-15.907934,16.140011,42.524838,33.427323,-14.336654,6.513897,127.199917,190.197216,267.709316,278.522516,225.500251,101.881323,66.651107,78.322142,100.568972,142.131805,145.174374,93.690301,57.25572,-22.267199,-172.262243,-236.902256,-228.794864,-182.42061,-111.972732,-89.388252,-24.067897,21.781994,33.916146,123.980825,183.128947,193.390747,139.9374,3.862044,-54.867516,-114.91467,-19.947901,65.584091,175.892915,181.183967,118.059406,67.345069,27.803476,74.018742,67.206624,16.997145,27.291628,69.381163,24.078533,-186.619035,-252.250864,-184.603988,-15.182399,52.586154,111.077383,113.745637,141.362123,161.781521,173.306114,153.851341,121.839233,24.646625,-12.493873,-46.565533,-74.22411,-179.80982,-217.22379,-179.29293,-9.514193,103.842817,237.886398,241.476584,255.711228,282.932362,294.102353,250.893049,249.873234,243.377109,185.785233,36.415003,11.546092,23.386198,16.505147,-13.895647,63.615886,137.19722,201.777644,191.222768,140.731806,92.956128,38.009617,51.341216,29.371179,-24.741952,-40.953864,-93.921386,-117.642839,-116.112741,-115.790956,-149.8077,-97.623644,-37.03325,32.093248,30.194318,12.02808,1.149478,-85.527848,-217.891575,-237.798895,-157.367081,-119.574389,-147.551779,-173.883444,-185.775711,-179.179332,-178.706348,-145.740938,-90.516351,-30.678269,-43.485583,-72.005602,-84.307129,-143.407654,-244.983748,-258.378613,-134.752551,-45.487424,56.881738,53.921339,-26.175158,-59.211897,-81.070167,-91.24478,-74.888199,-9.123553,15.652667,16.941706,-11.421641,-114.158528,-248.096125,-277.961494,-185.045225,-117.959817,-116.412564,-164.307937,-178.264709,-135.166791,-76.566841,-66.836546,-54.105487,-47.295769,-51.944083,-17.174413,9.629565,-33.472232,-127.726836,-101.932969,51.307956,105.282512,97.432207,30.030669,-182.733036,-262.975941,-304.488984,-268.720317,-231.427878,-144.780066,-123.15382,-169.570972,-217.3679,-254.91041,-212.379929,-213.004297,-211.460817,-154.128024,-11.895277,-1.420604,-71.018397,-87.883049,-57.343195,-31.331844,-21.307217,35.59292,70.732911,100.794985,103.301083,108.777311,113.318771,114.31953,131.56367,162.405567,286.811551,340.248934,318.072647,286.124683,290.201003,246.26615,195.587567,162.121003,187.866294,257.589235,278.486195,212.465233,60.490691,36.371579,106.388623,163.535207,259.443343,235.057618,1.276773,-91.024621,-55.566156,74.264561,111.277672,128.89099,131.268662,130.132164,97.91133,-70.909964,-259.327585,-300.899425,-241.339095,-164.924665,-14.492003,19.567631,-32.382315,-77.829493,-95.950891,4.620053,71.119519,114.710511,91.95865,34.546384,-6.676695,-125.013259,-198.348683,-180.144107,-26.886158,79.574147,274.866945,325.993077,263.999173,180.922283,64.080619,72.887973,82.78014,60.109414,59.865742,132.379591,167.577666,161.811156,29.197272,-46.924042,-45.431424,16.98969,126.825758,173.861949,243.354977,216.989962,33.537347,-18.825378,42.977248,143.649609,140.440045,74.283842,58.110825,110.303022,146.530489,137.913157,100.709617,83.058961,123.603018,181.265337,225.096827,184.231265,70.576694,43.976594,59.708599,57.960817,55.337241,104.26161,124.823464,108.769498,24.425645,-28.636105,-55.650146,4.344431,201.224572,256.832368,214.899756,154.654015,12.603177,-89.93277,-79.332224,38.216944,83.50782,48.095795,5.610035,20.641149,17.456043,-53.664691,-179.717064,-182.455881,-121.848244,-75.142754,46.228173,61.841313,-91.787065,-166.800517,-108.949238,-16.745575,-30.239973,-114.022618,-139.465946,-111.719895,-116.632635,-139.883543,-98.483091,-29.574911,91.577409,100.170401,-5.462699,-77.874248,-162.352519,-168.182352,-162.60378,-136.77049,-96.348881,-50.190806,-97.74989,-264.321281,-316.393767,-275.604495,-135.576707,-78.102364,-50.839277,-75.031565,-167.69538,-221.551994,-258.873264,-176.011549,-140.726575,-145.255931,-129.779513,2.926192,46.100452,-16.759765,-126.123247,-144.822705,-86.211202,-34.584079,7.384128,-26.461389,-150.895671,-186.494085,-216.799493,-276.095401,-271.778344,-196.634913,-178.483637,-228.319964,-251.151532,-209.550573,-239.656995,-291.802896,-220.590419,-104.434445,22.860068,-9.836356,-166.28868,-227.04451:right
252.767201,114.958631,57.185632,71.184966,113.808861,188.61951,219.461235,221.577108,126.081642,73.248262,15.02806,39.566582,177.334215,227.818304,226.717277,207.018939,168.544005,80.378508,31.583086,36.417065,78.392531,125.480299,123.73387,89.29594,52.275442,59.764839,135.704489,186.276751,237.128122,234.147358,252.809111,275.651128,258.48116,83.09696,-19.1526,-40.744187,37.17935,138.682328,114.91608,33.693506,19.491007,0.582632,-67.745493,-50.674485,104.617488,169.864363,190.209761,161.568466,134.901049,225.288095,255.478193,193.191575,129.340968,31.880551,-6.520843,-133.52831,-207.468681,-187.855282,-127.355532,-88.045337,35.350362,94.215338,127.454194,91.201993,-31.968622,-161.033118,-192.304832,-104.716182,-28.127759,37.24505,9.959125,-129.161815,-224.24156,-247.239985,-347.5382,-382.24133,-257.141247,-134.341181,17.493119,23.88937,36.499547,129.306443,133.657839,32.186168,-2.415348,47.239291,91.582657,110.205964,104.317966,83.770239,-57.299083,-121.362358,-102.09249,-29.889859,102.020715,103.323984,9.076085,-84.422694,-128.947457,-197.974343,-211.968363,-192.10258,-156.936139,-93.808853,-104.261678,-115.68702,-89.112916,-36.573185,76.585831,109.272447,137.081405,131.611351,136.055155,190.07513,187.592762,111.80448,74.332913,30.446172,14.920956,0.627942,28.934447,26.032379,-53.127642,-87.938107,-88.854437,-74.761303,-55.33071,-57.900451,-88.665505,-111.32561,-115.71644,-134.67799,-139.806533,-93.963084,-62.232698,-82.733015,-203.140121,-242.148206,-155.576632,-34.148103,210.692383,263.983747,217.936701,180.816164,209.870576,231.283442,173.206318,95.529585,137.437455,280.836102,333.73583,330.698018,172.879247,105.180938,96.623729,138.872981,237.457196,269.998427,274.214751,262.562086,264.197154,206.044085,151.018729,139.796055,192.269866,236.310933,155.475125,-93.958528,-99.782089,-46.002171,-33.56485,-50.643054,-35.708037,-10.490422,42.673562,37.830945,-73.531049,-170.368837,-179.31161,-147.805674,-105.346594,32.991304,90.602202,73.716439,-19.488335,-35.997488,-11.658478,16.050802,51.737311,50.168092,66.488213,96.617524,144.426473,67.356075,-2.765342,-69.534027,-57.93068,-9.587214,20.8055,43.729729,-66.560793,-139.054807,-214.457676,-197.502557,-89.354144,-32.291702,58.952622,90.336796,112.445751,111.661379,98.820542,94.408504,137.16979,291.377934,364.189669,391.851968,304.011419,268.480669,209.17467,179.145678,136.061188,143.172881,215.397807,248.599169,277.801368,201.194362,114.695568,8.821185,17.027194,84.215631,111.517399,79.664304,15.446403,9.785668,-18.380458,-39.035413,-30.902297,-21.350689,-59.065883,-103.649344,-200.150855,-261.786845,-274.39385,-240.675038,-186.841248,-37.937192,15.341908,-5.426126,-103.140235,-138.006614,-182.392549,-187.075901,-147.150572,-109.370827,-15.822637,30.944297,84.753672,28.879174,-35.538073,-105.901175,-65.375885,100.189252,168.485276,201.219704,66.80143,-25.152533,-99.94531,-65.706642,32.546697,60.441186,44.501289,-24.055119,-211.860704,-273.844578,-269.520914,-221.679858,-170.232969,-68.581867,-37.049589,-24.593143,-94.957539,-135.85635,-148.08219,-112.975615,-31.522294,-16.86288,-49.134001,-81.438301,-121.720183,-116.025925,-97.523518,-25.563477,-7.14968,-1.574601,11.886886,18.500266,-4.111035,-22.403096,-32.872961,7.904623,87.287403,78.323058,24.265092,-1.372553,-63.490916,-120.40858,-135.601035,-106.302124,-73.965296,-52.521346,-70.300819,-136.900334,-186.970367,-205.672482,-229.655189,-196.907299,-94.507597,-88.507772,-149.457984,-179.352597,-218.242173,-263.728181,-299.057101,-317.936671,-280.06658,-197.168818,-203.24357,-301.450995,-340.305255,-333.805908,-348.159386,-336.024285,-226.178769,-164.654035,-108.28201,-134.340921,-268.798088,-344.021896,-321.010914,-200.81662,-154.26357,-144.625361,-156.326477,-185.304999,-233.730041,-261.566871,-305.844611,-289.69184,-169.555283,-104.379839,-38.215387,-55.269739,-126.425343,-120.215635,-102.537692,-72.404034,-46.795267,65.220913,124.583848,158.008373,130.68288,100.747971,4.632543,-26.68942,-43.646019,-49.661275,-73.544043,-105.877437,-228.315013,-330.514006,-339.070863,-294.269317,-269.697809,-257.45596,-263.258895,-276.010319,-294.572967,-311.189249,-303.159534,-245.61793,-122.547548,-129.851679,-224.387108,-236.13957,-173.185569,-178.715501,-211.001018,-134.50277,-16.103078,155.38187,151.108962,56.786539,26.572946,30.659678,44.711189,67.919358,95.153947,63.79788,-24.175075,-27.031268:-7.748814,-89.066248,-106.553772,-28.203302,8.949097,15.926538,22.894808,28.572967,-29.922487,-59.704703,-68.15227,-36.263169,46.731138,67.299181,63.996171,58.177848,62.055409,-11.635503,-67.215737,-56.369485,12.497212,159.496649,191.39678,146.455938,53.964602,6.456924,-27.656174,18.8641,193.550177,280.234973,375.788931,350.73019,179.154763,79.18383,74.507095,61.013718,62.298446,155.825706,210.76479,175.845684,52.391777,5.136516,-71.906897,-61.470113,89.019853,150.497296,125.375381,97.718693,174.33676,234.553527,188.995936,104.397491,95.129317,27.696026,-50.419735,-180.32614,-169.523571,-151.005311,-136.739315,-112.066255,-5.89285,39.683461,42.134502,-5.179171,-158.496682,-278.040217,-259.301768,-62.810079,25.47423,28.132133,-18.823072,-82.551178,-185.557253,-271.743532,-385.835126,-369.548783,-228.215251,-138.091848,-0.710265,13.17917,-28.650006,-59.763312,-77.25158,-86.373852,-58.446295,-9.850103,-31.662894,-104.324803,-61.248305,-31.113694,-67.433246,-103.686348,-95.003632,-51.292979,15.730099,4.856967,-58.496918,-109.069208,-138.79059,-169.968181,-169.123409,-145.454734,-122.081329,-101.641268,-123.530803,-132.157887,-74.914503,-13.869457,38.188175,28.484409,53.634089,78.949233,75.56384,31.00113,-0.842632,-50.416275,-43.842416,3.188126,19.76206,25.579603,-26.848367,-92.881618,-191.972027,-160.456173,3.520484,61.457856,26.501388,-44.914317,-108.735586,-67.31899,-71.685569,-110.966324,-122.081005,-114.997974,-113.135953,-157.432825,-176.610271,-149.612528,-32.316107,60.65104,229.080208,261.190384,245.747446,233.212306,258.487072,274.705684,245.329052,197.120731,214.966503,337.201822,402.015748,417.71233,287.705104,213.716394,140.197202,157.240119,287.749803,372.900487,445.241627,407.884963,279.589351,116.396517,44.52257,66.76612,141.584851,232.180444,199.017482,15.546613,-73.833744,-73.551521,-74.533931,-62.967898,8.169307,62.345998,158.57763,165.969761,92.777004,-33.571655,-79.418482,-20.418298,79.134206,265.541247,294.293979,233.997892,141.829524,85.18314,30.832804,75.841854,200.078818,222.60631,201.061898,190.642521,174.688009,72.715573,11.911482,-32.515263,-33.528356,-70.320674,-91.191083,-124.371309,-190.569457,-223.563712,-235.351371,-197.869238,-16.583587,98.474558,253.336234,290.81845,310.342504,195.086593,130.811592,149.959126,224.999731,353.73978,362.124289,305.568334,260.951568,231.702575,168.88024,173.351067,230.530899,256.247686,288.204201,292.855209,277.239207,143.820926,46.774637,21.363529,92.395955,183.564632,159.975506,-3.006815,-128.790944,-126.660413,-90.936879,-77.290838,17.81801,90.272932,111.746432,35.219626,-147.377289,-250.562094,-262.912376,-165.430858,-81.405835,22.372508,29.245774,-12.271434,-100.847978,-141.949415,-160.394101,-131.236958,-42.065245,-3.288344,30.933829,22.46476,-9.333023,-38.379112,-64.270242,-84.103406,-37.352443,150.206579,221.733692,212.989989,101.541165,43.505769,-43.428504,-53.250445,-8.199719,34.492242,112.480646,109.68372,-44.76519,-261.054308,-291.287471,-141.693769,-36.221865,66.535378,67.021661,3.163898,-88.079913,-116.1191,-147.987001,-153.110163,-110.340567,-53.37969,48.924304,36.701805,-96.911701,-197.011483,-186.703358,-64.311375,-1.861628,85.588325,111.468561,61.415318,-71.225697,-124.187646,-159.890094,-106.128312,132.825877,231.397711,246.508531,203.597424,135.214175,30.15585,-21.85166,24.71297,89.43776,86.373612,22.043309,-77.892025,-112.668629,-133.068703,-146.480912,-118.123204,-69.414272,-92.027007,-166.185866,-167.583886,-160.687656,-264.12646,-297.179622,-241.853663,-213.910154,-248.306715,-273.460534,-268.339081,-258.234782,-276.375681,-299.808213,-261.810509,-120.539053,-77.993239,-128.807971,-192.729641,-261.568586,-282.958472,-306.58516,-304.100004,-265.366477,-188.382017,-187.028666,-252.115118,-260.498461,-247.161042,-241.22716,-213.527098,-110.076661,-84.244674,-105.918225,-126.770721,-140.800964,-138.871952,-145.002593,-112.218763,-62.053651,63.730481,117.450984,154.88255,100.589858,49.908675,-34.818037,-29.877873,60.228251,82.883404,13.725985,-46.212885,-169.258248,-314.193445,-374.986551,-378.234993,-314.897844,-180.339207,-167.899912,-254.068646,-324.915773,-328.125408,-277.021774,-210.965529,-46.132087,-5.441017,-44.289326,-83.624336,-136.83907,-172.792652,-175.888978,-83.341782,7.211762,153.928025,166.774297,76.237015,-14.738853,-25.122654,-9.783687,18.793424,94.552994,108.700193,60.996744,15.827827:35.303461,-80.514029,-128.786549,-97.763994,-32.454173,68.639244,77.777186,61.44984,-55.512871,-168.779969,-299.407907,-244.326388,-34.672456,9.125867,-58.75663,-80.867833,-33.423306,-134.777164,-228.183345,-231.895148,-147.631478,-6.572268,27.360962,62.235986,41.779592,-9.769986,-129.586199,-121.411377,54.853638,148.122488,225.114571,209.011281,116.312999,16.567346,-24.315851,-30.724913,4.683997,79.336456,108.707783,125.552405,29.946748,-46.914026,-112.159854,-56.890461,116.84002,147.331839,71.760629,45.625661,123.407453,186.647926,171.653494,157.447543,159.889145,93.839813,24.286489,-106.827541,-133.599051,-122.482107,-74.021763,-19.191042,78.795584,77.277187,8.129937,-38.832933,-173.282894,-300.03079,-293.292076,-124.71328,-38.051229,15.469133,-13.063821,-141.696478,-267.895841,-321.690933,-386.853161,-362.389905,-195.452209,-93.402324,21.357214,12.442858,-65.94687,-170.330459,-202.203033,-110.123014,-20.682987,36.529826,-9.927587,-117.221765,-170.127629,-197.318445,-228.730213,-229.152255,-246.633614,-246.433024,-190.378777,-167.994633,-148.753276,-115.052457,-121.527146,-167.061297,-184.629196,-187.201123,-173.497718,-166.371823,-147.97798,-135.630578,-113.777441,-78.939238,10.985911,33.963625,25.666164,26.834306,61.683723,-10.180605,-59.279067,-24.812347,30.129006,113.530138,141.211844,119.433082,-50.087986,-127.494982,-148.790209,-114.186446,-44.947751,-13.585039,24.526409,10.496384,-53.651287,-111.264243,-126.794402,-108.551075,-87.197515,-62.860323,-73.831293,-161.032222,-235.20325,-213.272298,-54.707884,44.178034,188.186104,229.743175,284.974594,301.36225,333.144723,327.725399,319.320227,393.384654,447.215772,461.203337,430.677861,348.4243,248.663477,200.969324,155.43781,177.841546,238.839989,234.701269,192.0416,182.034232,139.071073,15.725674,-21.682388,7.696858,30.930727,45.998081,42.911773,-6.234658,-73.603478,-102.235173,-98.752871,-36.674864,85.50491,79.571079,31.530408,46.835419,73.687343,-33.517659,-77.81978,-15.72412,69.655519,232.146981,278.330608,303.220123,243.016933,174.235173,111.176089,166.153248,286.604994,273.566266,165.299804,146.369408,194.426505,181.370724,154.033074,132.429582,128.710944,98.04117,64.568193,-3.933844,-22.640704,-40.59665,-87.774474,-64.160217,88.448492,170.112326,292.36698,334.011377,344.345832,283.286485,270.318229,287.668135,299.493007,344.798747,387.972247,433.384696,277.437404,142.113563,-33.246494,-15.396705,168.512423,259.10997,305.816005,271.094577,188.878184,108.813861,72.798914,50.487638,48.74312,18.982917,-9.518385,-94.658088,-149.384844,-159.541448,-154.717168,-110.741111,38.52835,94.775639,92.640845,42.100129,-90.296956,-262.086898,-308.161546,-177.547785,-58.089759,61.047306,49.998674,14.74363,46.167409,58.177962,35.692398,26.543008,58.901109,85.831831,115.269723,115.763865,87.984311,-3.858633,-48.041567,-34.572649,18.976605,152.819245,200.665083,207.805034,146.072725,87.967134,-44.122152,-70.506273,-1.094981,55.959354,44.559965,-32.541104,-163.482027,-223.651754,-254.411146,-197.919787,-91.221538,74.071807,65.982188,-54.257646,-118.841054,-113.383416,-100.230476,-110.957842,-116.02661,-86.671824,-50.939808,-85.688569,-192.172979,-237.112257,-222.519711,-89.809702,10.998345,174.668368,200.969714,134.344165,-10.219009,-64.754385,-47.736248,9.93942,115.308053,144.814058,180.438195,196.246265,169.070019,29.8597,-31.243663,-22.357565,37.896911,152.029495,175.212719,138.5353,10.22992,-69.601742,-151.782954,-125.275983,-21.271802,18.066151,47.716024,13.872232,-148.287745,-253.746811,-224.462923,-79.722123,-52.802702,-143.126417,-191.792525,-181.146922,-177.198084,-232.083717,-314.49126,-289.557277,-178.070054,-132.87218,-106.777215,-135.207544,-233.548928,-318.496319,-363.565266,-419.541088,-393.420369,-285.984771,-263.350627,-282.941804,-283.407006,-278.17057,-256.28805,-237.048293,-182.289463,-137.389555,-52.621902,-39.935104,-74.810119,-131.827558,-139.920393,-120.070458,-104.739248,-17.602632,43.344118,71.816051,-29.320303,-68.146945,-20.022494,55.132063,177.312307,185.279483,117.347559,77.845613,3.585641,-127.239403,-171.272532,-132.582085,-94.336045,-76.242649,-93.432683,-158.509777,-246.152874,-298.336344,-323.816552,-232.799031,51.603919,125.028097,76.933148,27.724345,-20.214016,-59.415774,-73.357954,-22.117491,41.733857,162.492242,179.285682,102.415154,-27.323125,-86.631637,-135.26237,-97.441748,23.010409,40.760201,-45.44845,-96.423259:229.185272,102.444721,31.462463,7.491479,54.166589,117.854049,113.030674,58.813581,-11.193243,-46.675062,-112.981752,-110.988345,-30.31248,1.630756,-22.857797,-63.103446,-133.241553,-193.823587,-213.912749,-151.110831,-80.443394,-5.706616,-14.030946,-51.626816,-79.798295,-80.32894,-22.002435,40.104138,173.429664,220.586122,255.664949,238.445985,158.200343,61.586289,10.48005,-81.778479,-112.372534,-114.875025,-94.498209,-47.576971,-14.802464,-34.547529,-76.030116,-33.142245,104.897373,135.141007,150.554125,161.007804,168.041899,155.700797,145.431687,121.456423,104.023164,67.4308,49.692247,-22.088434,-142.524778,-199.352936,-214.124405,-138.159334,89.867185,150.808062,85.644579,9.965287,-83.52491,-133.171884,-175.537676,-171.979394,-105.987617,-26.890935,-48.895646,-143.454071,-231.284731,-260.179186,-291.5366,-286.173211,-221.735997,-183.281076,-101.284759,-35.435346,96.700885,52.449998,-36.107471,-153.027287,-129.049697,16.594251,70.173926,47.11569,-55.252502,-120.224052,-243.616203,-254.972587,-194.927529,-165.257497,-114.770672,-98.437568,-111.217775,-181.742779,-225.794886,-250.778681,-219.755502,-144.827513,-128.089273,-113.261422,-134.949378,-172.068111,-169.505909,-95.223896,82.31059,138.744575,168.895913,147.316891,103.107243,121.269622,136.647819,179.740223,206.701546,232.876471,222.584059,156.60024,91.79164,77.650537,62.48842,58.076959,76.202632,116.287503,212.922702,213.003174,101.017739,-51.815128,-102.127729,-81.861943,-28.099809,73.728201,89.943168,10.054493,-115.367197,-129.144817,-22.212572,68.777291,208.264377,237.794135,262.814683,268.155162,281.089081,299.771109,292.896955,298.175987,318.583518,338.257692,331.33182,261.32062,139.227144,99.37611,100.950134,136.648943,200.606685,208.797935,236.286711,247.792538,181.580049,58.401724,18.7123,11.002368,38.601579,100.855006,92.102583,-13.062523,-34.420009,-7.746711,-7.213183,-14.872339,10.488937,22.288827,54.206854,89.266385,117.510811,-29.337589,-115.934549,-114.789987,-44.339527,83.462805,134.839578,236.36344,264.277802,221.786761,119.929107,129.780748,203.068261,189.608031,121.677545,146.778248,262.380533,186.391688,78.097283,-32.207378,1.644799,86.735557,86.649729,13.851689,-67.002313,-107.661117,-175.895738,-151.628634,35.681063,142.209094,302.463837,349.348645,335.12138,256.619294,265.803515,368.365922,397.702563,411.302769,437.248404,487.30725,438.782182,366.323391,200.289086,163.377986,217.178057,290.095267,412.648882,408.31281,343.668243,270.675703,185.593502,58.705089,81.521091,170.666976,160.564138,16.74687,-86.7271,-75.18137,-35.259321,-40.915288,-83.653712,-107.134318,-158.041839,-182.248435,-189.145014,-225.038732,-265.603441,-237.606197,-164.621893,-55.790282,-28.437703,17.335772,9.980588,-15.983062,-54.037598,-40.326665,36.25082,73.204427,134.520358,147.833455,110.98726,32.976093,-13.935497,-39.093789,6.785883,155.298592,225.327221,252.533837,110.099924,30.416453,-52.693108,-47.894141,-9.40781,-12.608319,-75.923978,-120.857373,-226.24416,-310.266832,-312.8355,-173.977944,-65.405004,20.212107,-7.082896,-62.139976,-98.358488,-125.858325,-170.729008,-160.297998,-58.726208,-6.137745,-11.679167,-75.489946,-216.549315,-257.295256,-226.918383,-90.32025,-32.866589,19.457993,54.376135,114.183907,-2.258435,-103.225403,-194.925195,-146.081093,18.620557,75.871266,104.695317,68.231324,-59.779089,-102.540771,-80.194594,-5.424441,28.317079,12.834839,-41.358841,-145.33941,-215.383091,-239.795907,-190.837027,-120.357937,-32.609088,-48.887244,-140.456358,-192.063248,-295.180704,-361.101538,-347.443074,-221.855965,-177.101651,-208.081182,-229.009758,-191.989023,-177.193399,-202.186642,-249.022553,-247.235377,-194.526081,-160.819348,-142.412926,-176.641192,-261.675606,-307.683713,-328.953829,-286.68872,-224.340945,-189.180803,-229.787203,-298.657812,-289.848826,-281.820796,-263.39518,-223.165865,-111.384808,-80.240095,-77.221416,-98.781932,-166.812311,-210.799028,-206.211077,-129.558331,-78.458933,-2.303015,24.21277,53.483159,29.528366,-1.698816,-38.079559,-9.341867,80.649224,90.932643,55.973173,22.223664,-90.513037,-193.467339,-208.768859,-163.300224,-133.168182,-115.756919,-113.867213,-129.025213,-207.93464,-247.047279,-263.369733,-228.796722,-102.152593,-53.699005,-80.581409,-148.316819,-287.533636,-338.675051,-313.137643,-168.473682,-97.596066,-38.192237,-26.016288,-6.893192,-70.615504,-125.839005,-193.115929,-187.580096,-121.929396,-98.628934,-101.955229,-93.511213:153.834085,20.211092,6.290053,92.597402,142.227399,158.378064,132.034288,50.041366,-64.650747,-142.439664,-256.517606,-250.797822,-163.217156,-129.107627,-118.65607,-130.121376,-182.358926,-315.186068,-368.250733,-316.55729,-227.482587,-59.910858,-6.525141,45.33772,18.07347,-32.374099,-106.191594,-62.903162,121.197458,194.089395,233.917479,208.292801,132.990145,56.349967,15.722551,-36.92187,-38.944245,-16.484446,-3.556235,-2.988707,-86.875801,-152.42618,-194.124141,-123.175424,119.162041,209.09203,235.112952,209.258962,195.148465,193.767746,175.550601,128.705355,121.830937,137.62241,119.43027,-0.400468,-113.905881,-161.908017,-171.40158,-86.30144,128.217314,162.641341,47.402612,-56.688013,-209.060371,-229.65048,-223.915579,-196.117829,-164.482205,-69.342264,-39.896437,-114.613177,-236.352208,-260.243157,-274.792354,-267.046208,-182.944974,-109.836703,16.414352,41.664327,30.960284,-13.300276,-31.589809,-45.215049,-47.472042,-42.083697,-26.232615,-13.133227,-88.108713,-138.362102,-200.704905,-224.560752,-291.400085,-301.351391,-221.6652,-175.711845,-197.682806,-307.173334,-326.648979,-293.879718,-271.144531,-227.670274,-212.606834,-223.887643,-219.350592,-187.474005,-108.604343,-75.48142,-30.948608,-0.49564,95.142798,122.69989,93.123707,28.092935,23.248343,94.848078,133.450821,167.286865,178.523831,156.87063,48.039129,7.497491,6.891518,40.183743,146.008129,188.006052,179.736888,152.325978,122.207058,32.808889,-40.193623,-113.246589,-90.536507,0.791396,20.889419,-34.83965,-180.157686,-254.261238,-234.292024,-108.4353,199.888913,295.555549,315.649597,277.656509,234.677243,221.208748,216.902663,280.206305,323.772482,351.699153,337.571478,240.596327,118.293781,90.564382,107.595094,128.055573,155.263275,172.430439,207.96155,198.118438,78.99275,-79.827417,-105.732978,-54.695203,-22.313107,52.35946,96.198141,83.193708,-77.525674,-144.891246,-129.94968,-67.611306,16.731781,30.441448,61.455121,86.124986,120.08138,19.999881,-41.177495,-27.014678,41.874947,202.784814,250.422859,281.660476,268.657054,224.318359,129.225874,122.773373,164.699089,177.150327,148.30612,129.352136,138.258077,71.908075,12.46882,25.436591,76.845064,90.190867,50.994266,-16.570911,-32.949664,-51.634966,-102.650333,-91.595101,26.288559,108.041577,263.107357,318.852486,327.360941,238.751764,220.383873,274.820371,316.194544,371.896149,391.252292,421.2193,359.398563,263.985069,89.898791,92.814343,247.514319,330.715885,393.61376,358.816643,215.654337,85.966103,46.71913,46.260499,73.399003,119.636131,117.06391,40.348154,-37.976674,-67.366991,-129.827657,-136.183013,-70.891902,-28.802624,-23.867015,-67.769498,-148.249792,-173.97327,-178.869335,-136.519932,-85.792004,49.552987,101.608463,77.128604,-13.728124,-17.318769,4.706565,4.823564,46.520137,108.554693,230.4334,243.149074,177.232895,64.80684,12.702374,-34.447494,2.994008,234.709155,350.815002,350.974452,132.944385,21.274984,-85.446248,-57.410105,74.926101,115.036472,35.389358,-52.21431,-170.361914,-269.805298,-309.48312,-187.492651,-51.152414,137.017792,161.729388,112.847718,-61.186364,-143.374384,-162.038302,-120.345494,-20.306222,29.885581,52.437231,-10.688294,-210.751529,-323.585722,-294.644428,-81.753177,32.225422,163.395188,186.282443,143.785544,-7.521128,-77.401981,-117.692873,-83.130545,47.099428,121.09293,228.569422,225.760511,110.520577,-1.333247,-18.820192,35.709522,87.502292,178.844775,191.839594,113.423345,-75.214253,-161.330864,-157.884141,-90.7604,-31.058022,-45.763364,-90.628623,-127.933731,-228.209125,-303.277156,-309.142075,-272.131291,-262.489807,-248.569605,-218.37975,-139.330438,-163.417265,-221.960555,-281.376481,-250.853028,-155.728177,-108.086249,-42.706212,-73.713182,-245.078067,-371.491531,-385.935581,-311.549188,-257.040836,-210.245543,-214.093835,-239.083276,-297.956474,-334.992643,-329.477752,-270.252228,-113.864138,-47.939405,2.972639,-22.316982,-115.207258,-183.354152,-183.766428,-107.406516,-72.99126,-39.025164,-11.600456,31.488782,-26.430933,-81.470624,-121.586356,-73.237057,100.226718,171.886129,159.817176,84.926751,-27.133541,-66.13384,-80.580887,-10.782558,56.263324,76.204488,31.118035,-24.076154,-79.526684,-152.473385,-230.00744,-168.96176,24.475801,77.182668,64.360969,21.777732,-77.498311,-131.610479,-131.286042,-39.806554,45.853621,171.588106,179.286803,123.026384,3.409014,-66.600757,-79.51262,-2.302348,136.759944,143.558572,110.22094,108.381339:341.374488,210.397531,133.601754,89.660612,145.381244,293.524029,337.699658,290.667637,90.898425,9.984224,-26.078269,6.582531,79.185523,95.219257,116.971301,122.451875,79.675762,-48.280566,-115.65614,-97.255635,-11.209711,95.339646,68.09252,-35.717278,-37.995392,-12.319387,26.382849,53.678128,130.921167,164.720104,195.991979,182.202579,138.571124,105.851832,50.503779,-109.968308,-152.632929,-121.030981,-87.696912,-79.22407,-124.24666,-153.203759,-167.813837,-113.231289,59.362894,132.738619,291.212174,348.728903,279.495875,146.126631,141.456975,169.191016,164.594319,149.323995,125.629041,8.078292,-77.958703,-78.733591,-21.063935,35.978923,177.109671,229.302351,237.18426,181.118754,8.51643,-73.977182,-80.397923,-56.252077,-17.413616,37.267719,17.287623,-66.403544,-86.484412,-81.907436,-97.383232,-109.309501,-151.509025,-165.383447,-87.322244,-15.89443,113.978017,174.88633,147.000908,20.266823,-25.554958,-2.579886,57.162554,133.102306,25.863275,-47.855709,-122.946288,-121.784683,-46.226237,23.324646,112.437694,72.92501,-91.151546,-223.93419,-302.168989,-329.158248,-247.832991,-128.199379,-123.369963,-126.314408,-173.275499,-217.653969,-205.755331,-112.25024,133.548181,233.786709,336.855152,317.790432,198.97274,171.260073,209.870259,307.582012,328.610002,271.378351,210.475077,129.09517,156.662767,170.433243,150.690648,137.864336,114.261783,99.073342,90.571049,97.654845,123.264022,97.405146,57.166827,67.651029,137.619948,229.406681,194.869066,31.931545,-96.93783,-134.842967,-132.447462,-58.774412,190.262148,291.349285,325.632453,286.591948,230.135135,198.489186,169.410985,148.836019,169.561964,214.292294,222.448456,163.150317,41.486901,22.15581,92.772859,157.536837,289.213521,321.066468,267.809989,207.012282,111.809217,86.42903,80.147902,52.781195,49.632745,74.39966,52.431369,-99.110242,-156.895199,-113.756377,-34.167114,-20.402918,11.81488,17.54668,-42.482837,-95.843848,-177.247187,-170.2061,-159.701122,-163.458008,-137.892421,24.557254,97.134294,119.265453,129.473734,146.194985,130.8732,103.86136,55.123999,48.630404,120.833939,180.733467,213.80447,108.58839,59.322183,39.734806,40.650477,41.307625,57.808863,68.015306,7.497023,-47.629067,-173.417543,-192.565224,-113.829767,-44.716807,115.82517,168.105044,127.832457,42.319322,46.172079,121.818287,154.4541,203.187617,253.530319,378.158223,367.210493,280.890871,66.222333,37.240001,153.138196,216.283508,255.862252,253.010514,253.039864,138.607614,37.570345,-65.259599,-44.370727,11.138074,-2.695853,-90.26288,-162.434917,-183.096352,-194.67051,-187.988378,-189.315573,-221.663246,-320.045514,-342.05532,-333.18784,-344.885269,-330.870317,-204.189949,-125.85859,4.04922,48.284225,36.045966,-46.249163,-81.678394,-143.526178,-132.488299,24.081697,114.756236,178.703728,151.972596,71.71772,15.990472,-18.147307,-20.402511,47.243143,219.737791,274.42848,260.960593,74.295703,-33.039452,-111.917132,-79.69054,-27.729066,-36.165469,-52.87385,-67.350881,-164.347495,-250.743778,-256.9805,-157.293113,-69.171211,26.386119,16.707646,-42.811841,-86.342624,-116.24819,-217.268205,-231.438478,-110.451828,-26.193382,24.76891,-43.110027,-236.312252,-230.672955,-172.481985,-92.480548,-71.965925,4.317132,56.744883,109.229469,26.246037,-57.587855,-134.409478,-100.564475,-39.589556,-40.897482,-32.706476,-34.964687,-117.456721,-203.131887,-207.554839,-129.270847,-78.787,-71.488766,-111.307269,-210.023852,-268.497665,-259.497546,-207.515548,-193.682179,-179.236084,-151.502746,-84.513408,-96.422403,-231.450632,-322.358453,-316.717425,-256.694984,-215.374059,-127.527989,-97.505894,-145.219581,-266.451823,-286.727706,-259.308447,-238.58162,-195.931078,-177.956284,-162.720403,-166.192559,-225.706392,-368.342599,-416.536718,-339.297349,-259.506203,-244.067552,-308.963742,-411.045635,-371.229946,-345.431352,-368.925427,-367.166746,-218.078512,-116.6761,-47.184227,-90.0374,-185.586615,-187.05977,-164.64249,-63.896675,0.872953,74.032304,83.241215,114.134215,150.651224,143.355862,66.046071,35.704634,71.342081,96.808145,56.472835,-3.919099,-120.317834,-130.359347,-87.004479,-10.981433,-34.709065,-127.882418,-118.18623,-22.483108,-82.359464,-173.097675,-265.725616,-222.612849,-82.946695,-65.015785,-146.910692,-196.177779,-265.920112,-310.105628,-300.638641,-183.662069,-104.052849,10.048451,44.515606,56.860882,-23.910689,-82.024521,-119.001153,-71.849312,46.446965,68.312309,28.637959,4.122846:307.10083,139.036529,65.095629,65.311551,111.076415,160.820273,170.428191,164.200809,16.787214,-83.717816,-162.324573,-124.564528,-32.62829,-15.294929,-15.663517,-37.88389,-144.576396,-273.164506,-311.978665,-269.082146,-197.268949,-79.130642,-59.757794,-67.620668,-83.599136,-93.930335,-75.709069,-19.784968,109.009377,148.441702,202.19277,205.978981,133.230934,-17.40449,-85.119294,-111.729182,-97.74539,-114.007707,-123.397669,-68.632152,-11.232009,-45.497815,-128.64342,-78.086394,166.904915,261.75988,311.146962,307.52217,339.898537,336.067269,278.692112,146.192401,128.460819,168.385999,159.18601,14.59107,-139.880061,-161.907345,-86.260447,3.243914,199.384371,252.489304,209.249561,124.97767,-85.252252,-245.49559,-265.517609,-166.33765,-88.542687,-0.412876,-18.119387,-138.34405,-181.490948,-168.685642,-197.020928,-225.15346,-182.262061,-100.54864,42.812005,47.896741,7.881135,28.054804,30.390129,12.122691,8.020975,45.421469,84.482657,66.701911,-138.342417,-243.621407,-302.059453,-234.651847,-50.716242,-5.844374,-29.204046,-82.655664,-221.639268,-339.039671,-376.711698,-365.255847,-323.629099,-210.359081,-146.079245,-107.495844,-221.519623,-259.321417,-170.992829,-64.998568,129.221122,199.559495,259.145235,228.871534,133.640763,136.621169,172.943313,257.0199,281.844443,272.244202,242.435269,155.895671,110.255938,113.75244,129.441894,137.72696,174.471631,211.277186,300.644758,320.868881,242.838227,56.98256,-6.643733,4.397892,54.930481,123.47098,104.697919,-25.642591,-171.910948,-219.375981,-192.338229,-87.576919,207.764851,308.017818,310.176358,248.481259,150.061932,88.880061,72.721899,141.250534,201.409831,279.289798,296.169037,251.735248,102.01974,32.172846,-12.19876,21.486758,144.75208,199.459652,218.064651,162.786799,-3.431648,-40.816551,-27.747154,-39.647369,-29.998198,104.926605,179.726898,154.910359,-37.434801,-101.909243,-98.371605,-56.144102,19.695886,40.208159,56.404412,45.317571,6.91337,-55.694591,-105.023171,-108.961627,-22.063056,210.042863,266.094722,225.09387,211.335082,231.987195,212.154644,182.019166,172.298272,183.243836,179.598304,159.556667,69.531108,-56.879873,-82.086048,-28.894264,0.542898,15.886704,19.142196,-0.683626,-91.566568,-153.739721,-206.509551,-153.296188,29.86049,95.076065,155.037026,165.196229,128.712633,49.596024,33.990365,94.528891,159.074358,312.440392,376.251571,402.696791,294.428197,209.936453,67.786283,53.11951,138.109319,197.167519,263.85744,260.456161,201.571145,74.330667,7.943401,-2.965227,39.976906,90.638958,74.269256,-39.138401,-176.375701,-209.05631,-186.701224,-163.284552,-169.202237,-187.357697,-210.597065,-227.51018,-280.662023,-320.161198,-319.992579,-228.49679,-140.578389,38.130495,96.187123,101.653019,-9.222312,-65.26364,-88.571187,-46.811328,94.006021,156.129014,191.200747,164.664984,84.948224,45.813651,40.463703,41.363246,67.552583,227.829977,318.959086,328.872831,109.064825,-3.176126,-80.27676,-55.213793,-16.399348,-16.693967,-17.737561,-36.931052,-149.01852,-281.957463,-305.32741,-188.86761,-69.251954,127.967659,162.167469,102.203258,-60.109,-142.847884,-192.208422,-127.231986,63.686863,109.482879,46.795203,-36.365934,-207.97581,-229.962919,-164.583879,0.73191,54.171658,129.397593,168.391935,165.79601,19.184155,-63.887308,-139.084528,-115.904212,-40.778938,-11.056119,56.177143,71.977891,15.97668,-100.764486,-140.822195,-79.447847,0.084428,72.883931,39.643067,-96.68903,-217.753936,-254.690048,-264.477388,-221.283395,-50.635117,31.177927,41.784798,-37.822848,-213.947645,-246.252251,-227.981602,-196.02543,-170.271752,-62.257725,-4.309389,-1.974342,-116.578224,-159.322773,-185.661828,-165.544809,-79.08298,-38.775865,8.210746,-6.441105,-173.454584,-373.480247,-394.600186,-285.473599,-234.496118,-248.517607,-279.558197,-310.49946,-304.448132,-305.493344,-305.284619,-273.164166,-157.728575,-110.76481,-88.25027,-108.739293,-170.147247,-253.72567,-287.960622,-244.067092,-173.0835,-29.024235,16.91056,-0.355804,-105.518667,-138.926008,-110.013398,-39.989923,145.744001,190.433088,121.080003,70.365014,40.154232,-35.148826,-76.615615,-8.129184,63.262747,127.525106,126.528549,99.912147,17.813814,-44.916726,-147.89482,-147.093916,-24.099601,54.31403,110.600658,59.852771,-135.627307,-233.759021,-189.876259,38.573797,139.365553,182.1945,157.207032,95.756831,28.477714,0.047709,-9.286579,15.804938,91.498193,122.300269,132.741056,106.317561:260.469785,126.952659,91.013455,132.925274,185.079672,213.103563,199.417341,223.518446,228.86953,183.817685,82.788375,88.330302,203.111206,243.180622,230.660306,202.409564,147.415377,126.804936,131.734586,140.497002,139.55707,160.463803,179.710259,178.451984,137.891278,129.915306,179.454919,247.66118,371.839077,385.217659,384.588887,389.239841,333.237225,168.201389,82.883032,-68.203462,-133.430188,-184.004196,-167.769416,-127.772847,-103.576655,-99.989385,-85.419312,-22.325222,230.739916,349.139576,463.46601,468.885542,429.575779,382.406862,376.983777,424.00723,431.083841,339.551781,267.934812,137.457656,102.674862,117.495576,126.393868,127.544444,215.462466,283.236566,320.985116,270.840604,146.978518,77.997236,36.729675,-26.570777,-25.625882,6.943146,8.807564,-13.856663,24.12394,45.273379,3.060632,-35.401318,-46.633156,-11.309537,101.426941,163.302368,303.180155,386.776677,354.671083,218.541522,164.549097,155.92185,217.695633,371.736674,361.488781,302.242843,169.229452,108.527053,36.311587,47.518055,141.091152,171.422678,111.292857,-71.15791,-161.217408,-219.161324,-195.238677,-127.328337,-92.067301,-52.608431,-69.164479,-76.586473,-58.746788,-33.606609,63.080156,138.7116,281.083301,302.913212,264.253773,280.750185,292.070467,226.584301,161.109703,9.070242,-50.101786,-56.20506,63.105361,128.599571,177.340538,155.500125,115.620961,113.98443,130.928771,156.353522,171.150539,62.112171,10.287968,29.450668,93.243032,152.272094,98.60956,-58.843729,-161.08443,-202.038144,-220.692099,-160.703788,32.927563,97.288544,132.749544,131.574547,113.220551,51.58122,-1.239179,-62.191607,-47.658304,-29.787518,-50.672238,-113.762553,-135.069125,-138.909767,-148.577417,-125.219363,3.981324,63.876475,43.166465,-25.739108,-128.853071,-64.972774,3.138535,81.050053,83.659049,13.729535,-60.64717,-168.713656,-145.254479,-136.740534,-177.218023,-195.534231,-213.613852,-227.198888,-205.232409,-157.725613,-84.480679,-128.047094,-168.862344,-155.067268,-92.204018,38.415044,86.690437,140.615357,67.950976,7.325556,-36.202611,-27.278007,-23.860348,-15.46563,28.571857,19.17319,-73.872031,-80.4084,-44.763918,3.443013,17.628396,59.258147,69.71978,10.976041,-96.817883,-138.729918,-209.19169,-211.678049,-132.424275,-86.778597,-4.30366,13.108622,-56.146479,-180.83757,-224.116743,-236.510772,-203.193154,-59.679726,42.884379,214.326278,161.462883,47.217317,-157.208756,-174.321481,-95.654076,-63.485241,-36.514963,-28.438393,-68.728427,-209.169086,-267.443409,-270.156669,-236.116962,-240.821573,-293.13596,-390.203117,-386.745668,-365.068947,-323.162497,-297.668957,-265.556371,-292.31648,-421.729176,-460.461971,-392.76406,-258.987594,-218.90131,-205.249295,-204.386028,-118.265898,-45.367783,7.307672,-90.642787,-151.310672,-236.324712,-222.980111,-70.62089,15.152909,96.308142,84.472657,30.470401,67.973294,103.785128,156.693549,206.965786,349.66037,401.921946,339.488531,3.963695,-149.897875,-197.164782,-129.053692,-34.501279,-38.233392,-68.322569,-77.88926,-102.016536,-111.353125,-106.751619,-73.971549,-66.270789,-133.938029,-175.922993,-175.826144,-133.946601,-137.10001,-194.242498,-221.158972,-255.575546,-270.800933,-287.820019,-298.769475,-333.55919,-291.136398,-226.175405,-101.900249,-79.578651,-137.320589,-185.812262,-208.701263,-137.652913,-109.485631,-91.092088,-80.733839,-51.80389,-50.420323,-77.874344,-97.634843,-108.80744,-86.310444,-93.766393,-101.20143,-77.421722,-33.347188,-29.173524,-76.780973,-159.04048,-174.490164,-142.419691,-102.312944,-5.77026,32.819933,40.09861,-0.433434,-108.21096,-199.099309,-222.852819,-190.857579,-159.335107,-91.175492,-64.213171,-116.46454,-202.643259,-216.171432,-231.462193,-225.539493,-192.376988,-186.031698,-203.496117,-224.1466,-233.678984,-227.170166,-267.932242,-358.546001,-354.796834,-312.887896,-317.710514,-358.781092,-387.767242,-392.040382,-379.013749,-352.350709,-235.507208,-168.823565,-125.053277,-143.634424,-140.042165,-54.326865,2.836643,125.638395,172.28153,196.0098,195.006152,276.098749,401.642605,394.359524,268.950154,227.976342,220.264265,212.380318,155.766706,131.473147,163.140489,188.010233,152.781249,119.471074,139.063525,177.982971,205.938233,251.284214,156.087723,96.475411,137.16141,225.97869,289.976586,225.016884,69.902214,18.814257,-34.695197,-5.354391,32.287148,127.760011,159.777715,177.384151,196.323344,261.227385,270.070452,246.027623,172.08385,152.239662,199.21805,251.808179,313.588865,292.246239:289.852817,160.161708,120.175954,155.553893,194.66084,252.957727,276.79285,289.391818,245.479904,212.314915,141.905178,127.364403,174.662108,214.8292,281.681588,301.389604,261.289495,131.980136,97.200089,162.997257,225.578003,293.275768,286.892389,195.337487,83.636016,66.254082,142.723235,219.32244,321.403899,320.892398,275.418176,250.56075,233.922617,193.889541,120.357794,-15.038615,-25.432524,3.656353,2.87759,-40.291044,-68.069278,-54.395214,-11.097631,18.708148,155.644311,238.033285,331.810711,341.698559,307.169293,241.011258,230.387085,284.57113,301.793011,186.128497,70.282889,-117.798502,-95.689785,-43.152532,28.043523,59.632702,142.789297,178.161209,189.613262,157.233103,73.634564,27.128197,0.481783,7.939676,63.276163,141.090517,116.189543,4.354782,-31.975156,-32.812055,-95.073285,-132.81856,-110.398871,-52.340186,74.444598,129.080085,257.650122,307.283152,241.046079,53.008345,19.434037,150.385442,270.042034,379.337633,234.621588,153.056422,109.345726,141.110197,196.244819,189.367987,143.766204,121.162502,55.501279,-94.451276,-178.775275,-208.671574,-155.348837,-47.145018,-7.03993,17.417166,-61.823328,-97.761463,-83.520807,-28.691387,91.314469,118.607445,148.416836,170.400095,214.632278,245.514555,240.794698,176.41994,127.558768,26.829044,-6.280192,-23.794031,-22.72248,-30.861078,-89.893497,-116.606694,-91.184152,-55.991379,13.878689,38.584588,-13.410537,-120.653564,-102.425007,55.783194,107.785909,56.259877,-6.32701,-115.462011,-205.281587,-220.969331,-125.987979,-19.692447,150.927004,146.100517,39.546503,18.984238,69.065015,61.321866,19.030245,-22.136354,-14.183534,38.272665,95.991825,196.807964,109.924619,27.173584,-50.042796,-17.401394,130.756032,186.383481,182.368913,138.509435,74.37208,120.079268,144.154522,135.510512,113.951551,55.715153,-5.542275,-175.893219,-193.921508,-146.236326,-86.153027,-76.122658,-49.994683,-40.665713,-50.606973,-90.18241,-234.108095,-282.840482,-252.989424,-167.445599,-122.350968,-23.73217,16.515709,18.684195,-27.291433,-41.170456,-51.540847,-43.347052,-29.668869,-35.90777,-45.257827,-32.424937,11.345922,7.495738,-3.78209,35.265505,73.912201,109.831349,98.469483,31.723564,-6.767786,-1.731711,-41.848383,-89.891079,-137.571515,-105.104664,53.941491,109.037153,15.822219,-156.933646,-172.463465,-110.283119,-84.609163,-29.331313,25.58876,155.554688,183.518982,136.125909,-31.19228,-94.394076,-94.48849,-55.225688,18.064518,36.10827,34.14755,-40.020407,-95.089966,-154.484915,-146.70208,-97.745807,-99.960125,-224.106855,-307.694805,-283.349995,-220.184748,-214.503384,-246.31229,-260.064378,-251.376256,-256.459771,-289.332201,-244.07906,-232.476713,-290.006377,-297.474929,-181.805911,-113.469952,-95.647087,-166.766111,-211.383246,-318.232796,-336.503841,-233.170544,-139.146317,37.969657,87.974446,97.83848,22.204976,-24.391521,6.332825,90.597513,255.128939,294.048269,217.184837,-30.072827,-123.498051,-149.340312,-126.620836,-102.033548,-78.978359,-20.747965,-40.205971,-137.059682,-124.833026,-107.005985,-115.424396,-119.626324,-75.953689,-22.614987,22.860778,-144.466228,-237.733134,-302.804478,-268.323761,-100.555942,-23.617917,-17.224548,-74.877919,-173.654195,-179.13138,-168.261034,-139.494209,-132.499125,-131.670136,-124.766071,-93.451812,-50.076003,-44.663861,-46.082608,-19.458757,35.43993,28.120409,-7.533627,-23.70939,-60.271041,-69.907899,-82.751826,-130.451354,-158.480724,-202.226577,-187.854801,-135.110667,-151.660897,-168.284349,-209.239349,-229.645209,-187.246523,-123.76214,-45.300147,-65.090824,-151.258494,-174.55949,-177.580227,-206.044181,-200.525172,-109.202346,-73.920935,-153.933895,-299.242568,-329.241371,-292.149547,-229.447023,-90.356461,-53.257535,-61.283731,-93.041574,-161.939332,-188.617319,-191.262166,-183.816306,-180.825976,-188.036757,-186.512126,-193.177778,-228.909471,-248.200706,-280.316145,-273.83694,-203.975003,-169.206932,-130.116231,-118.485391,-97.029551,-56.051175,-25.298131,65.566695,139.236334,282.791634,290.565784,217.379161,255.664388,271.851554,156.312758,90.216071,101.567758,129.496151,44.027047,-56.980675,-187.686295,-154.493551,-151.356702,-219.933381,-246.662792,-237.27848,-210.739564,-166.113353,-105.751754,-52.861172,-1.322884,-10.680994,-35.371813,-60.645989,-126.781267,-139.570946,-147.697414,-192.576882,-183.228331,-30.54834,41.688186,63.854978,75.687873,130.859466,130.012463,126.369819,126.263471,138.803931,172.442345,170.460956,148.731002,152.354856:246.449199,179.534951,147.089581,104.249884,123.879635,213.890108,257.793509,280.404025,174.30609,114.823797,62.550424,70.9871,116.361609,141.239046,166.220739,138.062668,13.099619,-106.577195,-144.128133,-154.108335,-123.996151,-43.622611,-26.48612,-21.931864,-11.300373,-10.566721,34.345871,87.558726,167.99787,166.053037,124.241179,107.351179,84.836734,47.335621,-10.46421,-202.192825,-275.71018,-255.460183,-180.302997,-60.522245,-59.588716,-93.190396,-174.663403,-145.614028,87.66877,203.577908,347.811667,403.655922,449.946399,339.003809,285.120022,318.546972,352.746473,284.062177,209.22744,130.699132,137.237791,117.244047,62.62271,92.074623,231.841762,271.218216,282.700252,282.392264,212.540254,-23.251112,-143.57813,-175.948969,-94.851913,19.332532,-0.68889,-83.29878,-31.414748,7.777239,-30.039988,-74.460756,-93.064962,-61.293534,72.46912,149.178897,232.894969,213.934477,183.859406,128.471247,96.984309,44.721275,54.23678,93.389883,51.399282,22.349652,-6.076993,5.074244,41.109751,36.61642,7.505649,-3.946296,-55.388244,-183.095758,-258.148648,-297.513733,-247.71707,-146.378528,-130.917505,-144.126726,-174.88967,-186.378827,-153.830966,-78.921829,125.759926,180.108787,175.587445,159.039394,154.614101,172.378567,161.762333,161.803189,169.312312,151.457501,154.940416,164.670378,144.439657,162.236665,221.459178,235.165166,223.88057,215.575006,215.817439,213.54811,189.29392,137.489196,103.238108,30.452798,12.207256,58.877601,97.887446,73.701448,-97.795784,-184.194286,-236.521691,-168.012669,86.176569,181.952816,221.041624,224.366057,275.756225,215.321592,120.694792,-18.733381,-15.906368,49.954424,65.847838,1.242115,-90.646191,-71.240489,29.412238,48.371863,50.984912,65.684928,70.958349,39.580504,5.214343,60.124167,54.998867,-30.248451,-41.138596,29.398434,41.39816,-37.603118,-95.198137,-126.541823,-233.604448,-249.300711,-175.721594,-149.344814,-135.347234,-124.806094,-118.990162,-77.282874,-46.31111,1.96129,40.664108,109.030589,121.473699,144.889197,174.047057,176.043681,124.371629,83.647154,62.46305,105.229152,210.335843,217.944375,166.044757,102.971782,53.925396,-3.263394,15.381387,50.972556,42.87516,-20.616093,-111.320721,-143.743294,-138.151409,-92.009014,-7.552976,-0.2308,17.821234,32.905371,-15.574266,-94.560605,-99.092028,-59.160394,-31.970027,54.113906,121.404829,220.563124,125.887664,26.385487,-86.561753,-54.961561,98.217689,155.785518,162.049653,138.88142,130.186966,15.481336,-106.997523,-185.505198,-106.19809,-27.288647,-105.057158,-314.651743,-344.674987,-317.384228,-294.696149,-283.8491,-236.47097,-217.50229,-241.520108,-285.10846,-315.98769,-263.414767,-254.594694,-207.743104,-147.169584,-33.694033,-8.366626,-39.231461,-120.566061,-139.893024,-85.922518,-23.67862,49.255164,55.075503,101.152074,118.794526,77.510108,59.500686,51.779705,29.421686,67.525492,225.174175,263.048867,136.155031,-93.084241,-165.074914,-205.71322,-180.5388,-105.355534,-99.781131,-157.161357,-185.529529,-193.658616,-219.88057,-245.695842,-181.142622,-92.605687,2.833391,1.011396,1.803876,-49.851701,-115.312377,-235.98175,-239.913748,-116.233765,-55.881221,-80.66625,-149.032157,-279.317082,-277.800152,-228.477963,-105.431014,-62.988685,-42.183467,-32.754588,12.121711,-41.660766,-104.817992,-120.940748,-61.830242,13.071521,19.102884,59.581814,48.758903,-108.925882,-208.458773,-183.942843,-42.046514,32.492849,44.501009,-20.425878,-118.442968,-79.031449,-75.389909,-170.716492,-202.241293,-126.500342,-64.80834,-19.776245,-42.948171,-100.167896,-123.237416,-149.875049,-152.052788,-106.585586,-4.205988,25.046829,-43.967407,-188.48103,-194.286973,-118.820717,-114.942202,-161.587542,-127.175114,32.705155,39.051841,-165.384022,-317.504221,-317.118382,-262.001096,-232.121065,-191.765832,-194.569451,-274.904102,-340.102176,-328.118218,-292.255177,-274.096329,-208.52492,-185.624071,-160.024902,-129.997357,-89.202897,-111.135123,-107.933798,-67.41298,-29.542445,81.974121,132.222207,192.525831,244.289578,241.761376,124.862331,71.864803,126.74421,187.665787,204.358906,166.369588,115.907787,125.181008,121.267431,103.908162,104.019773,128.643498,155.698818,158.335333,26.603413,-19.808471,21.175121,60.771896,27.632202,-23.093215,-26.038108,-1.832806,-47.405582,-63.641827,-3.636785,126.439206,131.271502,56.813068,65.947336,222.461497,288.404438,227.834123,63.229247,36.087423,83.24925,123.02396,192.456744,192.474847:right
-96.687004,-35.420148,-47.007999,-113.469189,-101.14762,-17.812234,16.428685,54.194525,104.938475,154.595159,205.666419,173.952866,94.867148,95.009243,177.802866,229.10681,279.592028,260.621048,219.065367,131.358302,103.998596,12.016302,-35.988554,4.07101,114.947209,128.29632,71.98883,22.380702,-74.384678,-109.044588,-86.785339,-24.017483,67.821143,-3.249518,-68.271215,-101.207978,-57.954275,-24.786711,-66.709998,-142.759575,-123.684249,-104.617427,-123.984302,-166.682543,-231.03601,-238.956036,-214.757488,-180.695392,-105.912266,-27.599009,17.564745,94.120255,97.008792,42.267213,43.859377,117.692051,87.840344,36.369104,-36.774208,-17.173565,148.809144,217.502603,253.155664,272.217363,347.202896,434.684566,454.765042,334.842478,214.691125,20.379593,-10.178673,18.921218,24.130067,21.525726,25.920326,34.010381,76.145663,80.193912,-39.603859,-125.103555,-118.151557,74.044193,136.354853,133.478632,74.123453,-134.907693,-220.042363,-204.054268,-70.714416,-43.045477,-22.675741,-3.312555,-77.937245,-189.491472,-322.699247,-278.94095,-101.217234,-44.852788,-65.067409,-84.134173,-71.222228,-54.922505,-43.334363,22.979756,96.871426,131.054377,141.042108,96.830459,-29.097557,-82.193746,-66.79032,25.398665,217.040432,237.692757,204.233916,90.417881,23.975151,-36.530889,-7.594381,92.432736,87.434253,66.508611,123.541684,180.049088,141.224295,21.574416,-171.570383,-179.35939,-129.101287,-113.184885,-134.698048,-197.402548,-211.621242,-206.920426,-162.329238,65.489878,161.666309,66.257094,-112.310472,-85.63563,39.163544,40.940839,-35.127674,-57.29929,-21.502271,84.843861,120.903344,154.531527,149.823744,44.193032,-16.160914,12.984799,144.964288,166.087985,112.681728,70.55668,-23.388495,-92.851589,-240.111132,-259.268353,-117.841171,67.429762,74.938511,-82.730217,-189.529954,-338.318739,-343.995136,-262.288078,-265.619011,-273.770331,-217.509603,-191.802952,-175.28753,-178.313404,-208.575821,-215.599735,-163.21433,-61.329222,-36.547166,-52.370717,-80.292253,-136.457607,-143.685437,-110.857605,-77.266262,-80.69047,-143.63145,-202.316913,-382.405103,-486.504526,-553.907203,-499.873294,-377.155595,-296.831384,-250.548253,-184.958993,-204.748355,-348.842572,-387.440137,-273.325503,-144.115564,-127.359733,-129.532991,-120.235127,-151.49943,-242.633002,-430.594604,-453.672898,-439.73549,-433.484906,-420.947347,-405.991008,-410.196864,-390.956634,-360.345191,-304.8128,-326.955037,-358.892001,-380.430453,-362.832403,-351.901574,-388.775628,-436.14208,-401.819323,-324.450394,-350.104779,-365.83888,-362.832749,-386.089576,-491.702834,-509.149438,-419.570856,-315.890894,-296.008813,-267.416051,-227.011513,-150.467313,-164.934086,-231.22623,-223.96946,-180.376351,-170.12955,-183.660676,-288.501722,-352.818975,-415.132992,-395.707652,-296.561606,-229.815106,-174.986874,-27.550412,-24.398992,-159.740108,-205.772679,-201.641376,-197.68914,-188.816844,-147.887349,-167.160976,-246.46272,-233.930081,-120.217906,-80.241165,-46.120885,-17.402386,-26.992616,-96.909147,-120.484795,-57.186964,9.180788,109.405465,126.067332,127.572676,172.90838,176.157829,75.777289,17.252545,-15.912323,0.472848,46.184357,154.261768,220.240419,254.930214,244.504954,242.08583,221.816007,153.606463,139.91417,130.407412,59.758282,19.091267,41.041243,92.188696,177.902387,212.810113,277.768827,310.433797,314.812336,301.197012,285.414153,217.897853,147.941885,26.008806,40.799344,165.261651,202.477001,167.732799,50.238468,-19.434476,-129.562678,-110.046634,97.094857,281.549321,314.602918,305.787176,287.158218,241.682886,208.215882,137.981084,132.50948,192.760775,196.628257,121.694977,-119.945789,-209.276085,-224.762164,-180.559088,-152.398123,-206.947469,-199.024095,-134.516665,-111.598958,-84.642049,-74.006984,31.693872,150.061685,326.005568,287.665854,249.52983,198.791666,191.034707,203.199183,221.624103,285.567766,285.951776,257.86925,191.75256,136.225272,-18.756789,-89.184578,-123.184379,-52.51062,219.061333,445.634289,477.393947,409.58584,361.995617,344.836339,376.843815,441.940632,475.919359,465.82762,348.973256,273.162507,179.322532,143.776034,53.8706,29.177643,59.052781,169.290658,228.859259,228.908148,144.092737,-70.866339,-115.241721,-21.289319,134.461125,175.737838,175.644155,155.363359,108.771816,84.456266,54.857558,64.47167,129.833084,161.049049,132.689901,78.106429,86.338255,91.075962,88.596983,163.99198,260.651793,302.616855,356.998323,333.47158,207.724267,155.163924,162.438803,195.533292:-47.474658,-29.915849,-62.357275,-141.386148,-149.557911,-76.290423,-30.674089,12.696462,112.095114,183.905808,212.788265,166.784588,81.365731,68.089124,82.926753,96.544095,155.846557,193.341881,161.254912,86.314766,54.242312,-41.622321,-75.534568,-70.967595,-79.633367,-88.414095,-57.166957,-31.03846,-33.192337,-62.210424,-75.983623,-40.853976,44.893015,61.50009,28.645863,-57.237702,-76.846974,-68.739101,-52.390966,-15.101715,-7.795932,-29.321025,-163.245879,-264.144275,-359.975255,-331.040108,-260.88395,-234.025626,-99.322365,35.061472,40.042266,31.552392,18.469472,-79.763468,-93.395888,46.304714,139.044314,101.160651,-74.294282,-136.678855,-96.635759,-50.098614,-6.213621,40.221892,212.884325,314.483164,318.35795,223.446345,125.475,-59.872971,-86.87927,-15.314424,65.585648,89.95294,92.206112,75.220361,22.440851,-18.187983,-137.559885,-185.508389,-122.918273,40.806605,80.899092,57.392182,10.574753,-118.396423,-180.872315,-193.170805,-66.527846,-41.27086,-70.198121,-80.898207,-159.095238,-230.3076,-264.6932,-211.954558,-86.6909,-25.521166,-2.921119,44.356557,36.98761,-13.392575,6.098638,170.016953,291.751366,287.539088,162.41158,55.502084,-133.325995,-161.975019,-76.256867,-8.784741,93.559101,190.104604,224.207586,124.785775,8.435297,-97.120012,-42.280449,118.284107,181.875497,186.036822,139.017484,95.167437,-0.877647,-46.860913,-85.626578,-80.356495,-72.533963,-87.11792,-99.206964,-134.819271,-174.008548,-280.820819,-272.9409,-15.911816,163.778705,72.937577,-194.613664,-217.514526,-137.032541,-147.609256,-238.320417,-224.737784,-41.81841,114.920469,121.583039,23.242909,-65.826745,-224.17594,-227.099063,-73.450341,30.161015,7.230889,-103.200656,-139.551877,-154.300194,-162.637698,-187.680869,-169.314856,-27.903916,129.968273,154.830572,34.812228,-98.462184,-360.785991,-415.486801,-395.795767,-422.208231,-427.277858,-316.551123,-248.238563,-212.662518,-247.833537,-314.831265,-294.376926,-151.966322,-57.715235,-75.733383,-118.604986,-126.230371,-189.347219,-222.179628,-226.751919,-212.101073,-213.032752,-236.120715,-274.246757,-440.944581,-526.443796,-511.747139,-430.514898,-325.489203,-318.372117,-310.488304,-265.228941,-263.209096,-363.852618,-415.905323,-379.279364,-292.648058,-265.810553,-164.251937,-91.781413,-87.12146,-196.166397,-422.416392,-462.42811,-428.708072,-325.275204,-279.067082,-293.917752,-351.376837,-423.548901,-403.421522,-312.786326,-308.468334,-344.557031,-360.160579,-319.532449,-237.893539,-236.966991,-270.765172,-268.713624,-236.474615,-227.731121,-249.378084,-342.833967,-392.158744,-429.876499,-415.610874,-394.96594,-369.282745,-332.178096,-285.629725,-307.843328,-373.966276,-369.396522,-249.297537,-166.380802,-106.099636,-114.167524,-96.961364,-156.050582,-253.425445,-367.894809,-334.850779,-247.497197,-234.890441,-212.708117,-122.865582,-91.354178,-95.49386,-119.374342,-163.2324,-167.710109,-99.317041,15.241888,-2.982307,-214.079989,-306.810123,-291.37317,-200.197721,4.819547,42.918544,-22.37944,-175.182158,-192.745178,-124.562453,-78.3641,68.940261,167.383215,294.562088,216.275258,115.387382,-71.627659,-111.176887,-84.496728,-49.519249,36.776171,204.809147,286.16808,319.188434,294.96808,219.263852,171.606622,142.730061,167.727081,217.653166,191.740228,171.881383,174.856619,177.216515,213.106096,260.137576,318.00846,303.334122,308.824796,355.807246,362.315457,298.421701,256.188213,247.297222,281.614105,317.92122,251.951186,217.475038,187.193442,174.999532,113.608654,108.440462,244.761327,364.553807,352.845876,270.609462,246.638838,236.119935,217.839512,144.773298,124.934133,169.358115,208.506047,168.182972,-17.952941,-111.073935,-180.627056,-152.575801,-76.950469,-64.052974,-78.118947,-81.948232,-44.449341,-8.370948,-44.972464,-21.270815,87.25866,274.543383,265.191576,225.63,109.899586,61.348768,75.732497,132.61288,227.639938,217.368177,211.026613,215.456185,181.816267,40.89253,-23.61201,-26.75889,53.082728,284.420092,424.063077,427.282914,380.339292,369.854728,383.24305,393.028177,394.23125,407.461772,430.677696,429.681017,373.37432,177.542003,93.167623,61.967829,87.467092,117.189478,164.006859,210.151246,238.910965,171.446384,-43.417085,-96.96474,-17.834945,141.995668,206.390793,257.081983,230.490082,100.365487,48.51665,26.443208,20.982109,34.305537,132.174237,161.869533,144.41961,121.121884,38.034395,15.126506,137.219595,298.874159,306.909839,246.552533,232.907953,204.140413,162.668732,150.378642,205.143403:-190.900197,-80.772423,-30.187686,-50.41396,-104.680968,-150.769057,-112.988036,24.08527,152.477485,184.576517,148.332844,94.015064,-47.768114,-107.839539,-108.33688,-49.132153,114.486416,115.175955,7.755411,-158.263823,-159.972988,-166.302344,-185.805075,-165.355387,-133.064535,-115.761282,-35.579357,0.826636,0.878542,-18.921906,-27.309405,-10.017939,34.426605,68.598589,73.800189,67.583101,53.976432,-35.686345,-79.855068,-37.666371,51.766508,27.356245,-114.381329,-178.430762,-229.74805,-216.545192,-173.388168,-157.549268,-104.077439,-83.516329,-97.545807,-91.065761,-98.546622,-179.706567,-182.050642,-53.813755,6.679471,-8.402794,-62.149101,-111.448426,-178.84813,-143.992002,-30.176594,-3.289587,97.186175,281.243432,326.883574,257.545661,164.394751,24.87858,18.260169,27.25074,50.006666,82.090179,55.268013,-4.675118,-122.145137,-157.337954,-147.356637,-122.160175,-73.799939,-17.911482,2.81032,8.389901,-9.120025,-56.86476,-66.766838,-36.277563,30.88637,47.270776,3.302646,-47.726738,-158.42804,-191.092186,-160.796793,-111.741512,0.247456,91.370027,105.737336,94.383156,94.830295,143.455479,208.982346,355.400818,340.041932,286.738969,163.082694,82.467048,-121.903357,-198.074543,-142.691893,-38.972988,120.593554,178.041193,178.986971,133.224664,95.430489,-5.915218,-42.480858,3.614559,152.295285,191.151638,174.99496,156.929047,106.035854,81.266855,88.06816,96.396514,70.015013,50.015378,49.521558,-15.111787,-101.850373,-233.995963,-208.417415,-28.004582,90.969678,52.878534,-98.164193,-130.150167,-149.421307,-182.550174,-239.742942,-196.776927,14.605938,153.936526,170.677484,95.167463,8.973961,-126.87762,-137.494008,-105.818981,-72.701349,-51.869989,-33.888326,-60.171604,-164.15614,-191.241327,-115.485662,-42.953297,112.721622,268.804685,301.632631,159.567247,-1.247297,-257.514228,-261.65151,-169.246138,-263.642273,-313.906722,-257.070931,-213.365434,-245.12852,-297.359764,-328.1575,-277.678563,-103.981208,-22.214478,-67.61773,-190.783798,-215.837853,-259.84574,-284.869098,-239.257576,-127.819024,-115.971546,-187.184889,-245.45913,-406.159512,-483.67439,-499.229466,-455.702914,-382.975307,-351.442262,-342.587859,-278.530943,-236.195469,-283.656048,-358.846654,-350.451485,-192.465609,-168.401913,-188.334208,-192.499022,-238.14794,-281.757643,-305.925309,-286.860341,-247.740161,-174.491704,-148.214354,-218.940373,-296.539525,-387.736629,-374.549181,-299.24741,-286.645643,-312.986165,-345.706185,-336.395044,-329.353063,-343.482246,-354.785709,-340.717046,-254.099988,-133.307929,-138.179681,-324.754658,-437.390305,-510.335222,-446.306066,-281.648042,-303.874163,-359.987202,-395.240532,-370.115072,-337.613017,-333.271843,-265.313042,-209.708354,-147.24764,-124.850998,-125.1418,-194.445741,-241.733585,-309.347517,-330.111345,-302.297595,-174.203725,-116.029358,-96.730371,-125.806116,-158.257504,-141.888025,-87.833197,-74.20422,-44.976258,-6.539178,-51.255443,-262.374811,-334.641238,-286.433368,-180.975581,16.157898,5.979215,-46.165764,-187.367091,-243.775675,-210.853625,-146.93988,-12.915837,80.112352,321.398612,378.039231,292.699136,88.984774,48.708381,84.095895,110.721997,129.515309,224.240882,298.005253,312.912647,261.123117,212.672992,223.662213,233.794645,248.977231,362.573072,391.171497,315.924274,145.34723,115.187434,173.696219,216.950034,256.921521,357.774209,410.019893,381.721896,338.633514,308.221378,310.397522,358.022469,404.492541,431.428631,319.229435,261.305594,200.185007,177.697605,134.103102,142.692415,246.415581,333.393631,307.58526,162.377562,112.43328,56.767781,18.762159,-13.14293,11.547383,88.786644,152.450535,144.314996,-25.072724,-156.234637,-257.106158,-172.133969,36.054946,80.293328,76.921937,33.17116,-13.898716,-134.606146,-167.697031,-58.279958,58.719843,262.251253,312.020826,271.656141,125.217036,49.413374,4.4656,66.47971,223.213361,199.331667,137.17158,48.203653,20.569316,-36.772912,-60.078153,-28.121175,54.764471,270.800421,360.467656,336.312835,254.854017,241.537595,283.906075,301.630988,244.722878,217.806278,248.733009,220.516819,129.050042,-64.323407,-99.994885,-59.047168,-21.065715,48.274923,54.639623,62.549798,95.701211,56.572727,-74.481485,-79.384046,6.343005,73.330967,107.272214,157.546633,137.127097,2.970355,-49.38313,-13.587575,38.449399,100.782919,113.820947,114.514209,117.080951,103.517343,3.229114,-34.490868,83.916859,285.282989,296.071709,207.103343,167.07999,79.871085,46.243061,100.784086,160.80936:-134.224246,-92.016443,-56.014833,-53.286068,-67.173697,-54.681376,-21.953738,48.10325,128.625055,189.347579,235.987687,199.58422,87.608207,33.203733,-34.21369,-17.77872,106.652396,107.986351,34.292195,-22.654534,20.668797,38.739506,-19.067882,-122.562585,-124.291144,-98.777307,-26.081727,4.058263,-11.156155,-52.769362,-71.811917,-26.38582,32.945408,-16.445294,-39.628496,-53.542644,-55.588826,-87.834569,-110.09754,-78.87401,19.00101,15.471622,-133.761078,-215.479002,-281.776563,-281.015709,-245.362161,-212.5028,-135.023667,-73.868019,-49.954698,7.850222,5.28232,-113.071328,-148.072695,-26.875084,107.869824,100.659669,-17.293006,-73.530529,-45.032736,25.286253,120.157533,134.94462,215.92595,375.175415,421.169066,376.518844,295.023731,87.668848,12.757791,-17.772186,68.187873,109.959881,110.423851,88.07579,34.123375,-16.83998,-148.664814,-181.934645,-106.48114,33.855234,66.541335,67.4174,50.338661,-35.54751,-84.912747,-89.185744,18.792209,66.216425,93.859958,70.374939,-68.677045,-149.870464,-158.184001,-87.083257,39.463792,94.083673,109.640739,128.046285,133.484627,117.257881,100.979406,132.962056,262.670258,302.286759,211.749185,98.536449,-105.836367,-141.551938,-52.270603,26.400873,161.337269,210.479402,174.005693,62.685082,21.138174,-30.731656,-22.243008,88.895982,265.775325,320.975031,284.87785,223.765068,91.911359,36.144793,12.155307,23.211382,9.093803,-34.993512,-66.587856,-115.156792,-131.276116,-175.695959,-182.503515,-97.280038,-0.969819,-8.700363,-56.383409,-40.38735,10.621932,-13.20631,-83.998896,-68.450474,23.046333,93.888939,117.783341,124.724246,93.38469,-23.520424,-55.794784,-0.750816,85.777994,119.889191,148.885212,117.548399,-23.490141,-94.217591,-141.273773,-104.164124,31.988958,109.290909,94.83611,-8.216319,-87.919685,-258.645841,-281.606784,-194.151786,-224.084591,-266.836865,-226.849102,-177.394843,-153.804649,-183.655268,-250.558777,-249.64468,-147.6957,-19.351898,-1.377648,-28.619696,-62.656278,-179.410272,-222.097785,-171.011243,-35.206833,-31.380491,-181.831088,-263.372701,-358.124268,-379.474231,-346.362624,-312.101766,-276.633584,-201.053111,-156.3222,-139.214999,-175.671261,-282.946791,-288.76932,-171.994861,-132.075968,-145.542416,-126.307733,-112.047027,-164.393644,-216.289522,-264.365253,-271.505958,-320.48425,-308.551618,-270.8751,-259.29175,-295.432019,-363.191701,-364.603328,-303.838641,-267.131282,-282.163294,-299.590851,-286.916073,-320.440229,-385.458712,-468.867953,-450.410953,-353.064598,-245.699606,-226.077828,-313.412144,-400.441988,-526.165211,-513.653032,-388.204534,-319.933981,-329.648251,-347.049635,-321.791524,-255.173031,-240.910536,-197.207165,-165.682701,-181.836041,-233.934776,-245.929184,-284.182788,-306.138464,-344.573515,-364.022486,-354.602909,-224.534498,-141.826522,-62.190797,-77.283243,-153.048029,-201.024068,-272.500107,-258.287294,-141.092583,-57.713176,-64.44391,-155.259808,-198.743658,-197.93324,-153.436155,-33.834501,14.374401,-11.853513,-93.239452,-95.875914,-14.06544,24.690868,94.92884,140.164062,213.56845,229.403149,185.407687,22.973658,-34.76548,-36.330175,-2.273348,81.789689,228.436485,303.829533,309.944459,263.634802,219.91001,215.37114,205.273368,216.160542,266.5636,241.625606,180.785403,97.834949,119.042683,225.392324,272.049661,328.199459,381.713273,404.926191,373.318233,333.859523,306.161695,306.210326,268.405255,256.793688,332.178396,418.082883,380.352619,194.834124,112.076066,36.971517,73.587665,270.917458,394.215907,369.119981,193.120217,106.065474,43.126757,50.837528,57.129567,37.704052,-1.964644,33.412898,19.907055,-140.361498,-227.153547,-250.462315,-180.355345,-42.967044,-11.842117,-1.085287,-25.590558,-75.212521,-191.732133,-224.996245,-121.535514,6.063956,210.330773,267.165461,254.734809,121.567974,18.816973,-115.202862,-93.036821,97.141642,207.202157,181.726095,70.340971,29.097497,-15.742144,-55.369463,-118.022263,-61.003931,190.66924,329.419484,334.270096,335.508191,344.286847,300.982276,243.173595,165.369809,239.358982,287.413547,268.687016,210.812807,80.620946,30.735654,-8.612145,-5.818962,9.365951,58.088208,93.895913,72.956363,-9.503905,-186.721991,-201.872616,-70.1978,42.543739,50.047302,40.586522,27.824672,-24.007957,-34.308419,-3.164302,8.633654,20.99838,84.934026,103.94596,63.753242,28.364499,-28.132349,-19.965317,118.352336,259.356974,287.971758,286.77716,246.713421,87.362485,2.712329,-38.504501,25.347155:-194.35177,-81.523289,-44.51014,-72.311724,-125.690629,-205.282037,-174.364194,7.016727,152.339905,180.831895,174.852641,135.428418,-47.83933,-147.326693,-207.718194,-178.969617,-90.640376,-13.643329,-14.840395,-100.959547,-148.163843,-203.500881,-216.842755,-220.485786,-183.075977,-157.954622,-139.602458,-141.10687,-141.155736,-149.359065,-157.161557,-129.496795,-23.426257,46.729212,30.945253,-72.642296,-131.252808,-215.310791,-206.520234,-69.212793,49.939915,54.748088,-26.401235,-89.724259,-222.046399,-261.078692,-230.905786,-188.375868,-113.702759,-89.496531,-97.452744,-115.322669,-143.70691,-246.420061,-262.023819,-179.459343,-96.713484,-74.098487,-56.438004,-63.527291,-86.594581,-82.44921,-32.414454,19.066375,210.833656,334.101072,309.456436,178.960275,100.27689,-8.998858,-13.896686,-21.43873,-7.680524,42.218899,57.986286,-14.166828,-177.455109,-211.107531,-194.950387,-182.94157,-139.800041,-28.408299,13.45185,1.819216,-41.876737,-104.332665,-91.982543,-30.145719,37.39931,74.631321,40.412628,-45.060378,-223.046516,-263.956267,-182.980441,-81.380093,83.241105,111.689697,96.474024,49.61127,21.96646,2.630674,36.379066,153.853284,227.811918,231.97748,120.780016,9.768035,-212.024487,-277.732932,-260.841056,-194.958599,-23.012375,100.177959,103.78486,43.753073,8.260118,-62.218146,-77.105635,-17.126192,159.28497,250.526351,260.994469,164.50807,-69.694081,-120.568155,-31.620809,41.194279,91.050866,23.781881,-20.197638,-131.193522,-221.143209,-345.392764,-318.760078,-176.846771,-115.16177,-137.823439,-209.782142,-220.836018,-216.344738,-215.515574,-168.623367,-106.280008,18.752314,56.103151,44.438422,-33.811307,-76.204456,-114.681641,-114.016257,-77.105089,-20.695524,-8.383572,-46.016548,-83.257201,-141.051811,-154.108511,-135.196227,-101.350818,-10.600262,101.49768,135.736227,63.201266,-26.339536,-147.139463,-139.891655,-90.992278,-137.241988,-166.06209,-164.465486,-165.796611,-271.711128,-341.372026,-352.256933,-289.975914,-100.723497,8.297442,-31.6473,-176.021285,-219.812583,-261.551626,-267.453481,-217.797245,-121.535591,-105.79049,-157.524171,-199.398234,-335.60032,-409.644643,-399.3703,-330.064953,-229.810995,-188.039346,-172.400593,-172.619904,-196.182527,-277.706337,-303.917425,-242.243886,-85.737539,-25.447549,-20.343866,-74.431056,-200.122669,-235.917421,-226.724279,-197.330413,-155.739459,-163.755878,-174.363952,-201.912845,-224.845282,-258.322119,-263.804565,-254.161666,-145.875092,-80.336465,-70.756346,-127.851354,-268.675511,-321.929053,-348.125638,-304.815273,-131.953655,-45.87416,-79.889784,-233.960919,-321.819516,-418.488929,-392.312518,-296.909611,-298.546192,-302.584707,-266.763108,-262.226142,-309.532797,-307.398767,-148.352445,-49.988485,16.528394,26.008462,25.114202,-73.107601,-146.118083,-203.510509,-181.014706,-115.671557,-46.62066,-7.000202,47.494121,51.851879,6.48862,-37.052402,-65.329293,-19.869827,97.556755,95.26689,37.065386,-85.886994,-96.421388,-34.897531,3.907092,87.245827,152.810499,150.309085,58.543894,12.559873,33.170622,89.09641,231.368966,296.185915,381.971748,407.119876,385.690573,242.594346,136.206861,36.295781,93.157515,302.977461,428.128518,437.572634,390.088581,368.834044,360.558445,344.800834,282.731139,274.639838,341.339933,379.723559,336.421403,191.33882,150.649828,198.839829,266.887051,401.489215,469.667436,466.767465,421.422598,417.706679,405.602289,364.238607,338.3582,384.644637,447.796899,415.517072,387.344114,280.958208,199.416639,65.600012,67.907978,211.562203,357.735216,364.244982,214.132925,109.220191,-40.836607,-84.0141,-131.582228,-142.403737,-89.803359,38.016988,29.399122,-147.760451,-232.501724,-277.78146,-231.260992,-61.8448,66.590623,76.518844,-26.12949,-93.182303,-182.068023,-200.414839,-122.927982,-33.605352,165.79043,254.076101,198.832471,-15.265231,-98.43429,-141.362521,-111.722887,14.607556,164.118991,184.274456,90.394922,23.910821,-76.767536,-114.520392,-137.478611,-106.252709,31.495417,197.473455,230.994332,146.192867,67.555172,-22.684214,-24.930806,10.420598,133.403135,198.59728,184.644214,107.603747,-42.847948,-73.976449,-74.652407,-80.957305,-76.14734,-15.221869,-2.819684,-54.275366,-114.778534,-180.79763,-140.678578,-42.268501,0.926944,57.293069,150.689685,123.591145,-15.233625,-62.625147,-50.521312,0.717189,121.739136,165.396691,147.771,83.595413,41.891739,-62.660813,-80.689252,44.71949,249.410772,298.089875,232.172029,143.54926,-38.121581,-81.583326,2.47809,93.370162:-118.335445,-91.730859,-69.063064,-71.35003,-79.630483,-95.427286,-88.98297,-29.001391,18.700513,36.878586,48.216259,33.810071,-20.458529,-41.928579,45.200676,145.623211,246.847442,175.631365,147.40131,155.823768,141.998964,5.779414,-55.410706,-44.307217,16.36155,22.194294,-35.971957,-85.42063,-132.617197,-111.484255,-27.75638,-2.257121,-44.754515,-138.384766,-160.646187,-107.856615,-55.247133,-44.669748,-94.66296,-163.341594,-89.799021,-48.842491,-93.69355,-159.613388,-226.755471,-222.486247,-195.592872,-163.143049,-79.084623,-99.132519,-131.221581,-92.10996,-49.922207,-52.23472,-64.922191,-56.285339,-68.90058,-70.215565,-53.349952,-33.778069,63.705242,112.583427,144.195417,161.799284,249.729099,340.051854,356.279449,294.779028,220.857968,19.658765,-62.758996,-110.163996,-63.777374,-37.773192,-18.648557,-10.09577,26.370084,32.577035,-14.43675,-40.891908,19.505537,139.167506,144.6663,98.19254,94.729266,63.57363,26.874895,57.725663,165.821132,179.982989,175.794184,162.635762,-12.304031,-137.31233,-144.913662,-43.592876,43.725266,-10.06128,-24.760374,-107.172691,-169.955332,-214.418614,-174.302302,-15.167281,90.173853,90.875414,-0.442701,-68.763263,-177.137129,-194.150496,-109.509333,-24.870017,127.635747,127.233059,34.319827,-177.876917,-219.32669,-209.459692,-187.577797,-102.119219,33.949204,92.797853,106.596061,78.17103,23.625451,-16.477065,-102.868696,-115.34358,-89.737565,-91.687728,-135.514385,-235.314389,-243.751604,-203.677025,-173.721789,-84.441943,-2.031888,3.018345,-4.180445,22.800177,66.070486,39.413718,-53.117293,-79.016348,-75.369901,-14.130261,30.287129,112.970382,125.563892,95.987321,101.536803,202.537011,273.703421,266.477852,206.245931,141.838027,-44.632624,-112.928417,-149.898009,-137.079459,-77.879789,-70.15602,-113.222863,-238.082045,-282.709946,-299.901608,-270.692504,-182.85418,-178.985202,-183.336691,-111.796145,-63.389585,-31.025751,-57.307806,-130.683656,-130.05476,-29.176024,58.488828,39.944691,-51.381478,-74.050163,-93.819343,-103.921483,-70.003196,39.856016,69.391203,-14.261558,-81.424169,-155.01153,-189.442556,-266.239947,-275.563853,-226.633418,-114.99263,-63.723933,-74.905043,-129.751842,-232.078946,-222.653355,-33.184961,95.143873,76.165311,-17.42656,-46.392547,-80.445798,-121.275216,-199.97421,-197.548417,-168.31965,-198.190046,-228.894786,-235.362908,-185.322932,-94.320508,-95.315357,-98.246763,-66.109533,-80.187551,-129.907796,-144.051719,-238.075928,-332.005042,-426.488333,-370.858948,-205.158038,-175.759473,-181.662086,-182.789523,-233.652567,-423.840677,-442.928279,-270.785177,-148.281772,-131.886409,-87.417128,-58.263481,-31.441151,-34.981286,-19.327221,1.216116,32.499694,75.399288,66.433802,-79.146032,-150.600959,-151.334706,-118.407511,-119.480981,-159.12106,-117.296707,58.796298,98.768809,35.920483,-5.060785,-41.502333,-58.708318,-96.479541,-34.080109,15.895217,52.530106,50.220572,50.977172,58.845514,130.568563,207.864115,202.291201,167.373617,187.414972,291.303712,317.615727,275.015083,249.160689,248.149934,257.384052,240.098803,154.090102,111.132657,90.969346,128.582498,251.949084,320.108064,323.341756,280.777796,260.434955,271.277471,277.357826,249.517799,238.70782,216.171669,98.027676,40.12865,89.249677,183.726563,318.412639,332.022879,333.343951,324.890529,316.28857,294.425386,276.12672,180.069055,95.138557,-28.225386,-16.711634,110.374084,234.000106,235.086658,72.605457,-33.05208,-103.464968,-38.657317,181.229331,278.051959,246.637127,129.573569,88.516935,20.790576,-21.361966,-84.179717,-101.598575,-99.822118,-48.607992,-65.599563,-199.238579,-264.688976,-341.63783,-334.907233,-237.136612,-180.903836,-183.223479,-208.962051,-201.312749,-109.308991,-69.981947,-28.911267,19.980954,174.246102,205.770273,145.344867,20.142107,9.869786,32.673171,36.118164,50.020777,52.631093,33.42414,-55.058751,-107.336644,-156.833692,-164.661664,-197.725344,-171.298948,53.98155,221.882776,208.351532,122.999946,100.724772,90.327647,85.872871,61.652151,80.222924,106.865785,103.83251,71.909275,0.101756,-28.090423,-76.862265,-101.614955,-119.559548,-57.717764,-16.484093,12.33961,-22.640004,-139.625939,-145.775757,-45.032493,-36.395562,-65.066922,-91.528126,-91.828288,-75.512966,-65.707761,-77.227546,-73.11096,5.720528,49.110564,18.135751,-63.867251,-69.872149,-32.092455,1.361159,117.660807,229.937004,246.85195,177.149685,114.922323,15.272457,-7.508229,50.387955,122.296343:-102.828489,-88.843404,-95.248281,-134.750326,-153.539985,-177.177787,-162.541925,-45.359138,104.34858,143.430557,94.510214,27.551253,-120.107923,-178.18533,-156.739193,-72.751607,110.915113,175.126514,148.105119,27.905257,-28.979738,-83.144553,-79.001975,-27.432637,11.434953,-6.592138,-118.204886,-177.789857,-217.230495,-184.094961,-81.51931,-48.748707,-32.382216,-32.035741,-36.09923,-72.260598,-96.238476,-147.339175,-173.916435,-173.509439,-80.033073,-31.540863,-16.412407,-58.520262,-209.121621,-276.008954,-259.289925,-188.573068,-91.075675,-153.183393,-183.692736,-112.583921,-79.417274,-166.921575,-212.325579,-126.315418,-20.244285,-31.58506,-123.098181,-159.640162,-126.043627,-75.403762,5.295232,43.51791,182.772551,308.58249,295.324995,161.490138,84.703345,-83.381365,-161.481828,-194.281921,-19.345053,66.234614,64.962649,15.247519,-54.095269,-83.930992,-116.840196,-87.2706,41.354708,141.247059,152.029512,119.86246,92.806451,18.083258,-4.854301,47.234177,170.550882,206.837921,150.391367,61.169391,-159.672662,-235.108761,-216.095142,-145.553422,11.907707,84.488014,55.206694,-65.094303,-97.110533,-73.703687,-49.651151,8.596212,106.788372,133.946285,48.648397,-39.923133,-182.794976,-216.362512,-166.429947,-85.618165,95.920008,173.09047,134.440724,-32.595249,-104.330097,-162.150443,-141.439765,-5.206205,185.210021,248.646229,191.452501,91.665367,-92.400772,-142.859115,-101.249552,-36.468091,3.07938,-60.48496,-79.695442,-112.332638,-165.900505,-296.614233,-313.190775,-248.14637,-151.192208,-93.884839,1.402837,11.157602,-68.888398,-134.326973,-188.257547,-156.597936,-60.133855,35.057544,76.482206,80.716277,35.777174,-65.071321,-58.840242,75.348828,141.397868,132.20579,95.53507,66.398962,-42.093078,-111.28516,-167.607757,-143.029365,-69.747971,37.274642,80.875426,49.510704,-18.650608,-150.217745,-154.74884,-58.831171,-41.205199,-55.079235,-33.694188,-36.540883,-159.216929,-232.088291,-254.996421,-213.955797,-75.863133,72.797803,75.987399,-40.128894,-102.076217,-196.855106,-211.193317,-116.469383,32.384662,69.17516,42.398731,-11.137793,-183.633646,-278.883181,-345.374198,-299.082432,-145.639739,-21.248578,3.489716,-20.223149,-66.279827,-191.049642,-195.542378,-14.322707,122.617265,111.445236,22.893571,-25.024212,-120.04047,-156.236174,-152.562658,-133.946785,-139.363068,-156.621056,-155.93844,-178.592261,-218.315588,-286.788571,-277.521452,-174.290277,-34.882351,10.539011,5.954357,-41.305826,-213.030611,-317.600747,-410.649667,-341.830528,-87.852154,-16.566895,-78.884633,-222.051289,-262.760241,-331.372734,-342.241082,-252.909287,-138.14896,-135.720983,-189.418034,-172.677024,-108.325241,-116.314527,-74.409238,16.500353,160.71566,114.53175,62.778975,-17.130021,-52.729773,-106.254753,-94.186951,6.704747,74.096425,85.14474,62.138691,12.084736,-74.876542,-80.671903,-57.620426,-28.88614,74.129485,137.313282,120.791548,34.352006,-12.015142,-57.133479,-21.522944,142.249073,225.404762,210.47224,153.210374,149.751149,185.495756,186.285859,189.111584,222.26317,308.718076,390.850696,414.097585,311.397302,195.67972,59.566973,90.962307,233.408757,306.69882,318.969932,319.945776,307.878953,247.928618,209.75109,190.921553,210.467174,218.901487,135.075359,92.353079,100.073154,130.696453,161.761548,180.868526,280.456738,428.14389,471.48062,391.370303,296.449026,162.012363,144.229307,185.435555,226.868108,278.483345,275.937079,250.506391,147.478138,95.785891,33.283888,49.790429,219.863333,343.366378,303.523904,90.276416,-20.135264,-178.606107,-219.677818,-235.85351,-237.764832,-236.819177,-156.491524,-127.945219,-221.04155,-310.422411,-393.734978,-340.032897,-120.857423,21.737627,37.576309,-46.805343,-124.029485,-261.139277,-297.773395,-210.997073,-94.597887,95.885283,103.951136,60.308298,-44.46792,-108.664517,-252.271605,-267.484801,-102.582299,86.067392,106.397892,14.561443,-60.595901,-190.363265,-227.873103,-201.286769,-131.856975,31.94389,131.942908,160.630472,136.969478,66.520048,-100.485113,-131.564326,-35.026132,110.026423,118.474534,20.632465,-24.79119,-87.552481,-127.770695,-201.83257,-230.48706,-240.71171,-95.172081,-3.209667,24.01917,-51.430875,-206.181259,-213.397434,-95.131032,48.337107,95.592858,59.691308,-13.041579,-94.594102,-85.322877,-51.931374,-26.703911,64.69991,112.596381,82.486223,6.00182,6.092756,34.173697,45.448927,137.922028,314.589163,362.031284,267.85997,161.06226,-24.151417,-80.024238,-56.201193,36.926054:-122.960951,-138.555067,-94.874241,21.27801,48.552155,-15.640202,-58.99945,-43.933193,-8.391286,-2.340091,21.396887,26.398628,22.071522,27.794165,63.381879,93.348429,203.209825,247.088177,198.109278,142.87918,165.585175,135.902687,75.691584,9.145776,-3.325781,-20.951234,-64.428824,-82.124346,-61.805535,-8.411188,89.425885,82.879411,30.497989,50.985793,71.155898,162.590078,225.448566,191.433218,70.683649,-135.664649,-123.466309,-83.31051,-42.295722,-60.226715,-124.337525,-141.001559,-107.862144,-67.558088,-42.927088,-142.713752,-187.65316,-164.995974,-144.421009,-227.49281,-281.673297,-263.640447,-230.903251,-252.702711,-245.094555,-180.587942,-28.716433,1.212512,9.792697,41.668347,151.347248,221.708255,223.787496,170.234016,118.677931,-44.825938,-116.632764,-147.675627,-122.21893,-84.568935,48.703813,96.204395,71.439706,17.245006,-23.434254,33.889483,233.357009,355.950337,367.711946,369.832779,382.9732,389.85915,380.435175,367.71083,341.516187,336.289431,304.54659,253.032893,116.971328,60.412947,20.522875,19.578415,-30.231857,-98.12604,-110.485803,-125.743439,-140.927341,-159.349408,-147.182341,-67.910936,-20.185014,-52.377296,-167.574713,-191.337818,-139.571486,-105.642378,-67.099297,-35.19421,64.910281,78.91406,30.364282,-103.935857,-142.663428,-141.805696,-126.033899,-82.815315,-40.580373,-35.908847,-41.171573,-42.882799,-86.00097,-122.344912,-142.243015,-122.783614,-101.996246,-125.958845,-151.432469,-212.370719,-213.615135,-155.682936,-140.538274,-139.331451,-98.797133,-70.437131,-1.960796,30.025733,46.436413,28.202243,-3.825491,2.445812,1.378626,-76.525639,-92.523934,-42.908575,-22.70131,-8.75508,32.171643,193.450945,255.312116,240.90577,242.371689,243.976886,153.819234,68.901417,-71.535887,-95.186715,-104.550553,-160.103888,-200.256228,-256.141875,-261.938263,-246.146429,-215.196068,-118.135087,-60.841689,-15.278905,146.182796,227.676396,321.616716,302.237702,160.06733,101.278737,87.954431,166.129205,182.087845,127.346452,82.70089,-12.137503,-35.147284,28.310954,123.861302,117.785205,-14.255047,-77.688825,-73.709377,-47.388803,-78.965983,-115.682956,-148.498033,-151.167755,-139.196019,-53.624643,-1.491558,22.475219,6.750278,32.814175,86.426823,86.47109,71.928367,74.428454,60.815362,32.658002,1.097549,6.993849,-43.573969,-165.768575,-169.72183,-24.053416,63.734775,121.490042,92.605196,19.035629,-20.156093,-34.906282,-57.619492,-62.055685,-115.983987,-190.902583,-338.449779,-340.01644,-218.579787,-132.455193,-129.578753,-156.143986,-172.745676,-209.329961,-215.753153,-185.009345,-105.283538,-50.22906,-3.962819,-29.818132,-44.070849,-4.768413,78.635598,99.881343,87.438885,46.235228,31.232296,25.33496,42.109676,85.718673,93.328458,47.886699,-71.71629,-86.031852,23.136024,51.362281,-40.159932,-89.446729,-74.168234,-27.314595,66.647132,75.153267,42.938259,-4.971622,13.125493,125.437342,180.370172,229.277391,199.737815,159.036158,95.232843,110.742951,226.633248,266.051451,216.239779,153.630316,35.423519,-15.507487,-26.547572,-54.074502,-59.669596,-48.607256,-24.790833,64.220658,102.259046,76.285569,29.47217,62.960456,212.524546,254.056256,185.588202,108.059246,-45.265611,-116.596943,-102.657708,-22.479807,19.023734,80.937091,108.702398,169.463322,168.439281,143.02251,59.09556,5.970911,-88.137621,-122.266199,-142.839798,-121.907346,-7.770853,94.206242,50.811812,-160.684034,-219.937779,-185.031682,-126.321984,-7.019197,24.210216,20.972761,6.357526,-19.598991,-84.052557,-98.891914,-125.783963,-154.178348,-217.080969,-257.218883,-266.412004,-287.245756,-287.57971,-246.479844,-218.818348,-170.67822,-147.365863,-146.283893,-157.909612,-145.142631,-43.565449,1.968358,20.578899,20.923223,41.600554,48.290999,40.018041,66.319331,109.884468,147.724444,119.373459,75.432549,76.479301,39.606961,-114.216269,-173.897368,-185.638713,-187.695343,-244.142446,-242.608489,-138.682271,-53.167865,-33.153013,28.942902,71.902697,74.161704,19.991021,-67.458445,-25.777189,10.098277,35.648316,37.566957,25.113525,-13.168559,-124.291493,-154.960437,-136.664918,-60.180455,-24.103421,-4.36976,-13.511201,-47.663565,-64.938382,-56.915956,-9.779647,4.069134,-14.344648,-28.518588,-7.207299,16.629802,54.854148,62.137351,1.49098,-104.657304,-131.947897,-124.081418,-92.546569,-13.003812,2.116172,-31.350997,-61.418401,-57.834651,-59.167643,-64.276549,-33.977898,-9.52048,3.225477,-5.513134:-30.840582,-26.27384,-64.373348,-128.361332,-110.586206,-53.13761,-34.847325,10.62778,61.594592,106.187689,183.341204,166.185861,58.866808,37.29945,162.183669,255.895898,306.605563,242.271607,219.706942,210.608041,215.027973,168.203348,107.47843,29.052802,94.024557,124.090192,45.493814,-40.462364,-102.727392,-52.822744,48.377362,49.379451,-1.904198,-26.045996,-14.730342,86.791455,149.946906,149.994955,82.500196,-28.853769,36.211779,100.365901,111.470789,31.761481,-152.193153,-184.64051,-82.085234,8.880084,106.352445,88.21337,58.939705,6.134602,-4.633623,-44.362013,-67.121497,-25.53251,30.8049,2.268402,-26.875529,20.762366,107.865819,120.680901,185.341455,225.073411,223.381998,299.340253,382.315789,395.842613,302.354482,76.509087,-1.180701,-41.370508,25.397229,53.942812,87.975278,121.007488,175.639352,163.336324,107.401686,93.963314,136.020363,272.788098,339.605663,414.521471,408.558888,250.53974,155.554593,148.978357,247.695926,237.510657,178.337069,178.00614,89.961171,-36.451832,-225.172605,-226.676848,-182.519896,-160.37984,-145.264705,-125.051537,-116.072944,-114.345759,-113.87509,-28.001411,111.034181,149.358211,114.674177,52.313955,-73.74932,-106.38774,-45.846013,34.886548,130.094755,99.045301,79.330115,16.955295,-37.201634,-147.427151,-149.320097,-3.208311,103.20905,91.922692,73.343707,109.264497,173.321557,130.074823,-43.527639,-78.512119,-19.314612,-4.995474,-69.203167,-212.772889,-219.620198,-129.872861,-61.978032,96.020607,174.349882,159.501687,118.724646,127.708117,186.695687,200.053429,94.02142,-7.240025,-75.250739,114.079675,194.726253,218.167174,190.891251,125.852257,131.131458,301.263147,443.387799,416.613524,297.172024,252.264279,140.971253,61.477516,-86.965962,-118.002154,-63.390774,6.915512,-11.912863,-149.261065,-230.125111,-310.774767,-275.029208,-132.682864,-93.499926,-83.734054,15.079984,91.388863,229.098789,229.316012,81.910244,20.491676,1.623427,73.511992,128.233935,171.065373,123.037228,-54.484693,-107.832565,-33.761001,92.887199,75.066249,-113.769098,-190.078753,-172.408952,-140.655693,-159.773053,-182.744548,-219.053516,-229.478331,-180.599805,-29.638819,-2.831998,-81.308545,-122.770341,-97.610415,-17.549846,11.444538,64.823995,90.421888,42.717775,-50.695833,-180.322439,-171.37374,-214.661597,-358.586607,-357.492076,-229.162657,-179.602987,-175.566845,-197.242869,-240.015052,-263.231345,-235.584576,-140.980195,-155.93277,-340.194827,-422.002335,-406.785267,-359.048736,-375.330017,-413.220323,-391.579893,-376.934933,-418.049609,-534.098176,-539.22517,-381.992475,-202.646405,-156.406224,-154.378654,-189.189134,-218.007764,-189.362476,-112.069686,-98.583133,-156.407989,-186.840889,-180.225561,-223.651269,-260.350293,-276.288357,-246.747493,-184.452655,-168.549157,-116.218203,58.891199,77.560558,-74.429015,-137.305492,-90.282742,-60.488282,-110.863143,-121.948739,-126.326081,-182.207286,-180.111438,-107.944435,-70.730429,28.901464,92.546699,69.232689,-19.684283,-33.208213,78.720385,154.115297,162.754482,102.553867,-15.025297,-73.566433,-88.053812,-77.086504,-69.487038,-92.648701,-87.000406,-3.695943,94.536452,134.497091,148.30631,149.52735,229.884363,254.220164,158.689458,91.480821,32.484708,-11.504888,-31.689612,28.536006,82.227069,92.748997,59.367544,36.389531,87.851934,89.630684,33.695574,7.661719,-62.918442,-129.974573,-250.801945,-245.278919,-103.562683,10.145638,7.712783,-89.488929,-171.156986,-284.997653,-227.978386,73.235297,208.043197,168.517586,64.628805,43.332486,15.484613,-5.807124,-40.201495,-48.269158,-23.550861,19.989447,-3.827387,-145.23489,-213.363558,-280.027371,-282.991107,-269.147889,-272.464085,-261.896279,-203.806706,-161.057649,-54.193402,-25.102828,-13.942197,27.250264,154.754273,217.248974,227.916939,198.06671,184.928868,197.716604,195.710954,191.512573,205.923719,165.453024,13.236043,-31.518753,-21.906067,-24.419779,-105.824281,-136.474633,-64.310408,78.864672,110.121629,138.655792,151.02203,109.568516,77.973404,92.51137,167.638484,198.570601,183.897487,144.675248,88.66802,73.571817,38.668149,14.64828,-47.012955,1.080445,72.166138,108.436327,31.668638,-177.311905,-206.336155,-75.616806,3.099433,-7.010736,-23.338613,-24.091271,-14.288341,0.888937,16.277285,5.697002,-20.233838,-33.532721,-46.931923,-82.367579,-98.784942,-136.785677,-135.183186,-38.703068,71.63775,103.250388,116.749137,81.29779,-48.219339,-89.412467,-34.41816,11.646382:-100.443575,-90.606022,-94.829127,-71.978361,-36.542995,-25.026985,-61.734272,-96.808736,0.339654,36.633871,13.293754,-4.609,-25.482394,-47.198343,-56.963934,-15.514832,103.31285,116.96473,76.725051,42.343854,67.792827,77.889115,35.351495,-50.0321,-89.22179,-119.958935,-166.098769,-144.193903,-41.42097,5.373347,55.221374,33.896353,-66.706656,-52.635882,-18.7008,33.882893,59.735923,35.290878,-30.076057,-134.807757,-118.231714,-94.01558,-72.320923,-85.343984,-167.128324,-211.749641,-202.491248,-157.301427,-119.705313,-178.927062,-172.387497,-36.690502,9.249794,-55.788185,-101.277595,-111.260425,-110.353918,-122.438687,-150.820135,-146.084884,-79.436591,-42.06336,49.299141,111.975669,193.535657,202.382479,202.096747,164.649996,93.455257,-122.877633,-171.757098,-60.327105,1.404594,-13.355275,11.547782,26.952791,-52.007206,-123.264852,-162.385653,-109.630016,62.849178,228.551002,281.418026,322.72144,318.174486,281.008745,263.291393,227.331651,212.40631,235.886418,284.126636,268.605215,124.724857,20.397402,-71.490012,-25.036615,109.96675,112.070214,51.226374,-66.03572,-74.838834,-60.350172,-60.292251,-13.358759,45.212108,39.996117,-35.674557,-75.212413,-112.697446,-118.372407,-48.144388,30.949058,127.037101,29.239199,-41.100081,-113.440999,-132.131239,-181.945051,-182.538369,-102.897366,-9.830197,37.947351,69.885306,20.014363,-95.722704,-116.443027,-144.555414,-159.170565,-148.555829,-95.036581,-69.966878,-95.597684,-143.469086,-226.407271,-250.421216,-269.639897,-203.295911,-125.994184,47.065708,89.140632,20.895417,-44.151684,-72.450687,-31.218291,33.599164,-40.454229,-87.495221,-68.176985,-31.86515,12.475741,61.089923,233.734269,253.957526,201.167986,128.914724,110.995443,32.119285,-40.124078,-129.22313,-111.57569,-55.464358,-19.251947,-7.539644,-76.501352,-137.075933,-158.439132,-95.245691,87.186465,155.305928,125.992106,92.134331,123.012337,152.522629,94.759158,-69.41444,-94.992077,-25.147616,51.961385,45.661882,-43.156354,-73.353154,-24.070667,37.168516,138.271584,160.335767,144.390393,81.632696,35.75234,-80.894559,-145.643398,-250.172946,-273.745519,-234.490799,-115.829807,-87.215134,-121.617913,-139.080292,-139.869816,-128.415147,-46.608199,52.760813,63.643598,22.496052,15.956801,35.083162,20.213953,-18.552264,-7.937606,-2.007024,-30.098425,-22.089619,3.519482,9.258365,-1.260244,-12.266768,-47.92127,-90.828749,-72.280044,23.769195,35.746883,-91.971344,-187.447459,-278.82766,-251.344893,-124.352026,-63.70441,-88.074487,-193.135675,-247.19213,-327.717641,-335.024849,-268.805708,-174.87659,-136.371346,-61.343698,-26.020012,-0.323711,-0.782503,48.053927,84.551841,78.203265,51.06875,63.323807,53.387855,34.292162,57.677091,80.864483,43.376207,-56.537389,-78.46373,-76.83333,-90.447057,-141.858933,-158.142535,-159.661546,-126.183337,1.81127,32.513294,-8.675602,-38.461655,1.529512,68.427193,71.167022,110.225842,183.338855,174.663017,76.355015,44.995704,89.149255,119.862064,113.648824,99.768625,93.899391,123.13432,133.664757,99.398687,76.539396,44.36166,40.562363,72.026078,108.114599,116.09168,99.940929,94.909647,106.55826,101.334309,87.91716,88.913528,51.87069,-25.661293,-29.099733,82.98694,158.553216,236.038272,235.633167,201.816298,232.323788,266.546036,230.162916,158.326403,56.085061,41.107111,35.510042,47.451207,102.975464,122.663388,83.919208,-90.24793,-164.592426,-136.405651,-46.936031,129.781171,175.598471,161.804828,85.596273,28.610173,-82.888157,-139.82433,-233.704186,-251.061524,-252.08191,-231.762417,-229.778121,-270.351996,-294.654776,-334.764891,-335.589224,-246.680475,-157.282401,-127.736678,-29.834269,14.950137,-7.036654,-65.947576,-113.920396,-64.73295,76.655655,169.128454,157.761999,19.964314,-40.968581,-86.565658,-66.408475,28.106805,43.803978,30.303663,-10.943478,-62.997302,-191.009612,-225.807414,-225.305259,-208.761094,-147.390232,-10.800063,47.839379,51.1183,14.784847,-67.41374,-99.604085,-93.005374,5.060649,58.030212,65.933371,12.202772,-67.016606,-65.60528,-53.090783,-66.267987,-110.976843,-88.6779,-63.146521,-56.695343,-75.294549,-109.640098,-99.525113,-55.402789,-50.502913,-34.910097,5.836112,7.877572,-28.410956,-64.017955,-113.297805,-100.051187,-49.844269,-54.587269,-56.212615,-15.974993,19.372457,54.688854,51.759015,82.435543,125.093411,123.335434,84.386696,58.678109,49.263111,62.285661,74.60544,88.920129:right
118.217433,3.701658,6.410334,116.319357,175.739446,235.685769,237.88755,197.725029,128.727487,120.271047,181.881649,237.730451,336.363953,365.547623,422.002025,439.972566,402.133165,323.907798,282.140713,216.300862,204.862869,169.242142,113.077435,-54.244956,-124.772019,-96.165799,-15.062479,-1.492442,-27.575507,-62.711092,-139.792693,-167.302034,-223.18515,-198.563245,-143.742239,-30.30348,7.324525,19.691038,-8.003376,-97.948736,-140.621151,-114.895451,-8.562591,32.676319,51.008637,38.096198,25.644091,34.910105,65.828171,103.383522,122.0362,176.519886,201.707537,207.741849,198.648556,146.504756,91.37206,101.808954,142.659622,147.879785,129.979578,109.31071,77.015436,73.850051,63.107745,43.764487,43.228641,45.24086,30.313169,-24.064706,-47.325706,-92.530129,-144.531144,-154.251396,-124.804263,-107.141972,-132.69508,-160.25744,-151.836319,-122.160598,-29.629495,132.480049,193.648648,170.681524,102.162835,10.205125,24.301751,36.854703,-84.954421,-135.633625,-141.768971,-129.4394,-149.791403,-162.823102,-129.962399,-118.383366,-163.327009,-111.562402,-17.416863,143.623076,134.70309,-27.457834,-108.352458,-214.617141,-258.920945,-261.189504,-240.062635,-227.18507,-249.162201,-265.135437,-237.236103,-209.866596,-105.854198,127.879673,218.118908,253.358707,256.103739,281.928214,272.909458,208.988278,126.120191,66.83014,-46.923603,-51.875621,-24.431597,-61.930504,-151.026553,-127.170735,39.321955,213.608008,255.155184,219.72091,175.982243,112.509371,92.369418,22.031983,-49.677184,-38.994203,30.239469,54.463993,69.448403,74.12322,66.379659,14.666481,-143.233661,-127.208538,-44.840733,103.106542,114.904706,3.536507,-82.293267,-211.978471,-252.081214,-250.128505,-219.614577,-199.457937,-168.441947,-155.629767,-166.788195,-212.367662,-294.107696,-224.441045,-150.929773,-12.86694,11.081047,-51.9111,-92.876144,-135.943211,-123.317541,-77.594438,14.253417,17.912712,-45.387067,-88.974999,-140.93944,-133.402732,-85.065806,-15.922921,26.996277,135.67021,189.987355,218.850206,183.31711,66.276312,6.535161,14.088436,65.895504,93.318387,75.734521,40.847849,15.610684,12.665537,-5.415265,19.110433,44.583785,98.991322,112.003569,86.295797,58.486416,-2.150909,-5.912313,7.356534,7.876366,12.12672,25.772357,14.925267,26.131164,49.832588,15.173565,-85.698712,-90.861453,-16.80266,-17.535537,-163.343823,-235.083721,-267.507742,-245.635663,-219.84725,-137.760222,-104.252869,-74.885891,-79.98325,-114.652115,-128.94363,-130.514383,-75.012914,-45.344135,-20.404201,-17.73338,-35.19612,-58.476089,-144.603369,-296.164586,-368.35031,-415.859407,-395.612501,-351.294774,-333.550369,-276.493992,-261.292065,-295.331037,-307.326809,-272.512706,-167.134773,-143.738102,-164.345464,-163.591864,-143.930843,-172.440414,-181.28053,-183.781197,-195.515608,-245.853306,-273.379629,-306.62749,-317.71535,-343.784339,-334.877063,-320.966031,-313.287706,-320.963993,-341.024927,-329.174564,-241.897212,-169.984762,-164.435874,-178.525893,-162.399579,-86.34245,-45.175331,27.774002,29.933562,-37.62408,9.166053,96.623781,209.075468,173.191309,-6.966464,-54.925933,10.431313,102.586464,112.38078,109.026101,119.036952,122.986785,99.524167,51.620216,49.097414,115.958363,267.095067,314.275614,246.937389,152.039824,15.457451,19.031432,48.238006,-66.443452,-130.674987,-116.501943,-65.242382,-62.085944,-103.572078,-114.880057,-94.946211,-127.589716,-226.850374,-265.157276,-259.944687,-224.228313,-188.146608,-209.771166,-305.723971,-328.320473,-299.745286,-256.668497,-243.587973,-217.001867,-208.331537,-203.371404,-227.546756,-344.509072,-404.606177,-375.094104,-210.162486,-123.779078,-60.21647,-82.223789,-166.350645,-116.530799,-30.776321,127.800738,184.526082,252.296796,261.627114,281.74436,293.58225,266.550296,195.497238,188.921682,282.97243,328.364433,239.393225,140.15459,68.970943,184.782393,223.214362,144.572899,87.08191,98.470655,139.131671,137.621987,73.973011,-58.391078,-49.541962,-30.846219,-20.888448,-14.4335,27.604346,64.145986,104.070208,62.068328,53.73884,111.351533,156.885341,209.748926,209.652604,208.689492,220.699791,290.371707,406.756306,434.514411,413.855343,394.948345,354.61833,326.829141,268.376376,283.481017,310.867336,265.842106,209.64053,154.001801,138.181822,46.14154,-15.594108,-83.474277,-106.413117,-130.627453,-157.841779,-152.709647,-134.645176,-118.779734,-106.112207,-151.933403,-157.291965,-77.050036,-40.4795,-106.242238,-176.369313,-253.232564,-258.791803:90.942875,136.751333,171.6048,208.814882,215.947805,257.887123,278.593022,232.161834,142.345734,137.878218,190.04196,215.591983,240.513863,256.921721,320.863852,342.994565,331.1028,281.050155,247.961852,204.206968,191.251617,105.073748,38.043465,-54.412224,-44.031093,11.035447,158.659036,176.273167,20.736241,-83.710309,-181.916808,-211.074386,-292.07156,-200.840455,-85.912738,86.715426,96.551126,3.343652,-54.222153,-132.175379,-158.40586,-136.293058,19.433743,103.893278,80.533554,-12.112292,-116.793577,-86.425833,54.973796,147.846197,161.044328,179.117436,155.43338,30.256742,0.710765,53.58526,143.608348,183.335847,228.504813,219.070726,143.431149,106.118398,32.553038,-28.058108,-115.284254,-61.42965,-19.80352,19.39282,9.522936,-59.691879,-104.501132,-163.683306,-138.880756,-102.242164,-35.405592,-22.054453,-70.343152,-117.128935,-149.309726,-125.72113,-58.153334,33.234991,89.032426,105.998504,41.480491,-77.436953,-79.749021,-74.96155,-123.176646,-132.023505,-100.722082,-74.157653,-65.477657,-91.706719,-125.729,-121.903594,-104.556783,-54.774036,-11.699554,38.639144,2.14195,-152.334761,-217.547824,-282.833565,-257.57036,-206.81148,-112.899368,-116.984757,-229.513241,-279.133711,-234.777889,-161.773599,-22.950072,118.841711,184.127532,227.30405,217.367422,189.386667,157.925806,80.046465,65.645075,61.079954,52.368992,58.517862,20.030054,-28.807186,-62.720721,-28.491327,50.155362,97.866697,144.477003,264.587317,290.442444,229.122278,153.97574,-6.859496,-45.658596,-9.112077,87.119592,119.571016,133.273066,112.470387,27.390315,-25.997606,-112.794191,-82.021253,-7.058335,113.865488,89.107148,-33.414896,-47.532603,-36.889043,-50.018894,-37.251668,-4.532201,3.828087,-3.396667,-18.282636,-89.420104,-154.046629,-223.15995,-99.844502,-12.82123,114.25255,149.274407,141.911292,83.563456,-91.316429,-130.266258,-95.733193,-43.214627,-27.896198,-31.534641,-58.410124,-113.88263,-132.562547,-127.12432,-22.714073,38.777112,155.500655,192.839915,169.269962,130.45267,55.539461,52.154605,92.690667,153.990788,144.836064,66.881378,25.506754,0.276831,14.285332,57.150436,57.031415,41.82418,45.341328,55.792908,36.450232,-4.31844,-102.895077,-37.181146,24.309383,30.895404,7.176667,-11.965251,-39.826456,-107.70187,-101.515752,-32.472527,-1.008691,8.881429,26.006655,-13.740255,-186.58073,-245.674122,-228.608082,-169.927643,-156.586073,-115.101217,-80.747897,-59.20266,-85.010838,-142.168923,-146.404744,-115.387514,-79.576089,-27.550819,129.076325,157.940806,54.74376,-34.692025,-189.228941,-266.814646,-276.847941,-239.915886,-205.749736,-197.26087,-227.504598,-269.807114,-271.065066,-254.867392,-211.149903,-176.999735,-82.863652,-51.771032,-79.819015,-119.075678,-175.424494,-162.400822,-122.36798,-18.127961,-2.686298,-118.613459,-207.827783,-306.136268,-308.846031,-290.105138,-319.415993,-329.521184,-272.968096,-226.741835,-190.065,-218.272833,-309.8559,-250.257647,-174.84475,-102.1334,-100.546619,-102.878365,-107.078118,-89.336642,-51.868244,59.739663,156.10977,203.367099,274.077142,244.470256,61.198172,-14.464307,-60.365365,-25.445388,16.0544,65.944717,43.270432,-47.142485,-61.630064,0.311882,26.993135,39.124382,143.04214,228.95009,293.952267,232.558314,48.21592,7.353989,8.769419,-109.33677,-199.249723,-236.141695,-186.380604,-155.006158,-190.649465,-239.457975,-236.182985,-246.754903,-285.916638,-278.158776,-223.289427,-214.834695,-248.255652,-265.158937,-290.82847,-287.70261,-263.163825,-205.801325,-187.085866,-200.969963,-227.45341,-273.865012,-293.674107,-331.293441,-322.671519,-293.645477,-147.827649,-52.13767,25.136934,-27.08686,-176.646943,-100.207041,3.347605,135.257632,142.143029,108.225908,107.486487,103.174126,66.112629,48.43738,151.41745,181.892903,184.494237,154.587631,21.153685,-26.74482,30.898029,131.262637,140.293996,121.489848,115.07717,71.834411,31.984461,-9.40196,-17.319886,-60.137984,-98.300912,-91.622105,-32.121433,-16.836143,-50.452083,-47.508319,66.625691,164.179209,181.688818,271.484682,329.211924,302.869323,222.928821,133.939113,177.157983,372.119064,510.807429,502.693348,401.937006,381.722112,409.270728,402.777679,323.782708,285.049545,296.472205,291.012659,268.387565,220.901994,190.820594,80.697548,16.13946,-39.035884,-20.360081,-2.383064,20.818207,-33.952145,-249.568355,-283.7715,-161.886804,-109.65718,-117.073266,-65.826631,-18.752125,-62.542464,-157.122494,-287.996151,-286.883048:143.393383,126.490033,138.999024,204.52322,232.45253,219.450361,192.7761,117.676831,93.221019,130.726574,245.880725,298.037754,343.068163,341.837154,331.215337,311.679148,266.850158,291.386341,316.212503,276.996101,213.324264,80.265405,22.988614,-19.445258,85.256599,153.338768,245.260162,249.965752,129.288995,32.070377,-98.348725,-135.912388,-228.275916,-196.469303,-94.456624,101.910464,118.254856,-3.843203,-85.816584,-187.622678,-166.735871,-127.607772,-54.955229,-30.980701,-12.31897,-20.36894,-69.371218,-93.325379,-89.706264,-23.501121,7.881031,24.257313,9.123807,-16.962104,-10.245035,0.524054,-8.547609,0.245459,79.986612,114.346441,20.284408,-71.473439,-155.371738,-160.37499,-162.317706,-83.461552,-26.780699,11.732181,-15.264437,-99.833069,-137.040144,-164.719194,-102.025591,-55.528327,5.048083,14.534375,-19.897403,-54.259027,-90.726863,-86.663929,-18.821009,122.100651,161.06377,72.543649,-22.003025,-131.237658,-127.822156,-118.465852,-120.207221,-81.657404,20.491871,18.387639,-123.079427,-198.315108,-247.927912,-237.527014,-172.062027,-69.948729,-39.467641,-35.274265,-46.369808,-123.167231,-195.960425,-275.11234,-192.230885,-165.740969,-173.763694,-173.539042,-187.917972,-204.86217,-180.6025,-135.690671,-26.55853,82.730243,129.82611,183.902742,177.880416,114.312327,73.408933,-21.770751,-57.711495,-28.683712,62.302998,80.651017,6.418397,-48.413516,-81.849572,-62.870352,0.119982,121.957333,207.243161,333.187025,349.481666,295.343166,230.995373,100.6599,100.025275,139.060678,219.825022,252.665004,257.671042,224.497163,112.892095,37.311479,-83.177172,-49.936783,16.319231,144.339719,158.516374,84.578809,35.484764,-44.950792,-57.203923,-26.915998,65.991647,95.626465,62.641075,25.589649,-18.997268,-56.323891,-142.208602,-57.151672,31.439093,115.832199,87.648619,58.749661,91.140216,98.995908,16.492327,-6.24718,41.172309,96.35637,88.602022,-7.661788,-236.043463,-297.038841,-289.616395,-169.503599,-83.674,70.223564,120.935917,180.265215,183.825924,119.755156,99.13044,139.052169,205.841095,193.879234,101.555895,52.452022,-22.50711,-58.268264,-103.017488,-74.420206,-47.405206,2.810748,8.216493,-9.076682,-21.933979,-67.596966,-6.947114,48.405322,52.076345,9.440288,-93.227482,-137.865598,-190.157475,-200.410982,-162.329185,-9.843848,65.588599,74.357256,5.261431,-143.222846,-171.854559,-133.478686,-43.775834,2.607464,60.960916,47.824753,-46.828946,-83.195975,-111.186173,-119.347305,-89.579554,-27.30854,0.506637,49.284125,29.592511,-80.184875,-117.105986,-172.333845,-203.385737,-184.430061,-147.430616,-155.463368,-210.167147,-241.045382,-264.032085,-241.050483,-124.163083,-5.135512,13.658456,-0.599172,-14.047679,-27.18504,-15.666553,8.13331,5.799627,7.46687,26.822685,39.346754,-34.906894,-117.832391,-206.229055,-210.47497,-219.02648,-181.092589,-134.16123,-26.713681,1.716807,-26.601927,-55.182118,-76.890552,-65.159125,-61.836272,-50.077291,-37.025948,-46.353981,-62.10166,-49.789563,-33.400658,18.944295,162.446835,250.808883,320.328842,257.07314,60.629064,6.365348,-22.892245,18.635691,80.920513,208.982681,219.981474,122.732964,71.931525,65.009954,89.223476,152.347405,216.059947,218.561635,195.88471,194.992284,185.454031,145.297004,9.322947,-36.882629,-26.297319,-37.221894,-62.881303,-128.441113,-161.032357,-221.899458,-235.047486,-191.609706,-120.876214,-90.716987,-63.78406,-92.493743,-192.079925,-204.959042,-134.892893,-71.443995,-72.957395,-123.207262,-145.857493,-148.691169,-150.144156,-221.06227,-275.239729,-318.357404,-232.740159,-165.048896,-50.505075,-34.433044,-88.898427,-134.925304,-198.112534,-122.653251,-56.165721,7.310353,2.259485,-26.796454,-29.26344,2.197868,11.931756,15.887857,50.541533,79.823891,122.348435,103.807474,-10.298462,-55.698535,-41.151794,55.352914,88.178086,94.094852,81.311874,37.20632,11.629178,-48.047269,-89.375695,-161.161271,-172.619704,-149.002032,-86.579846,-87.576071,-149.574206,-163.409074,-84.853893,46.710702,79.517993,110.505138,123.713297,66.228926,6.669392,-3.399487,53.644406,159.849797,193.767078,198.607256,215.8971,230.464457,245.096817,227.101471,158.37906,166.412979,204.538768,238.647743,210.378635,92.690794,28.123593,-83.621458,-112.229258,-86.065393,-73.68846,-81.907939,-100.63761,-128.032301,-220.569482,-266.31112,-294.571538,-198.48446,-135.844977,-46.393526,-23.243539,-80.490136,-155.233416,-271.400666,-298.261178:41.840811,76.160784,97.626579,126.727645,137.109607,164.986048,168.592841,114.223901,114.037898,167.24014,304.047845,370.630121,466.050138,472.0377,418.733333,388.392075,343.729874,291.394095,264.695209,237.738484,226.195352,140.68802,74.732352,-15.111256,-16.306659,-1.094421,14.487524,17.564605,-19.388048,-77.126982,-158.726491,-147.751833,-142.747345,-189.831041,-167.983161,-30.240323,19.366216,-2.150965,-48.282594,-150.288122,-143.100049,-85.373229,-3.378984,-1.178661,-2.739126,-4.211185,-38.637259,-53.71044,-10.744937,73.41758,73.90481,6.311443,-16.274384,12.609121,44.304121,77.337411,79.765734,62.567877,31.258014,55.837204,82.486756,27.875006,-99.108429,-111.797945,-65.790488,-15.237198,-1.961228,0.018822,-15.923381,-70.277499,-93.922676,-100.9879,-13.199205,45.403079,104.075824,93.211931,5.939065,-47.494145,-101.001321,-96.085877,-1.798894,160.198273,190.75788,99.050097,14.904804,-93.321252,-87.449375,-74.571395,-160.368629,-179.023434,-117.125565,-81.888355,-83.402784,-109.104703,-176.599185,-206.432706,-218.984242,-149.487946,-94.5217,-14.360561,-21.756408,-95.77615,-123.313893,-184.615966,-271.109653,-276.78496,-207.905358,-176.130132,-182.335141,-203.437871,-212.036066,-198.794326,-121.241255,56.446211,136.226416,196.95058,190.256672,156.048654,134.111466,54.262777,-19.922446,-33.430886,-25.160851,-0.639691,20.924806,-10.709049,-81.084127,-71.205671,61.526288,213.49297,256.148258,270.854913,240.686455,133.635763,97.501004,86.795429,69.859236,64.817239,56.57798,53.038521,84.789688,99.577929,46.871045,-19.329503,-144.569208,-171.701829,-137.514744,-6.246731,32.364113,-21.702124,-74.423822,-159.720175,-183.332412,-144.886525,-35.526286,-11.118698,-31.402988,-46.528218,-72.964064,-117.776365,-197.55319,-83.620615,-7.523512,50.839755,48.848273,55.782571,63.450262,31.658757,-0.226793,23.765063,86.003582,79.430915,-10.72617,-51.374242,-60.148746,-43.07078,-16.0428,-2.963978,7.437632,88.077886,156.617615,225.861836,200.584196,123.679353,148.504081,205.113045,308.434862,312.11652,228.748025,176.168404,79.681104,33.49577,-2.00591,42.811753,64.779436,121.437938,149.375955,144.99725,123.809613,65.621031,19.508462,18.868965,23.99584,9.436102,-61.107983,-93.85391,-87.292186,-63.920229,-53.405884,-62.916596,-51.339434,4.009721,21.038252,-14.725804,-48.380765,-106.707273,-136.787896,-110.827126,-10.028546,11.755425,-50.244871,-84.349789,-46.655221,-12.619101,-11.540132,-15.691605,-6.106566,-33.772646,-66.916289,-126.889143,-163.561584,-247.785674,-299.156043,-308.558343,-315.937511,-327.277591,-334.730278,-310.448357,-228.928354,-203.384987,-200.212357,-162.898197,-125.432944,-77.920435,-90.831953,-134.144396,-125.097958,-105.284944,-141.103593,-137.356107,-96.123108,-96.423747,-181.903321,-249.758298,-331.271421,-336.74642,-333.11241,-302.030062,-261.035958,-176.787694,-156.553855,-155.872495,-146.168454,-40.972423,27.956629,-16.164772,-106.194718,-84.419305,-7.843616,-1.410697,-15.422052,-23.521922,-15.982212,110.215796,204.477746,318.185432,293.449592,127.996613,64.509852,83.799205,183.652248,202.697766,178.055753,175.298415,170.046021,139.942554,77.965641,73.357537,124.296575,187.272003,198.834381,180.265044,152.203086,109.105693,105.036684,61.958042,-48.904875,-89.411764,-105.180907,-102.74067,-138.077329,-164.183501,-194.802858,-211.949278,-248.375089,-207.340529,-177.428541,-186.807715,-210.797519,-222.456874,-214.542666,-239.139154,-273.592899,-250.097833,-165.608564,-139.358284,-142.911424,-168.413096,-227.226501,-245.863293,-275.229588,-285.7455,-255.170472,-140.509115,-106.855644,-136.359337,-167.360363,-191.529701,-145.306716,-91.900821,32.894807,81.34521,118.948524,115.946528,118.652022,134.979837,186.302636,197.517699,192.331821,235.032131,246.105687,111.369939,30.123673,62.523374,227.149033,266.035707,191.06933,120.134209,51.519694,54.276965,41.460495,6.735306,-87.71748,-132.480676,-119.841656,-80.302983,-82.66457,-122.306084,-129.886547,-97.319978,-44.751387,-15.892153,39.318291,63.978634,67.041018,27.370565,-44.866812,-28.63416,114.363501,277.285162,295.817923,194.316708,144.541527,143.135167,146.889,106.210124,117.940826,143.629437,138.991311,105.284295,21.070056,-20.389031,-99.37994,-135.561924,-173.509323,-154.096966,-136.369258,-131.759927,-167.539375,-283.142219,-315.124977,-305.581682,-270.188048,-253.925148,-234.516987,-234.345911,-287.332669,-334.116521,-402.090386,-417.54469:14.12708,109.131237,169.149597,247.380932,225.459717,81.113007,18.611629,14.053237,116.892576,175.863172,328.647662,407.637807,410.209537,335.94548,214.6742,210.843207,285.456093,296.171374,262.088652,216.204452,210.946358,148.20818,75.606676,-31.149489,31.068435,72.191249,108.227421,106.819612,10.520986,-70.577954,-180.038341,-200.545623,-214.045104,-164.89165,-117.313852,-25.318367,0.963403,-19.111382,-58.527367,-131.657468,-111.274409,-73.708251,-10.8506,8.05368,28.452474,29.347548,-23.154026,-71.784586,-77.298648,46.17752,75.057737,50.779907,26.606123,-10.195578,-17.627594,-26.772353,13.908879,57.410815,121.608243,112.066805,-20.109847,-96.152871,-143.131921,-127.745429,-87.659339,-36.947344,7.012736,60.327746,28.50458,-82.708076,-108.040237,-78.757731,-19.679469,-1.145495,48.815,97.59888,152.853805,133.086244,32.407249,-11.807994,59.08743,170.613176,159.31553,99.53629,61.321877,-21.991981,-37.771678,-42.896969,-61.998285,-62.696378,-48.966206,-51.232493,-118.345897,-177.881549,-269.508099,-272.112879,-183.137505,-75.900215,-33.143932,39.902908,36.937541,-69.111105,-134.321307,-203.034147,-150.503272,-122.692343,-140.870495,-155.050046,-184.668696,-215.450207,-250.173664,-226.424139,-84.382902,48.689345,82.575272,96.573279,82.647947,44.040419,14.974183,-47.336716,-12.61987,20.968771,56.66975,74.890888,82.588759,47.57967,-63.971951,-100.967618,-50.709132,147.344735,255.090596,401.979119,411.057958,276.701605,170.34556,-14.290445,-60.837873,-13.264836,130.71363,176.903635,155.950518,92.209241,-98.761496,-187.578646,-238.951687,-157.835363,-93.837329,41.252216,62.923333,-15.798702,-80.747453,-189.482874,-178.385605,-128.093561,-24.627067,-1.175603,-7.759235,-13.969267,-68.057575,-134.542733,-214.080541,-123.161846,-43.953938,93.970326,109.341556,40.244976,5.640192,-49.044612,-93.559623,-74.111033,40.443418,92.087519,78.496543,11.331568,-150.46404,-201.11349,-200.269841,-101.257503,-45.317909,27.249004,43.683983,58.834726,49.674007,7.640166,81.417594,155.566325,224.322893,207.736943,151.074326,125.082762,12.787496,-63.801185,-129.676111,-89.384094,-54.849481,26.396554,41.668948,-22.33699,-66.406884,-80.914276,-24.232857,-15.681704,-51.960884,-79.280061,-160.862523,-200.974936,-218.328615,-200.978365,-133.603425,-51.318529,-25.106695,8.512949,19.837373,-17.282818,-53.567723,-74.362078,-54.800371,-39.795252,43.495884,88.86523,70.874929,34.384797,13.11149,6.821459,-8.332746,71.104566,137.724372,178.919159,117.168572,-54.659752,-103.376704,-136.315612,-141.654971,-136.708188,-120.340409,-111.622215,-118.498115,-143.17142,-199.847027,-201.495207,-146.041939,-91.234778,-67.209954,-24.690793,-10.589906,12.871325,10.193625,-23.837867,26.190459,69.864249,64.957111,17.045043,-58.851513,-63.366065,-87.990111,-143.6735,-225.844515,-130.162577,-50.922384,93.886536,131.775054,115.386932,106.060368,157.950734,214.420768,212.824538,172.016941,155.600579,153.169481,162.72449,173.347287,167.754833,184.905886,308.653777,401.100769,516.86623,479.922017,282.65655,214.023537,222.689551,280.872677,293.374571,348.740328,395.563591,371.499274,280.688146,155.711101,173.130242,266.42275,288.515795,262.260744,211.589908,201.73342,189.66525,172.043773,79.110142,23.735497,41.21976,76.610855,61.768294,-48.126369,-113.481191,-191.673861,-211.438961,-203.525243,-101.421343,-43.689187,7.938162,5.115117,-17.890542,-40.97437,-118.589508,-180.516909,-185.84842,-118.499204,-61.749585,-39.689522,-91.793804,-225.995506,-279.465293,-345.282052,-311.702072,-267.873301,-224.9409,-250.678109,-329.335765,-338.88621,-301.444192,-220.049725,-173.961019,-75.704867,-20.245694,0.032053,-48.437258,-114.448043,-89.841611,6.213195,51.609381,76.358725,130.196778,103.172561,-63.637328,-132.197769,-115.541193,36.61302,84.476175,56.153952,17.513669,-21.687859,-30.248359,-100.031542,-154.137365,-235.308204,-263.607727,-244.625982,-169.93784,-166.62483,-255.848231,-300.341791,-301.305471,-194.300864,-135.879361,-26.913322,21.679744,6.307314,-53.868597,-129.372147,-121.066457,-44.320588,51.694794,82.045181,123.485998,125.863311,65.643271,21.072346,-27.088451,32.859086,80.674437,128.839035,106.259285,-31.459229,-101.443916,-173.63948,-189.061704,-177.810968,-115.637004,-85.151789,-74.273018,-115.143597,-223.014075,-240.927873,-217.118127,-190.767368,-178.92226,-122.686239,-85.957949,-86.192251,-128.619433,-226.854294,-257.149095:26.961653,-10.785739,-30.268766,-40.148821,-39.897077,-48.797628,-51.816425,-23.660418,58.182691,92.931266,124.219452,165.438051,330.209447,398.867384,428.200145,402.345771,337.993671,303.079857,288.912152,258.716892,236.484749,150.587062,91.601716,2.251918,-11.277497,0.268288,44.041601,55.062157,2.361526,-37.756567,-59.107573,-68.480454,-160.171422,-197.427079,-153.231261,-16.08273,30.155119,-1.534514,-65.551751,-124.405846,-40.32425,-2.327632,9.079096,10.613161,41.232822,34.151806,-27.810838,-21.596714,83.893774,36.791919,-40.560209,-41.895975,30.472528,102.622242,69.703418,-24.707195,4.464406,46.644963,79.385212,79.853704,72.991389,53.3679,13.132454,26.989819,110.834051,99.211457,51.224508,2.84682,6.760087,-14.899702,-37.521594,-31.656273,50.68054,97.170844,139.653742,124.13577,45.524494,-4.461698,-64.454387,-48.374842,102.250322,322.130701,371.519438,288.005856,196.585404,50.783514,40.015432,45.780018,-27.30069,-25.721134,89.159845,116.004412,-9.906262,-99.551774,-179.254269,-167.069841,-58.292619,82.399066,116.002613,106.367425,75.860848,-1.655656,-24.261116,-82.228036,-223.658841,-284.11415,-314.837486,-297.692895,-252.72533,-232.219656,-210.443473,-208.793055,-127.902317,123.633191,231.148398,258.379389,226.665395,216.614268,223.233238,159.552294,54.30052,45.57715,74.170403,61.865066,-55.005249,-117.430519,-109.427705,-42.980677,133.269794,306.719778,347.672487,290.337707,225.452518,141.916325,152.885567,233.623821,206.582758,151.664884,89.756633,97.711384,124.663017,120.706119,64.415469,15.388298,-61.345069,-36.72063,-9.993179,-17.737073,-48.874782,-72.280484,-53.862602,-84.959718,-218.998746,-229.781869,-142.413672,-113.045531,-108.565172,-111.107069,-138.203957,-174.448031,-221.357634,-128.536869,-59.308993,3.914585,-24.951538,-145.197765,-192.258577,-164.118947,0.815031,64.535218,101.066858,106.814767,99.624911,63.376347,-25.124625,-44.13989,25.771053,162.360918,179.509908,149.815389,159.04243,195.027198,172.665005,47.464474,18.113455,78.702639,173.28066,148.6654,11.810767,-47.796624,-87.890424,-80.085814,-22.301624,86.303517,111.062593,66.628274,55.696456,109.732188,123.771674,92.766957,93.627817,90.501777,30.576432,2.12815,18.93676,56.622008,124.379394,127.578112,63.47535,14.666727,10.002016,8.813361,2.955094,-34.647767,-62.864406,-144.937314,-186.463628,-149.030635,-65.509905,-89.17806,-220.18656,-247.176715,-157.272773,-101.142001,-111.105573,-133.080957,-88.923013,-5.172528,-32.745625,-195.947031,-240.865071,-235.333406,-274.315081,-303.553983,-350.688911,-371.16514,-382.278371,-349.298677,-223.117872,-188.475716,-207.188772,-170.800304,-147.201213,-186.104619,-206.843188,-183.425188,-165.596501,-144.192145,-140.104839,-158.75025,-229.053151,-257.007076,-252.050996,-236.805665,-240.028315,-253.979054,-298.679343,-322.341625,-286.494518,-174.839524,-170.573275,-235.110154,-223.6741,-93.448617,20.141832,34.030913,-62.751458,-138.120806,-156.85443,-76.982154,134.435976,196.870779,222.622952,256.401053,280.870229,277.547837,234.792145,129.248412,112.731186,140.419986,169.155274,168.067015,149.631491,156.297223,170.051811,156.826652,116.183947,110.198115,190.797692,315.364393,307.726093,166.879031,97.385407,5.551053,-13.872233,-7.830215,-24.31221,-31.014175,-3.755537,7.978018,-18.772219,-46.000685,-85.347297,-87.225302,-84.80516,-168.869565,-230.903507,-262.112554,-229.34103,-188.554867,-205.19813,-284.059192,-299.183825,-259.781966,-177.710372,-166.363702,-189.340357,-187.901858,-152.329053,-175.79234,-343.045573,-410.471321,-351.312585,-170.293342,-126.675264,-191.021091,-230.724079,-194.382882,-95.845132,-43.948504,110.768837,188.194865,221.460422,193.1047,201.281574,252.087247,317.552537,234.872344,203.717274,281.519189,305.878973,142.319616,37.725701,22.103692,202.862116,286.120045,266.89915,170.252693,25.146736,27.408774,70.038484,48.797122,-80.588809,-174.911694,-180.719512,-145.124141,-131.828255,-191.584717,-255.547341,-330.056662,-306.309977,-291.281877,-243.739841,-194.744572,-87.315058,-62.099276,-82.717428,-73.445953,114.054995,298.554496,275.269781,122.148017,71.152374,12.618338,-18.831671,-49.869304,35.506799,78.703206,46.974322,1.904997,-81.507328,-126.608018,-192.622789,-211.582667,-266.305216,-295.028896,-273.565721,-215.926985,-209.013837,-216.312742,-205.630804,-178.509905,-180.856301,-177.464785,-158.058164,-162.75083,-238.538355,-282.165397,-314.882001,-323.135747:-80.964132,49.787205,113.275022,102.613444,27.539359,-84.925991,-81.468529,-48.901131,-7.44211,47.895052,205.04115,287.502568,372.761601,345.480629,238.759515,216.959916,258.991915,318.881411,339.721938,328.061728,253.18216,11.567637,-69.650955,-60.802426,60.639252,101.404683,77.395066,27.893948,-76.161055,-115.137011,-156.090863,-158.925873,-139.193136,-75.820257,-31.12211,14.318154,-12.935283,-118.295755,-149.487952,-132.258254,-61.679736,-40.228755,-49.190635,-56.614807,-74.460997,-99.491882,-135.926715,-124.371272,-36.00948,60.801726,57.673667,-14.704166,-39.529963,-55.209426,-47.943523,-7.955187,47.43445,76.542047,103.577655,101.125639,27.325547,-55.964063,-156.434233,-114.779873,57.702839,116.012914,84.796334,6.074058,-31.863618,-108.875269,-114.4011,-16.793588,126.054784,160.389623,127.935726,89.610482,26.494561,2.075553,-22.553925,1.64592,148.314739,240.22646,224.149113,162.033081,120.790406,14.21769,-24.074849,-34.375845,-16.82239,-22.385881,-42.711894,-47.23153,-67.545904,-92.295219,-130.242488,-118.224641,-22.91474,68.328461,79.160799,58.053459,40.050325,-44.120066,-111.226665,-198.025182,-138.422081,-123.182722,-215.458117,-258.120701,-256.734185,-230.32535,-164.33345,-151.450355,-95.279864,81.058519,139.51206,155.426684,153.902184,147.132325,108.436524,-43.654035,-47.211962,19.060586,63.249211,23.583694,-81.885144,-126.300522,-153.678427,-119.747652,50.77501,267.630549,327.71424,292.577582,221.155869,81.99226,50.152745,51.367592,84.270939,121.826925,184.69312,169.200628,32.552197,-48.489465,-118.997271,-123.063646,-158.674311,-187.19561,-167.346555,-82.266393,-68.931177,-153.158254,-206.386413,-231.517752,-164.454481,-134.73095,-92.413214,-71.977841,-64.049195,-82.932041,-157.474133,-199.583031,-190.661438,-54.287917,0.207095,24.146644,4.770274,-67.013331,-109.743829,-125.670128,15.465512,92.658369,150.572258,140.265232,78.601002,30.518852,-62.075031,-88.967246,-78.64069,-23.558182,-10.45276,28.698409,65.124994,73.434794,30.094624,-31.491564,52.86182,117.391007,182.533758,174.789996,90.612675,19.958352,-98.256508,-101.845234,9.536397,129.41488,152.393483,115.613948,70.691575,26.057846,50.902979,125.339965,150.107348,142.518714,119.271376,109.549887,43.343764,-12.720498,-92.499371,-90.847346,17.66098,170.215399,216.4198,202.789478,135.008031,-8.171662,-25.29501,-6.702672,2.195135,27.22052,106.256002,122.557272,25.838362,-58.527164,-127.040586,-96.421995,-7.161545,71.567429,108.253281,128.825404,81.805837,-116.406718,-200.63821,-229.127069,-179.869924,-178.068573,-214.123711,-232.420576,-239.680173,-219.087797,-163.881679,-161.895381,-187.648853,-142.599209,-98.15746,-54.270967,-73.599137,-119.369954,-103.90058,-35.938758,-25.597562,-37.853008,-53.653221,-56.236499,-111.748425,-171.069187,-248.644657,-237.192817,-139.794324,-80.720589,-70.291977,0.688455,38.230796,43.079115,36.512939,86.333612,211.140973,255.607103,243.201678,213.189773,172.79738,160.276986,125.762414,118.264909,221.04644,434.485033,507.70315,524.043062,476.990129,319.236757,242.005236,194.15901,276.211485,308.03782,308.661256,294.00276,247.158649,234.337159,240.842016,231.101096,236.684472,309.983555,308.89583,197.316642,128.132231,53.075471,52.601536,82.588466,96.229313,78.101418,37.633207,32.341975,-10.816249,-42.713645,-91.907216,-128.859427,-181.621087,-137.82165,-111.926775,-84.164543,-82.663387,-103.075193,-128.048906,-199.749473,-189.849325,-158.907309,-159.064397,-192.184261,-270.833909,-296.863457,-299.008473,-297.522974,-338.043709,-368.58639,-352.729546,-306.30616,-319.737106,-409.55284,-420.922317,-321.267537,-210.500034,-159.474455,-17.773147,26.715612,-46.04278,-104.741727,-76.598067,-20.080867,19.108621,-0.362043,17.96535,104.596763,102.6082,-70.887674,-161.24919,-172.292081,-58.649327,-10.943339,22.394253,-2.955313,-103.290982,-135.920392,-143.557469,-150.029405,-187.422423,-186.211816,-166.737242,-183.895755,-234.836375,-302.913098,-294.997197,-262.6811,-228.967532,-192.131734,-89.925575,-53.904053,-54.20934,-66.109317,-63.449759,-53.926471,26.321765,170.157102,180.571233,62.268404,8.09686,-4.079128,2.259364,-44.548597,-57.875459,-17.86994,50.125754,42.948895,-48.156095,-104.278974,-192.698296,-226.276404,-222.596454,-151.84084,-130.32356,-142.181129,-172.975703,-194.552027,-171.830094,-157.945928,-180.208879,-173.336176,-114.568556,-77.803178,-90.281466,-151.750376,-239.600975,-235.192731:-8.671001,-69.485605,-95.161951,-148.324332,-180.379741,-166.654671,-117.873443,-68.525053,-104.461989,-104.527469,-19.85358,61.912658,236.266007,292.951815,350.477571,361.404184,327.283238,266.349828,235.218203,165.809054,143.681658,108.816805,69.509703,-37.951374,-139.159123,-176.972209,-163.442075,-117.423518,-57.576327,-52.165215,-13.602163,0.238311,-36.174371,-65.658337,-74.666045,-95.026296,-97.651929,-113.550327,-112.846561,-35.212889,46.757189,64.415413,102.665279,149.555169,201.750958,149.917779,11.749106,-3.051203,66.160922,116.065974,100.500393,56.482468,55.971532,35.238313,-4.571528,-51.501354,7.674613,32.945886,27.17939,35.207564,86.932308,85.34187,30.576685,9.747303,-7.697977,1.740618,13.622661,4.784998,-23.346059,-48.283749,-24.494623,28.123765,49.249344,84.51932,182.491792,202.449852,183.567653,166.197911,129.279447,122.638031,243.233288,493.234226,544.082872,457.291055,399.207131,370.677893,380.9054,339.629319,209.272152,149.332667,101.786757,104.640796,60.943514,7.831926,-43.337915,-22.064137,22.359105,54.514891,82.964876,102.534678,85.97953,67.168428,66.504809,-6.86501,-174.000525,-245.975496,-292.050731,-263.009386,-158.213526,-117.091216,-95.943449,-84.802206,51.307597,241.107242,277.367209,278.361401,282.772872,263.432066,229.898451,145.716677,73.862066,60.021084,71.540747,80.772291,67.676043,52.605706,75.247156,113.677916,194.774783,311.41804,366.200806,382.390015,352.918276,267.505646,240.652987,274.649939,337.811688,342.517007,343.618755,367.177373,370.312748,325.650379,259.613234,248.059602,182.561025,103.528061,93.676291,87.537262,44.143255,-82.00542,-109.011548,-121.615013,-178.589718,-192.572725,-158.885027,-139.569292,-83.916691,-39.153885,-17.078289,-52.069161,-100.223416,-58.557113,-45.739623,-64.026941,-84.701069,-168.117523,-209.344561,-203.622365,-113.847924,-64.925462,18.522133,44.729929,40.368471,8.414233,-60.307704,-77.93064,-79.09844,-60.368307,-64.591678,-94.707104,-90.246476,-35.428107,-12.697385,-13.109229,-32.846702,-24.217072,-71.955438,-154.336516,-301.124355,-326.330226,-285.09109,-240.547089,-162.591481,-75.393351,-54.550938,-103.053421,-114.154909,-19.538634,37.65472,90.347101,120.699198,127.851809,97.855567,89.264953,124.368306,136.559636,151.735973,178.847332,219.631793,142.441678,68.076061,-51.318156,-75.64683,-109.204928,-138.848357,-199.664143,-215.231129,-215.051038,-254.0954,-294.397981,-405.663564,-460.391382,-464.830591,-416.593757,-316.666295,-221.097197,-188.31505,-172.281519,-178.595856,-229.398682,-265.449016,-318.522134,-327.315773,-317.69465,-322.842733,-347.700882,-369.476491,-339.179394,-232.85746,-187.037655,-104.98202,16.457857,62.802005,58.585417,19.510644,-44.901092,-27.754545,91.486235,96.55323,11.194462,-205.227895,-263.620726,-222.889607,-162.613663,-83.503838,-84.748158,-142.035759,-156.125417,-140.956906,-118.821611,-134.247077,-212.459589,-206.847002,-46.492849,53.425656,27.642039,-71.006176,-89.465627,-23.443102,51.912458,217.027354,265.982443,274.117157,231.706536,233.043147,282.76931,271.74834,151.661454,97.219281,78.24512,121.821545,106.821996,15.501169,21.890435,173.590524,230.989122,215.939313,195.946394,240.998141,353.48577,372.362515,269.8436,187.161088,103.476633,104.768064,78.738993,52.969436,66.937973,76.363005,58.411323,-6.253279,-41.601312,-50.228795,-20.119758,12.43818,-27.797797,-59.890587,-110.56711,-113.966126,-112.774953,-131.10746,-182.595746,-178.287361,-148.870885,-119.955165,-142.941068,-177.419728,-155.730496,-104.008228,-114.642619,-171.283819,-158.85855,-121.665386,-49.303791,-43.176866,-86.485317,-98.477496,-45.340782,57.3494,101.042884,171.430536,208.300627,257.831002,257.271618,259.2941,270.304339,282.153604,260.560597,212.602768,95.742286,72.263696,92.918608,102.356594,66.429049,37.745506,58.317737,70.982655,34.708482,-29.251903,-23.963,38.325375,64.381392,28.150754,-86.51912,-125.254688,-144.90496,-164.451118,-266.770891,-325.758193,-416.204051,-425.705347,-405.121398,-316.262092,-243.531387,-115.02463,-93.892702,-125.58643,-136.772861,-37.122201,106.391715,91.648106,-59.393112,-121.030741,-174.99548,-179.109651,-179.599125,-182.243563,-163.405989,-160.325862,-203.290064,-278.622982,-283.60666,-260.581356,-263.972387,-313.125768,-308.279148,-295.843302,-298.527496,-293.995216,-200.793896,-120.692813,-50.596537,-170.564385,-232.817523,-273.742255,-277.123051,-288.443291,-270.551394,-174.402976,-148.380193:79.604812,-33.46573,-56.324209,-15.679079,34.793795,72.822115,61.949969,69.002935,91.629526,94.544262,66.206761,70.898577,203.797166,285.950189,341.931472,316.902968,247.882824,218.301867,205.335011,178.864786,161.369075,78.943662,24.690112,-57.932787,-72.306657,-51.341155,-0.660577,9.895398,-9.336237,-30.95343,-59.418426,-76.333661,-133.318166,-120.102754,-82.41071,-1.734873,5.185208,-67.908416,-90.447259,-37.864224,48.643845,87.466535,122.01728,125.275286,177.183066,204.304654,157.263311,98.773697,0.769435,-35.412346,-10.883506,118.709479,161.216559,124.30027,93.070608,55.368706,42.375788,59.961882,85.696692,85.848173,88.219158,82.013344,57.361483,52.959711,102.339827,186.296773,171.973899,33.290295,-24.46837,-25.562999,2.375814,4.80352,-45.945988,-56.226849,-30.67342,-6.172771,-13.85478,-64.166229,-157.457065,-145.329182,46.262427,312.189028,370.595288,328.197775,281.834367,216.533726,214.679176,198.345329,49.405243,-29.169384,-94.115428,-80.945295,-29.621883,-27.878635,-80.421456,-126.395192,-195.409127,-73.552248,34.815454,147.151064,109.478181,-58.600547,-119.096706,-194.664237,-309.654973,-348.915679,-334.774981,-295.891756,-193.516031,-145.709629,-118.946785,-133.776536,-94.066675,97.375016,197.860884,289.837795,282.485984,245.29137,235.660525,197.781874,103.085804,58.696343,24.574474,32.701832,26.228317,3.167168,4.943223,39.778533,137.403111,277.092589,335.815891,355.412771,324.260667,228.960606,189.550016,128.467628,65.188482,57.815225,108.372791,147.142591,177.41446,167.836674,174.488139,169.392267,33.724796,-74.272344,-44.654113,28.010876,-2.33982,-145.716121,-200.934077,-248.190159,-275.281524,-287.317651,-266.101531,-231.905121,-162.580565,-140.00822,-141.424855,-182.880734,-261.600094,-176.556786,-127.482196,-116.481452,-129.42018,-139.829595,-135.868282,-131.562182,-120.970744,-104.771763,-43.034059,6.023319,68.199995,33.618958,-114.480657,-163.56114,-165.017108,-41.814711,35.830905,132.652868,141.278934,65.460179,6.861652,-28.392003,39.862809,58.610134,-28.955277,-113.219448,-228.594707,-242.782771,-217.903244,-197.455681,-147.903469,-27.301588,28.873577,43.636825,18.028658,-26.414925,-40.561303,-87.99476,-133.744318,-128.059824,-41.740745,18.547282,66.063021,42.269347,19.827352,51.168113,60.398189,-99.078984,-164.05225,-138.079552,-98.794735,-121.02401,-173.494976,-277.953213,-267.536709,-214.894798,-174.03215,-222.043487,-359.494705,-395.75937,-361.007,-315.909634,-242.560982,-147.224441,-92.079309,-43.100931,-61.005387,-108.084121,-116.594443,-181.422216,-326.774901,-375.981075,-384.549258,-365.484471,-313.391113,-277.514192,-215.357135,-214.893898,-226.958222,-159.644233,-121.573055,-74.858136,-56.520282,-32.509564,-29.405565,-22.981676,-20.057719,-57.813959,-221.088786,-275.48412,-197.601549,-116.231099,-81.371291,-141.322513,-251.354073,-222.182043,-197.680282,-193.070167,-205.703235,-253.160392,-266.942791,-230.500216,-140.035162,-95.700712,-77.462589,-75.949874,26.273397,96.557878,126.957825,77.575821,-27.118536,38.280119,124.98578,223.647112,178.12096,-26.53296,-80.875237,22.316738,194.450555,204.664188,124.816751,118.920984,164.890298,157.207606,90.717997,82.538298,186.971931,342.539515,369.061697,272.335849,189.216057,141.637606,172.460603,145.760536,64.64176,67.292994,97.541271,104.366071,100.270881,92.744504,86.38873,75.942284,7.593054,-93.767739,-127.494771,-102.455208,-54.491446,-32.257551,-88.152686,-221.680019,-222.391489,-182.440181,-153.029938,-179.513304,-225.027277,-215.163059,-165.288962,-167.012927,-230.799468,-232.233663,-210.564071,-141.611057,-83.266741,-0.440573,-7.614244,-43.894971,35.940532,107.809719,196.591479,221.820993,325.432957,391.246426,459.915378,443.530922,360.290063,319.350491,325.341248,369.685716,363.230701,222.263989,155.783615,166.992989,188.736905,172.542468,142.620489,123.521963,63.564779,44.447064,77.101164,97.162295,66.871272,28.11499,18.335858,-9.253168,-20.112736,-54.364567,-109.041588,-284.909811,-366.414808,-328.194757,-138.943711,-52.109291,-16.811474,-24.838127,37.147463,89.126693,160.144448,178.487957,169.650714,140.159225,119.703135,40.549098,1.764304,-23.529613,-1.08713,20.744444,20.854537,-10.869553,-34.473155,-3.014501,23.62896,-23.4457,-128.517387,-159.388798,-180.290673,-218.817418,-218.700562,-190.55813,-164.284731,-95.812498,-53.110873,-67.14748,-131.329638,-150.314558,-144.095415,-121.684802,-111.224169,-150.838622:-4.357102,16.041588,13.568939,-51.972764,-109.764087,-186.526177,-186.108032,-118.538266,-31.274392,-15.541125,28.259612,122.935429,389.26159,445.745688,341.296619,271.494595,243.671525,251.947416,236.774029,209.204093,193.806363,121.893106,70.899912,17.278946,57.342982,33.624898,-125.416236,-171.267712,-105.040612,-28.59214,83.355386,48.355217,-132.738738,-91.632428,-25.696737,-35.575428,-104.036479,-241.773478,-252.597603,-135.459899,-46.297429,-32.850653,-3.984998,-1.887961,-54.05662,-77.201926,-23.336141,32.830685,85.986106,-2.529586,-91.037725,-174.300137,-122.58777,-11.681811,-9.29885,-22.958238,17.907267,35.826799,26.869767,7.798155,-32.37535,-43.461069,0.798553,56.417434,114.140764,49.545208,5.011514,-45.757366,-43.889893,-3.77293,20.059666,-1.242756,-40.14823,-10.202421,26.431268,4.359831,2.232859,30.845218,56.332581,51.12438,124.542149,327.935439,365.858846,208.501398,100.629775,34.219452,58.947094,97.16449,122.239292,142.940615,151.115789,121.065657,-12.287839,-88.815418,-120.395838,-63.475638,50.490402,42.78347,8.518717,-40.986885,-39.827399,-36.809415,-46.326502,-67.178445,-127.699934,-177.960209,-266.426161,-278.29388,-235.066145,-203.577372,-133.249543,-87.316856,35.846238,144.496986,148.294825,104.352976,98.694588,138.270249,167.573139,131.717251,-15.415682,-43.592464,33.582044,60.917266,-68.243509,-163.75897,-143.506189,-39.727451,151.266755,284.72579,309.569099,234.905878,176.370412,127.616551,149.455802,224.502542,284.468264,313.941895,321.645061,297.680593,211.746628,154.303535,84.130043,82.514632,69.286915,4.932469,-21.453525,-20.555013,-24.921326,-144.48386,-215.974033,-237.885526,-182.902737,-164.823246,-157.963555,-154.459164,-104.230788,-80.496981,-127.213284,-179.634547,-197.35383,-81.402231,-24.159925,5.326113,-27.371352,-108.393763,-114.748976,-36.298388,83.248706,117.693774,98.129882,74.970804,50.166791,35.246114,14.595725,1.239846,-47.132579,-22.541931,3.611984,33.05372,33.242496,-4.776088,-24.617852,-57.327229,-75.245238,-56.336635,-16.967292,-8.524463,-14.940458,-57.374392,-189.634408,-221.500485,-156.432027,-50.078969,-35.109547,-4.083234,35.882823,87.299977,94.409415,123.697023,130.320404,120.889592,115.201563,111.582904,66.012112,35.765796,54.147084,107.796475,188.256573,173.195579,166.353359,151.993476,91.569046,-70.639694,-85.173807,-46.515822,-56.862096,-42.407372,2.471571,-12.557174,-140.101605,-207.92405,-225.44579,-201.778426,-191.28602,-148.75919,-116.902423,-80.934501,-80.154606,-159.16066,-242.121268,-340.493397,-211.932927,-164.525059,-292.737953,-367.615022,-262.137991,-140.105137,-26.654726,-53.876154,-148.383263,-136.441901,-113.009943,-131.590464,-160.678689,-154.184983,-102.604628,9.761249,-13.899251,-62.42794,-116.909555,-113.049217,-90.82358,-85.844962,-90.916928,-100.34052,-121.94522,-112.381676,-91.777095,-66.79525,-95.634744,-209.848682,-229.810793,-105.200513,68.66939,104.88638,88.745041,90.349624,178.041761,210.859859,205.283657,234.572894,389.199139,423.049537,385.61433,365.246267,365.692846,248.049833,173.171033,144.715903,196.962824,200.459423,127.004535,99.503674,200.861444,294.674114,324.190513,240.132004,127.891994,198.911918,206.863091,121.985921,74.213119,21.559751,24.148126,67.445596,110.350432,128.277016,160.719115,158.558426,69.521666,0.256761,-92.334308,-106.266768,-99.229353,-99.059587,-132.630776,-168.203211,-126.217895,-67.012141,-102.912163,-193.712073,-156.284605,-130.542269,-189.357497,-242.57774,-267.601976,-251.94165,-245.22084,-275.913197,-397.045713,-380.347534,-306.091427,-203.537731,-206.107559,-270.057301,-290.481345,-249.891875,-119.890355,-37.684495,80.827727,85.771247,19.921533,-7.176023,24.11411,61.398491,105.296497,134.24099,143.945046,109.607074,61.474567,2.97635,13.681468,29.119584,28.740241,23.445466,-44.901011,-82.743915,-100.278913,-99.356115,-104.814211,-101.34634,-70.492546,-36.262033,-42.156497,-158.13318,-247.798195,-364.295841,-390.659863,-432.51687,-381.369782,-318.752827,-237.417051,-219.677637,-150.364945,-110.477484,-57.337095,-30.221246,69.417864,136.340142,82.90555,-94.454206,-133.572453,-112.270991,-88.25122,-70.654531,-117.923613,-139.210671,-152.375685,-153.987947,-169.278143,-179.637998,-178.115232,-199.725598,-296.222244,-294.822881,-260.894911,-209.473276,-197.846232,-157.235778,-126.743976,-90.70087,-88.558287,-99.608878,-163.831898,-196.2265,-185.545337,-150.792914,-109.85309,-135.194375:right
69.089499,138.385037,104.342191,-35.490392,-88.598107,-149.716887,-175.55012,-228.710158,-286.386629,-298.065628,-226.746608,-170.863204,-116.298117,-100.058556,-30.23045,2.933837,29.070953,75.637808,97.844995,47.270911,-28.071046,-165.730743,-182.743388,-166.488561,-161.850538,-136.920905,-112.826054,-154.655446,-241.496766,-240.270274,-195.285332,-187.143059,-197.479216,-176.971908,-168.976296,-186.511629,-204.627583,-259.94439,-283.938366,-260.618695,-141.852433,-70.108571,4.056027,-6.513807,-83.568493,-130.494892,-148.913874,-106.212032,29.822954,199.702832,260.956963,215.733276,113.59099,-40.770898,-33.049511,23.641796,13.034976,17.279773,56.774797,52.21904,-66.770486,-136.177519,-161.60628,-141.104127,-101.470125,-17.165787,10.937967,-5.000065,-24.011516,-23.724655,5.460028,55.970338,78.966321,117.363,158.166132,116.230554,-25.133711,-66.459173,-39.592556,-8.323343,-1.682077,-23.731004,-17.957893,24.871371,16.253342,-149.908143,-255.256796,-343.110646,-284.615223,-244.087389,-221.672523,-236.686113,-266.826856,-265.458657,-184.616389,-135.876896,-104.224861,-50.671709,-16.921181,-49.673725,-111.098274,-186.851779,-166.114925,-80.818203,-11.937859,41.596062,118.042475,91.531263,-13.342342,-22.334326,84.920275,157.332256,248.917561,255.631942,215.184617,117.45074,95.494532,45.347015,1.058151,-56.82418,11.366282,71.877511,122.460595,109.946833,97.530749,120.738719,255.470967,321.344506,290.546022,130.768797,40.398636,-144.639079,-206.933231,-237.054912,-233.495129,-217.51578,-135.890093,-84.073238,-10.66467,22.910153,68.541766,55.602084,-12.189333,-31.805596,-13.517001,-7.677622,-67.475456,-257.119956,-313.338026,-313.727548,-286.145769,-200.406953,-57.105594,18.747466,84.29074,64.310192,-29.430769,-69.831355,-46.809327,-6.871752,0.559167,-4.485755,13.631993,10.508042,-31.604077,-154.465628,-193.727288,-203.211546,-145.912102,-99.295518,-59.027624,-85.572826,-170.936971,-208.931299,-248.233418,-231.844253,-127.38203,15.589129,66.281318,23.17911,-77.17061,-248.732511,-225.416285,2.297784,172.547653,204.981477,237.799929,262.504742,261.876477,198.461921,68.225377,59.322508,117.253726,203.950284,241.997229,243.39854,198.630564,105.959131,99.20166,126.309172,163.652084,202.308305,197.710205,106.689223,-182.748195,-293.416486,-282.72505,-194.971123,-27.704531,-30.926389,-126.873441,-348.879926,-398.526164,-373.913117,-327.095755,-203.548738,-110.289064,-81.730736,-20.388844,16.174015,72.08288,89.938922,116.557891,115.323077,94.895432,91.042157,86.235208,63.26195,12.662205,-160.764482,-191.225211,-65.538349,37.003637,28.247189,-18.066146,-38.785911,-109.418618,-162.280356,-213.035637,-172.711391,17.769989,183.019842,180.520423,47.88546,-7.568327,-1.20078,60.363283,214.066304,204.503513,145.379851,112.136966,170.543945,300.134953,293.956316,203.183488,212.540502,359.513371,455.840548,454.114595,387.994733,323.640837,176.81064,131.639612,58.831863,-62.220601,-95.100532,-68.984907,-37.639739,4.407132,6.417119,20.924361,40.326212,49.338868,39.528034,29.625644,-19.020399,-50.571476,-86.176183,-70.094392,-43.156623,-110.595927,-137.769003,-170.04501,-196.036001,-272.651206,-306.24166,-249.309316,-163.457583,-66.116207,-97.079292,-104.14902,-74.728479,-59.857304,-86.925346,-121.659192,-173.042494,-180.224632,-159.942746,-114.995905,-123.61532,-218.018788,-267.804415,-263.343898,-222.662475,-120.798404,-13.712327,-5.050719,-98.586385,-165.897146,-271.378373,-269.022849,-141.681389,-69.961942,-67.733142,-35.875203,-35.653394,-150.839307,-234.867313,-339.264585,-349.066683,-322.484608,-247.618735,-208.188833,-221.07746,-274.941489,-357.910057,-355.977203,-272.964259,-141.713784,-99.09801,-76.979278,-66.065102,-65.825559,-120.067724,-263.098899,-262.264106,-98.121897,57.521397,86.93248,13.46456,-85.831989,-258.787957,-262.282549,-125.55671,13.234285,56.094159,83.104317,65.018921,7.985806,-12.129472,-14.143342,-2.799727,19.047837,81.257452,129.235205,158.908375,106.539897,-23.455486,-21.66218,65.708793,79.92949,66.743395,14.063994,-0.96224,55.466237,82.286128,73.057372,76.244045,147.721603,273.18002,323.335135,318.00281,254.701851,101.070318,73.12194,90.956408,39.668078,12.315393,36.236629,60.848937,50.235872,18.250785,-18.714722,-14.309921,29.396325,148.232542,195.557551,190.370738,146.183978,17.573964,-27.028216,-15.162904,98.555733,172.74108,187.329261,82.257871,-192.689963,-262.25036,-196.243321,-110.94:221.878863,209.770058,127.7758,-103.663543,-174.713755,-180.120114,-163.570735,-166.197271,-211.465803,-253.446871,-276.592313,-232.948656,-142.498856,-122.031877,-48.288954,24.289363,140.739893,138.702527,123.309469,92.235718,62.072595,-20.044007,-59.571173,-137.51425,-131.20082,-92.868791,-89.386345,-131.750239,-167.172086,-138.402184,-89.17245,-99.412283,-94.083218,11.434933,18.218461,-113.276489,-189.408841,-265.865918,-272.644412,-278.408499,-210.288187,-133.148492,-60.119077,-98.528432,-217.819014,-246.689882,-186.934604,-131.383706,-32.726164,100.989879,154.006065,131.020633,51.341657,-102.684025,-104.688226,24.308651,71.960756,20.200452,-125.305463,-189.760478,-319.451075,-355.260767,-306.652566,-267.161839,-217.980651,-182.585182,-211.091613,-318.384838,-335.291933,-282.481806,-247.882625,-205.544187,-89.390721,3.481674,66.712579,13.565974,-90.288221,-87.160425,-12.723464,26.887949,120.029375,151.060444,103.962374,34.303429,41.61535,9.388157,-41.182968,-135.28924,-207.248389,-238.530826,-285.034916,-272.355111,-165.381163,-126.897295,-119.117216,-104.727663,-36.564989,10.168527,18.291299,-13.130194,-49.416872,-97.167513,-98.438285,-95.371822,-58.088107,-29.237,-24.612787,-53.07024,-121.01448,-133.919243,-105.583718,-67.115398,47.542298,118.896492,114.251638,81.510097,69.194323,44.349105,40.104313,44.617113,65.816902,92.912769,109.311282,82.581874,21.152711,23.881914,153.408662,229.375161,197.107132,2.98537,-64.123789,-171.155919,-250.70849,-353.088116,-338.980794,-286.680477,-271.086888,-258.582509,-227.574283,-209.684721,-179.496032,-164.824388,-105.91709,-68.824462,-14.139217,-20.416417,-54.049807,-156.657122,-198.526653,-228.5662,-213.510851,-122.088632,-5.820703,16.479642,-52.916907,-106.426777,-177.143562,-188.291926,-130.612858,-84.107011,-74.286055,-147.987745,-173.45023,-172.043286,-164.776698,-129.746713,-90.426119,-76.075827,-156.404565,-154.088648,-46.679166,-31.458179,-209.503579,-318.371768,-332.294248,-252.631612,-127.431238,-129.278408,-127.891027,-75.687484,-65.557149,-147.948172,-192.778128,-150.950726,25.899682,113.30521,179.874694,158.041726,74.181822,34.067903,16.504114,32.749495,45.517437,74.374599,111.546878,152.105447,119.671504,52.389566,73.146886,143.162794,192.250994,211.821848,134.839576,31.923908,-227.931689,-326.637765,-312.27842,-232.567053,-127.709612,-174.677038,-256.883202,-452.36745,-508.485731,-470.16755,-394.063602,-253.357479,-194.502691,-170.517866,-98.801603,-58.265386,-7.797948,-6.342202,-11.047905,16.057397,101.710828,56.685424,11.630806,-17.84829,-43.10135,-118.722074,-105.475639,-16.677506,15.71399,25.779017,16.521942,-23.092954,-167.586976,-226.672461,-176.516681,-85.229057,26.285799,-55.574209,-103.900318,-64.641756,-5.020443,43.527127,52.851236,117.840715,129.15211,102.847315,97.515665,136.949062,185.260629,160.738188,121.764871,152.622697,265.708868,317.966128,293.949807,171.015235,104.71938,35.537087,29.559839,-27.979092,-161.639695,-221.641213,-243.941519,-201.563418,-148.117949,-148.696594,-94.280734,-65.406597,-100.069412,-133.360995,-125.350956,-122.897502,-146.534649,-155.733646,-107.547662,-9.992833,-0.955425,-15.410408,-66.043368,-92.852217,-156.76014,-180.900381,-82.910236,22.779375,127.905398,62.59012,15.244689,-77.043321,-117.680692,-156.970832,-149.278724,-109.431538,-66.171516,-26.577757,58.74525,64.643273,-11.380733,-41.185995,-7.024274,26.771591,113.089126,202.231456,170.091183,-9.933869,-73.404224,-104.537154,-80.771996,29.706496,77.2774,59.294568,32.134342,18.973629,-92.400585,-176.008095,-269.262184,-264.523792,-191.671588,-118.754246,-115.776354,-182.539801,-239.972976,-305.532483,-285.695473,-174.319144,-76.761863,-74.838072,-89.11041,-64.008682,-97.182635,-212.294858,-391.157528,-333.159806,-40.827503,87.815829,50.058408,-83.102814,-131.179715,-152.668427,-106.446453,27.30875,64.931451,71.502799,117.451077,147.847193,157.035591,131.245767,108.960958,118.151565,135.976624,169.330475,187.946407,178.023887,132.253506,29.318324,29.154717,124.789888,213.297073,217.053802,86.575913,-7.629299,-61.44713,-13.035001,106.555931,145.332991,194.154063,239.044073,259.868783,296.212543,293.235253,205.460699,147.793747,82.721349,60.342851,50.897386,18.483982,6.305342,16.224944,18.198059,-28.549723,-55.047282,-10.406781,174.598547,236.134351,123.193832,-13.056209,-159.173499,-115.328548,60.531585,212.315985,254.521756,173.756493,63.357428,-132.304608,-165.015914,-143.210639,-125.931675:184.017415,128.397703,80.960668,-84.085702,-182.137009,-286.674108,-270.150109,-172.7024,-188.380012,-247.61162,-255.585223,-185.638803,-99.375755,-91.147996,51.973924,177.395549,318.166747,265.558397,199.059784,79.741283,58.294089,66.083017,61.796248,15.835471,-11.035768,-3.728177,-7.660666,-52.746142,-185.977974,-203.183908,-79.994049,-8.30289,34.159901,37.067908,28.038132,-59.737326,-112.443376,-160.267181,-155.783723,-120.826217,-20.512479,40.713341,50.446319,-12.488195,-187.867193,-247.099338,-231.436641,-173.475018,-4.980632,110.541458,101.680972,-0.61604,-64.101308,-144.908123,-136.124075,-64.603382,-54.411108,-78.779031,-125.409271,-154.829958,-312.620998,-400.045292,-404.745442,-341.826101,-243.294239,-263.626027,-316.85079,-415.251011,-416.170503,-307.611049,-233.087554,-132.092003,-73.27623,-35.804322,12.527472,5.457888,-35.314035,-33.820515,73.239546,174.971825,375.494022,301.180432,163.297002,25.864895,55.490731,92.482356,66.962009,-15.187779,-119.897297,-151.873855,-155.858182,-154.551162,-187.894134,-215.805301,-251.215665,-244.686078,-161.167876,-43.781934,-23.001864,-103.19448,-172.185244,-221.168949,-189.693978,-119.491264,-69.557018,-46.845185,-71.579846,-123.323061,-217.81403,-228.593273,-172.613891,-112.224684,61.114457,147.353137,127.08858,92.066049,95.805525,106.402099,110.197134,98.052461,84.743194,97.92975,121.443399,100.59625,-10.922541,-40.952911,60.307874,132.212929,169.363984,87.12398,9.333709,-199.68238,-294.34954,-367.2864,-353.561527,-297.808154,-219.165212,-188.798636,-171.454418,-176.496931,-226.901643,-254.38191,-175.424778,-75.395145,58.297047,-22.281738,-112.211959,-230.75226,-239.487283,-217.629518,-192.718744,-108.865713,-42.246746,-53.49777,-153.184239,-202.622805,-261.188519,-267.634223,-209.679606,-170.144895,-137.467031,-94.846539,-85.231302,-163.732466,-220.751566,-213.670497,-141.390001,-39.541488,-27.604844,-10.414566,-3.781814,-40.410897,-177.313039,-241.207989,-249.001651,-189.855073,-61.530326,-82.400459,-127.298663,-150.466278,-136.665586,-109.82361,-96.130537,-83.71361,-23.288564,41.029504,144.25848,157.070503,87.302666,26.991098,-28.662864,-15.004157,51.47682,102.919542,84.983303,-12.775644,-52.034496,-26.721111,32.341252,127.952808,169.465333,173.964665,108.234447,55.110699,-66.387439,-124.45738,-176.87425,-175.026828,-132.689002,-87.332959,-116.329729,-309.017402,-422.708709,-469.083129,-371.803515,-131.000316,-37.935001,-33.436358,-14.220561,-3.316447,-33.858558,-41.0726,13.953503,44.649109,70.762735,21.903762,-23.134314,-91.052902,-113.568625,-109.800095,-60.029871,48.270472,29.678277,-15.996422,-149.612432,-216.768927,-302.082318,-307.744895,-213.889998,-135.252598,-18.343777,25.368672,21.2715,-63.673725,-115.861543,-103.589585,-30.225922,113.609396,130.677906,100.222936,36.822829,29.112974,43.69743,45.277639,76.428755,136.94385,278.793206,291.893313,240.688907,78.159451,8.900976,-8.473996,29.025051,21.53553,-124.482913,-178.843014,-186.33031,-151.523498,-101.284494,-107.009707,-144.058801,-160.929578,-163.116038,-124.431262,-127.878825,-162.804317,-144.945218,-60.317032,-35.271798,0.960411,66.614323,81.051849,43.361353,18.141306,-10.389938,-1.642363,92.722828,139.227254,117.412218,3.490815,-47.610101,-108.143641,-114.612265,-87.083273,-68.113764,-59.895584,-18.769716,18.514103,59.022673,63.578333,50.481465,28.183801,21.586991,67.973262,228.632829,361.65083,341.812662,113.889434,3.089579,-11.934486,52.828768,130.694542,135.818737,129.461267,115.745338,112.943179,20.438856,-69.097016,-168.605074,-146.053024,-41.27059,-9.407071,-47.500239,-196.412356,-283.189968,-364.941847,-324.875811,-170.683542,-66.164317,-51.57976,-92.090264,-127.376083,-178.694024,-195.83185,-189.314777,-144.178728,-2.794728,94.603273,63.47823,-155.218775,-234.126661,-184.145152,-101.433104,18.799113,61.655298,87.893833,112.680578,91.774991,35.621539,37.95827,142.761542,213.35958,277.085903,201.898521,144.379153,64.580643,38.177546,59.37642,107.209476,137.485573,137.620692,168.634008,165.676156,140.957073,170.311024,192.706355,171.904799,174.574671,262.01723,289.390107,263.736905,215.926618,194.431764,160.599673,135.720109,2.168832,-83.333366,-65.823763,-58.010006,-87.678151,-92.569742,-48.774127,17.378194,8.215744,-8.842957,73.821172,110.128034,68.271438,12.808391,-25.103876,10.450994,105.204953,165.538643,164.56134,67.382957,-7.685622,-107.57496,-121.240793,-148.434307,-164.893374:89.8492,115.170452,23.856606,-218.30694,-283.243853,-309.159442,-319.964279,-336.703796,-270.575385,-226.341231,-175.782129,-155.550594,-92.84961,-53.848505,77.090901,156.975668,215.313496,162.555826,136.012835,78.969536,30.872932,-73.850954,-100.049708,-135.022782,-139.780468,-99.689508,-32.98534,-54.451265,-155.731956,-185.093786,-182.677107,-169.775713,-101.868285,-6.644363,-10.403103,-130.711797,-182.352206,-177.314162,-141.326746,-93.696092,-21.67264,65.138925,200.855279,191.166822,49.95865,-23.224877,-61.299452,-38.445057,90.078447,293.786265,317.996206,186.019596,100.920826,-31.643569,-53.661023,23.576121,94.137069,62.221713,-80.628259,-126.544553,-150.884165,-166.297698,-212.298028,-229.631609,-215.266627,-148.868908,-140.361053,-142.665515,-118.238889,-73.352848,-73.434711,-52.827428,96.197103,201.717196,291.863167,240.812176,83.97219,50.35952,106.096145,163.922663,261.557813,262.841118,220.035987,119.455307,77.276146,7.168159,-22.569156,-130.472528,-263.670571,-274.647062,-193.985519,-165.615911,-255.18195,-322.439405,-269.179333,-171.956229,-76.825052,-98.680244,-92.198641,-59.981553,-61.411672,-97.137468,-98.609278,-22.259528,61.933293,67.335137,11.398205,-4.593763,48.703348,81.421186,117.91786,129.36931,163.634824,256.512392,299.387276,304.429619,258.145775,113.493772,61.34255,40.048336,75.245274,112.339645,145.290509,95.055885,-74.278344,-99.396849,78.328885,183.294936,173.368362,48.619671,5.439042,-129.999236,-227.070457,-332.943051,-301.260733,-157.135316,-49.418936,-15.235501,47.683389,67.556141,14.608475,-36.370551,-43.915278,-9.785084,14.446926,-31.878842,-77.055148,-202.152973,-256.391584,-249.370513,-184.93682,-34.516095,68.252854,90.097853,62.256879,17.724229,-160.796416,-261.424205,-276.523545,-205.924222,-106.271208,-31.528878,-4.474768,-67.94649,-128.401974,-155.096401,-112.470096,-48.376952,-90.442825,-87.984165,-14.654219,-9.903147,-120.51657,-183.114188,-206.366764,-176.514023,-89.969188,4.791338,37.988092,29.451578,-11.976406,-100.378194,-109.498657,-25.244141,103.500925,137.222868,148.318819,155.029305,149.551493,115.265822,40.400601,19.300886,-1.785567,42.72141,68.382976,71.138919,49.052497,-13.233964,-9.745345,72.460782,142.895785,166.12067,118.389011,30.368621,-203.092956,-280.781675,-212.581184,-125.235026,-73.630506,-146.347496,-189.554277,-241.81388,-252.591297,-273.643924,-258.617323,-119.792985,66.929853,124.432436,122.050033,83.845529,8.71876,-0.119351,98.663787,172.50509,200.595543,111.797416,86.216323,73.660204,46.177716,-110.324221,-179.296111,-130.101328,42.062064,71.117962,-51.699132,-144.154511,-234.164865,-227.857803,-166.876279,-124.420395,-11.652252,88.078622,66.932249,-90.717022,-136.381381,-58.150928,36.552195,169.576413,114.219221,74.636651,89.252579,124.047066,146.705162,130.237652,123.201318,148.222284,236.443708,325.242508,325.729303,218.295291,158.097709,124.442345,139.722624,102.157605,-15.11484,-49.084418,-65.218586,-59.053819,-51.897546,-50.713782,-24.170567,-26.369916,-95.262513,-113.748711,-106.846182,-113.9377,-127.023435,-157.683782,-149.590669,-73.485278,5.579084,26.444613,-8.569145,-48.522173,-112.248786,-133.770688,-79.781161,2.662113,87.281652,-14.089388,-65.77977,-120.125359,-146.03764,-202.821061,-200.148809,-120.643219,-37.356686,-15.239853,-16.771737,-25.929651,-53.472605,-83.538763,-88.608303,-18.0638,196.246663,261.184145,195.420768,5.507312,-56.849054,-62.613199,-0.692771,120.828053,53.54396,1.467109,-23.013615,-31.739828,-118.438419,-167.166032,-188.014708,-180.90979,-192.774066,-154.80581,-131.227279,-193.329898,-280.190577,-427.125968,-415.412106,-254.802643,-181.032789,-179.781896,-168.929271,-171.874277,-232.740726,-285.564833,-317.841823,-258.902164,-57.659938,22.060617,-37.721079,-216.658994,-262.843846,-244.202344,-207.500055,-116.675685,15.598898,61.238197,31.009906,-14.026053,-58.905469,-41.638784,70.917146,126.533619,150.894911,157.123258,181.879565,205.471539,170.059928,63.312594,50.518642,112.821086,156.372435,140.019512,54.173793,30.29351,42.186536,45.623119,53.046901,66.7658,124.264382,228.971902,256.755126,213.128068,161.487063,62.011543,25.959448,-24.709298,-70.761074,-87.838708,-76.240964,-68.256273,-115.363938,-140.833169,-111.121685,-72.237883,10.257832,161.640108,227.877738,168.057311,63.773195,-68.023772,-65.769471,-29.857547,29.679185,69.418234,31.508592,-65.243065,-273.255231,-331.929159,-319.15019,-262.903395:83.950645,82.931718,38.681852,-112.742064,-186.34842,-293.331632,-316.826729,-235.309998,-79.826047,-51.463529,-59.347271,-47.612036,0.819219,23.655041,126.283661,212.504504,376.323015,406.432715,334.991257,105.915344,13.296889,-45.832999,-33.032549,-50.486663,-118.069622,-107.492606,-39.482761,-58.349364,-205.725509,-247.190368,-164.152882,-95.749416,-29.109043,-15.252429,-34.161487,-156.656674,-228.381146,-268.459813,-221.658569,-90.515674,15.140064,55.770741,75.558297,43.769315,-96.639453,-148.660033,-72.990537,17.938558,163.534631,199.864451,168.71097,65.704484,9.283501,-56.971929,-47.952618,-24.267149,-6.194954,9.105433,-13.022408,-54.744906,-173.699585,-222.136421,-210.626765,-164.55112,-94.235729,-122.15372,-162.445653,-223.970104,-233.112125,-174.112967,-115.164749,-8.484763,126.710252,200.24228,258.874198,221.931086,60.126686,11.213434,96.934535,180.614674,292.475053,266.633178,191.033552,25.192412,-20.570807,-47.11576,-46.945977,-39.369499,-68.632032,-113.189669,-182.698423,-189.531533,-248.728727,-302.183029,-330.27499,-295.663357,-173.418186,-63.776375,-36.306306,-40.700166,-70.800955,-138.561869,-156.825699,-145.494842,-23.837783,33.162989,22.56743,-10.024644,-21.690775,3.028497,85.882267,134.146958,204.512017,194.373053,170.848026,135.507283,115.726012,41.260533,-3.993716,-13.975037,107.667398,137.797705,48.639643,-50.114046,-268.874268,-308.300697,-118.616689,27.378132,145.62175,22.401195,-76.733369,-242.145799,-273.023782,-267.405879,-266.902244,-226.639488,-65.208805,-2.596862,-21.973867,-66.264053,-129.74418,-124.599469,-9.706697,48.300288,75.204038,46.862204,-7.561574,-179.848409,-258.303748,-307.714806,-244.280515,0.959744,179.052015,181.32275,30.439466,-60.840857,-212.103503,-257.646171,-186.231726,-91.331847,22.203055,-20.069183,-65.965319,-163.924762,-203.827204,-196.676501,-125.491397,36.908665,55.787991,29.651995,-50.133792,-114.914761,-227.322783,-227.733573,-173.865032,-154.871782,-90.04025,0.159259,19.608484,-11.442364,-49.95338,-113.23723,-118.276895,-59.534003,91.847917,165.856724,169.910693,104.342978,-8.413464,-9.778356,47.87465,61.763291,57.040267,39.292259,26.034945,-7.831914,-32.919643,-41.387465,0.7022,130.943139,217.740073,227.050447,160.222036,89.330231,-50.477566,-73.956244,-34.994658,-26.293988,-10.429902,32.363131,13.401241,-104.553023,-166.502269,-186.301456,-135.472507,18.704523,170.790407,202.865319,122.823199,58.148029,12.579617,50.074343,189.78934,228.702667,201.781948,157.719585,132.656337,39.662028,-26.988265,-126.208461,-111.545865,21.293272,58.408824,0.988926,-152.474302,-200.614662,-249.781958,-251.934032,-159.843341,-76.530448,103.980555,182.297182,132.65355,-44.462521,-114.315959,-116.48189,-23.387364,215.189568,275.481713,230.768594,128.443882,106.296076,100.103056,112.821313,203.214919,258.779616,313.343545,303.709877,275.790194,203.964794,185.436152,208.252107,226.913958,193.595059,114.458219,94.906416,86.976359,77.060723,24.83427,6.434471,6.197014,-8.138744,-40.743661,-11.922521,-26.737499,-69.467962,-48.174874,-5.776823,-11.645312,17.696556,133.931532,184.745232,204.392362,174.68098,109.336231,104.000139,163.789994,203.55459,230.616812,166.562727,98.965128,-42.614549,-75.969659,-81.033104,-83.444628,-55.606025,124.937556,219.783131,227.475769,158.930638,29.345069,-7.291858,10.31184,90.218672,342.229952,446.61739,362.447335,43.382912,-76.636201,-92.266467,-31.407569,74.791831,174.390663,201.492065,134.702149,64.521705,-78.991201,-125.529475,-113.570693,-90.37998,-86.786846,-78.256794,-86.432677,-236.591691,-360.148542,-498.444495,-461.834414,-251.48838,-91.820588,-83.288432,-149.303111,-200.04277,-314.090075,-335.531813,-253.197403,-187.935731,-49.713293,25.662611,-20.877822,-216.03711,-287.840435,-301.929969,-263.400964,-177.857733,-92.150636,-47.177266,-45.280367,-102.814636,-213.671575,-206.917403,-58.55878,32.549963,124.831284,89.714897,63.939283,70.155142,75.370932,27.033015,-1.789156,-16.392578,26.307173,52.008425,44.002568,11.583587,-72.234611,-97.523608,-42.716899,19.714767,151.962887,254.677329,258.392901,141.982628,52.733815,-33.344455,-17.66268,-43.422786,-165.301127,-188.56051,-161.319535,-151.552699,-184.832864,-202.277934,-155.119405,-101.784441,22.265235,137.676187,154.654285,68.3574,-11.28736,-97.839918,-63.852241,60.07153,82.681229,71.046741,24.097777,-25.838024,-141.490015,-196.405808,-287.239945,-298.403008:57.888011,12.600945,-72.416979,-202.423606,-216.246457,-251.523287,-288.432623,-302.409701,-240.639099,-217.392537,-142.774443,-77.751553,28.425764,54.078774,113.764705,148.145751,162.376928,151.512113,160.586418,131.899558,57.193505,-131.509955,-178.476016,-190.537786,-159.734071,-128.58595,-121.22066,-159.141753,-243.225652,-249.138596,-148.897907,-84.670146,-13.271548,5.052624,-17.436084,-124.639335,-179.887379,-236.715221,-243.551314,-232.047115,-124.121444,-39.183492,86.264451,98.163698,7.673815,-59.733696,-73.237505,-10.229011,153.551538,289.928207,297.419697,167.300375,78.752065,-46.351918,-63.880435,-2.915779,78.090001,88.798531,65.152853,55.319742,73.11962,78.427145,23.502786,-10.244461,11.731758,123.66275,164.834911,174.639757,160.372416,150.434596,157.288289,148.352429,140.927131,171.891338,227.682983,205.453268,65.526765,-9.866074,-37.003887,19.66896,104.162404,25.599092,-13.686114,-4.601496,-11.647055,-124.018935,-178.470781,-213.265707,-193.108536,-178.712332,-181.027044,-193.814246,-240.912066,-258.956799,-178.528542,-112.747161,-93.705039,-79.882533,-31.799283,-2.997995,-37.625737,-77.215723,-62.653241,-14.564248,51.305728,95.234008,147.857726,154.695557,182.836622,197.2846,164.151861,118.601157,92.119067,190.518438,206.48874,148.375928,124.804374,124.058273,125.897828,48.033582,-18.790121,25.290049,96.55465,66.489846,-0.119197,17.808358,139.950775,192.852274,194.672878,95.525161,29.281855,-110.959031,-169.597072,-213.619151,-194.571412,-131.765003,-77.324729,-35.64618,81.147295,127.920121,144.356512,129.723724,118.709259,91.820839,-32.930814,-57.292954,-52.231468,-101.821349,-132.630715,-190.790474,-205.941349,-114.964535,58.211498,112.496223,101.815059,53.597371,-49.813187,-88.785499,-134.606674,-123.198364,-8.962068,100.136659,119.859839,86.041226,32.388625,-89.508441,-108.296737,-22.450267,57.055797,57.459241,28.369899,11.792857,-11.572214,-20.201293,-61.085227,-91.059185,-58.320166,141.840021,189.894343,45.267593,-68.465334,-165.327907,-128.431765,49.024993,201.981237,230.146944,228.859973,229.793471,230.781535,209.920415,154.130863,129.809884,61.292259,86.870354,131.215708,144.447724,118.349103,72.614303,61.020291,61.880305,116.006965,167.896838,196.770812,99.609857,-232.588232,-332.080785,-244.73241,-135.190426,-8.794015,-39.662545,-97.094866,-198.702596,-206.047224,-174.569987,-152.030294,-58.036541,77.334888,131.574591,200.670566,203.806613,153.467623,154.35279,262.97292,305.051679,239.492499,189.172676,237.87378,287.783412,192.288732,-133.198432,-210.696284,-57.69835,106.648655,64.476469,-108.680453,-132.750431,-98.325776,-111.114097,-132.184093,-81.88109,100.092286,250.099973,266.032494,177.351799,130.607698,123.832936,146.17397,167.116888,125.326872,90.380555,64.926237,96.29326,185.772486,208.436551,249.23557,280.573246,309.688459,324.326826,337.733636,308.993921,260.84236,186.820004,196.01185,211.46625,132.200208,99.017823,62.333096,64.443847,108.450203,129.161418,159.795037,145.696819,28.528801,6.192444,62.307747,158.259477,134.173216,-10.701801,-41.368577,17.152921,31.371264,12.703249,-63.936379,-119.590379,-154.772249,-119.095807,-33.250657,-18.189041,-35.810916,-45.939845,-33.025027,5.742901,6.911596,-9.108662,-9.160573,-19.620296,-36.469633,-30.326438,-18.985137,-29.099455,-106.327418,-168.549639,-165.684798,-67.191704,115.14349,90.036185,40.273216,-38.234102,-85.932243,-224.870893,-257.545551,-171.361841,-91.529757,-84.519378,-30.313272,-9.660581,-128.020257,-237.072252,-348.838936,-329.127062,-233.277573,-159.412027,-156.433397,-215.378728,-254.426258,-326.143891,-351.372737,-344.11828,-262.275623,-225.195845,-195.947627,-184.750461,-184.867981,-218.991478,-245.318785,-186.598699,-22.375113,41.364393,28.246883,-63.199783,-144.201339,-309.369254,-298.464863,-83.002586,-19.24322,-65.892184,-159.158243,-189.88058,-217.827261,-213.784039,-174.515764,-154.724147,-119.937715,-6.92545,64.321368,79.851118,2.878808,-159.712643,-162.812683,-17.227141,88.589381,84.636427,2.868136,-47.341486,-72.858317,-55.090004,-40.885985,-34.40726,46.828378,179.182204,212.928192,151.273509,74.204339,-66.335633,-108.742653,-123.561374,24.16141,125.976022,181.024712,127.263095,0.863861,-35.61868,-16.070866,44.826899,240.215848,415.999097,430.74189,332.328696,271.323424,154.602717,106.152745,42.226923,-12.996021,-20.233942,-30.614654,-77.444358,-250.488826,-326.070412,-290.964715,-187.298744:17.605845,-30.259881,-97.822118,-238.632764,-286.537913,-339.316088,-340.076878,-277.465038,-144.255607,-87.237026,-48.105259,-42.142405,-19.747821,-1.977361,86.627437,155.364471,270.306319,312.573816,297.216961,184.967068,94.421557,-68.645547,-100.110859,-99.35511,-56.463321,-19.774488,-29.785069,-99.819491,-256.442672,-272.317332,-167.722043,-110.630916,-43.500355,3.873473,-15.266231,-172.964479,-260.317194,-280.747199,-217.766952,-132.09935,-94.631683,-25.720472,120.230762,106.978869,-89.411034,-162.569893,-57.625078,65.322329,256.296932,345.922879,317.661262,115.225371,3.229246,-103.798532,-86.304063,14.46492,102.116224,111.525559,55.97303,29.206831,16.053488,18.929768,40.961916,58.616524,107.31457,113.946802,79.155758,-6.481682,-40.260102,-49.671291,-7.844016,115.522763,238.229337,283.070851,291.842874,260.245698,94.063589,-21.433363,-73.771587,32.57199,286.99968,279.84326,186.146514,-33.30788,-116.383649,-165.775186,-151.830967,-161.70845,-206.60409,-202.775213,-184.978663,-203.167869,-315.833608,-371.924847,-320.515879,-210.117815,-4.439541,-9.926564,-75.887679,-157.839852,-148.959138,-119.875759,-112.548434,-54.775684,61.55913,114.904012,168.380306,186.994297,230.742445,234.02816,200.363881,182.973358,204.906111,295.510651,306.541162,220.716193,160.627463,83.156598,67.069041,23.605575,-8.591323,4.558719,4.933312,-42.640605,-200.896139,-232.914506,-82.223518,25.274562,95.150426,2.382699,-67.951767,-214.577813,-278.150962,-287.577526,-213.916898,-64.142994,39.196378,100.362906,131.063728,83.387261,-21.634179,-28.334607,58.209267,98.172011,97.428245,40.548815,-3.428435,-106.401034,-164.409176,-238.165245,-205.108641,-9.048504,184.147373,221.579862,127.724928,36.417522,-104.803591,-137.230243,-85.63704,-15.510879,80.29559,93.230655,92.810904,32.9916,-38.026827,-142.363782,-128.884604,-24.210051,69.406704,79.321387,2.577744,-44.171971,-83.454475,-95.051507,-123.416657,-122.146364,-42.954578,60.581714,65.709649,-7.195035,-54.570662,-124.133694,-118.093977,15.316496,145.938867,149.268593,109.368709,108.934831,90.553051,50.987379,15.399136,48.274634,108.884824,63.646007,23.433213,-41.127729,-69.627141,-114.250477,-94.860111,48.282971,182.354936,202.727828,119.247299,17.397376,-229.45853,-302.743091,-208.106496,-89.566789,50.417643,-32.539684,-110.930813,-167.75039,-150.797939,-190.432442,-213.388801,-48.936865,243.110266,316.030628,274.047256,204.884674,102.622377,111.721255,240.28073,297.527429,310.003422,285.229878,267.384301,159.118083,61.708326,-147.092383,-183.851646,-24.813948,207.68314,227.637058,65.928705,-31.398045,-110.240403,-94.545656,-32.812061,4.283374,151.170163,304.561473,290.117348,59.172897,-66.959602,-82.735551,32.778415,258.556172,276.61529,235.164562,134.274584,100.466437,88.146978,100.160216,162.47718,210.342096,313.781121,368.221146,340.92853,236.316008,212.769713,235.849876,269.575857,313.103402,253.979484,218.887927,188.516826,175.33659,98.397218,58.926755,75.469595,98.908107,88.45595,96.603735,97.629755,29.158167,-12.818253,-32.803813,-10.428033,69.782762,149.857385,165.544087,133.359168,104.729515,49.047729,23.12368,59.430292,126.18874,196.547645,132.410168,106.81835,90.126229,50.941121,-107.683548,-152.499561,-75.638633,82.345063,137.478964,150.622614,115.779837,-23.013295,-106.903326,-124.187431,-19.365038,249.375381,309.248848,221.090003,-51.490933,-150.262221,-178.901359,-121.893412,6.68944,50.221139,35.868401,-73.26544,-145.870633,-240.038994,-247.538638,-205.148084,-182.685482,-113.440819,45.176854,79.540563,-75.811032,-228.181137,-446.283207,-434.515487,-232.802874,-87.272218,-81.62195,-161.454608,-224.455606,-340.657157,-367.279444,-282.480384,-195.927173,-59.708919,10.602417,-15.923651,-239.891246,-371.926696,-493.005445,-458.620659,-272.950836,-96.388813,-48.8157,-113.735948,-221.761695,-410.823969,-417.744598,-257.796876,-160.648385,-58.61676,-54.018747,-65.566997,-65.369264,-69.180982,-139.03924,-167.319009,-130.682505,-43.287448,-9.786925,-21.41276,-73.223435,-195.749249,-223.230999,-170.840408,-117.603099,16.615232,167.890672,183.550977,73.384081,-6.429682,-121.237838,-127.081249,-69.534715,-34.667287,-32.236514,-47.310868,-77.551933,-191.054702,-226.291435,-163.162414,-82.485877,126.073275,281.846862,286.76951,176.22821,94.95006,-31.521763,-33.447232,52.516477,108.389034,115.822319,43.637563,-48.134352,-251.212666,-311.216796,-293.629384,-244.486836:6.236288,-124.735688,-167.375109,-137.034835,-126.258272,-225.651007,-262.141905,-203.601916,-152.608102,-138.444974,-3.202142,100.72946,177.312713,134.896721,71.591,81.976518,136.873681,177.328271,166.843984,102.922076,62.453872,-72.461184,-161.575375,-290.575546,-265.234447,-189.469295,-42.763933,-18.909614,-39.704865,-57.791849,-50.654335,-18.575926,37.009216,50.896873,37.181042,-73.799394,-144.671954,-227.66632,-226.836232,-177.33464,-93.853955,-29.457987,66.858669,59.13386,-29.199599,-77.579406,-123.890471,-89.62886,77.308472,199.95889,209.393648,167.640998,116.591195,-51.313885,-117.222606,-117.360724,-47.783673,-16.985798,35.520066,61.487818,122.002609,134.383392,91.192134,75.128543,137.368511,252.188557,295.173043,310.970791,275.988546,197.360231,184.016805,155.980169,114.047061,119.569542,157.938191,156.356012,68.327407,-10.092144,-126.230407,-128.821315,-120.874715,-185.686995,-219.391938,-258.421397,-276.267477,-333.505369,-337.389679,-252.939116,-155.368033,-118.610607,-89.686572,-106.360198,-173.551834,-192.020935,-121.355286,-54.890584,29.522982,46.059697,33.213572,-22.16084,-36.606594,-35.089205,-49.023942,-101.048476,-79.061681,-28.58158,81.421439,117.419532,140.288799,131.760455,99.471758,79.000616,8.332254,-25.424409,3.089617,78.575821,81.120407,-17.285595,-79.168945,-139.971531,-97.988641,-26.231136,105.341925,111.390918,58.391163,52.585642,126.103608,178.725098,213.475302,125.232645,74.538123,-7.100018,-65.243199,-180.331009,-165.275805,-7.324409,36.130194,31.181366,118.440847,202.424967,325.741297,306.877985,122.316747,4.608702,-186.405615,-190.887327,-158.209512,-170.957713,-217.858948,-322.273753,-329.003254,-177.11843,32.05185,79.539836,32.352783,-21.387859,-89.003049,-94.400416,-23.806193,51.453396,142.477689,129.530746,144.577455,195.009051,174.404867,22.157946,-36.113399,-2.132357,97.504207,139.939878,197.112478,192.000122,98.034208,22.140323,-98.417,-108.978098,0.246991,199.749695,246.768006,163.405163,82.718357,-6.149598,19.039699,185.237291,317.318637,321.013161,240.016995,202.302378,199.519978,225.842852,245.728656,192.416832,21.625375,42.542389,122.831952,214.183753,202.473986,129.863336,88.947159,52.363253,113.492266,159.819445,170.932539,93.191656,-152.809256,-230.678076,-166.325814,-69.782984,18.202274,-83.411141,-124.029421,-44.510674,28.237487,81.784721,105.874948,258.339287,377.045457,368.994952,277.700441,248.555244,270.826945,300.629503,346.303692,330.67337,255.956965,345.212833,433.607413,473.507173,378.475154,84.85173,5.291073,103.496487,253.075946,249.61511,101.588875,15.824017,-17.357098,23.218681,81.004171,85.855869,96.008616,126.214584,140.707561,145.112172,135.911965,157.028757,207.379104,274.04539,108.368609,-14.855642,-110.103161,-59.187476,115.796451,192.166331,291.180713,301.723231,263.805574,312.331696,362.437708,380.817672,341.719368,219.904146,176.991952,166.906918,94.353091,36.480996,23.671943,58.24833,79.606942,65.39018,114.059714,153.038709,103.960347,41.900727,50.179498,109.42622,140.335971,107.739797,51.609902,-11.877206,32.940694,37.224644,-81.895899,-155.69781,-169.18505,-126.290194,-91.415268,-105.613227,-129.126891,-86.139787,-39.320183,15.875555,-20.945429,-187.639365,-236.052311,-188.10894,-98.99899,-79.105006,-104.770413,-129.839319,-170.504389,-195.079657,-181.553935,-117.449921,1.469239,9.389247,-0.535655,-92.334474,-181.153579,-313.14493,-317.821674,-254.289131,-235.013149,-256.599102,-311.616728,-320.136026,-305.662847,-316.87405,-364.18234,-354.873658,-247.069743,-147.357548,-148.436337,-224.362902,-263.258326,-321.442602,-325.889331,-259.426071,-189.430347,-169.494961,-136.83809,-104.006162,-17.826574,-21.281535,-120.128753,-138.85351,-63.321564,1.393274,9.216546,-33.332115,-98.882374,-242.88648,-247.123334,-94.719292,11.025652,8.524769,-56.655701,-101.854586,-147.673814,-157.726947,-180.669941,-171.513377,-101.323546,-44.500394,-37.813196,-4.638178,18.301368,-14.849249,-54.533238,-48.752101,79.964752,129.368419,62.703198,-24.558046,-95.789126,-74.835909,-38.49787,-34.401138,-23.210288,83.770139,130.087582,84.800834,47.934569,31.957577,27.27017,25.566394,80.406616,136.409058,277.279341,321.012192,286.301804,242.701328,254.04882,321.152917,457.294159,485.646125,490.579178,506.577471,476.024119,326.442314,243.447835,100.857181,32.803278,52.912958,126.861288,105.845251,-78.911001,-170.126249,-164.722335,-82.689397:-34.941023,-68.52377,-113.007312,-131.817334,-96.071894,-112.530239,-195.722835,-312.085343,-224.512716,-162.996994,-102.713331,-86.439345,-40.501638,-25.751929,-19.080095,-22.966155,-41.141559,2.205531,40.538701,37.346039,-35.082793,-207.049744,-224.942477,-197.218431,-226.008175,-190.57379,-44.220463,-26.828446,-137.360101,-193.025709,-171.534394,-117.602405,-73.399475,-119.508167,-132.675571,-131.675419,-150.958421,-232.526565,-242.730174,-201.128226,-208.040876,-207.856153,-169.191262,-137.289883,-78.621148,-87.801528,-136.156578,-117.639792,22.020406,204.404171,244.611746,193.477039,133.175358,1.453997,-22.007445,54.562507,62.228024,23.570454,17.569337,51.79119,53.691221,5.065658,-46.630054,-21.3127,54.632088,140.804587,184.149929,241.710788,246.179993,203.294968,171.636985,85.831209,42.10003,94.784538,231.646115,227.114741,66.505216,-30.841279,-114.746155,-92.288447,-75.767406,-152.442275,-158.317529,-85.536903,-67.073259,-180.794336,-262.662543,-297.674466,-223.735367,-198.318139,-216.166498,-238.726219,-251.643575,-242.051321,-183.352396,-140.067926,-50.402285,9.441022,6.043994,-36.14912,-55.51182,-92.517362,-105.378403,-112.995414,-55.277531,24.357712,197.269879,239.849655,224.807322,183.371159,92.756135,61.569154,41.174673,82.467125,96.207868,67.137053,40.737103,-23.630439,-65.752443,-130.022441,-36.907066,65.395928,190.391313,193.191158,208.566997,243.47659,330.229602,366.356757,364.040843,246.115339,180.273391,91.246285,57.049136,10.627094,5.826992,-9.878451,-9.91731,30.145098,154.806001,211.117461,276.89719,257.985681,100.124996,3.549462,-107.071396,-105.275738,-107.781823,-171.596209,-225.28116,-317.195612,-329.055312,-272.466936,-133.309426,-49.048377,43.352592,36.023621,18.415157,39.718699,104.394811,119.131687,110.98289,126.494169,156.530019,218.891284,189.352592,-52.46704,-177.027957,-210.73891,-51.306691,17.293637,61.083404,56.03367,-2.662827,-78.560371,-248.369819,-280.127351,-151.274125,129.799861,198.896616,87.031051,-17.89696,-150.729064,-146.822312,2.14677,155.019072,172.824347,132.963256,132.320583,182.732006,182.400765,118.262057,91.246964,78.747591,99.267567,119.189533,173.918208,175.628505,65.377016,-7.228466,-43.242693,108.86927,205.703966,242.273944,160.755525,-65.290995,-140.694531,-114.059367,-38.915943,68.94368,18.151871,-36.710687,-79.126841,-63.85185,-32.212308,-10.681259,49.031031,58.939719,59.900442,70.292538,80.269494,156.623352,205.589834,214.567498,168.427939,76.470788,115.048752,166.682812,206.989459,167.977114,14.322097,-32.352905,30.490629,106.292863,83.19125,-4.149224,-15.873428,21.129797,28.707066,-6.385364,-10.821516,113.890453,271.416911,267.777031,186.36503,184.108584,248.969013,276.493153,250.529009,62.165826,-36.686992,-49.307527,29.766136,192.864406,216.821712,188.157675,206.44274,347.374134,440.747237,419.597618,325.897159,296.72868,235.875926,169.466231,-24.447473,-96.764102,-40.808641,78.898233,93.499482,112.908781,142.950426,211.284944,207.293132,126.698099,136.777816,158.944407,139.742612,106.528053,45.136336,38.933573,54.955944,-10.370668,-60.443282,-74.520999,-42.802909,-26.686743,-57.786235,-107.017679,-124.211579,-162.744713,-40.429387,70.779063,167.127487,108.023392,-92.681602,-142.788286,-116.678913,-106.402942,-121.327076,-119.873948,-90.122665,-102.742538,-181.884279,-253.644357,-194.250997,-90.329608,-103.24438,-115.66684,-163.879571,-215.980495,-316.094345,-320.36182,-272.623901,-261.200564,-241.17667,-171.056718,-169.207782,-268.272619,-333.347351,-393.56988,-386.546379,-315.63253,-191.835645,-159.175271,-163.101683,-159.44246,-138.037226,-143.044576,-148.891103,-94.787598,-66.478735,-36.537432,-1.312057,104.503256,103.732834,-34.544494,-96.779213,-71.39821,82.968405,133.064914,58.30181,-58.073605,-239.810388,-227.647244,-83.614238,-19.986395,-18.606752,-39.1106,-69.467558,-128.967621,-146.632835,-167.652709,-172.418242,-171.420034,-83.233993,2.334596,81.621528,33.848159,-91.96426,-103.871395,-42.866141,9.035223,33.641941,37.645041,11.53231,2.978948,10.411396,-43.477325,-79.430579,-20.058185,130.076859,146.741672,110.289825,105.808208,72.488208,24.162563,-60.30079,-69.912745,-25.664783,147.033374,209.469456,200.055382,159.062662,117.036183,141.83038,268.659876,364.413115,339.38775,209.460477,170.440957,135.281865,97.501716,0.1908,19.48404,69.166123,109.826057,75.232077,-73.128183,-162.867314,-200.159973,-105.354983:-26.185029,-36.114087,-84.61766,-204.106595,-236.085356,-256.767692,-265.696347,-325.162231,-319.620581,-244.018714,-43.818583,25.118486,61.075454,64.81518,102.772141,124.036605,164.558837,241.582267,270.267879,223.935932,141.962652,-28.534741,-63.679841,-97.803393,-134.256681,-121.258901,-108.426114,-127.407254,-132.215339,-96.273845,-4.149794,2.32798,-59.158956,-37.953518,-22.804062,-113.581883,-162.348715,-176.760283,-179.402258,-158.650642,-51.503171,-4.160614,13.649031,13.114315,27.809976,16.567369,-6.173563,17.794866,145.589746,307.099685,340.020797,234.919388,117.085087,-108.567781,-145.011478,-63.776011,39.517904,62.622203,73.411161,111.522445,239.209292,255.289513,200.055751,195.493167,225.398906,232.841658,241.817433,226.512735,190.655709,115.017981,96.252517,124.013767,151.806,132.090609,83.417795,72.495314,44.610278,6.742664,-62.936408,-69.194888,-71.622667,-63.240839,-65.170392,-130.813386,-179.03475,-288.486751,-318.667634,-253.594552,-185.931363,-174.946544,-134.908995,-137.145841,-288.907131,-368.661838,-263.249784,-117.760777,41.448076,-20.322288,-67.087867,-83.615069,-59.904228,-46.54938,-47.622511,-29.917222,-66.68914,-73.395244,69.208469,189.885332,315.014465,279.036982,140.36876,93.926421,17.86708,-26.689214,9.572855,120.096385,118.753281,2.156426,-39.188645,-44.754754,-38.264736,-22.368101,17.397255,23.972674,-49.394068,-128.199235,-191.960184,-131.849003,32.289217,32.576073,-40.238901,-203.101242,-247.044192,-206.125076,-141.429184,-101.029713,-132.660708,-86.498219,54.95507,102.472367,190.981866,227.079475,214.234836,153.142644,-4.637876,-49.684473,-61.242056,-128.253701,-165.959711,-205.774677,-174.317893,1.468493,147.462286,167.829609,106.198078,38.690925,-100.305959,-133.559594,-45.658092,50.152168,156.805908,107.829967,63.748136,20.196789,34.30826,54.828265,47.006305,36.352514,21.533827,31.866286,92.028599,95.00025,22.820402,-16.62556,-42.201722,-30.376432,31.759025,161.47418,217.889284,186.10006,106.587117,1.301175,30.242344,155.381046,166.716022,129.743513,76.707715,104.406138,178.953617,141.802832,-32.835773,-74.196889,19.172953,152.841946,148.629576,59.389651,28.159673,16.8158,41.307224,89.691358,33.609085,20.096654,43.059366,9.650882,-166.60956,-237.059558,-199.481337,-118.526227,-0.314929,-11.393135,-29.878689,7.393997,27.558934,-45.340093,-78.497596,28.986435,225.2242,278.178834,245.874774,209.331817,231.625874,271.836039,341.840114,343.631661,216.612891,169.176363,228.957995,270.053516,181.983043,-59.904013,-86.857354,91.323384,254.119368,246.802867,97.427446,36.974959,26.356402,22.8023,-17.489363,-16.479742,63.029871,148.151998,148.069071,56.44641,6.050114,35.098202,109.753342,187.997727,51.867837,-31.158928,-29.846482,60.600329,238.430275,265.295262,240.285367,228.906798,213.998562,217.845531,231.057247,242.47267,230.629074,193.759479,195.143374,262.567549,309.712084,281.740281,178.766202,145.561366,84.898765,43.211637,29.118371,51.702702,37.893849,29.668646,51.00831,85.53426,84.133824,18.772736,-31.040874,-54.878446,64.826752,115.826235,53.717526,-46.800235,-201.739162,-205.828366,-86.499864,-5.322277,90.74656,145.572646,162.860029,60.963425,-55.758355,-217.602554,-200.03957,-56.660659,5.936484,0.394319,-30.065459,-48.900043,-131.387463,-195.713445,-182.978166,-65.596505,153.143565,116.150037,53.496615,-33.045786,-80.99776,-210.520963,-238.621427,-174.847963,-109.141443,-105.01602,-156.277644,-207.338209,-283.764643,-292.70989,-255.333585,-213.728372,-133.899607,-89.309225,-80.35445,-113.122816,-156.812852,-253.037775,-278.714663,-251.81559,-162.680781,-153.417325,-221.088741,-241.943919,-210.83781,-187.60785,-158.329686,-148.205432,-98.459392,30.501526,69.593213,-2.378673,-75.380706,-187.821912,-194.438852,-113.623572,-69.173487,-66.17512,-101.051739,-153.523531,-231.985271,-225.032554,-151.26502,-106.673498,-33.930654,19.009852,29.865754,19.067072,16.896273,-9.676274,-41.27553,-44.240557,35.831433,41.587193,-54.979275,-92.983665,-69.89549,-63.279939,-116.8033,-135.252782,-58.277267,114.358642,149.584611,69.827894,16.001321,-0.379332,11.488563,-51.652156,-51.905073,37.548833,171.580881,146.454448,53.046951,57.893542,161.794338,217.515892,293.075428,342.006841,345.963846,309.759077,275.259473,187.988492,152.216356,94.177551,45.462424,43.704573,51.384985,16.65311,-143.623734,-215.659857,-210.322461,-146.871889:right
-135.867288,-36.487087,-2.606699,15.331546,11.848034,-49.996557,-123.878832,-252.278635,-211.549805,-161.297104,-105.070965,-84.797899,15.177774,52.163633,-13.33077,-59.258333,-53.021136,26.753493,65.767905,89.495242,90.702271,89.212082,71.941993,51.751321,97.042967,132.256959,147.481635,124.379445,109.991357,106.580084,17.14195,-30.869963,-37.480227,20.603915,43.360576,31.961639,17.840797,-14.360884,-49.28357,-131.254937,-222.932462,-255.643488,-210.155701,-152.810408,-102.396496,-127.643297,-229.308952,-249.546002,-150.770108,25.395282,97.358763,144.477032,151.171141,244.285015,297.528787,281.226204,213.445454,206.148559,135.55243,58.178983,-39.599054,-31.973336,13.328752,19.576981,-8.074055,-14.882371,9.024778,44.376139,23.708145,-59.203949,-77.940828,-44.233307,27.320344,48.742584,32.637883,4.570486,-19.585713,-8.204805,-33.348216,-70.206115,-139.446635,-136.585467,-80.14196,52.408428,93.472985,93.399564,39.076041,-94.650772,-60.772356,-3.564938,25.031465,-12.262921,-86.672564,-91.919084,-93.128856,-103.466155,-61.498216,84.891165,124.584131,75.089057,45.723983,38.750328,17.771318,-46.471115,-60.971807,-40.168828,55.872802,67.238216,-29.786769,-80.211104,-122.903361,-131.206946,-144.787521,-141.922889,-143.295274,-193.634328,-219.324174,-218.523693,-216.447033,-227.975145,-188.328117,-143.168668,-110.081217,-142.924425,-146.373417,-96.986199,-64.168759,-93.901153,-104.735695,11.471886,88.364424,189.077961,175.163758,49.029873,-4.629554,-36.235909,-48.171583,-65.669098,-60.196838,-24.329282,63.787585,105.695627,157.754356,155.632861,149.216564,260.907324,326.856841,313.198964,246.480087,153.1049,145.663308,159.610575,234.596666,300.136826,417.839519,446.45443,430.461124,380.557088,242.218388,204.233847,210.314078,216.83586,194.030411,56.235054,-34.541479,-134.129057,-138.689091,-138.730196,-117.359742,-63.91378,63.538216,78.523538,36.120764,24.848008,56.817472,100.65749,199.290118,248.245047,274.523821,321.092795,311.975387,215.883548,148.014239,77.273578,205.552214,290.593984,320.572636,282.215805,281.665602,322.947959,307.429038,250.70821,196.453002,224.213767,237.924001,237.729446,232.834182,200.402824,163.496436,133.457043,158.027566,155.075772,186.471145,225.692669,241.881753,187.626363,-11.743648,-97.752496,-160.092035,-175.963451,-192.15046,-237.192758,-266.871988,-354.271382,-394.110845,-438.614509,-473.296405,-436.74709,-260.871674,-210.417966,-239.378112,-262.281557,-229.053983,-167.792198,-26.190117,34.798103,30.485154,-29.954892,-67.955524,-98.526021,-94.060145,-24.566243,131.648561,201.654618,291.968179,297.003086,226.744495,191.124477,168.056366,177.877424,239.060936,261.262009,235.475615,192.863475,194.798924,177.823413,147.155373,141.562438,169.660165,136.30852,90.793325,133.035167,246.100028,242.19383,122.290409,80.263996,103.833669,127.083457,115.446976,94.613766,93.456209,97.775113,80.323488,11.879247,-17.938849,-3.391017,87.465056,127.894272,117.26985,84.92241,76.416572,109.201762,159.153312,134.014111,121.40436,141.350339,138.786116,16.200381,-48.014471,3.26938,178.618993,235.307305,289.456291,301.22927,309.104879,296.903147,159.679212,54.273941,-50.652287,7.15082,45.610394,76.837349,58.04268,-24.164202,-54.779019,-41.382667,67.771043,146.964643,234.056577,195.336795,80.58673,77.987659,107.365703,100.195784,90.664457,56.193731,31.183496,44.474446,63.095228,43.801836,-8.669154,-100.508871,17.780342,95.713458,105.87788,68.051916,4.491628,-51.679095,-220.2393,-257.169861,-145.269571,9.532334,41.292383,35.304328,11.10256,-72.631871,-118.354715,-164.612553,-172.644751,-125.291066,82.842985,170.236619,275.289761,298.087466,182.98702,79.229721,17.888777,128.765985,134.594847,13.602614,-41.965031,-80.910013,-107.24239,-220.600703,-231.628476,-153.055093,29.33121,48.726985,-41.561684,-80.595432,-91.452445,-88.870693,-71.885597,-13.519825,-2.264474,-45.71302,-57.90533,-37.425896,-43.184229,-66.579406,25.271455,99.422303,149.595354,94.017398,-46.569305,-86.889991,-138.936405,-145.753708,-109.106108,-59.212656,-38.110588,32.957524,87.671648,115.709465,51.000657,-86.242415,-47.591032,4.89019,84.211244,80.149011,-48.637426,-146.34981,-352.545666,-427.324139,-409.855781,-174.545477,-32.8394,93.562933,58.062893,-64.845926,-117.493034,-190.029249,-170.57827,-125.289876,-33.257058,-9.757699,46.280254,76.793912,12.894414,-64.593722:-181.43235,-10.215773,2.443876,-68.961052,-99.333876,-175.014663,-225.999989,-234.847108,-123.583585,-80.733316,-95.580222,-130.314158,-131.776741,-114.68963,-172.020788,-213.217916,-177.367919,-2.991737,91.953645,138.271735,101.615985,38.781156,11.08859,-23.979319,-1.218284,3.100691,-21.462004,-28.560239,-48.961307,-101.55719,-240.101412,-254.472121,-185.254845,-100.723239,-58.904069,12.450109,42.385903,12.725529,-57.803153,-148.034242,-75.687287,-49.262705,-125.765125,-183.785453,-206.619826,-191.03704,-185.570955,-165.318965,-50.484034,91.671177,135.933974,71.249064,16.01108,39.698421,79.339683,91.055981,155.515247,208.971933,135.901814,10.650865,-158.815882,-173.663985,-178.243364,-153.574237,-42.480969,-3.547363,9.686774,4.506609,-56.186271,-166.119697,-149.624802,-23.805658,93.219977,122.483001,109.810527,88.514965,104.762511,132.213813,94.654723,42.02085,6.728113,60.302726,68.74336,3.213541,-15.052215,-3.916944,-46.065349,-190.38972,-155.691523,-99.763474,-107.124849,-174.077411,-274.474073,-250.655626,-127.004243,-93.409007,-71.877402,24.057346,58.683727,7.536468,-14.846168,20.73368,35.132817,16.054745,-52.896968,-58.83018,26.933593,37.407099,-82.873071,-154.233124,-230.645461,-235.291854,-204.974786,-194.648886,-211.707563,-302.385727,-367.796356,-433.396532,-400.070494,-282.94237,-247.437131,-230.357798,-171.526066,-166.686151,-165.505936,-148.359863,-140.346454,-159.339131,-159.681208,-12.059687,83.785465,128.856049,47.675035,-138.315823,-155.074861,-70.386209,4.293987,27.001136,128.133754,201.625782,271.565741,260.247026,209.317285,191.847321,253.628424,418.057148,444.595409,311.165418,215.153566,136.381218,164.513609,230.750531,251.685094,288.908544,413.826594,442.576213,387.240647,344.660273,290.504231,266.881723,215.455475,168.515838,119.665581,-50.508484,-133.860584,-194.466016,-181.109224,-161.807472,-173.874825,-166.097092,-120.871885,-117.642611,-186.21335,-211.326304,-123.755927,-42.52197,37.967283,60.58092,100.236143,164.807477,147.607714,22.255282,-45.218679,-68.422473,84.369719,159.389338,211.886927,211.234334,194.881561,165.242992,88.871838,92.653581,185.466412,211.889992,201.326835,202.756169,200.406043,119.087857,53.744754,11.585803,91.175595,118.180182,143.508354,166.942092,173.324929,109.346912,-37.3947,-37.27086,17.415729,-33.852765,-74.560096,-143.30815,-161.837783,-195.748891,-233.481345,-297.051413,-267.509396,-226.518174,-129.397884,-100.167295,-102.55175,-136.210999,-215.291639,-192.998071,-23.60642,79.039504,98.499291,161.464885,181.41393,129.582026,96.784257,134.841628,223.731545,270.095293,382.109847,391.224868,250.244061,167.279348,112.271056,131.061789,223.953532,371.231117,423.972614,426.576154,373.878994,211.907975,170.097725,210.353922,202.251472,187.783335,297.978257,381.163564,384.717815,308.623067,171.772364,165.312969,254.132047,256.780321,208.160862,81.941858,4.479789,-94.701996,-74.820699,65.636417,182.585212,203.899047,232.545286,242.181734,181.369829,141.425528,189.333982,228.756538,177.147027,96.093413,70.487159,14.125902,-5.063642,-9.892638,26.278963,187.55113,334.260478,387.207566,468.720312,481.034769,424.673432,368.129645,226.443268,155.670205,70.565636,84.237087,112.634868,169.373019,170.327793,83.02026,44.514849,119.895904,247.670683,260.691164,219.180731,184.965647,150.594924,162.66163,174.629985,163.863853,206.2712,282.355748,255.453169,140.697809,119.586109,151.166324,135.882806,28.988409,139.681512,245.97722,218.801148,105.17832,-44.072851,-54.500584,-30.250966,-11.361457,59.203193,145.186387,162.598696,149.57854,128.782696,34.383827,-33.497133,-138.78719,-144.657334,-91.184378,77.562634,149.70768,241.860886,232.123799,54.715656,-25.012022,76.368922,262.797404,228.291373,39.503497,-17.585858,-104.026134,-153.742898,-192.658237,-139.898467,-110.460981,-38.026807,4.646994,-16.953718,-84.934626,-155.279648,-133.297989,-108.751659,-104.665749,-64.812552,-29.42033,-75.428103,-162.953952,-142.24399,-20.017496,66.351247,87.91663,49.598173,-13.331424,-92.156677,-96.841054,-127.245466,-132.493864,-38.777713,53.181353,49.483451,11.553198,7.329906,4.964391,-10.791519,-33.089681,97.364352,201.421062,265.991676,188.339498,-39.280386,-121.230138,-226.60175,-274.412352,-297.667903,-141.208402,-40.475282,31.770699,-21.147186,-179.7904,-224.960263,-230.493778,-130.916813,-58.863949,1.757829,-10.068953,20.480269,44.489561,-56.592471,-133.261515:-117.633421,-127.810611,-159.112507,-110.921079,-75.947138,-166.826141,-249.642833,-269.964676,-162.852438,-119.356029,-108.321721,-142.843833,-184.545558,-180.782779,-196.411646,-197.372584,-109.527056,7.458798,32.713978,7.922774,-17.092768,-53.125303,-54.464346,6.502851,75.722908,81.797253,61.544704,46.30979,-23.476174,-110.480934,-326.642874,-360.647358,-232.386822,-62.880954,-26.085447,-54.469583,-88.897281,-145.489243,-162.972854,-133.307846,19.410158,96.699438,89.705556,18.411332,-97.114413,-135.805279,-220.06197,-226.405552,-106.098261,13.672815,19.384255,-32.335699,-36.463015,10.824333,3.155217,-76.622813,64.594201,201.947721,229.159968,101.276353,-118.166991,-174.969073,-279.189585,-268.061691,-51.61002,41.326384,-15.848494,-132.142919,-150.884036,-147.804771,-121.796592,6.374823,114.777279,116.946019,48.116929,1.228883,-78.617693,-105.047951,-111.032485,-84.675067,-31.29608,-47.703525,-74.892106,-93.791804,-59.610091,-37.5751,-106.48956,-202.506114,-53.820531,11.046157,-37.303486,-104.319396,-166.248427,-162.030703,-182.131667,-203.790679,-152.559565,13.717129,67.69253,48.345539,12.538135,-5.994431,34.913467,137.216867,84.626113,60.540513,135.104409,135.242276,-85.222863,-214.74117,-278.822784,-214.149196,-74.295544,-121.307821,-195.059119,-333.779271,-377.546601,-433.090726,-465.057198,-471.732879,-330.348926,-253.172045,-188.059082,-193.999347,-164.994418,-127.395555,-147.931861,-211.558853,-243.17194,-58.890837,31.367044,81.641556,33.491391,-150.534446,-199.257442,-78.306114,76.626355,79.979897,74.512125,113.334802,170.916121,159.998824,115.25153,116.915016,231.976051,394.813539,416.860817,330.387618,256.037823,128.989101,110.736579,137.569458,142.794704,157.988292,282.830523,359.134354,350.965681,242.463772,37.31477,40.970322,188.463149,227.274378,155.114648,-51.408223,-99.885334,-69.719028,-52.390752,-118.323754,-224.883512,-221.950341,-91.68129,-33.007458,-100.324098,-201.340513,-263.134701,-180.278363,-8.025444,16.716481,6.695245,-14.509864,-22.649985,-97.524124,-162.623616,-161.424385,33.597847,92.535425,71.659258,57.41287,65.396205,39.131416,-32.220522,-2.633797,161.937835,282.915161,304.696637,287.139943,263.128739,144.660071,51.374895,-19.809403,74.073406,98.440752,111.296846,137.960492,180.428015,145.575282,26.65411,17.65383,69.12705,60.555071,37.5238,2.435497,-4.124955,-93.272816,-161.774452,-124.746366,2.021025,10.077392,14.816975,29.960027,34.121416,18.374107,9.341419,43.598341,163.068125,218.20205,231.705621,297.486888,316.514072,264.441065,226.58015,254.055923,345.220316,365.471471,409.045744,421.29972,311.735354,210.768727,85.44097,95.693934,207.010772,300.425085,325.972491,352.002832,333.986443,225.150019,183.417781,205.340184,264.187886,287.904548,354.364765,375.069664,319.137186,243.843669,108.348845,97.355092,170.082245,205.591388,193.827316,153.757783,113.32957,49.201379,76.387784,225.961062,351.82311,380.766468,406.604438,415.801583,378.837839,310.793857,135.498539,51.287474,-28.350066,118.385713,182.934754,90.141815,-10.172577,-98.842707,-38.228017,231.823344,377.53137,386.127251,397.248765,383.497896,319.051617,288.723397,167.040651,80.660611,29.729597,128.75647,153.790716,147.143136,141.405652,120.233427,121.117958,202.0249,256.783532,233.168526,219.379474,252.110607,259.304352,222.187653,142.294165,126.588347,203.985551,326.85692,327.226901,243.782104,204.391205,130.469199,104.653515,155.512322,310.354542,370.889835,332.833094,243.901162,120.890816,113.872449,113.674646,121.399903,200.233273,253.9681,251.482666,207.201459,153.628998,2.324564,-55.937129,-58.384817,27.421801,54.528751,94.885598,141.034241,254.250864,258.348553,126.901009,61.212204,62.453976,141.048518,149.586388,96.833383,47.091537,-105.709043,-180.526355,-208.045472,-107.165562,-68.278309,-62.753462,-74.146347,-95.406285,-115.69974,-144.723647,-129.637815,-71.848202,-58.149568,-48.150935,-24.702955,-40.565733,-80.852648,-67.467149,1.783285,22.747995,43.781502,145.891253,155.172963,12.709797,-81.638713,-145.319566,-91.407616,54.341455,92.222948,74.545706,38.168703,63.23233,143.504636,113.824633,-21.509456,97.297311,229.073454,327.866967,239.157302,-7.750205,-65.818652,-98.523945,-139.184469,-223.959548,-131.007691,-34.617981,91.72765,64.123428,-117.53199,-171.039155,-109.962933,-20.119783,5.372502,44.932409,59.309351,80.090585,68.848685,-7.922596,-27.663697:-55.580633,-47.872713,-35.181485,13.826569,-8.06491,-197.196104,-295.554896,-345.539555,-286.766243,-246.49159,-171.980668,-162.926206,-184.97012,-215.891154,-330.161759,-363.480996,-261.858329,-56.814234,-7.531979,-44.926372,-67.371409,-44.216739,-21.422295,59.836122,209.34176,276.92776,316.956275,271.334074,135.842729,87.591083,16.276964,-6.791047,-20.839738,-31.730398,-29.955087,-1.677508,19.979293,9.457927,-47.293303,-189.742339,-231.783721,-205.10371,-133.011106,-120.655339,-133.296264,-157.865133,-278.522068,-338.527748,-356.575755,-250.859625,-175.695522,-38.871183,18.413092,111.33268,137.5005,147.309999,210.548727,272.572775,266.042452,165.704833,-27.037659,-70.700087,-124.882436,-131.32403,-68.061967,22.837904,49.992678,-19.414043,-100.318117,-167.075986,-134.897814,-29.685673,43.747438,48.941042,10.578149,-32.463576,-129.894524,-161.583473,-205.834873,-208.074863,-158.747303,-95.956167,-65.406524,-2.850593,27.393559,33.448619,12.095155,61.779998,234.571778,271.454161,152.712486,53.969001,-59.590101,-73.522866,-99.475729,-114.53446,-55.468754,83.628645,111.66674,89.641257,89.137193,117.254012,121.301717,138.441866,152.335849,157.997423,148.864221,76.528892,-168.771101,-250.624152,-275.473781,-249.023933,-168.454139,-139.107744,-153.688782,-210.777637,-235.291191,-241.865752,-224.5948,-135.953083,-21.261756,-1.294385,-57.940748,-110.462645,-180.351906,-187.627521,-192.276348,-195.232874,-155.186761,-42.762326,20.654368,87.138175,73.0894,-22.947662,-75.633796,-98.783903,-1.652677,54.486978,118.808751,126.981211,164.754097,195.886201,205.892068,208.526645,307.665254,465.84192,522.082719,531.037521,499.558378,429.292774,386.051212,292.362619,260.03847,278.060839,374.280537,425.913229,442.069239,388.381489,224.275163,191.387997,267.136938,300.477625,269.10289,166.004688,109.871567,-7.581138,-64.721168,-126.557959,-79.743988,-29.100492,70.98326,98.255619,56.53045,3.646158,-56.545671,-51.12376,-10.597518,49.931325,73.954672,98.856342,112.487384,56.935968,-24.681576,-66.951706,127.927719,207.165452,236.71192,223.133822,223.616903,225.052286,172.953355,143.331716,153.596826,238.812115,292.568952,349.490389,337.125093,256.799333,208.851158,201.389855,291.706807,304.452709,266.884593,249.235771,230.237392,222.596357,188.902924,164.380853,90.285283,-1.425576,-22.549782,-37.070157,-44.785179,-88.106982,-133.353307,-194.810356,-167.451474,-134.702169,-37.791764,-3.929539,-12.071378,-43.175711,-84.357262,-51.659427,44.249079,34.185949,44.377013,126.946904,143.73702,94.497952,65.572954,105.960539,227.670346,280.268671,367.472461,363.857201,212.782988,115.912834,11.121238,23.68648,133.444939,199.012863,192.040794,173.245282,172.414044,127.58035,89.562532,83.202336,162.925405,188.523998,206.168925,217.483157,239.67064,231.97565,158.405036,109.105734,64.630364,127.53003,164.995946,160.640542,121.620565,49.186064,41.183543,73.694672,87.208408,99.758537,199.158434,252.455082,240.513476,172.226254,11.187969,-39.209745,-48.502529,-7.240144,-14.730016,-108.229479,-158.061951,-167.7737,-114.997496,40.768717,144.782034,188.22093,309.93704,367.448363,374.889186,294.975256,29.487538,-76.758967,-100.793299,52.301991,126.463318,170.545404,129.009006,-12.755082,-54.708627,14.73402,159.058527,203.886017,302.195284,335.744301,263.945562,197.632002,121.407132,125.397416,198.310535,239.276611,236.738391,195.860764,155.192279,87.511285,71.019313,78.476774,182.832723,252.073181,280.945832,223.43814,94.508301,53.140928,-8.868772,-9.311879,94.29471,181.185339,172.111196,89.684552,43.853854,-67.625513,-135.325134,-183.469777,-103.450977,-57.149249,23.966442,73.263875,229.049242,284.17802,171.938105,58.373198,-22.764027,87.928743,130.465246,91.216123,28.386031,-131.664416,-213.517613,-274.250852,-161.564213,-95.103951,-31.810547,-32.394007,-61.272036,-91.428124,-185.914038,-219.175471,-192.280793,-115.381116,-95.336833,-135.534322,-163.697323,-129.294918,-96.165788,-78.742633,-24.193782,30.985129,103.716086,88.9714,-12.1274,-69.176174,-135.904056,-118.394405,-37.098572,-16.826466,-11.506432,16.450061,30.668078,15.038271,-32.374034,-88.976757,55.457667,127.490173,119.444227,53.724386,-87.539944,-130.45584,-187.314414,-217.858456,-250.487951,-164.457954,-82.166184,35.381164,31.435696,-57.660136,-96.352611,-87.26397,20.714966,74.289408,120.643664,115.582479,98.707661,83.07873,-21.511431,-77.735496:-107.93627,-36.771694,-30.036417,-72.605322,-119.622501,-288.740698,-368.037017,-348.53404,-211.287661,-177.94857,-225.2101,-278.638056,-371.1246,-430.970718,-572.107743,-581.048536,-390.366865,-188.282383,-172.462385,-200.426959,-186.071458,-150.8645,-143.678146,-68.981548,65.504319,126.464738,197.399851,194.369831,108.910148,33.830218,-108.740301,-136.413166,-101.251211,-29.668354,-33.357225,-136.665758,-172.001932,-180.05281,-180.928861,-174.936242,-105.768704,-41.097403,-22.784045,-99.298785,-253.724053,-296.757151,-361.46378,-375.938421,-326.210525,-223.237494,-190.187962,-150.357553,-128.396612,-108.582602,-97.503561,19.11659,225.127465,291.838812,247.726913,171.265637,39.749996,-37.977167,-221.548059,-248.250416,-131.808992,-78.982042,-116.892797,-182.896055,-191.238701,-236.808002,-271.563823,-252.782449,-136.432821,-92.87951,-114.547909,-173.222017,-273.031074,-295.692777,-290.995107,-261.08005,-196.281796,-126.506105,-80.233261,-5.31441,11.390694,-10.234095,-26.765185,21.931105,162.77512,208.484214,145.32779,63.78921,-72.792078,-111.188514,-121.313049,-96.174856,-8.808924,127.146072,180.522019,164.80889,109.831458,19.817101,36.768553,159.467203,131.2334,86.311419,110.848484,111.113167,-89.376733,-236.852049,-385.626562,-345.355456,-160.674747,-108.372086,-140.212859,-167.265086,-137.343494,-104.832331,-145.752331,-214.502413,-53.814762,51.459667,94.147533,33.198116,-112.339442,-168.448296,-246.672337,-245.932843,-132.473502,-9.926838,-4.227306,-52.260405,-63.726641,-85.902595,-106.70294,-92.818718,1.718032,34.78704,49.532911,61.325817,93.821271,91.329161,87.871999,125.340614,289.900785,499.664863,571.119943,545.327863,454.358863,232.729088,160.103135,138.025044,162.070442,166.93631,216.296184,258.334866,295.143192,262.430544,116.389621,64.099683,127.250854,266.466612,268.734986,127.224506,54.295604,-1.086839,-31.040342,-175.346516,-220.616611,-147.286017,30.082555,65.703004,31.202897,-14.448319,-98.814463,-101.293843,-8.142586,115.145428,135.590727,77.386706,42.125757,-51.59771,-109.870011,-95.110209,32.704824,66.552091,104.65387,131.840408,134.075356,82.616526,29.191778,81.147735,197.434348,232.977225,254.771468,253.407863,210.699813,115.481892,94.963935,110.812588,179.742044,220.69123,250.593072,228.715353,138.711255,90.933277,34.811088,25.324786,31.160328,103.165402,134.313957,101.25066,70.709737,11.097084,-39.656634,-77.86964,29.048071,91.926748,162.422993,137.791789,-15.119146,-79.262889,-56.709277,13.136908,145.677378,229.665442,251.105461,230.706968,197.00123,123.912241,112.629013,198.967901,307.755124,333.927545,381.760355,380.729543,221.401303,99.961677,-0.98578,57.648269,250.27631,326.690766,315.409965,263.5042,220.059583,69.975017,12.896056,48.763516,204.110767,273.381696,312.824408,285.839683,224.383292,197.338003,117.67393,91.676861,134.769354,192.135754,197.879419,190.230621,182.312659,141.553433,117.657582,118.383408,195.045768,273.523308,416.358665,405.946719,210.218699,96.208411,-36.844208,-69.629129,-75.894174,18.914228,48.301081,-28.718051,-96.240293,-155.205977,-130.722551,4.371084,167.371697,258.317695,427.876533,454.503024,360.247688,260.412431,46.620412,-5.498346,54.0831,178.310401,206.51359,217.522965,200.031444,63.18056,-6.911237,33.318867,190.311703,254.391945,397.8742,447.052024,360.118936,250.699644,89.285106,67.078774,138.646209,277.73259,288.963694,176.878794,116.368302,62.724697,70.483652,146.938574,250.548969,306.094273,318.777778,254.871432,154.955918,127.547366,-23.74894,-89.768693,19.194341,230.797812,258.949381,169.98956,84.452718,-138.154637,-238.430724,-274.668219,-118.17717,-43.098539,15.935647,14.406222,29.512401,34.053122,-30.094079,-58.59717,-32.005688,29.600955,59.915275,40.561399,-37.470523,-262.476021,-347.854837,-370.563888,-242.508148,-150.771085,-26.288089,-32.653131,-153.507229,-242.025217,-348.738483,-320.509857,-195.46346,-103.585255,-71.419472,-101.076555,-156.754182,-255.250704,-282.887661,-243.061882,-54.503453,61.350427,224.281939,203.810524,-34.144609,-152.353959,-183.863772,-100.347256,76.158515,110.362482,116.393689,161.32145,163.350827,46.532207,-32.626017,-44.917039,147.625088,241.962562,243.818732,140.865939,-56.819967,-75.229025,-43.88986,-70.371785,-152.340723,-19.548963,78.120535,106.411372,65.345497,18.269872,15.98067,75.177081,203.982962,239.678653,230.973314,200.816672,109.175617,68.151971,56.614283,84.369631:-112.054646,-83.686435,-95.354711,-164.372239,-209.531591,-347.317086,-419.933746,-451.606893,-334.927505,-281.648345,-235.230606,-222.971898,-184.622145,-164.39966,-156.463813,-165.081641,-186.942055,-167.342022,-147.577016,-145.755179,-137.75305,-65.106616,-29.428672,16.554615,129.162624,212.528702,310.174271,300.049628,216.748612,175.493131,119.547317,97.65287,46.414347,38.909437,53.233265,17.024135,-21.16351,-80.71349,-128.205471,-254.557319,-304.002358,-279.073588,-214.760911,-217.191938,-246.149475,-263.570589,-374.723936,-433.319081,-424.926168,-240.445909,-132.676637,-17.850463,-0.614207,38.443814,66.158531,136.874907,235.620175,268.269491,193.448999,90.215914,-58.271791,-63.44633,-38.106646,-52.050365,-116.779259,-112.676584,-86.925898,-119.45855,-174.714097,-252.993909,-267.264979,-247.867001,-163.506899,-133.646376,-177.835897,-239.584054,-307.044133,-291.135821,-273.192088,-291.701604,-293.901153,-176.5241,-106.406007,-9.65905,19.718181,34.488925,42.60806,128.791854,241.140843,267.308062,216.704551,149.416784,19.757605,-27.777514,-114.309383,-123.986267,18.898525,194.050583,196.976662,92.999966,72.506195,133.492038,148.144812,71.983131,-15.985204,-3.656813,60.015988,31.340621,-85.354849,-86.952224,-48.085468,-56.988576,-41.359992,16.095081,31.577647,26.228975,26.233699,61.426843,73.422047,105.27877,177.870394,184.174663,43.105358,-65.726022,-143.944672,-120.101503,-147.719088,-193.730194,-148.235337,59.957603,134.124014,122.302699,64.196138,-2.719652,-0.137536,-0.75388,5.206609,22.7505,74.892679,90.718834,62.008765,30.466671,19.989366,60.43357,147.440521,232.926315,326.942597,463.325935,431.850817,304.86614,275.518837,269.706561,220.695244,186.980869,212.754717,253.477182,297.284494,301.380688,275.386456,266.950403,340.819489,388.238263,324.876744,123.446083,72.779986,56.433162,24.088079,-59.871281,-35.634766,21.655264,170.304772,196.963004,110.219932,80.652645,168.547318,224.674711,205.09062,148.660734,183.807393,301.370703,304.802843,162.963617,91.991933,104.15918,210.502336,237.817527,233.440635,223.418422,256.891812,293.739129,279.917761,241.5907,227.998407,251.759623,256.354563,216.350397,167.288405,91.235828,107.297029,265.791892,359.21887,330.658787,301.616456,327.47035,338.386098,297.694185,152.91147,81.407726,20.401954,29.641198,5.578336,-95.696849,-124.496903,-127.750528,-133.958834,-160.27399,-168.830318,-151.328162,-89.087342,-96.375262,-159.349458,-137.538367,-17.955742,22.712827,52.704402,52.087438,54.668541,39.031819,-0.72506,-92.974943,-93.100891,45.239195,220.163055,273.83924,339.349289,342.17244,222.343399,113.923376,-35.779349,-21.091279,120.275238,168.926201,148.045499,139.475128,143.427308,82.302087,40.308829,31.112392,112.530565,160.484465,196.985642,185.446415,181.844118,190.492698,167.721062,146.119774,147.494227,172.53768,187.423912,242.524602,253.201932,186.617957,116.210536,-51.235368,-128.976509,-92.621434,106.694751,196.569101,160.351557,59.28956,-49.664141,-18.125537,84.448394,77.734542,18.922671,-122.673293,-157.35159,-148.469073,-125.622931,-42.9583,46.449093,70.498957,109.317027,147.063288,210.253813,183.176742,-1.587007,-82.965586,-43.47636,149.102068,192.882552,141.579161,92.374604,-22.952031,-91.93026,-142.169674,22.227617,141.155634,299.040452,301.093481,239.956627,215.351498,158.607492,135.611549,128.062404,125.542827,106.119864,12.048163,-46.049088,-130.453738,-141.669716,-53.222149,100.132726,132.799928,98.058367,64.575033,9.211444,-42.810314,-230.953281,-306.902857,-267.475218,-78.104584,-16.40841,-18.430221,-58.508091,-120.906894,-132.783526,-196.309083,-218.036405,-127.715901,99.62194,137.870035,108.297968,80.593046,-33.514529,-94.22279,-61.546281,114.766554,124.398632,-75.350821,-167.835657,-210.036882,-230.547675,-315.91571,-293.281655,-212.556403,7.666021,66.486989,-25.901751,-110.524698,-151.041872,-121.899724,-122.268468,-139.508082,-102.127597,-37.986538,-46.662926,-78.294021,-78.627933,-56.576997,-15.063445,2.316324,-4.368439,-37.614351,-133.387999,-176.215416,-197.12974,-150.137797,-12.134261,24.733865,17.595505,47.117308,70.199814,5.187629,-67.494321,-52.858157,156.066329,203.179196,121.564724,34.435144,-156.887637,-231.907201,-295.780799,-278.874911,-174.610282,-66.336824,-12.18752,66.113371,72.459841,48.830125,22.919789,-38.16411,3.835433,48.309117,81.367695,75.585981,100.87564,124.539803,91.60391,59.675872:-96.249676,18.57813,35.298746,-77.706938,-191.122258,-437.528161,-513.432111,-479.068074,-298.01427,-217.97143,-161.819385,-186.275886,-287.876508,-354.682789,-471.436959,-478.315742,-350.547225,-182.655506,-150.898105,-178.798015,-192.218664,-185.476815,-167.69758,-47.072454,158.461761,252.961691,355.857002,340.89227,193.691586,97.175583,-44.152044,-51.923129,9.848664,10.587497,-4.510876,-26.696373,-49.064027,-141.114422,-197.195204,-272.14894,-241.917106,-194.400744,-146.401809,-174.132053,-289.44745,-353.535305,-462.29377,-485.744074,-414.975562,-251.975206,-199.783652,-159.602436,-123.868538,-11.27475,20.388767,69.982115,253.907456,363.076436,385.400176,269.409201,-4.029851,-92.83151,-188.863256,-195.866849,-106.420795,9.492505,11.999529,-101.456209,-164.760453,-250.273254,-287.982588,-291.909749,-148.590924,-90.722471,-121.680566,-188.03593,-301.809328,-328.660702,-325.673655,-309.183583,-309.964632,-244.726812,-147.32939,29.496804,61.259055,18.809568,-13.485114,44.173259,216.590172,271.442127,257.537853,193.766089,-6.646796,-116.163548,-230.991051,-191.688208,-4.832583,109.742799,121.728396,119.078481,125.112338,111.91177,80.847882,44.583845,94.3326,143.495944,184.141212,117.431579,-151.343956,-264.046034,-295.862462,-240.476096,-127.499322,-31.473163,26.228572,74.327855,45.013085,-47.49139,-83.076246,-47.039269,139.367131,199.036766,118.390975,20.51985,-107.947383,-139.137282,-228.98086,-253.836542,-148.099877,61.881747,133.57559,145.016073,93.396392,-75.328045,-144.382991,-128.543638,18.91853,80.166667,138.656096,137.228006,64.91473,5.286141,-36.66262,41.385376,344.133647,548.64702,564.610246,504.144154,451.938471,311.866248,251.381046,232.397805,257.788576,263.640989,307.40018,321.352416,269.393319,221.870525,163.350466,170.129394,261.863394,392.201993,390.876822,197.225885,93.656331,-7.984627,-50.333075,-114.575874,-37.624585,34.092513,159.01366,192.324157,156.582904,88.042159,-32.179381,-39.020848,27.411069,95.974765,115.890064,141.813835,131.998028,5.397622,-66.480371,-48.502315,84.218557,126.57749,182.155233,194.013344,142.169303,93.899849,57.394533,92.352229,206.026366,293.928339,326.574502,297.17094,230.453953,85.475548,41.242133,70.72061,210.509308,286.735119,409.687343,426.71786,327.230087,232.389108,84.23604,79.075835,170.523421,255.999696,253.135893,111.637481,5.448718,-152.425592,-174.733715,-111.620096,25.352666,106.392247,203.550123,171.530442,-9.566645,-98.382806,-177.824925,-144.759706,38.624629,167.35807,184.886788,182.09017,148.165224,8.687914,-40.802167,30.871864,204.627851,268.412863,338.632226,327.522448,180.303478,66.015125,-128.530181,-149.283867,-8.505388,168.920398,204.850129,161.760655,99.439834,-51.707623,-104.652429,-97.63096,54.403599,150.225769,256.322458,233.622235,133.369796,100.931845,50.369518,24.406175,13.686879,101.353954,168.566536,259.994288,258.602276,136.561387,36.692719,-79.815285,11.730171,104.571997,250.663666,243.255001,74.715293,-14.453292,-99.960465,-110.595551,-84.202391,-5.845325,1.986949,-131.070702,-223.824955,-270.463944,-219.751672,-81.012694,37.437359,103.911475,246.450416,286.34322,265.344294,196.259053,-54.375098,-152.719865,-119.015566,80.494385,159.101169,199.720873,169.366698,54.779519,-7.51943,-54.016791,80.028098,205.175354,439.892104,463.006857,284.508165,168.713376,68.06882,92.348742,201.968975,278.234412,293.43393,256.369455,187.899163,-40.212908,-143.592454,-131.808669,135.809277,250.740482,290.520905,229.998015,69.269904,-3.11951,-126.203177,-165.756586,-141.750606,-31.889878,0.531026,-15.433943,-57.490337,-185.356417,-239.870024,-245.639631,-175.212591,-134.700863,-20.605703,31.286993,47.564802,2.04774,-139.733666,-172.461175,-89.011153,29.762609,40.969514,-28.196891,-79.979191,-228.267408,-318.991735,-379.346364,-236.786078,-142.060201,-16.845791,-14.87224,-119.816649,-205.523409,-325.222738,-310.466187,-178.225691,-82.009732,-80.089712,-148.677855,-193.969302,-267.324729,-292.663078,-266.136844,-112.266655,-18.698014,124.646688,128.046907,-35.589928,-132.197185,-182.004539,-139.546663,-1.746603,133.791427,171.659867,173.741554,129.277374,-75.913483,-180.984172,-167.758234,106.91669,217.856053,222.854627,135.776391,-87.959691,-177.910301,-244.522596,-226.347963,-152.376731,-43.375074,24.763325,89.769496,56.359005,-45.332159,-54.973746,22.093186,122.801672,157.024978,188.518771,175.484152,112.165803,89.612486,84.704496,95.01143:-98.922031,-138.600057,-118.286028,-37.485786,-46.14378,-190.39986,-277.940638,-396.719618,-375.657354,-310.775031,-170.598703,-140.208486,-108.462559,-55.07942,47.069546,37.679887,-66.921901,-97.508268,-60.124615,-6.713756,2.336062,65.084294,103.800016,153.17851,224.701229,273.119319,361.551831,381.950815,362.756497,340.528528,295.648444,260.351841,140.479047,67.359928,67.056231,62.913513,59.776321,61.73783,24.310808,-146.176554,-259.66004,-244.648244,-135.477432,-100.208147,-120.594605,-162.439123,-250.377716,-271.233001,-259.783788,-157.398412,-99.808589,-76.146396,-68.167879,37.770542,86.325986,72.91279,30.896316,52.204159,77.431453,25.110217,-127.197489,-167.666481,-138.36984,-87.84999,-23.662998,-84.275289,-114.24299,-78.015751,-45.021059,-85.035295,-143.081936,-177.117412,-114.964244,-94.040153,-100.892973,-122.498015,-167.360813,-192.886382,-278.06997,-313.345261,-284.518944,-167.99698,-117.950596,-65.438867,-49.963742,3.258475,40.120984,117.514306,171.877057,187.225941,176.416924,119.860906,-30.17769,-65.117462,-69.287499,-58.218297,19.017076,117.33741,137.883791,130.199526,126.788391,119.664701,78.828083,-59.867474,-84.390304,-37.823128,10.714173,-54.23982,-249.313149,-280.222757,-192.724206,-119.770744,25.175496,108.888962,130.995736,174.831543,207.846989,274.600188,287.901583,288.951295,264.593193,231.737755,168.327745,137.355176,49.671587,1.350657,-87.04627,-117.021273,-102.66859,2.099732,54.533849,87.88201,89.269503,118.143471,111.287071,44.395811,27.272517,9.84248,-97.462261,-151.989447,-168.534845,-118.190229,-11.027913,-18.911752,-80.909533,32.098661,120.660256,169.041231,146.144177,141.057758,143.414654,96.934276,49.141321,52.51384,74.317438,69.322976,67.064391,72.938733,94.763089,128.960792,213.897302,234.487107,219.146082,156.897036,128.403467,91.055008,56.613976,-7.017879,72.004323,145.706241,235.303953,230.391136,168.032201,146.290639,170.753086,199.551375,214.766766,185.102521,177.409523,172.938418,172.471699,177.560779,161.182113,75.326087,24.947721,14.754545,-30.566528,-48.291478,-24.517034,-14.180609,-94.93537,-160.107626,-210.125959,-165.742864,-137.981662,-139.925084,-167.170875,-203.473128,-189.897847,-55.60438,53.065196,26.503178,-42.901261,-17.825915,78.346843,73.866632,-59.222946,-111.388542,-91.489293,-78.988571,-106.852668,-169.179963,-180.550436,-176.208124,-196.876837,-293.548231,-305.070918,-247.906764,-131.853389,-134.14461,-218.973992,-231.640512,-125.821353,-34.872322,86.964271,81.781706,75.334068,11.050574,-73.059804,-253.960536,-286.991514,-178.24301,-66.309365,-61.105328,13.475078,81.108775,55.962428,-37.259447,-145.321293,-115.794897,-46.213289,-101.473393,-110.332639,-65.205597,-76.541214,-206.725608,-271.751745,-273.812444,-173.273614,-134.261589,-87.357171,-78.851916,-54.785818,-30.366662,-14.965299,-46.144067,-137.841679,-114.771734,-45.60928,94.610817,127.033454,90.369507,9.866441,-196.186748,-278.464526,-274.524105,-233.293953,-197.775462,-129.725464,-116.435196,-131.471967,-139.492847,-129.407175,-108.092544,-98.229505,-99.799164,-114.29849,-137.11828,-121.308824,-51.179013,-72.129866,-104.940262,-94.324789,-44.838775,79.819456,113.825356,65.346383,18.30639,-22.620128,-9.144336,3.884538,-8.43655,-18.878395,-23.439409,-53.182179,-133.866027,-45.313827,58.243352,201.427831,201.313384,132.453791,97.626894,16.477762,-12.329409,-2.130472,-33.616103,-68.433853,-72.362315,-54.804317,-72.908318,-98.034294,-60.351768,52.620465,76.462311,76.940927,71.509601,34.268309,-23.539739,-211.2704,-266.888843,-236.579943,-201.061774,-187.740513,-154.036564,-159.483685,-210.460109,-238.278752,-272.93211,-239.403404,-164.680377,53.669399,136.751628,186.428504,147.313122,-43.638644,-117.872106,-80.450842,43.452275,64.727198,-10.631315,-58.399244,-63.122541,-41.788189,-24.186653,1.279351,55.267409,228.065463,280.332781,240.637501,192.090422,115.229844,91.90659,78.124586,97.825221,137.6981,198.666428,166.649317,19.989456,-44.010052,-100.451933,-50.596896,16.072351,132.560206,118.532031,1.139164,-4.03178,119.732448,165.676345,128.983376,57.825242,77.780952,166.596723,163.384869,62.112843,20.88405,45.684259,174.70932,213.289832,143.986556,45.813982,-152.155932,-192.183479,-159.580614,-134.217755,-78.341967,50.52781,115.907729,158.950371,137.594594,63.858629,22.041151,-57.6222,-100.216623,-91.487719,-31.479797,-7.844451,43.462895,81.545985,100.083483,76.080767:-91.248688,11.018222,46.673548,65.854868,59.510339,-23.797171,-105.370988,-223.356569,-159.91404,-89.284082,79.424038,171.167567,313.539626,338.690211,302.210754,274.791205,185.525134,71.683689,71.015572,106.603203,113.098061,178.639195,219.284698,244.943642,250.390076,249.485093,221.263013,195.852478,189.618896,210.577799,184.994223,133.793214,69.039468,131.299183,169.683231,171.256026,155.517509,112.273264,60.024401,-78.228427,-187.638873,-215.027366,-183.864281,-138.930105,-84.103379,-106.419656,-208.410655,-212.7089,-73.743209,38.25148,55.990689,96.725639,145.260412,213.902198,178.196526,73.101059,106.780653,121.18928,10.314359,-79.961013,-124.555255,-72.442513,5.920252,6.735365,0.496761,7.841812,1.562486,-16.128978,-22.338156,-82.376657,-127.912865,-135.219913,-27.296704,16.363019,4.368123,-40.640649,-96.631589,-85.657694,-75.37974,-94.863717,-148.036038,-89.400185,-9.884749,86.790159,74.946606,-13.833182,-55.95758,-62.917738,3.402564,33.233327,58.494338,35.303379,-51.237627,-75.393303,-97.290059,-105.326283,-49.71446,90.331457,111.671515,16.657251,-16.672671,-8.853479,-28.648365,-89.602494,-91.959456,-69.221225,-3.323485,-2.792745,-74.270893,-101.275497,-78.624739,-48.770949,8.351085,75.873296,113.79184,140.272033,125.33523,128.100466,160.369307,233.071439,187.293869,107.905125,-39.596534,-72.141425,-63.490725,-46.896405,-52.889881,-71.840323,-70.836697,4.1246,38.621142,74.092053,91.657319,115.693648,107.269234,73.984445,57.927515,48.517708,2.974693,-45.46253,-137.262578,-136.178442,-71.365916,-61.506163,-121.171701,-115.879978,-51.181587,80.823153,94.037656,16.980509,-35.214295,-67.266192,-13.874536,16.220645,98.881255,133.503423,124.248179,79.952382,-1.638891,5.405248,72.957817,79.843837,63.85148,26.474585,18.414791,17.100964,-1.461369,-41.590541,4.236182,46.437126,155.999238,210.277828,240.965432,210.281685,184.474634,233.754841,340.400104,380.632628,418.852087,428.535461,356.485356,192.083677,151.030938,103.933043,113.821875,157.043384,231.898135,243.149076,248.277736,241.425546,140.586158,62.61166,-59.019303,-101.560704,-78.823885,-17.13812,-11.776641,-45.073454,-69.214646,-68.662713,-34.550811,-45.169851,-37.618602,13.123698,100.820403,75.040729,-97.462238,-165.693432,-170.584433,-189.06112,-228.442044,-329.04901,-388.546335,-455.899288,-450.060228,-440.111656,-495.878723,-478.990197,-338.247475,-308.869879,-323.1946,-299.27122,-224.225984,-174.318734,-0.923953,107.126251,82.418017,-108.728136,-225.751399,-351.386418,-352.085713,-262.915312,-57.782273,31.935646,91.47899,79.039423,31.445584,14.426304,7.895343,17.498558,52.948467,35.557101,-4.812408,-61.742152,-63.968751,-87.264089,-104.170761,-77.289203,-82.099004,-125.273157,-141.681523,-97.95913,-15.015212,-7.551581,-75.717186,-113.302015,-103.960323,-19.74515,30.41798,91.618136,97.661108,67.029744,0.52118,-189.119302,-260.418308,-242.248662,-150.43364,-98.770584,-67.118895,-106.587125,-193.326451,-179.388796,-73.616233,-6.65766,20.504684,43.742254,17.086517,-59.273325,-77.15892,-80.530576,-80.397308,-92.542286,-109.577464,-75.884359,59.530606,93.959762,15.347759,-57.86344,-174.095904,-154.426317,-85.994835,68.225459,104.589919,-0.6732,-116.447552,-234.343861,-85.664282,31.61246,180.427552,163.541834,54.778327,30.421734,-0.941634,-19.188269,-10.958973,19.943735,24.832222,-4.041868,-27.11042,-91.399832,-147.350311,-210.480848,-64.437491,38.843016,134.393693,114.554294,24.914044,-44.235443,-201.920579,-230.288025,-188.401589,-123.410608,-80.237791,-25.150455,-44.873543,-138.77225,-170.835524,-169.455217,-124.988621,-69.020854,83.162329,128.844827,181.129653,197.88093,113.649811,47.789453,45.808238,85.210134,49.212051,-57.308125,-68.367849,-31.144368,-44.808363,-163.469389,-154.998253,-50.342681,180.117615,213.782452,152.147411,125.501738,101.685774,88.240749,116.399818,233.100198,264.470209,192.969566,140.558447,106.489534,95.611938,75.652303,121.513764,142.931656,143.504749,133.245006,115.088686,89.883685,-17.996222,-46.013796,74.242692,239.689452,255.267654,237.389944,250.718364,242.272379,184.003514,71.424137,102.452522,129.282807,118.912824,92.619577,3.285444,-61.244634,-196.554434,-238.011467,-206.685261,-41.312898,43.79731,82.049923,46.797514,-1.068121,-14.328043,-94.447922,-149.607069,-124.903886,-48.898135,-46.062233,-36.375922,9.036674,18.221687,-42.58684:111.473801,61.113823,22.914873,11.620583,-3.405053,-167.535514,-273.467855,-376.182025,-355.111067,-297.815952,-116.436081,-63.030285,-96.955114,-147.80241,-233.533292,-245.359179,-198.688284,-129.5833,-116.991346,-134.849327,-131.152847,-61.434264,-11.872027,109.647449,220.050173,242.215031,259.906259,270.181847,284.736071,282.892381,250.768131,229.634691,159.626709,69.290002,40.568695,-29.47002,-68.384796,-106.231833,-133.098772,-238.487249,-274.061397,-233.515608,-137.205448,-142.761764,-230.062685,-266.690025,-332.101353,-351.823725,-304.012,-193.677169,-155.348363,-126.560026,-90.86614,43.069722,73.052076,72.369817,166.326257,205.526176,183.257928,143.362218,57.277048,-4.645194,-149.421365,-170.140722,-84.402734,-38.292196,-46.210657,-58.660498,-78.745719,-211.181135,-290.110448,-279.959551,-130.84652,-104.132718,-145.358911,-191.126678,-287.592367,-310.362164,-337.273853,-345.567053,-255.300805,-84.65796,-39.323455,-34.334855,-28.225909,35.527781,62.7059,101.120298,189.238282,222.668451,199.90621,139.09886,-21.985352,-97.528417,-219.250879,-225.940256,-47.861495,140.686013,143.028938,75.995042,77.894513,84.732831,52.550631,13.880675,10.540785,10.69997,44.008236,36.801696,-56.295611,-97.431828,-118.071564,-118.714064,-98.422367,29.44602,108.02004,148.285953,108.804631,68.676013,98.186721,191.51334,214.830025,199.031988,168.241001,147.074334,50.698482,-45.394374,-259.372765,-283.163921,-119.768434,78.769979,133.124678,139.108414,107.199199,10.258698,-39.498194,-44.498202,60.896133,92.517226,109.207402,96.533661,28.022548,18.020594,88.044042,131.782351,225.695531,344.197624,373.678303,359.085615,339.891075,304.415135,279.298557,208.070287,148.649821,138.394285,189.264851,230.388117,247.161954,219.246369,202.426706,238.378502,317.822642,365.530667,353.085559,202.448482,126.279141,95.935884,93.792704,35.108362,62.64461,127.259211,211.520507,206.635814,189.043067,181.587287,123.894274,105.318216,147.180967,177.319023,168.91152,144.076491,141.673478,121.53418,76.399488,1.940371,54.274031,87.430959,98.622757,94.355564,118.126407,134.074653,81.011169,20.138226,-12.676584,95.400267,132.93816,93.363392,31.78913,-65.793276,-54.708529,92.735244,188.148585,184.941949,197.445319,224.37669,255.614905,229.254067,92.145509,41.529433,34.928353,-3.192806,-24.098923,11.777936,29.262118,-1.023674,-16.810838,-11.883884,-30.713448,-57.403755,-99.774202,-114.321304,-104.264704,-75.912078,-41.331845,-26.027079,35.500929,49.750879,41.576588,8.908833,-23.988465,-80.897433,-83.192699,-35.249904,-2.43063,17.408115,157.410041,220.732414,168.938099,88.692712,-47.006611,-90.347417,-147.387516,-113.630195,-30.589759,118.161006,109.034949,-62.035424,-159.492657,-262.488452,-229.158742,-163.477564,-8.641529,31.793178,34.121825,21.929267,-23.16569,-56.517934,-82.098646,-51.820437,-37.460083,23.819444,64.27562,51.063526,-28.949654,-213.781617,-267.072893,-245.028655,-137.311518,-88.927617,-108.747926,-156.504217,-185.820063,-179.149737,-209.346889,-208.961467,-201.067697,-264.60709,-318.960985,-340.858078,-294.261134,-158.721997,-24.112282,24.519163,18.500771,-8.184655,42.744195,74.900522,-58.676494,-172.293551,-207.181872,-27.593873,41.302157,63.849373,39.098742,-58.440239,-123.769888,-152.076437,-9.867904,64.513675,181.917781,213.281307,155.097858,91.050659,45.188733,68.247071,112.254077,119.63417,124.483928,138.097512,118.856661,-10.956041,-89.104661,-146.737076,-0.522849,76.721734,93.283803,69.975385,43.408113,5.807905,-173.57202,-255.695236,-260.957902,-159.850099,-130.835705,-162.111971,-198.896104,-242.625051,-281.499565,-413.503763,-343.577674,-205.926776,52.392904,106.774892,64.346122,-5.136503,-153.519029,-179.459862,-82.65594,68.911049,104.535661,27.004624,-42.195653,-116.606879,-146.379817,-199.920695,-143.946381,-66.321732,129.042451,181.589195,126.332039,71.27553,14.802667,10.046376,12.609885,74.055835,117.601476,52.115673,-45.731147,-148.385273,-142.194831,-107.450048,-42.403169,-7.221285,21.902457,12.10891,-4.570065,-0.394305,-13.925838,-1.829059,132.946786,161.884193,105.223263,33.517652,35.944188,-6.957615,-86.534085,-178.092064,-7.561535,60.173425,-11.19363,-94.419069,-177.236232,-174.436014,-185.436315,-205.488932,-169.301202,14.363726,113.78555,171.173596,111.819695,-47.587881,-82.431873,-45.044441,13.456468,17.065115,-21.321655,-35.645268,9.27221,39.805243,42.024839,63.161553:right
129.917392,110.540463,126.807071,166.281322,165.267485,161.841968,158.370794,55.982931,-128.335806,-190.854154,-217.961536,-205.919767,-147.954308,-100.828576,-75.573288,-119.689655,-202.071806,-105.804985,-4.397441,174.805537,227.522214,216.670224,155.313235,55.777441,39.880667,48.113966,127.601008,154.563941,72.271021,1.069366,-89.157623,-109.826605,-140.178149,-114.040217,-61.175644,32.191769,46.800595,27.732042,-4.212846,-48.06874,19.182934,71.140573,110.887187,90.975692,67.856481,95.215651,150.616762,134.107902,33.083965,9.709723,63.192145,180.901211,212.827289,253.283187,248.535127,134.816519,15.943554,25.75494,149.186595,196.215968,152.470216,85.982306,-9.577117,-32.756707,-93.476766,-66.061288,24.346699,161.346209,140.159427,34.716242,10.92546,1.612155,-87.784531,-156.926564,-186.383807,-151.77753,-117.70591,-121.240544,-146.25483,-164.449337,-173.084713,-72.638478,38.184426,269.280849,322.641058,266.591967,199.958825,102.353585,60.702875,60.774447,75.632554,73.82183,98.270512,126.373296,114.582591,81.112534,71.896797,115.340391,118.892663,88.507494,78.362462,101.613202,112.109021,66.697809,-9.735079,-4.243913,96.37779,138.183125,158.394121,165.716884,192.855082,189.002816,135.986205,119.407956,147.846962,217.216842,262.277368,397.518742,425.361255,302.745512,122.055593,88.839383,117.664517,131.267425,158.311479,187.665912,198.959786,155.11391,17.352361,-62.448017,-47.332558,19.489945,30.237241,19.165501,12.159116,-24.279309,-102.648223,-120.850543,-68.943357,-26.528463,40.214084,75.643404,125.902932,103.177284,-7.505329,12.155573,63.852808,20.211303,-87.509401,-255.506793,-267.435982,-202.598746,-100.633279,-49.032332,21.417867,17.169381,-58.945404,-107.726827,-223.795338,-287.953425,-335.092791,-225.467921,-148.089918,-14.180741,44.908763,112.452952,94.237278,-5.380784,-40.449478,5.417632,155.685734,185.178172,119.908176,84.307318,79.543067,117.441838,214.663374,203.685161,189.765341,188.053758,176.875948,172.430489,192.389382,181.412165,-15.324162,-150.041786,-276.209667,-246.712125,-144.964428,-107.723683,-60.081216,-67.161509,-170.741003,-202.59561,-143.64189,-33.869758,-26.970077,-53.846438,-66.904483,-93.71564,-107.581791,-86.005155,26.06256,85.52509,154.563492,147.759962,37.661168,-26.082749,-53.15004,51.28743,119.398157,216.806877,239.021438,250.203168,226.402666,126.748105,42.473357,26.55402,60.64628,80.693634,91.710609,114.73262,138.85596,78.105983,-114.706062,-196.850411,-175.180447,-91.389902,-75.497387,-116.111908,-154.336743,-214.574797,-225.47227,-212.060858,-147.309078,-104.117763,-21.186232,6.126313,26.104403,33.28028,49.573629,75.399035,89.771359,85.130704,94.774466,188.382984,210.810864,131.510736,49.057988,57.44565,185.298773,262.192742,338.537519,335.092189,245.34048,180.06144,100.143607,116.566306,151.308438,189.982806,192.951554,228.362352,233.860032,148.490435,69.81332,85.669659,157.964997,164.774742,173.08388,199.113946,185.248539,131.855524,37.786263,8.325403,29.509662,129.757743,158.294405,100.047377,41.233049,-12.967139,11.673623,35.178217,131.060682,171.977572,153.530082,106.932966,27.9828,15.592098,-57.271006,-225.897497,-249.332456,-145.234785,-89.430473,-92.681218,-161.039151,-296.784701,-274.517615,-238.009021,-188.136742,-167.597003,-90.996562,-44.036354,-15.964364,-32.475648,-19.937803,73.540021,118.660314,192.649516,227.256509,237.506156,191.435548,85.487258,35.780133,25.818154,90.409049,152.750971,252.959678,280.724934,244.463437,180.755825,91.430274,135.340515,157.683412,124.340138,98.433015,47.372891,3.171979,-87.560214,-160.522417,-187.033545,-159.53466,-122.65731,-121.879659,-162.182999,-228.330425,-226.554827,-156.653783,-76.074706,-63.831884,-81.003296,-67.539387,21.146553,60.459637,126.438833,145.448482,108.097114,37.008643,42.768222,98.051009,116.997486,144.477892,167.959268,198.383256,201.834864,209.385747,193.176622,169.342519,108.806841,63.492116,-30.580885,-94.638317,-97.817489,-43.40314,-17.719386,-14.058802,-30.053305,-20.234765,23.857572,89.006149,54.790729,43.126729,76.703916,102.942157,133.551766,140.373079,138.161976,84.381122,53.402534,74.597232,125.882917,251.109203,297.100244,269.431803,202.82129,75.355477,14.96249,-15.112705,-111.413606,-142.257665,-76.433127,-11.821211,13.899514,-107.458197,-131.721238,-15.012782,35.568388,2.053925,-10.047965,31.132005,32.509497:63.590838,81.778635,148.219593,182.62669,147.198472,113.717077,100.802436,9.147295,-124.364685,-170.061524,-178.01258,-165.345102,-122.299153,-79.387261,-5.745289,-8.066509,-98.184821,-133.046515,-71.054899,176.2375,295.349028,336.097425,266.494471,128.536224,71.141826,64.531325,113.367102,162.959988,238.380405,227.617708,93.17835,0.97212,-156.481905,-181.388996,-117.56336,43.48899,80.828302,103.160494,114.550708,95.016553,-13.973631,-37.412011,63.428901,112.317791,68.337505,34.074672,53.791451,68.487788,-6.223775,-115.577184,-108.727534,-0.068899,78.675837,221.710513,227.611484,114.008946,52.44754,91.866709,204.642925,214.348561,132.556194,70.299707,-38.323361,-68.531469,-87.191393,-28.113079,29.115185,104.590465,114.814333,143.238154,156.082651,91.590176,-72.061417,-132.472748,-147.68883,-126.792217,-133.670742,-176.808439,-225.046886,-187.367777,-117.505041,-125.125702,-75.550728,139.880997,238.42905,271.478471,205.343371,78.79649,61.874217,86.303668,169.109098,193.413401,205.744478,216.365862,202.742807,169.252212,115.390598,141.742113,184.268949,239.510119,229.673756,168.341622,138.723727,91.095902,7.567106,-15.436682,76.7435,156.177052,234.134673,233.395908,242.771669,254.850897,211.015883,152.724066,175.278934,247.386585,272.360701,330.999734,323.402775,149.127353,-68.411719,-111.26216,-47.237874,10.984632,106.582187,119.166048,12.465697,-76.879041,-185.720292,-158.208912,-103.882834,51.315224,113.949405,109.866879,62.163041,-0.959248,-28.68543,-34.268507,-32.753638,-42.650695,-1.98235,68.770965,141.397083,93.722191,-37.093254,-24.312997,31.175003,90.969419,54.834646,-91.384135,-157.956354,-189.520299,-98.429663,-44.354318,9.164042,-11.764245,-99.453585,-137.96885,-207.467548,-237.852682,-248.368668,-181.202141,-133.79495,-34.505513,11.865605,72.906127,76.697829,2.192532,-93.584396,-93.871396,-28.724867,-1.482626,6.514063,10.885804,78.782748,132.277511,202.351281,225.60654,250.993504,272.97137,227.585847,113.621138,108.800811,149.380311,122.629216,85.269675,-10.923898,-32.96002,29.065108,63.777302,26.964428,-27.520987,-101.658936,-56.543101,-4.831434,72.691632,70.262164,-21.754533,-81.577861,-126.806116,-63.81442,-11.39417,76.755064,97.805889,124.717376,135.312126,100.399083,43.909288,-72.961451,-65.1806,-3.943374,126.058018,164.025521,189.122262,158.599387,21.317773,-33.519804,1.409429,100.259042,118.675032,126.744203,146.727163,159.41065,121.312064,-19.568503,-141.068313,-158.523716,-133.371005,-125.510566,-159.19648,-201.502665,-309.32792,-313.398815,-246.137651,-75.976855,-27.73724,25.626596,64.527516,123.755329,130.096504,107.452648,75.679696,69.9022,85.073557,128.229599,237.742963,231.37569,95.380896,0.604946,4.269602,80.680158,130.77582,254.555434,298.828254,214.038203,115.184502,3.250533,75.132804,146.70813,256.240397,277.850847,256.738193,220.021262,142.889942,79.086531,62.722494,83.228593,110.1763,178.70061,187.179814,92.156866,21.812051,-21.247261,110.751297,172.782829,182.686906,155.169893,110.774925,107.061282,132.352853,120.196503,101.364225,120.090449,157.25268,186.951242,155.311363,39.048336,-23.363157,-142.409118,-216.176107,-198.228878,-70.845829,-28.729872,-91.551025,-166.97981,-276.708582,-255.844078,-210.793615,-119.833415,-98.073186,-90.16512,-91.40859,-100.153463,-91.263282,-17.637791,53.570444,71.248884,129.53262,175.186237,208.1894,184.392316,143.601106,124.938376,107.644537,67.665701,61.510933,116.852467,162.921653,184.787138,129.242933,-14.316281,46.630663,128.039223,158.366816,105.267193,10.526276,-9.867362,-28.115432,-75.536305,-101.990247,-107.941407,-91.618045,-103.852992,-155.064981,-228.736427,-207.192377,-177.661521,-214.397885,-186.009423,-55.398728,-4.552745,5.811681,-25.39602,-68.768938,-51.069939,-37.661617,-6.621863,5.362941,34.976752,58.977988,64.877597,47.171972,68.46805,188.256431,260.560267,332.491155,310.998419,211.199585,156.895333,29.15938,-93.947408,-97.45096,32.402647,107.269439,144.507626,106.400106,59.941891,84.430665,150.005797,216.946229,249.786676,248.836126,227.054624,236.66836,252.719195,184.111341,66.183988,75.139304,193.916804,241.554213,295.759603,303.267949,249.551458,202.346593,76.615847,-25.148267,-22.947065,31.937796,65.728083,166.218834,201.264583,134.274905,-11.496844,-48.475679,-54.058683,-53.576502,-56.408792,-43.114312,-15.365851,-34.419291:-47.126661,27.880791,103.331488,138.699135,104.243077,23.088899,-13.02137,-78.922107,-172.896353,-218.337631,-261.239121,-254.414269,-160.860812,-99.711103,-89.897388,-132.471832,-135.534384,37.423812,129.937362,240.99635,275.208401,323.595516,322.69696,245.181568,140.449693,131.112345,199.830536,237.411942,254.526572,219.198889,72.63277,-17.330103,-180.033433,-143.717903,-25.123609,183.452866,206.440929,155.494043,129.763063,80.541289,-16.627587,-31.128563,58.109218,106.789588,94.261999,49.357837,13.330321,31.25609,-15.124533,-149.769095,-136.134441,64.159828,163.948969,229.793029,202.471793,123.217342,105.317895,137.983087,265.263139,300.481614,229.539116,150.359952,-0.142992,-45.873227,-48.916559,28.328838,69.873464,133.365615,153.649428,131.090582,90.448723,22.040722,-61.602096,-113.694958,-137.473927,-110.96745,-87.751935,-97.794506,-115.845135,-117.999024,-127.422826,-110.37746,-53.106102,121.96485,198.721616,257.671954,229.392095,125.523607,91.765243,128.506742,276.405099,342.906808,355.559758,307.997538,232.309081,226.392295,222.924136,210.398777,225.284156,266.266162,261.677002,205.427597,163.738587,107.126808,153.835791,201.714774,235.579053,213.039161,192.470974,198.477983,186.984524,173.41459,132.35594,110.446744,138.00766,216.152958,228.738053,138.96538,56.436255,-61.847212,-142.957401,-164.142771,-99.529845,-40.723312,39.626786,41.370577,-59.272686,-143.944936,-259.721789,-173.549035,-89.531329,46.90244,115.313439,193.76077,151.554304,-16.781422,-103.056883,-73.703358,54.184658,73.947973,23.758254,5.232008,7.208137,9.829723,-10.849115,-20.176064,-2.990564,-1.768827,-48.122984,-158.348553,-180.508813,-173.765408,-140.324129,-94.174582,24.485668,43.869764,-35.956603,-104.064323,-207.068296,-233.483211,-238.664984,-109.683276,-14.509216,70.118331,61.611274,53.77279,50.077498,-4.326203,-94.368982,-107.576395,1.149359,85.124826,147.748609,124.388604,113.330903,146.981092,176.862873,142.226508,167.988796,256.383465,256.637687,206.23597,210.295272,247.05432,151.905736,89.112265,76.09965,117.73761,205.597431,202.695961,101.845801,50.830046,0.471153,54.443978,107.310279,150.248536,135.967265,94.183815,67.887684,2.800606,-37.596674,-25.275623,42.664645,72.983429,125.679864,146.021616,117.355207,53.139927,-115.586684,-126.963584,-42.644845,145.191741,189.345122,154.633881,106.194356,20.919639,-28.466225,-25.232541,18.184083,48.116677,146.32152,177.483803,114.219694,39.80347,-100.975499,-126.887058,-89.963361,-24.589411,-30.678911,-104.294326,-137.216816,-130.701281,-77.545767,-45.136623,26.21919,67.28803,190.792469,240.367334,220.049253,170.609265,73.727381,90.87199,135.480831,180.698596,188.105876,194.136531,167.310164,24.715597,-102.375942,-87.415297,88.486887,181.276868,265.216684,272.07086,234.770544,183.176454,61.669847,78.365636,151.688861,286.762924,306.576474,201.712764,105.992259,-28.992265,-90.299587,-99.974261,-28.700002,27.685006,100.241854,125.174105,159.401211,134.022541,0.836293,26.562953,126.126824,261.761102,245.660287,122.072983,67.124857,58.418703,131.4392,151.208979,139.194251,139.886122,186.039609,196.13775,120.469543,52.937594,-101.798219,-195.055342,-150.018985,16.380825,42.232748,-36.70421,-91.052887,-170.707,-183.631213,-127.477731,63.686986,114.633428,86.04061,55.244903,14.826984,-8.80764,-50.767499,42.553233,135.124554,267.046294,278.166748,216.701037,174.151094,146.766478,139.000062,108.254668,57.032168,66.891541,134.085934,152.134144,96.280868,35.646353,-53.070534,70.107064,161.010984,151.340126,82.800208,18.06547,18.480697,1.540083,-69.098309,-100.246937,-120.535076,-128.21265,-162.545674,-200.074847,-283.062315,-292.982274,-267.219423,-248.575052,-221.198563,-97.696731,-39.01209,-44.352409,-94.568295,-164.981489,-166.549684,-138.265854,-11.308462,61.526664,174.371103,208.889562,209.224206,163.386376,71.563073,144.581664,204.953096,254.150472,247.504739,173.806475,121.682034,46.697426,-12.825273,-30.394927,32.729918,93.304631,114.687843,67.335429,27.757936,57.84526,51.87941,17.445493,61.105569,154.682722,156.33793,97.981986,63.469595,-12.376085,-64.929638,-44.378708,72.058794,133.111981,226.325164,240.508181,146.442126,66.434963,-36.373609,-12.227634,46.109325,138.884151,138.835276,123.045662,129.220229,99.91211,-19.781935,-71.07891,-110.881431,-124.258431,-146.764945,-141.383075,-138.395061,-162.908676:16.632227,-18.17782,30.664401,113.012757,90.69621,17.601403,18.796305,-5.654313,-198.971993,-304.873182,-388.763158,-365.599577,-251.944373,-192.976764,-160.761336,-171.451668,-167.958134,-99.022291,-22.690607,154.254128,212.997637,213.764042,155.072468,60.260519,114.21183,152.415712,202.844067,215.830005,197.905844,146.383286,-28.021019,-99.574374,-161.848894,-158.494042,-117.837049,27.360489,92.556481,120.66849,85.562199,16.892121,-11.651871,0.773045,92.009533,118.400928,85.655852,76.009669,117.033138,139.027942,94.011742,21.329738,55.996044,191.912499,235.198277,281.996575,282.356464,191.562853,76.571684,86.751614,224.146062,260.843438,171.522672,88.236952,-31.63715,-49.737937,-52.795811,5.384476,84.316729,191.266461,165.485038,72.656468,62.117507,42.789931,-97.881077,-140.770529,-60.600796,-10.752532,-6.757698,-15.409546,-39.416489,-69.378565,-109.171681,-65.232108,-15.898268,120.774651,202.039061,303.038677,298.506385,245.384115,178.519045,171.784931,254.368039,275.048566,218.24545,192.162425,168.642641,156.652634,150.601182,184.311204,202.568791,236.941812,264.456514,274.748527,226.338277,121.224668,118.002809,147.873679,216.657512,232.670778,220.864862,205.616922,180.369071,175.470417,151.503928,105.022599,121.046445,199.077262,231.331819,304.527397,317.642261,207.113762,13.847224,-40.542993,7.729539,64.284276,107.037715,95.67066,62.778798,33.415796,-90.065804,-115.049065,-35.04011,108.835328,112.792954,70.681257,45.685606,-33.208293,-122.036091,-129.541581,-56.986217,-28.561897,-17.835981,-3.165587,27.711104,13.795526,-45.999207,-34.431311,-18.603467,-84.000554,-148.880824,-198.887779,-177.721181,-144.864044,-128.188973,-83.920727,26.152048,24.946811,-83.038057,-138.365462,-228.261417,-254.20706,-218.313407,-131.289951,-93.508521,-24.868835,4.495454,60.732184,86.191146,78.022506,22.275279,49.827889,213.390877,262.945887,222.829997,194.673036,193.096147,200.295582,213.529928,259.875832,302.225057,334.665094,313.994499,306.689999,327.355422,300.491169,84.709528,-32.910465,-86.663701,-38.725449,67.734996,93.39926,56.291153,26.512902,12.075537,0.57573,19.914586,120.91005,149.860355,92.434791,38.66692,-3.559188,19.718545,42.974628,114.063702,144.901295,148.597627,120.779569,74.54992,69.869509,32.573983,-7.308914,33.200536,197.257275,254.180792,247.355527,197.896948,76.73372,10.351672,10.736731,80.26008,118.688312,130.108249,109.266669,63.122898,38.748987,-60.705911,-179.396313,-182.259508,-87.630341,-42.874395,-9.174549,-18.679757,-94.974858,-190.882527,-185.273016,-35.739437,38.46145,76.809346,68.198625,76.000598,102.416285,160.75212,159.082059,122.215923,33.031226,29.842844,137.600704,202.740368,200.557767,23.36255,-34.700778,52.790971,159.651848,330.886686,350.537665,220.997836,118.081466,1.468086,74.569692,156.341193,261.953511,254.741191,178.246671,126.833101,-6.273047,-96.438945,-99.15719,-72.037206,-44.109162,66.884184,108.61805,68.020098,17.982364,-59.432381,-67.595284,-15.351282,105.768981,96.806358,-32.12598,-75.612721,-39.474577,54.829398,81.465827,116.781885,138.01892,158.921818,138.408337,33.688085,-10.180179,-66.338271,-170.24282,-199.157037,-164.8514,-143.487123,-159.019889,-183.543986,-230.78609,-275.509031,-269.432241,-153.468276,-69.720553,70.515233,107.765876,94.112187,53.798869,-19.342674,65.263509,160.940248,264.573616,247.13089,154.08512,100.526166,45.360869,49.030157,48.327505,64.269105,75.318813,83.770523,89.021602,75.33681,33.669546,-41.82489,99.519132,187.961213,173.168763,114.519235,62.767356,61.680475,58.150975,-28.706038,-100.1163,-115.556023,-60.825983,-40.169713,-95.920645,-181.276375,-182.939681,-224.135287,-287.549718,-239.4238,-35.286664,33.578608,26.792801,-13.673525,-61.668261,-73.591237,-79.672928,-48.014406,-17.196038,10.663085,14.99998,47.666828,68.3712,88.449872,120.371337,151.431038,185.527288,182.489298,141.858451,87.187043,-39.507471,-81.056479,-95.646359,-122.822585,-105.260328,-21.831238,7.029734,-1.315829,-12.383145,-13.903473,-27.755555,-31.468443,-14.425208,24.381688,137.233259,142.904922,18.354533,-86.576183,-71.104178,102.972678,202.96337,281.487717,262.069401,169.884141,120.638425,49.319719,-25.72361,-64.083575,-60.980832,-8.073049,82.370096,68.505949,-34.844328,-92.011103,-99.838478,-97.076135,-83.156789,-19.253077,26.771055,70.892874,42.274045:-98.37007,-115.079373,-65.94656,33.737106,50.040343,-16.046443,-85.762666,-190.928396,-229.362168,-246.052017,-263.094854,-261.164652,-189.538385,-117.682852,-66.895478,-115.276385,-192.512414,-108.063465,-31.224125,96.037223,134.992298,191.336851,201.837316,150.775427,62.551436,61.347919,173.472607,232.777368,253.029023,213.496857,57.001421,-37.818387,-190.31342,-197.939479,-124.53903,85.413716,161.990765,177.205383,130.944705,36.881567,17.647803,51.534755,144.12572,144.14931,88.673981,98.221766,150.059345,130.961605,-1.944709,-54.415061,1.076013,162.883825,226.472071,292.728013,286.292832,235.785904,199.848341,198.368825,257.923487,291.598501,269.690056,215.474784,95.111433,51.389144,17.801377,85.973619,137.644337,167.230005,152.194067,129.625219,96.895436,-62.295809,-191.574237,-176.463395,-18.269936,48.336361,44.489959,16.346525,32.584134,48.359265,-1.6928,-21.588571,16.914968,128.601307,186.347307,262.350856,264.443123,181.664012,55.259207,51.234565,181.124176,261.592849,354.911658,335.280698,195.090901,145.392755,127.174564,117.10708,131.697473,230.400763,290.422729,346.621725,316.796692,172.681843,75.352137,97.255435,213.578749,260.485779,319.456278,315.362373,184.937383,100.136179,9.247673,23.973842,72.473248,197.451916,240.237905,226.2416,159.913549,-31.499425,-171.801307,-175.953926,-83.400068,-44.73153,-26.630667,-29.358381,-51.420936,-88.231903,-184.143315,-121.393559,-37.810309,72.842769,104.066202,169.442287,159.201436,-23.275537,-182.588821,-156.716997,-33.72715,-28.078691,-64.979513,-45.718737,12.170581,-19.434747,-168.510675,-154.689888,-109.125092,-119.508441,-155.324643,-170.333464,-148.736753,-136.088112,-188.752452,-164.505242,-26.535855,3.71539,4.354687,6.795712,-50.802467,-108.177437,-198.531105,-183.663595,-119.866757,42.358831,96.539204,109.212478,83.827368,4.070129,-71.771438,-44.728499,122.100162,173.095921,140.205892,110.7119,104.823057,116.458499,132.130451,133.654622,148.956351,251.578989,317.829425,363.290362,336.56552,258.23151,140.876548,88.008207,73.157191,97.919959,174.857603,198.979461,154.805702,116.815203,100.379962,141.810315,175.960006,262.373996,270.769618,154.94385,75.163432,-18.042856,-26.529875,4.920481,118.71839,160.222222,164.073478,155.085982,187.609615,195.221986,53.713376,-84.612614,-37.435777,165.900701,227.397347,214.74406,174.066079,91.324121,7.463443,-12.80979,50.682214,115.904062,199.374351,190.364775,97.471022,40.062768,-69.537583,-123.500992,-100.939096,-7.872977,35.174104,69.576474,39.908069,-50.053512,-29.423558,16.461588,113.26699,166.403032,270.040354,288.854201,265.781361,249.146247,177.638526,101.024172,83.545222,109.69669,171.031405,288.795124,282.913133,143.084376,-0.56246,-7.555127,117.861956,204.720447,325.680298,339.178443,284.361654,233.250421,119.547538,142.605631,213.836959,294.520482,278.626292,193.888319,130.507216,-22.430659,-136.245372,-135.813174,10.291348,107.797696,212.321019,198.708327,77.297277,10.806134,-52.118557,19.770569,83.712513,165.991434,161.086325,68.873894,10.039532,-10.183341,119.919179,164.773958,120.862219,92.871,168.299763,212.544231,134.464231,40.92372,-145.684162,-223.366523,-178.169478,-44.494069,-11.44195,-9.420444,-33.897593,-122.321912,-185.551361,-169.94113,-55.77007,9.135434,88.167729,79.779563,20.282626,8.203263,-11.996649,51.815947,151.939816,315.103624,324.787499,227.066147,155.687792,54.939797,28.660143,28.912889,19.58183,4.203303,-4.01301,14.237839,13.806774,-28.166166,-130.420224,-113.064029,-62.698328,39.812826,87.695892,115.437749,74.736068,-44.425215,-128.318442,-138.198913,-87.633881,-59.185919,-47.59518,-69.695964,-189.539502,-272.36967,-410.5314,-409.756808,-328.435846,-104.132954,-25.738769,-24.853691,-85.139149,-183.720444,-174.664935,-157.303602,-96.039472,-39.012224,81.141984,118.714551,116.61723,78.167908,-3.700365,16.509546,54.131613,97.614899,106.491873,106.674305,84.451957,-31.172493,-184.527887,-182.60312,37.131121,157.55016,194.737943,114.233755,-85.073161,-161.564465,-274.049437,-239.460777,-162.819688,-30.477608,19.127201,98.745518,84.448008,-58.495562,-162.052979,-137.77131,53.367763,158.672264,244.599405,219.940889,147.900619,130.185149,71.600226,24.436676,47.627708,115.926504,125.659496,92.748902,55.683591,-48.005414,-128.848736,-142.764031,-133.585381,-109.286566,-40.143576,-37.726771,-122.517073,-163.504501:50.714461,-6.819855,25.682863,78.229073,68.160356,48.519055,47.578114,-8.825528,-158.418506,-222.640172,-280.398998,-300.835637,-341.841388,-336.249166,-281.061346,-251.987543,-202.425102,-127.243825,-75.656196,2.81925,37.108481,119.225157,141.042015,120.782996,67.751876,70.114902,147.515798,181.573766,183.778744,160.341045,86.281284,43.369469,-44.770146,-51.020923,4.311738,124.544269,134.932559,29.769659,-48.716885,-98.782016,62.317636,163.246659,200.05315,124.682253,11.312418,41.50971,159.449658,185.179634,176.50614,171.143687,198.580759,299.218011,337.542379,325.379239,278.125697,172.859137,94.406633,96.314822,223.600285,277.106318,229.27562,164.201217,66.983873,34.172504,-8.866963,54.0324,119.470286,143.566504,63.786146,-132.575906,-187.400231,-195.743302,-135.100618,-97.553124,5.889127,39.793976,-13.061346,-58.381515,-82.615135,-78.551764,-104.147358,-132.752285,-70.754338,177.791418,272.879876,321.056289,287.3515,142.455775,47.446448,77.085774,196.053869,207.023643,124.914908,89.412556,96.465874,114.189041,77.134311,-37.123531,-52.705538,64.095064,135.213153,150.749694,109.527754,57.498807,67.745353,77.899802,117.630032,138.470676,154.420174,146.704659,93.108006,61.984617,41.153101,72.227884,92.012123,114.491649,132.796465,197.422116,208.356742,133.683457,68.564149,82.157719,128.732716,139.108079,178.971649,209.119518,206.46351,157.349487,11.008889,-56.029777,-31.651274,-5.586444,-24.916291,-43.591349,-66.827703,-177.189635,-223.558416,-206.271636,-158.882269,-145.190244,-104.279312,-73.625284,-54.589902,-80.491328,-158.800486,-144.407019,-121.39769,-180.428855,-235.963381,-279.842637,-278.626816,-260.3671,-235.251468,-209.011148,-71.578214,-8.522766,-33.543385,-100.21364,-216.607075,-233.700733,-191.266883,-151.445276,-124.601048,2.81981,69.923479,112.325089,102.792366,111.194594,95.876679,79.576964,169.42171,244.913841,267.017016,240.17285,213.762058,199.223737,138.04025,67.467239,83.469944,236.59324,293.873461,265.66747,231.322681,195.004291,39.695592,-80.044384,-193.398851,-145.215302,32.079149,69.291084,5.981194,-24.826797,-26.670453,-13.703116,7.409528,49.722966,45.520127,13.117135,-4.312864,-85.03385,-153.450514,-134.288157,-26.235029,21.93143,49.139878,29.457263,-2.446801,15.677694,78.518964,84.41071,77.24288,128.451598,190.480102,250.299743,210.439816,81.152032,-17.230359,-50.014132,-48.06033,-23.468888,15.689485,33.14845,21.54545,-37.91209,-216.05399,-265.044379,-186.165715,23.548836,61.412375,-18.536088,-86.28344,-175.828029,-188.07358,-162.336577,-33.928489,32.09419,76.813215,68.44461,96.326458,145.142361,224.889802,229.918026,205.668831,109.988193,69.670796,61.423485,82.726833,173.330394,208.747387,157.996841,114.826026,176.937878,323.142791,346.94308,291.920103,244.346343,204.281256,227.190017,223.727091,184.72375,168.961955,133.235073,91.567757,8.039854,35.816693,61.065884,82.11136,108.393047,211.205061,224.010588,69.15679,-26.678586,-77.313956,-28.815775,-2.564216,73.866479,109.490529,99.192361,71.273687,108.080502,158.299208,123.368091,85.308219,111.953443,146.656015,139.253315,102.86829,80.515563,-9.726134,-158.032495,-197.235923,-156.545721,-101.667919,-47.703474,-90.086401,-206.241793,-170.657086,-124.664977,-102.651124,-108.610614,10.66587,118.225068,176.488609,108.126363,12.801219,107.076315,169.851582,244.541571,250.071787,179.214427,123.040696,78.860177,101.384851,102.247623,142.603062,191.189486,275.764937,296.403741,221.735052,121.174229,-15.499406,86.971908,152.842174,125.59065,73.794311,30.41433,19.013917,-40.700178,-98.581437,-100.706381,-41.375691,-17.607274,-42.669684,-70.898803,-140.710928,-170.442865,-152.497393,-105.446369,-102.812456,-60.50817,3.510443,121.388656,129.237559,93.745205,76.604464,57.411657,-7.133052,-33.039226,5.720619,80.741604,216.812622,232.512818,178.659481,90.764441,86.894541,147.897485,143.606661,38.149365,-5.78288,-28.838127,-74.663447,-105.581481,-108.916352,-82.639751,-18.133181,-4.545686,-30.14034,-43.769266,-57.537892,-64.766819,-65.295956,-65.585341,-46.89406,48.81641,69.812576,-21.364534,-89.482082,-68.59662,43.929062,115.824116,206.016787,196.564923,109.805942,58.10707,-64.675656,-147.155459,-156.794875,-159.957402,-157.076683,-112.518482,-68.209159,-5.684675,-72.615911,-115.110947,-105.759853,-64.063155,44.466488,83.93944,50.143142,-12.045002:-43.347725,-47.231602,18.585913,111.903274,97.905444,0.291529,-33.504155,-53.594252,-130.430675,-183.633909,-260.363325,-277.046124,-222.422912,-178.716087,-211.611423,-253.648172,-221.148487,-112.110738,-47.046908,113.508753,171.837048,162.695823,109.670554,44.56549,74.239862,87.693246,103.406513,112.950117,130.248587,109.616259,-40.625732,-133.67241,-269.089548,-267.708479,-177.549823,96.879266,206.043556,226.743727,131.655218,-94.298031,-114.565264,-37.623736,126.192345,164.105249,175.342004,168.331689,152.00378,154.865285,135.972798,71.005304,85.615919,222.782813,286.05963,317.772531,302.784507,238.932604,113.43514,101.533475,265.492314,338.333527,263.143235,167.528986,66.60652,56.389475,22.431333,61.94615,117.166787,154.547,127.31446,80.387571,60.439613,-39.930832,-165.833743,-179.840484,-59.968909,24.385424,100.921145,90.324731,14.921056,-29.287688,-80.628416,-43.5201,8.898186,121.200844,169.669323,249.211439,255.522983,155.651561,31.893531,42.093642,170.890522,212.786272,235.937321,236.602554,178.454985,138.910667,113.225804,125.123419,148.190724,240.453514,280.091082,279.650474,247.857119,192.436673,156.762639,148.024853,188.250702,227.713641,297.962926,307.605503,197.399909,89.146599,-75.7162,-18.18873,71.060284,223.184495,273.366264,298.984815,256.156768,116.327295,-37.393043,-90.527679,-68.947424,-16.299339,60.17496,64.802345,36.420333,2.822908,-135.797887,-146.511096,-58.343737,76.040714,83.512843,52.529554,7.122894,-155.723355,-257.486644,-231.530403,-91.950982,-41.217319,-20.310421,-41.610307,-139.750073,-194.503629,-246.846421,-185.682721,-151.907111,-195.798168,-241.159302,-232.269786,-196.074145,-203.855054,-257.798571,-218.884977,-46.284369,2.572617,-53.662229,-108.828023,-171.740032,-194.217835,-266.627312,-259.414781,-184.729156,1.39746,56.521459,101.004585,115.512937,102.327191,17.199395,10.392578,145.352649,225.103301,265.182289,243.417769,202.623659,181.814711,119.202683,125.96499,176.735925,298.195449,340.195046,337.744496,291.913569,188.640159,49.729693,-30.746522,-51.517296,1.309537,62.383219,52.298103,-0.854773,-28.938958,-30.313897,105.163974,197.981397,286.15236,255.711765,127.864304,66.045048,-32.309945,-36.691683,17.079526,136.433169,149.922733,107.855884,86.210654,57.625876,45.839863,32.583011,68.552657,115.135198,220.852806,254.919413,251.764377,217.135144,116.415031,-8.31071,-37.563368,49.821059,113.024752,118.390954,82.723769,40.352141,23.825776,-55.307764,-104.614258,-66.5802,77.667303,125.247607,89.393063,12.134913,-166.995428,-200.673352,-122.509422,100.314524,174.979523,214.352248,187.429077,109.921681,89.916763,59.814446,87.053346,133.005503,169.911069,166.545445,217.532302,240.209077,157.147824,-12.25039,-41.128566,70.743878,151.362126,271.159443,305.519846,272.142949,218.401239,156.134027,188.831314,216.589932,224.93204,209.564115,184.903338,155.477769,21.488544,-103.466411,-106.787927,15.285465,94.471753,172.109018,153.397089,52.314356,9.515145,-50.203906,-26.638226,43.008027,192.609067,223.192909,162.874826,84.89917,-29.917353,50.256873,106.615314,129.619291,124.584711,164.886015,188.248815,143.092903,81.66366,-57.557721,-143.285808,-130.330891,-52.561927,-19.360695,-18.05193,-74.968556,-232.246288,-295.378718,-270.066017,-121.465855,-30.985977,102.360505,126.69514,90.667742,49.938834,-14.594943,61.978963,143.621779,245.943712,258.876301,245.192936,210.932917,79.830325,-68.686745,-83.370782,57.677582,142.936237,181.142175,151.698553,63.787323,4.39258,-103.682703,-87.949007,-47.016295,6.982824,30.133612,48.694585,0.672795,-174.553927,-234.889165,-190.257226,-63.447412,-31.122439,-45.562981,-86.092235,-225.395548,-280.676193,-296.477466,-289.864945,-261.965921,-98.545979,6.583643,91.788607,36.263052,-119.987321,-182.627219,-188.40241,-150.86462,-102.268892,8.676304,43.281937,74.486228,89.210538,85.764786,35.810387,32.904593,84.328141,110.577109,88.627127,42.726983,-63.925198,-151.890667,-151.616993,-53.964911,-14.300434,-12.611678,-24.630204,-54.293923,-82.059037,-178.643344,-233.934845,-204.527913,-75.513445,-11.147132,39.620488,4.071278,-137.665146,-184.078998,-129.947468,69.024811,154.650546,182.052523,135.524404,52.535861,28.896827,-51.741553,-115.075699,-98.240366,7.129788,55.970719,53.074138,23.758556,-1.243564,-40.183638,-75.883764,-109.209085,-90.90308,-28.518384,-15.830831,-41.067948,-71.899119:33.913138,-84.928782,-55.784579,80.387811,129.409409,153.20161,147.321173,151.911584,97.157727,31.100545,-60.291867,-66.428929,-68.274711,-100.223403,-245.261077,-290.623093,-164.288945,80.327714,150.007383,152.611096,124.268357,93.176482,82.428342,24.612057,19.286283,79.703156,233.295533,254.401764,142.709937,71.960201,14.466709,3.849611,-25.813122,19.962892,90.694313,187.298023,153.258581,-12.131,-64.770051,19.828753,226.925886,267.201346,206.510052,159.760621,88.884952,71.490952,96.406809,124.074507,130.06749,123.307087,173.179339,351.527087,408.910032,313.401533,192.613826,13.980391,-18.260685,-11.138063,33.508705,58.599008,75.873057,72.958622,49.526085,29.317402,1.583812,24.10519,42.855325,27.360241,-8.502642,-82.383603,-110.761895,-167.998138,-234.904129,-229.135437,-92.646755,-32.642023,-74.557763,-124.345453,-104.721283,-51.044817,-18.021922,-46.172995,-8.871196,94.541865,105.459993,68.167723,36.265099,-16.936245,4.763488,35.267783,105.176506,128.348729,115.302959,74.122344,-48.743189,-86.689708,-44.745193,19.171803,16.817222,14.000825,16.269895,-9.38174,-22.528301,23.744933,113.497189,105.967431,14.248421,-1.891877,89.226678,131.362739,48.252226,-37.940611,-134.404075,-84.733732,-6.926699,148.958813,173.043584,149.539038,148.659978,189.534025,223.001194,231.048744,243.872707,238.944697,238.80499,253.32249,247.488942,213.723557,108.725656,-40.8413,-109.023549,-169.708529,-157.770896,-114.461191,-123.322443,-175.973446,-214.438248,-204.605619,-75.270024,-1.379552,10.064781,-39.837938,-111.911293,-103.779268,-69.389812,-100.797378,-125.258386,-177.933552,-193.206298,-154.590544,-127.1707,-119.090191,-106.516797,-69.940477,45.387477,67.138575,-48.899223,-132.64773,-205.033939,-192.822674,-140.893933,-110.652215,-88.217521,-33.860185,-11.460866,71.092149,116.817932,138.790555,100.066334,88.093556,124.908422,147.183231,126.889963,100.638899,67.6407,70.229814,73.946724,-55.858429,-119.940133,-77.498721,-15.605385,50.1981,63.682514,56.465771,-67.414905,-138.009043,-173.212667,-148.221382,-94.449566,-83.75918,-101.557313,-119.653917,-168.183053,-174.861412,-140.687003,-94.22763,-110.134408,-155.471369,-169.220519,-225.448166,-271.823753,-250.601578,-195.296893,-211.394354,-250.89303,-218.786676,-104.194521,-76.706087,-88.855369,-57.431009,-17.316967,53.960312,80.585314,74.25717,15.205286,-117.569288,-160.634274,-185.985252,-227.750975,-221.76648,-166.380128,-130.688055,-112.986877,-138.919169,-217.307587,-233.045817,-179.260113,-33.052395,14.172151,40.789658,7.479451,-113.892435,-112.970989,-38.234336,162.266548,218.058209,171.844003,108.571785,60.273366,114.869806,253.02197,149.827048,50.47078,-41.719194,-39.267627,8.343775,48.598262,108.227881,85.70259,67.717978,83.852519,110.741782,147.964276,149.693423,153.578335,171.361821,208.067375,196.919215,175.380199,111.517709,85.433562,57.686782,41.336564,26.936893,48.147554,55.248233,88.506193,108.681934,126.993845,121.738317,55.154418,14.731225,-13.246733,-1.867719,9.040061,13.130802,-6.019276,-32.196667,-21.588921,27.195027,62.515482,66.345406,107.632369,147.875635,185.276962,172.468958,135.338645,128.591497,95.727637,-0.9845,-25.212966,-7.114905,11.46297,40.907916,23.46423,-47.618581,-20.029246,-4.281357,-39.956093,-48.924828,41.004199,116.835639,170.925155,126.207375,44.272406,127.239823,178.690815,169.272839,126.304672,29.761263,-11.331783,-20.270883,24.258415,37.997253,121.427445,188.151297,249.743974,237.615895,166.143895,94.401316,-73.426898,-89.018103,-49.760472,-17.989003,-20.009609,-19.117921,-43.702694,-131.291035,-147.195958,-117.714031,-15.603017,17.128784,-4.481693,-25.201644,-62.191354,-101.248403,-202.425273,-178.107845,-109.672091,-12.736992,-0.400882,74.149277,136.90651,211.295934,217.552953,183.055372,30.559042,-23.500208,47.924766,133.070441,237.337075,243.005954,204.231399,166.514291,164.839526,142.626618,99.473989,23.575967,17.582381,41.253805,56.863505,46.342418,9.930213,6.646352,68.692508,106.689013,53.472982,-22.211305,-96.331366,-35.539126,15.073653,77.572213,75.504619,53.879878,39.728003,-15.792582,-72.26521,-83.081051,-23.866558,27.518618,95.136315,119.14181,142.265744,118.686737,11.280284,-84.878688,-103.298515,-92.692984,-73.957077,-11.485999,23.697335,51.331359,-15.633355,-43.803055,-8.179493,-5.553492,-121.239148,-153.051004,-52.311346,4.22706:147.109577,39.416251,17.418693,56.188566,81.601282,106.282254,118.623509,133.959729,60.850837,-1.343377,-60.249345,-58.171915,-78.471591,-94.076432,-109.301008,-114.126391,-126.08862,-86.137731,-11.36957,182.77542,234.367082,169.670076,91.867596,-8.661158,-10.594494,12.623257,120.35233,153.619133,47.847788,-46.457192,-153.486978,-154.681043,-111.859555,-72.783077,-41.424015,-1.774134,-28.091723,-122.049995,-134.346946,-16.594383,187.447901,261.933862,259.008775,176.269763,44.181951,69.542048,157.81723,143.008931,64.007786,54.094504,80.245325,193.242364,250.169989,217.254777,136.391076,21.966498,21.113012,43.354303,123.354603,154.386628,122.280889,79.82756,34.205258,20.724253,-35.404354,-40.210497,-5.411423,25.481212,0.224618,-65.25979,-80.289776,-84.6641,-161.857862,-208.292345,-141.968007,-59.319128,3.327628,-11.454985,-29.944007,-29.875214,-60.766036,-74.617927,-8.889457,186.254896,228.407742,169.484922,116.052339,32.525687,12.437918,37.158376,101.606686,105.933329,42.544089,5.48107,-12.432315,23.171121,126.318998,91.07647,49.440197,69.070488,117.713277,176.143336,163.056167,125.886222,171.954688,178.267713,92.511093,41.666801,40.849409,70.484436,79.768218,63.614958,39.051386,73.062057,127.840927,208.440497,217.020378,277.964289,318.960178,303.4583,268.518018,296.510646,342.070754,309.401984,225.203239,230.009615,260.553128,221.866551,53.806502,-48.115667,-49.944506,-52.751288,-71.365872,-107.009429,-117.33616,-114.082437,-128.383542,-152.281324,-156.686451,-139.561253,-114.054365,-88.768452,-5.520555,18.284477,-27.815455,-81.406357,-61.668827,-44.553201,-98.062926,-262.752602,-319.060969,-289.869147,-129.404139,-70.34014,-55.407241,-95.267718,-185.697712,-203.425211,-221.28349,-239.145806,-259.17602,-207.586156,-144.795399,-10.064038,37.399993,106.893821,120.064977,87.141146,46.114615,52.058008,125.141278,151.761715,113.788222,78.705536,66.903827,107.52159,180.992203,112.56552,88.648427,107.222106,102.794894,71.278394,68.10972,49.307568,-79.550875,-177.111503,-316.50515,-336.662931,-280.547936,-222.622235,-162.488123,-177.335098,-254.939287,-308.710532,-281.188082,-181.376141,-171.72508,-225.87627,-257.753264,-302.616676,-270.070191,-216.014376,-127.368386,-124.754708,-122.64823,-81.788345,22.630169,34.623061,-13.556209,-4.848185,48.215174,187.578067,222.929214,172.265516,118.227199,24.434873,-86.155654,-132.572276,-115.985813,-74.360416,-7.351508,29.44418,30.586242,-50.408156,-233.198242,-224.599235,-164.314492,-58.6846,-30.968063,-16.307004,-48.697796,-156.873716,-157.219058,-109.591338,13.45145,54.622473,67.064747,60.439634,76.203372,102.05533,151.139738,130.240935,102.964025,44.450804,23.98801,42.624758,78.752534,158.772259,126.678092,79.713925,96.628205,156.012509,230.371607,227.516676,183.835533,160.619195,133.771297,129.646434,145.353965,181.472741,180.335772,189.935281,203.587395,178.272234,117.78606,110.468957,118.829413,89.673562,53.330774,92.977451,125.305606,72.220524,-39.600674,-59.086444,-53.353778,-35.134952,-40.102013,-86.206112,-102.854548,-105.032255,-108.457851,-93.17574,-7.678032,17.449044,18.233159,37.844284,85.17005,62.714511,-79.252191,-167.893615,-149.220134,-55.773966,-6.291612,32.580725,-14.470487,-134.505186,-109.437525,-92.644925,-131.419647,-152.201433,-102.193385,-45.766874,16.777761,28.958277,108.772204,252.204732,304.273201,269.905425,214.002576,178.09636,183.160016,160.753593,98.591322,72.765346,121.868247,197.030414,349.889937,382.822184,319.397617,250.108676,126.766901,82.34882,84.631909,74.702213,47.392442,-40.54816,-82.01312,-116.113924,-86.880068,-59.276702,12.663931,27.526453,-22.366193,-53.923949,-123.511102,-165.201283,-168.441848,-68.485686,-26.910499,15.956154,55.312065,177.230061,209.690534,225.733757,265.304358,252.074037,92.40041,-8.948625,-41.628273,56.021835,250.85567,252.078362,134.361846,119.660614,158.84748,180.124134,144.428992,68.466584,40.190974,-27.263167,-60.203434,-43.542051,0.466731,-1.821424,-14.503627,3.108806,54.455318,72.956147,82.10906,74.139315,95.161962,192.234887,242.122619,260.072101,218.45309,113.010956,10.28471,-38.535523,-39.006105,18.41697,153.295834,193.662232,202.428108,192.346314,178.846155,106.213532,29.63321,-119.579235,-138.764126,-56.219934,-5.642079,14.510637,-50.010423,-59.85096,-2.368329,5.097974,-58.176456,-63.463318,-16.788519,-28.068313:-48.408751,-218.676024,-150.330482,99.613831,149.392499,96.040536,55.781411,26.887165,3.649045,-54.600566,-224.796666,-282.579317,-278.577316,-251.915537,-297.798191,-343.189797,-265.489717,-43.617526,16.834053,29.610951,43.156395,123.267717,132.696032,41.409392,0.576141,26.872274,137.25107,215.168405,262.5652,166.258261,-115.889087,-178.166133,-107.669345,-16.309886,12.829182,89.721368,120.069129,109.391628,69.577066,-31.479314,-18.093175,42.63131,148.721617,160.62708,138.471227,134.784826,100.76166,59.344816,55.374269,119.933986,133.08018,175.51426,209.654285,247.298813,237.600773,147.343537,29.955537,23.685025,160.570172,235.448949,213.909467,142.644464,52.690353,53.023464,85.7349,87.956204,88.773007,83.232741,40.501829,-86.415786,-125.785479,-163.198717,-127.821889,-72.247624,16.755706,5.766623,-69.147713,-68.159524,5.685274,26.708968,-22.286874,-68.791025,-40.99591,47.980956,80.145227,134.513853,162.052098,208.961241,196.090511,164.410918,120.354477,116.759202,141.21963,166.5704,207.779285,215.41584,174.025833,66.490495,20.692835,-16.615603,-1.480101,92.972853,139.092819,137.652598,89.316889,72.664804,56.634333,59.752508,83.559276,94.91231,53.339568,14.961887,-12.381048,-45.555459,-54.250088,39.840577,117.67557,191.155417,164.575499,68.201928,17.389028,14.756272,59.19179,93.720877,115.442515,99.563991,82.324698,87.831032,58.200348,-8.981926,-13.700139,1.584163,-10.081716,-85.728191,-138.160179,-190.656411,-134.505398,-89.418262,-5.090308,18.551201,7.148277,-26.45994,-117.330633,-135.309863,-108.923172,-114.297584,-129.355941,-182.349344,-211.755388,-196.30808,-158.389235,-121.296188,-125.621488,-91.399111,43.629091,82.740629,31.086325,-35.091956,-136.775452,-133.162587,-85.545489,-136.38418,-157.12805,-71.586833,10.571212,131.748035,131.385249,61.347669,86.422916,141.261824,235.422806,234.663526,185.980444,176.666392,165.185028,151.517958,103.091559,29.634422,38.200118,163.364606,216.749101,197.889846,154.606926,129.970213,80.981084,-2.353748,-130.844317,-112.361221,19.120598,51.04534,5.922184,-14.691956,-0.392098,69.263551,124.351157,137.712936,74.902297,-21.671199,-31.467083,-58.170621,-93.727487,-119.721877,-184.245965,-179.072537,-75.331667,-33.579773,-29.302031,-35.763868,-40.814931,-54.553587,-37.924186,61.178943,120.297157,161.394807,115.995354,-26.38147,-71.479079,-57.146656,-16.329317,0.965148,67.147769,111.205876,70.118035,-38.194154,-216.721151,-124.856143,-29.217208,63.795718,49.294978,-22.390907,-65.637189,-114.497231,-69.819393,-36.780935,54.477547,94.251004,79.356129,49.819472,72.370497,116.870937,173.787099,177.650832,156.76918,37.715951,-27.028685,-41.370844,-2.102831,59.963389,29.71626,14.050718,72.984101,129.571114,233.711307,258.642994,185.67403,141.946258,163.31116,136.516598,98.49264,70.477183,76.804019,67.4764,26.934838,-68.276837,-83.370235,-70.997331,26.773246,108.243385,161.713121,110.74634,-13.592388,-62.386746,-125.693445,-57.714102,4.139081,51.449269,56.868667,110.915617,138.977882,164.866276,129.961865,90.126206,93.087428,147.801358,229.914296,225.597537,147.47288,94.462078,16.80263,-9.235922,-18.600159,-76.790243,-104.829346,-92.443132,-67.431853,-56.818776,-137.494807,-172.700523,-115.810925,-32.048094,138.908824,193.978202,192.446012,133.917681,17.151585,59.798469,114.909913,180.146668,189.270028,170.164625,125.493511,-0.800137,-52.664155,-44.948223,43.906857,115.333289,157.643873,116.706476,39.070874,-3.881527,-135.407649,-109.156629,-33.439747,4.262437,-23.201313,-16.060968,-12.180018,-131.1873,-267.968856,-244.897674,-71.962655,-17.749372,-34.712913,-75.784591,-184.142857,-220.757006,-192.16477,-83.842059,-36.217354,9.681749,29.57019,92.505496,99.841885,68.665227,42.747674,7.319487,-74.608184,-66.989743,92.066961,193.949806,260.87489,218.861891,92.899667,9.558797,15.976215,99.84094,126.681009,93.687286,76.516905,87.369063,-23.425233,-86.095575,-14.294367,62.697016,92.730827,67.520574,-0.894132,-58.934779,-176.586917,-151.431378,-94.490445,-21.915067,-22.433627,-40.860232,-49.587392,-56.371347,-44.282537,-29.76412,47.784728,91.232161,125.382957,114.838072,53.185645,18.67399,-35.861968,-79.28449,-80.150058,-22.053346,16.334241,11.98976,-40.243558,-103.323934,-41.037703,-12.289777,-18.152465,-57.576311,-137.736877,-137.350405,-116.13969,-119.940952:right
-6.475085,-88.5633,-100.954304,-70.29295,-46.587952,30.441517,70.06384,88.627217,78.557582,93.707776,122.121986,113.969371,72.026334,42.794557,-60.281204,-120.251352,-175.052847,-153.097293,-141.908034,-98.136938,-53.720397,16.351546,15.448669,-28.255803,-38.860613,-12.225919,56.53128,55.532061,6.151257,0.875967,15.971651,20.442051,6.250147,-18.487713,11.29603,88.9996,79.503242,-4.968667,-35.38854,-35.149001,-20.849017,-17.580274,17.744388,49.839589,105.33845,99.049928,-12.044316,-72.100977,-82.480323,-30.886523,-34.85583,-90.797427,-120.425897,-179.665424,-215.712693,-254.654891,-218.326271,-180.045409,-49.120329,11.185807,70.628403,87.591295,96.443263,90.708428,78.659747,120.455707,178.209411,298.894819,333.811766,315.8672,274.786415,191.794404,98.607081,47.233094,-6.407791,-9.496617,-46.37217,-89.879146,-162.803044,-162.215526,-77.532345,47.408011,83.711115,68.61389,41.528535,23.036045,41.651912,64.548387,-12.513113,-46.340478,6.721625,66.909907,131.674176,129.574479,94.256248,67.640123,25.3896,102.765861,174.829564,182.743301,112.863616,34.914501,55.423174,96.016029,28.757165,-8.139299,39.278533,113.801845,199.299345,172.731924,30.095608,-46.126233,-102.540272,13.373587,80.847537,98.430167,66.832744,33.088891,30.317554,-27.693081,-141.300621,-152.15487,-60.439567,-23.622941,-38.229735,-59.470522,-88.345422,-91.602694,-82.733882,-97.174383,-92.494777,-9.809819,33.449316,20.899652,-34.340785,-119.63854,-92.248877,-82.803515,-142.937515,-192.66554,-200.175848,-140.320094,-28.030805,-29.163015,-120.206738,-129.976224,-80.708698,24.733172,54.749506,68.560227,58.588528,23.730184,-30.888109,-52.180358,-0.778577,64.105062,143.800927,137.628729,137.703009,171.900214,182.312114,104.838782,96.281434,92.367531,64.89327,-34.063849,-91.677157,-151.305769,-139.868605,-113.21286,-59.089044,-80.301912,-160.435188,-164.560039,-150.967304,-162.632126,-205.50133,-195.577671,-140.825948,19.997469,75.196093,70.385892,49.080567,78.634336,84.756144,60.843712,84.590977,120.528766,117.423443,76.910666,6.386912,-23.098329,-183.732612,-372.419775,-377.815253,-280.420705,-246.388517,-233.397743,-227.55013,-203.822287,-277.797379,-329.860486,-299.867598,-237.325251,-150.666111,-149.046106,-232.055637,-278.441328,-317.731131,-343.374662,-344.398309,-266.70579,-186.589058,-39.225099,-24.728243,-112.95041,-175.651747,-137.707602,45.988116,107.333366,36.652614,-35.441045,-44.675099,2.230541,17.793092,-38.78081,-37.467529,-17.383333,-24.740983,-73.242167,-114.800984,-211.605727,-312.53363,-344.553776,-306.677907,-258.641189,-167.532199,-136.506858,-144.380966,-184.71945,-275.724924,-253.702012,-194.602876,-92.123926,-74.287718,-39.11847,-0.472975,17.592022,-121.916461,-180.943604,-162.619592,-106.741071,59.188798,132.154421,125.839155,66.777366,-41.337609,-38.888319,12.178395,128.426018,181.210501,266.9617,257.39397,99.890563,-46.527273,-54.520634,42.849036,106.143813,142.279182,111.045048,53.131891,64.757417,181.693708,321.879267,359.95375,381.453615,380.554443,329.444514,278.404931,195.616976,141.897735,127.25088,140.422862,149.063718,139.652466,132.165297,131.513531,127.7164,125.044043,191.174092,216.138056,191.245397,168.248743,172.749216,210.668854,285.217532,210.139503,148.422699,94.992133,101.610624,165.922081,210.473567,220.238904,160.424303,-28.325779,-136.697219,-127.597892,-37.717068,2.950455,-22.076325,-75.854536,-135.15355,-109.151179,-95.54336,-51.005323,-8.484211,94.69333,135.682605,124.934637,74.105658,-18.074824,50.980936,113.81317,119.553044,77.262963,-1.694381,-39.563652,-113.90402,-112.164139,-56.854859,129.150588,215.967899,272.554122,238.602243,126.045329,89.921523,93.336614,168.939618,228.923451,344.210148,378.210384,353.387974,290.745404,141.627061,28.324279,-15.340982,-47.979809,-24.846325,67.59867,86.215871,13.09094,-38.275698,-107.430731,-94.435312,-57.430547,-23.023379,-47.109935,-165.426999,-233.5786,-305.335162,-351.103517,-384.638,-390.798564,-338.833134,-144.969393,-46.76628,3.137163,-50.419092,-182.148374,-190.118665,-149.703702,-62.87633,-5.084579,114.125816,103.18526,-79.935679,-232.650737,-221.299846,-42.900095,61.274966,183.350804,183.143712,100.420718,79.966951,110.170635,178.73859,259.899463,422.903102,421.830612,245.032214,147.251573,96.475733,146.467068,130.565971,41.672451,12.1112,-8.147352,-23.241193,-77.918023,-95.923888:-120.567258,-158.864882,-134.472615,-63.30964,-43.684886,-20.153181,-14.368227,-26.559642,-63.84415,-67.439567,-25.583221,-0.193991,2.252936,-28.618811,-111.566722,-144.688091,-203.716433,-162.38522,-95.635424,-34.545106,-56.180667,-99.059555,-107.204578,-123.98303,-102.450699,-60.000852,29.728058,43.747718,27.291966,4.740621,-72.723282,-106.074396,-117.493423,-29.898588,33.717272,61.528939,11.88988,-129.34447,-192.186223,-223.505983,-141.365801,-100.487516,-42.012383,-8.784288,66.185579,65.361949,-65.356716,-145.648853,-194.245166,-79.238885,-19.92205,-20.134739,-61.084972,-142.187291,-194.064546,-306.015361,-295.665814,-238.452665,-97.84978,-38.122076,54.327398,83.285804,91.057379,77.259993,45.03769,86.965811,150.479482,293.73449,330.934586,266.843537,191.72686,90.245967,32.077492,-6.118065,-21.927576,-4.595803,-24.082819,-61.572343,-133.642043,-152.481746,-162.304194,-151.861229,-121.292834,-40.39327,-25.607928,-40.603137,-20.961957,61.876045,46.37214,28.561828,33.147354,35.156335,30.267864,30.075351,33.12361,26.9849,-24.493253,-2.581531,55.581861,156.355345,177.126885,129.036533,73.482664,22.489972,50.485894,79.98789,165.735715,216.025686,295.140204,285.295684,144.507969,56.424985,-85.199625,-91.160258,-40.481868,9.934063,-6.095012,-23.358767,-19.762599,-38.804351,-67.373577,-57.435455,8.529719,32.575841,14.296237,-16.807714,-50.408872,-40.313024,-23.21355,-19.834561,-14.020025,-21.258694,-28.835655,-20.580076,-16.67389,-76.44216,-207.996981,-244.688662,-243.49945,-227.635589,-170.442638,-137.607117,-110.705193,-117.579019,-150.25203,-111.622595,-35.797033,104.178222,126.702047,124.022469,113.703056,70.472919,17.030769,2.008247,13.855217,28.058272,58.159909,71.437721,60.5622,35.401975,14.87333,67.396037,84.773853,52.115615,31.683954,5.785917,-22.729267,-89.734356,-127.388186,-116.591488,-36.881386,-2.614801,41.509456,64.020618,62.653784,19.254604,-97.847818,-93.429755,-46.319226,31.055707,52.449772,68.848668,84.977157,144.89696,115.670666,101.799989,183.260885,231.425151,200.459789,139.2874,35.140041,1.528174,-64.104809,-121.833781,-129.338709,-99.426316,-74.858216,-77.434275,-114.898772,-212.822749,-286.124679,-280.589917,-177.744392,-142.826761,-185.808902,-211.909507,-204.401387,-208.774251,-265.262791,-275.904319,-252.391344,-167.487852,-104.726216,-19.785987,-31.269431,-121.737086,-137.839382,-76.62959,79.410709,107.763758,59.567164,25.667047,-3.544697,-7.177596,-31.535823,-32.635822,-14.525598,8.63537,-9.918644,-121.215087,-177.354704,-210.473075,-241.356678,-264.422776,-277.718159,-266.22688,-187.080949,-146.403339,-146.474689,-168.544593,-184.997759,-175.924491,-160.750193,-53.421144,17.993675,50.903861,27.607899,-4.69517,-107.55434,-147.040689,-76.272939,10.577773,156.563967,160.168923,43.394124,1.584577,0.820361,14.945507,48.486636,194.926071,261.491083,265.143742,205.297146,35.198523,-41.948551,-7.146962,88.081738,99.944396,106.100073,120.392315,95.606886,67.518863,133.471141,322.086521,384.587815,449.153709,485.46628,517.939656,482.437387,345.126613,211.485846,188.22383,231.210746,247.306676,205.670566,177.686566,212.131591,252.248766,217.4438,128.608573,133.315378,183.145363,195.246811,201.839108,216.414694,264.305826,213.594793,164.900415,155.469012,204.79062,265.679704,217.324387,65.874118,20.505152,-58.052016,-132.225655,-132.464886,-68.007899,-25.202431,23.452876,9.245299,-71.959036,-120.351498,-105.385033,22.579985,108.971359,204.894554,191.861038,110.761231,77.280548,40.873454,57.322831,82.936028,128.518248,131.876049,64.166471,2.704479,-109.263969,-91.574773,-24.288532,115.401936,171.41674,291.150847,338.681843,328.760884,261.063841,116.544514,178.325004,263.797468,334.774564,307.977931,241.713334,228.88593,213.12676,93.052989,6.241233,-103.609061,-110.323004,-47.412893,-5.73777,22.808361,1.587596,-85.81778,-101.460926,-56.846395,18.627731,13.432842,-96.650484,-180.792651,-288.422977,-299.679705,-286.859332,-225.162252,-185.966733,-113.184247,-88.144502,-108.047291,-151.384196,-189.110041,-100.53386,-74.118577,-75.714283,-35.821151,127.034031,156.210113,6.131335,-189.953063,-222.93513,-146.871737,-64.529387,62.120191,59.250131,-24.101983,-49.220034,-36.330967,88.212347,190.58108,328.537788,312.904944,171.424007,122.4563,103.241769,83.923009,93.955987,136.827919,137.232575,102.024705,76.706751,-9.319544,-66.937328:-138.062796,-165.278191,-157.254902,-99.990584,-56.466803,-20.797372,-45.321702,-117.930197,-167.077618,-176.16115,-139.387813,-98.550301,-63.331092,-98.524658,-178.629118,-193.210105,-242.58432,-222.760262,-150.103542,-36.090241,-35.39797,-71.582317,-78.586838,-114.126441,-175.863215,-164.121116,-40.180752,8.344457,-10.662638,-38.248616,-52.333129,-45.822865,-57.136804,-99.299156,-98.479677,-58.50581,-56.121906,-98.478663,-122.68249,-177.476082,-204.689617,-174.824675,-45.217618,25.52289,124.659338,127.620702,16.497797,-77.90067,-245.263726,-231.318077,-172.176393,-113.490762,-124.709827,-178.398587,-208.325114,-238.155772,-270.380517,-281.868428,-180.716193,-68.887784,114.039269,132.899537,62.450151,20.140259,-20.007386,37.352423,94.834394,182.177287,206.192745,259.832298,272.821813,194.604673,51.960979,20.853334,55.686776,75.886719,32.895144,-30.207677,-159.188455,-198.379127,-224.287384,-160.642946,-124.656492,-105.976544,-104.977831,-102.788373,-101.567271,-73.90732,-1.88293,29.906931,25.467471,11.815697,46.402659,64.356651,35.765559,17.906738,-0.43039,41.266598,87.708995,129.315756,118.019685,114.943679,132.845915,127.951967,49.580611,33.077065,84.83041,129.504003,198.496593,201.833723,126.086749,49.970361,-128.605995,-128.184101,-46.579518,76.270372,76.958289,17.872763,-14.363172,-59.601024,-92.127914,-90.377187,-6.417731,53.099902,84.461479,33.201933,-84.295681,-101.228341,-91.641215,-40.308623,-7.155058,2.45096,-5.974617,-7.773286,-22.252213,-112.915447,-188.069652,-183.808256,-166.056692,-172.784914,-166.692071,-155.239318,-175.491513,-202.003217,-185.424461,4.358265,103.632024,163.787574,135.857927,67.781322,56.714397,54.819541,33.538751,46.866621,135.931555,160.529619,131.005669,113.685315,94.108649,74.598316,63.352172,153.982687,176.7191,117.572295,104.263447,153.420259,136.973944,-12.153506,-73.429467,-49.038956,7.901419,36.670299,71.84513,37.136128,-100.204394,-136.253474,-102.839526,-41.137588,-13.100643,73.59854,109.97787,72.120351,32.072275,49.14872,101.772501,117.204763,180.157185,212.063579,223.744125,194.711543,52.738824,-40.016258,-143.889089,-57.575341,4.910694,51.052854,43.450561,-22.023381,-89.39034,-222.578922,-277.169498,-285.296535,-254.6322,-193.663985,-52.341215,-35.766691,-124.221368,-190.123332,-240.195916,-127.943028,-71.818983,-43.367337,-39.52692,9.499149,26.808045,-36.695184,-71.752008,-5.070316,140.778055,138.012607,60.970102,54.443797,66.128953,29.543314,-82.755965,-71.238757,-38.932859,-24.428026,-59.013323,-184.068679,-234.010099,-279.189642,-314.679602,-321.234965,-309.134967,-291.522033,-227.351875,-208.003532,-220.633102,-226.513326,-210.60112,-149.209359,-93.822299,27.075766,58.518405,17.388485,-35.355269,-131.424345,-145.645357,-110.593645,-3.113422,45.853536,93.177836,75.228519,-11.327249,-51.226454,-99.745339,-74.748824,-53.088955,-8.078693,44.463109,156.500549,150.160815,-35.550132,-243.951993,-263.248474,-114.89484,10.248501,190.566742,184.895185,63.072175,25.730191,35.874189,159.807513,252.2775,374.291188,374.875514,288.66801,246.481159,233.360137,209.261525,180.685831,176.967828,185.560746,179.422914,188.205574,215.542906,202.165962,141.490849,135.930245,158.042288,266.897558,335.725346,367.019799,325.552253,233.243002,184.380258,195.957809,280.205924,301.666311,236.398576,168.154824,52.372218,21.757028,-39.808195,-72.245831,-49.850458,56.212373,111.360791,101.062389,27.072229,-122.365656,-140.059182,-91.394431,50.712414,111.164081,166.956938,147.828029,70.020476,42.828087,26.210151,103.224077,157.333947,212.852417,200.790615,77.177401,-17.521301,-141.563854,-79.48515,6.831196,206.441675,280.317502,315.356175,292.141276,234.240115,195.349033,120.459599,187.770175,259.448465,312.88184,282.85901,212.821724,203.196934,207.937762,130.01497,63.549086,2.611778,29.336816,91.562228,76.0986,-24.776988,-57.105838,-32.876251,21.638178,38.696431,86.852423,107.235387,41.920512,-33.106279,-142.776719,-182.436718,-190.179168,-147.082976,-91.502201,-16.124083,-37.954032,-113.124691,-112.011375,-60.042216,-13.991336,0.351755,8.25239,19.576065,19.793021,-37.780042,-216.905509,-275.606357,-256.607842,-189.516287,-147.132772,-70.90977,-59.142888,-75.489394,-79.596322,-85.913053,-18.891459,57.597579,151.87057,155.959096,139.336653,118.233097,52.470587,39.582186,97.303456,232.272999,237.458293,134.056831,53.550818,-91.98805,-124.377998:-171.799784,-164.773896,-127.948536,-59.64952,-27.487391,28.763983,16.902192,-58.94302,-77.978923,-48.560456,16.935428,9.32796,-67.073812,-98.321798,-137.152264,-171.05873,-280.261116,-277.803855,-211.921133,-97.470605,-72.845189,-51.299441,-63.182219,-123.318225,-138.387153,-113.575902,-44.689615,-43.923132,-89.594385,-91.537405,-37.210361,0.261743,19.929376,-0.463357,26.582215,84.481437,79.886117,33.366071,0.044749,-91.137309,-129.573168,-84.724439,40.256864,57.083476,47.367431,49.148595,-33.308627,-120.7249,-207.925886,-112.178479,-75.201626,-123.476397,-167.016889,-212.547618,-234.743198,-311.726367,-338.812193,-288.336613,-112.177271,-46.538099,13.332499,20.241029,-3.543323,-6.551902,33.542655,86.706457,122.054513,252.632171,324.148083,333.820847,284.637366,216.285167,133.794566,84.572277,59.122277,76.482019,53.319465,-6.251598,-99.595094,-94.577275,-67.797694,-78.236441,-78.729018,-94.076226,-117.388305,-134.875856,-100.374381,3.239816,47.442886,40.865122,-2.605938,-19.113673,-21.198889,-28.721764,-68.758114,-83.238132,-72.125086,43.902156,112.429781,147.97436,130.465049,115.191333,133.649763,196.371329,169.491897,116.635546,47.321713,66.621048,139.585911,136.996037,31.092481,-35.180663,-69.348709,36.517849,57.240484,-28.846647,-65.090861,-40.970812,-34.436065,-110.514215,-170.954247,-150.000239,-36.827884,15.169912,11.788952,-47.292257,-161.298111,-168.162725,-116.507541,-86.704141,-69.895572,6.787149,40.800664,22.084958,-10.748093,-52.84604,-128.701849,-170.526582,-205.246502,-206.457529,-166.358227,-134.027849,-124.874639,-150.668019,-210.064159,-155.024264,-87.151622,13.778227,56.591085,159.482535,179.963349,102.441087,14.107013,23.90245,113.506477,146.016976,147.871324,138.324849,142.463146,157.44511,171.969053,157.035004,157.229318,159.147435,154.287096,125.813693,89.302385,0.732971,-26.200525,-1.935676,42.672457,21.887095,-36.817568,-33.72387,-43.718003,-92.6813,-189.226486,-132.422093,-51.655563,120.174731,171.875355,156.172475,122.482437,116.450418,147.657514,149.622785,186.347768,228.087238,260.156949,222.508085,97.765598,46.689495,-51.396625,-145.765851,-154.622617,-125.918188,-115.082718,-110.526965,-123.422496,-199.835225,-287.467671,-291.179847,-201.568383,-153.306011,-131.105894,-142.268121,-139.738912,-136.345262,-210.844333,-292.528946,-269.725419,-112.067853,-22.101604,40.260597,-8.299291,-145.607098,-158.383603,-111.682435,-12.139182,6.597135,-1.643294,-1.079163,23.378855,16.954476,-58.955549,-90.500048,-68.74183,-45.577851,-72.467749,-152.325295,-178.111341,-225.899453,-336.782383,-371.697013,-330.076552,-303.564789,-307.478549,-308.257858,-258.15063,-224.945444,-212.975928,-187.427705,-136.890798,-28.622927,-9.562033,-73.366227,-112.488171,-101.950766,-95.121856,-104.28717,-5.479896,75.866906,125.771604,88.750204,-26.045156,-83.326706,-161.303491,-110.869996,-46.377915,59.164785,80.725615,74.205082,46.750313,-76.231683,-207.282768,-213.883188,-106.689459,-41.469624,30.67072,44.418053,84.386592,111.515866,128.429435,143.542567,181.330338,277.839157,306.422371,249.224418,173.977199,101.522572,128.896087,110.506216,71.633198,85.842815,146.211389,160.865193,122.232377,94.525847,63.622139,35.318961,25.151385,47.19252,76.130024,132.58092,167.749331,222.860702,119.849138,49.919961,31.820138,64.766718,118.82046,134.831734,110.231272,48.916022,-135.024231,-170.652685,-102.377825,42.308341,76.034854,45.818832,2.188864,-55.956545,-95.253838,-87.661503,63.812985,167.817868,270.57251,245.171215,135.237351,95.157512,33.941928,81.371637,155.803519,203.537133,154.370473,54.564475,32.02599,28.342943,54.298325,62.375268,77.351546,103.297202,191.005116,242.033272,330.38109,335.120051,233.680069,177.797025,207.080128,250.201742,232.530226,164.652254,140.089157,112.931373,40.86229,-1.307496,-13.443351,30.179616,143.506358,150.643447,43.600808,-28.987057,-150.737839,-111.125699,-25.49142,90.500087,84.581731,-20.167514,-93.691284,-215.112617,-278.681383,-284.964862,-238.54928,-187.480806,-71.574591,-45.922418,-93.88432,-124.898358,-106.833303,-61.993725,-63.959094,-31.360227,28.377992,96.973,46.702874,-152.527339,-292.585102,-304.014833,-184.78535,-90.855886,24.594264,17.157173,-64.128251,-88.171618,-85.257048,-11.179303,55.879442,168.984105,191.904044,176.659281,150.587308,93.870404,88.858384,111.746401,157.675443,158.327866,114.128243,73.912203,-54.2505,-113.682781:-283.91236,-275.773087,-248.359787,-191.5687,-155.729461,-97.339351,-109.347485,-189.934258,-232.802508,-214.596749,-119.088209,-79.551143,-63.817487,-68.543202,-107.521206,-176.356168,-335.603284,-250.485579,-133.526727,12.405696,3.001426,-92.546081,-129.541252,-144.098772,-128.414241,-106.54792,-23.311388,11.467702,34.591019,37.556938,54.922187,61.80338,21.009114,-12.450438,10.889076,56.792338,55.117284,25.215177,-5.564942,-98.427001,-117.919258,-87.065985,-48.08433,-49.385999,-18.833452,-6.451644,-83.759832,-146.319782,-215.659266,-170.732733,-116.925462,-56.935486,-81.173982,-186.090373,-241.504186,-379.665031,-448.35894,-381.414482,-161.367101,-101.425615,-65.224535,-47.645294,-42.524638,-76.484053,-182.292969,-103.005532,16.258504,235.264528,308.237026,358.642648,327.577163,194.719129,54.713235,34.089523,102.33173,126.507707,57.540217,-23.347415,-167.92513,-194.934101,-220.745881,-244.836239,-227.995197,-137.35405,-87.10492,-58.958269,-80.068398,-95.147403,-35.347451,-19.682342,-72.545458,-93.540023,-29.535011,14.996889,3.978571,-48.063275,-141.125775,-31.825338,87.710189,233.899316,227.669514,168.988553,158.636176,142.288461,74.043895,53.432385,107.110881,167.394573,283.300546,296.535592,198.975149,128.364014,14.350405,-25.033408,-22.543283,-6.213781,12.861879,23.696435,-17.644558,-147.755614,-168.36997,-127.092211,-24.906629,18.756658,52.941471,23.140227,-86.984058,-136.6188,-184.513738,-117.123639,-66.780782,-13.220255,0.512913,20.310193,11.974713,-67.751613,-144.084113,-147.441298,-140.217211,-142.967103,-134.266969,-136.958588,-164.478914,-166.570056,-144.034956,-88.423225,-52.976801,24.281155,79.261441,180.230838,179.882938,43.598779,-54.598635,-12.566746,133.995131,168.761166,185.854405,197.894034,222.968215,215.449335,130.156014,121.880421,177.301252,269.693062,275.93445,215.662404,156.960902,27.646348,-44.652111,-45.722611,-18.866661,-1.607467,44.304643,49.055712,-37.138057,-103.434295,-175.202454,-114.617652,-48.744584,91.847086,140.029135,151.371104,132.534497,93.377693,75.826115,93.018407,188.352862,247.831948,304.22931,271.545748,140.527176,84.973291,-28.378335,-129.322835,-138.56806,-76.648282,-15.008999,66.190003,29.770458,-170.882268,-302.100486,-290.474022,-198.646952,-138.270212,-37.078215,-47.882533,-187.182217,-247.127936,-257.246913,-168.763635,-116.847866,-19.774288,20.448941,22.271762,-21.340009,-111.914953,-111.458245,-72.897933,4.701591,38.918669,129.388227,157.993018,142.974836,101.911935,-35.942987,-100.843875,-81.645157,-26.823117,-33.996656,-148.729206,-205.036984,-251.917562,-322.172967,-354.810528,-320.778619,-250.802743,-109.18843,-96.933852,-207.453965,-268.359345,-259.877575,-136.164393,-92.268412,-30.076998,11.518552,67.161258,58.285394,-31.985625,-84.472704,-22.45759,165.631995,199.434438,143.281461,95.059481,34.535842,26.878476,-45.293103,-143.163665,-138.867233,-43.119419,28.183181,128.778289,114.371127,-44.175459,-186.22843,-168.621657,-32.505781,21.393476,97.247978,120.781845,87.309813,38.372425,-25.111304,101.0589,218.277392,399.11107,416.805716,257.095525,134.505776,42.933979,104.653229,122.944719,128.445639,129.805037,151.974498,158.190857,120.256281,91.943794,72.96088,130.602071,164.705724,226.330806,276.857856,361.491406,347.381835,198.550682,66.64038,63.831264,114.030368,143.519461,212.862328,220.211634,144.891479,93.840719,3.770353,-26.382303,8.79175,143.982937,204.776332,216.078466,152.848444,-0.317894,-9.44822,38.911152,178.647224,244.701106,285.162812,248.899911,135.801173,85.782508,19.346472,75.817551,146.221354,204.65502,169.356959,46.848613,-3.90549,-52.211635,-77.061517,-63.359927,45.902167,105.660425,158.494733,175.089765,246.998683,260.996975,188.586801,174.751823,202.636147,211.882989,202.489525,185.539118,160.723198,67.885741,-29.43089,-68.31465,-110.202231,-71.554165,110.813027,159.825528,43.150434,-70.564152,-228.781379,-192.86832,-128.82183,-22.056631,-2.841623,-41.786582,-85.544382,-208.717014,-336.283291,-348.583895,-242.589083,-161.29279,-61.047623,-75.876314,-162.570867,-186.658872,-178.189264,-114.585696,-91.049185,-84.539256,-82.682848,-115.206624,-170.39792,-306.368515,-368.213641,-356.135743,-292.45665,-245.262697,-139.45861,-122.94947,-188.580327,-231.689474,-262.745396,-151.518972,-59.151893,98.500342,141.24099,113.950112,74.666919,70.520363,92.684956,86.416479,113.823842,162.602421,217.018542,174.594184,39.397842,1.893102:14.834658,31.875398,45.282422,43.427559,56.087148,113.153002,110.066842,38.932067,3.524606,24.637526,135.775631,171.119304,75.327311,-19.014074,-129.777785,-138.20781,-129.878708,-96.392481,-74.647688,-81.442106,-84.819392,-37.37199,-27.893741,-73.420381,-120.535246,-126.523611,-99.321366,-89.308169,-90.10038,-82.878849,-23.051202,27.84959,52.9431,-38.382152,-36.313365,93.545334,143.133556,71.877835,-0.460458,-38.92768,16.488197,47.56326,82.460398,69.501024,55.168121,66.650501,21.283148,-33.057829,-74.39182,-32.544066,-19.901413,-13.130934,-23.824821,-96.064479,-130.585992,-169.668967,-212.318063,-208.210123,-124.389418,-81.044899,-47.919208,-65.357107,-96.328418,-59.519685,29.770459,50.23789,107.01535,309.493314,373.615248,332.63977,278.014837,221.837785,144.496451,89.560036,29.227888,7.568569,-102.396389,-166.727457,-182.422256,-140.664002,-64.688638,33.477106,80.240102,34.637953,-36.674753,-105.962145,-77.536989,24.539828,40.457135,33.79686,73.114343,82.758293,9.453941,-29.489157,-30.802806,-20.39502,-18.059894,86.822545,182.756915,254.276549,220.014122,201.491443,226.117961,208.85173,92.105983,41.785028,45.571675,95.454514,138.026213,94.721125,-38.91365,-80.34178,-52.526856,76.230925,109.802747,28.722551,-28.355982,-61.641471,-71.516483,-117.162327,-117.855083,-85.694043,34.831756,101.091068,146.652511,109.189398,-12.288211,-44.394848,-14.35097,28.549882,28.579913,-2.662064,-11.337338,34.453663,72.399709,84.580299,-13.786507,-65.738433,-117.025461,-131.290419,-137.483605,-116.888636,-65.239875,-48.241649,-74.190404,-136.081395,-124.971234,-35.180761,14.406487,38.525906,12.656309,41.40883,134.873734,136.400667,132.960181,150.78463,170.872009,178.229069,220.557365,239.330731,191.13841,118.319566,113.824269,79.961516,48.889698,22.570264,4.758613,-105.408353,-182.225592,-152.334594,-36.294551,-5.248524,-21.583986,-56.874255,-142.327108,-160.856021,-123.860409,-51.701037,-11.920857,68.8807,92.029619,79.759393,68.483269,77.045701,65.016208,70.326099,181.895535,259.325137,317.212324,276.030737,126.661455,54.758158,-78.102047,-181.237531,-204.853194,-175.039809,-124.749936,-30.075097,-20.54808,-131.539813,-340.92648,-372.034206,-200.500256,-86.903059,-3.913445,-40.740137,-173.678149,-222.395704,-262.754407,-262.121941,-249.156208,-203.092917,-169.147994,-108.490252,-118.024945,-214.61688,-201.127355,-125.780882,-12.352933,-24.242586,-80.597018,-72.830426,-25.955018,-33.279461,-123.07164,-118.362358,-53.963847,67.080416,88.905285,52.832415,0.219877,-160.299361,-284.766817,-278.003555,-208.583936,-210.803943,-283.221145,-297.369559,-199.9961,-129.807786,-162.11556,-299.422224,-265.813644,-57.059361,11.747687,-32.311359,-106.422351,-213.639526,-207.316363,-170.323594,-93.295887,-73.042791,-51.209952,-42.599124,-5.5287,12.006305,-54.632323,-116.491947,-61.264787,103.894884,149.131576,133.887727,93.006252,31.667854,-21.897283,-56.486791,-52.665062,-8.270957,85.843936,102.890975,72.918399,65.819149,123.882052,233.922828,297.944253,390.322141,364.781974,146.200452,44.98003,36.829508,127.658219,161.299973,214.946959,224.66731,216.891754,204.947881,127.101764,69.99432,34.051407,104.12794,116.357251,89.848116,96.06383,147.171828,146.143226,73.241489,22.456125,6.730978,-46.212862,-50.500193,52.42093,138.573625,220.571361,164.462436,-51.427033,-164.570737,-166.196992,-124.499712,-84.902841,-27.983128,-41.908588,-92.109519,-75.730802,-56.342625,-31.382832,-11.900382,84.603169,138.94242,128.191383,54.303527,-92.125941,-56.58477,13.438867,69.115956,47.70571,41.514409,59.947245,38.062821,-14.132771,-2.111697,39.38478,35.384134,44.22734,79.287958,128.497478,123.233848,97.842156,117.62769,154.785839,221.481311,229.059521,201.786678,169.216741,77.242484,-59.637174,-115.156534,-58.106538,44.097085,205.282131,208.500789,97.405163,19.552442,-154.292942,-211.226849,-152.519286,-29.679065,-36.205341,-141.778906,-197.146466,-281.401022,-338.650821,-364.280563,-386.069645,-354.063126,-173.958856,-80.576324,-71.127538,-129.719609,-196.754913,-194.007413,-173.637365,-34.520087,67.309909,130.623738,37.445092,-237.857081,-330.782566,-285.783175,-105.74651,-14.999637,78.094658,56.064457,-59.366243,-92.204407,-69.789875,46.744058,126.139276,224.939205,213.114153,103.894996,59.628968,53.745279,54.663961,39.394136,28.162713,22.851162,6.086069,3.545389,-73.774959,-150.839296:-147.747115,-97.102151,-64.249616,-35.856038,-48.803667,-72.973719,-76.927871,-115.130336,-175.3756,-167.370011,-61.992514,-12.48024,31.109142,40.481535,4.817037,-69.727022,-261.837379,-207.908966,-89.746424,55.968456,51.141641,-12.965463,-38.97514,-64.965648,-105.484993,-109.007243,-53.890367,-26.937658,15.617843,38.742304,67.803358,65.294981,12.381087,3.142875,50.509079,162.678555,188.479999,136.743157,62.236752,-86.712695,-99.304528,-58.911086,17.111771,36.32951,69.191969,70.261914,-10.564305,-71.479771,-128.957601,-62.26929,-44.20208,-113.934657,-137.555577,-117.151704,-142.782407,-309.754459,-397.443397,-347.650757,-176.358736,-113.75746,-60.602297,-70.922095,-128.244781,-134.843833,-80.652802,27.880369,101.44601,254.39361,315.565501,347.309293,300.001128,117.620661,-19.113414,-7.239943,89.387652,108.866567,44.171462,-28.752933,-149.328375,-163.998526,-165.178704,-155.1842,-134.5799,-102.77638,-94.473071,-100.902614,-133.300933,-186.578905,-102.196704,-41.403656,1.658664,-6.270418,-16.95416,-31.428048,-50.736011,-21.350784,75.068778,129.857556,139.179416,167.464864,210.549281,327.375051,356.584241,299.853343,191.713678,176.143017,224.017266,244.908312,242.180921,223.388098,103.969549,14.796847,-70.550736,23.282406,68.307218,58.414385,39.849313,31.073966,17.252524,-52.635091,-110.96291,-101.720344,-5.201635,52.123726,76.337023,25.853162,-80.014878,-88.565665,-42.950011,-7.542742,5.42062,37.15589,36.653993,4.648282,8.32388,49.280784,4.652274,-32.441879,-79.720769,-94.004186,-85.193743,-71.64973,-89.887375,-127.919423,-192.066061,-103.50113,-26.520706,76.753076,118.910165,172.130536,141.615616,15.221332,-26.779099,1.614208,148.484996,226.538104,243.456845,188.802072,111.568484,120.045178,136.398454,122.846723,139.310512,187.488193,204.764614,205.27166,168.040229,43.126274,-7.27847,12.725381,64.365422,78.948179,106.80829,119.671001,93.539348,33.947817,-138.007051,-153.872188,-71.418483,101.879888,144.508585,156.913775,141.061418,80.478837,32.389221,64.658919,251.366602,338.042608,367.235999,312.218379,155.402266,73.763839,-119.748288,-223.080745,-196.565682,-63.133248,4.747134,50.811362,13.327486,-113.515128,-217.513993,-245.595306,-219.440901,-164.39058,-71.903778,-78.894794,-168.865667,-214.636917,-285.646732,-263.505544,-205.323417,-91.579564,-50.14283,-10.717293,-38.270422,-189.017943,-245.401371,-179.308366,15.83679,76.155735,63.774186,14.904836,-35.730106,-25.293755,-39.654565,-83.791401,-67.507916,-1.578512,-6.710228,-108.033899,-153.130096,-189.536127,-270.841359,-309.294532,-274.72128,-225.36523,-158.92417,-151.089301,-167.443622,-193.519037,-253.945546,-128.626359,-0.392205,138.727365,108.297803,-26.535673,-63.945779,-96.254788,-150.988881,-130.095287,38.960691,122.025806,208.727468,219.696217,133.900231,26.058047,-191.993954,-188.173451,-113.130839,45.801275,113.558625,154.273994,92.00476,-111.411812,-221.004872,-196.666349,-15.410381,84.764383,184.104496,184.552102,157.195148,134.982193,82.181538,154.948147,232.284096,330.811854,338.751981,274.764661,212.755323,125.450932,102.303447,103.920445,163.538174,208.229621,272.931484,271.775595,143.093336,54.085008,-16.864649,66.022189,115.539803,147.3818,152.998327,215.264756,250.429063,215.276832,53.060971,0.757192,46.094385,105.752939,177.43898,178.277474,137.950685,101.775577,-6.576658,-65.737711,-42.571138,55.454749,97.410852,100.162856,60.620558,-2.674864,11.23635,44.724041,138.382619,173.518625,218.458367,231.133075,179.906501,110.502236,-27.919658,-15.191569,60.747994,197.959498,203.396794,129.592353,90.261506,9.586089,-97.066298,-102.331653,48.802383,139.464318,200.560932,182.142844,154.33084,155.359851,109.502629,52.526153,80.57996,199.197332,218.728027,102.240218,22.306691,-33.141852,-60.022335,-88.506716,-80.365865,-31.607114,93.868941,118.515282,45.712359,-19.447848,-138.805033,-170.877587,-132.743398,-45.411404,-56.672855,-168.077368,-215.50665,-294.244911,-414.636579,-444.566426,-397.159031,-341.469156,-197.21976,-136.49384,-144.655537,-214.87482,-335.519606,-280.099383,-209.785331,-64.02653,-7.276636,-49.113062,-173.419677,-423.337778,-439.548386,-378.678031,-218.792857,-144.8136,-64.863904,-73.513759,-145.761975,-182.815628,-208.346178,-95.194788,-6.134502,134.527784,169.568116,160.657411,116.331046,8.873426,-4.282499,29.581742,97.846213,108.385749,120.917449,131.332028,62.054216,-36.972862:197.591251,190.649286,237.492631,327.62044,346.666632,365.300305,359.78612,309.559449,233.198224,199.515083,223.500158,266.759298,261.108171,202.023097,79.352651,44.038306,11.046825,-4.863819,3.309683,21.425567,4.563986,-34.466125,-21.452037,31.373143,17.679989,7.443987,25.443028,26.864509,10.765676,34.494742,159.158953,193.110768,93.222573,6.557836,45.375798,158.822498,181.47917,147.680056,108.694885,67.027368,98.704642,117.066433,140.793925,154.45807,216.324572,244.522061,190.132075,127.518583,58.844008,76.014476,100.954808,94.218872,34.436592,-104.34146,-133.332154,-114.316768,-44.716521,1.155053,64.504025,77.697042,82.6595,57.012882,-15.589046,-3.597635,95.901703,149.80714,177.427577,260.373524,295.605388,307.01652,280.698161,208.798758,128.546781,84.724589,19.708897,-18.089416,-138.21877,-180.29426,-171.150093,-135.234554,-23.512689,71.178741,85.778247,86.111426,111.963034,189.776571,195.487462,155.939912,166.89511,211.405119,333.776873,361.161359,286.556532,228.815199,177.218837,184.716119,218.720048,203.18404,207.589002,315.648824,356.878285,249.421402,153.778604,93.857568,129.872772,133.369598,121.287984,106.712791,77.990033,62.197196,-1.741233,-31.469324,-33.300367,7.449278,16.913761,-31.929357,-62.196169,-43.440719,-5.109644,34.221056,-9.596065,-33.392622,1.591913,65.870598,187.101053,201.758195,143.21653,105.633418,75.825982,144.430066,199.284462,234.850504,213.878338,198.313543,203.285706,185.370238,195.86285,210.846327,151.742146,76.292225,-20.558349,-8.546348,75.568319,105.260936,66.873183,-71.754146,-135.73337,-158.005531,-92.055183,103.899393,162.716287,170.401304,150.770201,154.909233,176.307397,184.675309,178.030432,152.41726,93.970961,101.940227,134.368125,7.234086,-93.804194,-242.844451,-262.427344,-209.336209,-188.308941,-237.394217,-302.93286,-292.216784,-203.522863,-173.523686,-189.239156,-220.765739,-273.18004,-275.766689,-273.174279,-221.98144,-146.517812,-10.738774,15.689297,34.116395,45.227649,47.116125,-6.685815,-26.640636,7.17803,51.773891,116.563824,103.225331,22.442008,12.607326,12.931654,-75.825699,-105.522819,-76.109928,-33.174368,4.669098,-36.047383,-193.602213,-337.169054,-349.651161,-221.238417,-144.94266,-107.595993,-141.898082,-269.916198,-330.573635,-349.253724,-271.308678,-257.027234,-325.240159,-356.48896,-303.142002,-267.672951,-311.827496,-326.177257,-268.935655,-204.121196,-241.787866,-306.356863,-272.95912,-129.492322,-82.779448,-99.230449,-96.45634,-48.699356,23.871522,22.271079,42.940186,76.434875,50.634554,-111.705682,-179.868595,-228.327098,-217.301563,-154.332969,-117.27016,-66.823131,-56.854365,-94.14495,-160.1361,-136.867347,-23.36896,-6.730965,-53.717033,-70.903158,-114.734224,-224.214058,-257.558395,-254.556055,-250.669496,-218.546635,-179.161634,-127.28922,-124.50342,-140.203951,-124.582512,-72.609446,53.101823,78.638023,26.446341,-6.68621,0.025827,-42.233878,-84.434517,-58.716127,-2.312834,62.139246,62.417198,35.287527,20.121308,55.427303,177.736761,209.515245,185.877687,180.179371,168.519312,127.732376,67.995356,97.466852,101.205287,136.250297,201.486248,305.48667,288.286634,195.242495,177.859131,215.296984,270.892853,277.871894,219.120333,179.398198,143.666656,119.576879,21.987385,-21.528377,-16.298455,-10.377512,-2.756402,54.887085,89.206883,100.095235,80.960606,31.978377,-44.777003,-65.207122,-12.932345,32.438464,67.002239,53.452956,21.273248,-39.379567,-94.501405,-196.240162,-213.80114,-162.684954,-115.648506,-78.03658,-94.397306,-128.804498,-90.912614,-47.419872,0.432029,-13.238146,-49.158926,-27.331581,79.628299,72.678575,34.519498,0.028062,-22.529866,-83.176089,-85.886139,-100.568547,-154.237831,-255.76697,-189.347137,-126.815851,-37.518077,-3.343011,38.159692,9.700193,-141.271653,-256.065609,-246.732039,-122.295134,-59.459755,23.292873,36.939322,-46.994509,-132.49142,-295.363264,-311.156781,-248.722297,-169.554162,-205.955015,-315.243255,-335.081223,-316.406906,-347.98624,-372.741227,-339.581589,-296.063592,-199.832095,-137.85388,-62.334722,-82.841947,-176.913503,-195.596367,-144.067828,-7.914265,26.505719,10.712885,-24.506838,-88.701244,-114.116746,-110.979846,-7.099779,85.098622,211.309114,206.135891,101.691756,60.211084,60.805561,100.601547,116.956599,131.575347,131.265009,91.962357,48.067225,-40.958343,-112.623374,-125.239507,-124.150315,-148.378555,-172.644222,-127.38207,-49.206565,-57.083059:154.832189,116.996558,107.550607,134.782184,182.483898,301.421091,318.836487,295.842578,317.537001,338.670134,405.630728,423.121068,324.669696,234.827519,101.528802,65.081232,-10.876959,-62.014551,-42.795592,-1.556772,-16.604864,-42.087771,-29.711035,-7.48036,-4.580909,3.71993,25.220183,24.916602,34.649673,58.48586,105.224952,109.878223,54.267747,-7.054574,6.768605,40.038372,26.707999,-10.720658,-14.839899,44.429718,161.59283,191.07666,157.341727,112.583087,78.204391,91.969157,73.840191,61.852018,66.6349,2.569693,-26.278052,-30.686893,-49.743969,-128.079552,-127.082178,-51.461613,-93.342624,-118.663051,-4.126032,63.820445,40.533093,-1.902678,-7.640439,25.4231,72.565908,95.856851,147.828383,300.477454,338.377921,286.417826,252.799948,255.259343,199.42828,143.526189,44.971404,-4.801638,-91.468723,-114.456983,-117.809433,-100.874083,-21.471295,106.970576,146.682934,106.78581,66.483768,87.847897,142.145958,195.699084,98.531375,41.080495,16.385921,36.870519,90.556113,118.43301,127.786736,100.583587,59.516707,136.20792,198.428052,249.717258,221.864253,115.480375,73.628179,51.788213,40.643332,11.557276,-34.930058,-20.1988,38.024479,33.081999,-39.322653,-67.165759,-96.154635,-43.897059,16.722245,65.984394,46.540466,-19.637721,-57.408752,-101.19415,-69.403464,-28.580682,52.123177,62.968289,46.079682,48.840808,33.963525,-3.682344,-58.674943,27.109295,89.662439,111.837593,89.543006,61.917202,51.533457,41.885812,19.740272,-9.520089,-71.313409,-87.004347,-71.10113,-55.753703,-42.203916,-43.085023,-53.867721,-27.424787,-14.614709,-67.304645,-105.11995,-116.449838,-91.288417,7.553472,73.437359,65.60338,59.634707,90.089168,169.532334,191.007741,180.748125,154.560789,47.989053,-71.868433,-104.390617,-165.99037,-212.193809,-286.535828,-306.354423,-310.040806,-279.886041,-253.069271,-161.952713,-142.448338,-232.396072,-298.557874,-331.150211,-295.376712,-247.22888,-240.257369,-190.330822,-30.826601,17.548486,14.613993,0.748689,20.748431,31.084465,22.417138,23.284856,34.963829,59.607113,35.264769,-93.325865,-130.019534,-151.403014,-252.011354,-283.254854,-234.652653,-190.568156,-127.68163,-119.983901,-166.06751,-271.777199,-332.594736,-366.92559,-317.244409,-202.927474,-186.006066,-186.817591,-186.315473,-245.004874,-298.994032,-269.681658,-176.816911,-152.823824,-167.618269,-203.042031,-290.844382,-291.380799,-235.762324,-102.901197,-85.317951,-127.077317,-137.651954,-131.306143,-135.395528,-131.565526,-44.638524,-12.394663,-65.846651,-106.759237,-92.262511,-51.368897,-28.315944,-136.324234,-178.934035,-148.546974,-121.629704,-143.917939,-158.137751,-133.162384,-130.894311,-202.201424,-213.298097,-164.013853,-89.324956,-93.024517,-156.917282,-207.933899,-278.141258,-262.694897,-249.988917,-221.57046,-197.187972,-117.925553,-82.855162,-65.822553,-66.527837,-64.596702,-58.617904,-26.282468,110.945753,194.375375,265.288853,214.266695,53.738799,-43.326334,-72.738249,-80.688602,-55.816483,31.10233,62.501557,44.040352,38.435823,151.735722,312.928342,344.29165,325.497658,319.279726,297.467494,250.471807,144.892029,102.396508,99.373029,132.617264,153.156802,171.872779,169.9569,125.224148,111.975842,195.666943,288.59458,273.169601,159.018953,126.587414,195.650969,247.776997,246.446108,132.56604,90.276835,75.811,88.052551,176.30688,239.331158,255.243572,201.740249,59.534947,-52.085378,-58.856843,14.890002,65.219997,86.078134,28.205545,-110.787553,-118.270682,-103.234726,-149.871808,-188.978107,-133.866945,-41.149048,72.474975,50.850528,-82.02919,-106.671456,-43.021621,56.142872,47.10491,-10.189114,-14.776387,-3.935819,-50.159354,-55.499115,27.572009,79.670046,97.23935,54.335059,-50.303301,-62.741905,-9.029442,59.830889,109.798237,204.963717,221.920418,190.658056,157.022119,79.361668,-42.540994,-72.934958,17.236071,88.502046,163.673664,164.068645,119.809178,79.906729,-39.298495,-92.90003,-48.850903,33.768808,-11.058905,-236.367893,-336.477711,-404.86426,-365.181079,-334.1515,-250.581688,-198.290991,-84.437001,-14.911119,71.348449,16.038602,-214.782524,-226.191197,-148.770769,-8.110724,74.057861,241.064751,235.883289,18.213905,-186.081889,-198.670975,-32.245959,99.338768,290.61321,285.622153,104.131467,23.662831,-6.805445,90.38606,167.224359,237.605603,194.324316,48.799409,11.923395,23.726763,15.617831,-20.585266,-124.105591,-169.188922,-174.491051,-134.769619,-85.037627,-100.891106:92.90893,120.103077,103.221211,61.772314,52.899003,62.411595,70.026353,63.758827,0.362977,-25.835461,24.866262,78.647492,94.428202,48.370386,-37.749064,-51.985046,-47.13902,-7.210878,36.713455,101.03967,83.895712,22.019555,10.453393,-12.019992,-62.451493,-70.20329,-57.516461,-49.431448,57.964321,159.35472,278.102068,263.396408,156.500054,34.543187,13.740251,101.221884,170.27053,212.167019,182.697029,105.885452,16.812291,2.242102,72.754709,111.057138,150.771505,153.027304,98.4682,52.418721,-32.758697,-77.408173,-71.625473,-57.931139,-80.865439,-155.314794,-170.089933,-164.009493,-208.648131,-215.615169,-113.711423,-40.924053,21.134415,-7.086432,-98.424476,-95.847106,13.280855,70.816945,101.267506,256.284861,331.819738,337.975734,269.317403,118.855765,64.285113,65.984265,63.698343,31.40862,-54.720788,-73.979767,-104.679034,-131.593289,-126.994966,-54.871825,-62.150005,-180.211735,-204.251347,-70.917039,6.127683,19.91117,15.016198,61.742818,145.543389,115.556502,-45.081194,-91.175136,-35.187337,39.42873,159.116215,144.653094,129.194262,188.16408,237.827409,282.087907,275.901778,238.828169,178.747625,157.754349,171.891368,175.978888,94.852364,46.469766,64.284949,107.854596,96.234301,18.498342,24.822222,52.642452,46.583155,22.16636,0.425505,-68.518479,-90.68668,-51.796009,53.90542,91.117455,129.018293,129.355837,118.513145,115.736226,95.310866,92.838107,97.512473,87.910679,90.204649,110.882227,116.927009,97.682674,9.798369,-21.653494,20.356713,60.06482,114.997988,126.411563,81.522583,36.314709,-55.762588,-77.105456,-46.519082,7.464453,5.826535,13.079513,55.62082,164.062644,155.082741,135.429759,190.205851,230.665784,208.502553,158.283017,99.108385,103.775692,112.249391,81.338382,66.074612,42.25299,37.249313,40.670847,32.774232,-44.102835,-156.863004,-161.720476,-21.285366,48.245387,-8.649938,-118.572238,-228.25324,-178.575283,-77.27258,-39.967258,9.713216,100.313634,99.385914,59.563029,62.161307,76.153598,-0.330251,-2.659233,165.93545,242.798089,233.704212,189.942482,95.873427,39.144503,-86.153428,-93.235725,-35.934426,74.421627,106.69683,104.906257,45.544415,-108.854158,-156.910977,-150.926366,-139.515177,-146.809733,-171.715701,-186.904898,-254.369189,-308.810729,-381.747964,-328.704663,-285.839748,-232.693157,-213.557137,-178.204157,-183.507965,-242.03089,-265.811014,-239.930003,-134.594022,-85.702533,-61.089384,-85.726883,-129.793463,-130.148243,-103.780757,-20.946336,30.496948,80.330988,83.203601,41.653536,-9.584,-137.251151,-232.470498,-249.222975,-225.255583,-194.588561,-125.39787,-120.346585,-176.392703,-190.624741,-178.611634,-154.353032,-95.494178,48.257607,56.639364,-42.713107,-89.38427,-99.480689,-102.411649,-110.709942,-79.709857,-57.506614,-49.30292,-62.897975,-105.253631,-109.190531,-83.666204,-37.884479,4.711729,54.344668,45.464772,15.953748,12.038038,19.469497,-37.001423,-78.851267,-43.671434,36.417546,167.301852,176.408373,135.462327,118.410128,120.805546,213.541573,276.604053,292.67388,234.340244,65.119276,-7.533421,-25.38867,42.965453,66.560937,105.609774,108.720434,75.282545,49.714316,-13.812775,-39.804676,-16.843631,72.155495,94.177221,54.693544,25.582916,51.625884,81.099173,52.033645,-35.533323,-59.710728,-59.93068,-61.323955,-41.077934,8.732507,100.904179,102.287298,17.758754,-70.345208,-76.684823,-41.295965,6.304894,135.886866,147.83817,37.169385,-20.709486,-22.557455,-61.650914,-69.327466,-9.301902,16.341173,-19.207262,-56.073336,-89.675678,-30.549451,20.162481,116.39167,158.88003,191.065988,168.95488,87.228896,75.22277,121.288763,157.477381,98.461933,-40.539754,-60.635327,-10.133874,5.471144,-101.652265,-199.012059,-162.285086,16.857608,100.633347,105.71343,20.287227,-131.702082,-149.068108,-140.224177,-105.148512,-69.271019,51.381058,95.777475,9.566641,-90.480333,-198.719527,-178.099723,-156.399086,-140.231589,-164.879279,-269.284896,-315.905536,-325.969543,-325.10254,-356.528448,-387.134357,-359.234751,-238.738312,-170.919752,-140.483373,-188.216938,-282.666547,-246.444752,-177.598798,-23.863181,22.32978,-5.814029,-73.946703,-222.016711,-318.969445,-322.471184,-167.525143,-61.748598,33.34956,34.469352,3.921105,-28.328888,-87.982461,-36.800559,26.587109,110.358284,100.278297,-8.576247,-51.410704,-26.969848,21.741725,19.479889,-49.657984,-112.594539,-157.417965,-104.313264,-11.310191,-37.606681:right
-37.787486,-120.895043,-104.290186,-9.140583,44.001231,47.717244,-12.758629,-132.905864,-89.470189,1.83256,201.300854,264.986008,292.059518,258.971689,144.718534,78.316472,-31.969485,-70.296982,-54.879072,14.649962,15.259459,-104.113381,-179.185386,-260.455901,-234.484941,-199.111158,-107.065311,-51.816081,32.181105,41.289691,-10.073981,-45.102756,-32.714915,23.135496,30.00469,66.298335,96.307989,118.600755,106.666967,61.449027,83.320269,132.801403,200.802386,185.249175,81.015302,33.023689,-33.475739,-73.950323,-141.242185,-112.51579,-62.047447,3.372351,-27.292804,-162.654538,-198.39898,-144.33649,-80.853691,-98.309006,-142.240799,-116.92437,-14.779737,35.416836,147.36978,177.067933,112.622684,44.954201,53.312781,104.453718,129.802937,202.466851,228.573345,167.864297,79.455514,72.271014,99.448458,113.587556,109.873895,96.678286,57.288095,11.711554,-103.617697,-172.677238,-204.879257,-236.819816,-200.729475,-80.536799,-66.0428,-147.935874,-179.003646,-142.372376,-27.098239,33.471764,130.121982,152.555351,132.890816,96.851194,27.162634,50.525516,103.277419,204.943986,213.508513,162.795967,149.779453,191.58624,236.768928,235.192988,234.146052,266.973073,312.700468,281.933185,180.677214,158.045573,197.496775,253.988777,275.19905,364.898155,417.487119,443.873212,425.682188,362.274562,288.427881,298.755152,410.955889,455.841604,443.6542,395.700088,261.845786,190.099348,97.245558,97.265879,123.818442,186.860454,180.277453,84.299741,35.281756,-33.35987,-67.941522,-77.934322,-107.915926,-119.912416,-143.803948,-164.416984,-219.917234,-249.234488,-247.463319,-181.3072,-162.033058,-105.466709,-65.327987,-32.07895,-54.261354,-179.84888,-271.25411,-253.214518,-144.715348,-100.890041,-77.624119,-80.6696,-124.828858,-157.177209,-137.785034,-41.600246,-17.311309,-28.041114,-40.929824,-70.305179,-105.969417,-188.425643,-170.532209,-142.084979,-98.009356,-69.780906,-32.048334,-46.770968,-110.907161,-133.645594,-102.514366,-44.057113,-41.98681,49.944295,167.127803,315.956621,260.671083,32.584619,-67.153071,-80.979496,-105.936344,-117.601524,-107.029541,-82.342855,-76.180379,-124.09278,-212.538182,-78.146441,32.115524,131.631043,98.070904,-35.550825,-90.961016,-183.869484,-283.139013,-309.061453,-227.79268,-142.457338,-99.746271,-143.454202,-171.070271,-141.784382,-25.444053,111.582595,134.722095,79.540372,28.175711,-69.345548,-107.989602,-170.965909,-163.562261,-121.733498,-20.71118,9.669879,-2.351835,-16.614335,7.940888,38.289104,139.026682,248.410638,251.260753,168.166642,114.682766,19.494023,-36.686257,-191.896652,-255.825948,-224.183523,-112.00722,-68.090327,-62.25377,-96.721014,-118.380218,-59.310035,113.194503,201.578296,224.122413,244.942421,202.981554,58.995336,17.709362,-39.719347,-77.375788,-71.526702,-88.503089,-104.826508,-96.614398,-85.565343,-118.898109,-171.093522,-223.318059,-113.886452,-39.59248,74.767631,80.658644,-42.825506,-121.278474,-189.571152,-177.876189,-188.482039,-224.187816,-222.018138,-234.056982,-229.628699,-113.065213,-67.397121,-109.533242,-157.276317,-155.877442,-131.208303,-124.092728,-144.198878,-162.159635,-183.007681,-134.474364,-111.361598,-121.305285,-112.060699,-15.740936,36.415827,75.057221,73.312318,99.904878,85.991949,47.280611,25.086417,32.855803,-4.789943,-32.258094,-69.830493,-128.390383,-164.727918,-186.546665,-151.684476,-81.696424,-91.747279,-193.008952,-258.244734,-349.971676,-399.146343,-418.551423,-365.541928,-285.271405,-142.434562,-125.70827,-194.547972,-243.74419,-228.979146,-171.84564,-140.626245,-83.52662,-76.797865,-149.006759,-220.41769,-310.142362,-175.664284,-68.24177,19.578654,-14.426537,-167.485523,-259.799276,-380.74322,-302.524088,-216.208338,-77.29009,-22.858735,59.65144,63.907943,-23.853047,-87.112766,-118.943484,36.198245,119.705167,177.145394,160.427251,115.675163,102.605877,61.438284,-12.91136,-34.141805,2.693083,63.047896,173.373857,171.73286,62.839566,0.809278,-48.492372,-17.209863,21.804146,115.483128,119.54448,46.522735,10.269036,-59.89212,-44.153131,19.623704,141.952854,160.887051,152.931034,174.615649,225.665926,180.707428,8.706295,-61.848609,-76.314892,-91.227176,-66.123275,19.669637,22.595078,-88.069518,-113.542687,-38.038106,127.656084,151.973452,139.404275,141.97231,101.632164,37.090178,-78.59699,-62.549924,-14.544319,70.269698,72.663295,5.968199,-40.526845,-152.059132,-203.844588,-150.0119,89.324646,211.143359,289.346123,238.294913,53.627311,-55.61961:-53.821925,-29.444666,26.884904,96.76048,102.108065,60.496716,2.683995,-149.384365,-166.009498,-76.802874,160.76524,222.959376,206.955971,168.173149,74.528337,31.10839,32.252542,98.805339,111.720806,134.63323,141.742696,111.41685,69.572743,-47.997904,-62.213491,-29.219324,30.903635,55.128195,78.275573,69.761405,26.166916,7.913604,32.642197,111.109829,131.537666,88.040975,50.374403,29.212578,17.84899,-52.693074,-26.164251,47.660444,199.737477,211.331932,63.85373,-47.07992,-238.726812,-295.867001,-250.09006,-57.480016,37.262023,157.617358,136.695895,-60.322596,-160.135788,-203.098741,-110.884199,-87.030521,-109.924278,-107.041053,36.158099,108.465855,38.81804,-43.214153,-47.659042,29.360598,37.18215,85.444685,131.058392,188.196266,182.199009,120.891636,118.657727,155.629222,198.350191,166.528399,23.280204,-31.838814,-17.836747,22.229886,24.094665,-78.162386,-84.530362,-3.328217,20.409445,22.719989,19.238082,-11.448217,-48.847464,-38.787649,109.385846,208.009884,229.825816,154.946485,10.06067,-22.493091,-19.640869,37.360474,102.599388,245.99177,269.800196,217.738223,185.93834,187.239289,271.631023,325.146362,364.304514,323.294862,178.113702,131.714844,131.841514,145.566274,153.201003,194.858465,242.553115,324.112808,330.996371,285.349256,238.48904,129.52069,156.637759,228.799678,365.959008,375.164862,232.127309,135.362946,4.37616,-43.7852,-137.558758,-153.050843,-98.192237,75.118236,119.60596,46.374905,-28.961693,-123.222704,-68.391975,-13.401005,27.889819,-0.703435,-81.394011,-97.986557,-118.152757,-150.007105,-198.696152,-168.920601,-142.135609,-78.468301,-52.006023,-48.335204,-89.321814,-254.718238,-354.819152,-336.21958,-219.657621,-159.49972,-86.063209,-79.66506,-132.825587,-159.235694,-124.507915,-74.369328,-88.547918,-107.714471,-81.281842,-50.157304,-85.437743,-231.55674,-342.087661,-352.489951,-295.143661,-254.430861,-220.149093,-222.647386,-249.492205,-274.649795,-291.47884,-271.160469,-251.639247,-68.03368,67.724925,157.503195,95.290173,-37.439039,-72.019924,-87.891574,-120.467942,-121.855722,-110.786782,-106.591415,-132.837995,-161.227256,-175.306298,-70.714497,13.692019,111.799896,89.161472,-38.880767,-105.178884,-192.074305,-253.278732,-294.887206,-297.480396,-246.302338,-186.181642,-189.550728,-185.129379,-179.29326,-193.864801,-161.381252,-101.480987,-52.133145,-113.332288,-270.303022,-303.159466,-302.192899,-313.835337,-324.015477,-277.977258,-223.494386,-146.278623,-132.705534,-139.809268,-152.724616,-101.629308,52.990785,100.906731,84.82471,48.776379,-75.006638,-177.468756,-331.596542,-259.676214,-205.358371,-172.790315,-176.57705,-170.772877,-153.750175,-141.953739,-149.370011,-111.089287,16.002337,91.446503,144.724825,88.443299,-37.023878,-50.28633,-61.004051,-113.569736,-114.227602,-27.440884,9.853224,-24.028804,-67.896496,-124.09457,-139.54698,-169.276339,-129.496862,-87.263355,-26.143896,-2.884872,-6.37428,-58.463612,-156.704607,-182.580719,-220.768314,-290.438791,-268.340201,-201.355181,-192.811039,-138.320517,-97.628593,-84.860254,-101.871038,-74.271756,44.408084,81.039896,33.017482,-21.180557,-82.989781,-65.368769,-69.51069,-76.828893,-28.522458,98.617303,101.308297,4.217057,-6.765715,113.809267,102.496092,27.342432,-26.882392,-21.008199,-62.552536,-68.046395,27.0745,114.310004,77.026647,-150.608322,-231.191821,-198.284785,-168.182056,-205.233944,-236.116964,-269.910249,-313.427997,-319.585365,-214.212674,-125.898279,-43.67707,-64.877332,-116.570873,-114.938443,-113.866004,-116.836726,-102.562766,-41.837337,-19.802039,-97.009496,-180.294437,-197.949901,12.990489,121.700675,211.983448,170.217846,-24.667171,-122.943282,-207.774269,-139.87607,-99.876009,-30.471617,8.731505,18.059956,-26.975549,-133.300824,-149.719984,-49.325616,193.681959,299.41593,342.136052,283.803893,131.829147,81.913891,41.307892,-34.2973,-116.380528,-177.382148,-72.923438,167.868933,154.523753,-67.16336,-126.3481,17.600158,175.582604,157.093799,53.827213,34.259356,45.111894,22.919912,-75.785656,-19.072052,62.66453,187.941487,208.981112,183.314583,159.069018,98.122311,45.867221,-23.078524,45.18538,77.109156,58.050941,42.487522,71.681387,86.57715,28.648582,-22.856851,11.684353,151.425107,208.515646,237.384228,217.133269,148.414184,117.420062,98.902463,133.707057,171.018742,215.811084,180.127966,48.326318,5.139556,-34.671269,-90.828389,-78.746235,117.110569,229.424557,294.526203,254.936296,73.265892,-43.143183:-73.410631,-88.230432,-9.985684,150.962957,152.617516,-41.497991,-154.03749,-202.257124,-68.779245,14.677085,150.003656,167.582385,124.771777,113.896752,90.664532,52.502534,59.905853,227.266548,285.500543,270.665051,226.490391,150.144624,112.829407,29.336901,20.817968,51.860839,146.721304,179.80834,191.407022,188.819756,156.217755,155.73683,263.874042,279.036628,214.497921,92.384009,61.049056,29.386567,7.141139,-52.416231,-30.405069,31.053092,176.392487,202.428083,117.194214,34.247346,-194.144347,-301.531632,-273.745638,-41.641809,31.261583,65.717225,22.36194,-169.461535,-264.476392,-318.659979,-206.966683,-138.302917,-33.810674,-2.774867,32.929185,48.905246,50.444613,20.043967,-17.06465,96.915991,176.115148,224.136663,194.804193,138.816936,131.728716,139.782333,141.190409,155.438155,256.802441,298.243025,224.719618,120.324247,-49.516898,-46.348422,45.31133,-5.208966,-54.527105,-52.21518,-22.767825,-33.83761,-79.5678,-153.695953,-84.469608,-2.615277,164.300764,205.157943,125.481871,35.043103,-90.637749,-105.465036,-101.628166,-67.174462,-19.794652,88.564487,131.945236,173.089058,144.476857,25.896134,55.80613,147.292748,311.030223,324.999046,233.47632,178.461126,92.881141,68.197422,95.021601,190.027551,243.561584,292.869947,271.336206,214.751761,199.423124,174.755536,137.286491,125.490775,188.97342,235.35423,191.534448,96.528956,-138.866378,-239.50839,-328.016057,-297.804372,-242.232306,-62.500512,-8.055102,-113.919496,-223.847638,-310.823816,-237.277498,-215.088804,-189.86043,-167.311711,-139.589128,-143.77454,-204.52561,-240.270749,-210.834759,-83.365826,-23.697038,-11.738416,-72.879578,-195.659948,-228.569939,-275.81181,-255.055633,-229.757931,-189.392881,-176.885677,-206.669453,-220.632206,-180.56512,-156.570305,-142.588023,-168.071943,-177.507689,-159.283391,-139.219737,-121.482096,-147.448708,-270.881728,-379.090321,-394.305294,-307.186463,-247.767445,-259.82294,-301.379106,-312.780629,-291.362465,-292.983607,-373.582882,-365.04181,-155.47227,-49.913473,-35.44994,-66.331051,-20.347808,68.686199,60.063395,-54.748642,-113.294306,-140.487635,-124.947687,-173.819628,-237.635463,-256.013623,-96.637924,-18.045179,57.744243,47.72989,-44.08393,-112.05853,-239.616452,-246.766985,-225.014565,-239.188541,-261.02643,-238.562124,-220.083593,-291.045939,-337.893218,-289.784002,-122.062846,-50.811803,-2.419981,-37.604746,-188.873071,-288.978781,-434.627176,-332.056309,-241.111046,-148.530658,-134.112904,-113.046817,-109.787416,-146.757091,-187.192523,-217.505737,-74.139754,11.136214,36.743511,-35.162575,-250.605212,-346.330074,-375.194253,-140.691756,-30.957653,-11.932851,-71.053314,-153.716591,-153.953592,-160.297699,-174.165645,-149.660043,-81.91425,-38.289445,46.227723,41.447318,-90.045732,-170.850735,-235.255264,-155.230944,-114.236007,-79.949581,-83.982837,-125.548627,-147.972679,-231.064447,-301.732178,-395.520078,-280.558031,-172.50173,-23.896509,-4.423926,-50.668315,-106.943885,-193.410978,-175.70479,-168.809167,-180.797631,-184.405212,-171.006458,-143.37789,-102.105032,-115.443512,-128.215906,-58.494422,-19.290941,9.238058,1.076889,-24.414619,-46.32494,-54.959305,34.365449,62.304097,102.132225,167.997818,300.603557,280.936938,89.949093,20.324752,73.12838,127.8401,76.243706,-61.008981,-83.784676,-50.857629,-34.879763,13.105074,106.338792,92.781274,-125.319893,-228.615578,-214.847356,-168.908191,-202.341277,-234.173158,-226.85832,-195.06802,-161.744768,-36.553453,24.941381,18.429182,-48.155543,-95.953573,19.74042,39.262112,-28.558909,-68.795964,-108.335839,-112.361493,-131.637358,-119.37884,55.406727,250.627851,270.828768,175.841191,102.53138,-0.061806,-30.689784,-92.48906,-75.945727,-46.276644,12.901269,34.804509,18.430587,3.242266,2.465849,-3.722022,13.940855,170.239498,255.902694,267.484137,189.740943,33.871822,10.537093,22.568258,-92.35718,-168.672294,-129.798908,-21.184441,136.652937,118.621842,-58.529496,-128.512689,-78.28024,91.017729,161.406914,221.411349,194.714122,106.549752,81.804074,36.996379,64.082799,134.119743,255.606357,255.906675,204.068186,179.195831,85.006564,24.748402,-18.901137,73.113065,123.123646,77.357251,3.783482,-29.332575,12.084245,26.017209,3.247439,59.298154,227.271317,256.58683,212.456146,191.483867,130.011511,94.946832,124.682842,193.170104,206.097223,187.86889,145.846954,30.003612,-12.660266,8.215161,95.836864,117.059971,205.945457,273.02752,308.774201,264.293779,85.077679,-17.453608:-101.979275,-203.504948,-167.148586,-14.338921,31.751387,-41.813697,-131.825247,-234.768296,-70.738074,93.028316,379.057376,423.699248,336.363459,266.793971,111.994081,24.374337,-79.750126,-60.32022,-11.147194,122.62552,129.446216,-42.732409,-152.258332,-248.897123,-196.672981,-165.580617,-69.487236,15.61264,151.504537,155.2195,87.279465,65.810066,124.892364,211.289961,215.758987,204.886064,204.845777,191.241652,166.570945,112.700447,152.106904,193.885695,190.217595,137.215287,49.598711,25.790429,-95.340641,-191.631143,-252.586005,-123.282722,-69.173185,-11.013201,-25.295447,-177.895008,-260.584807,-309.425441,-275.674692,-248.868144,-164.729042,-108.041645,7.846282,53.355317,83.985018,70.598645,72.660881,152.866964,186.760051,236.345738,266.918737,276.339227,244.63481,194.06765,202.797579,210.91826,236.439779,245.249478,176.771968,102.336944,-3.669598,-3.620016,27.038997,-85.013408,-167.283193,-189.769772,-151.791977,-167.511322,-222.577052,-294.427887,-272.765819,-245.951859,-120.333515,-16.106035,85.511049,49.534065,-33.774012,-49.226517,-32.615865,92.631351,164.102439,227.043295,227.075985,227.315917,220.575081,158.330018,177.220057,243.930558,378.909756,414.412646,404.360045,362.491698,224.38266,161.097804,182.162243,334.629262,391.537736,473.211949,488.388038,417.220598,350.490416,220.44492,177.322245,188.859833,233.198266,263.524798,269.688196,212.8288,46.94526,-10.902772,-16.523719,36.979382,62.132392,164.283015,221.391605,197.350322,110.002809,-95.558509,-223.298979,-246.075028,-212.284868,-164.361778,-103.914949,-115.939129,-197.371551,-248.7633,-292.977727,-240.106538,-210.80458,-170.806823,-167.688934,-200.277203,-229.182225,-313.194448,-310.464681,-263.026159,-197.219581,-195.337683,-206.678483,-199.24683,-189.42711,-211.016659,-210.777828,-80.533944,-17.205065,36.038846,15.493184,-85.702228,-142.353543,-268.177152,-333.129388,-313.183781,-205.702781,-154.291492,-141.763941,-163.607564,-189.125081,-197.767861,-202.026372,-164.006268,-130.129209,-14.973073,40.612988,65.648504,42.320697,-16.994172,-5.884664,9.726112,-52.042025,-112.079194,-148.384934,-111.435045,-78.293538,-122.407806,-191.073068,-84.834483,-0.490938,124.49142,143.207966,101.454427,50.493046,-99.767988,-221.84998,-250.408867,-228.89453,-173.773599,-99.297487,-123.851714,-192.120533,-183.703142,-59.265489,96.673516,128.861333,119.294294,94.269417,-6.899735,-89.601521,-245.545285,-194.905731,-108.904531,30.337705,49.119793,-19.297119,-48.520612,-28.087844,-31.630823,-71.720715,-31.253709,-5.920063,36.539393,58.109309,17.184509,-67.251411,-222.431799,-154.203818,-99.158048,-104.482299,-130.51589,-190.748876,-253.194501,-382.041356,-387.006538,-262.61364,-122.288114,-69.892776,-25.466888,-57.083448,-190.477942,-263.421174,-346.829813,-263.757659,-188.947159,-73.997545,-42.246015,-45.083238,-81.64924,-190.338581,-260.045242,-382.256146,-294.428562,-168.424214,11.595876,0.689107,-112.079271,-149.59102,-193.984877,-197.302196,-176.997322,-154.995867,-162.036434,-171.791082,-144.690201,-50.611305,-45.833086,-133.196918,-195.329966,-196.089658,-122.822555,-83.187029,-93.316145,-117.807838,-90.494157,4.104344,22.78551,14.631444,26.950866,83.739371,86.266784,-1.570415,-32.070375,71.56118,123.8281,59.869407,-42.915311,-44.219175,-41.632892,-58.013725,-65.544324,19.870504,54.601235,15.103708,-31.469273,-104.482312,-141.452499,-238.41987,-277.802801,-284.437686,-243.066049,-220.040397,-140.471233,-89.755409,-2.002588,10.639127,-43.098817,-70.030035,-59.724024,-71.469757,-100.729081,-164.659915,-185.237576,-211.490633,-222.416603,-198.179752,-112.0499,-56.078139,24.570971,-0.505335,-143.963682,-198.136167,-232.976179,-214.372468,-193.015025,-55.944883,55.904325,173.39468,155.333798,97.980604,82.494776,86.524435,187.695566,246.620598,282.013039,258.104792,202.055998,181.63277,138.700829,53.127146,-13.653573,-44.51072,34.506183,166.081991,123.779985,-118.163001,-216.148629,-196.402242,-68.772153,-26.384789,43.915972,56.703762,27.115641,-1.358497,-68.202535,-30.640289,38.823012,190.354902,233.583995,192.264768,134.188659,35.930282,-14.325558,-113.321932,-135.938893,-128.043826,-122.981395,-123.747387,-75.314067,-41.395345,-78.397184,-138.75461,-95.526563,66.670942,123.176802,178.456083,189.967918,145.007839,86.88126,4.930775,76.905921,141.802971,234.456359,230.28944,104.641956,21.748126,-66.743311,28.442927,110.966856,252.674182,307.399227,331.523324,284.626476,114.125788,32.386144:-112.87516,-107.202499,-5.794003,182.80552,171.804113,-23.62733,-119.306377,-145.240573,60.022237,196.32922,378.078404,391.215684,299.683897,220.95132,30.442078,-46.25886,-81.027297,19.197622,115.836346,288.57976,296.115187,144.68441,21.561673,-149.477164,-59.624818,29.283079,191.175798,250.434217,296.464598,285.18656,204.24617,170.727888,191.303191,255.029844,297.639315,355.012213,324.169721,177.29948,103.035958,16.893916,88.706036,163.025539,226.459824,176.308664,34.833337,12.950078,-44.479307,-123.751253,-166.941849,3.916196,64.539465,76.013883,48.958261,-101.225508,-219.388352,-376.530674,-340.695928,-281.592678,-152.445604,-108.862736,-30.109531,33.790424,122.368273,131.499566,193.051141,212.172204,176.528676,202.482678,273.230826,295.804255,230.161504,177.252046,306.844138,364.416465,415.236086,404.125465,242.440416,112.281785,-70.715687,-77.73569,6.753115,-5.984967,-41.242909,-41.983209,-43.162043,-161.198571,-253.559015,-414.108533,-409.370079,-303.021148,-7.986916,101.187552,144.586443,84.502243,-70.919311,-105.075477,-38.191754,117.824351,190.001261,234.487076,183.479499,31.080461,-13.52055,-10.779692,42.953158,70.240733,189.936169,277.971784,360.438342,334.152491,172.312424,74.314915,66.597313,286.850346,367.170874,384.573547,342.540626,205.73525,120.723144,-7.087584,-22.089354,3.195445,124.29467,183.627406,142.855259,33.998072,-210.303331,-261.985007,-146.284823,49.699811,110.94301,186.978031,181.751225,15.561808,-114.010608,-314.827005,-332.401155,-287.702014,-139.468172,-59.274572,-22.442771,-80.06198,-207.530202,-231.685686,-210.4579,-150.857029,-116.291256,-130.849547,-189.166786,-281.694952,-301.786414,-347.11497,-290.428113,-227.136896,-190.307868,-214.384244,-252.611385,-247.511007,-224.107552,-221.008811,-166.398249,-38.943481,6.51107,-10.679114,-48.738291,-119.248558,-178.03956,-290.566574,-190.425741,-113.362444,-74.072784,-99.033078,-160.877961,-180.324247,-174.703943,-164.925471,-192.579902,-210.628888,-161.883719,-3.727138,36.916566,-0.275741,-39.639099,-77.892406,-35.496115,-0.766122,26.871788,-0.174294,-98.009003,-131.263644,-168.442051,-189.184184,-178.006473,-94.218202,-34.399849,152.660648,230.42126,193.48428,95.93752,-86.989856,-144.458134,-146.602455,-102.698451,-47.40548,33.243826,-3.044303,-217.974111,-290.970506,-184.18776,49.093498,125.295655,201.660307,190.829595,23.297882,-99.325404,-231.739139,-123.171643,-31.741614,100.515185,114.825387,56.918179,23.799467,-56.135774,-119.191537,-178.869809,-95.355059,-42.072902,26.145451,18.773631,-121.537925,-222.22626,-302.677086,-145.829467,-57.029468,5.571641,-18.121,-131.811584,-203.606584,-341.659779,-380.295937,-337.713694,-175.633629,-86.756642,-31.384084,-74.886549,-175.862118,-216.827536,-277.199393,-229.818378,-184.969175,-116.094027,-93.873041,-79.909347,-90.060188,-157.275424,-216.233206,-346.472224,-316.75566,-204.51971,-10.5727,-1.965279,-88.672559,-140.777324,-169.526364,-74.132142,-38.612212,-25.406174,-31.03069,-41.47712,-27.291223,-8.068122,-30.944923,-69.534853,-45.202325,-33.529801,-16.658719,-8.160279,-36.586698,-88.681977,-146.742065,-6.533469,67.261914,106.084182,106.007438,132.431969,132.28676,57.105373,28.345436,94.51206,172.884421,173.683944,83.590093,4.453577,-75.708764,-60.941685,-10.365543,-11.009163,-40.810016,-98.035188,-104.830732,-120.948341,-154.537255,-231.967639,-248.400326,-234.408614,-164.975922,-111.351425,4.130663,44.850801,47.345597,0.715712,-120.097131,-135.141452,-103.83411,-30.108688,-28.383029,-120.235566,-163.516253,-193.551198,-189.255191,-115.195184,38.14484,102.155489,74.126896,-13.062386,-160.787719,-187.559389,-168.324371,-76.410718,-33.286454,65.433311,127.097178,167.184588,131.002562,33.57855,5.850533,25.59856,133.167194,201.730969,265.472551,233.019332,83.858853,-0.524955,-86.189523,-62.604351,-67.611011,-91.017946,-76.94102,-46.009354,-71.52074,-231.482692,-302.453571,-264.395107,-129.905627,-60.866473,75.531366,84.935766,-48.992371,-126.413327,-151.822794,-48.891387,10.812244,172.583,238.349209,191.317626,88.328879,-123.510249,-180.04445,-169.59932,-119.166336,-114.527396,-114.074813,-117.27476,-139.160744,-166.369417,-276.91651,-254.689706,-132.587713,116.333379,151.756215,129.042806,132.079236,112.184821,75.252283,74.937878,179.579346,222.093385,238.519437,203.255931,81.013029,22.144364,-23.570674,83.916536,185.844713,389.856315,441.978361,409.937174,357.053435,211.856039,136.37727:-36.60583,-128.857621,-90.347589,37.825034,70.825037,-21.375229,-102.246677,-148.853109,-6.863644,100.793597,337.447201,443.011748,498.211835,424.94839,173.84418,50.134641,-91.568556,-107.172388,-93.392026,-62.352509,-76.504837,-181.992394,-237.208381,-293.830676,-256.055085,-204.969411,-105.212671,-58.908703,18.686435,32.581554,47.827958,67.574433,128.833948,177.161981,181.532308,190.891554,200.151077,186.844361,159.82149,97.005355,136.028301,208.687677,301.646837,258.01949,60.333295,-11.899602,-103.466479,-172.036269,-262.009246,-157.570004,-74.848952,49.919696,53.540072,-83.483735,-168.106339,-215.428329,-149.267624,-139.478418,-176.751091,-166.899937,-52.356963,-6.310095,8.576495,28.266029,137.028529,171.793761,155.645874,181.565567,209.934593,195.512662,166.435026,132.93414,98.996652,77.18241,90.791801,109.975577,66.043621,23.276176,12.418955,35.505057,25.985644,-138.044803,-229.12229,-247.826927,-182.088657,-112.41014,-162.309766,-313.629597,-305.761204,-247.225298,-108.52264,-39.919088,60.751933,92.256379,110.175587,88.041299,69.548391,118.993412,133.043459,173.477595,200.82579,191.410463,147.339789,29.783292,24.838706,88.501701,254.783361,308.295368,289.322765,248.803419,198.12043,176.115674,134.523587,177.961786,233.932602,365.234991,419.50745,447.153856,420.894156,349.163074,256.852806,219.882633,309.499074,431.099895,590.454973,568.385766,385.828564,280.975059,197.140702,265.798445,284.671104,315.643085,339.368855,293.149166,210.278485,5.863409,-129.696172,-148.646978,-103.182138,-61.282608,-47.169514,-89.900728,-189.627274,-220.666079,-203.300643,-153.444054,-167.243761,-197.63637,-171.219924,-79.182726,-73.537446,-203.467742,-270.822514,-203.887457,-25.175868,2.598009,-91.407675,-153.1019,-185.059063,-163.764706,-85.741418,17.351136,61.477243,103.281467,97.110446,18.157715,-48.244536,-159.806248,-140.090493,-85.092616,58.957534,130.874916,186.34073,159.729939,100.855987,87.266241,79.519595,98.96857,114.565099,194.216031,239.322507,216.886537,161.209787,97.272433,75.192692,31.557804,-68.768447,-61.697412,53.604562,80.9226,-26.168016,-105.332036,-113.18291,55.262036,141.283595,232.901131,216.738741,130.75259,92.444807,-34.559928,-211.815385,-259.610124,-187.944243,-83.339525,92.162814,101.515792,38.49304,37.210239,128.386194,256.138787,309.906425,343.04026,284.228941,27.313542,-97.873475,-196.959092,-80.428995,22.387833,170.268732,182.770775,129.823255,123.036445,172.073549,179.988219,183.000351,214.089663,219.341423,243.609457,253.389795,161.329636,52.371008,-144.256419,-157.626442,-123.366391,-45.42901,-38.402782,-175.989674,-274.391646,-321.526489,-264.536901,-124.056281,-48.938236,-42.070422,-96.394825,-168.356725,-274.611546,-257.503937,-250.015689,-307.013833,-270.076067,-138.95463,-108.518553,-110.63514,-119.774034,-174.834416,-216.647504,-233.041411,-135.541639,-80.949578,-31.478248,-57.723064,-170.54992,-221.989654,-293.941736,-254.098935,-187.671828,-103.216,-124.063277,-223.828345,-225.161567,-84.260023,-44.876131,-205.551555,-382.808058,-349.077389,-146.121846,-95.642486,-166.899416,-222.492449,-265.300677,-203.678666,-174.518519,-182.572367,-181.878584,-141.61632,-135.387941,-143.001715,-115.798229,6.842691,13.914593,-35.279634,-65.253604,-50.982614,-88.988427,-117.820321,-87.350931,-44.754385,-74.153172,-123.481034,-80.832913,1.550351,-35.66734,-191.88534,-241.030144,-233.248653,-271.509261,-332.657043,-366.188209,-316.026141,-194.13438,-171.041588,-219.752546,-328.067392,-383.029432,-389.766102,-331.774288,-261.018928,-286.709496,-398.915874,-459.733348,-506.855713,-395.3675,-310.520259,-172.913255,-157.705496,-265.856896,-353.835002,-461.453519,-355.368396,-258.175266,-105.037158,-40.272197,68.951616,83.012963,47.984827,22.728468,-11.100717,35.538177,89.852991,170.419522,167.773771,150.013453,137.491621,41.149194,-33.361626,-48.263699,-59.232692,-24.287949,74.033862,77.992374,1.714819,-44.510172,-110.09142,-76.878712,-1.671159,136.994717,128.164049,0.021141,-56.610168,-85.50081,46.735726,145.242519,242.144823,228.561784,183.126839,187.656964,218.443479,182.816865,-29.186803,-178.653843,-174.262988,-126.883552,-119.788499,-88.64141,-56.72182,-37.78424,-41.463626,-10.821099,29.668883,19.678742,42.236789,83.377918,89.201709,33.064135,-22.966767,103.300817,188.561295,274.319215,235.339159,63.824354,-5.350258,-90.95326,-83.314716,-10.532857,205.362788,299.061053,364.298128,315.762309,111.992084,5.939513:-55.558016,-94.943029,-0.734794,200.714925,192.860723,-42.816137,-175.582444,-263.602592,-11.051824,176.943991,455.109669,500.142001,398.149015,287.642029,33.643091,-67.140926,-86.441353,45.729947,91.285459,96.724636,58.41412,-79.720135,-165.511265,-294.954105,-220.691469,-120.097321,57.019939,119.435507,231.88466,261.168566,228.708446,211.153879,268.977711,352.197403,371.125402,426.522089,449.594172,352.472393,230.67318,26.283297,77.973902,174.358552,288.974466,254.035348,106.787194,62.544311,-29.075459,-121.83341,-232.39458,-98.496451,-10.603146,90.679556,84.228663,-54.546092,-160.382125,-308.148621,-280.880603,-223.356662,-64.914475,10.711782,102.425136,130.124631,163.934148,170.144635,201.49041,233.176524,238.12451,271.684561,287.980154,240.771637,180.685969,96.50256,168.769891,237.549741,349.519238,360.980616,230.466372,129.518093,31.110091,33.523407,46.764706,7.933494,-17.523249,-4.710305,3.215665,-115.048703,-237.442263,-424.705925,-329.181525,-219.02681,-17.842642,67.898542,144.09467,113.307203,7.287563,-13.82597,47.960969,146.901717,186.457284,245.008497,248.145128,210.844081,177.4925,53.130663,-37.449953,4.051563,226.370614,324.178971,351.678413,287.504199,77.847217,-9.999506,40.662285,270.903799,335.488185,367.655449,363.231241,304.892156,242.519734,83.827135,89.495482,177.071614,352.800347,393.559633,377.484592,307.241239,37.872929,-73.296953,-40.401785,111.105669,145.849845,210.24049,231.645531,130.101131,10.207446,-222.984247,-269.570662,-229.335374,-83.7997,-4.724419,14.273967,-69.066036,-260.867661,-302.1701,-259.344538,-175.430416,-162.243493,-160.530223,-156.673807,-172.438721,-210.270216,-322.607615,-288.20371,-189.963012,-16.02352,-13.313583,-145.096189,-195.374697,-195.613552,-180.548675,-129.448403,-59.150509,-36.583197,-25.429286,-41.103555,-113.858842,-167.145215,-254.533361,-182.625036,-108.188765,23.833796,85.341798,126.698854,88.870872,-5.496865,-45.746188,-110.1073,-71.483364,1.84496,194.984582,253.735999,179.554079,70.382432,-85.031107,6.060476,86.611673,117.644456,62.446262,-25.46866,-27.105976,-111.342858,-210.455171,-229.833002,68.423048,202.392401,328.049075,342.70565,275.678738,174.45366,-78.969227,-167.436128,-147.017783,-48.782464,18.712841,98.328378,66.989292,-88.936473,-137.303162,-61.389394,137.080493,228.50069,336.154939,312.752715,93.501283,-39.259737,-192.129696,-91.360247,49.616805,281.047436,284.951541,154.868001,100.87691,6.424508,-54.230759,-83.391593,42.570836,93.988415,90.15611,52.797468,-36.726147,-91.785902,-182.992081,-99.353791,-17.329005,68.509659,48.719061,-87.188999,-161.319739,-266.80719,-299.435886,-284.137116,-153.370091,-78.468155,-23.64398,-70.53951,-204.796213,-249.234087,-280.592134,-206.971628,-151.162526,-37.855321,13.630033,31.203963,-5.640602,-113.945564,-172.980692,-256.423756,-189.397172,-90.982456,61.667924,56.338538,-48.829245,-107.07272,-196.422631,-142.691335,-62.743463,52.040263,56.492246,17.302164,12.346173,12.29393,-29.757687,-178.387463,-241.404468,-206.635933,-94.768984,-83.940385,-128.295491,-137.394554,-126.083919,-64.760217,-23.747557,40.727799,64.37237,84.083686,73.658372,2.349664,-30.366304,15.816108,114.410337,130.122022,109.497439,72.839692,-66.12861,-137.420801,-157.653634,-11.662011,43.860033,49.21714,34.849807,-23.388168,-76.344021,-168.49138,-194.552716,-208.061687,-159.856854,-112.786437,-25.201664,-25.85694,-111.133231,-159.426578,-212.112462,-207.813415,-206.947403,-203.132048,-192.389294,-219.405982,-280.735067,-411.662788,-417.948093,-300.997273,-185.415264,-152.422619,-139.134864,-170.651796,-305.708897,-387.301178,-455.065159,-308.957993,-212.935943,-79.731916,-17.382444,110.063595,133.230883,74.949071,31.538175,-3.594311,41.572628,86.497042,159.595931,166.980198,116.215554,57.212096,-63.031512,-135.033202,-161.531276,-120.591347,-47.249282,-33.811923,-150.414625,-420.416576,-483.824425,-436.600293,-248.760193,-147.262581,-43.144867,-69.682152,-189.813168,-221.185428,-225.377988,-163.794325,-86.82916,86.164937,120.787608,35.307636,-30.789104,-85.568098,-99.844676,-191.186827,-222.131668,-178.792637,-111.463189,-122.514406,-163.636374,-178.046104,-229.126149,-179.515256,-88.111854,44.880192,51.141335,50.436821,57.258998,-0.398243,-60.67441,-119.45895,-17.283808,83.774488,249.73707,244.770426,88.535581,14.117894,-15.085633,91.764551,176.765446,382.295758,465.838941,447.917799,333.827475,71.899506,22.041186:-184.383817,-166.533644,-73.310773,79.664125,88.377268,5.460197,-34.871603,-46.619366,53.855905,128.450818,254.382484,316.393604,392.581055,367.334223,203.423665,95.750513,-44.842174,-46.098596,-37.704986,-59.877711,-99.259214,-208.056038,-249.071974,-273.656979,-176.994296,-95.953765,-5.908452,5.335276,48.821731,58.090009,9.679852,-27.270097,-123.932721,-166.597152,-107.512157,88.327291,137.933473,73.978629,13.706683,-28.190201,17.449637,44.303805,83.115019,80.736002,4.610678,-73.991391,-297.21855,-409.395604,-484.966365,-323.880108,-234.465578,-150.449771,-138.447415,-125.108731,-125.271192,-162.910853,-230.626274,-231.883091,-130.647431,-67.022761,-38.600193,-73.096646,-107.688002,-77.690801,31.264752,72.300962,57.81574,66.743473,82.440997,61.263244,33.319635,-22.968747,-58.467323,-64.324375,-55.33522,-54.747168,-95.039255,-102.849911,-29.273736,6.706654,-38.984178,-182.906743,-213.65812,-148.000015,-108.949812,-101.962524,-123.85969,-197.18723,-206.604732,-168.093183,-102.361611,-84.690639,-39.545692,-10.234554,25.193473,14.66047,-6.287502,29.530636,40.703618,59.811254,70.976131,66.605114,42.901225,-95.737316,-252.16064,-253.825572,-113.287083,-38.723951,-21.824477,-67.799237,-145.334835,-163.705486,-193.316598,-197.955138,-163.293068,1.197857,88.651726,144.150811,121.350784,62.350116,42.378297,65.126518,187.308152,285.908877,481.41023,519.311457,420.940101,324.749864,199.312166,219.357097,250.895812,306.504665,303.608623,242.719276,223.705327,170.608853,78.592212,65.467218,114.187519,148.377176,150.103154,103.390221,2.387331,-8.926635,17.722126,-24.488877,-55.579132,2.45791,63.278139,70.272952,14.398405,-106.617494,-139.663298,-111.313011,-14.073751,11.510444,-64.276175,-122.967831,-112.47038,-74.10679,-51.735205,-8.528183,43.364661,159.177181,199.062468,204.178942,176.870327,112.544686,114.828544,152.107996,246.715249,305.730952,464.055624,541.237258,608.439468,549.695431,277.380255,224.315497,340.391585,567.101098,576.670496,413.373679,313.11682,215.836544,242.398356,207.651994,13.374472,-22.23173,143.258803,228.532687,217.533873,181.585149,168.769996,195.842458,238.719135,383.121239,406.173381,268.898621,164.177229,8.502224,-18.825262,-7.504179,14.187022,29.714079,52.493007,54.076819,95.356183,147.8877,242.949076,300.97205,342.218959,406.2151,379.670675,188.710271,59.923903,-139.664536,-116.726253,-39.445465,78.262497,103.32947,107.767284,75.603149,2.113946,4.002904,116.648385,232.011781,230.49528,196.141151,183.88441,83.539898,4.484596,-107.106858,-93.808926,-42.91948,37.715842,16.319389,-128.07386,-190.478508,-211.51691,-187.743209,-115.46994,-36.106139,-26.218734,-84.547442,-134.19451,-194.59197,-193.967859,-250.571436,-357.223023,-340.811339,-217.081265,-187.098557,-226.357132,-241.772113,-197.201446,-181.041618,-214.566197,-221.814655,-205.795874,-181.772445,-181.446983,-199.667633,-221.021239,-267.566708,-212.285858,-150.908285,-99.586039,-122.523256,-184.42418,-190.815067,-158.931223,-167.921578,-273.389783,-339.022771,-315.306451,-203.74771,-160.743592,-89.733145,-47.064513,-10.074292,1.053394,3.583823,-53.466792,-79.950496,-84.695991,-95.743529,-108.180856,-79.285946,1.303757,66.912072,87.793811,-13.108073,-135.828329,-264.553329,-202.825291,-23.878621,-52.129276,-106.658866,-138.568298,-109.744652,-61.866665,-57.722112,-63.015437,-87.712657,-132.973771,-87.218068,-75.953911,-132.100319,-145.881912,-50.024327,18.282775,69.64344,-0.645743,-48.101359,-101.468829,-110.359764,-113.237185,-99.914703,-107.665985,-148.155894,-192.072971,-153.379531,-123.754219,-53.090245,-50.972811,-127.417001,-162.109325,-203.778173,-201.301408,-163.656374,-32.364179,54.183312,196.332089,207.458016,155.655449,129.424767,88.703211,44.462172,10.751662,-14.259902,31.079142,173.028021,196.180917,93.010576,-15.867734,-22.783282,11.602532,41.075188,88.811688,70.542751,-32.020575,-60.011197,-27.641626,-43.664234,-60.35294,52.318258,135.628686,167.715825,132.679427,75.846939,110.169799,159.618957,230.057439,217.045894,145.072684,147.669023,203.348378,171.172,-34.306647,-153.824724,-125.745734,35.624493,116.764156,199.450281,190.702502,97.610468,61.545584,76.270969,101.688565,134.366987,232.291978,235.398285,110.8536,30.498889,-27.156372,79.510212,138.296255,203.799981,214.599326,182.800559,130.459762,-5.835191,-6.020738,60.938123,188.526708,216.752649,209.517224,167.920714,29.174894,-33.33449:-54.835348,-65.179703,-29.290349,55.308035,80.699701,43.271046,-4.291693,-76.736009,22.007578,129.125408,305.477572,341.793658,312.91188,281.426955,225.369213,159.138093,-25.269801,-36.349305,18.727685,65.575854,29.468455,-79.285473,-113.442563,-127.89633,-130.251887,-143.140514,-124.907493,-69.610063,60.718992,89.068179,35.688635,-15.435581,-60.875935,-42.916469,-42.348289,-16.893347,30.43619,132.269946,153.573801,138.999463,158.007775,190.935234,191.823022,146.481784,42.377505,-5.868056,-153.780633,-250.056206,-354.330134,-266.948235,-187.955694,-62.511443,-51.172171,-135.899575,-183.177241,-193.048596,-204.272222,-240.580348,-265.717159,-232.319472,-157.692169,-129.461704,-46.238628,-4.311585,31.894244,21.294976,17.228812,121.684798,209.442255,244.255865,165.656331,-18.776637,-41.370813,-11.000896,27.798197,18.34732,-25.057854,-16.056788,63.818607,71.879104,-37.512187,-187.027529,-225.429383,-218.020263,-190.025643,-100.725618,-62.558579,-91.005182,-149.264999,-142.703215,-90.118988,-53.61829,4.417585,22.916431,64.335933,72.262354,50.987634,38.013028,37.033925,68.290696,117.990399,204.784968,184.643672,58.645827,-3.978778,2.648266,46.403805,61.000745,24.412956,-25.639999,-121.157483,-149.787018,-141.980703,-25.656748,62.278983,237.29644,284.071214,260.685255,225.661059,177.041732,195.83827,234.799491,346.187944,415.960886,505.792929,501.28586,419.699684,364.628524,303.851682,255.311757,218.116291,209.898682,215.974634,139.251412,72.003623,-65.02674,-115.572285,-99.14209,-77.200034,-67.612161,-47.392387,-85.22523,-274.496129,-349.942472,-291.713816,-110.501538,-74.005784,-76.297275,-62.911569,12.940048,33.127303,-70.337396,-208.173739,-206.253248,-111.426045,-68.796384,-74.360455,-116.425122,-158.802725,-122.634065,-2.715684,6.257605,-33.95753,-63.236176,-31.099969,33.489196,46.275675,76.771587,95.780098,83.515798,103.604923,168.475459,309.161374,333.372113,308.339827,265.869393,146.015629,122.661469,157.027282,301.020974,393.386897,444.106564,358.643728,136.171655,59.812853,32.614052,-39.53955,-40.634107,53.065363,112.28469,160.887976,135.829295,56.78568,93.671057,162.169367,248.096181,209.189054,42.900678,-7.404271,-25.59439,-80.455821,-115.638141,-77.881806,-10.627609,43.613172,14.199717,-9.528384,22.945881,160.111223,305.135325,338.901642,316.81996,247.857943,79.013842,30.623227,-60.914096,-128.971318,-112.394832,-70.218563,-67.505235,-48.40743,-6.157786,107.382497,133.683349,153.878126,197.761776,186.295681,79.275907,28.120221,-11.106793,-34.786731,-139.373366,-182.867798,-135.724649,19.903925,49.610844,-37.525281,-90.093492,-88.468676,-46.016737,58.582907,165.665599,207.328147,198.426268,125.955873,-37.478114,-66.007413,-84.148084,-136.145706,-145.330057,-130.073542,-116.223855,-124.283073,-149.699347,-155.781003,-130.644263,-95.682417,-93.475187,-100.823257,-85.318892,-48.69155,2.107811,-26.788717,-156.676774,-161.528758,-116.254584,-64.414863,-66.23261,-131.210576,-150.249485,-42.719321,18.593833,-25.109535,-136.186531,-124.189455,14.735063,67.699015,50.899328,13.769931,-27.853404,15.423714,41.695696,14.167948,-31.946142,-69.986969,-26.010943,144.522205,211.068677,206.099464,65.017882,19.654766,60.799215,96.165027,55.726031,-3.473273,-93.623131,-145.340847,-165.33788,-146.439058,-102.719385,-30.883782,-20.695279,-49.73706,-107.589841,-256.444292,-292.731944,-252.186506,-151.677282,-137.7975,-148.440144,-138.672283,-106.150009,-106.708381,-111.351216,-119.814316,-114.410938,-69.398211,-42.362676,-59.614485,-115.548546,-222.371019,-233.244842,-205.982128,-101.763395,-60.043545,-84.502438,-147.297486,-318.381129,-370.090323,-321.40057,-143.596884,-30.601388,109.306243,91.507023,18.026143,16.678775,26.372874,-24.3375,-46.608085,-20.072942,17.232926,53.994415,34.173078,-24.742597,-12.445089,-24.634561,-93.220422,-63.061836,121.767763,157.982623,26.168299,-57.021209,-104.86829,-72.730002,-53.210904,3.780553,27.997387,50.038443,48.814644,22.399672,30.705183,45.345564,48.792792,52.069889,73.119422,78.319307,37.217817,-19.106923,-134.615582,-177.047993,-175.155221,-151.461649,-137.803603,-118.633168,-116.625854,-88.215029,4.693859,26.999034,1.262434,-3.788243,44.34259,94.186547,155.507361,108.721513,-52.368816,-53.556903,6.630292,157.253827,205.39375,186.155948,130.051391,-23.516032,-69.817632,-13.139319,133.038162,179.595061,186.856772,150.50399,46.240375,-14.65064:-68.137632,-158.92997,-94.742821,85.090686,96.054337,-61.393046,-137.952864,-123.125262,85.037173,207.354113,373.693533,401.360006,348.071592,290.422553,154.329169,66.764512,-98.719684,-142.652282,-120.431191,-87.687096,-109.933788,-187.114891,-205.588325,-188.88786,-125.828875,-93.887296,-23.589165,41.462705,134.542201,105.08915,2.994932,3.449528,104.70496,142.935786,130.041924,146.180172,149.410975,118.144328,119.56859,92.011888,9.691883,17.25162,83.917344,70.165486,-39.298193,-77.897718,-163.826192,-246.352181,-317.061208,-189.962971,-136.471988,-92.66465,-84.119848,-66.346816,-75.75714,-165.771136,-205.890348,-185.065046,-91.892622,-30.811287,46.957145,59.495159,45.938941,31.418653,61.281372,104.572615,112.453151,195.113979,240.604816,171.695405,85.915332,-13.147383,5.452336,29.187532,99.845063,132.805107,74.567164,-5.579623,-69.447836,-34.725954,9.523453,-68.704903,-114.637729,-143.98301,-123.729673,-89.856597,-115.31174,-229.393482,-264.183245,-228.086475,-73.920892,6.877047,57.212456,53.023371,82.441327,93.636587,63.48562,33.017082,48.840145,108.57334,104.399556,20.997531,-20.960976,-103.61998,-182.021946,-157.21532,28.796877,113.312281,133.014101,97.236575,38.639458,13.079862,-34.135034,15.168045,84.409496,203.660032,211.529389,124.937539,73.644154,29.473913,32.334985,63.04184,211.271727,290.569353,358.672793,324.356242,158.612779,92.297584,94.940541,204.16172,258.934117,299.661817,253.803877,107.154059,61.9197,-36.65356,-180.444777,-216.210447,-136.461784,-51.18748,34.945478,18.694392,-86.743901,-139.932371,-127.051956,-42.575517,-40.207264,-61.589672,-53.36716,-58.568489,-114.253944,-325.270967,-346.549383,-226.831047,-3.12011,17.861844,-58.471354,-101.1166,-137.685586,-135.779408,-85.885231,6.71327,56.53998,151.965107,160.733009,81.581573,38.844147,-8.921424,-3.962489,16.704621,94.714393,164.56983,312.685989,346.206723,299.394771,228.094174,90.037988,139.456477,219.090188,350.310136,372.969673,294.527873,216.588535,104.866838,112.758199,123.551819,79.543152,50.061426,59.98254,104.694081,169.292212,139.9526,73.281038,176.057967,241.328852,287.445416,273.858276,222.409606,196.716793,133.700623,32.780181,-18.626656,-48.892384,-10.323704,96.442292,107.861494,98.209581,123.389474,200.631653,251.849644,280.245888,342.928314,333.887668,175.836432,54.569138,-105.022762,-18.08522,65.265907,166.116093,190.881706,210.162001,197.729482,179.207381,175.353112,141.83644,107.46714,78.966503,42.258492,70.737173,119.064497,82.518082,-38.780296,-16.986872,45.921309,106.381532,65.019122,-101.373308,-164.516328,-156.401226,-123.532806,-91.49743,-78.294014,-81.184846,-94.343844,-118.514836,-175.363664,-176.453612,-179.15086,-181.061398,-150.020069,-50.897413,-15.717105,-82.793044,-144.352063,-134.389716,-99.265248,-143.650806,-239.108067,-232.827816,-144.59395,-115.408521,-110.225062,-100.262697,-78.733211,-121.786857,-125.972145,-71.544583,-66.508383,-144.103195,-172.245832,-150.75377,-157.22328,-301.636517,-438.046242,-415.698845,-215.289033,-122.933944,-110.990467,-171.563383,-236.849687,-102.964128,-45.761394,-69.541936,-99.964078,-109.665453,-98.416945,-51.784208,-20.082951,41.727867,41.739519,12.924655,-42.153747,-67.192061,-117.059135,-134.830053,-163.09647,-165.420912,-147.370873,-94.578941,-64.306461,-50.384285,-94.894236,-204.445417,-219.612121,-164.72197,-109.242464,-132.233147,-230.356412,-233.427403,-110.820306,-52.525359,-74.756409,-194.038781,-235.617594,-246.30554,-236.687973,-273.391093,-308.725486,-331.558796,-305.160576,-193.200936,-124.371535,-142.947885,-203.388875,-217.047875,-255.396315,-283.60631,-280.349102,-191.256612,-138.365419,-29.582169,12.969106,59.813434,88.351097,149.23491,134.960993,42.554735,0.47027,-11.467068,23.584708,91.02648,175.557689,132.644024,-9.091592,-67.932341,-92.176464,-100.638165,-40.708958,56.492357,4.86363,-194.560729,-255.488256,-256.814093,-207.469145,-159.88814,30.44638,100.162417,31.450227,-40.544778,-46.467949,108.42765,177.940001,211.289676,204.148163,196.536938,177.791781,126.340853,99.463495,3.743412,-92.650324,-84.083314,27.145532,68.231011,42.058128,-13.524837,-124.081449,-102.848193,-57.963704,23.788824,67.496068,127.498627,118.203378,72.476051,57.147909,35.668631,41.309189,69.227836,179.167324,218.767889,178.193853,122.246591,25.10217,24.339199,76.624494,213.351729,253.59512,256.110774,231.605764,121.81274,47.803483:right
80.519359,100.200394,74.049407,-4.572082,-17.58634,32.688974,79.146067,107.970182,-14.407444,-91.463511,-115.838792,-24.280528,231.418631,288.258889,186.333277,88.350406,-26.577332,69.573204,155.494501,262.188173,280.287214,271.929761,232.693563,101.46381,85.680997,128.147387,152.531595,108.626175,3.533578,-4.335799,14.058375,-28.340212,-140.578824,-58.095215,-1.650253,8.935812,-10.48907,-41.268515,-57.480378,-142.584484,-204.4176,-184.174504,-170.633394,-187.596168,-126.886389,-60.792811,-17.337208,-58.411059,-155.29729,-127.450725,-76.045065,-0.054604,7.537229,59.89891,123.746761,149.104502,7.919533,-36.277462,4.373517,81.517798,209.264807,193.218055,33.387851,-43.890493,-75.706847,5.882557,19.069933,-11.404881,-11.525491,21.914945,23.466113,-58.858423,-42.158012,62.417051,221.746792,211.749084,122.685148,81.754441,-16.308952,-62.224227,-74.683484,-27.97481,6.764425,141.049788,206.648179,227.573278,211.582385,197.408473,149.978547,112.997293,77.373684,88.047881,90.079517,72.008155,46.073704,24.477612,-42.207836,-16.984434,26.777182,77.976636,71.697069,54.026055,64.909447,60.685074,35.413169,41.486848,-9.046546,-64.974437,-140.432201,-153.946026,-142.343492,-124.434639,-94.73144,-80.931982,-84.902881,-141.890104,-177.649533,-143.759071,-88.663976,-99.380921,-244.878478,-296.652578,-342.816844,-334.866832,-297.372085,-292.710681,-281.170795,-264.181921,-211.185271,-84.316053,0.052598,149.246554,172.257381,80.396022,27.365444,-9.053086,-36.137327,-39.916751,23.520146,89.912148,228.978,254.437454,157.216232,60.519383,-50.711785,-2.185494,20.759356,35.778215,14.039857,-120.6833,-203.120887,-328.599136,-388.003439,-409.53694,-414.317147,-372.999413,-255.952081,-228.335267,-311.541205,-410.549341,-559.910879,-445.16329,-308.578322,-102.623359,-92.681628,-194.738933,-229.219911,-189.199346,-111.156367,-71.549882,41.827743,105.779911,184.765557,198.407768,216.235785,205.753285,113.477749,50.436172,57.959264,105.001108,106.789438,68.076939,59.126327,22.438111,-38.56373,-30.941963,48.082549,90.146313,135.167263,125.78613,30.719163,-60.546881,-232.849154,-170.779081,-78.379401,54.282004,77.667713,68.72162,50.190658,10.011355,-25.121302,-32.967337,-18.696306,-19.544909,-97.527263,-151.522102,-225.182738,-244.506321,-220.326858,-162.445393,-150.838401,-143.468022,-151.157359,-209.502323,-263.549462,-322.366099,-129.428621,-36.145978,-58.086242,-99.555304,-62.161226,-1.326085,47.802504,5.82023,-114.121819,-169.806233,-185.635081,-180.13553,-138.122664,4.975023,52.011751,10.309442,-47.253863,-33.755158,3.978736,-2.423174,-41.321152,-32.317064,52.021898,65.698881,-16.325808,-18.344426,35.354197,96.1427,88.91555,109.197044,148.602909,175.407113,193.395624,267.013626,424.676195,434.614216,392.46888,412.241198,440.261077,374.716994,184.052687,127.748505,140.210164,173.469546,162.525424,97.516915,105.450709,241.45968,341.822523,341.66233,342.642559,373.56886,412.137758,370.889733,238.184429,201.785879,181.589837,200.685147,226.734725,237.703829,195.382526,61.835308,1.084202,-88.959281,-48.323008,28.799367,192.343588,250.542994,256.325815,203.469686,108.823921,94.484291,112.417223,128.500774,110.78079,70.249967,70.244287,68.808897,50.519352,32.385915,80.674447,93.829045,54.880431,27.321204,16.199551,42.178469,109.655928,100.623052,-0.40321,-24.151528,15.968544,148.159047,196.459811,155.007511,81.713186,-55.941416,-169.634356,-224.44671,-218.207001,-135.163836,-8.154254,-28.180357,-122.549867,-149.937253,-114.511183,51.227441,120.479209,120.837559,56.743238,-80.529659,-115.813349,-148.518083,-114.157884,-54.522164,43.249058,38.227736,-28.494387,-37.929331,39.212635,93.534146,144.054249,162.408933,202.357464,335.586879,384.931583,417.344846,413.71679,325.530178,193.267115,156.934198,128.429036,127.94498,150.097697,160.482161,98.870029,32.627498,-3.671409,104.282684,147.527752,177.724629,168.272148,119.630988,102.124555,116.751922,219.573602,287.718537,348.633012,328.087144,264.920671,242.408484,213.782491,194.345771,136.576431,152.698443,205.019081,320.29463,330.198024,259.475638,227.59413,197.506551,184.554738,171.897167,107.723149,76.602774,9.118259,-45.875282,-120.924825,-111.855805,-80.699708,-127.637027,-153.353544,-123.097904,-90.264666,-97.85088,-135.494637,-213.382958,-218.204743,-188.202245,-119.903762,-92.04125,-52.443825,-46.436518,-99.577081,-173.460598:21.98848,72.799584,91.410156,46.420215,-37.633485,-225.979887,-239.34219,-94.115196,11.085256,-19.714059,-102.939409,-59.564784,137.373893,181.64079,69.747547,-20.969931,-89.32208,-10.72856,31.886486,91.692104,110.272845,104.281152,79.219755,22.473457,50.223856,92.511333,144.818033,126.968504,32.641702,8.633888,36.761232,40.691512,15.322541,8.197278,10.402108,36.2668,46.497365,23.448207,-7.18823,-101.693723,-147.214176,-116.888436,-49.586862,-40.461285,-3.55891,39.071129,77.519539,34.565906,-94.436525,-93.559546,-28.845151,122.519222,166.404019,214.484067,244.00292,235.662198,121.24258,96.62374,162.939079,222.288033,270.389595,232.774004,89.339092,17.19323,-60.222677,5.054827,58.447908,129.347249,140.761042,93.487762,42.620629,-57.989892,-55.050949,3.416314,139.811627,173.367829,138.936145,105.022615,34.480556,-23.934429,-87.024209,24.340518,98.520378,181.973869,170.700486,94.812502,71.767833,44.871017,6.928139,10.435739,57.306299,57.653444,-11.014039,-13.675547,74.725119,87.607559,38.036745,115.998908,168.1323,118.47897,62.623497,65.260109,87.410488,-4.937991,-109.339549,-90.99598,-14.497008,8.389427,19.30387,17.944459,19.552078,22.669127,54.139295,63.529255,37.370385,-34.572533,-59.013342,-63.990639,-56.343142,-73.31911,-95.752876,-103.850157,-168.659045,-197.343999,-212.918649,-241.0886,-354.993918,-383.702468,-259.845734,-44.439723,22.266702,72.088499,49.369859,-75.414757,-129.768974,-159.882081,-105.802145,-46.06797,51.883652,45.900757,35.553224,78.05935,93.820807,6.325002,-195.972657,-185.364692,-116.187689,-4.303739,-37.982463,-267.18063,-350.244611,-341.457479,-314.170198,-335.947028,-329.094764,-266.562632,-144.496294,-134.360719,-220.992816,-296.770255,-364.642115,-267.863359,-216.892975,-190.427157,-210.446465,-254.505388,-248.17743,-196.089926,-167.481818,-144.945335,-52.860234,5.902954,74.679417,59.999414,-3.82506,-33.456805,-91.426063,-57.325223,-1.746976,113.282405,129.016031,45.241617,-17.539044,-96.68571,-64.996283,-40.235247,-3.405563,44.409626,114.399399,64.985277,-115.98302,-178.422985,-223.061288,-173.526389,-115.692659,27.954626,75.309756,59.619003,18.768878,-50.989884,-21.311584,18.64905,37.543154,2.779971,-147.817197,-242.625553,-367.638002,-369.375901,-264.735778,-180.941402,-175.982706,-190.625176,-192.17025,-141.781807,-125.147291,-209.963789,-268.366236,-253.646498,-180.972051,-129.730912,-43.696978,-15.720791,-34.53973,-96.874817,-188.635009,-120.596234,-70.623663,-38.790163,-61.702995,-82.738523,-78.487424,-145.606024,-134.513116,-49.315007,90.481739,74.660519,-93.331138,-158.365957,-147.419844,-124.846407,-121.410319,-79.215102,-38.211716,8.42299,-3.367163,-12.160091,22.690704,57.963141,63.137645,132.355678,307.174704,344.085116,344.695188,339.72522,313.134713,290.486272,245.55169,201.817872,168.553639,120.340744,125.679698,154.576813,168.188751,245.865626,379.509426,410.248082,388.371082,362.827966,289.123179,253.52764,237.963164,253.280964,274.634982,276.198762,305.541663,361.567451,319.568721,138.600745,69.302734,8.726335,35.395853,87.562251,225.445459,267.102014,229.402589,178.879791,103.184146,87.388834,141.238712,208.495928,196.498504,139.674845,119.290236,102.784805,82.422047,-10.431436,30.461549,111.625393,187.639198,173.953435,125.844433,89.92687,0.235032,-34.220715,-10.659362,133.820775,217.91872,343.668688,349.791874,249.179231,190.739861,113.011559,9.122446,-50.258605,-42.950381,27.703396,57.102977,-15.156319,-90.46262,-69.461181,-46.740597,-12.196155,8.913621,-34.505702,-91.005674,-159.390946,-163.728687,-180.954295,-169.299236,-140.281282,-75.564799,-57.742351,-84.424481,-91.441775,-6.274339,40.985928,54.445639,41.93048,62.024349,190.497463,254.356348,281.366874,267.171533,214.567579,151.854753,148.112661,164.7755,156.747955,147.438726,168.179593,158.31587,114.79826,98.535648,158.313847,178.700284,196.573283,197.095786,198.763268,198.175342,176.913551,179.778303,201.310918,259.445872,288.935927,289.005379,247.889118,154.320206,124.19923,121.354035,244.791873,334.612487,418.244557,379.466042,261.111683,226.069119,196.312987,216.242022,233.235618,240.47565,221.794654,100.159886,7.257289,-96.387251,-80.218488,-33.555801,-62.655862,-62.699884,18.941724,47.688694,-40.309807,-126.243175,-237.191977,-214.021013,-177.175086,-118.169667,-87.72634,-32.313096,-32.805955,-113.035552,-176.107731:66.12954,120.977178,147.253857,62.405349,-46.944163,-158.247586,-121.349204,-24.045822,9.275696,2.257001,15.783883,58.207472,94.257078,79.348621,110.927502,134.279919,67.757382,7.034508,42.360351,168.151081,175.786552,47.018072,-6.408684,-7.204388,63.099554,117.272699,210.59013,213.44737,131.192174,84.865863,50.028096,63.470955,130.969666,167.133136,142.671552,45.852671,17.694609,22.325743,25.770693,-11.49912,-58.956353,-43.293337,91.980521,159.946565,199.607741,191.581294,143.58128,83.96591,-16.606053,57.929926,129.76144,233.582497,245.561916,226.789117,234.404102,264.466905,224.34225,213.839327,283.570187,337.703513,391.618013,363.064264,207.29977,143.242399,162.515752,218.379934,207.053056,199.416169,201.314828,103.671979,24.060172,-44.758256,25.307021,52.95057,64.433333,70.845505,50.445695,10.961354,-71.421121,-87.220626,-54.450721,-9.410963,13.150373,54.725387,35.266493,-73.393268,-119.577812,-186.801864,-169.210601,-92.809795,64.065642,68.856182,-24.962153,-44.094938,-13.008672,-5.196314,43.593694,175.585869,217.425251,212.689671,191.913117,150.317828,134.074952,105.106273,92.1373,92.601923,89.581827,78.093353,40.75715,32.92199,56.434796,91.701743,196.634187,176.769109,105.33153,19.96113,39.444863,119.70543,135.510968,46.908286,-89.713699,-115.994258,-136.566409,-153.705993,-199.112924,-235.710133,-311.658811,-306.927664,-180.061778,-34.900725,24.938289,108.907008,82.664774,-108.971147,-185.599035,-171.438846,-62.760027,-27.47329,-18.059071,-40.283667,-53.622053,-31.859875,-64.570934,-121.506115,-169.673883,-145.278317,-124.691265,-86.931799,-119.969579,-294.865624,-358.410902,-292.017712,-178.32819,-195.048199,-205.852224,-141.197643,-18.45681,-20.865026,-128.756382,-193.482107,-266.79926,-228.47923,-172.139009,-97.968446,-123.985514,-181.938417,-149.258744,-82.416874,-122.935744,-103.923386,28.087237,62.225196,-24.296662,-99.289888,-169.416613,-153.995554,-70.191211,-12.625358,7.987606,88.470357,117.882261,62.88674,-17.498348,-166.169435,-116.403866,-34.851513,110.271677,153.124915,111.549253,15.970826,-218.558972,-294.714901,-306.556281,-224.345292,-174.651407,-44.032116,14.615631,8.229436,-48.988229,-126.798624,-117.556542,-119.022984,-111.24646,-97.875554,-186.984216,-296.070961,-454.647967,-451.305863,-313.424821,-135.504061,-78.84202,-106.73997,-181.701041,-306.023548,-317.041381,-282.8336,-213.331895,-177.575091,-126.546982,-106.315174,-82.577855,-67.491819,-46.462259,-65.492879,-111.380652,-92.833375,-59.108215,-10.44265,-32.755974,-91.895218,-98.912631,-140.222199,-151.986124,-107.978486,-11.674347,-6.186802,-110.35521,-185.859736,-269.839145,-277.725158,-249.565712,-187.30861,-179.018683,-187.589254,-173.513016,-133.355805,-137.079225,-162.450989,-68.693334,20.966158,170.071818,213.935372,242.824135,231.116534,177.711757,138.854825,60.795127,59.843261,87.779529,151.021681,153.994221,45.839558,-5.765128,64.874439,229.972834,284.786234,380.442854,417.519564,374.471155,302.023289,192.502388,180.235093,196.486195,257.881575,316.162872,355.27617,281.025185,57.494012,-20.815613,-40.910493,68.598122,100.117762,131.302439,177.470932,226.929696,178.731695,38.836288,3.810985,67.245393,210.304379,217.931872,121.103108,86.570218,92.071125,88.038869,31.835371,6.52087,5.698979,46.088654,101.543288,155.029692,114.151007,20.781277,1.842376,-24.726297,-13.479207,41.433851,212.48929,273.536139,272.342364,236.218651,173.086021,92.749532,35.087728,21.04762,81.674217,142.729054,95.403546,-52.947995,-88.784699,-12.752016,79.401615,54.621642,-72.671424,-123.425706,-166.71998,-168.852308,-184.299199,-260.450886,-277.906037,-151.696403,-63.441299,-59.889313,-115.430924,-177.080138,-178.105724,-147.582439,-71.380162,-1.233224,163.114575,204.445909,165.852097,110.139862,22.601205,109.166191,180.663574,179.363014,121.722932,63.710649,56.612347,20.028918,45.063428,235.581504,332.871673,316.651865,272.026797,246.380747,196.969226,182.371332,165.268732,191.251918,215.245147,231.814871,216.280221,177.324947,176.60548,179.481472,134.933376,-6.616214,56.034029,169.179214,328.167448,307.272514,146.599997,79.298209,56.079901,146.874943,172.307321,163.935367,169.08262,156.248739,89.275352,-91.579965,-128.780324,-85.954458,-87.196299,-127.221193,-193.230366,-197.424247,-165.619191,-150.885092,-143.254059,-51.912534,9.433346,14.552324,-27.681686,-67.534826,-51.553342,-29.153677,-51.137083:151.16909,192.391368,196.364614,138.170567,97.829561,86.088328,124.399561,195.066923,149.62477,81.5641,7.627571,59.813847,235.73384,273.085999,210.959388,153.835048,89.858772,99.178798,89.186534,88.676592,125.770353,186.5029,172.904488,76.2209,29.8285,50.583756,110.193003,118.863088,82.4121,64.472951,33.143758,0.552759,-6.668507,45.460741,33.247293,19.905257,47.625284,66.769095,36.224658,-49.469946,-79.697535,-71.889893,-48.628071,-20.752557,71.316954,107.581106,102.684653,60.984219,-3.587548,45.181129,102.907557,211.569286,223.792441,201.929778,208.966202,172.931176,33.869142,11.321175,123.784825,220.069032,357.340851,367.472585,277.700872,212.304565,156.670792,146.502879,134.604577,153.625804,169.970451,131.031549,68.913867,-90.533752,-106.873548,-44.906456,67.554944,88.878081,48.087787,-4.877214,-117.735878,-160.680118,-183.70892,-191.543885,-192.090768,-79.708111,1.331771,24.974298,-15.260684,-76.636672,-79.542968,-54.212156,5.10342,11.550995,-47.840151,-81.287912,-84.200154,-69.818635,-1.769501,163.573174,229.801792,244.414547,227.51872,210.09725,183.008629,23.846016,-69.549104,-23.451416,79.149796,86.043838,50.636325,26.616015,3.40434,-2.568634,-25.792448,-42.408749,-43.706474,-76.55574,-123.091198,-209.575419,-225.745934,-255.274318,-298.12509,-308.008774,-341.226617,-358.80312,-330.017771,-291.308265,-272.084079,-299.87064,-252.739046,-31.625569,60.239015,171.145511,186.222621,110.232832,57.66029,12.087593,30.253835,52.366956,118.25747,157.014986,203.504205,175.714501,-17.038308,-146.083462,-285.892597,-178.112787,-90.221598,8.982849,-18.074688,-200.813999,-300.560121,-385.050192,-351.565867,-345.914531,-321.222543,-265.608133,-165.65416,-166.456287,-203.890842,-218.704008,-244.209454,-197.240545,-133.834901,-21.202597,-35.748961,-188.060687,-226.302565,-132.48395,-15.216017,25.025326,100.776217,126.451516,145.66793,152.275678,150.151027,115.92224,25.873505,5.814269,5.537898,25.725899,39.169705,28.007761,-0.537488,-116.865859,-161.54509,-115.524806,22.425701,85.267519,91.009576,1.717752,-217.001567,-269.776341,-252.227997,-189.326613,-148.043763,-23.014435,14.830894,-64.333277,-132.82937,-171.694113,-110.130142,-86.866592,-52.04037,-29.48461,-51.256253,-105.138475,-221.169278,-264.570085,-255.449482,-129.516711,-85.891928,-118.13028,-173.463301,-238.01749,-230.446759,-218.843952,-208.916603,-168.21244,-75.527361,-55.997817,-33.202453,-5.991778,13.661273,-23.47394,-106.242948,-112.826705,-113.392674,-124.39335,-113.000783,-37.73985,-20.570876,-143.26669,-242.332754,-204.506573,-100.930573,-87.979813,-108.557492,-108.52907,-105.81178,-148.738027,-287.465316,-289.49665,-247.793184,-190.443398,-178.370988,-122.688988,-90.621801,-73.12291,-7.576078,61.850719,191.212687,242.52008,330.454478,344.623954,256.417163,161.024811,10.778902,72.803476,128.210308,142.757066,115.011537,83.009838,97.73387,169.201342,263.906799,311.283176,383.833637,395.867653,379.210618,369.936658,327.15545,278.756876,203.259824,247.055109,278.708335,261.030956,204.496576,54.919143,-6.092402,-29.522725,89.539846,147.123831,209.34295,243.544279,286.683101,254.48233,124.934045,74.902416,56.367642,127.582268,174.045724,235.525855,214.682382,41.485618,-57.630156,-113.657768,5.058627,52.101577,51.778135,34.623729,27.327356,35.015646,85.964576,118.242151,98.473471,5.941614,25.007972,221.769769,305.962107,295.235459,223.624447,13.952653,-190.17892,-225.213188,-101.510269,13.322012,124.318278,72.331898,-113.725444,-165.337135,-108.634027,45.388494,92.950577,78.800937,32.047223,-95.30112,-168.642378,-289.192872,-270.413521,-224.920918,-142.542019,-113.730015,-123.482343,-162.065284,-180.457941,-131.098095,-20.05275,37.910014,84.00136,224.969065,262.494829,222.283735,198.261449,152.193006,90.893122,89.54559,99.154072,84.31875,43.014799,37.08001,28.897901,12.420393,6.437703,52.223632,78.221297,151.585028,177.811687,139.380095,98.661997,73.668984,143.96284,186.43208,239.758218,254.969352,253.063598,233.806678,168.560916,111.633388,42.059536,144.891981,197.378149,217.307674,192.023213,119.266869,103.137911,109.191543,75.716507,34.506873,-17.113754,-0.994114,30.920153,-7.70951,-147.551001,-182.1831,-167.363827,-205.607073,-227.661441,-170.767072,-138.95708,-182.481577,-210.854987,-173.613976,-85.843386,-52.842998,-32.985293,-39.896881,-38.246749,-31.910455,-49.093771,-75.506719:164.86982,183.408909,185.20763,215.024636,199.890184,51.586432,-14.42308,-24.084181,39.750668,65.587192,143.145891,200.974557,272.971032,286.196069,277.419385,227.278291,105.204914,130.192986,170.943502,208.969603,200.180787,146.240674,102.991759,-35.30424,-89.592895,-31.149116,149.01736,208.089395,184.398348,118.957311,-15.267904,-52.235941,-42.150819,4.389138,30.219524,84.213475,88.192464,35.156124,-11.069222,-104.493709,-127.381603,-93.660119,35.369902,97.154688,195.978015,228.895558,185.663843,107.853175,-25.814828,-15.21574,49.340813,213.810339,251.666539,206.680765,154.970621,48.961937,43.361316,87.446785,194.837292,239.801444,319.483228,354.593357,338.691086,283.494442,213.010663,236.048357,259.978084,293.054055,258.452975,82.406854,-10.330969,-121.491731,-50.995447,31.356323,146.417593,134.160234,-34.231527,-124.374058,-177.971491,-146.626381,-39.482296,1.205914,-5.008186,-35.134032,-84.254651,-246.539408,-305.510773,-328.221383,-219.171664,-120.576367,11.599519,4.756082,-76.437133,-92.132184,-65.642807,-61.105778,1.454246,218.41846,310.954779,309.868203,244.080662,156.846163,132.060414,1.265574,-86.865375,-42.076654,103.853467,143.767301,117.703833,67.248687,-22.019941,-43.706928,-58.616059,-82.04701,-105.756734,-164.358231,-189.192323,-219.590291,-239.745787,-302.13941,-324.421191,-319.430237,-285.288036,-246.971159,-186.508716,-185.997399,-226.7514,-230.952247,-113.886038,-2.442736,19.411731,112.210272,156.307986,122.231568,62.646535,-23.722408,6.189431,49.713268,129.865755,150.867807,131.91777,97.086108,-33.061922,-124.429534,-224.911316,-118.307429,-29.584138,74.892755,38.711717,-146.802125,-202.768471,-160.444763,-120.426824,-148.470982,-121.863052,-32.193838,70.689038,41.075169,-26.973846,-36.880138,-58.720373,-107.164163,-98.118532,-17.233327,-20.912263,-119.314716,-137.020656,-48.380314,55.332775,61.981371,59.813886,92.656395,136.322736,101.64682,-1.842147,-19.926157,8.418334,9.439772,9.331929,104.555168,164.677687,135.733464,33.187471,-173.773664,-99.104696,12.038218,169.854885,202.28691,163.742375,72.240544,-188.488328,-279.027211,-248.405744,-109.462615,-71.492417,-29.680319,-7.08366,5.282023,-21.529872,-108.164623,-150.049134,-137.300908,-23.741678,49.127141,44.916916,-42.72528,-217.368713,-241.967245,-121.356709,58.425628,86.687932,0.557532,-66.187638,-126.082612,-131.621249,-186.818657,-189.624954,-120.62598,54.641421,98.822094,77.522028,61.679928,100.008315,124.473628,78.392986,-41.152852,-54.657855,18.842904,41.085783,-2.166499,-47.051511,-144.537607,-142.519052,-79.693197,55.399832,63.340303,-66.814165,-142.973248,-188.845816,-201.714675,-299.247443,-346.623222,-333.191335,-295.624217,-278.450407,-219.51747,-186.317183,-146.546899,-75.54731,-6.729478,153.00258,205.394273,213.07103,181.418394,104.734033,80.197516,78.914492,113.349082,134.021586,145.897996,121.607833,66.861193,63.399262,117.690168,223.252898,275.8231,382.24985,426.334371,431.61611,382.700145,243.805222,220.353591,328.149102,399.300853,389.267425,391.795997,377.518805,225.367395,116.668041,21.387748,190.98367,273.56995,309.623106,306.889755,258.275673,190.019137,55.624734,41.244815,127.797297,226.615785,249.579472,261.106847,234.960679,90.734061,3.340377,-89.557946,-14.838551,24.767408,73.316538,139.120658,293.080756,302.258958,182.2978,116.339505,80.228499,87.874486,101.539326,231.690865,312.543808,334.363904,269.486882,113.262599,45.255934,65.83791,205.081824,270.405947,230.249289,129.240458,-75.969379,-119.264338,-47.167347,33.869951,40.593287,48.523931,34.176118,-69.745615,-136.196814,-242.098385,-335.460817,-378.609982,-348.248869,-275.401171,-224.794377,-264.503361,-298.42579,-286.813292,-301.627807,-269.109615,-175.658686,67.84873,132.407132,113.368611,65.945669,-21.74869,38.222399,106.310004,109.721392,27.091325,-79.271899,-57.454673,-53.088873,-83.40814,-3.340807,150.168328,168.693539,95.729393,29.510875,-50.601458,-47.463785,2.309758,25.66348,19.90945,58.875543,96.36845,92.264335,44.317782,-64.849359,-116.177996,-188.959656,-106.360703,-8.195748,148.800222,162.791154,81.967559,7.19,-95.369089,25.88101,115.135597,169.101497,124.041279,-44.125966,-135.186096,-260.825648,-277.712158,-230.916692,-202.491411,-206.976745,-205.348022,-215.028823,-280.47863,-305.892607,-228.084401,40.557486,119.264886,-5.352239,-88.320718,-46.854196,8.106469,-9.000172,-41.704516:122.817127,175.506979,171.676645,104.627319,88.68656,115.225111,143.46942,170.288985,73.044642,8.137455,42.889699,148.626605,279.749363,256.293627,189.044718,167.883161,128.143704,185.922425,242.292365,352.979625,380.512853,300.898848,213.220929,38.304354,-61.06061,-46.756934,72.652038,108.684026,38.748069,-38.425663,-167.266094,-198.824095,-216.859928,-143.462105,-66.236315,48.528402,47.957216,-40.160121,-72.107323,-74.861896,-144.130591,-198.435299,-246.262785,-217.38465,-64.526367,8.734951,28.555108,-7.357911,-37.477414,-15.781075,-17.008513,-24.905995,-27.58735,-19.679156,-5.688093,-44.930174,-153.829067,-159.130915,-11.068083,110.162547,245.143515,215.864082,113.646451,108.31254,143.06685,94.412604,49.528922,-3.705941,-15.021992,-69.305751,-113.985694,-188.500035,-116.702123,-28.532399,101.948867,124.347713,81.628123,8.002189,-165.170971,-212.396717,-159.643696,-3.140189,65.761801,165.790023,169.910309,74.587565,35.482647,31.7121,68.544187,96.268748,127.616602,116.164872,47.117952,6.425891,-45.192752,-49.829542,11.821219,153.235601,203.983356,180.444445,123.333021,82.026933,132.313745,222.324532,166.997738,129.744673,76.70592,57.413574,14.430695,-23.34254,-71.842308,-65.33164,-63.818983,-116.290939,-145.078692,-175.00828,-180.446285,-182.150435,-173.947465,-174.031128,-225.079846,-260.675059,-332.460563,-327.142645,-220.147195,-181.613496,-187.359341,-190.68169,-138.991472,-13.643195,55.638354,174.640582,226.049201,243.883318,208.711224,156.975152,158.360176,157.290017,155.508444,183.621204,281.191095,298.981624,225.579692,164.319593,52.939257,7.313993,33.240144,108.931189,86.069264,-59.288855,-122.48917,-223.131161,-308.140161,-319.66552,-283.707517,-248.434897,-180.867214,-177.905576,-269.602868,-334.80224,-356.246041,-206.817515,-125.342031,-27.855679,-22.70011,-30.318418,19.107428,166.303128,206.581694,221.117821,304.606054,375.783191,526.399743,554.659857,454.159245,351.966866,178.928905,105.077114,86.760815,86.959428,80.153353,5.888872,-29.01054,-56.016593,2.388602,59.093494,120.41839,123.850079,125.956692,111.012383,5.341043,-79.291681,-206.909835,-155.139618,-101.441647,-31.999933,-16.279838,-67.389048,-123.661671,-185.144786,-145.886019,-97.891485,-7.351508,14.956791,33.411324,21.629971,-84.065308,-141.231746,-153.697827,-116.625718,-109.373965,-77.482877,-65.617246,-153.385933,-236.280912,-294.939294,-120.730899,-41.977468,-59.520607,-100.863608,-77.630735,-14.267475,80.187184,68.627044,-19.006934,-98.278488,-140.931068,-144.707906,-75.453457,66.67324,65.472435,-60.616809,-83.954928,-51.93303,-29.761666,-33.715284,-42.185202,-33.20192,33.294559,50.179435,-7.448078,-46.385002,-43.723893,-39.076057,-15.257305,87.190334,120.670259,93.254917,76.523621,102.178672,207.212525,293.162187,442.26289,432.339259,208.043466,66.078265,-58.589906,17.149353,41.949097,27.337581,14.423459,-28.475736,-41.824865,25.631987,168.913647,217.076852,229.790769,227.095416,258.22086,257.885608,143.806504,62.442153,20.843952,109.013138,110.832154,10.518559,-49.80193,-164.196973,-212.388521,-223.548216,-58.252466,38.04749,114.398363,129.768614,167.731831,143.5177,11.401822,-30.36263,53.58849,140.308096,98.95126,3.004455,-7.712413,-33.26938,-55.405851,-43.437164,35.006884,63.749162,41.910927,-8.511644,-95.746687,-89.679484,-24.817912,-33.192213,-135.134998,-174.491634,-140.438144,8.788569,73.643694,57.386348,-10.144354,-154.317098,-301.565077,-365.818384,-306.060999,-171.143929,45.79718,47.902032,-77.688674,-132.838354,-83.226871,121.824615,164.383539,96.650426,39.371086,-95.658169,-156.854694,-202.994272,-184.148272,-169.081658,-103.528725,-59.313781,-48.577305,-78.2789,-75.293421,-43.108731,-1.423301,64.926695,134.957444,290.73533,327.524203,301.290162,280.719479,231.707391,145.0272,120.829344,86.52282,61.201663,69.189134,119.621677,167.769118,113.263755,-33.299289,-17.987792,37.317032,139.227317,166.549505,168.145678,159.908597,179.006596,255.707336,289.706569,312.057855,321.092871,387.109031,411.457166,319.955064,211.832073,76.414071,176.34203,215.381326,189.2375,179.462772,179.012663,157.685877,104.976583,132.867914,156.93585,141.433759,103.194812,8.868255,-44.572589,-105.264888,-87.502312,-19.091057,37.879627,76.748628,113.178278,65.603074,-99.62187,-141.421561,-85.636651,5.277474,28.714076,59.953125,75.992418,59.401808,16.967041,-53.149233,-55.310407:204.709283,268.908986,317.201361,325.979126,273.074181,137.687914,104.020492,112.316504,101.59088,85.116963,162.67033,270.710852,427.80952,413.178204,271.920992,192.793647,91.071196,144.856339,215.900455,318.670911,312.766888,226.072905,171.050066,19.993602,-60.637884,-11.255825,174.64136,226.004155,137.011821,40.826474,-115.568379,-168.068155,-203.331298,-98.019277,-19.203346,73.927915,62.794453,-49.099963,-121.128101,-212.17445,-167.566232,-115.229656,-38.686219,-17.558248,53.331792,106.90863,141.107899,87.254806,-39.341509,-4.047555,57.70359,150.642491,135.639259,8.739874,-43.045391,-92.086467,-92.6013,-48.058456,138.98769,241.103821,319.018853,291.558793,218.145186,189.071001,132.263623,137.247746,174.317708,237.658284,226.489923,72.675102,-55.700529,-260.524325,-170.370202,-49.811051,101.269628,97.145908,-21.558539,-98.64176,-227.353289,-266.642949,-236.101656,-147.327087,-104.766215,29.983899,62.830517,-85.994275,-202.773158,-324.54963,-255.706572,-167.463895,-2.35444,36.397865,28.795037,-3.461488,-128.307527,-187.020656,-117.690513,115.474157,202.924001,262.345139,250.062443,198.934677,151.616098,6.157263,-42.537168,-3.06382,101.93494,126.856997,58.558339,-21.415254,-134.724041,-149.382768,-157.946674,-174.600354,-192.148884,-252.254748,-285.007229,-321.569785,-329.620588,-387.008152,-460.349293,-444.960687,-343.431819,-307.303307,-260.763376,-230.772734,-211.910138,-220.109827,-138.363912,6.404097,63.674895,210.588866,260.292911,215.677561,175.575093,136.003716,113.10436,125.844097,193.351937,237.498325,293.859139,269.519419,101.213375,-3.864724,-120.185219,-65.041721,-7.09693,69.389113,51.354669,-57.760309,-109.790799,-201.589343,-277.32297,-268.569805,-114.605772,-20.146426,21.044307,-42.956785,-210.334295,-254.8771,-209.469622,-74.954411,-2.402211,134.394944,151.379867,48.707072,-13.206677,-59.108687,59.972377,166.127924,312.291916,327.17939,282.618622,240.29968,135.723744,85.544362,53.021485,93.988814,100.62847,84.663253,70.567638,3.964029,-40.348769,-104.744869,-78.464653,-23.76129,142.784177,229.521092,261.930763,181.467432,-54.144417,-134.713761,-131.610751,-59.816058,-47.805691,13.308775,63.741563,41.482956,-37.316495,-145.898189,-128.282452,-107.628417,-34.686679,12.919771,39.86871,8.917974,-97.27479,-151.598583,-167.665718,-86.137356,-64.404363,-44.262765,-25.123017,-21.764383,-53.731614,-131.391147,-123.997597,-69.59697,78.887244,120.925992,89.453956,60.470902,44.820073,34.115595,1.806472,-23.589123,-38.840316,-29.765383,-11.887708,-1.445418,-32.428012,-190.518711,-210.359053,-119.158932,34.537194,23.573865,-92.2436,-114.537426,-77.805556,-86.829326,-188.570323,-263.274585,-266.706642,-206.503143,-149.689926,-46.851628,-44.94367,-135.995751,-114.359556,-28.668964,177.901355,264.871454,336.094887,298.440705,149.075806,94.78522,68.145408,93.10738,114.767815,154.067889,138.021561,32.36362,4.291084,64.545989,199.800566,268.57581,384.128678,428.672377,443.85338,386.730211,183.09777,112.387746,178.103294,354.485819,401.970029,368.333238,283.018081,54.085706,-34.398114,-71.583572,52.801647,117.183723,203.142723,244.882127,256.954178,194.768256,25.403386,-18.31978,54.832402,221.030299,277.734478,322.465512,302.334507,153.766115,56.254867,-50.653435,4.437431,53.664103,121.55415,148.767087,212.849102,233.016239,203.261668,159.045461,103.681002,122.36019,141.432213,220.993592,265.066052,246.541903,174.539957,-33.723594,-197.010472,-205.353428,-42.796128,87.07025,187.32374,107.289031,-116.576338,-170.131333,-99.405278,77.386424,131.152955,120.61733,65.782944,-83.945593,-162.9175,-281.408156,-259.018792,-216.361435,-146.460561,-118.514548,-99.506501,-138.825527,-297.203308,-350.896182,-280.759206,-116.440692,-63.186026,24.157813,58.479943,93.656104,99.563507,62.916952,74.540429,117.481588,113.974663,48.049226,-77.704091,-98.000952,-112.878097,-142.571012,-181.296915,-60.478213,24.744461,70.059022,15.397526,-103.157418,-123.654184,-86.562964,66.698477,149.422466,201.025725,178.201285,119.064141,95.813403,12.998317,-64.418596,-180.483044,-136.286103,-86.139447,5.234508,20.180963,-43.382281,-97.330156,-121.715242,25.160881,85.102678,57.207983,11.518427,-40.25589,-70.466523,-191.763779,-245.973858,-247.082625,-161.44726,-116.316849,-61.961515,-75.670402,-157.897237,-182.48307,-140.222259,8.08191,78.033793,88.331297,42.471995,-36.945555,-48.186701,-20.893448,-6.737938:41.087152,60.139756,100.431308,97.572805,53.636195,31.108585,66.941251,135.723811,126.150894,82.146547,-1.152671,21.149161,184.398918,238.863956,177.515779,103.450706,11.292484,68.026339,108.545156,134.016042,137.044846,120.279392,65.163988,-101.017572,-131.133532,-95.294637,-60.905134,-79.221048,-165.596832,-215.277052,-264.183761,-261.074274,-224.58743,-156.312945,-138.473765,-150.948111,-159.460963,-157.175496,-145.288761,-168.899496,-299.614011,-359.047745,-399.401673,-365.723867,-208.364363,-130.926061,-58.632176,-53.838543,-54.422889,-99.172952,-136.06378,-164.393829,-172.457275,-206.384301,-192.539731,-179.542525,-337.087572,-395.742358,-337.520971,-255.526597,-106.885887,-67.728191,-48.082553,-47.831131,-40.182504,-70.583809,-125.420571,-246.756976,-267.8591,-240.400052,-227.064426,-230.005151,-157.880416,-81.260843,40.983046,73.94131,69.413668,17.979755,-93.123116,-108.609977,-70.594175,21.215739,87.557032,225.408106,278.381953,335.445853,343.432542,308.167829,205.421737,154.283512,100.082872,102.217873,126.851488,123.370744,77.721236,37.79608,-34.041734,66.183064,146.38138,199.113314,192.753091,180.920551,155.683559,71.75249,22.488004,1.056076,-56.369269,-72.608588,-82.644662,-103.465186,-158.749698,-165.144851,-151.802018,-149.031152,-139.20806,-95.958614,-85.748467,-95.277262,-101.383347,-110.267584,-45.832495,3.056792,23.059457,24.763939,55.451484,47.958392,14.15258,25.402851,110.129772,211.595506,258.608422,381.395143,432.980321,427.141102,392.926018,354.535855,374.613688,405.602249,452.201066,444.103095,416.543171,430.133967,473.552381,447.943197,287.243034,188.189524,200.975009,264.688372,263.384687,225.690751,235.651386,213.08543,81.969631,47.599,56.33668,76.077327,71.481707,33.003369,-44.104744,-68.627721,-94.620267,-79.508828,-61.739868,7.316036,46.595834,125.178313,187.648775,295.839854,286.254984,282.97706,363.830075,419.197455,487.639925,498.806604,428.20429,324.094869,113.877005,76.681611,69.859365,5.601738,-13.74724,38.710577,77.769722,78.914422,69.885103,101.177772,180.735127,208.307638,229.74478,231.744205,238.426051,218.508753,143.932819,133.553707,117.743461,47.733042,21.843017,-8.635008,-18.421931,-88.249122,-205.310105,-203.614646,-90.755857,-41.779761,-33.684716,-60.936882,-115.741094,-140.469851,-202.306836,-198.257894,-124.063214,84.773645,104.609921,-81.604707,-171.771847,-163.127932,30.265182,137.521321,239.505346,196.286847,-28.618053,-109.603394,-43.028944,42.374854,83.996016,-27.20118,-75.098976,-99.422711,-79.889538,-31.508278,-31.224177,-103.342387,-139.387573,-110.892959,-43.126013,-21.126168,30.851054,68.202615,109.772168,84.931053,-15.540716,-68.081505,-66.43223,14.461058,77.474446,117.115496,82.865521,-50.302911,-177.5137,-185.170414,-81.468489,1.323879,153.5308,197.718126,175.409246,104.065828,-62.336279,-88.846573,-51.031463,5.623681,-12.066759,-93.096782,-96.836185,-10.98602,83.453619,131.974104,181.33246,176.131769,151.367368,118.791613,-9.647784,-81.493474,-145.505828,-89.630566,-91.421475,-200.550089,-249.456911,-298.559466,-335.151714,-411.150531,-345.863041,-268.902109,-152.680057,-124.022241,-104.865065,-117.37536,-140.069847,-134.085965,-123.881842,-153.625857,-172.507936,-178.824183,-173.424033,-196.54241,-217.419522,-205.302046,-76.707258,-16.630798,-62.452316,-138.347289,-202.940986,-176.129843,-94.400473,-77.435234,-98.771845,-141.911297,-168.750284,-138.334865,-71.301006,-14.254099,-48.485971,-139.474613,-219.381334,-229.219329,-158.928154,-103.874654,-40.292373,-42.977515,-79.928118,-96.964733,-33.104453,144.18687,172.280543,78.267403,17.26401,-56.962539,-45.824262,63.965326,144.961047,150.056876,138.450102,147.9863,180.346126,186.010127,177.722015,165.097971,166.493093,244.162137,293.278325,390.586411,410.231347,342.155018,311.363358,336.80479,298.399885,231.219688,99.812738,74.428998,123.065372,158.742425,145.861011,83.813035,-82.933008,-141.277165,-108.514209,31.455858,97.047008,140.944311,138.185234,142.502725,165.099574,184.524818,248.510492,288.461563,308.088381,289.393134,251.795308,204.59502,61.725023,67.408968,108.780298,158.954308,186.351595,251.001788,246.510766,97.079936,-24.484941,-6.637372,56.237161,41.766739,-66.012791,-98.27497,-56.170129,-27.469839,-15.925771,-12.165868,0.556988,70.354447,116.035201,141.041558,103.579551,-19.660468,-66.188091,-46.779071,-29.934196,-42.049891,-36.822648,-14.078136,66.477414,106.96821:69.354417,26.94695,51.334403,116.683192,118.4667,87.044834,86.861128,95.794212,58.924743,38.908863,63.646851,120.177816,249.69234,271.655085,196.993349,129.941196,70.515594,207.105608,276.57601,289.189793,265.319035,258.976035,257.270318,168.432795,54.276421,44.000169,74.336019,71.652503,24.421411,5.118713,-46.99573,-102.018553,-182.860767,-116.765706,-65.443144,-1.14825,-1.626363,-66.37881,-98.874976,-161.166459,-270.100332,-322.222644,-376.313394,-357.94368,-207.914563,-119.05973,-40.142731,-60.441971,-98.072634,-46.133259,-48.68139,-152.070085,-206.047449,-210.115077,-170.399502,-192.193813,-281.263835,-241.306213,-73.770135,-15.595258,-0.738797,-43.802426,-146.516013,-158.28302,-82.280663,-22.633175,-50.470655,-142.43238,-163.387576,-162.769796,-153.858045,-117.02921,-11.937033,69.064139,186.027441,196.885129,144.361232,96.832666,-22.684348,-92.153315,-168.039789,-65.374421,32.2071,238.838258,307.502302,347.188987,353.622802,357.885415,261.599253,177.157643,97.182955,140.302598,198.206135,158.433051,59.211787,17.409173,-74.246643,-47.412003,-6.937363,5.990728,4.521261,77.058824,128.432752,113.804899,-25.532182,-82.389365,-173.669102,-207.073638,-232.590154,-244.937917,-283.586667,-294.862247,-294.012713,-260.890195,-227.840455,-159.197772,-144.274193,-111.56077,-86.226022,-90.300173,-106.053461,-92.427344,-87.080607,-83.109105,-71.127996,-92.367038,-141.055781,-136.150041,-56.468751,52.133382,93.812126,156.873546,174.716434,195.573416,214.790123,215.97218,136.147804,122.653238,237.386952,338.512978,434.30409,384.283043,191.616319,105.79934,37.263067,78.296802,92.059735,118.645976,128.755908,80.307307,37.347737,-64.376853,-168.032455,-191.276977,-202.977736,-192.74677,-132.018141,-115.609533,-180.794978,-249.986787,-336.679837,-222.479346,-124.062461,33.133406,71.308322,58.375252,35.287715,47.724666,148.23215,197.131774,267.927403,312.962482,410.781169,421.633674,346.649056,284.366196,158.272746,66.961707,31.239084,1.04464,-3.874094,-25.912433,-25.331413,-7.808326,38.338103,81.060129,154.930903,186.32536,270.422607,300.323055,218.209356,95.437022,-125.382296,-54.846432,35.125148,86.118005,52.468862,-3.048608,-22.264323,-114.233928,-211.160548,-213.783371,-173.413551,-165.715245,-204.539722,-225.434076,-233.718006,-253.254596,-312.078085,-260.792077,-211.502555,-150.458411,-150.322976,-211.596924,-245.137517,-242.812499,-109.559978,-36.367757,21.072982,20.414545,1.712776,-4.179958,6.925953,2.012861,-44.188527,-84.488549,-93.503032,-57.516667,-10.398864,68.492247,72.92627,6.946944,-43.067687,-28.178938,21.926341,36.496793,75.786527,123.367225,218.082879,213.683977,124.840646,97.268999,102.211643,112.525682,143.756552,257.80222,295.87552,236.753239,159.136898,208.388804,337.02048,325.528418,246.045001,251.459727,289.824292,260.363003,148.927455,122.544112,109.991169,89.100224,108.672187,172.425713,199.11367,219.044726,226.451883,246.660782,288.836776,309.482776,334.045665,308.843442,173.68026,94.933381,28.092377,82.631713,98.084603,62.742851,13.53457,-121.403005,-172.345329,-212.788266,-160.606364,-111.710271,-7.078598,49.684538,82.076426,32.182046,-85.544153,-104.772335,-62.50262,-1.350742,13.41471,27.160282,12.46448,-68.101716,-89.928913,-66.692637,-65.94203,-69.515731,-56.990021,-53.467737,-93.642804,-127.489047,-130.648774,-116.807516,-146.93391,-156.875625,-130.888742,-40.267468,-8.436733,-66.161071,-119.995927,-166.545535,-232.40496,-285.685472,-280.852673,-186.144564,6.852382,10.297984,-114.419734,-162.580885,-121.979657,36.973502,75.336875,25.230962,-16.031649,-71.080883,-79.762495,-57.729525,-1.777893,24.154753,72.434445,101.240923,106.701796,75.463906,52.624826,72.69199,139.858991,240.30371,285.068724,350.653906,355.344157,318.750928,301.486392,205.379048,55.813315,7.449534,-48.58686,-48.919607,-7.169054,2.149459,-45.174607,-105.543868,-213.776601,-194.156312,-149.003305,-35.589358,0.443858,-13.215526,-41.113574,-63.770316,-6.684638,32.539382,95.312024,130.193708,218.460861,250.283357,214.132474,136.112654,-15.26905,-1.859402,34.948177,93.340844,109.98525,98.080027,78.514419,35.989144,-10.336333,-42.027887,-132.279112,-151.188519,-155.624254,-196.00964,-250.544057,-200.916817,-66.128238,-120.507079,-184.267881,-174.586773,-112.57799,-57.915042,-92.473797,-189.869218,-177.702706,-147.885117,-111.656636,-96.832523,-95.712089,-116.766387,-143.947751,-153.730229:158.754724,189.9518,202.642686,206.146524,203.667816,221.705896,232.79349,189.837218,104.363046,78.318725,114.359733,188.714686,306.138715,259.707841,-1.200787,-99.60963,-65.342691,103.066729,133.621711,94.546817,94.082535,155.857863,145.987668,-9.888483,-121.928837,-108.42757,14.88932,81.870269,66.870871,-28.09155,-207.200144,-248.278846,-279.459613,-178.048477,-87.305583,-9.867804,-38.410934,-118.416153,-134.201116,-137.60789,-103.262667,-83.389906,-145.818285,-180.277753,-107.276623,-53.807385,-64.551909,-100.840347,-88.164928,20.161523,47.843044,11.301797,-43.775421,-134.103173,-134.19551,-147.808947,-252.719799,-268.890988,-170.425906,-104.971335,-51.173722,-46.935993,-21.412429,-26.374306,-99.315148,-147.557189,-150.567212,-97.793777,-51.717538,-21.638703,-54.785578,-192.964274,-210.147496,-129.379024,12.708304,35.417952,29.459968,2.04084,-71.791257,-101.789549,-118.936474,-47.498449,2.372765,80.673652,93.468984,85.246848,89.815937,98.271599,117.366726,151.394135,188.860335,171.247987,129.650246,113.572634,43.761703,-1.298687,13.777601,214.092515,275.067286,214.187193,159.211631,142.215085,163.064186,125.940563,33.821735,41.176284,103.883242,101.567532,26.254855,-30.095818,-120.343487,-133.86558,-134.154465,-159.181348,-177.282864,-181.767882,-181.115275,-217.688607,-238.294418,-268.30199,-288.960017,-272.221599,-191.087724,-145.803593,-71.38849,-44.051243,-19.477689,-17.717064,5.957863,110.230575,175.519114,242.852261,237.012564,211.6256,225.982621,279.136616,266.237463,258.222512,252.482038,228.946162,190.74936,196.601426,193.103731,179.292679,157.194286,97.997266,69.541245,129.568282,183.013141,124.579929,24.640027,-138.57607,-183.061403,-163.047567,-45.747434,36.736607,90.964076,34.536762,-83.639973,-130.272873,-247.762991,-175.105076,-60.905081,98.770596,117.649705,104.722435,105.993656,146.150682,236.74358,304.769444,379.246943,361.218253,294.334069,266.328638,240.389053,232.918368,202.737919,171.632792,144.640425,89.497992,69.01482,65.239958,100.156611,160.864944,105.652131,101.867415,185.74951,231.586001,283.237716,267.130241,108.091732,14.405651,-33.562348,-17.15424,-33.810662,-1.838305,44.835407,43.994441,-16.432519,-148.907215,-194.6612,-153.743432,-19.453334,8.167727,17.527084,33.418379,48.407979,13.947313,-139.447855,-176.792455,-116.602605,27.648639,67.795385,22.542161,-52.310239,-144.271256,-6.196736,99.365193,167.427661,105.796175,-48.860668,-69.910414,-9.444927,18.057582,11.572947,-11.695341,-19.262169,-39.0452,-56.016227,-85.226114,-82.513435,-84.113411,-120.464134,-128.135154,-118.21266,-105.164332,-87.84584,-75.222148,6.215937,41.836074,-1.258405,-129.929469,-178.270827,-169.33155,-106.513812,18.794361,26.872084,-45.534754,-82.772146,-81.569595,-71.458175,-29.429929,119.234706,151.733584,88.677102,36.202413,-57.113225,-100.770281,-85.527234,-17.122199,-16.533276,-108.661961,-136.319965,-58.888522,94.853406,141.216571,162.85497,177.787611,195.605113,164.534628,71.116982,46.143158,42.163426,13.910835,-26.690673,-85.051705,-91.506162,-130.708975,-165.525372,-209.289291,-145.122128,-75.650006,30.583476,60.063991,86.515422,67.343779,-13.331709,-49.33603,-67.318835,-45.779412,-57.2316,-87.384271,-85.617862,-72.867922,-72.140923,-69.896061,-28.107617,4.005665,32.086176,17.209402,-7.135943,23.494418,110.197547,81.146347,-50.464041,19.751827,89.43994,128.735877,90.152291,-33.094218,-65.445937,-63.480404,-137.550745,-189.980567,-197.569469,-157.214211,-98.083402,-113.090111,-200.860891,-229.293007,-135.15731,86.673906,133.357605,67.03046,18.459037,-54.095058,-99.011489,-158.562372,-69.871308,-36.429081,-73.541638,-70.381053,34.082759,62.152187,-29.730463,-93.334853,-73.201452,13.651795,7.383947,18.549326,56.277268,107.330182,121.527816,159.661586,231.454686,239.719889,92.741604,7.159749,10.028407,53.297617,15.088883,-66.042352,-158.293393,-84.325705,-39.413474,-4.604072,2.552541,42.611918,53.044028,38.894562,110.084929,165.533828,197.451286,180.482917,155.540037,143.771212,100.332696,72.473042,14.173646,-12.673683,-3.843716,69.175734,111.920884,135.03968,120.416092,60.331925,36.193508,56.782747,84.312607,68.341243,-30.931784,-100.377135,-160.24677,-125.837415,-38.513327,-8.414352,12.831898,75.290991,97.461167,88.246911,56.025381,22.519808,140.963565,207.052697,175.71611,99.959208,15.00319,22.7054,76.262166,87.461781:right
67.38999,168.053759,245.300468,356.699199,366.74676,344.741386,316.086461,238.765627,250.720224,296.309998,368.587957,357.153245,269.758998,224.260621,114.920753,63.477945,107.24165,276.154281,311.100863,252.692255,199.003792,154.514932,149.184372,48.187687,-72.753188,-75.810004,-29.916425,-20.833609,-18.292742,-5.26637,31.356673,24.861744,-33.969681,-23.944263,23.464161,134.680518,151.282862,92.887668,50.264707,-3.562516,-14.603591,-20.728654,-8.057567,10.110446,17.836787,8.008343,-36.722206,-74.581426,-128.632906,-108.124923,-84.56531,-89.566225,-127.17997,-234.534873,-303.617475,-403.331844,-365.657489,-330.799428,-245.001983,-186.201273,-65.104879,-14.212826,20.378852,0.974073,-39.311751,4.094029,43.838501,62.25497,43.763356,-7.941331,-62.456241,-202.226338,-197.717454,-140.313318,-52.853624,-27.874818,35.080283,49.836765,5.27624,-21.591728,17.635509,137.297323,166.053225,149.178407,137.693625,138.782706,119.608683,42.050878,8.967936,-4.053984,-37.000044,-48.197033,-81.334032,-98.851678,-109.144447,-102.448919,-49.272865,66.477791,113.820074,81.796082,-10.083728,-197.391443,-224.876929,-217.226937,-227.339349,-212.707773,-143.360583,-111.362553,-85.875537,-97.077758,-180.34373,-233.00959,-272.88481,-261.968894,-247.580945,-227.038719,-257.329703,-346.009511,-342.093796,-248.223172,-177.221348,-147.233854,-87.53557,-75.692385,-105.216586,-133.276142,-200.649389,-239.534508,-240.854171,-70.028056,82.177926,418.252531,494.044402,406.017756,327.21958,218.498472,137.475888,98.179167,53.42721,31.215235,-61.093124,-112.722788,-196.366227,-208.002394,-106.407007,49.356795,98.624283,134.834186,105.350345,-65.144396,-177.325679,-357.197022,-381.857205,-340.012092,-225.483655,-201.85314,-282.22367,-328.359549,-328.823339,-317.667701,-289.680945,-156.828299,-79.353726,7.872801,36.388716,64.189901,30.531242,-89.868225,-169.721168,-212.070275,-331.349068,-388.116928,-394.681761,-325.133766,-190.578292,-180.350867,-170.068329,-57.97892,9.27669,125.151339,174.274933,202.000328,150.036429,-1.48688,-0.993206,36.416306,90.392261,109.46832,155.664152,197.674527,260.993616,237.94207,129.230586,92.076314,137.583402,282.243358,305.659181,213.653282,134.061696,-8.110464,-54.626045,-51.188949,-23.119813,-1.688767,15.658806,-5.507115,-105.646772,-146.240433,-75.001295,75.827174,81.542016,-19.581442,-65.23168,-83.159397,-76.354355,-89.986789,-113.918789,-112.869867,-44.970811,-5.829521,-20.024793,-43.540638,-31.147521,-19.940941,-56.684755,-77.838176,-22.048296,177.152329,241.527602,167.124764,48.467652,-153.527221,-127.001178,-51.468792,75.51603,100.682102,149.674269,181.020144,149.253239,89.537959,52.155883,148.552249,193.829424,230.875751,220.084801,174.994722,129.509009,-38.478628,-70.303631,12.554499,190.882412,217.117443,169.799545,141.998702,77.10425,19.502127,-110.643535,-123.525629,-65.920005,53.885602,67.936853,42.91941,28.823244,8.645662,86.006283,150.746677,211.853962,189.659484,87.797114,42.386673,-30.815814,-70.53222,-76.020982,115.067949,224.264756,236.419165,140.430218,4.54304,-12.537662,-106.291861,-145.075555,-75.405615,103.007898,143.744972,127.364279,92.492818,-32.6007,-101.456813,-136.659061,-7.667328,69.70175,100.706914,32.708548,-157.113611,-236.380059,-354.568486,-396.402256,-389.489994,-318.380315,-259.669371,-206.248429,-223.190637,-237.153534,-195.590043,-22.821873,120.572078,127.037531,49.829425,19.089161,-1.513514,-16.579235,-44.828455,-21.942175,-25.214897,-51.472749,-30.4071,82.47509,110.512136,13.183016,-27.011058,94.388736,256.629221,297.359594,301.021363,240.968067,64.449538,5.645917,-32.309699,-71.178627,-101.793518,-74.715429,-10.440296,87.193476,83.797265,-0.518987,-30.881271,19.847091,92.984397,93.26606,49.71645,33.646704,67.233535,104.770628,181.311023,262.059728,267.991741,216.532711,206.240999,204.216015,177.15999,99.000595,79.535563,56.866785,42.258732,79.145544,212.678212,254.354128,248.290136,214.879072,129.438331,104.958264,120.946153,152.870915,148.498094,82.182518,31.574561,-57.084168,-76.360237,-28.016804,39.600986,47.021699,52.385457,55.313223,11.730435,-34.918991,-104.428265,-86.997743,-56.925323,34.724895,81.731817,114.324563,106.272785,76.00311,61.120289,61.608965,83.82901,98.975547,136.318352,146.307562,110.211944,44.729831,-103.283418,-66.836887,3.481402,134.093217,183.772572,246.721271,254.820811,220.723536,200.531866:80.749018,148.178571,220.392434,353.177162,373.772917,316.018588,243.803715,101.466445,71.38909,108.005292,251.577121,281.671591,123.120728,-0.156854,-100.475982,-63.338136,52.807173,176.207202,225.733855,166.756698,82.711249,3.552087,18.942303,42.1184,-30.41412,-85.793005,-131.893016,-120.468467,-74.548786,-30.869928,35.455593,13.766717,-86.996295,-89.553926,-21.226884,128.687852,125.513793,-44.623936,-125.406315,-139.716555,-43.070284,-13.996986,-8.929596,-6.143554,33.602191,56.79409,16.251971,-43.640159,-119.271178,-87.792336,-50.51343,-2.019141,-11.701875,-104.994281,-185.714529,-302.041275,-219.613284,-152.774784,-68.744609,-41.627365,27.818405,65.245252,76.919969,57.068978,68.840156,121.697755,117.952724,48.197521,-6.260518,-134.01356,-187.290715,-232.821848,-210.807918,-171.10367,-51.992597,7.567439,105.884241,127.757838,67.231839,28.289105,73.706354,215.088072,262.796838,251.903509,202.290309,91.407017,48.426974,30.290797,83.380226,91.351618,96.609174,99.907521,32.717737,-33.980888,-123.89538,-114.967831,-30.045832,38.034749,39.043038,-70.095578,-159.732901,-257.628601,-250.509452,-251.793169,-299.601857,-300.447261,-233.063026,-172.199568,-77.648621,-92.458324,-258.445873,-330.660252,-271.402248,-119.097818,-79.968814,-85.61234,-130.589534,-260.978008,-316.221813,-317.126439,-159.237886,-73.040388,13.725203,4.536336,-89.224216,-136.23165,-188.81582,-218.95418,-242.523944,-18.335298,165.664647,406.98871,423.099474,298.647982,175.188298,-13.927429,60.000347,113.940941,131.614804,119.362793,65.308561,5.708606,-127.872999,-136.641699,-23.532912,52.923048,70.187403,105.407209,75.907838,-127.417497,-234.954191,-300.075561,-245.218754,-218.546155,-143.73239,-117.016687,-165.625915,-221.75407,-297.69806,-287.580202,-185.633014,-44.332911,15.99982,41.962109,21.898284,-11.986855,-33.698876,-73.835813,-110.03198,-164.45956,-284.817265,-304.729862,-289.613088,-275.132757,-244.250809,-236.463463,-219.578524,-114.819192,-35.732355,70.940562,75.300818,1.025647,-56.488626,-131.313217,-101.929427,-57.705588,59.716364,102.536954,112.060633,117.059877,165.192545,156.067904,50.882693,35.290054,79.661483,131.324935,111.043711,10.003075,-53.974739,-190.594114,-306.498409,-313.533666,-211.393758,-160.412407,-188.967715,-263.30308,-398.970391,-392.934978,-237.565681,-143.675784,-165.428643,-250.145494,-257.480406,-225.372662,-248.936332,-376.02362,-383.633264,-323.674691,-199.054613,-160.657918,-104.353421,-81.746961,-68.353552,-74.478872,-100.973192,-112.708443,-82.449145,20.667293,39.866793,-56.091844,-135.433669,-183.96561,-61.180452,10.444755,105.544593,113.317376,76.2561,65.349756,45.434703,13.758875,14.258937,209.490295,324.059364,420.277981,372.845991,196.196231,140.164395,137.447058,183.139502,222.201562,337.454212,375.129078,341.643852,273.889844,141.97228,128.527612,139.804164,80.379179,56.237413,66.428786,81.53268,58.421457,10.741077,-62.374498,7.064203,92.410755,247.510519,259.186439,177.728346,141.378769,72.257199,2.22955,-98.214041,68.696678,185.732839,194.645635,99.27652,-36.298562,-69.421093,-147.400461,-88.431584,15.238066,177.444187,177.788819,79.624695,31.434016,-43.280731,-71.352977,-54.682215,64.929691,121.64039,143.962677,99.899015,-56.951951,-130.740691,-187.586519,-112.490928,-55.452375,7.922948,0.652697,-79.355659,-137.608025,-185.473305,-137.724036,50.950272,196.270878,236.512337,245.70538,208.129752,118.068744,105.759501,163.30896,247.560296,260.402842,231.874373,211.84833,198.15939,211.274088,213.570444,201.899615,225.020088,252.916692,250.531296,215.606429,184.83001,140.969496,115.334977,38.691809,5.89646,11.972678,79.143878,119.519396,133.924573,112.010956,82.890525,111.761365,224.895352,232.061034,199.641766,174.617644,185.898776,178.801671,146.39511,83.246027,114.716914,160.375594,286.33847,351.21529,344.85665,257.380758,94.211653,74.879889,108.278575,208.055847,271.541763,314.880651,287.169485,203.210516,154.346791,85.775547,135.857708,160.737577,129.497657,93.597382,56.356865,41.583587,-35.519509,-56.134586,52.825835,203.842286,217.783344,164.125254,117.515621,-10.590315,-60.523728,-93.90802,-74.134559,-37.597086,32.745237,21.196856,-22.760942,19.688806,175.849214,220.106038,242.840624,204.960498,172.388361,151.780041,156.61279,115.586671,72.843818,12.815251,26.95102,57.50122,113.668563,132.082602,194.442802,232.343405,255.449114,254.744279:-26.730081,126.966181,202.006293,320.535038,354.653927,297.329506,205.036511,59.816993,90.436299,135.381603,199.02731,187.156154,86.409943,38.22128,-38.4004,-60.675046,7.053672,135.915156,145.01618,51.342591,3.178508,-61.962213,-106.814385,-188.714181,-184.338079,-174.632233,-155.963847,-140.336152,-133.458619,-138.557333,-110.777027,-79.365782,-27.750816,-18.754143,-5.273688,67.358722,93.901053,62.304098,15.139817,-64.016915,-89.58301,-89.024264,-54.385513,-32.618535,-13.96933,-25.173712,-91.795293,-111.093052,-58.788215,14.629883,32.449647,2.432483,-58.340235,-222.239653,-280.378478,-285.379823,-204.262256,-172.096103,-129.708334,-96.724649,26.220974,97.905952,142.471848,112.009933,73.203516,117.325186,140.781585,89.11477,7.449766,-157.036535,-201.826589,-180.273353,-88.001107,-50.001456,54.520335,120.401854,169.047027,133.402436,46.440972,56.108664,170.973273,223.54855,216.1944,167.654182,124.444866,48.315704,30.262922,35.647735,68.003923,69.825904,70.945435,74.035209,37.57701,-6.759872,-116.40867,-153.656035,-175.760334,-119.475605,-60.049852,-37.430764,-101.648294,-254.648592,-302.423371,-297.024859,-218.772344,-195.744429,-154.49586,-128.683844,-114.367062,-143.576699,-262.675634,-311.132747,-299.624869,-208.649136,-180.632164,-201.10869,-227.14045,-222.368048,-211.651255,-238.459488,-208.079824,-144.073453,-7.625854,16.476688,-40.020844,-94.177878,-231.043814,-277.596045,-209.637139,6.850535,123.477257,267.965317,277.132815,217.309514,162.354231,27.00951,-63.054274,-54.802971,20.105491,31.772987,-2.422713,-24.67429,-83.377021,-106.231324,-73.488415,36.369602,91.122239,116.269551,51.613745,-165.414349,-253.550344,-293.000423,-141.582453,-43.716397,50.889033,25.479138,-99.191999,-164.034527,-235.710645,-213.080779,-66.580972,64.986542,91.786862,65.287346,32.625101,-18.726315,-37.7181,-48.054119,-54.738053,-88.847743,-168.768252,-176.219976,-91.225909,-37.513836,-49.411576,-99.406499,-136.776629,-69.771581,-28.537055,16.938243,13.837508,-63.761297,-124.525322,-131.32034,18.522156,76.916463,112.403729,103.559459,61.815554,30.324288,-21.053493,-15.12651,10.928345,16.187116,51.228848,125.445641,101.339471,-66.375143,-150.579568,-236.894094,-261.006337,-267.626935,-238.185344,-196.173471,-147.263217,-185.708771,-363.259844,-407.635061,-281.953267,-158.025367,-183.126545,-284.171706,-293.925011,-273.884326,-301.396427,-387.579572,-298.801112,-210.370872,-106.876509,-97.400714,-80.090888,-61.823315,-72.457335,-92.27582,-71.457296,-36.935215,-19.944216,43.015484,41.35085,-85.667415,-161.092447,-204.601746,-70.750746,34.2766,174.912865,160.776149,39.040675,1.027905,-55.121092,-97.871929,-65.291006,172.120369,281.756139,329.636097,282.27967,196.779435,173.067469,128.112321,189.525362,252.357957,303.162624,295.408598,267.048965,225.610966,108.474419,74.87144,41.929239,59.677911,103.729276,156.054894,135.217177,47.209812,1.675544,-39.683656,4.021601,48.144689,151.821135,183.029601,169.796088,134.302432,35.575271,-12.157546,-67.623034,10.36657,81.486808,66.614232,-21.720777,-151.039788,-171.879625,-182.756714,-144.42918,-103.456293,-7.349392,27.013504,23.593853,-12.114201,-109.009559,-143.250105,-136.241742,7.959514,110.177649,188.216924,138.954933,-11.441701,-63.589809,-31.907442,95.210549,113.871493,64.50448,33.364556,4.403415,-1.153887,-20.365274,-5.562197,139.506043,303.054625,324.684832,270.516028,234.779843,175.919283,168.757706,270.823497,399.647006,411.421474,367.614998,339.391185,303.997313,293.748235,271.212493,273.878858,301.079628,255.039964,236.549312,277.416699,291.938915,228.227311,164.202706,39.204142,-11.302335,-7.426184,44.909364,87.89078,123.158303,93.154155,18.527973,17.081839,85.942594,152.822956,172.879714,203.667556,221.914421,197.771589,120.179083,-26.670026,83.598804,188.246485,311.616924,314.349454,265.017785,237.023439,173.918706,152.945108,165.70392,224.933129,258.637111,272.653817,238.253254,122.306788,72.216001,96.648133,269.408664,339.770341,348.94377,290.096364,140.277134,84.327073,58.109838,100.402672,216.945585,255.815912,255.874475,210.212723,166.339789,90.040088,65.003287,59.351716,115.677462,144.214454,162.998712,147.338963,106.802934,97.352468,70.456851,59.337744,131.808733,266.223657,280.772059,191.488899,147.612723,91.489178,38.518181,-69.58214,-26.592168,42.657021,134.622307,125.811208,116.555786,147.692603,195.221789,207.449028:39.824399,147.077181,205.715092,293.441164,326.925804,351.859796,324.110965,211.669165,188.602615,230.810416,296.22869,286.804715,204.373899,150.812669,50.901505,28.054408,90.914601,202.028723,220.534199,159.062555,104.642759,24.821884,-1.597724,-79.487239,-175.548686,-194.434587,-135.424609,-83.242752,-4.998591,12.655672,-4.666714,-24.707034,9.096179,90.724681,95.959221,82.848085,91.279472,103.694099,82.090901,-1.481247,-13.830531,21.506806,106.732641,119.093227,53.305767,6.610934,-92.926249,-141.935844,-152.898247,-90.113403,-45.249947,33.938656,15.099521,-176.380405,-301.432056,-435.376314,-373.546663,-318.476906,-213.787629,-170.009176,-81.383815,-34.693045,-7.981916,-23.297676,11.655445,118.736502,145.057655,112.536888,77.482965,43.873796,47.847274,61.751974,79.924541,87.327549,92.684441,103.161892,159.924569,189.304402,176.096023,136.440447,122.123092,246.446246,279.689229,204.733937,150.875501,120.777827,119.148719,49.161279,-57.156315,-92.483352,-116.335189,-119.848192,-164.936102,-189.694636,-196.826775,-184.768181,-113.372136,51.925823,146.328515,229.742662,189.152773,10.945838,-83.639267,-207.776395,-216.164118,-196.533378,-143.725777,-120.251394,-100.108357,-113.849875,-230.860185,-311.187186,-369.927049,-346.622352,-336.171865,-304.916712,-304.730311,-333.182403,-341.294048,-307.309775,-178.393724,-105.223347,-10.796416,4.284423,-24.432386,-68.126134,-228.811833,-314.611347,-288.880813,41.490152,235.973868,510.800168,564.857213,519.799282,423.223569,191.113923,128.004047,139.352777,88.819253,22.562107,-92.009041,-131.581678,-205.518321,-210.892843,-107.614127,51.116017,115.233604,161.189979,129.799573,-44.864499,-169.268524,-340.089628,-294.961086,-245.551568,-199.682421,-208.65053,-277.659959,-312.956243,-299.82333,-244.819399,-117.137749,28.019394,124.708443,247.198686,240.674728,178.491773,148.342259,66.074897,-41.814856,-103.332949,-198.434278,-207.762981,-137.299256,-75.794086,-4.748989,-15.686051,-47.241666,-2.58961,37.578965,79.047318,66.911669,16.805969,-0.202211,3.1256,45.989897,58.673658,70.7896,87.310666,112.266412,114.109403,103.782951,87.53631,84.313162,210.928175,298.604368,335.848629,278.308843,178.687056,136.431361,-0.453989,-59.187091,-31.332837,56.688471,89.41965,83.390721,33.304685,-103.059553,-135.353506,-83.764113,-42.512323,-64.350594,-166.025399,-211.040816,-197.211015,-163.100252,-139.203396,-140.306114,-127.570025,-76.41208,-50.507899,-10.883019,12.034692,40.531825,22.580251,-59.17497,-102.493931,-75.479354,24.637167,42.58679,-17.639941,-70.371996,-164.754525,-162.74835,-110.277903,28.107234,53.203002,1.099701,-17.96267,-48.974084,-96.528484,-179.093852,-77.08098,37.692502,210.824568,212.711642,129.844869,87.367539,-5.082188,4.895333,89.647189,274.353448,303.572604,234.334128,164.253398,-6.228162,-72.504541,-91.209459,-13.965047,21.191503,56.273359,52.241254,-5.63523,-52.151936,-129.818502,-95.065213,-20.923984,107.538768,95.279389,-9.440415,-34.596992,-62.76393,-100.304443,-176.459792,-145.69385,-90.051598,-37.639224,-64.753579,-150.273867,-214.363007,-383.594397,-379.999043,-284.696941,-88.145828,-54.146589,-112.550515,-161.492374,-236.909947,-265.472468,-244.63691,-95.677004,-44.262021,-71.378852,-108.171241,-125.937963,-133.437272,-235.021318,-334.366456,-334.409003,-266.637315,-231.326305,-215.311593,-216.200666,-172.434984,-133.420293,-39.514306,94.945085,150.730929,149.040511,87.717795,-62.521766,-97.634707,-67.080987,8.47621,47.256534,86.840429,90.727382,151.172868,197.614426,206.409546,195.665393,279.050962,357.697303,338.453027,242.794466,194.565456,126.129415,89.679791,-17.626906,-42.964046,-10.891063,33.74931,32.270559,12.261648,-3.242257,-53.41524,-65.320022,-6.388092,53.121985,44.471355,-2.949629,-7.629094,52.768935,73.533897,35.499716,74.131957,132.293097,223.014938,245.885919,221.265211,154.761134,-30.211655,-87.88494,-54.170187,76.44931,130.669115,183.068502,179.945551,136.183346,106.169668,112.735647,247.867727,295.269276,268.80808,227.319255,145.694463,94.693962,-10.582828,-28.002528,38.691958,128.356042,150.216963,163.808877,153.786891,75.616892,19.768349,-33.956165,25.065301,56.185802,104.12825,126.071676,150.587807,169.175507,211.11158,209.91966,195.615857,199.200025,188.303306,114.299923,55.85766,-40.508925,-64.398443,-106.479774,-156.668651,-130.912235,63.89175,164.755722,248.949816,242.180382,190.409878,169.698409:-97.194388,156.760981,247.578395,229.461262,194.21802,174.817904,146.492483,52.009576,45.208607,105.205412,298.245687,347.987788,267.851022,187.150143,49.644164,12.659849,29.594213,157.452735,228.061723,221.854053,136.777497,-50.321455,-118.280672,-200.938671,-228.887614,-225.137267,-162.559279,-110.979817,-45.364556,-60.744732,-145.670479,-169.293254,-144.713396,-67.849346,-25.533608,25.536322,38.844041,42.798766,9.419308,-84.213913,-100.625517,-81.621434,-26.229974,-7.591601,-41.745649,-95.543415,-205.89882,-221.787947,-166.68839,-87.679367,-43.163474,6.971599,-20.260324,-203.649076,-332.777909,-482.979024,-412.971454,-332.805529,-154.303151,-93.516327,-73.572932,-89.068418,-122.731011,-130.962994,-84.141539,2.330168,38.704814,73.3713,66.30843,27.810536,21.158444,82.684814,193.842438,234.427896,260.203165,236.495424,149.894668,109.068942,-0.153272,-43.544122,22.716902,204.801516,259.516476,220.987504,145.515428,-2.337395,-48.875044,-84.180379,-96.091518,-103.362185,-70.796337,-60.473281,-150.54002,-223.169891,-324.801916,-330.095571,-244.932332,-60.052878,55.601812,181.190178,142.479961,-40.227416,-112.276348,-154.423221,-126.682104,-99.682823,13.311259,68.762917,16.264237,-96.582614,-335.730048,-396.092685,-363.914508,-254.293839,-223.732681,-250.501231,-284.203688,-302.657317,-297.482691,-314.496409,-267.621523,-209.555317,-108.826121,-88.887726,-100.281095,-120.069871,-223.754969,-279.968448,-214.814281,56.943641,199.439759,401.206666,443.287827,416.835281,349.6899,158.437802,65.603223,70.157563,59.277531,15.068532,-80.463625,-110.458276,-200.238918,-244.894534,-200.065852,0.782052,99.957122,144.445907,65.7311,-167.628222,-261.132467,-335.849132,-240.977824,-161.53479,-54.69447,-67.647522,-204.671597,-282.117697,-347.66813,-296.915854,-80.829632,79.540421,132.769185,200.135488,183.719813,63.401836,17.022095,10.263183,-29.212182,-67.378202,-68.237792,-46.888455,-36.555246,-40.23801,-53.760337,-60.165508,-68.80774,-75.649883,-42.939001,66.840793,83.739167,5.168106,-58.755297,-123.962982,-5.15705,77.153944,138.421261,119.69382,70.342786,54.515548,19.118754,10.566563,43.023732,124.999018,193.227515,281.653694,255.741145,108.015806,20.467758,-116.218427,-101.605651,-28.015452,161.432191,206.723155,119.746439,26.839833,-146.367859,-184.952686,-90.273926,87.702168,112.170382,-19.929344,-102.90866,-156.16984,-164.146706,-169.165947,-71.137805,-9.353461,52.648124,39.790979,-22.649601,-46.453256,-61.635711,-52.381542,-53.113096,-56.801554,-9.72729,103.521978,91.837091,-92.93164,-185.803473,-201.564894,-83.854966,-36.082539,56.694916,96.901486,52.914876,-40.342225,-210.803307,-218.28217,-105.635722,93.644149,199.589832,278.749742,246.009226,141.915618,84.758902,-11.501413,35.856287,135.562117,392.690585,465.339915,390.817436,302.392156,178.336957,143.134859,118.591448,173.45324,222.460089,300.997997,296.295508,177.076612,90.699077,14.315175,159.263621,244.731323,269.885639,213.079714,89.388969,62.21602,31.842296,-0.149837,-58.461926,1.60646,70.72919,107.530498,46.482611,-98.407134,-157.951171,-235.93042,-177.018615,-107.023269,7.110552,30.664731,29.006286,-10.615368,-153.234508,-184.954885,-96.068355,67.607214,150.443684,232.535787,187.311859,-20.782094,-116.490469,-173.963109,-76.33292,-17.871753,52.34631,55.19009,17.654496,-8.143927,-48.326193,-35.966317,79.610465,239.607676,305.164997,318.037123,255.472382,94.697169,44.306965,61.534633,153.835775,191.252659,268.455113,298.525321,291.392968,250.437088,122.642941,99.339433,219.98222,351.779744,376.182171,335.411929,271.080622,99.458713,20.153984,-32.192423,43.792379,85.851652,123.844578,111.357114,24.613929,-42.006807,-182.456316,-221.572912,-149.442501,25.436594,70.110081,40.910107,19.404822,-2.977329,-40.053481,-89.065764,24.890483,99.562424,196.496575,211.155944,158.127149,81.97727,-142.08589,-215.176206,-137.130772,37.650457,82.589969,126.981803,130.339977,44.739899,-28.430542,-54.180071,166.640039,279.851718,365.237873,361.750945,296.007342,217.366169,48.931047,32.052241,190.716647,361.885549,367.562388,235.891883,147.701599,42.301594,32.153214,89.836599,215.060503,264.855065,326.235073,322.356773,225.191116,165.051934,58.250528,31.403597,125.039522,245.873498,222.312417,111.816606,98.321596,72.427535,1.292499,-119.194262,-44.461056,27.587582,169.66695,224.156852,277.615002,261.354786,128.751653,69.502953:-31.799977,22.764403,73.590002,230.42734,308.823533,381.667114,355.945453,212.924089,167.388859,225.957996,377.703209,406.857822,344.639053,280.90925,128.508719,72.958466,119.408161,235.06146,245.562236,176.924507,113.253539,8.588107,-3.47578,-21.944755,-86.373277,-96.64193,-58.898989,-32.5295,5.190736,20.85019,58.684579,73.254865,64.013437,-13.60278,-43.023126,-17.101934,24.101327,67.621593,53.95368,29.318369,23.153171,0.548274,-13.542964,8.897693,38.956556,34.820181,-58.665463,-145.414013,-233.554734,-158.874726,-96.826891,-2.198812,-16.660511,-183.885825,-305.661673,-498.519941,-487.910453,-431.807842,-321.056752,-267.380632,-142.568613,-89.624179,-97.545503,-153.514044,-215.58925,-128.71603,-60.64767,32.125278,54.042512,103.122756,114.766545,28.514662,-80.480957,-69.21964,39.000499,85.712665,124.147323,116.298491,32.21008,-19.550468,-24.532038,55.592245,88.235173,117.026535,105.343078,51.54064,17.816352,-67.315438,-159.674059,-209.684039,-309.193309,-337.548977,-325.164443,-295.680316,-232.13384,-201.011656,-116.915127,14.777332,93.276911,183.546193,137.58408,-80.595093,-152.878589,-157.627502,-157.008495,-157.739217,-82.434052,-41.104975,-57.6454,-105.649585,-213.359014,-251.971481,-256.40486,-237.978923,-241.298267,-236.855016,-245.795861,-297.996844,-316.495686,-309.032534,-275.998737,-252.927096,-168.511656,-121.220969,-93.40553,-128.545264,-270.423771,-335.077553,-322.165696,-114.187759,55.15873,452.138597,573.526878,569.6086,500.475341,335.582979,184.749833,122.532489,59.094835,29.804966,-118.327096,-195.761665,-270.872972,-274.435303,-177.689492,8.285577,77.851647,149.132374,161.721654,88.570255,-26.420368,-312.457418,-398.093424,-351.865347,-246.08639,-244.936174,-334.264418,-369.745166,-364.195731,-340.297208,-246.688962,-89.529099,-9.64297,101.694977,122.139187,123.044026,102.091525,-8.798681,-142.627589,-193.692433,-228.600217,-217.813363,-216.136358,-225.666733,-182.933669,-119.454668,10.316374,58.602303,92.577797,202.61323,210.981862,96.655685,35.853828,21.120211,109.393916,142.223807,187.593163,215.634993,202.860314,164.48278,120.635077,120.623302,147.937606,183.482566,216.304681,318.129748,340.862943,271.121523,192.699596,20.850714,0.748949,70.245683,248.032373,300.3206,300.335894,268.316391,169.177049,132.006376,184.594182,273.628141,251.430841,106.29512,42.861685,12.998415,17.460651,-32.518363,-53.005175,2.569446,128.832933,134.015931,88.819978,107.857763,197.906235,207.241983,145.922409,112.351471,137.113207,250.090796,290.694154,242.17398,147.578956,-58.751692,-63.669362,-17.957162,32.13117,32.572593,33.117466,47.909483,52.598281,9.104084,-77.804636,-19.919125,30.984704,88.6047,58.659628,-103.048594,-157.489176,-141.895883,-63.087958,-12.621423,109.141808,141.43471,65.885704,2.278736,-57.669511,-65.315513,-71.41261,-53.371082,-19.215065,83.186483,100.459384,21.275245,-40.537958,-117.82264,-30.640329,56.900777,156.921799,139.611359,16.12916,-53.454207,-113.848696,-105.949935,-49.131336,87.778094,139.645139,94.944011,29.091802,-78.301199,-126.572286,-205.981298,-167.420967,-131.083975,-88.015782,-53.275774,27.409847,12.371402,-155.31139,-245.592193,-292.464908,-159.601033,-80.563648,-38.860304,-90.25159,-239.726159,-311.755405,-432.821333,-491.339106,-498.806967,-424.82651,-352.929576,-316.034145,-368.045008,-429.716808,-378.053652,-167.876227,-16.699192,20.878856,27.432512,-16.442281,-129.562575,-156.804808,-181.859669,-230.842672,-225.735056,-59.095989,53.926024,129.927398,95.751794,23.576291,38.677019,204.469272,308.71945,301.702548,290.043254,272.520116,116.835596,1.835372,-154.77991,-151.373593,-121.738082,-72.835033,-71.251553,-104.316895,-112.545119,-117.584683,-133.009822,-141.64799,-126.79856,-147.500074,-180.589656,-152.634847,-37.777318,1.663702,1.831862,11.119781,59.669734,182.725729,200.999866,118.437731,55.197801,-67.473886,-105.460199,-68.667518,68.113774,131.370973,148.647468,98.642156,3.625474,-8.925504,39.121752,167.165111,231.972978,301.323759,286.085707,155.472728,75.552456,-60.03754,-106.88233,-64.321131,116.833483,187.947517,204.983367,149.525714,4.22942,-36.966685,-27.949793,8.111009,17.341124,51.829112,82.925347,152.787819,157.46351,47.740111,-13.285568,-17.233717,-13.511103,-32.466701,-16.35713,-5.985621,-69.388117,-115.574431,-113.971295,-27.733003,-0.621926,89.796699,171.933622,284.767568,287.715083,218.675301,162.088211:-104.480429,103.659125,175.321084,217.813313,191.292477,91.077859,46.781998,20.235911,108.245736,187.324781,332.473888,357.371461,279.131727,203.399934,31.811531,-37.110728,-16.062237,130.503417,170.277778,100.6584,4.62423,-172.81509,-226.203983,-289.27882,-252.538413,-191.134719,-77.137644,-51.500618,-41.405868,-51.331075,-135.342403,-182.283171,-173.269798,-109.966614,-83.8846,-13.592251,10.049101,-10.201414,-40.477036,-88.795501,-135.420132,-147.899786,-54.526478,21.67114,18.683018,-77.931604,-301.447594,-374.992382,-398.578006,-228.220873,-95.542707,78.899051,57.242043,-194.639847,-369.367653,-589.105042,-509.512488,-416.473343,-260.831222,-223.448116,-200.708958,-194.284315,-203.926964,-204.911367,-93.503179,33.371708,29.948725,-13.684618,-5.111565,34.570182,33.129555,22.404032,64.418873,89.805341,133.990603,132.708265,51.049131,-1.15865,-69.933024,-79.585024,-27.989844,113.013496,182.9245,206.20356,162.203413,58.693835,1.420703,-127.894616,-226.104343,-242.904761,-202.122631,-189.090378,-272.803462,-345.46589,-440.466165,-425.994349,-248.492332,35.349783,151.142962,183.358794,122.838568,15.52107,-28.404915,-159.729004,-234.008725,-190.42596,16.69154,86.105231,-2.100853,-117.864245,-333.725559,-390.131749,-379.480973,-348.523863,-329.241142,-251.682132,-239.484065,-334.96232,-408.742166,-449.969892,-291.832639,-204.144379,-97.852248,-74.541854,-115.515739,-189.368409,-377.296781,-443.179298,-388.308982,-28.790514,191.71629,449.794267,454.039398,358.705091,301.102767,184.334874,140.242564,125.127082,48.299088,13.907164,-40.852758,-113.926389,-354.796483,-416.734287,-261.690289,-0.054846,83.541584,160.058603,136.741753,-64.750628,-209.276932,-401.333462,-330.178826,-251.968801,-175.495218,-187.261274,-258.257531,-298.481438,-360.872175,-365.579045,-258.846779,-19.788946,98.338912,195.675352,165.179301,67.190976,29.289387,-45.205862,-103.152549,-120.852733,-116.191543,-92.201408,-75.335452,-94.501399,-122.166093,-114.265263,-71.611971,-19.929514,22.102454,127.553483,152.820142,69.476615,-18.697057,-90.273413,12.60722,41.607782,74.1048,126.413764,197.074537,150.840756,-17.694808,-57.160922,16.531855,227.035794,336.057563,415.071153,370.106812,223.066638,148.826088,17.278746,15.755758,75.791648,228.643816,280.696113,280.395625,234.970082,97.716572,40.274743,45.380988,158.359971,188.655757,145.728735,107.945751,32.432171,-24.769253,-93.561684,-2.957873,67.220449,177.708411,190.889783,130.774267,96.347433,47.373992,27.403769,62.829474,173.739998,216.16416,270.928318,264.959534,112.336828,-14.155225,-188.146635,-115.553517,-12.877594,197.949507,238.311257,113.243787,-6.154351,-199.695771,-226.168004,-109.562093,119.892378,221.4332,268.821946,207.034079,34.971337,-43.256791,-138.852062,-23.862241,117.568884,386.036447,435.895863,329.848595,223.421642,65.43608,43.760069,75.045801,168.659273,236.480583,321.372274,306.010754,165.355204,75.309728,5.188799,142.6117,244.702468,369.779813,356.529115,202.730746,108.159883,-15.628252,-27.984686,58.848706,217.686548,271.641271,264.976015,220.482464,109.725685,48.963504,-34.821849,17.497498,96.070314,276.401084,321.1788,223.689257,102.172445,-124.104728,-174.727947,-94.940131,156.233545,252.328493,271.278169,214.187666,27.084019,-73.818918,-196.097722,-184.353198,-133.347436,-6.444727,18.382414,-36.087289,-81.079943,-131.969574,-111.485822,56.609361,313.797618,411.902744,388.517865,268.787112,-5.046839,-111.497313,-204.710493,-84.05112,23.724705,215.402337,252.221977,163.421185,79.80845,-9.665175,38.732492,301.630993,504.564837,531.618895,468.316787,378.208425,101.956762,-36.166194,-133.356249,-0.378992,63.008016,94.104854,53.979288,-103.888639,-172.872488,-252.948701,-270.578035,-217.456393,-81.610461,-30.229468,-13.415182,-48.973608,-173.843678,-230.325441,-219.064024,4.039614,126.712784,216.043617,178.595446,52.043534,-9.233176,-162.982329,-234.574154,-190.272131,21.466097,91.11465,121.741865,84.909593,-47.533801,-100.364786,-91.275817,123.004916,262.952525,420.610801,398.059142,220.405405,108.321104,-94.272269,-115.073112,81.798398,263.213714,269.581566,222.301436,193.20929,65.937136,-35.127181,-119.373192,106.130413,238.043942,327.987281,298.269679,227.897874,192.387847,31.074514,-55.680025,-29.837979,138.125628,166.58455,80.28999,-2.282113,-132.30651,-156.006992,-108.936586,13.493376,58.678208,149.045593,209.045571,268.887756,233.802725,71.777867,10.827906:35.904065,64.715759,111.639199,237.982618,284.772832,275.911888,224.314726,126.942882,137.359905,184.94547,352.69011,425.366895,382.072793,269.78341,-7.19112,-120.032106,-110.706698,161.74882,243.397523,169.314609,80.942159,3.725296,33.053597,83.629105,-1.501716,-40.349692,8.006442,62.650372,90.712377,66.614657,43.402312,56.593425,62.443242,-24.802619,-61.72957,-5.862575,61.598935,128.174892,106.812217,22.529864,-22.513365,-50.703993,-132.203203,-138.316163,-62.797652,-36.320126,-98.634566,-174.131744,-307.547156,-290.989417,-232.629602,-130.827162,-122.939269,-193.992881,-278.588843,-478.804521,-430.989917,-327.032019,-181.6676,-142.706213,-58.571064,-24.374563,-50.427567,-104.884279,-159.201456,-118.385874,-108.182541,-89.137734,-49.574754,41.964524,29.062245,-151.548126,-295.038915,-299.963844,-237.885174,-193.450453,-153.47524,-162.420282,-174.409328,-174.921394,-194.183666,-226.004079,-229.05839,-188.316958,-162.032692,-158.570249,-177.068003,-232.339128,-312.017794,-353.188971,-391.278704,-376.362709,-289.292857,-236.934205,-201.837379,-206.650113,-120.616998,48.290027,124.506844,252.208722,265.31692,200.399275,174.960166,137.104281,56.077692,27.701129,69.720259,124.288724,180.319975,152.685379,-3.371849,-91.920215,-131.907119,-47.392107,-29.793704,-27.170288,-41.825132,-144.044862,-204.426768,-231.241181,-146.392267,-128.199974,-202.276588,-255.50468,-298.398517,-288.128597,-289.226301,-322.95399,-378.476969,-286.089944,-173.918458,86.110191,182.289412,243.632422,215.242397,98.372802,-43.700214,-119.635198,-236.021617,-252.497626,-240.501139,-246.957143,-299.773022,-323.595454,-283.976025,-97.917293,12.355875,140.617929,130.566557,-1.629694,-86.108253,-212.597937,-259.286754,-263.653802,-222.904929,-208.860993,-275.076854,-309.297323,-275.089756,-248.804862,-238.575756,-134.941755,-37.256865,83.488239,56.103216,-48.976154,-67.059183,-110.816085,-282.204725,-387.711055,-498.544836,-497.487388,-444.434431,-392.018903,-244.8636,-166.028477,-35.021937,-68.246973,-114.427125,-65.693443,1.229258,35.53511,11.460696,-3.021583,-12.200359,-27.312766,10.746705,58.383463,75.88126,32.064515,-74.450531,-89.306772,-11.385621,16.081358,-6.248916,-21.081583,-15.280134,-0.112287,7.998608,-15.02138,-26.264631,12.800019,163.22902,222.750451,229.926216,212.130549,187.364905,165.521248,119.78684,102.12686,102.64975,112.311183,102.166115,73.828813,84.66367,105.712255,91.470041,118.659688,213.500116,223.799327,171.058473,161.080901,203.988119,229.477176,252.240228,215.090067,204.015786,303.87628,365.451774,329.692702,240.454036,76.714762,40.143316,36.948188,35.913023,54.021053,127.866016,165.45931,164.160841,117.679968,30.781016,53.754575,79.294597,56.123945,22.687035,5.83367,-18.121336,-188.467152,-265.950039,-204.915433,-29.548158,10.808805,-32.724261,-74.720008,-123.993915,-117.542921,-47.207301,-44.361133,-63.78913,32.807134,131.080128,200.46208,153.501988,90.269771,184.010679,219.153336,177.549089,130.263881,58.529671,49.943114,49.360983,38.853844,62.436817,180.472819,244.471947,305.019096,279.622731,218.775206,220.901464,186.088235,127.947687,137.662817,179.071532,186.43239,196.697013,193.542213,60.173503,-55.391982,-150.789353,-44.280306,13.394931,75.6421,60.512015,-34.614686,-97.88341,-270.791888,-360.524119,-341.471307,-258.421685,-223.737364,-238.547953,-290.140852,-354.411301,-315.904261,-140.573341,-54.053623,-54.268211,-31.080655,-31.957781,-132.498628,-188.1163,-195.704602,-106.099002,-62.042386,43.215842,93.616683,76.723612,29.525142,-7.409371,27.808882,172.704296,253.776724,235.373965,133.742737,82.969702,-59.105449,-172.67078,-382.737881,-416.357205,-369.805887,-240.274706,-195.022682,-211.166897,-266.035649,-340.541222,-317.721461,-224.11062,-238.97728,-281.047894,-308.648585,-281.857162,-198.641786,-152.30068,-76.470812,25.215091,82.237304,130.673323,136.880758,123.333345,76.032925,-60.264537,-95.807502,-59.088666,15.00676,56.181322,159.871041,172.039357,47.604881,-32.43827,-67.577365,65.016858,136.622619,164.387649,118.470627,-15.435856,-78.826144,-159.577749,-150.979861,-46.613233,5.095685,-2.840555,-7.500118,-10.207872,-54.45183,-65.510874,29.689845,119.612281,89.835562,9.950425,23.494578,107.968594,118.651256,-6.557104,-107.828703,-234.633313,-276.432602,-289.865985,-259.329756,-224.449654,-170.231535,-156.113668,-140.95317,-94.092165,-57.116841,46.054969,92.510497,100.126526,85.694849,73.38089,56.241449:51.067877,135.040677,185.502386,248.974155,267.431414,283.375907,272.798943,206.505049,204.556576,249.561685,334.783529,336.533034,262.83002,224.652716,158.150277,111.989407,77.178461,144.032933,173.521189,209.136657,200.341742,116.790795,73.16332,37.520868,63.618532,74.969563,46.003071,17.438092,2.596308,26.408756,43.286489,9.908663,-78.857477,-86.249262,-47.833698,23.385156,32.82653,46.218753,43.596228,-8.641374,-39.055869,-39.495003,-10.301121,22.090643,63.974449,50.481348,-52.478047,-113.513119,-186.486753,-221.607214,-217.757753,-179.041519,-180.90448,-248.174004,-297.919291,-360.735479,-271.111146,-206.302198,-118.001886,-64.536756,41.954217,47.877009,-62.636177,-140.523779,-193.632159,-101.743501,-70.359809,-49.544599,-18.620993,66.098393,57.459828,-116.488825,-243.468843,-232.761901,-185.771758,-173.528091,-125.129765,-96.628732,-126.081333,-179.012158,-237.25205,-208.307304,-189.126915,-128.671189,-96.366231,-73.91053,-79.582068,-94.57171,-127.767977,-169.872717,-242.096001,-254.040825,-243.143462,-214.610233,-155.581174,-142.98029,-75.315327,45.25585,78.004359,110.594496,101.378151,-8.495147,-79.331496,-166.839033,-140.709293,-104.592359,-42.432469,-24.594279,-2.032652,6.103358,-3.184085,-13.3265,3.528048,-27.558792,-77.52402,-139.349326,-148.173937,-155.352555,-155.826966,-183.291928,-216.800973,-209.327199,-174.389217,-159.840336,-159.309737,-184.402784,-264.174944,-289.896638,-266.17897,-197.726505,-126.802632,129.945673,256.345843,357.872561,324.327084,188.694649,73.885095,23.860992,-41.253417,-57.282647,-122.18467,-181.436151,-293.416776,-316.787248,-275.907453,-173.234406,-126.567334,-61.645984,-44.341486,-26.085757,-48.571482,-227.278706,-383.051232,-366.702707,-256.637935,-247.115986,-319.360577,-334.019964,-268.775894,-227.068617,-173.652616,-134.758302,-92.637987,33.42881,72.732097,77.100159,62.633577,-47.338848,-263.880881,-339.917025,-385.194876,-388.830761,-387.26225,-362.013736,-237.145083,-157.150418,-42.930169,-9.843085,30.904335,173.175387,201.045824,112.421147,42.042259,-71.368593,-80.163879,-24.536749,141.974464,192.901396,156.885323,91.91221,-34.394841,-44.998126,47.573163,106.359609,123.204058,179.227874,191.250633,168.856812,145.486955,86.806614,64.202979,80.743675,176.72222,220.668059,211.75222,176.307132,99.302885,74.395207,82.468456,118.274922,135.764374,159.992305,138.75156,85.220992,97.860441,107.512821,53.567058,48.441497,103.997982,140.343406,163.107324,166.135385,172.637814,153.690849,118.352824,182.294602,240.401989,352.50767,387.233871,362.457301,283.937851,81.322349,43.614482,79.693527,135.986833,148.086038,190.625484,214.793658,161.733752,86.567134,9.38605,101.46321,136.278881,91.143935,41.48408,-42.712857,-83.958804,-193.541365,-270.072136,-269.429879,-182.722231,-125.788973,-106.568485,-141.442166,-211.183919,-227.581181,-199.367245,-110.30769,-72.872384,-42.688195,-42.80367,-42.197754,-39.480154,-4.309148,120.042023,166.408734,154.508174,124.178094,40.795117,-9.894712,-71.00012,-66.670343,20.523435,139.992577,171.287926,166.485694,139.180138,100.087864,93.953226,15.445634,-59.717203,-27.166577,84.279101,111.586419,127.831033,134.957277,65.186772,-33.595633,-175.45333,-63.21674,8.521985,5.462747,-47.731291,-156.44476,-220.842049,-388.311024,-462.700251,-447.686899,-384.750234,-359.985435,-342.64529,-326.627614,-260.173669,-222.963988,-111.483755,-30.714054,-45.723809,-117.01581,-134.013972,-122.847817,-131.111152,-212.669277,-212.782666,-161.808838,-47.66029,-5.407747,-0.89062,-33.186771,-59.170103,-6.423558,179.682093,196.612496,157.49491,141.748463,131.328932,6.187073,-91.880393,-267.363767,-291.777948,-245.779477,-131.306555,-104.746603,-143.32155,-182.793186,-224.232088,-204.923195,-95.476469,-51.483446,-84.090913,-162.756663,-168.362211,-58.741727,25.946867,99.962933,103.724146,121.704273,146.212805,149.250938,189.157271,226.115813,253.106383,208.990173,53.627647,59.214369,156.482503,289.917904,258.741347,161.128086,158.576355,193.981031,196.520619,188.492958,182.251603,181.971599,149.534704,105.860833,-20.994231,-67.052188,-44.164442,10.612489,18.266937,48.074402,50.113309,-29.718959,-86.29284,-157.886923,-138.954648,-99.648817,-1.581746,37.949952,62.242448,48.224521,-34.237172,-94.223791,-176.401368,-153.85769,-115.310553,-46.381513,-35.172923,-41.28218,-46.402856,-45.380449,-40.49123,-42.603636,42.828044,135.471076,233.98961,213.408634,134.078131,107.358221:-23.280532,-32.350397,-8.088704,200.159411,293.374957,254.994717,179.405352,126.935556,237.433515,312.251202,408.367594,408.911041,309.444174,222.261223,56.789451,21.774469,61.739109,132.852325,145.871536,125.297458,94.147514,-0.700493,-59.719604,-148.5966,-125.415934,-107.564704,-77.201448,-47.252924,-13.891236,-12.411023,30.805869,50.222057,23.938399,-23.026203,-29.010459,2.59698,24.47684,45.569346,43.598309,31.532384,4.169152,-26.274403,-35.383015,0.860175,0.180131,-63.327083,-183.236655,-187.659558,-148.403213,-186.442688,-167.7791,-10.733851,30.159348,-77.930921,-183.862619,-365.523342,-372.398464,-318.194364,-192.847768,-145.545811,-77.373038,-45.687806,-45.016166,-83.721961,-141.467847,-135.483955,-107.898581,-18.112006,22.814604,102.497386,121.154596,20.870116,-105.105998,-100.238855,-10.578226,20.964217,21.340704,12.298719,6.219701,-0.467197,-24.639119,29.43181,93.182358,181.87088,180.066771,116.462728,69.311098,-45.713777,-160.287285,-195.315325,-207.740781,-203.315541,-195.530656,-198.190491,-230.788745,-228.242064,-116.004568,41.241846,111.515168,203.511291,202.476735,160.609047,130.515833,9.530616,-94.209409,-95.938857,18.905583,103.560831,162.100903,110.520487,-66.198718,-143.734599,-191.438859,-170.214445,-158.592243,-89.147698,-71.61319,-145.973408,-204.605523,-244.56938,-169.08223,-136.774867,-125.767023,-137.143676,-220.216001,-298.396637,-453.162695,-490.386393,-428.301881,-228.503797,-96.352268,212.75405,342.877524,424.328774,374.010373,205.783472,75.434773,19.951358,-72.041989,-100.572348,-151.770863,-184.481636,-269.770778,-297.140971,-211.302193,-10.259202,66.153503,158.258121,180.606827,130.131283,45.22841,-176.608561,-275.768409,-236.991053,-90.123799,-67.499068,-169.501107,-220.353245,-228.875772,-232.55457,-237.544625,-48.327563,74.174405,132.293798,75.192645,-8.386608,-13.772947,-88.741194,-230.429742,-260.263136,-236.532485,-221.110441,-207.226575,-172.921475,-48.209722,-0.302477,38.476756,91.109471,132.10925,179.199808,163.982762,68.551221,7.517925,-70.651845,-25.989218,10.857038,65.798825,96.842377,164.846663,168.766359,85.119716,48.983222,73.105741,129.467239,153.388516,187.835717,176.555688,107.097316,66.253305,7.478216,102.234583,180.106216,270.38046,278.430754,271.15161,268.515609,215.727177,173.269887,167.94576,199.479513,180.357097,142.258648,147.677509,168.197915,163.785137,117.056889,95.378764,133.790815,263.744708,280.641161,185.754802,159.860724,228.017411,257.597309,229.265001,168.219068,153.108659,162.500443,159.467802,100.295934,68.84493,49.386247,44.594144,32.711111,20.00531,26.497663,44.8098,52.242002,-7.347328,-91.887175,-201.984082,-83.178408,-3.87614,26.099767,-18.53318,-80.674231,-89.560802,-130.000304,-96.791606,-29.452155,91.351829,109.636962,44.298462,-25.874796,-119.652772,-107.368687,-28.63397,10.421195,34.290677,144.02923,181.630241,124.638065,71.750628,48.329184,120.845997,141.866021,90.326718,43.981124,-24.545417,-51.087852,-101.586794,-107.112872,-42.379611,70.950735,117.932144,162.026665,144.664421,48.132249,10.886759,-30.700256,-46.007439,-6.954933,139.08802,200.653575,198.943075,124.795283,-90.809493,-187.782113,-268.216627,-153.776088,-64.460389,51.630769,55.740083,-62.853708,-182.234797,-422.070664,-494.430095,-463.724479,-313.124587,-229.187727,-184.632996,-245.961984,-386.256044,-386.35406,-206.729797,41.791294,118.413094,121.744115,44.890935,-152.17157,-212.294739,-240.97844,-183.891754,-133.084324,22.822444,95.132666,102.161499,70.541506,63.810976,83.678164,188.038414,331.583244,356.688869,305.687287,243.583745,43.6142,-72.813318,-197.677186,-155.344451,-139.020584,-147.19774,-164.517736,-245.825415,-275.287231,-239.983452,-206.563408,-179.911661,-214.276337,-228.886233,-239.071841,-240.888368,-208.549238,-196.673001,-212.140747,-75.515454,56.107077,186.062489,144.590359,-22.350638,-100.531628,-198.756131,-210.462015,-165.567952,-44.837746,22.003559,61.850012,34.217192,-9.694885,-19.730841,-39.596926,13.543737,60.984763,101.857222,64.949561,-92.769444,-136.762477,-83.699705,-45.352103,-16.768562,-21.096267,-8.827125,58.379677,61.402489,3.603461,-13.551409,-24.166285,27.129386,69.688783,112.188908,135.893317,222.56981,209.277477,-27.217626,-139.135028,-127.304239,-58.250521,-74.276327,-71.218267,-33.125151,5.10674,-17.757569,-58.98753,12.612545,52.139194,69.230471,76.596171,130.451301,148.580372,83.291757,23.970713:right
-30.019458,67.619343,118.158628,158.740652,112.738197,-103.660048,-175.189994,-46.199512,169.813664,205.832113,217.737889,250.132488,329.357893,310.401074,181.53734,159.400884,252.241939,318.156076,288.651981,149.622513,95.463609,97.664009,143.244103,256.230113,294.281293,281.569566,267.885919,283.281053,308.821267,271.780089,97.484976,35.034915,51.184829,116.018282,128.247414,142.005145,153.763051,109.115812,58.089418,68.59532,289.70827,437.717396,647.612118,650.403596,496.287949,396.112618,243.183038,213.719892,223.799318,277.140698,299.295496,254.533865,205.232926,100.45669,57.569779,87.49218,240.382116,306.484321,316.192459,260.26825,155.148696,130.500906,113.593705,132.152966,231.105447,302.688601,287.015428,217.799209,193.836766,133.890891,113.228771,119.92402,101.105072,77.253466,42.523836,47.660593,75.33105,61.584247,5.940431,6.399421,62.310483,138.736232,152.378546,39.554875,-50.955275,-139.129561,-127.070741,-69.016704,-47.444064,-59.265324,-76.515064,-28.539239,194.555627,286.285071,316.197808,277.066794,155.386249,140.794563,187.302859,218.859202,191.544363,151.543403,145.035698,98.876807,-7.527307,-31.268907,45.507836,119.575478,229.333266,212.894476,72.275432,31.081814,76.555298,156.563003,162.681518,101.139041,59.580518,-34.000762,-74.417876,-61.766229,19.180087,41.560629,21.17275,-16.375245,-110.933717,-146.060893,-130.654818,-71.669997,84.573444,143.33949,120.991631,56.251213,38.181402,-18.345,-67.146772,-103.488539,28.553477,127.733682,243.082395,239.461523,217.373514,214.584487,219.234599,244.819314,314.568535,319.575374,281.044735,197.591769,201.194638,255.817998,257.919417,208.891262,196.517186,231.003498,282.713848,250.94445,135.494958,83.829413,-24.340731,-60.655477,-33.390431,82.145646,141.253828,166.054198,119.412738,-44.480528,-117.445566,-136.093785,-93.603911,-81.629427,-15.492802,15.677595,-26.263381,-98.390751,-207.271906,-194.443918,-112.013756,-89.176192,-97.691348,-150.335902,-185.151243,-234.668857,-245.057839,-218.660719,-142.889264,-100.037062,-40.297522,-44.671806,-87.786432,-89.024618,-4.548171,67.783488,165.438959,169.464242,167.32625,190.780292,197.720796,98.763504,8.00668,-111.628086,-98.155565,-48.750494,43.173861,39.9454,-33.739829,-69.223412,-78.50356,-35.800117,55.067206,3.596993,-39.381761,-55.054366,-62.730295,-159.529727,-206.04555,-209.538494,-167.718367,-152.280907,-153.885389,-167.171232,-205.725498,-256.796456,-363.922562,-360.626799,-268.608712,-153.221334,-89.990678,8.710982,12.023312,-102.314764,-168.910252,-185.259403,-109.226738,-72.580853,-8.048879,13.664647,2.256653,-37.686868,-139.769734,-163.140482,-156.246431,-138.511132,-116.744085,-86.933322,-94.431552,-151.015082,-197.55538,-252.322517,-203.909731,-161.093842,-54.365227,14.904154,73.402263,1.83331,-195.043666,-234.311781,-249.240036,-221.6688,-196.218149,-202.529601,-219.862797,-234.989316,-239.359375,-226.974469,-183.403088,-154.621448,-102.977232,-89.369497,-111.13885,-160.664919,-297.813045,-350.707349,-358.655389,-231.542474,-164.164056,-80.143046,-61.432308,-124.198341,-192.198908,-238.138744,-164.74688,-140.290122,-157.22902,-199.39103,-337.869496,-407.829764,-460.511244,-412.205392,-213.209546,-144.234297,-169.727025,-179.643362,-186.985738,-297.672366,-353.140552,-316.25368,-136.064193,-66.83049,-17.798701,-2.987198,16.425746,-10.374649,-99.677447,-121.506369,-65.283829,76.31332,91.880536,-66.969357,-162.941399,-204.566521,-155.448427,-71.795159,-131.498619,-144.089476,-78.608161,-65.924646,-163.16443,-261.165649,-430.497555,-439.097965,-324.757295,-173.52043,-106.913027,-42.948242,-64.039172,-196.443384,-269.866829,-297.086449,-191.082656,-155.623238,-168.43188,-190.421284,-185.173092,-164.858774,-149.057876,-156.44887,-146.821015,-63.426103,-33.846508,-104.184927,-192.477278,-360.696945,-406.546872,-368.629689,-189.849548,-106.835572,-96.3854,-167.211817,-267.948503,-265.454718,-230.423358,-209.326886,-165.085145,-110.721459,-90.594626,-123.447892,-168.621856,-272.945275,-295.491872,-155.985926,67.773984,118.054235,127.694476,124.357773,116.661669,94.880624,37.436614,35.565228,71.233863,140.747538,204.715969,312.525955,307.670644,155.297673,63.933389,22.120525,130.077503,185.090786,206.79119,161.716103,53.233727,21.161006,7.973171,19.980577,46.703959,90.872476,108.882991,87.460613,73.966207,69.308634,57.940314,32.454495,63.320747,107.083802,139.064609,94.097133,-17.231787,-56.08591,-128.913581,-155.456667:142.015017,153.769542,127.481006,44.527111,-5.433881,-116.920127,-137.653867,-35.706872,145.775373,216.846457,257.261307,241.768708,204.931927,160.933231,65.737253,79.008207,196.100116,211.523103,163.587099,74.077227,60.742867,65.515192,72.299926,140.086941,262.918141,289.166937,276.472106,271.631585,217.883283,141.752682,1.441767,-18.672885,-5.44539,28.495617,22.69038,-41.311761,-58.49518,-67.490801,-73.125596,-20.498911,171.54607,278.101319,387.844822,379.514181,277.852762,197.619038,71.277889,73.582258,173.186265,240.160659,215.428007,58.694747,-24.158406,-120.936453,-119.402447,10.007805,208.826821,260.54119,224.624724,188.061525,176.947687,171.093289,108.720944,96.111502,179.440071,253.33061,237.366317,162.368896,119.764452,54.615455,65.888449,96.586905,20.676738,1.563527,16.902227,12.534359,-31.080009,-60.164476,-71.500107,-54.778626,-39.4193,8.643259,55.62213,112.959813,76.810878,-118.40064,-188.559683,-128.090318,47.754232,98.91134,54.072815,6.211803,34.724555,98.414637,203.915808,234.790826,260.198289,259.656048,243.552943,178.813425,137.687841,51.357381,28.893546,42.261199,53.211315,30.795006,-28.355985,-24.180869,38.190771,43.821078,-23.861619,-50.056108,-26.705537,19.476931,11.681943,-81.2216,-138.382624,-198.130602,-194.245176,-119.048481,0.126661,35.008529,20.764797,-10.31831,-109.430977,-185.56687,-261.984896,-202.064889,19.528451,129.332943,128.484761,79.353868,41.359147,-86.074419,-151.5467,-144.032103,46.652962,151.12425,248.779414,229.793547,124.787724,67.438001,22.168326,53.287393,146.879847,166.06844,137.752242,57.523685,23.989856,-50.417386,-81.435193,-64.101885,47.87763,107.076259,157.334125,143.161854,73.376856,36.818949,-11.586386,-22.842471,-3.382928,79.612645,114.62021,77.098584,-13.284566,-243.465073,-292.365042,-203.651012,-126.322775,-125.022366,-122.24706,-140.431394,-228.323338,-268.688806,-290.199599,-263.720226,-177.170539,-90.632889,-73.564519,-146.396706,-195.818321,-248.459606,-249.324332,-146.266871,-1.80976,26.687749,12.34431,-0.547629,-21.114108,-41.193824,-39.739563,15.510582,150.935187,171.439926,143.977578,92.856584,71.902034,-6.144646,-45.955065,-69.508218,-55.724148,-38.610371,14.325275,34.106986,9.39274,-16.110999,13.551398,51.624674,77.646935,70.33397,60.83685,1.296069,-42.788497,-102.521146,-97.116328,-88.501479,-161.736646,-180.985642,-143.43671,-123.422524,-143.295013,-175.846084,-230.731523,-232.66376,-180.16036,-98.652948,-51.916999,42.437532,55.484275,-21.321147,-80.297138,-151.465902,-71.817854,-10.322015,29.03975,32.967155,43.302065,14.533479,-79.061539,-99.157199,-112.339005,-135.158502,-116.835871,-5.361608,48.749845,48.209131,1.773973,-69.71656,-36.116313,0.440632,19.068386,-2.040444,-52.276204,-70.866721,-70.97322,-54.567647,-18.465503,26.865755,42.409914,21.634464,-10.390202,-51.675299,-46.181032,-23.881508,24.819946,66.567083,90.592989,55.384598,-59.901845,-121.422546,-198.057172,-204.213342,-210.232653,-195.685343,-160.44682,-80.245189,-69.143383,-140.042885,-176.507974,-126.885787,-13.437972,12.769218,-33.307988,-91.418501,-203.163164,-240.522681,-241.960212,-186.569602,-23.502255,-0.846263,-51.243675,-139.524904,-164.589511,-221.50384,-236.993955,-133.595403,105.48391,188.348242,174.833435,118.168742,40.774461,13.432107,-65.44003,-95.827476,-61.691564,59.910376,69.805125,-53.589181,-129.109697,-186.933315,-153.706492,-51.178668,-85.644752,-135.382873,-164.354678,-151.979327,-165.932783,-212.205891,-322.399368,-339.657468,-286.012399,-186.363937,-132.494031,-81.632407,-120.585941,-272.201089,-306.117379,-265.738307,-246.142463,-243.812501,-244.967452,-264.067984,-290.220728,-293.617572,-288.894047,-247.236598,-91.021804,23.44378,31.48286,-36.949521,-94.783142,-216.583462,-241.592291,-145.432477,17.081897,45.511968,-15.225013,-49.276962,-93.996978,-131.375447,-157.955335,-109.968499,-3.002849,44.843448,65.843417,21.123173,-48.1184,-155.189348,-144.622471,16.793947,177.50745,199.779892,155.90095,121.680581,80.717222,69.989622,73.381491,96.153966,143.241965,183.475551,211.09372,277.688798,298.575349,221.402748,144.692866,71.578818,123.288777,158.100878,141.892994,86.426005,-7.06402,-12.187391,23.90496,16.786009,-66.776396,-39.892567,28.342088,90.661686,39.734317,-89.886274,-86.640228,38.977076,159.855778,190.889906,177.587827,135.31219,-0.325306,-73.685516,-99.420363,-43.110913:66.686315,89.626245,85.080394,38.127815,-3.720045,-90.997659,-93.987689,23.27624,159.559002,194.451529,210.833205,191.545323,98.069587,50.127411,18.520524,30.987513,87.953101,161.097515,159.466188,36.518397,-30.721998,-49.942423,-13.233168,85.426274,182.412944,195.324988,118.670105,80.636063,51.327677,1.193837,-148.956786,-165.892694,-72.771506,16.578927,43.903417,44.937245,7.265685,-80.443724,-83.103453,10.895071,121.61747,161.487963,218.836791,234.936179,169.33774,79.414899,-57.053079,-46.308247,71.449942,123.681625,102.617181,48.108492,17.712527,-96.945503,-139.618122,-61.047439,97.139751,119.065624,69.537185,45.573684,42.280891,43.481952,42.964225,58.881325,108.568526,146.121143,149.553075,124.353991,87.571388,-37.453011,-67.725989,-22.018779,6.751163,15.186915,52.805764,59.564891,-6.665687,-55.548889,-84.825488,-85.616116,-83.962048,12.855797,59.789087,22.260818,-56.201772,-191.330094,-203.355978,-120.437773,-13.430154,11.898416,23.432837,21.964071,14.574393,22.510502,76.308198,110.289463,168.494811,178.608953,153.61036,110.017559,91.038532,-0.684387,-35.774711,9.592191,51.932674,38.523922,30.278267,40.040459,19.617692,-17.620179,-64.676479,-45.279245,25.014409,-4.67076,-37.250374,-18.657922,-1.084953,-79.085673,-135.065627,-119.163112,-11.646944,15.144052,7.803363,-4.324469,-70.530005,-138.011195,-197.061735,-148.488676,6.66034,169.376727,217.920823,162.968986,86.958048,-77.764715,-131.065122,-56.927995,167.091507,221.127746,123.352615,39.615134,-43.137062,-58.987943,-89.50202,-94.163266,-84.697872,-73.743982,-82.051774,-125.807399,-150.279642,-203.391769,-229.997773,-237.081381,-107.485944,-28.601041,4.01972,-36.76783,-102.982801,-101.799025,-66.062651,-51.96951,-14.710619,25.192334,25.98032,-42.677951,-129.047942,-330.743688,-360.635738,-241.320118,-93.42892,-67.197151,-116.113265,-161.412413,-241.378481,-263.794589,-232.280831,-177.063949,-68.022537,-31.973309,-26.131364,-22.83461,-21.826739,-9.597828,11.786754,106.773417,174.802829,181.671739,182.052921,167.677481,108.757046,89.854668,115.398181,144.078334,177.608987,146.21133,122.591128,118.630256,110.594858,8.598552,-42.225548,-38.954596,-14.517338,-15.540906,5.715448,8.307171,-56.92762,-74.864328,43.452213,126.535139,159.284955,84.96322,55.797154,8.16182,-30.477741,-115.520219,-126.655304,-103.485751,-106.520188,-109.912596,-118.704599,-132.238612,-161.627795,-172.293095,-169.516965,-155.986317,-105.309672,-13.928193,19.53207,-7.808057,-57.710477,-161.433405,-188.445451,-113.520202,36.234711,70.736191,70.631234,65.720898,69.068972,64.53449,39.260228,36.628978,17.689854,-57.390007,-71.263605,-31.056975,-14.143621,-28.356976,-42.013562,-47.569392,8.200928,60.599588,132.016308,124.980297,44.459804,-4.884214,-60.72531,-44.600375,61.921884,95.623742,81.902041,105.214993,125.244408,104.930261,87.198666,107.665924,150.411866,148.558283,159.444926,190.28865,195.257987,143.752503,14.47304,-43.692527,-155.129488,-169.854661,-141.883335,-88.578163,-69.806099,-61.64124,-59.885011,-3.257441,100.300143,126.190608,51.327969,-17.90707,-95.535562,-115.756432,-142.574793,-107.318068,45.130344,126.658065,119.049745,39.725609,-20.533201,-124.820698,-131.050473,-47.065938,74.813737,128.89844,147.167547,114.706616,91.566993,100.688248,77.453939,62.534314,97.079561,144.336442,116.75278,-53.781576,-144.620041,-212.276355,-198.824135,-141.690008,-71.169501,-68.731351,-137.141848,-168.74842,-222.171524,-266.495572,-303.948991,-258.108824,-161.185318,-185.130129,-182.871126,-133.618957,-152.753896,-264.148124,-270.237009,-142.541209,-25.704235,-11.863021,-68.17624,-98.982067,-74.950101,-43.827965,-25.221646,-25.277908,35.480433,110.906168,105.912375,38.858852,-11.012503,-113.719823,-128.369821,-74.352392,4.69691,43.261774,58.363675,17.692182,-87.607257,-116.258493,-90.662462,-43.086615,60.987753,142.709513,155.738762,104.8488,75.301759,32.052575,13.185231,71.959061,208.284317,219.597332,121.973458,82.771214,78.923294,82.316695,106.622995,139.137502,194.142942,187.968643,176.826562,174.515591,153.65161,53.249421,24.270955,68.354029,160.285688,181.326787,80.094507,-25.613465,-201.131558,-245.091013,-233.404948,-186.598872,-67.246947,15.491614,17.878157,-37.62139,-54.448296,-38.208188,-24.87198,31.324089,171.599723,229.524264,175.025899,79.593543,-87.52332,-115.203281,-23.27931,57.189976:67.522412,126.138829,133.820386,91.903778,67.915807,28.661258,12.773521,41.815971,152.874339,218.493285,301.840358,296.925424,217.767379,158.027605,78.263381,109.434519,278.733371,367.656084,333.676148,173.588696,96.644246,10.561984,37.906099,236.576257,317.032877,266.819116,153.913942,137.254523,139.550358,108.803512,-32.383601,-85.33362,-41.84219,88.323324,126.004341,124.207127,84.848545,-61.593378,-124.703484,-89.25159,129.793987,258.517702,428.073922,451.422579,411.797027,326.057185,62.934083,-10.521436,50.176953,186.44289,208.877891,103.555562,15.975585,-116.802892,-138.406139,-19.067829,165.028993,190.029386,96.0169,26.867027,-11.413492,4.298529,-4.498958,-5.320257,85.530051,215.361492,221.032677,106.465459,55.495202,34.944144,35.680714,19.185856,-9.297488,-17.283575,-1.785996,10.244449,-28.29331,-85.199235,-171.521505,-164.038191,-59.429221,74.638451,106.586922,29.302585,-59.774512,-188.229047,-191.544267,-125.899176,-63.555673,-49.741144,-25.192782,10.657885,105.109923,129.026425,106.206558,84.311687,109.796601,193.371586,192.049652,98.99212,59.550622,45.066293,60.73187,101.31591,48.732067,19.248775,82.647847,139.03955,167.825355,123.309345,9.234031,5.064275,90.725786,169.83319,196.658551,180.231171,114.979871,-55.665527,-96.916266,-44.614162,70.945034,107.634263,100.230172,45.390131,-141.375961,-223.069686,-221.726938,-140.651396,28.530268,64.792055,42.643134,-27.31737,-58.363783,-124.285623,-166.809614,-185.266912,-42.013744,56.613643,186.618365,193.679837,111.973127,50.205703,1.951624,36.258376,106.718922,98.581803,75.858574,-14.517963,-57.623449,-93.193454,-101.289654,-102.311918,-19.502854,41.226546,48.114449,-21.971329,-126.26158,-111.945076,-28.324555,-2.837891,-9.350831,-18.853428,1.489842,61.376603,61.630156,-38.826658,-95.273396,-118.549279,-93.255885,-66.415725,36.059851,71.910134,44.443024,-7.048112,-74.597365,-49.092801,44.952969,70.447506,76.386939,90.863907,78.246062,1.876589,-21.206457,26.222288,90.706078,107.870764,115.002838,95.077405,45.530299,44.707149,135.462316,213.828948,288.72371,238.864395,215.517893,178.662257,148.899609,50.554699,12.664549,23.560036,43.32981,49.181367,80.883747,82.326284,35.829096,0.401108,-23.498265,5.572337,73.930226,64.192938,55.496607,92.593647,102.141084,10.620214,-37.08254,-27.763838,-24.427584,-45.076666,-91.99331,-108.897761,-114.451693,-122.291924,-180.688914,-214.935108,-239.528851,-189.853102,-157.158191,-97.493334,-74.368801,-93.937612,-136.161405,-187.111984,-80.718874,7.952054,98.576892,96.718295,77.617165,40.288312,-45.856301,-31.86567,18.463831,-70.560198,-119.989879,-145.684644,-149.039901,-204.852783,-220.244347,-143.165124,-42.567424,-1.631506,91.55841,132.633053,133.119279,59.788041,-125.859233,-152.050334,-80.238579,16.609795,51.008577,72.437759,72.168243,47.13911,20.174668,-1.6939,31.118855,62.284627,125.708057,131.655215,69.479985,6.461529,-139.961412,-196.679172,-241.295191,-201.150022,-174.329273,-142.946336,-137.445862,-171.781558,-197.838797,-173.434371,-76.14898,-26.19221,-2.306551,-62.299053,-250.189978,-309.901603,-307.707581,-280.191775,-239.860637,-180.393852,-144.609851,-143.858981,-187.005943,-281.784311,-284.950874,-134.733957,109.692014,180.668804,148.030023,96.427395,59.77363,55.872682,20.947427,15.393301,51.278813,107.852092,120.772985,56.041344,-15.145077,-152.597315,-174.100294,-121.76644,-139.930887,-181.901628,-198.964984,-170.881814,-159.481022,-206.479775,-326.293048,-341.943608,-257.477649,-150.840704,-123.593442,-87.515631,-88.595956,-182.135233,-226.973719,-200.226462,-118.545252,-87.683109,-67.123832,-80.714675,-108.840967,-113.127626,-99.502901,-73.872862,11.048139,105.982289,126.384394,64.002563,-11.945569,-208.14356,-264.589416,-176.590994,-14.972237,11.798214,-42.858558,-84.889491,-121.159422,-127.26608,-124.794849,-88.30022,43.885257,127.791063,124.183151,31.225776,-35.82377,-125.8624,-117.774444,-16.280847,96.806336,133.702166,120.83472,76.328174,5.243815,-6.218121,17.309156,48.669476,93.384702,120.46799,138.971053,164.687805,156.060779,67.363788,35.175705,82.844319,98.850148,66.68935,-20.412405,-69.148054,-135.039354,-137.94308,-99.661024,-85.592507,-98.88534,-21.852011,42.359374,74.860342,59.276786,23.857115,-7.013971,-40.741121,28.89154,95.455764,186.453304,157.907854,-15.233057,-99.284572,-162.564407,-150.237642:37.524552,120.797478,126.389369,79.070083,33.726756,-90.704379,-119.325621,-3.441005,189.973076,238.988999,185.162989,124.552367,43.98589,13.462356,56.109304,159.496645,328.588529,278.372027,209.723655,56.286719,-28.812759,-147.359452,-125.871617,43.68973,157.83817,170.211413,136.419575,92.180671,-57.711762,-154.626455,-275.386243,-243.937287,-41.345083,103.481847,122.26739,93.293183,45.114423,-101.649722,-146.912148,-77.176422,122.470941,212.520349,277.637118,254.974148,148.27788,76.565792,-23.613556,-14.955539,109.463178,246.471278,251.541561,79.589275,-51.278648,-257.645398,-283.038127,-152.466361,28.098995,87.671089,88.239541,19.177804,-149.408274,-199.732089,-145.757035,-56.683617,97.582712,163.380678,162.052144,72.039193,-2.821867,-106.600257,-102.669484,-19.744518,97.015119,141.048625,112.321367,49.25175,-86.468675,-128.718107,-122.05818,-104.198515,-81.174884,-5.144112,12.146465,-34.424781,-73.189865,-147.772155,-162.100006,-110.766343,-65.515285,-77.130084,-85.897265,-50.744504,18.305011,3.757792,-61.271308,-57.678864,33.386525,85.760569,36.592191,-102.217428,-123.098892,-121.120914,-118.263665,-62.350074,17.975152,59.061594,141.2004,154.010824,84.138193,35.504016,3.666881,7.863574,36.687413,142.298363,195.256779,191.067017,124.538982,-66.364162,-147.166373,-194.73781,-88.269779,-8.458952,51.019067,-3.20404,-166.494786,-220.317341,-222.94788,-177.435548,-13.549343,159.11557,181.760593,84.036676,1.760294,-142.952544,-160.257211,-59.382179,52.93072,68.923622,20.175101,-22.584668,-97.619827,-130.659674,-161.516533,-139.435842,-38.144943,11.223242,-26.91621,-169.209258,-222.59274,-288.968163,-309.744655,-287.834728,-178.29182,-120.593472,-102.617941,-134.412546,-173.271362,-171.666423,-136.342076,-110.904485,-87.20017,-57.401793,-36.929704,-55.892397,-116.372471,-258.31753,-257.396807,-110.978211,-76.157885,-94.532321,-36.002349,-4.252938,-36.791523,-55.810153,-36.943965,-23.804445,-8.111801,62.789787,105.208411,125.895824,97.992492,-5.130937,-26.300466,56.799049,167.719044,198.841704,172.399408,125.359396,63.341973,64.143838,115.774446,162.42764,261.204715,267.816866,220.565253,124.73023,121.712143,139.770724,121.808793,94.095722,140.969625,172.507556,142.002235,61.948624,-100.826057,-112.505154,40.223889,129.756895,167.050801,126.149181,119.141853,87.644816,30.231518,-116.070965,-117.993701,27.797981,74.250435,39.807633,-32.14652,-58.780331,-123.975743,-153.380488,-136.24422,-104.888171,-79.923673,-87.698607,-82.787383,-29.706814,-8.035654,-70.516947,-99.18947,-5.305913,109.870061,130.212121,181.427574,208.209226,156.658391,91.113991,41.850788,78.530824,162.028226,126.674286,68.015194,-26.154542,-37.205706,-3.327809,35.153281,117.57524,162.679549,190.660025,253.623578,259.959982,201.014402,149.478106,94.109741,111.327547,177.895833,212.329306,215.781646,211.64077,191.764026,121.687164,119.859877,238.362565,372.479334,387.934637,346.601403,336.746686,312.24008,253.549956,104.719383,65.410631,57.68843,75.365221,68.453597,29.952895,16.222779,11.509123,28.196697,99.959436,172.746262,197.629936,192.999124,159.690081,63.631138,19.795248,22.769109,64.463232,144.022236,167.516241,126.119733,-10.165713,-57.601144,-71.63315,-35.702016,71.341688,238.65805,353.293526,438.259662,376.952529,227.620251,184.890214,172.004693,203.587361,303.648507,355.185175,323.518682,157.006512,44.110488,-160.918345,-195.720412,-87.973549,39.79844,34.754875,-75.702208,-123.101799,-145.38188,-159.76165,-215.30245,-210.833012,-103.601941,8.982446,10.625141,-63.567309,-97.934377,-155.417997,-175.388108,-142.562516,-47.074842,-20.046217,-41.686599,-63.398547,-93.967533,-110.439815,-104.644055,-79.279282,-13.269774,78.13933,92.555453,-2.585823,-88.338238,-249.583345,-279.741944,-212.50896,-105.045199,-66.116939,-71.011209,-123.500614,-233.138972,-243.906669,-172.931659,-121.806969,-5.112728,113.066423,113.751318,-27.158289,-106.390085,-208.000974,-227.438006,-134.630807,77.466234,147.636401,114.775296,39.733582,-105.757653,-144.708395,-102.017934,-39.48932,44.630246,51.65879,45.132074,55.038628,60.699077,-7.147946,-48.547497,-28.607951,38.592697,41.513863,-80.958773,-190.288284,-335.00315,-342.047488,-284.479668,-249.203563,-190.718883,-105.780833,-68.079566,-47.710007,-64.846423,-154.003853,-188.37755,-136.461996,11.333508,80.091215,100.697985,44.453386,-83.775872,-123.490771,-147.901685,-128.609189:-140.410499,-126.790869,-111.225388,-51.709769,-31.742693,-71.119602,-98.710866,-18.893533,123.976277,141.41544,111.168969,104.618315,110.190405,96.196854,69.265811,106.748844,270.222503,343.551629,292.239763,67.09996,-11.450308,30.679766,103.687748,218.139014,230.677802,215.597858,167.712612,139.297321,124.951007,110.226705,-5.847173,-42.798505,41.991594,165.856363,181.916083,125.190619,71.29919,-43.193871,-82.711816,-52.313192,116.530772,218.881593,366.45995,383.679283,324.847675,253.081398,85.456668,40.203135,41.665985,134.231793,183.550306,161.530072,107.098046,19.065398,-9.759239,-0.280784,147.328877,209.080848,145.651034,50.165093,-79.118432,-94.19055,-48.230449,8.770977,111.816815,123.077772,109.085566,96.051892,95.086278,48.677656,31.592928,98.551808,151.67036,138.727523,102.275355,85.059539,9.472355,-59.081394,-175.324637,-177.249944,-85.676683,-3.121902,6.160983,-67.169641,-137.910718,-243.395473,-260.454688,-257.767035,-214.581233,-182.393747,-152.989433,-136.085566,20.321915,126.851743,209.911755,179.915887,80.090108,14.67314,-5.159575,-4.28677,25.578299,97.242441,123.07081,122.838047,29.135234,16.053766,144.449639,235.408779,327.531974,290.576533,90.607971,20.831004,67.964048,184.103632,200.583681,149.739863,116.559946,48.059526,-0.220262,-37.374907,60.04925,94.475567,49.413297,-12.262085,-146.786894,-199.08647,-224.480567,-178.692651,-36.364526,-20.945608,-59.099596,-98.601672,-83.032382,-58.992473,-89.501976,-208.446706,-180.785391,-62.848203,175.381282,194.129904,78.820102,28.81391,59.014375,122.920726,201.76045,143.739675,81.501243,-24.262828,-30.053629,25.37722,48.568963,58.625744,61.368465,64.48224,47.255278,22.55987,-53.847574,-100.208172,-147.787242,-119.954497,0.722183,131.703631,196.866598,238.516935,189.754014,62.853351,38.186296,45.506036,46.335452,53.778118,83.362576,84.240185,97.582451,118.481605,109.128522,75.980952,23.054972,17.653724,24.187663,17.365198,-2.798125,-66.740492,-85.382705,-35.878492,44.053511,43.855695,-16.848931,-30.000414,0.26625,15.827382,81.345338,134.472162,174.635314,177.347088,212.284447,308.342962,320.305475,214.853823,144.521193,99.704893,120.123962,137.431973,148.594168,98.354242,-53.975426,-79.493746,-6.502869,39.282633,57.817443,-15.013463,-43.186478,-24.695226,-19.345133,-111.765992,-161.463375,-124.5557,-41.605558,-36.107695,-95.647159,-133.399823,-123.967179,-109.539652,-174.797493,-201.595526,-140.449827,-35.192006,4.080856,68.219321,100.887993,91.458674,41.909673,4.089804,121.641707,181.619158,229.93374,232.71235,199.562864,148.661029,36.608902,26.527171,65.501309,2.926827,-53.751747,-86.793357,-74.249872,-119.24258,-144.530458,-33.591787,138.695847,159.392536,143.818555,162.584967,234.344837,231.438641,87.734705,-11.393894,-143.732429,-121.159682,-72.130735,-13.652062,-18.166267,-50.164709,-46.502662,-7.33734,-31.730819,-38.591284,56.787628,109.918668,48.364288,-54.347958,-215.34366,-224.271559,-166.722724,-124.675776,-84.9113,82.202827,155.339395,81.116621,-30.683801,-111.943958,3.845373,43.152997,17.418901,-27.070898,-132.85452,-201.05753,-329.325302,-328.342452,-203.425085,-146.837138,-144.330958,-112.262287,-105.790593,-152.424611,-157.698096,-69.270724,35.06214,72.057414,102.762941,101.584314,103.167343,90.85312,21.439485,15.066176,136.497434,282.535757,316.405911,296.08518,234.963198,50.60619,10.047174,112.41878,128.725612,76.242583,85.734425,147.834606,121.145605,0.628316,-191.702696,-173.718672,-15.839154,49.760095,52.512599,79.632412,86.769972,7.076229,-47.153821,-27.311154,69.44576,81.333768,79.458683,96.766822,118.913434,88.486274,28.414297,52.200976,100.216063,47.769276,24.370062,-32.622197,-82.932581,-195.869604,-233.498838,-258.730591,-257.94877,-214.655364,-73.106196,-55.962481,-143.68587,-191.267104,-203.06421,-158.096637,-37.007813,-39.11437,-98.779898,-165.360072,-126.592428,-62.261999,-87.860234,-120.616625,-11.979623,45.864493,50.156523,12.457574,-34.35789,-49.108803,-91.550817,-105.867082,-150.473638,-116.46487,-20.868036,175.055844,191.889737,67.048857,11.381144,23.516178,35.657287,23.780586,-26.572443,-77.621505,-137.968425,-122.735992,-83.891446,-80.124584,-59.341867,33.581563,70.688508,67.634585,63.973746,53.390426,16.735482,-57.03374,-12.191073,41.646378,60.465397,15.042683,-104.390846,-178.23689,-295.083054,-298.943368:-103.458428,-6.159821,-3.446587,-93.38678,-143.15526,-159.640344,-111.315217,75.958469,245.703958,300.86276,304.50258,234.068008,32.072261,-41.15648,20.229772,147.645218,334.116489,287.697374,216.140938,20.977788,-70.942775,-124.693886,-70.06256,112.404055,237.184561,252.174515,182.314646,122.650559,46.685466,28.571386,9.335428,33.553191,160.165636,242.955197,230.838756,138.220234,66.965733,-92.050952,-130.528979,-43.672827,167.503796,280.020426,396.078542,371.046234,219.771166,119.281466,-27.333587,-19.926653,150.17261,296.204355,272.392373,104.640562,29.950177,-58.550758,-63.646288,17.810747,109.814417,120.705888,37.616266,-35.736483,-119.120813,-118.841667,-71.659712,-15.916439,156.570584,279.325327,266.011588,117.800744,28.960067,-98.891,-104.759884,42.822454,209.111262,213.657529,108.64526,51.004293,-60.26696,-127.919773,-217.473001,-199.82152,-63.908707,58.002061,72.068888,8.607797,-59.320145,-208.811471,-241.382281,-184.334584,-104.549994,-86.527121,-50.843225,-20.758282,16.827423,3.790886,-36.673443,-29.377565,60.619324,146.21283,131.058084,16.823077,-40.364567,-114.125292,-114.698075,-20.505291,84.949847,105.44438,134.134851,145.880481,123.958753,91.529485,35.730827,36.070841,60.583199,116.352409,183.239186,262.942756,202.376863,-45.215423,-138.529395,-163.518304,-59.589381,6.489538,25.046476,-51.995874,-212.258114,-234.979041,-199.817036,-161.264557,-33.076074,89.304703,75.648159,-76.858875,-139.791804,-178.520266,-177.118288,-154.193874,-42.400778,47.892831,137.628048,97.911047,-43.53545,-91.293697,-86.442489,-42.32752,38.826378,9.556176,-52.436232,-164.539249,-184.437505,-191.581288,-183.570911,-125.799732,-46.401713,-16.793055,-42.38117,-103.414432,-201.495274,-198.307929,-119.344235,-66.137489,35.611854,83.613363,72.413547,-16.635766,-81.71534,-209.650143,-229.109271,-149.13643,-55.728888,-3.855667,89.015628,91.251788,11.558156,-54.404047,-135.360627,-95.278796,60.472795,81.373785,56.076802,30.054544,0.701342,-133.397421,-169.486133,-72.547628,39.561592,62.089223,68.029212,43.569283,-21.846499,-28.525444,80.129352,162.270117,228.547604,239.452556,252.965722,245.266838,210.008076,72.624286,13.735716,58.878777,189.980036,219.152965,193.1046,133.262266,-41.121535,-108.579135,-81.671601,7.968889,201.799014,295.526789,278.497832,128.288969,23.335993,-134.820163,-132.320582,15.110204,108.39986,89.292681,-33.388375,-99.355937,-177.142526,-192.771372,-179.453718,-150.144095,-72.662611,15.450345,39.422833,32.353822,21.671892,-20.472333,-41.296,12.618225,182.48507,258.875655,340.345293,346.611294,265.239839,188.078162,122.996517,157.008672,220.120034,200.313073,161.25825,65.94871,22.435354,-62.421277,-65.444451,70.087927,216.853108,260.46481,321.858099,335.819147,299.210558,245.588623,157.095804,167.921336,245.32834,249.006825,227.181499,178.285456,154.990298,127.296882,129.637581,158.204366,228.416676,287.2657,388.742113,393.580642,288.278134,205.745433,85.231872,54.054524,24.69082,87.155258,135.806955,173.491541,150.550593,63.128031,50.736073,152.682629,239.823467,217.767044,131.03776,112.520721,75.480292,19.754522,-79.502034,-67.498489,53.347305,135.281313,119.995032,36.144207,13.547596,9.155271,8.125086,67.422593,277.76584,378.084462,412.801427,365.682323,284.930634,260.326177,207.05603,200.744662,314.178839,454.475912,434.473493,253.763223,173.183967,107.934209,105.20771,115.53007,107.241551,100.039732,129.516634,147.260267,66.086246,-31.593026,-172.102932,-151.193179,34.482305,147.261817,115.372864,-20.42651,-68.873176,-132.588331,-147.117513,-67.723413,109.754987,168.961743,117.945124,42.186418,-86.902372,-141.068481,-197.228046,-166.828147,2.361378,134.375543,103.802401,-92.440166,-187.500699,-314.665409,-328.546606,-245.438015,-131.583948,-98.393692,-114.486164,-150.10309,-204.289486,-216.467029,-230.428948,-221.764506,-120.366203,12.611731,17.96251,-137.600851,-231.783225,-301.686991,-279.726888,-187.952577,-77.702496,-20.06218,23.0342,-12.221901,-142.131862,-202.247928,-236.411508,-209.033481,-133.448809,-68.226496,-50.15674,-45.018566,-50.631537,-77.971875,-82.824879,-57.68384,-29.517729,-19.717058,-69.763078,-143.859241,-291.308465,-320.431335,-278.984618,-233.740596,-156.396931,-87.163532,-44.96938,-1.924656,-22.192283,-104.356281,-134.648674,-127.096623,-36.202409,9.622958,2.305361,-49.269392,-179.310294,-243.975724,-335.478891,-335.593849:-196.436104,-28.455011,30.209481,5.022988,-22.810964,-13.375825,4.999623,83.755717,184.727988,213.589428,246.114865,233.195901,146.617445,119.054296,170.832714,232.143474,319.636834,325.365321,300.475521,156.675202,66.065889,11.275616,67.006218,164.610984,68.436664,17.510871,22.370316,40.368745,19.29561,-19.794915,-104.677895,-106.206219,-1.06672,54.584909,49.301691,43.265591,30.448452,-57.819566,-113.492233,-136.662388,-21.304478,57.704322,183.997851,200.949574,128.709813,58.910399,-32.087004,-14.550603,71.496378,92.753969,83.16047,69.909184,68.060948,-11.533758,-82.365041,-131.399942,-46.077324,-8.923828,-40.642524,-101.757405,-164.333898,-152.125292,-148.909688,-154.181986,-112.174072,-49.795541,-20.866099,25.206645,23.014542,-44.728378,-75.346073,-26.840935,105.32041,164.829361,251.339979,260.90895,165.097289,70.599487,-69.65699,-60.886026,54.978426,62.593372,7.469085,-89.639268,-110.016726,-144.141163,-155.181471,-143.310138,-161.873006,-160.006299,-74.975569,-32.151271,-22.714178,-32.848928,38.417466,113.800128,143.799913,11.244658,-25.568602,2.262233,57.31946,184.358768,206.927334,162.731933,120.054081,127.010122,161.997382,172.952678,206.941038,224.677485,176.426374,116.575466,35.213486,96.483487,171.668329,247.580562,212.319943,84.78702,39.984394,37.942184,53.77698,35.76715,5.625154,-4.508834,-87.558623,-146.7066,-184.620655,-129.653114,36.565595,-25.511211,-123.952819,-190.401813,-138.515206,-75.840224,-110.740619,-171.177732,-114.991084,-72.858306,-2.716647,19.375859,48.154048,44.87168,-42.572864,-98.186538,-126.964628,-104.236065,-107.222833,-86.592961,-49.537953,-24.092761,-59.43592,-121.485206,-78.656212,-33.039957,22.869123,11.648591,-90.887034,-158.664344,-169.134824,-74.412095,150.443472,207.856025,208.600883,221.37178,208.277865,129.984039,80.37946,2.856247,-12.03917,8.463882,92.382265,127.234501,129.027853,98.014644,19.093344,-3.282215,5.225815,27.017987,11.520712,-70.187661,-105.515479,-161.651332,-187.435182,-160.492076,-46.016277,-3.168518,53.53667,83.356971,122.0748,113.925303,106.126196,155.505553,288.52108,297.265513,290.014214,303.240187,298.803141,282.257725,277.662428,198.00691,37.078742,-4.926437,-15.248039,-39.984144,-126.385105,-149.333045,-148.943363,-136.908469,-97.12558,-54.350687,-42.425833,-66.423529,-102.26427,-193.454129,-220.206619,-158.523916,-56.10924,-21.406377,53.576811,80.831539,71.139422,38.814263,-22.157098,-33.670705,-28.974673,19.731085,57.566798,92.396043,81.498111,72.855718,105.164537,220.761487,287.430687,286.754104,254.990332,219.969422,97.142504,27.24651,-31.816911,4.367392,74.369759,14.544719,-5.576982,19.549955,24.982085,-1.674057,-7.934481,6.181878,43.864245,71.597437,140.765984,187.785829,283.571171,289.742257,180.348368,100.884323,-31.407852,-78.016066,-66.625969,-41.440498,-55.918018,-97.745453,-90.759119,-65.455906,-105.183387,-93.397902,33.103011,75.979126,38.663566,-2.711413,-59.715766,-93.548526,-193.88621,-161.636223,-46.547405,213.170007,249.269302,84.596006,-22.521909,-79.721039,-33.056094,-33.455766,-52.52696,-46.794331,-49.001511,-93.833217,-204.399736,-200.366819,-69.595932,50.874483,82.898918,81.908954,55.749994,32.247262,42.649419,50.682517,63.20124,104.343588,209.579885,222.194559,135.691766,97.208333,162.71774,229.567703,304.773917,358.896056,401.297991,432.665696,403.33284,338.607586,332.900134,337.619049,266.847971,233.404646,289.115753,361.010395,419.85633,360.938258,161.056523,100.295612,119.276527,222.350984,256.707613,245.300313,226.047331,185.184036,153.390909,129.071569,182.959366,212.646129,268.823058,298.372898,334.225157,313.755117,221.927503,208.725513,266.578155,299.132653,286.191106,195.606401,120.472672,-41.311454,-87.747102,-42.599031,53.989236,80.723514,120.974129,125.536562,72.616107,24.516207,-40.297708,-18.045836,133.622702,206.850724,142.748321,-57.297248,-110.236601,-121.795521,-111.981678,-36.239187,34.437361,26.004832,-51.91152,-91.727333,-89.312152,-68.312821,-103.387682,-147.429396,-221.588802,-222.727551,-166.982233,28.78181,114.358397,138.656855,87.044307,25.680654,51.966455,19.25121,-122.912825,-154.826131,-88.737656,-58.128122,-78.229229,-81.159046,-5.271244,108.75428,123.272691,30.231595,-23.844823,-88.150327,-120.796302,-157.705666,-144.453318,-153.253063,-201.224567,-201.210391,-134.025769,-135.137636,-261.83649,-311.570195:-158.936055,5.57455,95.803185,145.73029,130.45736,73.707477,49.73523,110.239841,215.937754,232.557069,293.466668,345.783057,368.862817,322.460096,218.284659,216.106828,314.15175,370.206682,338.030339,204.523775,156.621267,163.520085,218.601102,357.134257,347.598852,307.840537,263.013808,258.063527,249.029676,209.572992,83.105644,74.910453,184.381845,248.781999,259.170109,253.862057,227.687473,151.710915,122.960184,153.164765,334.91932,441.848037,574.313154,593.304299,562.742655,499.512175,287.812405,206.556314,218.390725,311.794913,303.573874,204.484921,166.245552,90.583043,42.137701,64.502902,249.943433,305.580216,226.178354,137.863296,46.340827,40.53178,44.470876,70.550021,155.688935,162.706966,129.989617,99.107952,124.756685,127.777664,76.426658,53.921721,208.294629,259.381376,246.3022,230.022407,195.625795,134.533694,-23.579875,-55.186466,-10.763975,73.805269,92.347034,29.224198,-36.276986,-146.281544,-153.597611,-43.186944,47.928151,48.609246,63.064878,92.385543,166.991949,202.698183,285.603265,305.192773,211.096585,98.38746,70.514129,36.259441,78.390299,293.164481,360.115008,271.634763,95.947397,65.10161,111.58789,162.177865,278.979612,299.076368,183.198747,94.439178,36.417157,141.354596,167.0294,87.416563,48.509187,75.744869,106.565079,115.56965,98.831695,89.037971,38.696787,1.612011,-64.784033,-71.848784,-26.116954,9.690368,76.059778,85.298863,64.739236,7.338744,-8.20451,-17.45945,-33.292036,-29.723556,78.4609,155.107413,282.24791,290.291825,216.25859,189.465371,206.850195,218.911039,182.356784,150.688576,172.769623,242.054984,257.393038,242.327998,223.774812,178.877143,157.389295,174.709184,190.763255,165.188387,80.603425,14.854979,-138.259833,-160.911609,-51.387771,103.208971,153.976739,167.928992,144.522174,89.017503,65.299179,32.556094,-32.110471,-63.351277,-56.929748,-43.05793,-58.989076,-77.910923,-107.054489,-112.02599,-78.29373,-52.934296,-92.286559,-233.001909,-289.235337,-335.01125,-306.818962,-178.819216,-149.854518,-165.32932,-125.892843,-83.478007,-13.870656,10.81429,27.059692,40.02024,113.045887,174.546358,190.904128,220.088569,224.224885,148.959499,79.9619,-26.937305,-61.342736,-58.625313,-58.195491,-76.990815,-143.388891,-181.210873,-209.241965,-170.179415,-43.495278,-10.68857,-33.97266,-102.791466,-154.282302,-280.332442,-310.358241,-270.344215,-217.256223,-190.581013,-106.484674,-77.560301,-99.757344,-138.737673,-186.910007,-164.730082,-68.927424,1.501333,24.802484,61.894118,71.638068,44.318889,24.416856,51.507513,130.309303,144.904371,111.103318,92.805804,71.962117,33.422121,-74.340674,-83.043396,-39.836758,-48.556851,-63.007945,-57.760668,-29.655627,-5.47986,-26.440328,-54.904812,-79.240038,-85.381748,7.217043,89.781434,174.525425,137.537073,-43.748105,-143.523939,-278.498633,-291.870939,-275.700479,-241.710465,-226.050027,-228.443151,-249.390067,-264.966515,-213.655879,-167.017438,-42.548856,3.932962,-43.904919,-126.886391,-244.171262,-247.854912,-222.775763,-154.252729,-79.706024,81.466872,116.726958,27.822363,-39.373459,-71.691121,-94.140487,-125.46113,-178.948675,-206.369989,-253.219217,-262.580623,-279.811532,-281.658101,-227.482528,-133.842946,-88.045692,-39.843445,-61.109423,-175.993655,-211.748785,-158.240833,-86.993789,-82.535233,-88.902304,-87.096118,-82.639683,-81.128867,-39.398606,2.99535,62.391966,85.211665,96.221239,79.333725,44.754213,-6.344267,2.879666,21.355347,-32.49847,-39.153434,18.362663,33.308703,-68.781266,-184.054703,-376.342297,-389.579419,-340.933386,-273.527825,-197.786284,-20.602385,17.353994,-99.191765,-193.470967,-224.703022,-137.91455,-114.123327,-81.262692,-52.441784,18.130764,17.113795,-66.267475,-86.873958,-55.94625,-45.749034,-64.561008,-139.368292,-186.417983,-276.562664,-300.836809,-264.595528,-207.482411,-183.931796,-90.327288,-54.190067,-107.230902,-176.57032,-248.205349,-216.635968,-112.219253,-96.500919,-131.331535,-224.70817,-252.573624,-275.071539,-261.004344,-137.515725,-37.557962,-30.985073,-24.152552,5.289914,74.111087,61.304244,-63.941516,-126.08729,-183.281005,-123.983225,-46.034149,146.86612,201.163951,125.000442,48.671265,5.209482,46.086382,53.416422,61.418855,69.508134,84.447172,76.267785,19.95521,-1.554516,14.179414,63.087626,65.904697,-17.125896,-70.776176,-114.843071,-116.402644,-109.837235,-69.662733,-33.759377,38.584823,57.105978,15.771143,-63.930893,-246.722313,-274.140632:-135.524561,-38.993472,19.025132,82.035877,104.811597,133.892053,117.524868,124.183461,230.820118,272.480834,282.874673,253.444771,184.400171,158.923092,153.262171,208.857602,388.782144,432.662423,378.445002,195.754457,117.668496,57.661651,74.805427,144.360833,83.133535,14.56846,-40.280207,-11.028617,59.359571,53.281999,25.04966,59.714708,167.302926,179.40892,153.404016,110.204086,115.711704,122.461093,96.067203,35.693978,100.107376,178.821423,305.286972,324.758499,259.162528,165.747326,-26.17766,-48.035555,85.263021,252.482919,253.070534,132.720706,100.238043,91.79602,58.388293,-12.309713,59.734739,103.024759,33.878875,-66.070072,-184.050519,-164.244275,-62.884752,-10.682296,103.049149,192.242174,198.676585,122.53119,72.225559,11.050161,3.137828,46.608489,129.403299,168.686054,223.989307,223.089743,116.086427,11.842473,-181.169264,-205.686764,-111.212596,-4.759115,3.620505,-74.819025,-137.397796,-197.618619,-170.170566,-144.054866,-268.181079,-291.743708,-148.313728,-40.012413,114.811705,127.978696,50.035125,23.027225,29.551166,8.485177,-32.812004,-98.001701,-74.227484,14.819648,17.034464,-5.072548,41.40178,65.565113,100.820119,120.650119,175.986607,174.581982,54.105487,3.865213,42.932181,165.293181,213.46675,208.069405,158.391868,15.265433,-50.048087,-82.389879,-38.309203,-21.395177,-3.915031,-8.4314,-50.688521,-72.711273,-127.669839,-149.34346,-98.213298,-16.394475,-24.868338,-137.792784,-179.550942,-145.408111,-132.537632,-217.83738,-233.638147,-159.04621,-18.687538,-1.557614,-44.017555,-97.61183,-155.290534,-116.506923,-50.707041,-103.295436,-120.48408,-137.647025,-144.808755,-136.520257,-128.699577,-89.438861,-20.057393,-0.860666,8.345791,7.25131,-26.442881,-42.240579,11.792605,69.412446,126.542194,117.292193,113.657775,94.721959,66.322354,-37.509942,-80.393151,-97.002849,-55.220117,-6.887244,98.982676,101.365653,10.533882,-27.750187,-20.469199,-1.778181,-32.999038,-77.387099,-83.535416,-138.738961,-177.700713,-230.020558,-244.6939,-212.875512,-83.878037,-18.530995,6.495208,-35.762504,-44.331147,19.865111,150.267915,178.432703,165.402981,137.270583,151.990935,232.475438,261.96491,250.533799,236.915529,231.27981,177.150827,143.752084,111.094023,87.971938,-22.493979,-79.704425,-65.000936,11.82543,145.044468,141.711387,111.905577,4.26674,-72.054029,-205.231579,-214.361505,-78.750223,75.601734,100.470748,64.206747,30.026076,-16.078384,-41.250231,-172.002873,-244.04296,-239.67749,-67.937574,5.330977,64.151635,76.238396,65.130171,38.143987,65.20304,207.988015,244.006794,188.925176,158.673359,152.795681,116.554034,10.063309,20.191205,120.946866,117.578387,57.926052,-55.679681,-53.848119,-2.242081,5.613613,22.048392,42.925076,41.850165,76.895469,121.470389,196.670193,185.266242,40.602247,-32.072015,-53.787126,-43.732659,-62.337007,-110.477062,-129.629311,-123.114293,-104.090401,-75.964294,-29.178951,1.201672,10.840234,-12.17168,-60.940932,-87.482931,-157.645223,-182.92491,-172.895866,-71.391452,-28.743026,23.331538,60.254429,61.096786,10.277875,-16.010832,15.258003,-16.214398,-104.177699,-123.287737,-136.291469,-161.033666,-223.54061,-216.913068,-149.201314,-110.076333,-89.79387,-54.224048,-67.788266,-151.643016,-167.44758,-35.402645,189.816923,254.037165,213.594381,149.336676,109.550497,126.633105,110.533312,95.205118,170.776056,338.87279,381.91482,300.078936,207.795062,91.300287,95.967182,148.997631,130.178063,105.279695,125.114253,163.237514,171.113434,113.664967,-9.471209,-6.35691,82.742532,184.004167,230.707433,195.926305,112.946948,-29.733122,-37.345429,54.477249,107.794023,114.392447,119.4929,115.030417,123.019304,108.572151,-13.537175,-65.152259,-19.243249,153.702379,200.572892,81.877422,-38.183494,-202.041846,-216.567665,-133.658797,-44.954647,-37.603799,-49.084055,-43.315444,-8.334464,-6.229328,-64.62209,-73.404571,48.080027,141.020155,106.568552,-11.749526,-33.916863,-68.553649,-118.210951,-166.906146,-50.226412,13.627133,-2.158102,-64.677892,-123.802678,-109.955244,-112.277116,-143.437403,-180.702721,-96.88923,-22.750141,147.047904,212.522286,186.852182,120.01572,57.216849,75.792812,56.200906,-35.937008,-63.599885,-29.610371,-14.457396,-75.40365,-104.891026,-62.323392,42.832899,83.394185,77.720265,33.539147,-64.695289,-98.913013,-108.362793,-61.474602,-33.245026,3.342089,-1.134457,-92.120579,-193.665321,-346.593463,-299.435177:right
-79.256233,-6.371783,61.857201,123.784974,71.643698,-148.796841,-263.479349,-361.721494,-190.545833,-49.065401,137.918898,134.054016,35.596423,-5.373523,-102.734,-150.290121,-114.164257,67.511811,126.948652,84.667653,17.801007,-69.4001,-77.391027,-98.382156,-118.449597,-89.575679,22.000783,79.003135,143.615904,126.384578,7.397036,-53.603217,-90.419452,50.542913,161.996738,297.136496,292.417612,184.605791,109.259699,74.539467,228.997124,305.721733,374.104944,339.573362,150.410208,65.649552,20.313642,38.1689,88.559168,183.915083,242.88476,217.108808,112.546449,-86.965509,-113.113172,-26.336912,86.105176,131.295389,269.651493,332.520409,275.186255,153.132045,-51.20366,-42.71785,141.346194,245.722711,237.93979,212.956476,213.002326,150.042769,77.507994,-16.56653,15.332058,54.749271,159.08856,190.63607,138.714843,74.43383,-13.633143,-4.473367,36.991029,-10.973733,-25.36408,-8.173859,-17.836842,-108.07375,-158.803383,-166.487064,-43.359598,47.33534,174.741494,152.025189,26.716733,8.191463,58.018426,96.257337,176.203322,184.038865,159.389394,89.434312,45.799306,-61.614516,-114.850322,-125.56275,41.516357,147.553635,278.806913,282.257371,198.453193,131.213437,-1.064648,-34.674956,-15.340482,39.304221,37.72374,-29.386953,-47.101831,-48.279785,-75.674572,-133.363221,-122.69218,-110.701762,-20.499746,49.901032,138.065418,138.288204,95.334737,88.166485,96.863938,110.792339,128.34366,107.049707,52.879062,-111.433905,-191.282581,-201.746306,-78.888855,-73.240227,-175.274802,-233.84323,-314.625324,-335.745056,-362.449381,-368.000094,-328.091521,-276.596657,-274.937913,-293.596667,-299.338259,-318.92047,-342.592522,-354.233032,-248.20268,-188.921537,-116.27557,-85.144404,-14.935253,13.691806,27.1825,15.553427,-12.950109,28.69723,109.745061,256.592148,250.794452,117.319205,38.920249,-98.854653,-220.075152,-227.157344,-78.732236,-8.290533,-31.091532,-87.648031,-169.079079,-164.614548,-91.015455,-31.825657,-19.160931,-37.750214,-57.736892,-116.720608,-158.40649,-186.425448,-95.549444,-25.844912,78.190692,83.409676,64.614713,58.38201,-16.616691,-64.879029,-69.116591,-9.722473,17.494045,83.741295,125.216552,195.598623,209.522086,208.42105,214.867483,218.836712,188.705149,170.773081,182.949483,180.336194,97.335054,55.476725,14.902612,19.470786,68.842305,184.93432,187.399879,30.364772,-88.4172,-181.568576,-58.126358,-19.389035,-77.752539,-149.340133,-272.314018,-297.014441,-302.507747,-297.63179,-296.350847,-280.695839,-244.561421,-218.400945,-246.458303,-288.514802,-298.68789,-306.490186,-274.458897,-263.016728,-254.481412,-245.0152,-210.061872,-201.750627,-228.585828,-239.224276,-208.425765,-164.500299,-149.689775,-143.373797,-150.004047,-171.257303,-190.887793,-194.625631,-154.700456,-162.186578,-155.591415,-125.57256,-83.685895,-77.078949,-104.79726,-128.522403,-81.016382,97.830479,159.732236,79.362003,-30.01316,-208.192936,-255.69219,-223.284848,-20.2139,82.367242,159.037944,113.554522,-55.507646,-133.089431,-239.77308,-255.119554,-191.480438,-30.23651,72.811829,196.170927,205.626402,208.071291,189.834203,103.779511,56.960934,59.971819,44.361017,6.150397,-55.730626,-61.094608,-65.110349,-62.625256,-62.61871,-17.908592,55.124562,153.455174,121.027301,-54.708929,-139.550153,-166.688274,-11.883826,66.572459,111.309099,78.880057,-8.232583,-37.926341,-51.440575,-35.739144,-27.468468,-38.318674,17.113951,222.594811,278.562351,172.004103,64.841018,-57.274522,-68.681371,-75.100534,-95.384859,-112.945386,-158.837315,-181.881716,-242.020334,-281.431456,-345.115389,-231.065005,-99.307603,70.494797,35.302179,-197.725152,-302.954544,-308.967573,-133.699244,-69.067326,-21.566601,-43.497812,-238.415455,-384.564061,-547.570709,-511.969034,-380.855224,-388.432587,-399.279737,-345.898927,-325.092849,-406.991843,-492.261593,-596.959233,-487.421612,-367.705505,-165.450248,-141.072349,-198.732722,-231.851498,-260.447569,-255.427343,-244.855655,-227.522308,-182.19808,-88.656171,-84.779081,-124.391545,-134.71242,-109.258823,-76.61017,-93.264073,-221.023681,-296.557139,-307.269215,-238.234374,-141.437451,-164.426036,-275.866106,-298.851856,-250.319873,-98.10662,-35.948414,-44.949918,-128.952431,-300.294008,-280.915298,-197.51416,11.634808,67.475102,5.268434,-80.626456,-217.784565,-224.959274,-153.311354,-72.415649,-42.784031,-53.775563,-73.551966,-49.782609,-40.828665,-86.007749,-76.122999,-29.66247,56.833214,55.164807,6.722583,0.517522,-12.170209,-17.525417:-58.123523,53.040937,125.508667,116.363279,41.542196,-102.019667,-142.081496,-141.664565,-4.107555,111.291932,300.799329,308.882731,198.521677,151.168541,104.789258,92.577602,130.545011,207.07539,219.705702,179.793854,128.362471,-29.637487,-95.786629,-99.760407,-37.227114,-21.682013,17.681789,46.304274,59.747778,17.018774,-128.361598,-179.03074,-160.453443,-17.854036,51.34494,98.714486,70.219094,-41.310525,-81.702467,-33.865448,79.132721,112.678317,193.991238,219.729492,120.239074,40.473177,-6.509156,15.227291,99.715907,237.278685,243.535423,45.365677,-72.766268,-190.642807,-194.934944,-144.819997,-1.665672,120.051104,293.988006,278.323293,113.484925,31.936295,-14.441965,27.486336,149.661255,197.823689,187.541937,159.084961,156.953225,108.095438,41.887897,-51.54447,13.413919,67.567226,123.888095,102.590112,31.3901,20.711559,35.675663,52.247566,78.428126,75.892983,79.826889,70.472221,38.035957,-77.398887,-132.804157,-154.615099,-45.524368,43.062831,147.207704,111.914272,-36.894628,-77.28419,-28.994853,32.293052,141.334501,229.961795,261.213107,200.197254,114.131657,-39.094723,-68.39739,-13.675035,114.764311,194.502045,320.343184,308.577983,143.566201,32.147003,-120.957602,-104.615122,40.033415,109.656445,118.246479,126.980936,121.868581,69.581621,26.641895,-0.670612,50.849837,54.720168,55.250412,91.025891,170.761341,154.853774,65.75851,66.208019,143.910843,185.35431,179.680555,112.810761,52.5217,-99.076162,-169.654586,-199.922261,-85.01684,-35.581221,-0.176974,-6.805584,-65.360738,-136.322884,-331.881012,-382.741571,-301.038134,-122.944866,-59.690533,-45.360359,-75.397,-112.180563,-121.421777,-94.262481,63.678123,130.65424,123.321659,86.210993,91.089074,114.176205,82.935744,54.964641,58.273095,100.048967,129.177748,154.113355,125.167839,-0.58372,-67.974051,-141.876065,-147.188474,-122.023191,-55.824849,-63.366696,-99.690147,-72.44783,-5.177128,-2.345886,-3.798549,24.134469,27.910978,-32.473619,-80.093931,-163.567175,-188.987323,-151.549391,-46.135867,-3.502459,69.19203,88.833655,51.231091,5.39432,-56.433292,-62.109316,-47.47684,46.427419,108.467629,130.193312,102.318863,94.692971,114.849373,159.55353,195.016322,209.166091,228.04325,227.963465,187.359015,131.63487,19.807917,2.450426,3.257177,46.32895,84.494205,66.589582,-0.092001,-143.734057,-194.519556,-213.178682,-96.417592,-33.878057,-51.132957,-132.827251,-298.194818,-336.101852,-343.761512,-336.539118,-303.882792,-250.024069,-234.109054,-294.127176,-362.873576,-442.598017,-420.040479,-345.429794,-331.351077,-312.162415,-243.686518,-240.090111,-320.6508,-366.823063,-390.691792,-358.774957,-225.838782,-116.257671,-127.298324,-222.424423,-224.710764,-125.421011,-102.320697,-164.364451,-185.855077,-146.771649,-61.167116,-57.88593,-95.624188,-108.981102,-149.872758,-175.672066,-164.791978,-42.826232,19.491082,-1.363213,-82.558085,-221.557815,-245.154799,-222.705642,-140.392257,-89.29858,-17.090545,-26.5497,-160.389536,-261.642865,-383.110274,-341.670686,-138.856918,-19.865385,15.970949,93.496176,129.502746,114.810387,39.818126,-114.207923,-127.103682,-90.407182,7.01298,35.938106,44.847964,33.396751,-35.829208,-82.016771,-139.872614,-79.692255,-17.143031,13.462573,-38.105855,-161.776964,-203.198332,-215.764683,-101.730944,-15.293667,103.69176,80.668788,-89.250446,-151.030046,-204.470018,-227.516775,-186.429958,-22.87592,38.252646,55.457156,23.802915,-117.213668,-205.877336,-249.228355,-120.991781,-83.178348,-134.304236,-190.924823,-248.362325,-264.63844,-356.864167,-397.740501,-389.406694,-239.135683,-128.599345,-27.312472,-82.331799,-282.565247,-349.206644,-299.991969,-103.52991,-40.795089,-14.912887,-32.001426,-167.477022,-297.322612,-507.678948,-492.090383,-300.734904,-169.094064,-130.732513,-144.717694,-203.007878,-328.578463,-378.292187,-431.260074,-375.221623,-294.566048,-130.028304,-102.317304,-152.623716,-185.741932,-196.226445,-180.51154,-149.294343,-118.7701,-102.303634,-104.631954,-144.326021,-255.355698,-282.322351,-249.99014,-167.570655,-134.48379,-147.881091,-187.182872,-213.358449,-198.609689,-256.413019,-326.840501,-320.060057,-146.734564,-128.005257,-218.849103,-248.239435,-267.736601,-299.515414,-366.179418,-278.589879,-169.439366,8.261398,11.541821,-137.098231,-229.381013,-286.948632,-252.683788,-234.066507,-244.365918,-173.666039,0.890653,21.423821,-24.597549,-39.355437,-29.423118,43.583484,100.304897,131.187705,67.795681,-98.318448,-137.371457,-106.468655,-55.054463:-11.663003,121.221907,186.657367,181.770852,133.958571,64.249076,47.399298,47.756332,142.056985,217.224858,339.634226,358.266765,331.178344,314.661127,286.739973,272.392516,279.9815,329.787549,333.758051,245.292354,172.05824,44.945091,3.744414,-50.314488,-93.233083,-92.613651,-57.847035,-50.896388,-60.943107,-76.5599,-151.932392,-197.070002,-197.324422,-88.934768,-67.018909,-111.562571,-142.749365,-205.733157,-217.971821,-125.165269,-35.86546,-42.585717,-42.359067,-4.104614,59.864877,56.864874,8.323991,-32.469309,-77.283461,48.835936,111.588675,44.359408,-52.133592,-175.619529,-191.287859,-178.988387,-72.50272,7.988071,101.630636,90.336633,48.239573,44.804026,32.025742,28.198005,81.238243,150.302286,150.52448,157.896807,211.223021,263.57051,203.900201,99.476911,156.284873,185.30925,141.786638,83.118842,18.324863,28.363532,94.400149,163.613611,316.15977,306.093603,278.753194,236.52704,187.322473,25.573609,-52.010423,-135.896382,-105.134765,-63.459549,-41.792032,-73.201701,-170.446834,-213.334243,-145.454663,-16.976462,205.346021,258.342429,257.492043,171.602793,100.581777,-4.359434,-32.088545,-20.988234,44.623925,68.679166,105.664693,106.179068,4.188958,-90.784378,-211.578962,-180.991026,-9.331103,103.889063,90.560026,-25.716877,-70.437713,-99.747455,-90.766369,-28.21247,50.178786,96.103442,156.032244,150.615141,121.167927,100.577649,-9.43305,-70.24892,-47.083886,83.54241,116.859236,89.864899,32.248746,-96.499522,-127.392767,-93.414412,10.879195,74.045773,192.153466,183.008637,-26.170997,-163.735065,-311.223444,-275.036992,-61.277777,84.113354,80.494579,-12.637766,-44.958429,-51.576107,-52.382101,-41.40456,52.837788,115.291064,157.099387,128.36359,73.133467,54.264322,-2.249166,-5.324213,69.449077,170.657201,206.147895,170.484343,105.139222,-37.510376,-78.505999,-80.0117,-77.414816,-79.733713,-90.304967,-86.851601,-32.472256,-12.603239,-50.581669,-83.409585,-63.980064,93.430636,144.997381,76.513976,13.912861,-25.49971,-5.242125,33.548148,9.846381,11.323659,94.544161,144.85582,176.988626,140.424063,-24.395394,-83.307503,14.117789,196.89683,192.887564,77.190664,79.661755,205.974665,256.30668,287.910564,266.56272,246.548473,224.429196,235.273888,208.382483,129.104442,-9.301554,-2.165361,49.211164,53.009362,64.88243,50.297987,-4.528972,-146.726296,-181.865303,-145.490587,-98.305165,-92.337323,-103.508978,-129.053573,-210.931028,-243.325701,-264.980673,-275.673062,-322.024772,-306.050477,-263.903941,-252.646042,-320.102307,-456.189417,-454.75503,-359.782408,-311.06888,-295.475291,-243.72544,-239.719755,-318.401539,-369.491256,-412.262756,-392.567076,-248.553626,-55.158855,-27.552878,-104.04328,-124.695389,-84.74601,-85.660499,-161.324165,-148.144119,-93.737933,-31.353254,-43.372195,-75.602606,-92.887425,-202.88228,-260.570291,-199.383242,20.091146,72.153876,-34.111627,-139.075657,-279.777022,-303.362374,-318.774046,-283.930856,-226.79474,-62.824035,-16.915773,-126.290931,-242.387694,-373.236159,-345.714263,-217.538552,-109.725981,-65.787209,-26.250869,-8.204452,13.034601,-29.158857,-164.736847,-137.37543,-63.852336,-4.403192,-41.761559,-75.608869,-46.774815,-30.373856,-64.305023,-147.88975,-142.029992,-92.919176,15.733105,27.535122,-73.660204,-139.505264,-132.858785,-15.953619,21.152936,61.924549,48.682841,-91.347087,-175.599785,-225.311941,-192.889931,-153.51078,-124.458544,-77.386099,-21.336188,-26.381317,-59.754805,-83.103909,-93.954545,-46.233977,-21.288222,-8.682839,-25.916153,-118.825116,-215.19257,-407.551136,-415.783611,-272.365921,-110.668903,-42.675459,2.741467,-58.967799,-268.811157,-308.75105,-173.238506,-69.823851,-61.796958,34.496579,88.391671,-30.905991,-204.490742,-452.234877,-425.98853,-235.01402,-153.914643,-152.127086,-188.618347,-227.522107,-296.876957,-335.402836,-454.834624,-404.884675,-278.221859,-87.325842,-96.303473,-200.818286,-219.509183,-126.382115,-54.956815,-6.170524,-6.332495,21.007906,11.083783,-67.041087,-222.286669,-226.350413,-168.985333,-194.09533,-227.611006,-318.501453,-357.754896,-342.376916,-319.709241,-367.0708,-398.195158,-322.425598,-199.228294,-202.592966,-261.396448,-261.413606,-259.620772,-293.909737,-367.399863,-317.193839,-246.900774,-99.663023,-56.113512,-112.15288,-214.149256,-365.389317,-345.014737,-229.715977,-184.753822,-178.314966,-175.215217,-161.483408,-87.817592,-56.96927,-56.674585,-68.940048,-48.645603,-16.347289,-59.755611,-197.39736,-217.912143,-174.585923,-137.932446:-94.957478,119.844829,202.626741,175.938168,99.961601,-21.45329,-59.736657,-72.40915,45.617385,140.707801,325.011843,362.860183,269.363087,177.762663,66.920061,88.741251,229.770814,323.752353,346.736413,323.012854,257.214039,38.530882,-86.302787,-227.855313,-201.258826,-168.092427,-85.300191,-56.764158,-55.086862,-71.815618,-144.331073,-179.191892,-152.217019,-7.042663,54.987127,74.260582,47.325839,-68.16753,-134.415184,-86.742224,110.25445,138.197349,80.634569,57.59665,32.321515,4.16888,-69.719719,-83.417649,-35.601587,44.941514,74.21789,48.148945,-16.600446,-161.500528,-204.168465,-191.026827,-49.248795,29.648851,112.421444,115.005326,72.680233,19.665279,-101.746908,-88.715573,105.730528,251.281056,276.336789,285.538277,268.42602,147.721426,65.478917,32.857698,176.006671,236.1566,257.266197,227.679935,177.860055,179.048491,212.583111,243.936217,284.711814,235.769636,218.499537,206.102521,175.550648,44.835596,-27.531008,-93.715349,-33.621648,14.676064,55.439654,25.84716,-95.796549,-150.611348,-186.613195,-144.318208,62.529393,236.334372,246.820432,145.021813,74.76626,-44.215533,-92.033597,-152.692981,-104.101958,-35.555539,93.106249,108.385586,41.993495,-15.941423,-130.109504,-142.293395,-34.949293,71.593208,78.317731,50.99028,33.550656,-27.074714,-56.927765,-63.227463,-7.141156,41.812102,150.101834,194.196835,224.118001,189.325842,78.596914,55.241376,105.817206,182.179435,201.990264,173.796886,124.5007,-14.468642,-80.814524,-116.620765,-33.457969,22.054461,78.207363,40.073763,-79.462883,-112.426193,-163.242608,-181.665354,-178.50876,-149.110942,-129.096816,-133.187684,-168.615369,-252.390809,-281.51648,-270.201297,-160.357465,-128.087701,-146.960651,-144.292691,-114.217621,-137.646498,-227.596512,-226.977643,-107.747887,33.941384,103.786363,211.652743,223.52163,142.485131,64.514326,-61.195831,-64.44967,-33.485905,42.734434,76.882734,115.705561,86.050114,-78.974717,-134.765989,-88.389058,30.143083,60.382933,53.295209,49.627637,10.581844,-56.907356,-146.951194,-42.102016,28.806368,137.443476,173.561877,150.965158,87.457317,-42.303359,-60.417323,19.516619,110.079613,118.734458,139.696494,191.04601,302.831969,328.307158,392.771905,460.492601,455.087087,397.449843,382.512229,333.374681,239.780136,61.071824,77.77461,208.178538,247.114436,227.857817,131.711556,88.790819,5.454888,-50.587017,-67.972105,17.508533,27.375063,-37.621383,-105.269848,-235.121274,-261.707341,-290.401901,-309.227578,-317.179509,-269.116837,-242.794497,-252.641643,-286.228758,-316.03406,-302.683652,-265.060916,-211.06838,-185.625233,-176.604092,-185.741425,-219.036167,-257.691296,-356.59342,-367.608685,-252.163931,-95.323042,-78.333064,-178.294961,-220.623916,-202.12066,-192.043096,-220.529904,-198.089173,-147.02805,-51.715549,-41.640382,-42.657251,-51.758587,-132.317357,-156.065296,-87.858489,38.981216,84.320692,53.170401,-17.513451,-153.639852,-198.12788,-251.85812,-198.811688,-106.53857,76.56044,74.117112,-125.561793,-236.893447,-340.613775,-334.022972,-263.384776,-75.497939,67.341687,233.003458,227.644944,154.415913,91.681837,-36.465342,-58.204302,-49.356226,-57.01761,-65.361742,-38.812221,-20.765169,-51.175706,-86.685533,-115.880728,-33.625797,13.146933,30.354541,27.363094,29.531934,18.705226,21.722342,64.662921,70.271104,75.473601,76.047852,47.447447,17.450812,-93.600347,-149.708575,-148.647315,30.58971,148.279274,262.115473,235.516899,103.644769,54.229187,112.223567,205.270934,177.112401,105.70184,109.958894,68.403386,-37.931561,-305.248668,-347.120598,-203.756468,-52.683851,-10.447162,24.891463,-19.596025,-226.603861,-320.141959,-324.593902,-127.624904,-41.372918,33.357332,27.775935,-115.2635,-259.293089,-505.557012,-516.295595,-406.860242,-415.100132,-445.939818,-440.123035,-426.167156,-463.988695,-506.743147,-545.553649,-423.615896,-308.924794,-106.632161,-82.542208,-161.380447,-189.245132,-144.946731,-99.175095,-36.136317,-8.051554,-2.182397,-69.503521,-123.362076,-157.596993,-148.05143,-126.0377,-113.458772,-110.464645,-141.775139,-202.725158,-350.062789,-388.770193,-408.732786,-411.399937,-389.130326,-306.919894,-255.208802,-189.804284,-182.252422,-229.918495,-295.842524,-418.658574,-380.171896,-299.337736,-66.783214,18.156553,-64.641946,-211.415131,-394.655938,-358.052892,-208.67339,-137.716895,-135.8591,-215.278106,-257.862592,-268.545937,-266.263446,-285.886614,-254.648112,-195.954559,-63.769847,-47.969025,-78.072245,-76.188736,-91.979194,-106.598901:-12.226504,127.640243,172.989608,112.413704,57.131502,27.626466,36.829974,44.982116,129.235561,220.584334,354.321235,342.722662,245.499957,222.015143,256.119419,281.0521,281.084565,310.29748,346.260275,325.690557,252.224676,34.909363,-86.34801,-258.6874,-241.439945,-179.012537,-105.606561,-123.759379,-160.473799,-168.376513,-223.742311,-259.107848,-282.697024,-176.877119,-90.77257,-0.721001,-28.847899,-181.678179,-239.256859,-168.448046,13.766289,64.907219,85.00099,68.551147,-22.530732,-91.519733,-187.688133,-196.051393,-167.729658,-34.45834,40.319401,11.24607,-80.328201,-239.533778,-278.462204,-243.812891,-63.444139,27.094074,58.052826,8.876213,-42.292906,-27.701078,-16.285294,-17.212626,68.912035,231.763289,269.952957,238.337626,211.002049,134.250341,77.754154,55.356793,220.145896,298.487036,294.994037,239.51291,175.829334,182.808149,269.896828,344.406717,449.706096,422.657841,382.572789,233.866824,131.161092,-20.017433,-39.92471,-29.447431,-16.189661,-10.570612,-72.889703,-127.149062,-182.760016,-197.148611,-212.387869,-170.976735,21.141981,230.956486,275.168333,173.676529,78.774596,-92.276892,-163.163214,-237.496834,-173.928743,-99.090145,-1.689885,-24.232978,-157.819151,-232.910251,-273.897423,-201.97297,6.259495,93.764423,72.860629,-21.707822,-57.629865,-132.773138,-171.254814,-136.766878,9.524572,72.160656,104.74007,84.193903,64.125055,51.170677,-33.187276,-68.115449,-24.845053,100.13013,150.859747,190.811425,162.686192,22.135335,-57.301721,-149.839609,-99.162749,-14.183969,152.840729,139.05266,-84.410709,-205.828581,-290.077205,-229.727791,-14.005097,111.745329,113.311748,0.62651,-93.957008,-222.287801,-220.826619,-135.854119,-20.746476,21.26438,-22.508455,-97.856084,-226.296219,-260.890111,-231.996832,-168.62835,-71.231442,15.64759,89.717991,206.739884,213.194303,91.975356,10.439229,-28.60039,24.155957,29.582119,-12.921311,-28.687857,-7.904118,-19.017046,-134.821785,-174.880257,-104.638685,40.664445,84.352125,80.849875,51.074465,-28.224574,-75.229828,-127.402525,-52.57343,28.111705,150.036213,138.800807,34.120873,-7.280736,-37.562669,-27.52218,38.467461,106.403124,104.244887,82.523007,106.729368,200.958179,262.081216,431.189879,520.322801,507.441979,428.895852,375.836671,224.330224,136.939191,86.571919,137.164576,232.327087,247.771366,225.513588,96.516042,21.882233,-101.773714,-147.015508,-125.768488,-33.259695,-12.544515,-2.619905,-2.629342,-32.848423,-76.531612,-186.697841,-212.830789,-159.890211,-39.067347,-16.760313,-127.969523,-223.233701,-310.870898,-276.919039,-163.347826,-90.312508,-57.377547,-54.577059,-109.704825,-290.02683,-377.921744,-419.672226,-350.946953,-113.615722,59.552621,55.75031,-66.3225,-112.565162,-162.086648,-196.662967,-217.991258,-72.295531,20.390321,95.84353,68.859345,-19.472902,-59.093847,-128.872513,-135.435039,-27.220007,159.477311,176.227576,-10.029856,-131.071253,-271.812219,-286.023409,-261.329027,-182.162886,-103.253297,36.825004,42.517218,-46.78876,-120.017921,-264.147194,-265.9805,-113.923069,74.34683,150.141973,182.819031,157.777139,148.348923,148.085676,75.938657,-2.669823,0.030631,60.867589,79.44149,68.787351,57.24889,19.176003,-20.836774,-101.58234,-0.828776,106.2698,222.714856,219.503856,171.808294,139.98839,117.100404,167.289729,201.398707,245.932043,217.245762,60.073514,-12.597708,-112.682882,-147.208309,-120.191991,9.612387,70.049908,135.242118,139.48794,119.381946,115.871543,152.883431,178.788984,166.992794,108.557043,68.508701,-63.809141,-175.569589,-367.763231,-367.942309,-218.551629,-85.908455,-44.250834,0.361593,-20.53925,-198.35386,-291.586769,-282.851284,-112.746126,-33.746471,51.451599,27.953424,-167.733304,-315.19789,-510.48271,-481.698759,-340.682578,-342.974817,-339.912387,-288.988998,-292.975075,-357.73983,-388.041119,-414.678023,-303.730072,-178.532207,22.736423,29.172921,-58.967579,-98.8084,-123.469237,-98.156849,0.018749,95.068224,113.325846,37.947212,-26.205431,-117.676756,-150.231084,-190.99283,-179.919058,-163.155645,-186.267493,-233.659264,-327.126051,-376.654674,-457.015069,-445.710321,-352.284793,-254.76481,-218.653134,-218.286398,-241.027514,-306.742856,-355.864809,-402.556585,-286.664517,-183.082035,2.199707,23.49965,-110.00993,-217.641846,-315.221175,-281.014082,-190.409764,-113.422997,-93.442692,-150.447079,-179.721023,-192.452643,-208.993784,-220.253692,-157.669482,-114.843166,-62.378068,-83.850741,-169.627944,-182.585524,-135.52884,-87.971329:-84.781157,104.547134,192.538686,210.944848,127.577694,-108.806989,-218.427156,-311.823605,-115.10152,34.13701,180.603001,160.302262,81.016543,47.815261,-41.614596,-68.376584,9.27046,162.568212,212.326185,179.155864,91.746328,-116.442142,-194.148208,-297.726087,-358.742707,-355.06394,-238.779608,-149.415283,-57.90193,-79.219938,-119.379522,-88.46805,32.491911,125.62005,151.27944,170.868816,157.156844,60.777144,5.639421,-8.115767,78.537329,118.896544,127.830254,75.943919,-67.993534,-102.224389,-68.923929,-30.178265,26.233431,70.320485,78.288999,-24.140972,-104.437986,-176.00126,-161.186873,-85.187461,-24.65717,-20.286417,-28.576694,-27.322262,-34.147854,-52.621491,-86.450369,-65.514199,68.208401,214.754051,258.231206,314.888758,331.614502,248.288375,153.586325,41.447504,94.394265,146.181923,240.156312,239.837201,170.458321,162.678486,208.248199,213.83529,105.960114,-5.762469,34.75442,198.776908,207.08429,52.994142,-7.630912,19.510892,64.98844,78.848412,156.878123,184.627032,131.416518,85.328588,49.726929,63.644385,122.131805,191.878793,220.467249,223.160561,188.387754,30.834865,-73.546006,-190.753076,-153.810426,-88.080231,145.278838,250.644194,260.820311,173.764759,9.570274,-10.566248,-14.256835,-66.993483,-75.496824,-45.051832,-38.336517,-96.360245,-141.670713,-162.354262,-103.626073,-90.622321,-71.510147,-12.293078,208.341781,289.860184,257.653751,196.130015,155.606207,183.936924,187.598074,159.939439,137.392309,40.847976,-48.431204,-156.754579,-120.577216,-136.061823,-216.844776,-220.484468,-174.514204,-179.86965,-265.284139,-301.488807,-280.34539,-217.070347,-233.013689,-353.426079,-400.001521,-391.703627,-358.424066,-285.798808,-275.411506,-317.631853,-367.253292,-332.20222,-234.048978,-207.434959,-193.242536,-183.213991,-99.079781,69.875527,154.078478,250.226895,264.279423,256.872997,228.329009,108.164138,-20.49588,-28.306515,89.867232,156.109109,169.426056,113.779787,-67.363388,-135.534692,-130.860733,-27.584404,14.609469,-16.890572,-67.423705,-122.166605,-144.57313,-162.142581,-33.260154,14.266681,-15.6184,-26.00464,48.98469,87.932203,21.430726,-58.001182,-106.320199,31.203198,115.812985,172.813764,133.748928,92.397741,142.225094,277.814996,310.905176,295.138547,208.912902,154.270953,123.497326,133.519539,123.64762,125.464248,174.726588,220.269179,223.447529,198.001617,192.365215,163.021728,112.460745,59.019026,135.96609,138.157235,15.097559,-64.20053,-152.898653,-160.664162,-156.390649,-149.57945,-129.828474,-101.299498,-95.878714,-122.762545,-117.954776,-59.07671,-63.944032,-127.822969,-79.072631,-10.236539,115.175406,120.608008,-5.555709,-72.675078,-101.873216,-91.402556,-84.543329,-70.592645,-61.130918,-98.236234,-153.100651,-226.805742,-210.086232,-120.082541,-76.269027,-78.113967,-54.092352,-13.477057,63.931555,69.437137,18.843138,-12.000971,-38.723868,65.759333,134.499734,36.444488,-124.283729,-346.743287,-341.031861,-178.017831,21.517137,89.898576,133.193788,111.667175,-14.253932,-111.656337,-285.163924,-310.936049,-238.204368,-106.182623,-35.964907,65.603093,104.222795,163.323288,137.337016,10.818049,-38.014825,-40.256943,-66.57126,-102.694062,-168.922094,-177.844738,-153.261212,-121.639101,-65.194842,14.12153,73.600118,126.771026,115.282585,42.425298,-16.518466,-52.141969,90.254942,145.89135,88.449451,8.832734,-47.396645,-13.995662,15.099992,-16.46935,-97.331363,-53.937921,49.794795,309.88653,381.906066,344.136267,288.995652,258.473426,268.569688,232.920254,118.783361,70.175553,3.204111,-43.892693,-184.843242,-217.739005,-151.72247,-76.514925,-41.379214,23.907067,1.865026,-160.851386,-227.676617,-203.851182,-70.635858,-29.551043,-47.309492,-98.685707,-275.053293,-371.551864,-461.057898,-454.337515,-477.992321,-567.805241,-573.144427,-519.690423,-508.25476,-541.599661,-565.628219,-543.705873,-401.509973,-318.04804,-201.837269,-183.211114,-198.181617,-222.371202,-272.635271,-268.464198,-196.5485,-128.528674,-97.119768,-98.862077,-154.693205,-261.80869,-254.162298,-85.583531,82.206121,84.967226,-39.475704,-120.043139,-231.655808,-261.590636,-275.39704,-248.291828,-259.629656,-395.632392,-376.068831,-161.156407,-88.668941,-130.317999,-196.893625,-275.370765,-222.060276,-159.539934,11.048893,66.917512,-37.746532,-150.131113,-209.035105,-142.864586,-37.912953,-35.638929,-48.603319,-142.898791,-206.65104,-294.960793,-330.201618,-367.090128,-299.170739,-238.058692,-132.662546,-122.567648,-121.308661,-85.878808,-8.315896,16.093568:-144.79649,82.425081,168.179268,142.958903,68.953449,-55.013772,-105.692446,-148.534251,5.854222,123.296164,252.79637,244.225,176.194223,137.142529,72.214376,81.367287,162.024898,238.015803,276.771243,286.872171,222.417859,-56.801577,-221.174879,-395.993565,-363.590648,-306.307137,-132.353562,-72.433691,-106.621821,-167.43278,-246.803175,-239.377886,-119.942487,62.107242,122.015551,142.817852,119.052221,6.914941,-73.276558,-134.390645,10.490282,100.884081,178.002704,140.135975,13.237267,-22.793784,-65.372128,-85.389553,-71.046403,55.502274,117.387173,42.071017,-85.718853,-275.853474,-292.837485,-261.945854,-168.356975,-81.490048,47.79149,42.191395,-61.563521,-115.293933,-162.326093,-137.719584,38.067841,267.994938,329.923805,320.081845,268.063998,84.691654,-15.093995,-51.360344,126.961584,218.645766,296.636958,279.170398,228.568495,214.541796,200.395352,220.008066,290.298238,315.714443,317.398521,238.170243,138.840383,-39.826115,-61.718791,-26.854467,-31.652263,-23.383673,50.326344,59.672118,-57.998844,-147.011851,-249.540929,-225.975796,-27.573019,195.382814,232.116534,141.786704,32.693898,-247.832611,-344.124507,-341.300093,-180.36429,-70.114966,88.950728,89.595882,-14.282461,-79.272445,-127.916062,-83.890718,49.575673,63.765034,29.73687,-39.328209,-74.049964,-165.982208,-197.660663,-123.664559,54.295125,112.417873,170.311261,208.757645,269.329343,243.61575,112.363226,71.218336,121.315383,223.999571,234.148311,160.847405,106.5344,3.515364,-64.66687,-182.735743,-99.036062,-27.747467,5.614031,-21.727587,-83.925456,-137.026552,-288.25889,-309.135463,-166.210523,5.214688,34.433405,-71.774346,-192.810143,-375.935922,-376.177397,-285.774342,-245.825582,-245.46104,-282.460177,-315.076752,-339.590845,-323.382749,-260.436087,-217.161996,-92.761021,95.710861,179.220183,200.098392,154.193391,87.920058,78.818028,45.745664,-10.980451,-3.484201,100.373045,141.082759,112.818094,51.92019,-104.204559,-148.753172,-98.903641,36.973577,80.450139,39.975827,-23.557208,-157.406776,-215.347043,-240.996672,-132.262809,-64.877443,5.391654,-8.760746,-70.318166,-109.295484,-204.88671,-217.656864,-135.107735,-15.886356,23.15848,42.670397,49.28847,91.682536,133.900638,281.668201,347.127092,332.122102,301.074669,287.298517,253.325082,222.469241,172.330643,186.459214,261.01919,333.189668,354.633194,286.684867,179.721958,-67.072692,-115.329351,22.683414,175.653769,170.362136,82.58805,39.329537,-42.345444,-85.618359,-153.753736,-157.341328,-84.735543,63.020718,113.963231,35.20961,-49.067374,-112.374908,-102.687541,-68.525774,33.919649,110.801214,173.31129,94.24506,-175.842847,-251.677816,-213.450827,-156.803896,-56.35858,24.768462,33.302855,-49.997164,-105.00044,-136.669528,-121.821418,-96.2969,-41.663841,20.034928,134.05259,138.041219,66.9903,19.932232,-66.182746,-71.384229,8.10444,82.235208,71.887807,-85.02875,-181.375009,-256.621768,-248.421988,-177.353676,28.870893,142.747719,233.505139,187.85705,-4.938707,-92.799491,-139.084459,-94.539095,19.546092,113.90838,179.877994,276.704134,265.533062,153.764047,94.00727,34.889979,76.630376,109.982422,88.7982,23.193448,-83.357053,-76.531706,-2.625516,28.931089,60.944048,134.757494,209.018251,317.5875,314.259721,166.997946,60.213645,18.77665,203.153147,246.887667,173.560217,131.014287,120.28624,93.471212,-98.326396,-187.349818,-140.38872,87.663135,186.352679,300.288418,319.805891,276.641472,229.410609,204.024612,220.010871,208.410832,201.22333,185.001177,34.11748,-92.002907,-281.011308,-267.661673,-95.017637,-6.160419,7.675552,36.163798,8.005812,-189.863177,-272.35633,-168.98781,101.700648,166.864658,95.337402,-2.129205,-227.605553,-344.580741,-512.756665,-527.118616,-468.945475,-421.91319,-410.133234,-415.385672,-437.837371,-474.91427,-469.786845,-401.206617,-283.718993,-216.211326,-108.918608,-86.346011,-96.82169,-144.110005,-261.759121,-252.757421,-90.542925,43.621498,51.791534,-36.669216,-98.520713,-212.817801,-251.476353,-206.660652,-87.822399,-61.493312,-96.957184,-144.778294,-235.487659,-283.193153,-355.216612,-341.321965,-278.913943,-283.333981,-278.034914,-224.207552,-209.785046,-263.478035,-323.315805,-419.303875,-324.326653,-185.400071,67.237341,93.430655,-60.721219,-178.964856,-295.771906,-261.678301,-122.753544,-24.99295,-12.765334,-118.010223,-217.242693,-411.21502,-468.973643,-423.545496,-257.516506,-167.764375,-24.292561,-20.034316,-114.28056,-149.344019,-177.018034,-171.02381:-17.139167,-61.565849,-63.100856,-51.13804,-71.484692,-188.346492,-263.761608,-350.676934,-272.920722,-180.072146,-0.633129,41.945743,24.419849,-22.311929,-183.154518,-257.92488,-239.216138,-42.642568,25.052884,-24.899085,-120.519447,-357.69772,-467.285669,-580.194767,-512.084739,-437.564041,-282.138529,-223.555034,-191.978055,-207.434676,-192.127234,-131.588946,40.81136,133.532227,155.176272,200.677344,210.6107,155.494048,96.315967,7.055687,-0.389903,9.870458,59.331435,82.648178,82.516278,70.521389,20.82618,-13.541057,-45.208686,25.16756,102.33241,203.295932,167.8904,27.436091,17.031406,144.834356,195.572475,154.285742,110.441828,142.513304,211.496692,204.101808,135.493928,119.764879,134.601285,176.273293,226.434118,340.677426,369.888866,315.109191,227.788516,74.517221,100.706138,149.603262,244.246894,274.875519,283.351277,261.865724,153.03028,99.441831,82.673662,91.702782,94.419341,78.527811,44.06042,3.746069,22.75932,118.608188,226.392823,271.375675,325.205007,302.302516,162.601225,100.881807,78.193741,112.74154,219.42299,306.954814,319.525644,245.836884,188.124335,101.113418,46.74153,-82.947274,-58.943149,7.491763,122.84152,154.094293,175.129956,158.630335,40.334272,-32.599052,-113.299099,-128.567603,-114.693161,-50.144798,-19.347746,-14.41348,-54.512248,-167.196389,-190.237224,-152.761175,-21.92925,44.062517,158.991927,202.630966,255.237013,290.894362,377.571493,369.923888,342.657928,270.073547,216.61531,101.974377,36.59655,-81.395779,-109.660137,-139.552181,-298.10403,-360.332028,-304.212328,-240.639189,-237.708714,-277.030077,-302.742146,-304.717636,-322.257418,-388.767755,-419.914868,-401.494236,-360.96765,-314.910165,-337.735607,-347.495545,-307.618752,-271.324679,-219.657711,-198.432435,-158.78907,-140.519778,-86.718976,1.990818,85.254411,296.350658,360.915526,335.854313,268.140444,117.62636,82.507913,113.971776,149.791585,123.607512,79.291257,83.330055,43.207492,0.953814,-41.713428,-10.019578,43.92333,141.630118,133.853066,48.399755,18.201643,43.752347,138.278265,156.837824,120.499419,116.562265,185.301928,202.678067,114.729231,59.069435,48.609368,74.873579,59.96442,23.060829,39.637041,134.610941,178.869667,204.11882,125.307643,58.252874,-61.804755,-89.321481,-57.157839,4.35315,138.540912,163.61431,136.1989,99.729402,86.898068,47.587893,21.713633,-41.186377,-75.440545,-55.933646,53.075139,54.905205,-11.445304,-2.558574,99.039984,116.113912,9.951723,-55.471591,-76.067608,27.704746,75.68241,36.200378,-36.135561,-122.50946,-123.505241,-78.896577,-32.517447,-26.884173,9.277511,35.6993,31.878325,4.611021,-27.928503,-2.723328,84.779309,43.307213,-7.872789,-67.736174,-86.9883,-136.779314,-157.302622,-136.397802,-64.278123,-47.527577,-56.912652,-64.415628,-51.864608,-33.250349,-24.730462,-38.74392,-79.579071,-93.266414,-81.507732,-184.880601,-309.437236,-430.633232,-401.614784,-308.795233,-168.362038,-107.875174,-128.258439,-194.973081,-292.258391,-294.761686,-271.219957,-278.945693,-329.607637,-340.328265,-315.401198,-217.97122,-139.079455,40.721049,71.485799,-54.842584,-187.992246,-191.585004,-175.916321,-206.310093,-272.261352,-265.376774,-225.084516,-199.489143,-81.126839,20.638523,19.088567,6.332044,50.631133,109.279664,28.402856,-171.257946,-65.147783,29.358397,85.903764,76.858823,101.421965,115.892054,65.401007,-1.798844,-151.538867,-155.765757,-67.286913,162.08868,228.860189,252.322662,258.21906,292.950417,266.706778,236.274707,173.424528,117.430249,-6.636915,-44.169754,-115.182851,-162.997986,-216.488866,-147.823457,-90.590655,-32.099454,-55.762363,-169.934551,-215.253694,-160.740677,24.114385,67.244577,-20.837481,-112.249486,-294.079842,-366.262419,-370.752905,-306.539868,-274.704761,-362.417697,-345.629878,-207.288604,-149.854138,-141.78342,-178.801264,-199.303753,-84.962475,-12.601229,97.295776,107.491726,64.639391,51.011664,34.339378,33.903083,99.666119,133.910768,132.691125,172.059884,187.74016,162.97465,146.373947,179.976052,280.782501,319.816978,283.618894,207.24274,100.638586,93.047008,57.78481,30.86815,-26.717849,-121.468081,-129.523035,-29.76213,21.324328,-14.463276,-102.936168,-257.792314,-248.279361,-198.367488,-71.780272,-40.668084,-94.285821,-133.94356,-146.769376,-130.018269,-81.562193,-30.954172,-32.682938,-161.43678,-255.264698,-318.000478,-278.239091,-190.337606,-171.904336,-164.690284,-81.440405,-20.367751,42.4304,33.446191,6.630674,19.504333:-156.49092,-173.637939,-91.98719,95.953874,94.065456,-156.370395,-314.996642,-460.305611,-309.661241,-187.088268,-25.638796,-9.552879,-44.796221,-85.208799,-216.301009,-255.867485,-217.995777,-172.228823,-147.386688,-71.985184,-66.376682,-172.835637,-254.9012,-369.31779,-323.391286,-254.461636,-100.039144,-37.780121,2.896775,-4.139606,8.86864,20.995157,53.612293,129.964473,165.738699,212.359804,225.072802,220.552822,195.059149,119.019411,119.616062,175.543634,275.855863,247.674817,98.892675,59.333298,64.61892,77.062274,77.103292,52.73565,80.7917,161.034309,135.218714,5.996511,-12.914283,74.613399,160.479099,173.730642,220.579441,250.92384,218.359556,154.575136,32.577434,16.849101,94.914092,180.068955,207.425706,272.035242,302.378149,285.539484,223.189915,95.236161,61.600297,75.945423,144.470221,160.188071,114.064293,76.296429,-42.258983,-102.838416,-82.632535,38.502735,65.622813,-11.981416,-91.624886,-181.329222,-163.855997,-40.395316,85.47205,142.609129,258.331257,255.911044,96.044177,44.265329,99.326095,139.458486,174.345851,178.130319,164.732767,57.895448,-15.86718,-88.46452,-97.588908,-112.701071,-53.601033,17.781722,145.670528,157.357979,116.513069,83.841577,-45.800119,-128.656391,-200.079887,-135.673098,-114.181874,-89.072166,-60.739837,-52.876306,-91.998551,-165.914547,-225.422701,-267.606514,-233.341094,-115.978395,160.926784,211.178153,123.7222,92.567084,147.015695,225.049859,255.212411,245.065232,192.115284,54.394362,-1.194757,-21.891024,6.793307,-31.594842,-150.963876,-164.763384,-134.414386,-148.596581,-238.436338,-273.92389,-321.555568,-398.847034,-422.105747,-386.924666,-343.295687,-269.366706,-251.742679,-220.786401,-205.148429,-211.885833,-145.582372,-84.662624,-40.548958,-49.78298,-30.375863,5.183333,47.565129,63.939589,130.935621,333.19902,382.462432,297.961766,194.577776,14.690422,-19.199751,2.229462,60.797948,85.96127,126.04311,125.806042,67.687973,42.841909,16.386392,-11.50056,5.614701,62.922102,63.726178,23.765613,-7.162131,-71.479543,-42.604849,-0.668012,21.152312,8.870421,42.696729,69.837041,32.24819,-10.17204,-54.023994,-81.098104,-78.011273,-35.7446,-9.747951,65.409491,110.782304,123.953366,-12.112052,-76.01825,-96.32495,-70.639547,-60.958514,-88.697721,-103.519987,-66.687054,-0.488952,-6.868155,2.778917,44.651676,46.100052,-50.338128,-128.435792,-152.703497,-12.539833,9.896895,-89.669082,-140.03834,-132.877147,-104.981859,-77.517496,-71.087332,-53.359459,-52.649812,-67.852357,-125.614642,-130.359502,-70.206092,-71.156144,-175.424399,-225.030286,-199.28003,-78.922693,-12.191777,38.833719,-0.819006,-141.210399,-160.454969,-61.329743,-37.768115,-67.561382,-107.519616,-105.467744,-45.265635,-5.948422,8.630876,-79.343376,-122.201053,-88.804305,-44.694467,-4.475468,19.132142,80.023552,80.159877,50.667313,104.292985,113.321845,-49.315377,-166.218376,-261.790133,-249.913448,-170.715885,9.465214,92.509917,111.685151,55.507184,-62.36539,-98.002011,-120.500365,-103.047488,-46.66685,6.782948,50.804358,145.158632,187.602513,249.847745,235.447496,108.158191,4.95809,5.210696,41.628334,25.881031,-43.379774,-43.18704,27.321725,69.262126,122.945715,133.13906,154.449223,192.994307,166.906496,-1.27206,-104.901636,-173.122173,34.727814,153.862049,152.01824,54.091894,-13.669931,39.71255,79.753654,26.278485,-107.868639,-74.869581,34.366767,268.494997,307.369687,196.643154,106.450007,34.558099,70.316537,69.940985,8.458668,-47.039293,-168.292896,-219.263829,-288.55256,-305.837832,-340.884832,-291.208387,-198.760474,-53.052055,-66.103431,-197.773209,-243.447516,-182.28415,-59.136256,-39.481235,-97.176185,-157.249119,-277.806515,-322.676578,-349.902736,-331.085639,-319.692931,-333.263602,-283.839036,-148.391374,-138.048823,-244.59287,-316.928292,-379.537204,-286.486028,-207.572013,-55.803956,-9.756295,1.687327,-22.080611,-102.902781,-136.277305,-122.570251,-20.440987,41.483041,94.610995,71.073314,3.04844,-11.240095,52.098457,193.788157,221.529258,124.06578,40.126189,-48.585757,-28.741397,42.761731,42.076807,-75.709112,-213.838269,-187.531423,12.30779,81.448926,51.315621,-24.861918,-173.239633,-186.274714,-143.10304,8.130392,72.948303,39.245707,-54.06042,-186.810413,-168.941103,-88.324118,-102.448188,-118.874659,-181.063835,-221.676742,-204.355303,-165.306017,-198.852146,-303.780852,-277.63508,-81.263119,4.09664,62.876416,51.155154,-13.627401,-16.779438:-121.678914,51.74436,95.318772,33.171468,-36.342454,-144.73733,-181.142898,-181.115787,-52.841617,23.131151,137.308285,151.890701,86.981306,49.780597,38.410391,41.630299,-15.223678,-1.782091,82.035721,168.034424,89.606792,-211.049397,-353.352434,-476.545027,-417.780028,-381.478603,-300.864415,-254.32674,-190.17486,-183.496283,-223.964659,-233.390942,-107.800082,79.06513,121.15663,86.671841,37.427368,-15.523938,0.042954,65.870258,73.772643,49.232116,29.702066,37.832307,6.400233,-39.182988,-93.280482,-78.895514,-44.997924,-57.396695,-47.178699,-15.732726,-20.583451,-68.775247,-93.391166,-87.658489,-12.975834,16.484338,27.549189,25.556186,45.99735,53.312703,23.702838,23.307735,99.455169,155.901716,177.323805,247.764367,268.911409,210.418069,143.790437,48.069749,31.502252,46.267361,143.245446,203.088223,298.85125,337.660394,355.452071,317.253633,184.982306,117.313902,130.388852,122.049492,75.581791,23.491617,42.295883,89.273898,83.315602,79.256161,129.282104,157.860326,111.629562,36.856619,-86.506083,-73.385136,114.076028,324.660593,356.788206,244.812521,144.517951,-51.294549,-119.2615,-140.898517,-77.080182,-24.553388,146.477213,212.36347,188.185579,121.407914,0.486712,-22.954354,-21.120468,-66.198371,-100.990241,-145.471391,-161.919462,-192.382184,-201.004445,-151.919533,15.620609,86.414677,115.724348,110.383465,125.785478,131.26885,110.071199,102.869925,139.219729,191.781475,210.364381,176.54297,105.853353,-72.40141,-140.067922,-199.230385,-166.217564,-119.45184,-57.55721,-84.20875,-195.985337,-232.841278,-277.217919,-283.586208,-207.775817,-189.267116,-243.753712,-362.917806,-393.414081,-397.131147,-381.766186,-331.339923,-338.016746,-388.151703,-461.739782,-432.587374,-307.725625,-275.336472,-306.346862,-332.887726,-306.847859,-109.724519,23.519184,211.742495,234.953344,132.32044,49.12584,-20.220836,-9.149844,-2.019671,65.41928,89.545269,71.32762,62.544521,28.131598,-13.555349,-73.845683,24.739667,97.765008,83.210229,16.075341,-44.906872,-39.940251,-28.435784,5.751953,13.844605,-24.127863,-45.178993,-31.248998,-13.823492,-52.682229,-99.221869,-126.720472,-43.989232,1.439116,31.059083,27.496201,95.63009,172.684925,308.986281,288.545799,237.984033,166.132286,150.8542,116.149084,95.981754,88.437462,102.726672,165.96181,223.103832,240.910129,269.006054,243.992274,70.744001,-10.018526,5.759362,98.203196,102.279105,40.747444,4.455296,0.038322,33.411602,84.09672,74.683487,25.97826,75.715522,130.194248,163.845991,130.62504,25.801619,-9.243371,50.20754,150.232921,141.342364,90.600012,78.688804,36.338284,2.534566,-69.941167,-87.044905,-23.097851,57.916404,58.223652,5.034005,-29.721175,-50.455901,-25.61037,35.333789,45.846368,39.354449,48.963446,65.330083,89.784543,76.729828,-9.548232,-33.169493,30.345781,64.021988,35.568257,-73.800488,-146.483864,-289.783569,-328.764281,-254.035741,-64.223906,-6.353191,19.662203,25.882777,53.06694,31.621436,-136.138029,-226.47754,-275.876677,-169.787184,-91.251271,43.952926,76.633202,59.503165,11.92119,-52.555445,-12.308798,-11.435414,-55.516989,-76.834993,-118.837356,-138.111774,-124.641299,-79.951841,9.169905,36.936628,57.451181,116.292453,128.206293,97.386528,64.512151,12.604427,54.569997,98.716891,133.267833,110.414211,89.913846,108.353538,9.594084,-124.801656,-277.455156,-128.50509,-0.125949,227.747004,275.851533,221.288971,182.048827,245.907797,361.188747,337.087281,152.841092,60.362825,-14.619972,-31.284191,-161.554231,-245.923385,-285.93931,-112.985607,-0.454365,99.288807,54.245015,-143.520344,-225.464829,-226.53627,-71.553909,-15.4823,-77.760032,-168.161903,-319.835904,-368.849105,-409.61836,-384.026185,-314.890712,-336.547805,-348.108194,-334.905957,-323.380063,-300.979384,-304.845693,-322.308853,-251.494188,-184.718847,-108.020737,-120.833438,-153.676953,-156.469145,-190.894338,-195.489994,-93.270813,16.394711,41.893623,23.932866,-17.60653,-118.360744,-141.827024,-53.544432,73.353973,93.373062,34.582447,-39.38886,-143.51993,-118.493146,-32.859143,-38.619664,-128.769974,-211.50674,-200.991701,-85.92775,-33.786837,-35.949071,-88.138109,-184.369557,-134.786489,-57.644094,95.868,112.683087,-8.004732,-84.104384,-110.029333,-60.795083,0.107305,-53.852534,-70.546103,-115.742178,-169.51122,-273.493164,-291.160306,-260.817452,-185.384652,-119.729489,14.66564,33.447547,8.01233,13.881417,36.196716,41.458286:right
-302.030071,-346.838382,-335.844863,-263.366396,-228.032958,-143.269624,-75.841412,47.48207,108.369488,116.800107,59.761284,16.374969,-10.310016,4.806538,60.724731,79.862718,45.904242,-36.138122,-90.250411,-210.836352,-234.713788,-211.198552,-204.115097,-157.313997,-37.276361,-25.845963,-169.218879,-252.845007,-273.40353,-227.759065,-142.34043,-114.096482,-76.483821,-88.811674,-141.147502,-272.911565,-278.857121,-144.912194,-65.324578,19.967386,15.554648,8.888537,-5.052028,-26.7105,19.261331,138.463493,462.949809,578.811092,570.127538,344.945531,216.275055,-3.510696,-50.532255,3.683685,55.445115,83.472384,18.808765,-14.6651,-68.089201,-107.583119,-229.458149,-279.837508,-248.957472,-178.899609,-101.023334,-129.770708,-146.049431,-188.114573,-196.074795,-143.99847,-98.199714,-32.952361,-82.236034,-108.211104,-75.389135,-73.328171,-142.592282,-137.825841,43.778025,173.810806,328.551995,282.045464,242.34065,215.651272,231.133537,230.98444,174.291017,-5.326112,-137.989028,-156.841551,-155.602211,-174.288905,-182.210976,-146.715034,-43.597874,18.879776,150.028094,156.357343,74.51439,-109.436329,-122.312676,0.85913,80.595917,188.081919,138.713295,62.080313,-59.760362,-57.283853,51.795144,112.131423,222.534337,283.352372,364.01901,325.842224,235.661528,-21.042921,-94.047794,-61.401502,-4.400085,105.684551,83.08745,-2.685813,-213.708467,-287.44099,-284.777378,-207.411082,-36.535289,-8.788541,-112.81157,-225.058298,-225.160299,-213.331179,-199.011527,-105.705014,-67.738721,-62.294767,-119.27373,-184.888202,-359.428425,-431.7147,-428.817821,-338.06483,-64.985546,75.460056,195.027135,-15.736329,-163.295827,-319.754772,-304.985718,-182.925357,-113.558577,10.998713,20.645848,-42.78879,-194.297846,-218.801579,-160.519316,-121.876922,-77.885705,-60.959973,-36.875404,-55.717641,-72.970016,-57.192719,-7.556266,107.931713,129.486264,62.249532,-13.943537,2.806463,52.897117,40.835492,37.681092,95.78939,257.571085,274.302681,89.170866,-82.142773,-74.722757,-14.793032,-2.392727,44.327015,83.565578,139.888342,84.889729,26.71487,-47.356362,-62.301829,-111.508587,-137.58719,-99.973766,-55.705917,-34.946379,-46.516849,-44.414338,-73.978409,-100.696967,-93.582259,-42.301751,79.638616,34.598567,-26.148836,-86.858914,-90.78391,-84.287998,-86.384091,-70.951203,-31.557903,43.178789,9.048511,-59.749158,-242.956193,-281.758881,-136.232363,-12.970009,79.633966,-90.529506,-193.923373,-320.012778,-347.583392,-348.562309,-322.979454,-189.435532,-79.453467,93.314183,70.463975,4.175499,-94.229702,-71.283492,41.94926,62.025909,68.563153,118.984008,135.621386,98.395657,44.916514,-46.237736,-60.35611,-72.42255,-94.797754,-143.649012,-93.983937,-34.779788,62.273476,78.202445,54.375645,35.40096,53.101816,123.098978,109.058648,-118.856306,-261.647898,-275.508861,-154.920096,6.838251,-0.756758,-81.884411,-135.309172,-129.049115,-86.00643,-69.854106,-46.49736,-36.899629,-33.260063,-77.440864,-108.055376,-167.166439,-216.333591,-303.398494,-290.531599,-194.643574,-185.666693,-302.135407,-394.817568,-389.61306,-298.897605,-218.515379,6.451973,145.320677,343.339212,277.605668,185.209313,10.653841,-46.633266,-44.9509,-9.231351,47.535262,70.376228,99.482397,109.891741,93.773041,21.047141,7.889717,38.445541,60.147489,121.705191,131.279092,90.475346,-23.41485,-48.29212,-13.671232,16.377292,115.426331,172.992508,160.674149,39.758723,19.740531,53.53354,74.692806,122.54714,170.716147,265.505355,170.088833,103.164518,46.994737,22.744334,30.319935,82.860936,151.049104,132.999245,55.328311,-28.230495,-93.528529,-205.217894,-176.149827,39.011004,127.216111,180.317831,195.646245,174.634698,26.358261,-54.982383,-89.239,-40.523054,74.351429,84.676097,-49.220335,-186.229492,-172.399631,-106.097334,-126.454297,-195.147004,-180.437212,-53.286701,48.101034,60.585523,-3.553262,-55.863316,-33.335166,55.078337,247.441556,299.216553,280.501682,211.086045,198.27752,224.117359,256.389463,294.02988,295.494686,270.650653,169.028421,128.26582,145.92998,184.856141,235.573477,212.710655,113.235372,108.099009,216.029125,315.590844,333.247923,268.480418,190.684501,52.686182,44.405075,186.948799,256.678068,194.492682,61.335495,42.458912,99.294483,158.398444,263.215605,290.680043,309.517743,336.666795,344.563277,274.008435,202.965287,112.293615,126.377957,204.268674,128.811853,44.646316,-32.587593,1.551408,133.040802,168.175647,185.081154,221.08534:-289.931964,-390.029468,-412.398174,-370.429606,-318.536267,-185.517054,-122.480124,-103.447038,-91.436682,-44.858059,-37.548779,-82.953089,-115.4503,-68.633579,89.175361,124.233577,16.801429,-134.235608,-162.597722,-131.073799,-102.189798,-105.035953,-118.62681,-45.34944,84.832847,66.479595,-147.959827,-222.394067,-130.853656,-30.396569,80.824069,81.048693,35.818166,-14.568171,-60.482412,-139.545526,-130.278629,-91.748667,-101.692076,-95.239534,-16.590153,19.756137,60.185129,50.169236,51.050496,122.232886,384.645368,491.807434,439.368297,142.519053,8.912962,-122.674944,-117.043908,-52.043902,-24.69566,-10.857958,-47.176008,-79.782136,-141.413706,-159.057666,-228.839581,-280.398423,-251.166459,-164.571999,-80.662285,-141.936115,-164.868529,-189.653037,-183.845371,-129.013799,-96.586281,-47.943691,-43.865503,-33.92432,11.477362,7.427148,-44.517243,-33.134072,117.036991,213.548037,316.506162,294.36322,274.069202,240.78903,241.926301,288.590383,289.547406,144.03808,-76.303251,-127.550981,-104.772756,-75.333048,11.092555,78.663872,198.571249,226.662573,216.5832,88.649,-11.626963,-104.111927,-53.492163,120.85638,172.311316,113.821052,-37.837021,-42.786909,39.262933,40.07036,-18.710235,-26.283918,81.877486,190.854827,336.008165,234.26013,112.877904,-133.9693,-163.557767,-3.123911,84.470111,107.763044,-7.742915,-72.911719,-193.065122,-233.611349,-207.544878,-132.102035,50.203011,78.960769,-49.476388,-216.071104,-253.600002,-210.775519,-143.912171,-67.236329,-83.15308,-86.431383,-62.025064,-130.837743,-379.610593,-460.860329,-383.391046,-262.164453,-89.046215,-60.403127,-54.870429,-148.652329,-223.169049,-306.201576,-301.995624,-262.586046,-214.353289,-46.488928,-54.851752,-149.593585,-267.319738,-243.138389,-156.032348,-135.665568,-73.418494,-10.500198,79.209597,41.962238,0.732768,-18.738622,28.307265,148.810284,171.240871,104.609709,-35.353043,-84.805819,-93.915997,-58.467814,48.959099,100.084617,173.977181,173.361823,22.366561,-143.44352,-157.923947,-131.947447,-116.708022,-35.176329,16.663458,32.883668,-86.651715,-132.854673,-126.350919,-98.360603,-39.712043,-17.371395,26.262872,38.384816,40.830688,108.734155,125.607562,78.563879,61.878852,85.681893,93.649302,40.468514,-27.909044,-42.17964,-98.855582,-145.545266,-196.345246,-181.217048,-120.748136,-116.591188,-173.82638,-190.634192,-185.693706,-220.109395,-228.082578,-108.191955,-9.522759,29.099223,-175.169459,-260.095027,-354.973314,-396.834227,-440.994183,-411.774325,-220.168977,-109.731691,-42.671706,-101.052436,-120.059767,-129.675558,-108.39218,-2.355226,46.095526,62.100739,25.378258,-7.788134,-142.879284,-220.929852,-295.792424,-275.937582,-172.718181,-154.694594,-223.473056,-210.585062,-159.687004,-38.109839,41.373774,194.310745,212.962084,112.579117,13.916311,-9.586251,-75.916826,-89.555248,-28.595688,-8.553012,-28.762601,-28.908374,-30.725595,-123.993804,-159.218425,-84.493682,4.279095,116.413087,112.299075,48.870581,2.063428,-13.091499,-59.164806,-82.188024,-125.518564,-153.209125,-176.798372,-156.5268,-99.516813,-110.499536,-154.219748,-228.418836,-204.488261,-12.199697,119.630799,266.364264,114.829679,-0.992843,-140.573733,-153.576211,-71.433798,10.234427,150.55142,169.873963,124.136433,70.846389,57.301904,49.80382,68.074017,153.803834,202.380312,261.285466,208.726958,156.408511,105.194081,129.163791,208.460684,234.100853,278.548392,295.980624,269.331438,159.745203,127.058926,180.763316,225.511027,234.702065,249.690667,389.883744,371.152717,287.459756,165.773944,149.144383,196.889305,243.871734,286.449653,265.15055,178.652142,60.651829,-10.740555,-91.222184,-64.404126,85.522803,148.071954,174.626593,167.201265,154.788077,31.91585,-49.912633,-86.228982,-52.969225,12.16849,36.7841,25.653507,-76.138249,-124.204206,-193.258689,-217.112765,-191.504525,-142.138047,-24.056925,25.569355,-16.75503,-157.361486,-163.80368,-11.929746,75.941889,182.890139,205.121278,182.864044,120.310893,107.682226,143.915031,197.547111,292.161127,295.04592,222.328415,109.02031,75.253273,72.871303,86.953331,103.441315,101.612514,126.173266,167.386574,266.752743,287.410441,255.059582,182.718943,169.357284,187.880861,226.629303,365.815145,428.717588,359.184562,150.8572,126.81927,260.848061,326.514485,342.477712,328.759984,320.310922,270.908463,220.767179,152.106881,166.356546,225.394095,228.953679,198.264004,158.834187,140.29243,67.472492,41.286022,96.125534,144.14329,217.793287,233.765347:-232.36924,-412.254765,-497.877863,-491.721806,-368.235577,-44.955559,39.967545,-58.105521,-188.755173,-171.164225,-103.924916,-91.813226,-90.592571,-100.749156,-105.325926,-75.932026,-10.98042,-101.723003,-190.820239,-248.001703,-200.101126,-111.368384,-100.025121,-117.788463,-137.783609,-118.454676,-74.609341,-79.085937,-86.044111,-62.378378,43.112394,95.790832,78.389016,-60.896319,-101.742265,-64.695163,-18.413687,16.267198,18.97074,85.740354,115.004183,97.941015,86.138873,105.327073,202.992485,288.369841,492.780897,543.802736,406.531899,141.891484,27.216288,-160.383154,-186.70244,-57.474892,19.535699,16.603247,-71.078758,-102.877697,-210.529596,-264.420171,-278.864215,-271.746744,-222.367929,-146.073927,-40.669246,-163.038639,-242.492028,-268.207197,-229.059185,-151.240194,-121.313497,-75.225838,-77.268549,-83.343695,-90.443583,-95.757668,-68.031608,-24.350931,119.787881,198.46967,201.136924,66.416956,93.506218,284.941452,306.3792,217.90173,210.376047,166.382451,-70.289073,-160.643914,-167.136352,-118.27155,3.722943,50.574917,85.589182,86.260738,95.555196,34.733879,-34.545214,-130.153391,-141.259069,-76.878595,-0.884402,74.791176,-25.945513,-55.770267,-47.989438,-60.800877,-106.082012,-105.618783,-18.494204,54.253702,133.122871,40.681964,-50.28926,-185.777846,-168.287194,-31.092027,17.94113,52.8522,48.117003,17.458053,-149.335989,-233.311883,-205.283897,-112.708501,-33.246762,-95.082149,-237.516429,-275.653419,-289.271263,-286.053445,-255.703058,-183.842001,-157.290729,-116.767964,-144.924715,-201.233641,-341.107988,-406.406565,-434.740349,-339.579075,-52.003023,6.520598,-104.558887,-204.52405,-206.85628,-196.785528,-195.853643,-186.827016,-157.594399,-59.549768,-57.973911,-80.947215,-71.470693,-60.996868,-76.339716,-60.848588,64.260067,106.37748,77.522166,73.276245,92.49221,122.878885,126.396968,103.08427,114.177313,199.436002,147.216228,75.263332,17.940459,47.042173,139.720635,182.951169,263.869578,271.970477,172.007561,20.922413,-44.036803,-113.578124,-109.219158,-40.505209,16.907784,111.341255,13.642458,-94.526932,-204.239078,-141.990368,57.808083,84.644133,40.748178,50.47377,152.273473,262.76203,282.548544,256.898399,244.747988,241.674919,233.34178,201.59178,159.942417,119.838884,1.073995,-52.205539,-116.462464,-126.745735,-111.315477,-103.752558,-153.233341,-243.182198,-262.999096,-257.387593,-251.931674,-215.22522,-160.93855,-59.11115,-106.623261,-163.946678,-256.314974,-280.835582,-362.63159,-424.107618,-355.411774,-193.906294,41.689796,-4.133196,-44.587348,-39.716489,21.088058,166.835933,180.342914,99.111086,111.571907,140.334218,29.357932,-90.859388,-196.182949,-145.782026,-33.789012,-46.936223,-149.153812,-198.187936,-190.398838,-85.345549,-1.50438,158.466231,208.530246,195.779115,126.832419,98.518258,5.497895,-32.868574,-2.465415,38.440659,62.570646,35.993753,-80.338269,-199.923868,-222.17543,-125.918544,-23.586006,100.356437,83.47955,-20.308181,-68.437246,-73.127245,-93.865181,-97.653136,-101.14233,-124.586431,-187.009593,-194.245119,-149.591365,-136.938856,-157.024041,-162.932727,-135.980892,-11.29035,92.036353,209.907745,63.49802,-16.388736,-36.931721,-9.564665,42.527201,80.334507,198.186966,237.992412,157.941427,-3.454867,-9.301361,130.597662,187.616411,217.673991,251.498223,353.380278,356.543505,303.902096,144.398935,99.099634,166.365448,241.859104,340.852591,346.861621,271.994432,156.487231,142.343854,231.441047,285.557064,281.778645,277.470287,388.178531,306.176404,175.764654,54.052622,88.763163,196.961355,218.465961,226.982317,242.04205,241.087966,178.06177,127.005799,7.751655,-15.419885,88.828111,190.824278,334.022757,266.340702,174.053953,-6.464381,-57.628196,-75.482672,-70.043046,-17.139113,38.310194,110.804333,115.718411,106.237694,2.881444,-71.916104,-104.375437,-46.951249,87.041442,62.284039,-0.182036,-100.113794,-114.029908,-61.744768,0.430425,157.924809,221.223784,234.610139,100.843843,4.637866,-74.448784,11.325352,262.707119,330.133564,337.985058,197.422011,105.350359,40.823416,99.770437,278.573077,313.432075,275.293742,259.253209,238.233034,191.356424,177.437817,188.048546,194.948643,216.027195,258.858354,380.601146,380.37585,319.679173,207.66323,200.287765,251.534486,270.730092,307.040684,340.862455,340.88605,173.674003,106.782158,162.692789,229.539068,237.625912,216.22958,237.718386,250.405306,246.735036,170.178427,116.75161,134.208683,185.900097,259.175543,273.501871:-257.906187,-355.725213,-424.733558,-509.52904,-489.835438,-289.955556,-151.188483,33.634336,71.198117,59.386116,21.411607,22.474108,26.530191,-0.891754,-12.246674,41.343611,104.106866,-17.7535,-112.733187,-275.912467,-299.684738,-206.113361,-127.367871,-23.749284,-53.158451,-94.527381,-188.13445,-235.995365,-278.144949,-252.080447,-131.535139,-68.032526,-20.946771,-103.047203,-157.009272,-214.271985,-198.680308,-106.286475,-55.678441,64.299549,122.695641,93.397854,1.214558,-6.77648,143.12633,290.338189,583.660734,650.105828,509.596196,220.299067,110.066421,-36.056724,-53.380677,22.545945,58.730077,23.138999,-98.094175,-154.435626,-254.077341,-302.619451,-376.687136,-392.54386,-329.451133,-260.109367,-194.385738,-243.616976,-273.303021,-317.784278,-307.684367,-206.174325,-150.598255,-87.229464,-80.750342,-81.852547,-91.237612,-103.519647,-87.279884,-41.643592,126.067414,231.690692,351.564026,294.042534,259.897899,277.290399,319.412425,375.111065,336.282267,91.860026,-155.402824,-207.314467,-229.979185,-230.786834,-148.655738,-63.708623,99.679414,144.321042,98.82099,-46.214269,-103.40094,-187.198534,-202.462973,-87.337124,6.923639,66.285516,9.217699,8.944419,16.288541,-2.96352,14.619118,86.344051,309.93817,402.516453,420.017669,296.370586,213.303841,26.083549,-19.266149,73.475813,166.878688,261.451194,127.493706,13.645,-171.561801,-216.850214,-232.651593,-211.720651,-142.809436,-134.661815,-222.307845,-326.103831,-353.327766,-391.927891,-399.024923,-354.021325,-304.618734,-209.896253,-237.333567,-307.951934,-430.380518,-439.803104,-361.210398,-284.697587,-96.251144,-11.96546,44.221631,-87.484848,-186.42496,-320.982492,-324.141436,-222.858087,-152.520379,-46.429477,-66.585102,-115.472919,-201.268207,-219.087257,-207.299408,-183.765083,-80.808782,-6.907175,91.838214,44.608009,-1.371179,-6.141309,37.638353,107.999984,134.943368,204.511124,184.757107,152.091364,143.693926,167.23737,248.950802,304.732024,404.438069,417.088979,305.949775,143.448437,102.260623,65.032539,73.605839,179.577816,239.5676,264.132387,123.552161,32.837567,-32.382248,10.29338,108.0334,106.092441,64.128712,64.027975,95.383242,142.784706,151.863847,142.032363,151.123227,203.130178,234.010479,265.996669,152.237936,51.30436,-95.971907,-114.712017,-95.334632,-98.761756,-142.063261,-142.085358,-82.52557,-50.667774,-77.01609,-216.294131,-290.725595,-303.677002,-219.990588,-14.980112,-30.772454,-115.131295,-284.407943,-332.704283,-304.687111,-245.719792,-107.335757,-30.716704,109.669119,188.445727,164.700769,19.166381,-13.565401,75.138068,137.879771,227.58458,288.647896,282.808894,135.665244,31.030505,-74.747573,-59.101929,19.381734,23.74542,-60.398255,-96.989977,-69.77496,24.2737,62.826573,88.397938,91.135246,114.387456,108.910625,66.184954,-104.998558,-168.571486,-111.209768,-37.132547,56.111549,60.931086,-14.033719,-127.246873,-156.391899,-61.446264,36.194206,84.894179,28.292197,-30.843448,11.140892,2.728821,-119.449609,-193.294383,-262.114803,-251.815823,-171.011541,-141.494573,-226.679681,-322.068836,-313.79464,-286.580194,-276.666274,-175.86937,-64.685794,173.712266,206.752255,138.517624,-21.93171,-55.770971,17.315545,78.848207,145.307609,166.245148,189.095768,147.711283,114.257342,56.29136,51.661792,102.170347,145.03756,209.285505,190.672473,173.945631,133.49988,101.165511,90.569015,129.388772,230.825566,252.477741,166.327892,63.622649,74.149567,93.792773,59.107787,10.259975,58.829013,218.555146,134.22217,33.612423,-22.420852,16.320093,106.654525,137.386121,174.301198,191.841267,188.94642,125.004236,77.245737,-3.105587,2.482925,96.967477,157.006554,236.240015,152.035722,91.257651,62.726592,71.569238,60.623526,43.664024,59.467181,100.469821,139.775332,101.165141,70.691439,-67.895692,-140.042257,-106.447361,-14.145386,120.575394,91.60188,49.479071,-24.913357,-35.47611,43.019846,110.110073,209.136515,234.901452,252.59666,200.014754,123.986077,-22.407322,1.762497,192.069449,256.143197,258.877579,171.655513,110.419755,54.504266,99.563908,220.379465,222.067952,173.53085,191.734304,255.984351,218.055796,173.572769,48.825843,-3.367913,20.617791,89.511319,238.768136,276.781523,238.454836,108.386376,57.226149,81.908668,144.449127,226.892904,229.813617,201.943698,152.289067,130.184787,148.229865,166.22383,107.439907,80.241302,161.933958,221.174487,184.352125,58.215812,31.133572,97.148763,130.64803,152.619083,195.208:-253.556738,-375.323398,-484.839782,-593.111043,-500.835978,-154.800115,-27.251455,33.157127,11.51996,3.090629,-42.714467,-62.967882,-64.672837,-42.268656,59.054749,110.775223,96.771381,-115.315537,-239.938651,-316.527475,-250.65273,-114.910133,-95.103468,-93.868307,-125.151288,-137.92426,-142.642758,-168.47807,-243.860469,-223.663349,-58.539518,-6.616474,-69.233666,-178.013257,-213.926383,-231.816312,-191.0521,-32.167625,57.442231,189.158796,165.451251,106.341292,21.204486,50.321173,250.53171,360.843272,521.428736,564.900948,490.573665,238.614641,128.336887,22.003785,32.139299,116.616755,126.112011,40.739748,-46.471108,-87.028602,-216.036171,-268.788069,-263.61402,-245.869625,-201.964047,-139.903862,-48.581864,-180.731925,-279.227968,-380.824261,-366.182491,-249.353501,-180.973858,-69.758966,-57.675308,-86.817791,-131.77875,-130.535425,-98.374184,-68.477167,88.139346,202.959823,293.354704,137.9195,83.450354,146.20569,212.362012,318.424149,338.199002,157.014757,-182.798154,-249.979759,-197.896872,-156.214157,-89.615283,-50.312556,57.734987,94.71304,46.037539,-114.149357,-178.618437,-247.088556,-262.671036,-182.072535,-89.35439,0.044715,-98.941268,-136.905654,-97.64541,-34.677691,96.069129,137.278479,210.740058,268.005675,338.790364,211.592096,108.739002,5.315329,35.204192,156.617941,193.226931,157.537899,22.720553,-43.108592,-180.014356,-241.292826,-251.742581,-211.086675,-166.978123,-192.135292,-302.984303,-398.628766,-420.007124,-386.307527,-331.118057,-213.964675,-187.377317,-231.223994,-273.929367,-256.466785,-259.699172,-314.631992,-400.340211,-342.69987,-56.164942,48.647496,13.795367,-152.553572,-212.816241,-222.983682,-174.323861,-68.879932,-41.702892,-36.250964,-84.635757,-104.927129,-117.923724,-127.438134,-121.494822,-73.636101,78.810639,114.08921,49.184803,-25.47154,-40.229702,3.86367,54.258775,111.378588,136.786277,234.679132,254.945669,198.531873,54.454212,52.500969,196.286233,261.903797,312.08257,319.118745,280.281396,163.896836,111.459756,51.948797,51.41626,127.382529,182.089046,235.673385,165.277388,96.371584,-18.344065,-15.076812,82.760784,119.954499,168.446434,204.969995,246.303511,201.86069,176.706256,177.145734,199.425737,231.132444,248.110268,311.446289,239.466997,133.778747,-51.847205,-96.820835,-120.442368,-104.276646,-68.083511,-79.638985,-141.377141,-169.911978,-189.392578,-288.453405,-332.744855,-296.382783,-210.011575,-14.803402,14.173563,-51.565563,-259.401496,-335.279522,-340.105797,-309.895745,-238.096895,-164.797509,11.497995,54.742949,1.625168,-115.628524,-93.138468,106.491848,209.850275,280.955819,219.495522,175.866966,27.509504,-37.321108,-20.937293,23.311375,51.371886,20.916998,-84.819424,-142.064407,-124.214908,-21.749576,25.103251,96.698873,136.331759,173.825404,125.431961,88.949009,-19.48338,-62.906111,11.969397,119.014891,274.337511,266.960031,119.216879,-54.990713,-127.499679,-136.673597,-38.476895,169.76041,188.088904,63.68173,-65.960368,-94.473312,-149.923638,-182.737349,-197.767459,-168.806443,-66.03126,-34.009684,-93.793,-224.5764,-265.419239,-243.185316,-184.471466,-9.430696,100.374687,266.721513,213.129082,137.054969,52.235117,66.253331,128.077469,147.113688,206.2112,245.631063,258.288846,174.254684,116.002676,46.2876,62.602792,194.794569,293.997841,427.994785,409.189049,392.215139,295.440519,204.099983,174.603927,278.039305,484.114771,487.041266,330.039749,184.155919,131.171474,81.365536,94.802742,129.694579,155.727709,253.084179,211.253337,143.063088,98.871168,128.451328,178.526056,177.41186,206.348824,251.16173,270.755199,158.687999,81.942667,-24.001729,-9.990657,115.875714,190.823946,298.266228,212.608162,106.351662,-63.201745,-80.689859,-39.77818,-37.924922,-23.717619,27.371721,107.150588,48.31714,-14.383747,-121.03791,-125.224897,-15.907884,66.624864,142.135788,21.879948,-52.489795,-130.486821,-133.272979,-59.886405,10.650719,121.311732,134.017154,125.821132,87.538709,14.493207,-165.861524,-176.481959,17.588219,140.940001,239.13637,122.249604,30.839058,-67.477534,-32.56802,120.006782,169.48271,185.929539,178.308347,155.668193,120.677711,83.207431,-1.60526,-1.068834,91.46144,148.17855,239.289044,235.404798,185.812931,80.686951,65.863814,94.713612,119.438658,247.607521,333.457199,339.416122,120.336816,23.131624,8.713307,69.338895,177.63886,222.920859,272.774138,219.352609,186.509197,86.361768,31.158554,18.433116,65.807607,231.644798,309.53762:-382.267475,-376.624412,-357.441712,-309.278187,-263.846271,-87.274906,36.781191,260.722149,319.016528,289.403421,191.154867,166.875149,201.335701,220.843718,213.9683,190.881439,110.52015,5.27214,-82.561882,-240.567982,-235.739726,-142.402392,-121.41003,-96.877261,-46.45191,-41.989977,-123.250323,-195.014434,-286.722791,-274.486872,-169.83137,-116.822792,-112.638373,-272.288244,-353.256229,-378.409034,-317.233838,-164.416499,-118.173148,-46.999708,-12.41293,-37.065778,-75.741743,-39.991695,159.709598,286.670133,484.153459,521.110915,402.718571,139.320232,34.17929,-24.857827,19.642594,119.72971,127.701392,78.509657,-18.092432,-81.457789,-188.490067,-232.965738,-309.861982,-327.589546,-283.146446,-225.471609,-149.667968,-200.209808,-255.680903,-354.462867,-369.220714,-321.19905,-257.662909,-111.136885,-94.752369,-108.513322,-78.555227,-63.338948,-78.471576,-50.060242,201.479752,346.004973,391.569512,263.827457,253.863962,316.838451,349.214634,352.983,301.029797,94.422209,-127.70944,-197.466184,-245.389706,-240.16441,-216.471941,-217.341899,-182.454206,-106.051722,39.927687,1.260364,-54.587538,-158.083104,-174.302637,-75.04976,10.919789,116.048401,43.164947,-25.478266,-66.872026,-15.086936,139.858694,206.755224,358.794324,452.597909,553.874913,454.285546,357.374184,171.792478,128.335282,190.539043,260.913215,294.069222,75.550237,-66.61361,-236.080313,-256.371475,-261.357405,-252.240153,-185.858103,-151.844172,-175.044208,-253.122582,-259.036725,-247.87094,-238.952752,-188.509446,-164.154814,-149.069669,-184.17247,-224.319046,-337.788778,-382.902236,-372.667771,-299.279009,4.316425,186.477905,327.103007,85.988171,-53.207011,-160.224966,-127.741122,-9.915415,44.949071,127.892529,86.982166,25.888844,-36.64474,-23.943355,1.032369,7.144696,46.175641,72.536949,69.496176,-16.675202,-48.172313,-19.955237,39.400596,214.818287,294.970472,356.218447,315.446303,290.949458,265.038057,255.666968,267.833898,316.628833,465.174073,511.124029,456.943578,333.029884,291.715406,202.958914,174.762486,252.842114,326.904988,381.230337,251.220863,166.921985,83.333109,75.05923,45.144844,23.360303,7.553072,2.201667,-39.218639,-55.235124,-51.366859,-8.462092,46.433656,142.605199,157.965924,165.355109,91.598692,27.582535,-3.744368,31.369312,58.058421,9.341922,-134.976398,-140.282077,-11.302887,22.979866,-26.23809,-172.303654,-224.540338,-194.220073,-101.71545,58.955717,-48.283745,-135.271225,-221.847206,-229.295651,-193.054129,-162.562353,-92.112876,-47.545071,32.805108,137.140862,168.753766,94.373506,40.938703,45.304362,92.768872,213.650072,299.093103,282.116235,132.340747,70.307826,81.653329,110.098282,71.050345,6.487378,-74.24467,6.854429,51.485935,16.839445,-23.783777,-10.930456,23.927258,38.572114,-9.338792,-33.976021,-130.768499,-191.016528,-177.738646,-98.579905,-9.023485,-54.971605,-228.092207,-303.188068,-287.690513,-172.795788,-86.481766,48.414901,72.213182,55.804387,-33.17517,-81.882892,-154.115836,-205.879788,-305.793884,-296.57004,-170.99363,-137.338991,-273.730768,-448.397714,-436.420663,-249.624276,-136.473332,58.942728,144.85943,244.098079,243.232082,242.02231,200.13735,158.422831,145.99857,159.664168,155.968968,168.444337,226.504643,227.764379,176.431555,50.153068,61.759945,184.048185,206.52105,217.22853,214.394356,161.799883,36.673028,27.539208,115.591396,162.710853,178.296527,156.170177,121.345689,142.67633,152.222686,113.313101,75.753793,42.670193,75.811447,183.985621,125.542752,54.540262,-17.579406,-29.505846,-18.535971,3.322642,23.246022,24.335703,38.969994,10.239081,-38.563789,-129.1972,-124.371,-14.99588,43.330832,59.2841,-38.722861,-66.039379,-63.822017,-75.887741,-101.234443,-102.995463,-101.28237,-88.930196,-77.69566,-129.888405,-137.267795,-79.73936,-52.483872,-41.42638,-26.736681,43.385064,23.790608,-14.858728,-40.701936,-34.570757,-17.724595,-0.796448,70.082386,118.920493,154.953082,57.860795,0.178009,-40.056205,0.884348,144.396641,182.179675,124.803087,21.364921,0.185244,7.700445,15.708438,33.573149,34.436023,-0.739401,-3.736972,52.831525,105.024793,124.752364,112.522389,51.254882,-101.816654,-110.386731,25.006792,55.498111,2.962715,-83.263361,-108.754805,-118.14162,-70.174108,88.163221,137.18333,116.751696,46.991819,31.301386,10.243574,-21.251768,-91.210104,-84.198434,22.098906,93.330557,88.024859,56.978683,56.869726,114.467411,155.841272,225.905814,268.621815:-295.997163,-440.267534,-503.553891,-499.802835,-405.064679,-97.193558,51.100371,215.220421,194.325602,143.899714,37.495147,18.022812,86.597466,138.32907,203.467572,215.907919,147.296143,-55.741683,-171.547471,-277.96956,-226.003093,-45.838427,1.66535,-43.069568,-179.654525,-228.999271,-309.425133,-358.552146,-366.97473,-289.946465,-92.95368,-50.638342,-124.953066,-260.130016,-307.012096,-310.515941,-249.39384,-74.426554,2.894916,124.292963,105.039706,27.198906,-73.145526,-28.061709,205.593827,338.158825,549.912382,601.602194,509.164687,197.001009,43.110981,-101.34624,-74.888957,74.260019,140.778706,172.337741,27.457821,-92.883202,-308.671387,-350.860633,-277.09319,-221.770798,-165.341312,-145.218323,-132.010963,-259.520479,-370.78851,-489.03974,-434.984621,-215.553119,-120.273715,-35.67546,-127.301075,-189.347227,-234.846416,-235.855157,-220.983111,-157.236539,130.737787,273.229728,335.754924,228.650462,210.97308,243.736435,278.756039,398.573086,424.646455,262.823049,-9.065984,-111.51794,-262.643454,-304.538117,-230.037179,-133.146678,31.107915,65.326481,-7.153537,-196.625575,-273.591919,-306.531693,-243.464999,-35.506177,36.100122,67.609767,38.755069,14.097914,-19.494559,6.302329,179.66714,284.420621,421.439247,453.550462,476.647755,412.651845,326.699238,145.340265,129.162919,255.644101,322.87765,321.118055,116.180257,-13.788074,-209.298302,-246.915848,-205.474587,-172.471956,-154.152644,-160.950616,-218.895404,-354.469182,-417.190511,-446.586953,-406.257047,-262.309643,-193.24581,-165.507217,-244.085155,-270.680502,-325.35515,-361.527306,-340.80023,-250.74303,0.800922,93.51145,113.708303,-69.375391,-182.663623,-258.285102,-197.899038,-29.447373,40.758758,121.496555,25.437856,-58.803799,-142.64361,-114.696455,5.42807,48.911753,107.105865,140.724681,148.378536,-7.246292,-78.907898,-16.060307,91.648916,246.213542,282.044844,321.592661,267.612028,226.880774,208.505351,226.288563,257.411433,287.081779,428.277227,493.555448,451.845016,288.679325,247.007246,253.522189,283.525602,374.984015,410.872412,379.626734,210.351494,118.89232,8.391127,23.005587,192.533688,261.762652,230.399654,179.580981,109.468712,65.930789,73.640942,176.341506,228.362129,233.729754,219.946223,246.834172,199.783894,109.35879,-89.44421,-137.171565,-117.749692,-101.674812,-106.019535,-99.108705,-81.816282,-115.259613,-150.76447,-235.938116,-254.597884,-186.282652,-102.124141,46.0218,-6.647976,-100.367401,-303.61522,-339.802437,-192.243751,-78.569126,37.994065,49.149619,85.842222,136.930639,101.701608,-37.875643,-50.58874,69.287825,136.354771,202.794305,231.463458,220.45766,68.73372,-29.052784,-66.007652,-9.172756,87.485212,82.007,-21.840953,-123.181556,-132.877031,-50.653916,-3.507903,-5.115018,-21.23278,18.000803,78.444129,65.443985,-49.855185,-87.061722,-9.568374,61.628118,122.634593,94.713416,-28.618413,-130.943868,-173.855199,-208.069315,-147.728468,66.515676,140.652796,148.754709,55.614298,7.175352,-110.917009,-182.64853,-249.232198,-205.616798,-46.986296,-20.82049,-166.264448,-327.647401,-333.431263,-226.043493,-148.833797,-23.056489,43.73931,230.328759,342.267539,320.133347,175.56136,114.802606,100.554495,126.864956,202.699031,248.129153,269.32517,189.682309,161.916958,159.21961,180.054575,238.107917,269.519742,332.012829,288.95148,220.905746,101.185115,79.50208,134.999126,197.250809,299.57114,315.363162,248.101591,107.249841,52.623814,-5.232928,2.301381,84.381783,120.256851,103.620688,17.821503,-8.099084,-12.515055,11.316166,128.53438,179.901613,175.729187,143.065917,81.263394,59.910966,41.509918,-44.143792,-66.070382,-4.648635,55.098762,165.299502,171.632542,120.382583,-8.469982,-36.369453,-25.139329,-29.174121,0.570797,64.234838,113.860253,-19.688768,-57.043278,-24.802353,-4.900891,35.297998,83.520512,167.905812,78.101463,2.144271,-89.576165,-106.055871,-64.642148,-11.361031,72.922184,84.809973,44.025178,-55.404054,-119.51468,-167.696959,-88.316949,153.912386,203.375513,108.273757,-29.638507,-70.338203,-98.482526,-71.857931,37.190763,82.060553,129.152649,129.500338,65.044442,-51.560313,-110.736732,-198.168568,-211.920005,-131.57252,-42.1954,97.0435,45.223872,-29.373807,-184.09184,-217.203544,-117.250237,-24.735732,114.329563,153.835849,161.134053,60.014946,-3.503296,-64.855709,-38.716272,63.125116,97.128502,106.033326,99.350502,112.631739,85.321594,37.708256,40.354604,107.636461,242.278411,289.754014:-230.924064,-230.827975,-199.367927,-145.804763,-126.811856,-29.444334,68.035779,314.978817,448.52559,431.492465,321.628382,268.944605,209.403686,205.904698,226.248304,224.28578,179.930456,121.358542,83.152153,26.903391,51.049822,171.003865,213.207779,266.318155,325.611813,329.387746,243.600028,142.412866,-115.649356,-195.826067,-193.872835,-178.564885,-253.725249,-353.775569,-360.063809,-311.662387,-280.431244,-229.852857,-202.916929,-143.040529,-152.09668,-198.541999,-259.622961,-225.668207,-55.277431,31.19307,97.389072,73.665806,-20.679598,-134.803051,-200.83769,-288.843938,-280.190666,-197.85422,-166.090632,-178.193588,-254.656184,-260.024701,-180.627933,-149.906142,-132.243688,-118.432699,-95.969105,-98.389555,-132.131964,-209.160048,-257.117036,-334.918444,-341.623505,-293.19858,-267.319131,-244.341053,-248.289098,-244.230861,-190.999577,-150.824293,-79.590935,-43.576194,76.315493,157.737211,289.764538,303.502526,270.820671,226.397992,264.388098,364.817565,328.820802,73.008033,-185.910848,-248.338593,-232.643044,-213.898328,-239.012067,-241.941422,-169.910668,-122.946118,-52.385399,-21.584656,-43.762323,-129.264405,-133.738698,-46.098807,-5.989525,23.167171,23.910609,8.713207,-16.183673,-4.874945,67.046958,127.23495,264.757706,323.031766,380.751044,313.663123,239.997638,128.462681,121.963709,184.24634,236.084422,301.204514,167.725257,42.285759,-155.526627,-204.379228,-274.087413,-303.506272,-249.161697,-146.442816,19.396322,-32.758832,-72.1091,-67.366353,-40.240137,-2.319537,24.410882,117.546901,84.414354,18.45979,-75.39405,-88.669608,-26.431163,65.017203,301.07461,392.752313,450.614406,353.179423,289.627879,227.61728,235.626301,300.718988,341.959877,363.633089,221.661275,128.708971,48.815499,58.682968,56.534918,40.111488,54.345642,90.32558,163.909197,176.708134,154.06555,124.472453,178.036211,380.210008,445.405706,461.062399,442.302214,423.970759,335.444479,283.215466,260.122674,301.661021,424.600349,465.698304,425.38452,271.221896,217.499521,219.421534,258.592194,329.617637,331.665022,295.215824,249.172656,220.860035,168.843607,137.132468,60.339203,27.59669,-32.058596,-74.235544,-168.917095,-144.492186,-92.445168,-30.93768,-7.259098,113.246475,179.550111,230.293896,196.81165,173.530976,169.956955,179.614618,197.625118,212.130463,210.91928,198.700819,201.921825,157.619599,108.550977,50.309699,43.239572,40.24732,67.615086,179.371259,178.229175,117.234815,-12.787594,-60.545221,-148.916755,-178.910003,-122.87339,-35.602284,110.878551,114.958601,73.590834,-49.598387,-78.629105,-26.433502,15.594733,108.128505,173.793225,160.28187,78.554622,38.414336,8.420873,18.032679,0.227079,-38.936978,-90.191691,-58.284848,-48.687005,-109.648898,-158.740339,-225.214638,-249.630705,-310.234445,-329.670364,-310.269558,-308.237993,-343.8911,-377.100156,-347.963071,-281.56132,-280.407929,-319.790969,-346.105686,-359.699768,-351.754318,-310.265131,-238.873623,-224.012882,-126.431351,-34.252589,-42.09152,-112.217021,-167.229438,-279.339679,-286.689423,-187.766719,-141.583166,-209.722834,-333.271248,-308.65047,-104.523402,15.589793,158.000567,186.420282,275.399883,310.916924,265.326488,137.386861,85.903963,44.037824,62.801523,136.722745,173.067103,208.706823,159.448049,115.456309,48.859753,45.13964,58.186597,53.827997,79.51292,123.081906,98.854122,-22.823567,-72.634691,-64.182731,-29.11599,1.263397,6.817553,8.895562,-29.621739,-29.755016,-7.666757,-24.076363,-83.601702,-88.360341,-52.582203,-95.308876,-135.056698,-131.771078,-132.423863,-223.200338,-255.060547,-229.515186,-211.002475,-194.949718,-135.534668,-120.738822,-176.361887,-188.537235,-107.291907,-57.17891,-15.072328,-12.738175,-20.886027,-106.821709,-158.273189,-146.602957,-107.793344,-89.609071,-102.459328,-138.987859,-161.81147,-128.758168,-19.046453,13.237593,5.308059,-16.872821,-7.241038,29.579127,4.775819,-99.067111,-136.359738,-116.767354,-64.242483,19.867789,18.271501,-41.836056,-128.79761,-170.488628,-175.936776,-118.725833,12.131172,17.269767,-76.972375,-98.49132,-72.021868,-48.218236,-43.057868,11.589523,15.374517,-88.105058,-130.741163,-127.575557,-114.80048,-94.342801,-61.446102,-100.571984,-225.88296,-228.719693,-102.770287,-65.803684,-105.874125,-195.426511,-220.631949,-180.377201,-112.087073,21.978298,45.145613,11.523123,25.899292,59.566513,46.486127,-1.219472,-33.514183,-0.919622,84.542897,135.97601,139.437452,68.124648,6.457139,-39.763373,-10.521823,93.17677,164.49402:-182.312347,-172.543008,-112.602404,19.042731,33.173554,48.749839,121.674608,308.654742,290.831136,232.744958,156.396617,141.565641,149.863805,170.499016,204.713594,195.842307,122.531828,55.9839,27.776245,-32.386739,-30.326402,34.355298,53.233388,75.517248,158.979517,202.484578,155.281358,42.80844,-196.779116,-229.668089,-128.520915,-74.010436,-45.390214,-82.080483,-132.083821,-268.131955,-307.667578,-287.106614,-250.34371,-172.846639,-125.262373,-118.867871,-99.206686,-67.479896,55.501393,116.703687,192.960945,223.841563,222.676539,125.377813,65.519471,-48.702183,-70.595522,-47.83174,-43.962568,-85.508029,-141.20567,-164.208062,-234.368018,-278.19743,-298.159105,-268.712813,-208.883922,-186.961861,-157.104091,-151.225436,-138.188467,-125.233359,-145.352716,-190.548198,-190.537926,-150.826003,-136.820886,-140.740869,-104.664668,-73.474495,-45.155573,-22.600239,108.815002,188.315303,266.828373,225.49439,187.759539,149.850871,179.461846,214.639873,142.26464,-73.039747,-178.480877,-206.710886,-238.882591,-238.297059,-222.045437,-231.947222,-227.833374,-142.229283,98.825922,141.267817,82.172132,-72.994815,-104.605231,-35.362501,33.017535,176.257322,207.794596,164.750355,76.230088,54.116587,41.426572,65.494244,204.413985,280.275722,344.998868,323.805745,257.652067,27.69707,-37.520068,51.80435,141.155911,196.709382,35.483324,-54.76221,-182.537986,-255.320954,-369.481273,-344.841023,-166.419566,-87.993177,-45.371257,-76.132548,-83.340276,-77.091991,-44.987951,64.882097,100.976854,76.845654,-32.864322,-80.229551,-148.389582,-173.927365,-159.365958,-95.672799,153.918794,290.434005,354.73211,185.321146,123.670887,46.058848,-4.453309,-61.574502,-16.035662,170.308983,185.530786,112.45851,-11.234713,-30.501999,-24.03974,-20.161931,-17.665404,-5.643048,32.360184,36.456194,4.617512,-74.443358,-59.246612,117.254645,208.27093,231.024003,109.511012,64.455018,46.747065,69.431449,153.564405,203.437751,281.477563,271.39914,145.356962,58.648952,67.334473,109.292017,113.229895,114.397502,137.855964,214.151161,174.53137,125.680054,91.598911,90.349079,14.99417,-47.14302,-91.59096,-77.632343,-100.915602,-123.458007,-104.346691,-109.993277,-124.48513,-41.53628,40.797406,143.946035,126.110594,119.585418,149.450427,149.58376,141.863191,152.49801,165.373017,162.237564,113.470711,72.623924,58.927522,-36.157653,-80.258613,-27.043878,49.267771,160.260244,103.236568,33.077961,-96.889253,-141.305327,-151.903432,-109.750078,36.288779,103.608517,149.095433,116.909063,68.475173,-51.632255,-49.938534,95.683199,155.246052,137.646856,87.223689,85.518596,50.701902,14.341019,-20.543956,-28.856637,-73.218423,-93.230199,-131.877523,-115.738019,-59.15864,32.549929,29.52816,-36.413457,-66.036571,-66.857574,-18.06408,-17.396729,-144.869698,-248.451462,-323.060211,-266.623572,-164.296164,-178.881377,-278.349888,-322.676122,-304.959554,-261.381252,-255.264237,-234.804671,-214.216767,-184.97512,-171.453481,-146.728889,-141.333238,-220.802033,-437.61434,-471.103058,-393.065909,-369.185966,-453.778701,-483.724396,-413.915576,-262.849437,-209.98091,-28.41939,95.681711,243.120411,213.027006,171.654955,37.003051,-48.520815,-102.271654,-64.897156,12.044218,47.789065,128.278395,124.719923,72.504682,-23.528655,-26.669374,-28.568346,-65.084934,-113.284659,-57.190294,-42.626093,-93.644679,-134.623341,-163.735253,-127.137878,22.857922,89.718982,112.257421,46.136995,28.571964,-4.858788,-37.711313,-81.387839,-70.851907,-18.723239,-22.387647,-48.411781,-127.947665,-173.162593,-191.041916,-149.258698,-71.042646,-71.846487,-146.091465,-234.922473,-248.957505,-220.343711,-196.568672,-173.36394,-186.908294,-195.499641,-84.817411,-42.798026,-108.902948,-172.480023,-173.132819,-107.907626,-8.15252,-16.006839,-133.869786,-224.75813,-195.051374,-93.132531,-92.861018,-143.552552,-137.668386,-50.909012,38.752222,54.138815,17.602076,-17.709672,-34.620844,6.316366,140.568894,189.439214,188.541541,133.586446,119.757627,106.90779,112.923676,190.794065,241.777337,222.418004,51.527377,-3.587568,46.488924,117.707741,156.908985,88.265391,-56.541115,-52.528261,43.053248,89.112814,105.974409,125.635175,100.765408,3.635127,-20.984823,40.669155,82.750926,28.028554,-110.685625,-120.410625,5.425024,116.31908,329.186677,364.396649,233.398586,131.686331,145.723349,124.658557,78.495796,52.95203,99.211829,238.287481,203.930764,113.455464,4.096126,6.841733,-4.516418,-37.962766,-51.437939,-2.990044:-312.613045,-211.844791,-196.451711,-169.800507,-142.211208,-39.374219,49.648896,225.225602,252.777204,212.162589,118.984152,109.679067,163.678922,178.084991,152.592061,144.908699,114.804117,-66.12476,-170.73323,-236.106332,-191.907285,-58.123611,-5.163802,64.754208,61.71185,27.69833,-122.539985,-224.298208,-325.602824,-287.830546,-141.347544,-115.303411,-242.987772,-388.313475,-381.55439,-267.675334,-204.149062,-105.070056,-69.7645,14.077875,70.327631,47.333098,-62.833143,-76.328001,98.748082,224.595472,346.424942,326.217425,162.533915,-45.829932,-97.364167,-66.463633,-23.871839,40.195107,58.165016,53.824976,-52.178718,-120.629211,-245.388626,-293.456697,-276.993088,-223.201424,-166.449156,-163.856783,-127.629338,-154.266702,-220.453037,-354.436419,-388.789642,-404.870516,-382.470869,-276.129492,-198.700293,-186.495351,-198.98111,-209.655519,-152.398441,-67.752409,128.787907,195.779613,233.095194,233.016387,248.306064,288.623095,304.013315,294.034977,254.731104,140.168399,33.552062,-30.520989,-181.369292,-232.649307,-199.953544,-138.098485,-54.067852,-34.095403,8.953355,-38.474266,-107.302408,-215.734101,-211.528062,-96.716672,-28.090312,66.718678,63.820123,5.827059,-115.684329,-113.121525,22.707709,106.233436,249.599545,326.405116,447.389866,389.03913,296.792675,128.901577,114.173425,229.92049,299.291191,315.378864,138.580862,29.802551,-111.319101,-155.417282,-241.334579,-263.587027,-202.362498,-135.095981,-83.486365,-151.235567,-162.12176,-141.230732,-135.767903,-121.853708,-100.310378,-66.292837,-133.176237,-180.326071,-207.271906,-202.181987,-165.7003,-112.2367,59.26209,153.922017,222.747576,76.766057,2.422084,-16.530237,26.234896,133.965441,177.285108,186.850301,92.360734,40.192346,-25.137009,-39.990784,-24.711692,-11.166676,-22.597752,-27.263364,12.772142,33.271165,27.43917,89.858306,181.048566,362.132713,393.820305,376.741954,384.771647,389.110966,326.767223,289.490382,324.108341,382.691639,454.475204,460.164612,420.739344,290.556864,235.224985,224.213729,262.81289,333.492023,324.831816,272.999439,243.521496,212.981026,94.864169,37.496181,27.313011,41.794369,1.715262,-15.206412,22.208784,40.553518,23.273827,16.537899,48.705202,124.608401,138.803417,149.227198,168.819274,164.361011,102.125085,62.123726,43.946519,63.721988,112.945124,145.18259,157.526412,40.313162,-4.369579,-21.460637,-22.627132,-5.463599,31.490253,123.740964,92.6249,27.117551,-109.295551,-125.104298,-3.021375,68.942558,112.724189,97.063491,56.075262,100.180502,128.832992,87.548853,45.302647,31.611375,69.389421,206.377764,273.220764,244.572362,114.94095,32.524698,-81.979466,-84.098898,-51.608025,-59.695311,-97.764306,-101.335036,-110.171064,-138.602554,-137.887612,-155.881875,-193.065907,-225.948739,-143.098516,-102.061399,-127.655727,-182.593392,-212.346256,-163.270242,-53.013274,-54.402602,-212.802941,-354.936292,-336.220764,-195.386318,-129.65402,-52.126524,-24.50104,18.816735,11.887774,-13.174322,-136.661567,-209.54108,-245.453508,-202.503687,-132.165748,-158.08877,-293.993573,-286.930021,-210.331396,-93.073337,-65.085745,-14.689646,23.854596,171.814604,285.542637,278.050423,201.875548,150.526814,12.410128,-21.443938,92.890951,170.484043,162.423266,64.258854,35.6792,-42.164623,-75.451167,-21.241669,44.381515,109.686525,62.128362,30.096618,-13.124215,-22.312144,2.404373,13.902452,-5.750352,1.122931,31.72019,-64.153909,-94.768314,-3.280041,41.523455,-22.633535,-88.714346,-134.265433,-102.675733,-117.557243,-199.89693,-217.829114,-146.180886,-109.955147,-149.705148,-179.153764,-113.016894,14.123198,13.809487,-68.146308,-86.238055,-45.259007,7.965926,112.658912,88.548354,53.294909,6.215486,-10.825728,-21.293037,-29.338828,-58.486108,-39.993705,20.228669,19.283657,30.488536,55.380834,66.141599,116.654942,138.341017,139.230214,78.128821,31.241478,-39.480597,-49.798344,-39.820045,-16.085692,84.318003,113.508799,6.768903,-130.165245,-129.100054,-18.511309,59.526107,135.231587,108.674584,59.927175,76.766585,64.830357,7.776742,5.038488,65.795497,79.278968,16.085984,-14.661729,-23.665028,-71.332001,-83.108603,-35.946708,-31.895198,-123.096261,-156.933721,-118.21511,-93.500708,-112.50073,-196.54101,-241.720183,-219.312187,-140.743004,32.772505,68.58582,-2.413328,-134.928172,-168.688036,-148.433325,-107.601912,-11.73182,15.577208,6.609332,17.933911,45.141463,66.537081,58.570432,53.571518,52.733259,112.703288,193.77876:right
53.307192,3.316112,-32.202176,-116.380944,-149.584798,-165.916999,-148.500128,-41.824938,123.895513,169.557794,110.366022,34.858872,-63.944336,-52.135427,69.880737,127.719893,130.88246,23.180307,-40.476111,-102.809562,-68.382035,78.474518,129.031889,116.489432,40.221246,10.918606,3.346325,38.727067,186.642001,279.679171,406.970441,408.366462,307.359882,121.03786,34.02584,-16.521954,12.855223,101.202405,129.824308,148.654253,136.751226,108.677748,31.847267,-6.178818,-52.88344,-45.972764,14.521709,51.506705,86.852099,32.031777,8.836121,25.0289,43.649805,52.050457,55.153109,96.791002,66.441511,-2.590029,-140.214386,-178.662321,-196.979224,-168.431556,-71.65571,-47.361976,-115.657284,-239.192493,-252.984414,-291.171286,-353.626435,-376.363402,-284.883087,-22.308478,67.763778,14.768176,-112.48625,-128.992935,-86.882556,-55.473712,19.953652,68.752715,88.318028,-76.393772,-149.010791,-148.700856,-101.962872,3.102418,48.238185,75.931751,-45.843673,-116.174958,-111.429326,-68.846343,-41.036517,-55.146886,-98.493793,-109.197944,-81.471182,-20.652977,13.796701,72.900933,116.066906,260.657299,321.02298,355.273497,295.561626,231.23409,85.407517,43.243853,68.343723,107.46171,100.694509,72.649707,118.615487,166.431472,132.199463,6.869436,-45.05758,-73.695107,-68.958696,-73.005029,-94.656033,-106.72034,-151.248643,-194.333697,-274.992297,-276.874154,-195.583441,-136.216085,-15.588719,4.894231,-65.780052,-273.087169,-318.163851,-215.611166,-143.300781,-86.288983,-37.754886,-13.760185,-20.261308,-35.43254,-84.84253,-121.871391,-120.955134,-54.451725,77.038627,25.994909,-46.869878,-193.513413,-219.639765,-142.95025,-91.076129,-19.893464,21.863451,13.029152,-86.583867,-147.872814,-172.025463,-132.08154,-70.972309,-74.468193,-89.315074,-85.387874,-109.06365,-210.613939,-240.530371,-155.780573,-69.276135,80.82469,148.728809,120.633839,-28.644352,-94.514728,-99.151453,-47.940339,52.765467,78.367666,40.817453,-58.055089,-66.02471,-78.618258,-141.116541,-274.249344,-287.227153,-200.952301,-100.05209,-103.994518,-183.394861,-207.972054,-173.410123,-124.798415,-13.916195,39.811949,105.56235,103.832119,102.371622,73.785317,44.048451,29.221977,43.580526,64.975998,115.222561,138.347163,81.885718,5.357008,-123.683941,-130.939877,-25.958804,53.916464,153.215407,117.915143,73.683983,-7.992648,-10.104106,67.183776,82.105943,24.92363,6.53574,29.552182,95.151495,107.145105,68.397208,33.976409,-16.182145,-2.951853,95.858436,71.606234,-42.80494,-306.518027,-344.886157,-213.22211,-135.310274,-62.043274,-38.140095,-42.511681,-60.350072,-59.922523,-28.807209,-13.739788,-48.310374,-73.681553,-70.750703,-69.429988,-80.519436,-147.823004,-210.145024,-309.724602,-301.885268,-181.844505,-124.869068,-156.109452,-274.349019,-334.876877,-366.636015,-315.218281,-186.054888,-152.533533,-145.732553,-203.312705,-233.961652,-232.268275,-199.660046,-125.726485,-88.235044,59.18466,261.544042,308.053191,229.658137,143.156465,74.08493,110.833721,127.634508,87.195465,46.871494,30.092765,0.334235,-72.042398,-79.752534,47.046678,155.335725,282.555142,258.295167,229.551873,106.984898,2.993353,-131.868001,-127.164304,-82.101013,-66.621451,-101.514124,-249.207787,-278.867952,-196.746302,-148.078543,-76.024652,-15.947751,168.617092,288.211486,266.558977,110.582876,44.805489,35.810306,62.329217,93.475683,102.522969,82.231855,40.07581,50.049084,10.192874,-58.453622,-123.2249,-104.129889,-55.254675,-25.365929,-15.750977,-17.829856,-42.382363,-81.562034,-46.006199,133.499887,218.224931,238.857414,157.432713,154.442905,151.383753,123.863519,102.941956,109.646301,115.777964,143.247302,139.466052,45.828926,-12.594716,-33.613919,6.630338,58.757495,41.03585,-19.538295,-71.770367,-84.989137,-74.700597,-77.480498,-141.365039,-181.687004,-133.26862,9.809682,21.526436,-58.842161,-127.174067,-268.213638,-310.752616,-321.654355,-298.412213,-250.635742,-270.574569,-286.166873,-268.853686,-217.114711,-37.884507,35.722467,65.993918,-8.339937,-52.341993,-125.271327,-152.693355,-148.192722,-117.705789,-69.948027,-56.829144,-15.22664,58.739803,114.420513,172.904858,133.901699,-42.403453,-131.377805,-165.66268,-81.55737,-104.437779,-261.647451,-299.706753,-208.048903,-144.426542,-106.592712,-93.158749,19.471738,92.64757,60.408562,-71.957796,-113.71282,-88.596119,-43.822762,84.062042,175.665155,158.466735,78.358681,59.61686,81.087646,116.052568,180.594473,185.885076:16.250825,-78.655587,-109.946076,-139.613518,-160.387179,-200.525237,-177.849693,4.22502,173.669631,191.71234,120.791837,56.486189,-55.224281,-75.555459,-14.943281,37.454952,49.853822,-77.348319,-137.180946,-140.139727,-80.003083,97.834549,159.985367,125.743845,33.437399,39.551855,88.001965,85.509121,81.473864,119.359637,200.947142,213.599429,220.616786,201.053734,169.001083,48.944589,-16.856983,-11.135679,63.202293,157.963477,44.057562,-28.938501,-45.700865,-10.5221,27.916278,29.122835,64.271578,101.677721,119.347869,38.400117,12.055676,29.930599,53.579562,110.431641,162.50225,277.982631,216.619808,114.175397,-115.990051,-198.191366,-209.87925,-142.647587,1.033951,23.08088,-23.260413,-79.885899,-107.202073,-196.401723,-230.088272,-190.118494,-121.463374,29.655856,30.406313,-27.038264,-80.274649,-56.619533,-27.913089,-26.533379,45.245777,89.131246,56.581876,-28.815434,-34.358359,-43.215896,-56.056353,-1.061494,72.534483,180.019741,129.842097,93.038281,58.260604,19.099454,-101.84782,-128.089795,-57.226794,15.135708,115.674117,71.243547,44.777747,86.311321,143.828292,281.317167,353.187904,490.009524,429.193266,282.327066,2.515447,-39.465535,32.163371,94.373473,189.09822,209.402937,206.114231,158.014313,125.170385,38.55074,-0.576507,-24.190992,-19.660524,13.50405,6.43578,-52.961671,-188.462721,-220.021252,-222.847345,-198.843882,-109.135305,-64.514129,-20.310925,-31.209715,-71.48066,-219.651766,-270.486475,-276.697753,-248.920763,-79.049218,69.183281,37.876652,-99.306057,-124.166611,-85.936378,-70.391996,-34.705597,18.477805,94.135918,-34.16266,-124.945804,-153.404163,-93.214468,19.959493,41.454931,29.699091,3.477988,4.012922,-29.137753,-72.107411,-90.85042,-45.691274,57.463911,85.11188,65.728338,-55.526416,-136.533756,-225.381367,-200.012717,-63.767072,15.538878,145.896653,168.920932,127.022562,-19.73392,-90.101797,-102.832582,-29.838186,124.760381,143.303625,24.865067,-135.926271,-148.41824,-115.749504,-142.240566,-253.757149,-274.235484,-175.41328,-84.021396,-102.845661,-161.21865,-169.437192,-150.595311,-114.788839,-20.503128,1.36351,-4.589829,29.486856,49.392728,32.154903,13.491874,1.202885,-14.01358,-34.262674,66.6364,108.736995,1.070782,-131.620175,-288.563446,-260.254959,-97.670633,-3.978908,99.498857,4.338021,-54.563242,-85.743901,-68.03347,-22.807029,-11.704663,18.172552,58.109426,48.21303,29.629346,45.668406,62.918138,44.058381,-2.69598,8.363141,85.407949,28.395739,-66.608663,-201.80206,-186.451759,-79.383399,-47.966877,1.573016,116.025061,143.158233,53.771083,-12.886425,-58.921943,-46.845691,-4.391147,25.241574,36.221476,-52.59381,-82.838193,-121.011805,-159.645214,-247.341715,-246.389618,-145.527292,-117.524837,-160.415631,-274.469072,-315.823239,-316.870287,-290.316002,-276.377848,-257.080548,-99.093294,-28.63982,-91.678802,-260.346512,-278.566689,-161.609607,-74.207481,118.791389,263.520925,268.162573,146.373874,67.370646,31.705859,64.013413,60.171667,41.10563,47.766093,0.623452,-25.067035,9.364312,50.779006,139.757557,185.707882,277.029441,342.001113,322.531413,156.935482,65.594999,-8.814771,-2.767531,17.962074,21.645324,-20.864949,-177.749628,-287.583539,-422.188567,-367.58612,-66.409121,76.36935,230.878737,221.762527,173.481801,86.48853,71.292143,47.665391,15.058325,-30.844769,-5.533323,62.176493,47.03018,36.585569,-40.234042,-114.584643,-178.062542,-125.954424,40.182157,74.716377,27.37657,-112.646371,-171.609265,-190.532093,-135.163818,57.82594,147.049844,193.04011,90.92641,48.832779,14.591451,-1.615521,-4.559302,37.542439,173.502064,205.911341,163.372301,55.65584,14.129096,-7.029985,28.529066,151.252316,197.358939,167.7167,-7.430415,-89.787854,-125.65863,-84.768614,-17.145385,-12.398836,33.055548,85.331967,56.224944,-43.374344,-73.004423,-131.930732,-178.523651,-229.039155,-213.348482,-194.829885,-241.477675,-248.147549,-206.77939,-172.513949,-81.247183,-19.027885,62.266099,-17.617118,-76.20835,-130.214844,-139.254399,-151.69203,-145.432859,-113.764837,-83.258294,-18.687821,-45.249859,-74.342845,-99.248389,-104.115001,-129.836133,-134.487575,-83.29758,-51.004668,-93.334849,-231.176328,-264.205362,-190.701265,-104.378434,48.09501,80.738246,94.12222,91.494305,83.411396,32.980466,-17.725209,-91.552297,-74.946397,22.622779,72.204192,72.706925,94.06363,104.721368,77.507023,62.371,92.360987,128.965298:115.817975,58.810099,1.348851,-159.613946,-214.607189,-169.968851,-85.097854,70.98629,92.67961,74.399849,10.42966,-38.52564,-113.29242,-124.300783,-89.116163,-42.290733,-3.606182,-111.680171,-144.796277,-85.875707,-35.273132,33.296001,54.114507,46.586389,-45.380001,-85.145732,-116.490113,-120.021727,-57.794042,19.3166,155.232524,177.823837,140.053053,33.111708,-13.749885,-42.792907,-30.867273,28.285817,76.347604,130.346844,24.90466,-37.625613,-73.074481,-66.036338,-39.041084,-1.827045,149.798391,216.78323,182.786384,37.660964,-5.523941,8.18032,57.623201,148.141576,173.348008,215.042815,169.771428,92.329421,-75.935184,-111.576051,-82.097968,-51.919118,30.952054,97.344528,198.489419,120.175293,46.539678,-36.754055,-39.072908,-7.287838,24.452869,120.129611,137.898389,99.291142,11.27821,-22.825672,-58.987556,-34.969668,141.592499,248.916197,327.099867,248.962947,207.182607,169.999152,184.98734,241.267637,248.638812,225.912799,234.815341,249.441814,200.877293,131.957715,60.091734,91.687827,175.332046,176.715697,133.449593,115.479822,104.170062,83.94117,113.801384,273.34331,344.103856,382.79831,359.569449,311.360033,134.839426,63.230831,72.053452,148.366079,349.79269,426.443116,417.724989,204.954861,101.090903,57.363902,102.985992,165.492517,170.997777,175.986652,88.232499,27.047936,-38.636694,-60.61676,-88.845697,-68.377343,27.533259,68.814135,71.54833,16.275073,-12.452766,-95.900184,-124.534919,-120.770542,-114.719836,-70.329717,4.597558,-1.137362,-76.578095,-95.17267,-48.770527,-8.726794,63.245372,102.851454,141.085804,46.386538,-29.158703,-92.715609,-49.700619,98.889136,155.361493,184.092444,153.109511,154.59006,157.677573,133.250825,106.829104,142.776134,260.098228,287.303338,211.476824,42.257285,-39.314473,-101.68789,-43.985133,161.303984,233.841725,269.705642,196.63787,140.350588,71.207158,66.643454,87.147778,119.068007,211.594996,236.538671,184.927453,101.595994,82.566462,40.052698,14.033677,-20.760414,-14.096513,82.330712,120.505585,84.842846,15.305067,-3.83665,2.433649,37.435498,102.209295,108.534094,80.956905,58.077982,65.973168,79.294267,84.083857,114.233258,118.283028,90.696122,59.385898,44.365793,-28.9698,-96.295013,-162.938068,-129.689809,-33.659091,-10.00038,-36.70815,-66.855409,-56.84826,-112.335536,-166.862645,-123.861844,-37.21287,82.936414,74.642528,33.144615,-82.157927,-127.179102,-102.935171,-51.712493,21.185271,59.907313,157.173829,87.251771,-19.237168,-185.195479,-196.30746,-130.887358,-74.12227,88.020558,131.295291,57.598703,-108.810249,-120.133236,-17.264405,38.57558,127.251195,166.153925,122.700676,-53.603692,-116.854661,-188.36452,-200.33796,-180.364141,-155.706454,-92.749428,-118.116104,-175.051535,-281.713671,-305.473316,-286.216938,-253.619774,-208.037542,-195.682358,-136.456763,-138.051467,-201.394368,-308.961555,-278.144348,-101.4344,-31.305193,62.949141,149.197949,161.68217,90.957277,27.651993,-41.78715,-36.295291,21.957412,72.669763,119.979733,17.708064,-48.533539,-131.720629,-127.846707,-29.112176,29.454348,103.316053,120.786431,104.11702,46.21576,12.270959,-49.45769,-54.393309,21.055786,76.85647,102.97318,-57.387504,-169.391979,-285.030966,-239.554161,-20.788375,66.893826,135.455706,158.688829,151.557385,55.481949,-5.774066,-19.194506,29.690293,112.44046,123.453991,95.522151,7.620938,-45.963267,-140.903318,-161.203726,-102.582225,-34.518497,81.091591,45.619388,-31.613093,-214.074987,-261.310433,-173.388933,-74.656783,49.066412,59.764845,86.553463,140.405566,138.916112,53.794055,1.178301,-42.597672,-23.597564,97.727924,161.167744,120.694122,-7.074842,-44.382413,18.013687,91.169253,161.922842,148.51531,85.291929,50.298786,47.66582,4.589454,-26.359945,-44.492114,-28.964963,46.827846,69.413232,13.072485,-146.735332,-202.707516,-217.40503,-170.851877,-61.46001,-45.989967,-103.094938,-175.386573,-196.454687,-227.242147,-217.768488,-115.988894,-55.035212,-16.322707,-123.513474,-196.575486,-297.42041,-295.486305,-177.586885,-113.069747,-82.164378,-94.573796,-113.154155,-171.784107,-214.852031,-255.79391,-234.576461,-139.298297,-100.56432,-92.28445,-112.326845,-117.018775,-153.624769,-186.943872,-199.449343,-162.478919,-65.280981,-14.66718,63.251375,-42.770053,-142.109572,-231.526899,-204.455137,-107.547468,-72.455221,-50.757536,-32.730566,-8.39916,25.963144,12.787614,-39.361476,-34.939104,77.636145,137.428121:123.578884,73.843068,0.875957,-158.969195,-208.090528,-209.449032,-164.479714,-9.913359,143.126095,163.260874,87.92642,50.470735,45.632897,50.289414,44.262813,52.890472,58.605738,12.496389,5.604834,21.128299,23.790173,44.507103,71.739849,93.211803,35.410143,6.168151,-9.037715,7.540258,99.396973,171.723521,308.109815,334.664477,265.813451,143.231844,86.797644,-13.212172,-26.603928,66.739199,137.616389,191.84295,133.25122,109.713677,73.590155,49.356077,4.8421,-7.165468,33.385817,94.499448,185.062258,114.802797,53.664297,-32.111811,-33.096142,76.778992,162.317353,264.998926,179.67275,95.218345,-38.210611,-76.139787,-102.740413,-78.620162,50.505602,136.4606,214.879363,75.969796,-2.954405,-84.963411,-112.753782,-143.10943,-120.556463,7.5478,95.953294,61.295086,-44.391617,-39.06873,42.300663,68.86288,148.156263,215.888864,243.013227,130.816576,118.337334,184.107481,223.548829,276.696927,269.549013,186.878422,116.433102,102.392773,98.042266,94.0782,102.221534,115.267656,86.783299,58.603063,70.939139,82.954805,70.218949,99.408047,147.515567,286.089438,359.473474,468.134994,466.965879,409.315255,220.962949,123.419642,82.39659,167.014895,355.9267,383.117805,305.867434,186.351589,158.235066,165.226512,168.924557,127.103218,94.349903,58.123918,62.888216,68.662218,60.821829,45.153938,-2.364468,-30.063365,-27.759817,20.682838,130.401349,119.262617,73.499693,-49.763743,-98.985307,-84.748669,-33.787138,69.306522,90.895641,60.030975,-0.237229,-0.484705,25.189313,29.100426,42.34028,73.580851,141.230791,88.128084,34.219258,-39.03857,-55.421205,-51.307288,-13.660751,138.972402,227.231913,213.004365,155.807127,129.394784,103.918615,131.094392,252.899283,307.920314,311.157899,174.470549,99.805289,29.616981,46.783396,158.132369,218.508799,301.763807,325.477904,305.302213,218.865593,172.821737,151.919616,189.141506,289.715138,317.020628,274.197621,138.972958,85.824908,16.574508,-17.739635,-31.540811,-1.287661,92.05491,142.271132,136.379894,87.694127,49.837551,12.228239,29.686121,61.675458,60.135143,62.202963,86.626121,108.568127,141.122529,126.023287,72.263197,77.365117,171.582344,242.582468,223.953634,93.880767,10.936218,-78.191502,-70.075355,-19.838996,23.232675,127.387664,132.484048,95.78424,-8.030971,-34.076782,33.993613,76.17799,46.587207,-17.124606,-24.662265,-26.357942,-27.754057,-35.95244,-42.322686,-33.119324,0.428238,81.700603,-25.675409,-138.078606,-267.196136,-256.323431,-203.73761,-192.397898,-121.416865,-13.637351,-3.077722,-36.438455,-31.55547,27.320045,43.038185,14.30677,-3.958887,-27.739323,-112.444043,-165.631584,-252.186799,-274.097566,-250.477484,-224.889523,-173.512386,-125.378718,-129.839519,-213.673049,-251.597889,-222.616835,-183.981237,-171.876682,-182.038477,-141.360024,-116.938019,-138.813799,-169.314969,-158.640378,-130.693725,-107.62283,43.244467,181.675544,192.027792,143.88101,89.212616,-7.785253,-12.744934,16.23111,36.022071,67.543588,-25.88193,-99.262661,-165.753656,-144.601903,-46.484363,-6.157358,43.536388,80.58502,73.390022,11.359116,-25.333285,-82.64863,-85.835676,-42.172099,-23.259114,-48.427157,-152.854674,-215.528238,-286.5935,-253.494,-67.795249,10.657534,77.425859,129.181039,132.37308,67.657824,32.416349,-9.064716,-29.705535,-56.283501,-36.648427,20.645853,-1.745141,-25.57849,-74.299954,-105.029261,-159.423194,-163.348655,-61.631675,66.50411,43.519588,-132.55022,-215.242395,-247.013438,-187.693691,-31.274229,26.125715,64.580324,70.024648,78.879957,32.151587,-5.205246,17.855353,52.208824,44.259047,12.189228,24.573568,22.137492,-28.520839,-92.670557,-59.259594,3.323949,5.225204,30.14584,14.74886,-41.903214,-160.152963,-182.537241,-159.478842,-136.614082,-64.010726,-28.823762,-67.300423,-164.096476,-181.324973,-164.592838,-145.64653,-108.466297,-98.42066,-105.041098,-115.648874,-127.489951,-169.01336,-158.208889,-38.727126,28.518707,75.328149,-29.272033,-92.429038,-133.880879,-128.553166,-123.930687,-122.99476,-110.742421,-94.961132,-47.975633,11.434121,28.018213,-55.492,-143.985539,-250.927556,-226.778055,-88.805763,-72.828077,-141.410629,-297.254723,-344.227214,-322.708427,-248.693372,-86.573774,-45.945639,-50.618714,-109.652869,-128.449482,-164.552445,-196.429729,-220.103286,-176.353173,-9.136546,28.733057,-33.411657,-139.459943,-146.028518,-133.022915,-120.453067,-66.351419,-50.088873:155.630701,46.328216,-44.824811,-187.062861,-189.037204,-72.624305,5.475664,125.284837,134.727686,101.849643,19.349325,-8.132952,2.906919,21.31193,51.211795,81.163295,118.856969,33.977328,-17.823094,-25.835624,14.830119,71.1957,59.930303,0.535776,-14.713247,-7.404798,-46.596605,-90.900145,-75.115106,7.011148,211.573422,280.841184,230.519592,30.693293,-27.309033,-26.718267,-6.907135,5.61231,14.141793,88.799845,129.735457,99.282885,1.174245,-36.20912,-57.121743,-32.166274,81.069311,142.683181,185.724836,138.158801,99.004299,4.497716,-8.710917,83.319404,157.588573,250.594594,169.007656,97.365141,-22.546303,-64.669102,-48.592847,11.474564,148.479894,195.967047,178.058068,65.800251,27.558188,-45.445978,-82.941665,-87.28289,-60.641114,20.714945,79.103325,62.417568,13.241171,20.525944,84.611506,126.655416,260.078326,341.016616,387.407848,277.261088,220.774199,164.490958,163.779117,200.588763,231.9568,273.098942,212.645669,155.879516,37.466556,-7.608231,5.416214,51.741908,100.860438,96.928725,75.648485,2.729876,-60.024313,-131.351259,-90.546289,137.490298,265.97177,392.589207,282.853433,198.707917,101.958737,76.607694,89.602595,160.454333,330.682636,369.331082,336.38552,202.600375,122.027839,28.142932,44.742943,87.799036,69.366912,70.183857,88.742667,36.726879,-88.603429,-97.94984,-17.475231,23.288284,43.649501,46.144156,88.228816,114.494079,73.827244,-102.258567,-155.943146,-61.047909,23.045201,79.180812,75.94938,80.385595,18.130468,-48.205752,-128.219883,-107.813647,22.864431,87.978071,101.110876,33.858927,23.264197,21.709684,26.783375,68.68144,107.475152,240.779949,347.035997,349.901833,269.207748,202.867819,103.903229,113.393911,296.136695,407.464116,393.799938,156.380144,100.809608,124.660059,151.879205,212.382937,238.416186,292.703483,298.236045,247.525434,144.57993,148.844451,216.160903,226.810113,260.037911,313.144098,342.029857,204.23845,146.799267,85.373579,58.526573,38.453436,65.606089,151.555163,172.721918,171.0538,174.66073,146.854565,48.662901,32.665176,90.806147,125.04236,130.718007,76.269235,45.531673,9.320323,18.081963,78.560535,116.938061,194.557544,194.190715,158.75066,53.140239,-12.775101,-90.626625,-69.663997,39.69218,82.164067,67.172604,-32.734946,-71.614647,-100.840021,-87.117078,-0.801989,44.875311,73.915768,36.91326,2.441881,-108.978761,-158.838875,-173.098059,-159.508583,-98.091066,-25.210486,98.913354,-15.999098,-131.90053,-283.758769,-283.219738,-205.975135,-171.597793,-93.945091,-33.202253,-35.917476,-55.208208,-53.373431,-1.263283,47.266126,124.423887,134.585934,74.192057,-58.917012,-120.479353,-214.485981,-223.734113,-150.231059,-102.644035,-38.754744,-48.824087,-93.489089,-199.664559,-238.525701,-248.703251,-208.448848,-92.862174,-53.710922,-43.3469,-104.313771,-144.014955,-169.770648,-137.817504,-50.158904,-10.561104,121.726386,210.907907,180.908617,69.435341,42.831395,38.400472,32.440393,40.803124,77.629668,132.757839,54.989303,-5.742017,-107.651947,-135.994524,-103.669847,-44.677148,52.094801,31.75019,4.466149,-33.364092,-41.718265,-34.938757,-11.860985,67.899287,98.821479,73.004771,-66.615877,-145.025026,-220.229554,-169.028037,76.096606,183.675286,244.553953,170.063093,128.272038,41.962302,-14.259114,-75.768319,-65.242797,-1.181037,52.921381,99.397507,-42.487509,-121.724688,-203.740381,-206.135591,-139.439129,-86.740699,-24.611078,-79.644447,-135.729889,-251.943767,-297.504996,-298.170359,-240.880322,-70.226068,6.533793,80.622557,67.563765,40.812127,-48.233695,-82.539689,-68.152547,-22.647797,91.90629,98.919104,66.255969,-16.789264,-74.448324,-115.725526,-62.893309,74.253923,116.278999,139.525631,84.803193,29.988308,-109.492587,-158.454744,-161.622408,-132.441324,-46.011313,5.366978,-40.649991,-230.546316,-273.069071,-135.065135,-25.898637,78.919814,63.919452,-9.980729,-43.756015,-58.703887,-125.704349,-157.892841,-113.747926,-34.601903,75.397866,-28.104633,-114.176885,-234.235152,-256.435777,-205.75602,-155.875338,-106.544102,-109.340612,-142.707298,-165.813501,-168.57635,-183.221449,-176.302889,-118.228559,-80.412032,6.000772,43.410001,21.782541,-110.819847,-201.897233,-253.447675,-174.311757,38.080357,84.612204,14.765176,-64.492623,-74.031294,-141.666039,-181.720059,-151.054241,-88.154117,28.68936,44.220165,2.9152,-106.930257,-127.910411,-80.810664,-41.94437,9.271188,12.854861:185.485086,110.204664,66.176878,-22.785971,-56.712481,-82.542793,-74.451269,14.483966,132.916203,131.182599,45.648532,31.545139,115.381804,179.476434,281.05636,315.872533,291.969436,89.219883,-7.606903,-45.113479,8.293216,135.618058,151.625765,86.64785,32.043868,36.590836,92.993601,130.790508,277.548221,385.186038,513.532794,506.636798,399.727979,233.202233,166.087225,110.312941,118.403252,192.739072,229.544396,253.288458,316.727496,360.629882,326.73524,227.488113,61.067125,80.184802,202.671512,230.321063,249.095551,204.591857,138.304366,12.21273,-15.403874,16.324707,56.719977,109.234695,72.459168,22.634396,-103.106591,-169.45038,-213.135271,-169.480632,-44.547419,8.208078,82.953655,60.841188,5.77597,-127.216679,-172.463672,-149.49643,-86.52529,45.322274,62.608142,37.279308,-9.918355,-19.029471,28.743151,69.707075,123.134447,137.704572,108.045191,-39.297386,-109.611999,-137.970442,-86.910648,63.058852,98.63084,50.969667,-38.988774,-55.127261,29.053495,81.213561,59.023566,6.928607,-53.546417,-41.784865,15.465649,14.554065,1.203612,-6.402698,39.779588,309.735263,451.31438,509.11062,319.311554,204.889607,59.288044,51.283707,134.502116,179.991736,174.559549,131.505735,93.49198,167.517917,191.926012,134.211106,69.853929,-40.636843,-62.071356,-40.389855,-47.500797,-65.123321,-52.176401,-25.573901,3.407517,-9.707682,-40.085841,-9.21027,134.360463,185.435409,151.543608,52.767944,33.262578,51.082083,57.249014,67.86682,85.585107,86.659686,99.855696,102.126286,74.257076,79.84387,138.368647,170.132408,237.257984,214.521206,150.57678,1.418822,-33.933568,-11.024635,11.990357,75.240743,122.171071,82.889746,-66.110549,-104.997305,-94.387083,-78.908848,-13.320208,54.870571,156.869169,116.348649,75.505797,-27.946457,-68.279257,-12.841435,71.805346,246.079913,327.844935,317.01208,266.933496,259.668691,252.943635,240.881259,221.828163,221.615626,200.976914,117.459584,74.698787,-47.368777,-126.681135,-176.574931,-132.519349,-20.616466,10.158416,-6.096352,-37.635171,-19.463492,100.034661,147.925939,110.71545,59.516705,-14.801861,-35.44848,16.207489,162.52634,162.918301,72.289055,74.309425,166.177686,210.475097,221.991866,249.541269,212.736192,20.263066,-44.657043,6.242093,82.345179,211.465803,176.436441,103.565746,-36.731616,-65.395593,-9.738656,40.167478,70.771201,-30.735008,-90.540012,-90.868241,-45.018748,-16.288832,-36.09142,-79.281566,-90.075128,-62.642012,-70.04209,-134.107397,-325.97333,-380.69191,-333.734405,-278.826812,-166.132548,-93.248044,-112.585326,-165.293253,-149.513175,-132.482868,-165.905092,-223.961561,-196.009287,-75.550154,-101.48566,-173.90819,-320.119987,-343.418968,-283.592469,-254.044859,-216.619631,-175.623494,-193.507621,-300.281497,-342.976291,-309.263262,-229.792168,-65.875982,-31.946562,-57.880071,-144.567955,-178.250405,-176.734279,-154.262748,-95.753486,-69.078054,-21.28935,68.169719,109.1479,136.002561,137.458172,152.253819,144.760155,55.030135,7.156483,-25.383918,-87.328389,-134.427356,-139.363994,-100.730967,-5.018313,36.94287,61.245712,81.821577,102.268216,28.091996,-78.870203,-238.983702,-239.206077,-180.9652,-168.203889,-207.72054,-299.207791,-318.445995,-286.34816,-234.514729,-47.794343,48.110652,124.637722,98.729171,92.105619,85.302584,71.517898,39.35447,23.275521,-35.149054,-53.306695,-15.873731,56.218708,57.24088,-38.943371,-88.369017,-125.020699,-126.021483,-65.452548,29.200572,24.10101,-88.849209,-157.28,-203.807806,-154.278975,20.311896,85.648264,90.356766,33.914319,47.228203,92.78916,77.291818,19.511124,7.424209,13.41917,-7.57674,-44.238307,-137.68763,-185.739279,-227.120395,-180.688772,2.067362,53.154624,-36.115539,-159.637221,-154.271066,-100.93491,-103.736113,-164.096002,-189.611487,-185.647711,-174.960058,-178.588699,-196.436586,-217.186861,-232.603369,-211.32495,-153.874103,-125.013502,-78.53019,-122.297188,-149.173571,-123.285406,-73.293992,62.057685,115.49438,122.924592,-15.820115,-87.521014,-113.645314,-83.495338,20.335442,76.969198,107.468669,87.297455,81.529279,162.401012,206.860391,225.370889,182.643416,20.487861,-52.097335,-102.563019,-155.767055,-232.024163,-349.82844,-334.212422,-225.373309,-183.417602,-136.971613,-107.992743,-38.043426,-43.802539,-64.457539,-106.087007,-141.780515,-194.240052,-157.959618,27.464692,70.358562,23.624058,40.96408,105.433691,155.468743,140.263017,133.768498,128.751363:175.008894,23.526734,-16.775654,-37.25707,-45.610522,-55.507229,-28.765568,93.749977,144.473288,112.707502,46.564692,30.612621,55.872522,112.622154,241.108478,272.515968,220.26769,41.51922,-28.558841,-13.251079,53.653845,146.723602,135.322455,64.38214,38.75475,39.998165,11.406039,-12.441151,53.514537,159.315581,370.940971,428.727313,409.912568,230.699299,144.59152,90.067259,124.435121,251.958292,286.144898,253.431419,195.403604,170.184794,121.945886,93.252722,49.594457,63.145589,151.042942,192.15105,204.822614,140.460923,97.767838,-3.59236,-38.362395,-17.527573,28.764265,129.002006,109.008647,48.748444,-39.361113,-49.07451,-54.583548,-48.316146,34.810271,98.136072,125.180825,59.989749,45.397235,-31.632221,-86.004744,-63.35186,5.403013,109.26845,112.009435,78.96279,-1.23965,-15.444151,40.488178,83.75549,141.750905,170.489211,211.8325,146.600389,108.332658,102.601614,121.411559,134.545563,131.259225,169.357053,159.41432,99.177858,15.583208,36.456904,104.829597,89.887494,4.681738,-3.736566,6.50927,-50.184221,-76.133887,-115.038094,-99.285382,132.24982,278.652905,346.083978,191.703204,133.146404,92.065963,76.225969,85.96313,133.885298,225.786863,231.331834,190.942118,161.772702,155.30096,131.563167,107.058393,26.275089,-19.692706,-45.228417,-5.216093,-5.404736,-38.374392,-52.838891,-47.968204,-23.409482,38.287429,67.976118,96.927568,42.447126,7.88853,-28.901848,-22.68782,44.291075,78.399253,89.833302,40.199081,4.276252,-48.626504,-68.467299,-95.762308,-75.726773,60.198479,145.48886,228.937734,188.941221,162.781274,83.237756,35.357598,23.753885,67.988829,176.897728,166.046055,105.068201,2.808755,-3.692687,39.041676,86.852493,262.386746,348.966975,352.342536,164.631095,82.034053,19.472961,24.006204,73.017702,131.654643,313.973678,412.017925,379.543399,234.582279,173.493374,122.453921,130.245438,208.093411,258.106667,251.681415,96.370968,21.464615,-85.94318,-126.780078,-111.6313,-46.235766,78.714489,105.965569,89.512707,26.039316,-9.271029,-31.118149,-9.463399,48.985654,66.578659,61.351499,-8.806358,-39.111344,-47.308761,-50.291873,-53.592125,-19.096472,137.085212,224.342316,194.405665,43.836356,-37.516756,-108.171232,-87.593575,21.497409,87.771073,138.570774,22.040148,-57.03396,-156.017676,-135.403631,24.418293,77.225559,13.242338,-112.159946,-148.964172,-207.4696,-230.489004,-205.066518,-159.792206,-90.802818,-68.969877,-17.981449,-68.926148,-150.426283,-300.751089,-326.292658,-277.365566,-223.934145,-102.681668,-58.520857,-84.496937,-126.262062,-117.717469,-78.686747,-58.337053,-18.31749,-3.278448,-51.210284,-183.959755,-234.137762,-284.827076,-279.257274,-211.852386,-179.874945,-126.367827,-67.453458,-79.172243,-173.029846,-204.510183,-177.46935,-128.231613,-4.982919,56.468419,77.012239,-95.981429,-171.508123,-191.443907,-153.009808,-73.118804,-55.795386,20.030741,169.106104,193.102534,75.260629,0.909894,31.662352,120.72264,213.294992,179.50858,50.50881,-59.570025,-102.531049,-168.128745,-181.035626,-138.168919,-92.682163,3.561558,59.490138,49.513584,-60.40416,-133.648346,-200.960177,-171.494631,-37.231353,27.521475,47.195774,-116.758022,-188.354183,-171.694928,-100.127212,35.491702,67.298031,139.922041,174.910171,121.603646,-38.669945,-91.378184,-107.937959,-81.253038,-4.02167,27.362745,33.618444,-33.840521,-67.55711,-125.459293,-154.935623,-180.342753,-160.348038,-76.46429,-77.326196,-142.831529,-312.118672,-360.145856,-333.100989,-277.63227,-123.644468,-36.092204,65.184298,7.64952,-48.429024,-147.791293,-173.131457,-157.177155,-126.798104,-68.863184,-117.747647,-176.918189,-278.529754,-301.646635,-231.862583,-140.815608,50.786661,97.549184,47.703493,-21.349005,-38.335697,-118.509399,-169.166577,-207.635812,-182.249981,-87.416563,-131.676036,-217.633644,-303.412711,-267.011802,-179.029683,-164.471131,-105.565871,-45.185077,20.350882,-96.619274,-176.220984,-221.376626,-159.377787,66.104815,148.262151,122.184242,-48.645234,-114.186102,-146.480656,-132.938336,-78.082479,-35.558454,31.300425,37.619985,21.685093,-8.851097,-17.435875,-13.663227,-25.696995,-72.752367,-64.169231,27.046387,-5.765504,-90.393851,-228.585864,-234.299703,-136.873355,-65.036292,35.38645,51.320575,60.798397,35.779793,-10.389282,-161.248272,-211.492136,-131.084185,-30.593218,129.099111,125.222823,76.567657,3.60136,-6.119599,-6.665579,4.793706,68.073987,87.013627:298.061668,368.234878,365.69105,265.501987,196.788184,121.068081,113.881779,124.497214,104.732387,68.491995,37.438411,62.879461,193.866951,297.855283,487.564953,528.953918,460.273067,229.574515,109.891645,35.954522,99.471568,240.060486,240.764939,138.122439,68.820295,73.858596,149.945893,196.673946,307.621345,378.917828,453.426883,430.299589,310.569946,178.985664,136.376293,116.050416,154.972633,322.191012,391.193554,443.115538,471.639969,454.833246,312.519961,210.967689,39.568476,6.592895,53.671152,100.022168,187.460468,191.775274,131.510505,-60.825125,-139.887082,-160.534575,-107.642159,-1.830485,-24.535098,-77.437987,-161.954175,-176.021753,-145.653612,-106.574368,-39.772454,-20.946498,14.165407,30.39687,24.43206,-15.121812,-39.817718,-23.671453,10.260527,31.691386,-0.399756,-9.644611,16.651728,34.524258,1.973451,-32.601425,-56.738274,-62.881486,-126.018219,-171.575319,-155.021891,-104.195928,-79.306479,-14.387792,-15.07155,-91.997094,-144.074935,-175.21071,-208.983391,-184.742751,-109.609577,-104.772104,-180.090223,-208.219877,-196.028752,-193.649328,-172.091305,-31.252814,64.808342,243.843712,289.459411,210.32746,27.748311,-11.015234,15.066608,18.377915,-2.402729,9.397419,50.295211,55.248914,90.342665,162.14412,164.214506,55.895802,-36.04814,-227.548188,-309.582396,-360.058306,-252.40854,-212.908377,-205.347819,-195.403314,-118.930267,-75.503033,-28.979802,-0.693622,118.674424,207.846351,190.776629,94.10345,65.462636,71.677149,97.674885,164.32989,192.194085,189.54631,196.4431,211.806387,208.201345,171.00252,73.385652,64.500868,168.694153,284.160827,278.048596,128.455074,52.557921,10.90049,9.047382,-31.246741,-62.838023,-68.34618,-116.330151,-161.875164,-217.442315,-216.259273,-187.601246,-161.708045,-112.739921,-170.860194,-231.697485,-305.014359,-306.257551,-240.367409,-157.477348,64.707814,192.169004,206.156442,185.058303,159.761558,108.485529,89.627567,31.428544,-12.699553,-66.458723,-26.919928,-10.856546,-101.614309,-188.867955,-264.002714,-240.921047,-216.636642,-194.392607,-137.022175,-12.383881,-5.508729,-85.052003,-114.829529,-118.02515,-109.362493,-113.780033,-121.042732,-77.608402,-1.471335,-34.269861,-102.002012,-74.313851,10.489565,61.580216,94.218949,148.372168,118.952825,-37.315304,-81.52486,-29.958786,30.324027,144.080973,123.274884,51.490731,-60.373919,-72.24155,-91.720558,-128.026848,-212.476766,-198.516004,-152.846912,-47.651592,-18.577555,-50.898649,-94.049983,-171.671867,-187.930023,-142.485282,-148.343966,-212.9625,-350.820541,-385.729914,-389.281214,-367.653957,-271.455238,-222.711053,-251.374853,-250.091237,-203.210115,-189.813231,-227.946299,-251.661279,-222.707481,-131.505216,-68.817247,-80.453524,-213.120186,-293.094598,-336.835295,-305.430352,-249.304299,-226.309532,-216.650868,-220.630362,-253.043064,-282.552134,-221.346896,-38.382324,10.666257,-20.311223,-152.046511,-199.98397,-186.925163,-143.496753,-38.05326,8.046767,53.895277,86.758735,121.464693,140.777019,109.233137,44.359667,11.826604,-69.624289,-83.185978,-10.664101,22.312338,-34.681034,-201.23952,-229.633598,-81.346769,30.921625,118.415018,94.328218,68.370366,-61.271781,-138.521408,-192.374327,-163.246208,-107.045325,-113.969202,-139.446742,-112.763442,-80.221647,0.800961,41.777558,115.924361,116.421074,66.579052,184.367258,271.261192,278.794789,237.538863,247.468892,264.972843,195.860124,150.96086,163.617049,224.036857,207.158554,69.48877,18.813163,62.242755,102.628218,105.06133,51.644226,22.075097,-45.351237,-79.790135,-101.707363,-58.558958,96.751612,135.410174,93.109902,90.051737,109.439536,57.195629,-2.189877,-48.859187,-44.171111,-69.080414,-103.792007,-94.196354,-36.432024,-22.076278,-16.029373,-6.10078,-3.136966,-17.198582,-57.555389,-79.512031,-70.184051,-54.843776,-64.62098,-86.462337,-93.884417,-76.586177,-4.357617,8.917007,-22.802832,-33.652578,-3.95836,21.60144,45.281318,55.348755,119.659449,147.433082,119.278986,70.521516,90.29798,215.63161,279.755152,332.951562,303.9423,256.149503,104.637686,35.912177,27.68597,80.919751,120.23561,76.063027,-9.235248,80.13042,201.007634,410.164586,404.57354,243.78983,180.295394,91.995128,-55.857282,-127.399961,-227.279544,-255.422444,-232.752228,-203.904068,-194.114881,-183.493861,-88.700566,-4.854851,10.352054,-23.341317,-60.998348,-95.83678,-82.868336,26.776036,169.664838,203.987959,258.369949,290.697293,326.269039,326.779349,285.754192,245.556424:360.359032,338.238642,260.021582,98.996498,61.119309,33.633672,23.117325,49.21814,129.436732,127.687396,57.686147,58.554759,171.832091,245.992342,347.315591,367.952484,320.152634,103.349401,-12.985202,-140.062305,-145.330003,-14.751213,90.291789,181.311381,92.988177,71.021595,140.691577,183.855412,282.839303,353.460581,396.060705,353.766191,258.990085,126.604858,48.020483,11.325576,73.984546,207.138364,222.011951,233.649484,290.655223,295.195622,210.554318,136.434818,27.959683,23.459128,52.374307,61.501146,119.476793,149.745253,109.971148,-19.451678,-64.556928,-61.10604,-31.489081,9.09108,-41.551357,-99.436858,-196.88937,-213.161532,-194.514212,-172.017113,-125.225752,-108.644175,-125.919469,-183.356563,-184.0836,-218.819669,-289.988585,-362.077179,-301.322111,-103.502845,-27.034019,-54.923881,-116.468977,-114.48811,-74.367066,-41.522215,42.825584,59.825489,-21.279944,-123.988363,-134.254929,-122.759713,-117.577387,-97.922053,-91.600287,-105.650091,-96.51085,-60.807073,4.583721,-3.572941,-74.447002,-103.005514,-106.825015,-82.406873,-39.140945,-83.832998,-112.821731,-102.807698,-53.592223,116.400759,195.285006,234.899359,163.201926,140.885844,138.838226,137.640135,108.092145,78.642948,6.225699,-2.668883,91.628251,187.269847,196.130336,132.726546,63.285559,-41.093968,-58.360641,-106.289885,-157.998333,-153.372843,-97.718574,-88.256415,-111.48999,-108.601295,-74.592445,-46.053372,38.032923,64.475733,38.54358,-51.903045,-86.257056,-60.39311,-14.954837,49.150256,102.391918,128.386445,131.873186,110.14934,37.182565,-0.290443,-12.855448,27.415882,113.496686,79.610356,27.799529,-80.886293,-91.195358,-12.538265,13.936234,-6.454837,-11.489983,-22.860139,-155.944571,-242.835102,-303.448685,-274.505186,-196.218022,-156.00086,-71.193068,-118.734792,-199.802592,-303.829538,-284.79724,-175.980065,-123.779904,-5.010835,130.73852,145.489092,33.820113,-33.028416,-90.47662,-99.315715,-84.467949,-46.527581,22.726211,6.095443,-19.254271,-109.327883,-167.922545,-242.950706,-249.60783,-179.764138,-40.726864,-2.353245,-31.872471,-83.127853,-155.947227,-146.237125,-77.778056,-48.499329,-40.138131,-44.187825,-3.336635,106.273133,104.207992,-23.138019,-78.872934,-44.770604,106.699766,154.939386,141.111191,85.645165,-56.264557,-82.823899,-11.944315,32.162884,86.433513,96.942506,69.797535,-9.084372,-26.232651,13.854515,41.004287,30.35699,-46.417763,-71.570479,-22.117626,32.641315,83.309333,67.941509,18.350456,19.018009,93.56818,54.702495,-58.458172,-307.959323,-368.383117,-374.68689,-360.48474,-281.748963,-176.885658,-172.095661,-231.1084,-261.281478,-287.817352,-284.455864,-250.499079,-209.492368,-90.804977,-33.363676,-58.824329,-191.41077,-272.647352,-412.894745,-437.752809,-325.352047,-149.055563,-131.464064,-246.828932,-314.433384,-318.888442,-263.649365,-182.995189,-174.201371,-149.339494,-164.38085,-189.342945,-167.491091,-114.505294,-14.175999,15.802397,79.565224,140.93532,146.613999,119.355096,106.365248,122.459708,136.469046,119.043796,105.255803,94.415909,16.940054,-16.860849,6.699465,24.420422,56.325003,121.122655,313.864941,320.7116,221.877953,-21.402036,-108.302487,-185.788716,-182.821308,-130.036209,-102.136897,-93.308417,-148.612368,-158.600448,-94.986024,-43.268687,54.735643,74.973783,65.522038,202.036138,309.759228,357.186757,282.542545,144.122372,142.232586,193.433622,190.449238,102.142671,40.992984,53.111156,27.894348,-19.069882,-30.255255,12.088521,62.43776,27.367937,9.831611,-11.972591,-35.881614,-73.653262,-32.089514,148.063808,206.31492,186.707743,157.568693,172.975677,153.662815,100.356723,8.440447,-9.393454,-12.531047,-1.034343,-11.027997,-64.324099,-84.397686,-46.700947,6.975687,38.519092,-23.80693,-187.250966,-226.953999,-196.693529,-120.566892,-96.618107,-100.364961,-136.68969,-174.208368,-125.855218,-117.882479,-131.76618,-142.072783,-194.72121,-242.959882,-292.219061,-251.50803,-86.109418,-45.922477,-97.371234,-166.434798,-139.784516,10.59264,98.226225,178.181372,106.79913,57.664186,-19.904425,-65.795696,-140.502922,-128.737695,-23.799143,11.818352,1.903657,100.368492,229.207972,343.298108,241.056253,-33.204135,-89.552155,-85.846199,-162.392748,-249.923182,-370.124127,-362.933631,-287.938304,-264.801568,-221.137677,-167.468333,-13.433518,61.092437,32.335681,-73.944566,-96.739311,-66.640629,-34.511871,55.093911,122.452468,143.86914,232.024343,277.296364,294.112879,285.639878,234.296766,173.765514:236.911774,234.445173,179.273469,75.842229,82.285515,167.389072,180.895232,117.957295,65.375776,60.178993,66.849998,79.575068,155.96872,206.467867,245.336762,239.153679,202.642067,85.151583,27.077146,28.1138,94.077453,245.732032,261.959686,128.203816,-25.286171,-25.173034,134.797347,228.106409,329.034478,357.759637,376.393264,368.320152,375.978241,298.296903,227.189694,183.001181,223.117095,316.761062,325.102375,293.148716,319.150904,339.454334,305.656298,245.99219,125.946014,103.775264,134.875543,166.917581,203.823566,142.579538,84.101187,-34.247705,-69.548131,-88.079764,-85.790883,-35.621938,-12.738226,-52.417774,-113.257309,-103.38715,-54.183105,-33.875512,-19.906946,-18.618226,36.330042,153.852352,177.640677,82.58424,10.923177,10.326791,79.471908,176.681506,143.318824,115.346488,103.660785,100.178304,71.793653,83.037688,143.841843,142.622641,73.341648,41.731484,36.246631,-24.209503,-37.493578,62.200351,116.302685,72.60245,-98.917332,-157.793674,-87.467404,23.153492,192.326804,200.052656,89.673611,21.709067,-30.700562,-30.007125,-37.765538,10.025214,84.796372,247.199644,269.269325,158.635319,44.608808,26.840624,-9.85284,-51.610504,-94.28978,-56.365702,56.21705,87.757104,129.118785,190.925484,207.601508,141.716166,63.577169,-87.624681,-133.473054,-160.853069,-132.23626,-125.66425,-105.011549,-76.655999,-23.870607,-12.404113,18.805849,64.156872,169.560092,167.033937,143.140522,103.397435,75.284903,21.48862,16.480321,60.193875,108.351311,99.324392,92.154973,110.900914,103.523525,79.260202,74.807074,116.775832,240.732631,239.821455,180.680293,50.081848,13.087477,-12.286636,-32.75464,-82.193665,-47.981584,-7.006323,41.375988,26.183196,-72.199039,-102.231201,-19.224725,49.460575,82.470403,20.719639,-20.073388,-103.706897,-109.048677,-47.535175,-6.39849,138.014228,271.478053,260.052607,185.939874,184.251915,182.526764,159.042194,146.397965,167.867413,147.949203,-47.404673,-143.919801,-219.281468,-205.270911,-122.053519,-92.904319,-106.770625,-106.048073,-79.671197,-54.86378,-79.517795,-134.305233,-131.300819,-95.212709,-92.535268,-132.680541,-152.574779,-119.008582,-54.419679,-65.058438,-70.330685,-36.708569,49.171679,98.105578,79.496301,-15.813293,-47.391391,-31.116178,12.307419,123.779987,152.204742,107.962193,38.012866,29.339179,15.998831,-20.057491,-116.853368,-158.17574,-242.943533,-277.794269,-253.247653,-168.788021,-148.228329,-162.298123,-166.605243,-170.267176,-181.724987,-201.167838,-230.667743,-243.449163,-255.295195,-277.954137,-326.386128,-311.911621,-203.898429,-149.932169,-179.831887,-220.37252,-191.697036,-110.944587,-98.616921,-169.614247,-216.624101,-180.433595,-93.354294,-135.63236,-304.531836,-335.555201,-274.704838,-249.152991,-254.813243,-230.237699,-212.108604,-223.253668,-244.413721,-227.87019,-174.730633,-84.75636,-77.515767,-71.765444,-100.63141,-143.253901,-181.721457,-151.258734,-34.663902,-6.116922,-39.304254,21.503455,92.070323,147.007224,120.076278,53.65614,35.055343,16.234821,19.979825,5.759577,-125.44086,-156.56314,-107.363169,-114.834407,-178.297816,-159.277556,-55.175152,8.99908,4.062291,-109.148092,-188.742644,-256.787666,-222.389495,-103.288609,-56.066291,-44.610539,-126.002362,-150.997747,-113.293788,-69.289925,8.473274,38.231731,85.807719,99.835654,91.955946,72.324013,61.629421,26.216215,6.097129,-15.791776,-4.982552,36.973727,61.682171,82.891355,103.237702,68.149212,-38.593752,-82.762082,-149.278244,-153.052894,-142.678691,-171.021758,-197.820275,-143.756281,-68.349969,24.576601,37.869335,69.236189,79.867182,65.90836,21.317042,7.20737,0.836171,-8.10804,5.457454,62.323115,34.725319,-111.468303,-165.084107,-161.944449,-118.821124,-33.127141,-15.222864,16.210239,44.622429,13.529718,-101.257758,-123.817555,-88.4862,-87.701287,-112.346404,-43.660181,-23.831014,-91.528677,-137.826795,-147.14306,-107.001268,-20.069113,6.471077,33.724275,-20.388984,-54.415709,-39.192593,-9.051324,53.820066,92.408195,150.537775,108.98969,69.387433,32.861741,25.710294,8.988256,20.139564,67.340468,68.429109,29.31237,75.546945,135.498574,169.187559,121.387167,24.417552,1.380828,-52.77672,-109.718228,-116.974649,-152.551119,-203.355527,-264.641272,-226.455193,-102.824659,-72.819635,-54.271699,-66.113858,-80.108081,-108.740626,-129.332341,-139.737388,-105.891881,40.720789,140.11612,134.320934,134.560865,163.975878,193.752354,177.805043,104.09668,57.313786:right
3.406217,-39.801818,-71.784328,-142.072902,-151.562514,-57.78117,18.290303,92.714318,63.578138,29.134566,-48.20063,-72.232648,-21.486647,77.195765,254.260968,238.499582,82.10611,-42.404154,-104.569913,-222.626288,-227.254832,-116.72183,-70.118435,-57.526732,-92.939679,-138.684619,-240.170397,-264.486895,-223.524196,-160.350977,-37.891358,-3.15765,37.41707,21.346823,-10.563207,-43.194661,-27.569522,42.604328,65.602288,58.213639,54.615535,26.986491,-98.654237,-115.772778,13.308707,77.650294,79.744495,61.314702,64.403503,0.180667,-63.480516,-126.228332,-113.447247,-55.591804,-20.521052,33.756453,94.23873,133.655476,132.799214,85.60931,28.099801,52.973642,108.103904,83.420812,-34.164377,-118.348396,-140.197042,-183.928264,-200.144257,-118.279385,-42.219827,8.635174,-49.76625,-76.187392,-66.347181,-20.553377,67.143864,73.80942,48.810732,32.368878,-41.973814,-167.870915,-198.879532,-161.196483,-121.31544,-55.85504,-46.4962,-43.461033,-17.315579,-28.166865,-32.745868,16.915752,139.610285,178.838654,209.839352,203.999158,158.27636,77.063181,44.420047,21.701927,19.846308,58.548626,88.703726,69.998905,1.753251,-7.538019,67.954,145.041605,301.050473,372.513698,457.38459,436.76968,320.019952,214.193475,168.265542,103.757882,113.768491,232.443548,275.064825,213.743937,103.375242,72.007515,90.707521,133.983014,220.853122,247.751527,214.492988,151.549939,44.511996,66.727298,117.83543,214.949669,233.817276,237.390775,236.621558,222.571719,190.170499,160.36651,116.005987,125.87034,189.485144,229.796459,263.997781,218.268265,45.055874,-31.30539,1.62291,109.27183,116.939899,28.024927,-12.299303,-25.027063,-37.720629,-84.790508,-171.626299,-154.987998,-64.471552,-20.887169,69.98939,96.869095,87.367249,66.327614,79.977893,100.828521,62.36949,-50.843304,-60.721804,-4.095064,-0.333166,-18.089819,-19.896356,1.615769,30.347939,25.180546,16.749899,38.632199,168.470861,294.822944,315.849722,303.025359,288.501535,257.240658,209.02386,15.512651,-79.395352,-52.468787,22.261458,52.382113,173.206345,272.344415,383.874382,349.85996,265.001366,294.665791,304.091745,271.699396,247.828017,210.305558,184.213532,106.459937,57.042612,34.82634,-4.940512,24.894082,235.659926,354.121871,398.876505,324.685096,220.667752,252.703132,265.558453,268.981788,255.363267,168.998595,95.116745,-82.195091,-203.627731,-231.649487,-186.150055,-99.269223,99.388217,149.890703,91.744756,24.443741,-12.36454,75.749563,108.175073,117.316832,107.573138,88.06065,57.804943,-39.453055,-31.165152,-0.628598,20.191383,18.98928,57.932046,99.527613,149.011404,142.813427,139.472239,157.174052,165.455534,204.067784,215.793997,197.962229,176.020393,79.534568,-76.005116,-128.939596,-103.731191,-49.365784,44.179439,82.56912,111.762478,69.590428,-90.190196,-210.70161,-244.807265,-270.893357,-251.653027,-154.116899,-101.30901,-64.448345,-135.927069,-167.0587,-136.746562,-84.498409,20.435091,66.30958,106.735114,73.504176,-84.286255,-242.036308,-249.140598,-142.019183,-117.689775,-151.636194,-160.822952,-163.595587,-167.647797,-164.532142,-149.982989,-146.251333,-130.080803,-87.1395,45.014373,74.552568,12.447075,-98.580557,-120.355177,-74.145174,-49.347712,-57.610392,-82.182383,-130.904543,-133.015967,-131.328664,-138.107872,-129.404143,-80.155777,-57.880774,-88.191521,-144.270943,-251.425477,-316.906874,-322.382808,-215.56154,-133.81795,-35.035127,-31.837608,-76.857192,-166.088011,-228.844606,-315.422263,-320.298493,-260.047251,-208.63573,-174.921654,-212.258446,-290.179977,-294.091867,-263.519199,-160.974167,-118.563431,-64.005881,-48.254761,-33.806852,-38.11407,-70.173619,-173.857125,-213.0342,-235.863699,-216.480622,-157.739453,-151.074103,-183.046738,-232.607,-259.355332,-234.454256,-171.187712,-22.957423,25.157474,9.875283,-87.301951,-106.987711,-67.730001,-47.412608,-68.933807,-78.711366,-34.187551,-4.362567,12.110896,-16.054924,-34.204805,-74.783162,-88.825378,-87.39808,-88.973498,-144.764512,-205.392155,-210.609732,-208.832078,-196.145484,-95.337859,-35.069712,7.607829,-11.094839,-105.900059,-207.91697,-212.992228,-144.247341,-123.666371,-107.159067,-73.693425,-3.165141,-37.207795,-96.975486,-173.505746,-139.945984,7.908424,54.334279,24.278404,-18.305917,-70.527897,-90.54106,-94.705569,-100.061305,-107.483908,-70.803619,-19.813597,48.554029,24.955283,-28.424605,-143.28598,-139.622967,-34.850168,-5.825992,-64.175097,-119.670226:6.180496,-63.005732,-79.499467,-119.251588,-134.494592,-89.303959,-43.579796,-24.761569,-111.067278,-146.809073,-114.090574,-54.88229,54.631884,91.168064,120.301475,104.660459,29.093452,-53.186121,-79.605042,-69.116407,-24.434666,91.61571,97.556099,-53.85781,-173.960171,-166.182382,-89.332873,-65.221474,-48.085725,-5.993592,125.366367,143.112677,57.311014,-26.99417,-32.961875,0.358264,25.324097,88.213974,110.381681,86.717991,23.821699,-1.667441,-59.670822,-81.314741,-58.470508,-26.800417,-0.163321,-0.223038,-11.913802,-73.063204,-79.714811,-31.321024,-27.813269,-40.967578,-15.437828,67.26002,52.170002,11.763052,-45.86026,-58.876357,-39.003216,10.003788,96.128888,89.185831,11.102,-77.724015,-123.055274,-200.842574,-205.072469,-101.586306,-26.082507,49.859746,-0.904528,-19.068625,61.897414,126.03797,183.004787,192.019387,185.387797,144.060848,13.119306,-70.21147,-73.955383,-36.516611,7.275582,176.142369,249.030695,236.465433,141.194989,104.089986,58.760002,68.192174,158.706199,226.21008,307.89513,280.426383,137.723485,81.090139,112.066103,168.727694,150.860599,82.633871,71.720487,106.970302,80.276429,14.541044,-57.944405,-13.504702,161.888015,240.01756,261.016633,186.826,3.822458,-69.372927,-75.499829,-46.077991,-11.057425,90.318284,124.319077,70.468599,-18.742623,-30.017172,-0.733478,40.568099,166.548232,209.221666,119.377449,21.841666,-62.609647,-3.222034,53.631234,191.661868,246.914549,318.102104,316.378233,200.175535,74.402517,46.539704,61.000946,95.425814,172.405866,200.561523,208.57268,184.040358,93.068547,-19.573167,-28.908015,92.311347,154.122635,137.013479,77.886325,5.671577,27.76102,8.306737,-101.470577,-119.400146,-12.364676,63.120369,109.532638,76.471422,27.272487,58.991973,74.796248,35.961604,-14.942822,-71.997492,-67.398734,-44.473426,-14.597556,-23.870043,-76.272172,-73.522083,-8.267311,4.941578,-92.308749,-166.404919,-175.543857,-6.677998,73.888733,155.465424,164.263383,158.848233,131.816346,-3.537203,-132.62729,-143.257229,-24.410538,67.124601,190.647888,217.286197,193.881111,139.838836,70.318345,91.564899,105.543507,158.016796,189.862805,224.615785,213.569045,108.197631,-42.357942,-102.399455,-104.513191,-27.562949,181.136497,261.021735,316.626351,296.174786,195.207602,83.060562,78.841931,186.017715,218.089027,111.200495,17.009531,-68.80574,-55.964987,-98.354824,-212.56265,-184.689901,63.035054,166.160578,96.31902,-14.883877,-93.013781,-21.625353,-4.51597,14.132293,29.611138,27.518604,-3.975547,-89.208967,-91.381362,-38.989372,92.369306,120.653708,116.956115,127.879819,115.331949,58.748508,-19.248234,45.144272,92.972776,157.418253,172.61132,203.860471,213.125702,121.713227,-35.722188,-54.692726,11.187632,51.567741,142.731978,214.408477,316.168925,277.778772,59.878938,-115.635835,-150.851689,-135.458948,-90.024537,24.271478,62.790881,62.820551,-14.909551,-28.269401,30.160883,55.787744,89.907711,138.535863,211.097111,176.760907,33.274285,-61.36666,-65.16619,4.361278,32.587797,31.203275,17.402482,-41.487729,-127.675014,-145.247968,-39.947795,45.847131,115.292207,106.076449,59.516749,23.79086,-3.598405,2.763262,-14.069535,-29.944228,-19.234987,15.553518,39.252064,52.822277,-54.645694,-126.070527,-164.781812,-126.888821,-41.026547,-27.817514,-89.215771,-137.546104,-195.426847,-222.53572,-217.161668,-155.585806,-108.999172,-9.160259,15.648736,-62.306841,-248.858048,-322.034647,-334.829249,-288.509683,-178.870449,-151.143439,-248.150429,-345.64965,-444.13418,-404.334415,-364.313323,-222.907599,-130.748866,-19.672683,-29.066923,-63.65018,-30.900056,-34.994066,-96.066313,-113.257193,-85.007519,-66.170887,-98.316003,-136.847557,-170.357772,-195.641395,-214.413122,-198.398806,-162.182437,-71.292039,-41.502649,-64.980373,-119.231144,-128.323558,-120.135829,-107.500135,-54.445039,-14.247311,60.869985,89.612175,105.169368,39.102493,-4.919037,-85.558587,-112.668326,-117.662042,-103.081712,-90.098958,-153.97702,-192.302869,-165.495823,-105.499112,-24.396869,-10.339348,42.03149,66.174407,38.276413,-52.706994,-77.95977,-78.73439,-69.92594,-18.127676,1.944385,-46.308667,-131.679337,-174.605066,-191.035695,-139.486883,-7.629334,29.885752,-0.635782,-60.314192,-152.068692,-143.666419,-120.615173,-42.641316,12.51025,103.628662,108.191673,77.797635,74.953578,24.622705,-147.192631,-180.725948,-106.505714,-54.249576,-44.881542,-89.999731:3.584418,-86.636823,-103.867428,-139.22311,-140.591127,-55.026992,-21.867642,-67.658179,-87.155502,-75.017461,-75.906673,-84.451488,-56.334739,-11.163761,36.804368,12.954386,-29.744206,0.026628,12.292926,0.418253,-12.296489,8.711818,33.39706,26.778844,-58.804293,-87.048889,-9.71777,51.693249,76.396837,78.288691,133.509658,139.327723,50.760975,-34.088135,-45.431005,-31.529842,-10.692608,5.184855,-25.398595,-101.979953,-139.339101,-152.667011,-169.840179,-175.816928,-118.434606,-38.374316,95.783597,98.639834,7.074915,-125.379028,-175.961094,-174.206228,-124.179,-28.997283,-18.491076,-61.253031,-88.606191,-77.845443,-62.409719,-75.671071,-91.150658,-43.984789,89.882387,91.981588,-22.57299,-127.717166,-147.26419,-138.906018,-119.368396,-26.859246,24.097323,34.464821,-56.95315,-84.5013,0.231611,95.628765,278.446012,328.366902,283.184619,208.073633,59.464197,-33.047401,-35.639388,67.502664,145.394305,264.360698,276.322172,226.502012,209.454503,211.873587,178.535383,157.370078,204.216588,280.024983,380.944427,342.568075,165.112877,95.664741,99.891749,59.910038,34.02723,102.768636,163.229652,161.310242,29.201236,-32.79863,-46.968551,4.848287,134.915788,178.393948,152.321325,76.234679,-113.251618,-198.851899,-177.114848,-69.99685,-37.04987,-12.148584,12.633801,49.445169,-46.182518,-121.880068,-153.563203,-100.806208,25.163358,68.623882,66.015285,18.22658,-65.296135,-13.600319,59.528962,200.610987,233.710275,250.646027,247.393452,221.549166,162.179104,133.309803,191.984924,272.715214,371.106678,363.023829,284.723475,234.564433,167.32883,192.344093,232.074114,249.34155,214.712459,193.033643,219.493126,214.433462,51.950918,-34.345619,-100.054048,-83.015824,20.63175,87.775307,139.352016,108.154639,52.843892,71.62256,84.297663,107.716316,111.245086,74.011961,34.158631,-19.227001,-34.094947,-75.57334,-157.323429,-149.58351,-113.144603,-130.24397,-204.252917,-212.546432,-135.842569,-22.99509,39.722321,138.806046,152.285234,118.688936,76.687618,-35.848931,-95.370385,-112.447526,-124.221466,-77.262688,104.376099,169.110195,143.165867,77.841876,-34.021636,-33.066167,15.167947,102.188038,114.243529,145.808171,154.912977,70.67678,-44.905441,-60.37257,-6.503591,50.191827,206.430889,274.597097,272.804425,217.958251,98.268245,-12.807356,-26.377962,48.66475,76.138119,20.164101,-39.789869,-121.76605,-122.907525,-133.962435,-154.31222,-121.825188,-14.923358,19.354742,36.663497,25.09934,-19.279443,0.4516,34.666324,42.784965,16.574635,23.98153,54.857396,35.972531,-81.846077,-106.232742,0.018529,89.067409,202.368016,209.937506,133.43579,71.005834,-19.530581,31.266545,104.391217,194.827226,184.363909,153.806508,142.616211,47.193419,-98.8573,-130.801698,-62.769378,5.22426,132.197615,173.24208,147.39375,95.066504,19.664039,-46.552741,-83.77071,-77.473192,-26.644328,92.379409,127.294856,106.440633,-16.865951,-62.328801,-5.018182,62.703194,113.076112,96.835413,66.470875,58.417352,29.843559,-40.494177,-36.048416,129.100422,200.757831,137.56364,55.119526,-36.959164,-75.671787,-91.112433,-31.860247,29.026916,90.120792,92.780752,94.56434,78.09691,18.45834,44.317273,82.541437,122.079715,128.91292,166.047281,172.632765,104.667947,7.856301,-24.472746,-26.089892,-10.874065,-1.275429,-1.410624,-34.704338,-86.34795,-227.646862,-306.34077,-287.18359,-178.696747,-118.93752,-20.755051,-11.668493,-118.726404,-269.292424,-316.650482,-336.588317,-304.284553,-202.772506,-181.787982,-225.181322,-257.269235,-326.002602,-381.82216,-357.316996,-185.304174,-87.454536,13.53726,15.640542,-27.51107,-113.660651,-158.05056,-193.729995,-185.628718,-140.118802,-113.238347,-68.760783,-46.474913,-42.517241,-119.652481,-142.595886,-125.758329,-100.825792,-3.312463,40.282759,-21.627033,-168.795848,-178.30013,-85.091545,-42.395617,29.803563,86.38462,144.781485,103.693594,-25.282622,-60.486788,-50.177076,-22.023611,-11.018464,-23.960995,-49.331606,-76.613146,-42.176866,-29.61518,-74.436197,-118.870148,-144.647641,-103.845794,-15.006375,-27.447918,-140.044783,-172.46357,-140.302747,-62.776107,-38.054828,-15.772437,-19.576385,-65.305163,-148.642444,-190.253328,-208.181898,-159.924235,0.434868,44.917404,-28.922998,-95.526332,-125.643308,-77.043216,-69.383989,-61.987382,-40.247111,50.676892,90.314206,80.783255,-10.042856,-65.210997,-148.987492,-161.152616,-137.790158,-110.726678,-42.327782,-34.911582:-66.945213,-155.916125,-152.331198,-99.795063,-75.128391,-21.981523,9.948819,24.808807,-80.856089,-162.941666,-240.390917,-192.356857,-8.768961,59.447962,72.40694,35.929008,-19.044034,-33.345986,-65.896889,-140.41192,-141.751453,-94.309173,-77.049502,-86.850477,-135.67944,-166.334952,-206.220861,-192.76296,-82.44515,-9.130748,85.640793,84.626301,18.854181,-25.794776,-44.762751,-94.05971,-95.229102,-32.858514,-9.063,-34.754576,-109.65559,-145.282318,-187.894415,-178.657101,-40.214306,58.209654,104.879098,50.048412,-25.764533,-83.117647,-145.742887,-213.417268,-187.068499,-100.71086,-59.268768,11.13562,-12.08427,-49.984091,-97.64759,-100.048583,-73.374808,-28.517738,85.009793,91.500854,-20.306641,-144.155697,-166.683933,-149.421253,-147.334714,-131.339277,-79.941399,27.56133,-4.722757,-31.983308,31.057246,95.776529,147.228297,133.871852,110.273202,108.782357,76.987198,-52.67822,-104.906166,-47.1817,35.245842,151.631409,160.638761,128.954824,115.045087,102.811853,55.601144,66.555187,174.358933,220.627533,240.748333,234.107813,198.833456,94.21422,34.012449,-6.8798,24.218811,128.121354,160.657186,137.943308,84.586002,63.193098,62.619089,100.981065,182.353988,206.162996,259.273624,267.370838,143.725502,-65.153238,-106.2209,-38.909694,13.419562,101.564761,128.252644,94.382307,-0.510982,-45.191085,-74.967354,-46.02481,54.223032,102.923365,105.87755,47.58354,-24.350921,71.83963,133.517906,215.119288,239.675307,276.223922,279.672901,213.32539,126.904385,119.685518,227.501806,318.943042,414.481287,395.440324,315.954723,291.975836,268.635513,240.247228,258.21699,357.226882,374.929721,299.294289,245.28199,160.293133,72.055114,-3.467977,-133.513718,-119.845836,35.401583,104.123888,133.541028,109.690743,84.757029,99.95199,89.73863,10.920737,-45.611594,-90.122115,-65.223233,-21.392549,-8.307876,9.725842,35.967986,24.672911,-55.021897,-97.503838,-86.51847,-33.449926,73.467033,114.047389,136.127142,204.919102,216.206428,185.441596,167.935528,124.984649,51.349787,9.92837,-26.893756,0.432036,137.947029,219.080816,287.476875,245.883939,102.781296,56.235973,98.192983,230.387359,257.607373,247.807918,232.489529,102.304624,-74.583914,-92.166714,29.921905,116.485695,263.470901,338.92463,444.153318,415.288538,230.716368,125.923739,140.244856,203.848399,206.620588,142.201723,87.058758,-54.233706,-189.769519,-231.50592,-199.09652,-115.709301,85.879981,142.870839,116.979796,70.033576,-8.579719,-81.117062,-91.558958,-23.6106,10.000099,26.553265,17.21646,-50.96714,-108.610181,-103.155049,-44.387401,-14.09816,47.262512,91.451816,121.728409,69.158779,-48.985161,-3.285158,46.366922,72.587447,56.701759,83.705202,110.726753,45.544722,-105.547647,-153.062531,-155.666544,-115.959895,-22.83422,10.316779,73.600446,80.357533,-48.026014,-206.517987,-214.558722,-123.607643,-75.302076,-46.487531,-67.594932,-97.852502,-59.195743,-41.682474,-4.831629,22.76393,74.679007,91.777587,52.851623,-5.588779,-109.186991,-184.473804,-194.966872,-75.528932,-0.422928,10.873417,-31.388599,-74.9012,-68.304202,-76.521324,-68.694458,-44.599176,-19.074424,-6.4284,37.74512,26.259625,-54.768088,-52.372424,-9.710948,36.046816,9.565645,-22.483041,10.032729,52.780893,-83.10526,-178.456644,-223.125345,-162.51618,-55.448717,-63.004776,-174.660213,-229.96085,-286.523269,-301.144818,-277.136003,-194.2179,-167.536632,-125.564135,-98.205012,-115.475948,-277.238943,-354.807913,-390.176105,-370.828971,-349.893244,-346.142506,-353.09501,-364.415412,-356.200019,-338.523546,-327.445718,-240.211127,-177.548059,-83.218572,-75.653567,-135.868914,-208.35095,-236.724255,-250.076367,-237.732239,-213.024459,-195.315017,-151.408499,-158.121327,-264.961112,-362.443604,-344.637624,-197.254174,-122.180223,0.55816,39.494595,-18.307283,-135.921087,-145.581163,-88.370204,-59.628281,-13.83373,25.132088,117.659287,145.39393,140.544699,46.138479,-10.775201,-90.719576,-108.197082,-87.783387,-73.041716,-105.87862,-189.180851,-216.959302,-219.227749,-204.819576,-139.592343,-84.002896,-26.319534,-61.560827,-178.629089,-270.008401,-300.925223,-261.979122,-195.476623,-71.240274,-38.390941,-56.458729,-136.994624,-154.990758,-117.954499,-84.540978,-20.558839,18.648121,55.650001,30.976969,-32.62972,-78.161577,-108.112406,-138.941407,-121.181886,-25.570268,37.457254,130.410271,87.483538,9.613715,-141.384456,-162.059261,-72.043063,-1.24928,36.068018,-9.964938:-71.289366,-137.799122,-131.223559,-71.543929,-39.715657,12.468837,20.113341,-32.14168,-118.403957,-146.768795,-149.08542,-112.190482,46.039602,129.557177,157.324155,97.182561,-21.308514,-40.358581,-17.458988,41.990446,52.395706,87.112688,126.82924,118.631942,-101.037023,-198.151724,-159.86757,-47.493014,145.144756,178.326435,160.499603,132.287076,54.131907,-68.781845,-138.459426,-191.446592,-146.456982,-32.053249,-30.236667,-123.811652,-242.451944,-285.460066,-283.811455,-242.356004,-79.886176,31.092428,108.329083,35.678109,-127.812964,-158.139973,-145.972903,-153.932013,-165.071612,-97.79539,-32.856908,11.806013,-102.741461,-160.098932,-172.718797,-147.052488,-64.183462,9.509972,145.341113,139.617797,-24.065682,-179.621699,-204.904435,-168.794114,-118.209791,6.178189,37.944414,-1.036424,-74.001259,-101.955423,-111.891374,-84.667849,20.382135,98.007269,190.17414,151.005661,-17.075174,-136.741236,-152.690886,-88.794265,-19.354257,134.840166,177.287037,132.039627,35.173525,28.828259,71.437342,87.200145,128.548392,173.210909,217.792092,176.025742,34.666863,-41.843906,-51.843135,-41.918764,-6.73375,148.930894,213.616326,165.271817,-13.748207,-74.213247,-59.01207,-5.401709,104.266885,158.316827,218.418632,184.947843,1.211382,-155.605031,-161.102856,-98.268865,-78.178439,-53.817852,-39.159844,-46.787592,-159.024593,-220.467904,-221.269653,-155.009667,8.999292,51.485151,-11.949215,-74.888153,-120.307881,-71.401152,-26.739463,90.6618,159.769797,244.074135,217.091459,96.966257,38.224786,39.473607,117.243436,199.179241,377.781899,422.765754,377.71812,330.650732,309.360999,323.174276,329.299832,363.898581,364.992228,328.839193,303.355952,214.261332,55.368376,-24.670749,-65.960791,-38.188586,33.388776,78.311691,105.562867,52.821973,-63.925701,-34.802699,0.604047,22.805035,21.839722,25.060161,15.362515,-48.702978,-105.361871,-107.554529,-72.929451,-61.474089,-83.607295,-92.250449,-75.058737,-78.726293,-133.031212,-104.547132,-36.174,81.65232,109.102272,151.642895,158.415892,79.347564,-93.292732,-149.671305,-108.416924,-53.12166,63.078468,141.253359,187.653199,99.265377,-110.245616,-120.91723,-58.988831,103.502471,169.671931,212.958438,172.263423,33.655154,-28.673566,-25.263625,31.485624,81.562272,240.994178,343.602696,426.759066,374.077218,223.776979,174.887948,202.361517,253.301286,237.897955,175.720735,135.210445,-31.396122,-238.211145,-291.923361,-243.376235,-168.216871,-33.121149,13.816842,43.953209,19.020709,-40.883822,-32.012578,-3.359125,54.812918,71.742894,121.816205,150.728308,95.615846,-83.721818,-131.841396,-69.561536,-4.780206,94.637526,132.33249,139.75442,85.058045,-57.761948,-48.411442,9.742391,118.833879,148.103136,139.226824,105.985054,19.495633,-71.388707,-117.979606,-172.580042,-147.7204,22.949703,127.609547,193.796933,128.226808,-61.542235,-140.279065,-126.661427,-41.297927,6.995727,78.444236,90.045674,52.877204,-27.669234,-60.162959,-53.95412,-3.050553,148.330783,200.14254,178.388851,129.935422,50.625027,-13.772874,-26.889012,56.237048,120.383161,159.045369,115.850632,-14.754364,-107.60335,-128.208312,-34.705991,54.179851,124.923346,102.993402,68.434713,72.476287,91.795971,130.994165,161.049907,180.451402,187.752029,256.539507,268.108044,145.111744,-45.799749,-98.124446,-60.464286,0.455082,77.081927,75.124862,12.304175,-42.491509,-194.105993,-290.608988,-257.370201,-92.50354,-18.811049,49.874308,40.028825,-65.82031,-248.745473,-324.820505,-346.761273,-307.844915,-243.950416,-237.07914,-282.543301,-323.295641,-365.739855,-339.966395,-303.106022,-206.872079,-161.507241,-56.747963,-17.474591,-29.603236,-135.713479,-197.568639,-262.130082,-255.442513,-193.842352,-157.364331,-120.605186,-137.924776,-265.398818,-373.398325,-356.071287,-220.122923,-143.499605,-14.745337,27.753548,8.527115,-140.027965,-187.066679,-132.220563,-69.741411,61.150969,128.517248,182.222586,150.704862,48.55202,-79.762207,-135.033106,-137.297834,-94.077179,-12.174811,-2.936649,-57.876699,-185.626689,-250.639327,-303.805987,-282.331725,-129.895217,-30.431035,32.238043,-25.215752,-173.284699,-233.025007,-234.257932,-159.887283,-95.267608,-10.759603,1.381188,6.582456,-66.369586,-133.093964,-169.117055,-118.661719,33.181862,97.931543,89.301608,7.601075,-124.055415,-100.98391,-79.283279,-45.815173,-5.217767,136.973934,185.391507,126.674216,-37.411479,-103.768376,-165.723085,-154.009375,-46.855384,20.044736,69.535035,35.595957:14.319362,-54.480327,-87.570559,-25.857732,22.574694,31.566229,17.405958,26.60725,31.617259,-21.972425,-193.948439,-222.81236,-67.999628,55.434083,131.063847,50.677199,-123.927601,-158.532426,-170.855145,-228.707332,-233.858772,-118.730723,-41.705839,-27.332955,-177.422659,-243.853989,-259.463096,-208.230305,-73.112656,-16.995408,45.3372,48.351423,37.409755,-1.31319,-45.60518,-96.882939,-78.664206,-19.147067,-15.920523,-52.18375,-84.87028,-98.97541,-79.547078,-46.76963,-9.716935,6.942801,92.578618,126.438902,79.958495,-75.824778,-150.777835,-195.580018,-163.721473,-69.635235,-26.313858,-2.094589,-100.712473,-155.862531,-180.040568,-152.969512,-66.938216,-17.927243,26.846263,-4.250777,-132.490239,-219.717684,-216.466582,-158.887657,-148.519279,-132.63138,-98.475478,-52.62273,-56.306775,-45.221955,17.686809,48.941875,37.415887,10.464276,-28.837288,-56.609578,-126.947027,-202.40324,-253.591366,-308.00033,-274.291948,-126.574015,-73.979005,-70.169149,-70.48516,-61.093669,-69.812149,-59.412745,74.346139,160.156622,219.009986,200.691799,171.528924,125.258721,79.887075,23.310268,38.523966,109.863547,127.287956,71.181045,-3.439319,1.451317,55.75568,96.491373,219.68605,277.934201,316.069265,306.711679,292.505187,260.202996,237.94599,214.446976,215.790742,250.948411,269.550104,265.530227,203.722762,159.039922,106.061538,99.799875,117.439343,166.167567,256.12171,219.421786,77.702943,81.914126,119.523839,188.042221,209.599598,272.087049,314.454168,327.577324,256.466571,203.906778,140.838174,171.992859,290.921558,317.322427,277.636903,242.695716,175.360146,161.747739,200.838795,285.810687,268.506345,128.964568,78.805566,54.616362,-30.073705,-103.744007,-181.502538,-167.887666,-93.098925,-40.687838,50.529,53.102623,-0.727424,-22.764097,8.565246,101.048432,82.56461,-56.966349,-81.903042,27.072061,146.367759,134.23704,-19.710637,-84.950317,-35.084414,48.973849,116.923457,86.56725,82.535982,218.76659,279.922116,301.906709,261.396696,124.079121,69.817895,51.804277,65.81811,54.973128,27.204689,31.864962,97.061187,147.176254,213.336605,210.703834,167.13695,145.935085,158.057771,207.459029,228.462547,254.222367,233.311144,76.80569,-35.754802,-24.72698,64.861529,123.693761,271.58638,338.494703,362.799478,326.30623,293.531425,332.10401,323.985649,263.963575,248.282106,228.128699,173.779297,-33.399705,-151.322835,-136.81367,-59.803987,-26.24728,71.888586,157.978118,273.941836,241.117808,94.758277,18.762957,26.602041,113.099006,150.461189,142.368849,94.201827,-13.992407,-31.157643,-21.892945,-1.880025,13.08535,71.011915,124.164231,219.588017,221.606173,133.646598,6.232897,-28.501298,43.96727,112.360943,149.590956,104.461991,-35.896213,-100.407068,-100.612809,-121.338372,-136.752204,-94.049418,-27.441788,69.72413,26.433446,-199.812785,-306.065867,-280.328777,-201.555105,-159.992955,-67.124675,-48.225931,-103.480742,-165.186131,-165.528752,-137.707668,-105.444011,36.499788,112.272342,94.79696,-4.702166,-192.913409,-231.245164,-205.378534,-118.533148,-88.762362,-66.446267,-81.458292,-146.580497,-99.684534,-67.260319,-120.771622,-161.353189,-101.373144,-15.041817,55.126435,0.006495,-109.535019,-48.201928,-11.487167,-56.65208,-115.016892,-158.04971,-141.356611,-159.635082,-265.928479,-309.198981,-283.187944,-217.204354,-106.143518,-92.029042,-123.025648,-143.442061,-172.673783,-236.245297,-261.751568,-202.804528,-125.240348,7.246974,18.288311,-96.343427,-316.338404,-421.048671,-480.539213,-406.65427,-192.889484,-127.402387,-131.823465,-177.54134,-255.232708,-283.611378,-263.901039,-130.243011,-62.156757,-14.225693,-29.284891,-97.685849,-190.102026,-257.58739,-347.802842,-318.780791,-190.975179,-163.402481,-193.355799,-219.739733,-299.894764,-408.03397,-419.013182,-301.234316,-220.704469,-92.447024,-39.604301,-16.615043,-95.146725,-134.909921,-183.01846,-171.453993,-62.03345,-0.049477,28.02569,-1.825563,-54.975225,-67.281589,-64.990185,-52.711334,-58.556265,-102.496683,-110.951625,-78.052168,-98.580218,-143.896644,-201.19259,-184.388703,-101.192197,-62.755944,-63.423103,-128.087541,-311.682516,-351.077493,-307.679347,-220.528311,-198.808951,-138.577768,-92.679586,-41.2595,-67.655936,-101.693749,-143.51559,-118.84027,-16.905975,12.704746,-9.402751,-28.773788,-8.586832,-13.498335,-54.037089,-85.128984,-49.864443,45.252559,69.775371,57.215869,0.456101,-66.699492,-237.146431,-248.198129,-43.574534,84.24973,137.009716,51.352476:12.12809,-121.567733,-140.087227,-39.307456,21.420326,53.50627,45.26638,9.570418,-84.187914,-139.275086,-173.937261,-144.433794,-19.70414,53.905155,102.379473,60.671427,-64.991648,-162.054766,-170.658656,-86.980629,-43.048972,-27.041103,-28.818958,-46.17327,-163.623259,-221.275619,-183.313948,-84.581088,118.966136,166.197027,141.743985,92.609588,-23.175578,-111.856124,-134.399808,-127.062131,-105.342698,-59.509939,-42.151517,-66.718319,-214.506006,-278.524052,-255.307873,-184.786628,-6.976909,77.798353,103.121783,25.188683,-143.772597,-205.562249,-229.654032,-275.635601,-256.263206,-137.496445,-101.340287,-164.823214,-270.940092,-273.86632,-197.454197,-173.07398,-165.893176,-126.936325,9.335556,32.836801,-83.2063,-274.264989,-305.468739,-201.645663,-126.697416,-37.368463,-33.208497,-79.694378,-121.564054,-142.889842,-134.457692,-92.041295,-1.717961,32.870323,39.968624,-2.675179,-113.622704,-183.832063,-201.09334,-175.761928,-119.730604,40.398606,76.702712,-13.245956,-142.563612,-183.176166,-196.964025,-148.565512,22.534921,95.82313,144.747707,126.901651,41.025771,-72.193376,-100.319406,-33.062737,39.273473,159.572507,183.22847,107.883115,-38.66865,-62.989889,8.325514,68.076327,203.916268,285.405964,343.167541,267.425104,54.914186,-9.298096,17.888225,83.999917,76.823756,34.811998,41.658356,71.597224,-1.555981,-94.749108,-231.201092,-194.076577,26.660966,113.43595,105.867767,34.297003,-101.453671,-120.307448,-55.410925,184.856366,280.30508,315.602484,266.707587,131.080205,58.15541,40.385861,84.980592,161.088589,328.088198,375.967033,345.899317,277.153749,165.560692,202.361656,247.89934,276.605804,257.718354,236.776634,230.114327,123.734055,-94.107031,-182.916436,-194.406021,-123.137456,-2.325112,5.937852,-13.527915,-14.401502,-45.41616,-154.75822,-178.403725,-98.572659,-43.123913,23.196032,36.510255,-1.532242,-93.011402,-112.931133,-74.20903,-50.527044,-35.083388,-16.312346,-7.629745,-46.217487,-78.426985,32.004754,89.470381,187.186301,237.206296,251.4026,192.063665,44.573498,-24.593831,-36.970372,-12.902086,18.915241,69.635223,90.346902,126.357086,128.189575,70.350939,-13.141325,2.191196,140.311122,203.211253,255.820428,244.087339,140.415874,26.340803,-4.144337,25.127069,96.387635,288.905288,377.57936,443.10824,388.041566,208.922978,154.461897,186.440093,283.31735,314.433911,294.403021,232.92135,7.004345,-211.134743,-239.772011,-142.644517,-64.623346,75.983024,132.084018,191.399888,182.924474,92.571115,-10.737147,-4.656614,116.292741,174.971727,247.051441,242.985197,82.422514,-92.177419,-88.433217,46.13621,110.347184,189.24316,225.631537,250.059678,194.25873,-12.999024,-103.64389,-62.690228,88.767647,151.130104,189.668099,164.68611,80.615903,-16.288402,-89.137939,-242.557521,-248.594914,-58.540971,53.73726,88.004349,3.109929,-175.894834,-151.309142,-90.285963,-23.835023,-25.6132,1.941625,35.629806,55.198537,-24.005624,-60.562306,-35.023947,16.456701,161.033975,236.676105,273.30436,210.369375,33.518656,-84.508335,-91.363738,47.517973,139.298325,211.411051,182.946645,76.834074,-14.565065,-63.714178,-112.274656,-90.621554,16.796465,79.811015,100.192444,51.313274,1.993914,56.776414,78.872869,101.532848,113.614781,128.079763,100.624896,-30.619416,-158.859221,-200.30071,-141.962941,-54.567487,23.566222,1.126779,-14.72891,-5.764122,-92.582942,-243.962255,-237.625044,-50.277947,43.957386,65.456361,11.247903,-137.6343,-332.107033,-415.571901,-431.751515,-366.701966,-237.32161,-212.061467,-236.54795,-271.182158,-318.492073,-319.522688,-302.682742,-206.403144,-133.087176,-2.160631,11.041813,-103.561848,-275.483382,-334.310567,-319.760925,-247.707082,-89.672217,-42.196329,-47.173317,-107.050021,-281.916214,-403.546364,-408.905896,-283.516773,-173.395711,58.986244,119.926732,16.467204,-179.817312,-221.657211,-180.953698,-113.103979,60.4903,144.173174,233.815482,210.911861,60.918463,-78.921595,-91.429668,-26.812146,6.550022,27.327418,3.150436,-118.867402,-218.425862,-235.146998,-206.810375,-164.76014,-39.998125,20.936957,11.160886,-74.220058,-271.335723,-326.253699,-298.42309,-222.653555,-181.403192,-49.751488,14.419477,-21.97111,-235.797836,-289.656739,-195.744634,-109.000581,19.093713,63.906554,118.401935,107.898996,8.982972,-104.834024,-123.144214,-16.807043,83.48438,240.963366,265.170734,211.085673,50.082414,-47.532466,-160.352088,-134.524411,51.665082,146.849334,177.24457,105.797403:11.656641,128.214004,129.788692,151.754364,181.750873,241.749554,267.429037,244.2542,156.638484,127.588898,55.468604,8.731693,3.161382,70.760172,229.061504,240.827799,102.893708,-60.705521,-102.324613,-73.083774,-17.946254,108.434781,156.199864,139.45734,-3.79615,-55.835173,-44.100271,-5.768626,53.011612,68.326155,97.678555,127.446215,203.939471,210.635387,189.812717,152.115417,133.483294,125.709065,147.462336,145.202058,14.92978,-59.489746,-102.974902,-56.814801,59.48926,87.894435,97.286387,98.470089,86.298939,-25.459583,-106.980901,-221.048472,-250.356173,-245.923762,-216.846195,-185.225433,-195.109576,-195.974771,-165.621098,-141.083815,-107.583803,-101.687524,-98.082475,-84.649788,-54.286143,-91.783155,-89.90806,-33.938123,-44.882011,-129.494048,-145.211242,-122.438455,-133.110532,-162.551423,-213.33582,-219.569699,-207.211388,-184.38424,-150.887798,-188.132412,-338.126772,-438.157036,-450.16437,-415.952342,-396.95499,-382.798831,-362.766522,-284.470109,-238.890866,-246.423272,-285.644574,-272.538302,-120.662605,-28.226236,2.327641,-50.074036,-97.425245,-88.673366,-114.723099,-175.259556,-172.522379,-80.753611,-28.782279,-7.511154,-54.922741,-78.954117,-121.746599,-114.138226,40.584697,163.220993,342.281761,368.472467,339.558116,236.124166,170.251856,98.41617,99.468723,135.812646,158.125295,188.175718,204.131935,208.120103,219.912161,218.972469,182.371554,182.40371,244.388602,255.625636,178.889701,58.900158,36.653786,91.864389,123.482558,171.864966,194.126902,166.954631,127.826426,126.363466,101.208162,88.96324,99.568117,102.061804,80.320058,65.586757,13.843756,-19.605483,17.124634,110.8235,77.75535,-76.290253,-101.882746,-92.540343,-94.161002,-79.678404,-25.704523,-12.579383,-35.828621,-29.490003,73.514142,128.603232,165.978646,68.898856,2.259993,-20.124217,2.930255,15.117539,14.814381,27.808327,40.83607,28.948137,-16.827531,-23.361928,19.128552,57.929624,133.468323,165.521209,224.220202,187.928836,148.425697,123.020534,108.907601,-8.698534,-88.905399,-168.693671,-130.03297,-119.577764,-111.063488,-77.277979,15.308251,49.345101,89.212322,87.511563,57.725443,81.275104,109.139586,136.503178,125.123541,100.876589,116.014721,131.833771,35.00944,-4.694686,36.580653,93.06377,179.123619,212.838947,266.176698,257.441828,209.099456,240.365434,257.884761,237.829174,227.18109,198.207531,132.824986,-53.61941,-52.086451,-11.044801,-51.515499,-82.878904,32.421247,145.950023,218.561442,132.736602,-79.216624,-107.851451,-71.874004,50.833747,134.217365,232.69488,189.155625,-6.829849,-63.680005,-20.181607,77.669567,117.871143,233.768793,290.66769,256.400484,172.161199,89.734111,105.830833,79.007663,27.530158,26.794623,-2.008622,-29.164731,-26.760625,12.827953,-7.233453,-109.438851,-157.441821,-192.238744,-153.847081,-20.67111,-3.072188,-86.727599,-106.923176,-82.215384,-38.910198,-9.562013,81.865961,112.25037,100.043182,57.242235,26.884418,-26.146701,-22.782478,25.765383,45.79091,31.682017,-1.949598,-95.124766,-192.052078,-198.900849,-95.407353,-35.545581,-5.728532,-35.772198,-110.12619,-97.864332,-94.398232,-176.018951,-217.353333,-192.496432,-130.226284,-3.338078,12.517508,-60.965786,-116.685067,-104.612608,-91.928737,-114.821801,-142.692213,-121.33958,-74.581114,-112.359983,-139.277137,-105.60474,-53.977348,10.185861,30.202075,94.423993,105.585166,40.425314,-40.061448,-55.760173,1.079347,61.011208,150.613735,136.286206,-50.868834,-230.392156,-258.733644,-238.735523,-196.90581,-78.050632,-32.306796,-62.229451,-124.160565,-146.547024,-28.421675,3.019758,3.787282,-4.232179,-19.213056,-20.236006,-47.820002,-141.966372,-181.285053,-163.389943,-90.088452,64.399939,66.224787,-66.436608,-123.977167,-155.46694,-226.720012,-264.551219,-200.428534,-120.453047,-28.100452,-30.561403,-67.829315,-72.60379,-61.334818,-70.148133,-82.386304,-70.613893,-56.990868,-75.171372,-110.323209,-151.844767,-134.434932,-133.377296,-124.293841,-121.104441,-137.585122,-124.748075,-50.89924,-42.074363,-70.77541,-91.066975,-49.889971,64.975522,78.0368,-8.404519,-71.011262,-186.806109,-226.307677,-186.075586,-69.884004,-52.498408,-61.577842,-24.705675,95.442535,99.729206,70.031443,21.067778,-0.641047,-56.905081,-62.609716,16.656363,62.408227,78.487954,33.011842,22.22436,30.379432,36.701361,53.072168,36.385339,-75.197914,-128.810743,-128.547608,-166.222623,-165.593262,-31.232437,45.356103,66.244382,30.364373:-2.648031,38.60519,36.984555,6.636655,-15.987249,-21.377538,29.518864,171.882848,205.787454,159.346866,16.096034,-16.048988,69.136781,145.733026,210.188649,182.080221,65.377971,-76.772113,-122.633563,-103.69115,-56.264026,23.876251,22.917014,-67.034152,-125.107012,-144.174545,-269.640529,-331.081193,-265.692905,-160.514069,0.642105,40.616979,107.774523,78.669258,21.858447,-55.735895,-61.300581,-0.645159,60.840137,155.175032,90.999544,6.261357,-94.870424,-70.965195,23.012098,45.370097,42.180826,37.947873,37.284341,-45.307193,-127.737589,-227.120466,-203.372125,-95.024144,-63.606565,-12.045662,124.869732,149.033197,78.739451,65.428018,104.730269,101.120942,22.482582,-7.890724,-25.605097,-105.680487,-147.505397,-108.137032,-45.698819,20.498516,-6.799793,-90.345399,-105.332449,-119.766654,-146.905273,-142.101908,-123.061809,-104.673363,-76.566192,-90.033173,-152.435601,-244.413206,-283.956979,-297.665507,-277.48864,-229.656097,-221.063531,-217.345012,-186.600022,-191.889232,-208.193201,-157.407181,63.671836,156.055213,172.011812,135.271812,105.383291,78.594966,50.833015,-18.582896,-54.006128,-52.861001,-2.723035,128.877024,164.572593,121.547004,46.787232,74.464763,195.463154,244.769966,323.383768,355.653339,379.459536,343.468152,316.178177,264.243883,252.918474,303.315267,354.706127,420.351189,375.020877,337.594005,336.006572,353.355051,348.882164,366.219434,464.503621,462.505067,265.259604,54.774631,26.991694,74.379455,101.2265,179.757314,234.769999,277.474466,190.678346,137.705498,122.252535,149.55849,192.783625,212.967356,220.266296,177.269811,32.67078,-10.04833,35.961659,127.645379,108.000326,-26.744045,-73.072856,-57.015257,-3.441092,-20.452043,-82.51034,-69.589005,17.169847,60.92037,167.037484,220.126154,257.760326,201.080001,161.263016,81.784023,29.047455,-62.331629,-64.870699,33.165996,146.791305,133.842127,-6.407885,-62.720783,-47.337161,7.754938,117.245507,165.574215,278.707227,304.982157,263.405338,151.016997,104.300511,76.488664,85.36084,41.648436,-52.060521,-79.179072,-63.60177,1.021918,209.21386,299.288997,374.699798,373.713184,365.197254,357.013776,348.402648,294.607045,239.58967,132.180162,99.130122,40.609652,-48.088214,-95.816599,-130.696692,-101.168769,13.050568,85.722044,241.723065,285.232128,250.408235,183.861859,163.216763,106.818467,82.135731,70.8715,45.959379,-91.166531,-163.290949,-159.027576,-106.174207,-43.732696,108.719943,161.424848,183.724739,145.607608,-5.286942,-96.544553,-77.742499,49.986749,113.528356,141.041439,92.677994,-38.547695,-35.95157,-3.503696,-6.16418,-8.265929,110.65287,188.021981,220.714756,199.055867,152.488003,48.760041,12.147267,52.318272,81.326988,62.323612,40.381422,-26.232119,-174.054591,-227.067093,-206.012572,-177.717708,-143.781029,-92.682522,46.853829,62.862714,-43.233498,-173.014295,-201.476153,-183.908734,-141.342457,2.71028,54.128744,-15.358695,-173.91327,-212.076088,-198.294565,-168.642852,-111.187239,-83.320059,-38.219648,-43.258012,-125.29401,-249.227267,-282.253765,-251.631506,-228.370869,-215.969777,-216.389869,-222.828349,-199.673129,-183.049408,-200.443401,-216.452691,-168.292642,-109.720293,-51.931693,-77.849818,-121.042098,-65.538447,-52.062747,-130.960876,-187.62113,-196.083317,-150.22811,-104.280267,-174.368136,-221.828871,-246.734896,-197.017779,-65.034747,-42.472774,-101.333731,-138.418042,-143.075847,-143.832264,-146.449443,-96.361451,-62.564988,-14.535743,-10.601299,-82.379245,-207.46111,-265.638457,-320.9246,-282.930481,-110.599903,-47.914546,-63.938126,-118.202162,-220.623342,-194.230461,-130.071888,-51.018386,-64.416536,-75.800386,-45.710864,23.450272,27.198049,-19.971583,-161.154989,-197.760721,-178.512735,-153.701475,-124.716699,-136.823827,-213.653282,-287.284027,-300.033777,-227.051148,-148.837155,-48.054508,-51.867152,-56.511185,-2.964075,4.941152,8.317218,22.553132,10.215477,-24.422522,-80.737483,-80.489624,-46.456307,-50.163846,-54.251401,4.906046,43.471437,10.459509,-47.431676,-72.258812,0.574267,-12.947464,-96.806689,-102.775335,-67.871995,-65.705444,-75.776939,-87.652296,-157.334004,-159.309624,-110.401274,-70.065798,-111.83715,-173.405034,-139.13431,-26.025071,-1.836332,-25.988192,-76.457124,-82.745451,-57.741152,-30.610812,17.792928,15.277956,-56.64359,-144.944456,-163.594372,-153.287057,-141.939627,-120.965668,-125.521673,-190.831423,-209.54851,-198.605984,-241.768445,-257.745417,-141.406649,-46.262152,14.421885,-40.443585:1.248819,-19.187815,-12.258252,22.843369,51.290841,112.645065,119.418271,91.846097,57.039611,19.8434,-46.538065,-49.265389,-9.881139,33.77648,95.55504,60.345163,-71.418741,-117.642747,-112.390929,-125.898215,-154.696949,-145.873829,-87.846475,-13.83927,-81.199969,-111.502972,-70.798515,-18.255597,69.038041,96.716742,109.563794,110.184635,124.077891,-12.543573,-108.927917,-113.687153,-43.084234,60.095223,79.79703,60.298397,-37.438366,-95.588331,-154.170835,-136.51718,-49.557218,4.819915,55.913321,12.541359,-101.544741,-124.643893,-140.759415,-186.21509,-200.918799,-252.30304,-298.276678,-353.996231,-303.240224,-262.366317,-183.763134,-156.043981,-146.458455,-145.077222,-88.162293,-52.661515,-93.034308,-219.218373,-234.276936,-203.211001,-207.433087,-193.317628,-140.46547,-56.455993,-83.073007,-106.003095,-119.512975,-98.071226,-54.665434,-56.733276,-76.442616,-89.740533,-125.947167,-203.942354,-263.502688,-315.747059,-290.956593,-203.949712,-157.282875,-91.159693,-98.825685,-146.431776,-267.474717,-273.027843,-147.946102,-76.336483,-22.474018,-24.913941,-9.211542,-17.313642,-29.465101,33.399696,91.708462,145.515465,131.274273,57.574064,-1.846669,-5.284609,19.656057,38.438248,135.324848,221.135538,310.537014,261.885501,137.660497,148.49491,161.855552,133.139359,105.074231,96.571515,127.314155,195.019374,127.450198,44.070403,-34.067625,8.553108,134.088068,163.386906,145.028574,127.518634,106.853889,2.366931,-48.071893,61.429719,190.272558,330.781396,302.44807,157.022191,55.561921,45.028072,134.241278,202.885043,244.103008,208.455912,115.644345,94.309187,119.221406,152.728725,152.632176,129.651566,113.585476,109.858201,108.636357,10.709708,-78.745322,-56.011083,-14.816563,-61.283974,-201.838037,-205.182152,-81.888133,-46.621598,-87.0899,-89.941169,-55.151607,20.437372,41.829882,17.133771,-15.754092,-32.557771,8.35866,25.328913,46.053514,53.009421,92.200407,140.246864,223.879655,214.97555,120.549884,44.613142,45.904136,133.993076,164.241866,76.428942,-3.292875,-108.31404,-145.2409,-144.197786,-105.587904,-81.059346,-37.593808,-2.932351,81.177974,94.059804,58.726547,49.865816,69.24244,105.498836,122.412899,201.836022,220.569139,112.946255,-22.437461,-55.332493,-3.142962,107.210854,387.733734,456.616095,386.700594,322.00085,293.478809,313.340425,324.071072,410.129534,442.730474,361.418002,257.174936,47.538921,-55.207506,-67.221471,-24.744777,-3.676941,19.910634,49.802046,83.494492,51.452021,-30.662738,-63.300049,-52.257628,56.716642,114.299896,127.939579,85.664259,-7.117289,-14.521926,16.163628,126.088128,173.01251,193.078033,200.080023,231.91292,217.975937,149.196753,89.365096,56.322591,25.922712,18.273515,-32.472241,-56.084776,-71.383884,-86.710797,-83.93662,-57.748803,-59.113279,-89.206187,-86.540508,-48.505147,-59.122672,-150.811822,-153.866504,-93.07089,8.347143,6.26338,-13.542205,12.954039,68.519202,18.833124,-13.149958,-22.522932,-11.84641,36.873137,95.545173,220.468993,226.807661,93.842404,-100.357167,-147.102658,-71.157955,-11.837108,15.183632,-1.648064,-65.092294,-111.169571,-127.146969,-176.815521,-182.60494,-108.455899,-40.934595,44.222301,30.178318,1.772986,25.840498,-2.284988,-98.991303,-90.563548,31.435291,42.144308,-131.474316,-309.278935,-323.14581,-212.506538,-131.271031,-44.013475,-36.667795,-4.906156,12.0799,-24.257772,-89.361238,-95.764772,-75.662697,-52.445741,58.011513,93.202744,-39.269895,-275.231283,-356.115296,-401.455241,-350.710794,-169.072081,-98.431026,-117.771124,-190.42405,-257.107029,-171.005876,-129.136328,-130.549595,-163.062008,-128.782362,-47.78829,-26.211746,-277.384966,-361.649948,-315.608622,-244.611516,-118.862713,-77.123974,-71.092226,-108.900334,-187.722938,-223.669846,-252.511482,-255.897006,-192.850335,-44.793427,-12.067588,-34.064548,-87.211666,-92.331707,-57.314193,-22.64557,56.252708,75.981695,6.102882,-73.416695,-163.782423,-149.607317,-152.143152,-151.756313,-144.27148,-137.321407,-136.167492,-118.428355,-72.993599,-81.313005,-149.31491,-142.077401,-62.37122,-37.18227,-31.180555,-64.62592,-194.983361,-273.773594,-266.423092,-190.070891,-151.496232,-128.576617,-127.944289,-61.280783,28.766079,22.474512,-44.919614,-43.922144,57.772925,108.06275,95.812623,57.558845,42.737634,9.941464,-44.496926,-44.030402,44.628603,230.656815,260.399926,178.99128,-15.392654,-119.4303,-205.44289,-150.694611,36.12149,99.979325,94.532162,42.747477:right
49.268792,-69.543658,-143.905633,-164.76567,-107.961795,-1.260489,-4.166311,-64.597761,-49.730395,-43.717548,-79.437801,-102.77731,-104.818812,-71.187841,-37.268614,-72.358243,-164.307883,-217.729563,-227.296243,-165.578364,-106.718227,-16.160895,-3.029124,-59.639285,-151.262559,-162.765679,-85.018439,-29.207541,13.016532,3.055715,-19.443656,-16.779424,-39.701163,-133.043257,-140.908656,-37.526796,30.76825,106.728067,83.557798,-55.595773,-145.194391,-151.409183,-118.192326,-80.467806,14.856053,44.677568,43.622648,32.669169,-17.99517,-141.533644,-177.587926,-153.640179,-134.51278,-124.48434,-113.838545,-35.766699,38.097483,47.185228,120.507121,189.416133,256.554139,251.872716,200.636912,142.040182,8.213594,-47.073116,-25.050773,73.714831,111.781415,160.060726,188.821818,234.943507,233.247145,220.63056,161.574417,113.092746,59.733556,85.597972,147.68269,140.986345,87.065045,30.153204,6.041268,-5.806618,11.480732,56.487533,62.853559,31.792417,28.720964,33.031062,3.374361,-4.515434,52.265131,90.900827,93.342162,64.372671,3.884515,-123.905142,-188.758649,-203.589906,-159.515739,-46.662007,-31.021931,-106.96613,-177.022371,-200.924078,-241.002815,-261.318997,-295.180187,-292.760039,-257.785834,-233.40896,-175.994719,-180.965926,-215.218024,-246.574875,-211.871352,-84.358229,-35.386289,-10.929008,-30.933456,-55.359773,-112.300408,-110.742002,-45.919111,-22.062934,6.609176,57.322941,216.476531,250.428725,213.695799,170.695932,192.609585,285.0125,327.024095,363.423827,257.773425,161.827984,31.312532,13.84088,10.324153,0.569934,-79.079802,-137.500543,-189.750578,-126.610812,-73.72921,-12.595504,-20.035855,-49.51081,-61.462191,-76.258813,-72.060006,-78.533383,-64.031001,-33.492924,9.371346,4.683496,-17.863894,-9.14144,49.981722,106.763418,124.749431,127.481758,126.47999,170.895969,200.103646,209.833407,168.724988,155.574841,186.802614,225.50484,296.790284,313.490661,326.017427,341.638151,368.997753,292.555403,223.048107,90.517582,60.969436,117.330334,146.117402,109.44866,72.219159,66.318394,43.151863,16.792496,-41.415827,-44.926501,-12.195112,-8.062234,-40.023282,-35.833244,-7.654943,3.750682,-50.617753,-170.36088,-162.155917,-88.19663,-184.452298,-266.082123,-313.505512,-290.658924,-258.818971,-248.096685,-220.185215,-206.082463,-191.562238,-264.207628,-343.718481,-462.73419,-438.92575,-296.463631,-259.529201,-308.843325,-433.60676,-476.738377,-434.705059,-370.986054,-264.721478,-237.573545,-252.74324,-282.480699,-279.520183,-183.649464,-160.269683,-169.541581,-150.419948,-47.118233,-14.639333,-15.932541,22.668758,64.039398,119.463454,102.97466,-7.374334,-60.907377,-102.557568,-102.477411,-153.22003,-277.584059,-278.909901,-143.89567,-98.346225,-132.452771,-161.903633,-143.151695,-130.856879,-143.639168,-53.200877,47.309306,188.160629,190.356619,72.98078,3.703004,-23.580026,37.560732,43.052679,-38.59934,-87.149028,-68.61366,-19.667989,48.52772,70.926841,77.768026,124.639787,156.524904,121.574232,38.45618,-144.927546,-185.656302,-142.67715,-100.76498,-106.284619,-117.239267,-101.871461,-32.110116,-25.639546,-100.062833,-110.768207,-70.984913,46.148655,119.372128,255.883264,277.655911,181.018682,112.119499,63.963052,73.001641,104.749029,205.272283,203.695516,69.299098,-5.057494,-85.96834,-118.438158,-140.9077,-160.429284,-129.108737,36.23065,136.173401,186.899302,132.55987,40.447794,-6.389563,-23.563214,13.49644,59.823252,119.319652,107.308124,45.801941,45.639317,60.721944,95.487059,114.295035,170.057968,212.581879,285.849198,299.892339,265.772714,180.204511,127.852494,5.311415,-59.793036,-173.525332,-208.902926,-215.606971,-176.350592,-167.908601,-124.383782,-92.782612,-78.571391,-60.119421,81.426977,172.197521,229.354207,4.258761,-156.533878,-359.824931,-359.324058,-204.589643,-138.435147,-139.229904,-160.229743,-156.527029,-148.618682,-141.497711,-109.176449,-66.04484,15.79487,12.505144,-58.927185,-107.823258,-90.857426,-7.471671,32.401401,108.946791,132.237015,94.372461,-10.85487,-50.301228,-17.190695,53.176953,181.411794,202.24339,157.021675,134.035527,107.769639,-34.814948,-97.471368,-30.267084,73.744749,236.716881,244.249757,164.234906,101.431877,96.241329,179.582856,247.19616,292.363102,252.181464,166.586216,178.549432,217.797212,73.595326,-11.459293,-38.343983,6.267235,97.639896,118.049858,109.635114,131.947706,175.991007,255.639726,265.821706,257.376661,265.261905,315.516365,347.754132:-104.742669,-134.761017,-113.2526,-49.256641,-16.848007,27.518136,27.432357,-2.130081,-24.628934,-27.633481,-39.118035,-49.342713,-12.535942,32.253226,43.269626,8.721733,-19.414829,-44.770693,-71.004876,-55.353198,-12.344549,46.848438,49.035233,36.277235,7.04603,-16.929049,-53.086227,-53.168562,-48.633703,-61.528472,-82.697062,-62.449266,-7.080613,-28.94315,-44.605616,-17.509515,17.116287,47.855829,24.960293,-42.722669,-98.085159,-114.687786,-130.183845,-147.163496,-113.729833,-41.667797,50.679169,25.15097,-91.631604,-198.23846,-218.583825,-176.126211,-142.016749,-109.918458,-115.434049,-122.387527,-55.113623,1.985086,93.920513,111.93945,141.194129,170.315634,194.778628,159.574408,-2.722897,-158.521493,-164.285593,-41.700013,31.541312,97.935175,74.220629,13.122209,72.469726,92.678297,48.076028,37.323672,119.553307,159.916073,138.455453,115.148865,71.486795,-3.231024,-16.204914,23.454005,57.977439,105.337404,94.209829,26.415459,15.190456,27.045728,17.281999,11.160586,72.969206,123.916642,165.587496,147.504652,30.263282,-148.325191,-204.483074,-181.883471,-101.180789,54.069627,62.679456,-19.947523,-174.772304,-248.860233,-278.533482,-251.552026,-190.458685,-166.469027,-162.689887,-166.325999,-166.483716,-227.633592,-254.768712,-212.201814,-143.692523,-10.64704,6.072115,-69.936235,-174.943449,-200.074873,-209.869893,-213.571184,-197.071779,-164.414424,-59.902049,4.18384,126.719949,162.312988,132.941956,55.589474,51.809063,132.214439,174.466716,206.474454,224.018235,219.309348,138.989297,106.501817,160.87094,201.275605,125.896249,22.322208,-139.948492,-177.50581,-167.751115,-108.021057,-68.082327,-26.860304,-38.585505,-71.011888,-81.798528,-81.465087,-44.721196,-21.586614,41.240993,91.858681,110.613384,55.899716,-22.705339,40.934561,84.751377,97.902209,76.453797,70.067109,81.541163,81.782012,71.368883,78.087487,140.248323,193.174508,287.547827,313.098147,343.795002,343.126708,222.558806,6.113931,-63.045391,-108.393095,-110.099079,-93.985283,-78.627077,-12.282213,37.61559,6.514834,-118.159701,-154.531664,-114.24005,-64.105949,-55.900157,-105.804771,-149.659528,-120.897271,-139.882461,-196.631057,-194.74664,-175.93496,-189.753054,-236.42058,-256.328543,-264.58161,-301.555335,-311.080094,-220.535168,-151.052028,-127.245027,-154.902745,-186.521054,-272.355073,-340.823947,-364.68521,-301.96724,-181.771622,-164.704765,-148.566437,-172.144695,-207.242841,-181.366508,-125.478508,-80.67414,-92.232241,-112.95336,-118.192753,-146.285866,-164.426424,-130.353651,-39.348794,-21.092832,-15.220613,-18.715487,-31.510159,19.160399,77.726891,142.036687,128.936086,124.442342,124.995802,27.747941,-45.285606,-154.359179,-190.767984,-164.943325,-36.095023,28.887061,55.369257,10.055968,-106.622713,-160.994553,-171.360037,-133.38987,-56.465523,171.59246,244.499868,172.983641,56.963733,-163.552741,-188.141082,-124.38874,-45.257572,-69.351706,-130.091808,-131.974475,-88.070373,-29.316773,0.599038,91.993272,135.68874,123.383875,53.787414,-137.270686,-190.10942,-144.801194,-97.188398,-112.753392,-113.629236,-57.760099,113.03501,149.047918,40.270109,-62.043673,-38.056002,94.123561,152.098232,200.330637,207.807372,208.651133,180.901814,63.185707,-0.844741,24.255069,93.693887,86.402032,2.360374,-29.934141,-21.385288,-80.961244,-156.329055,-194.433624,-129.370302,3.452068,26.767856,12.098832,-6.484661,-43.843976,-78.979204,-78.930823,-24.965433,23.144521,94.710693,77.072699,-31.116344,-148.154484,-191.784765,-165.924134,-79.726951,155.19747,216.921737,163.096726,125.240492,101.89439,66.936359,46.975484,-17.313493,-38.951685,-18.119799,-17.129374,-82.112427,-135.690883,-135.290902,-62.054128,-17.542808,24.287032,46.008804,93.311698,109.097971,123.727758,-18.783667,-133.187129,-281.407209,-286.739226,-197.658073,-155.65357,-145.059354,-181.250063,-193.809143,-191.221346,-177.421114,-149.046257,-138.488429,-109.546992,-87.199764,-64.607859,-104.94902,-89.988225,54.841543,140.693022,260.369272,262.015288,140.67661,28.066637,17.238905,77.228731,125.926465,216.533969,244.36515,201.152467,137.39635,26.052365,12.074902,61.221569,187.88037,219.597115,215.713566,185.516223,104.085698,78.584518,86.140887,140.734015,181.640854,217.269542,194.471726,145.322625,144.275715,129.311179,53.818361,17.766239,7.911969,46.240676,140.81303,129.77905,-7.538687,-69.66969,-36.178156,76.392863,117.054125,127.088411,119.314137,157.011759,182.320969:-105.604219,-183.701074,-167.722541,-23.669792,37.857209,76.152346,63.887213,23.931711,11.869355,0.640858,-54.694878,-72.600158,-0.562878,60.076994,54.140407,-11.6389,-131.272767,-156.193873,-144.423668,-110.306663,-64.151407,94.887241,136.621678,50.689984,-109.032819,-148.411991,-123.810558,-106.613665,-99.689553,-74.276915,27.983391,64.179587,19.58116,-97.165985,-103.003806,-3.280865,37.12974,8.950101,-41.483233,-148.196364,-222.398523,-208.020412,-74.129621,-14.592356,15.474876,-4.102138,-115.799035,-172.241671,-194.009392,-206.642142,-237.632244,-279.903746,-266.334179,-213.220922,-204.934129,-206.968512,-148.546769,-101.474085,-13.278625,19.858595,71.086406,94.596415,108.06451,93.875768,17.915118,-94.28948,-108.004758,-24.156516,31.783518,68.120749,35.925298,-43.378905,-7.022241,33.220663,62.322213,63.582166,76.937929,73.277414,28.59293,13.173448,31.135187,39.734676,31.345876,39.666887,57.157875,59.301367,38.751437,19.003962,38.127912,32.864178,10.213724,18.21411,68.350484,93.921778,113.795951,92.63893,-9.420295,-88.037645,-95.664498,-63.712495,-19.700566,87.569397,95.804534,-16.438578,-150.562889,-173.601514,-158.548122,-169.395449,-176.651699,-123.845633,-23.806661,-34.955415,-136.862797,-190.031938,-155.842039,-43.03031,-13.098482,-39.917651,-95.278257,-222.360778,-205.984784,-151.091244,-121.768443,-151.989978,-129.984653,-70.179863,10.854642,17.446307,19.811937,65.487043,84.036273,75.530404,81.036411,139.536696,158.481131,180.825105,206.074489,197.779568,181.190439,212.080298,320.04,334.430124,206.988472,93.298396,-100.993659,-111.92201,-71.934996,-22.306789,-9.399006,-18.256944,-52.307691,-97.668748,-32.637866,13.366924,67.832805,79.259159,112.012113,135.313252,151.142412,142.332578,113.732364,92.925653,115.539914,183.833195,193.364122,168.255795,133.768096,43.954508,11.683618,39.148137,189.444619,269.007329,325.696688,318.929222,315.374501,305.753826,188.258199,-37.220691,-127.394477,-172.746922,-139.486101,-82.286948,-86.645335,-93.967347,-97.159335,-110.934058,-110.967886,-100.386456,-107.962243,-126.738382,-150.213026,-129.754685,-66.826143,-76.787608,-98.34747,-159.576424,-178.425546,-139.105276,-103.267374,-66.474172,-118.912909,-149.905169,-89.657585,-5.282539,121.470945,123.48686,48.68141,14.259447,-55.73139,-183.352817,-230.381252,-214.703757,-165.964822,-62.172844,-43.325474,-110.132929,-194.872572,-170.379099,3.269596,71.104681,71.508403,32.428417,-65.377183,-95.665845,-116.578428,-125.542012,-89.455607,38.189229,87.848781,106.397507,81.349097,40.323032,33.332072,26.20476,-2.615759,-0.484929,70.674039,94.52489,-1.033291,-95.657881,-219.516788,-138.060158,-54.999865,40.327983,53.683488,70.105667,52.209892,-68.965,-184.70831,-182.184688,-14.192265,97.262496,210.407664,206.173033,140.14011,87.37808,-49.271635,-131.995772,-134.691747,-145.689442,-150.344432,-73.486006,-26.289211,-46.886585,-96.18169,-57.036504,103.519819,152.526909,113.312354,63.035787,-8.275869,-23.872463,-40.43785,-74.458771,-64.322627,68.901749,161.362353,287.501727,290.915057,185.841901,45.114108,7.518122,58.831751,127.416637,242.381051,249.478617,153.813663,98.884289,37.443873,6.983013,8.188225,18.084529,11.285509,-24.945189,-34.970292,-23.222899,-96.53896,-168.293276,-229.98169,-198.659696,-69.631764,-14.87534,-35.237307,-91.542069,-166.731266,-161.828076,-146.543068,-89.428643,-42.742267,3.708739,-34.696994,-158.285253,-255.120436,-288.066175,-225.241147,-125.575266,49.363727,59.004707,-69.490191,-133.597089,-161.985533,-162.966488,-153.896025,-65.713162,-0.310983,74.150142,55.425591,-23.227563,-101.109526,-136.546734,-117.814104,-70.145015,33.182028,66.343238,27.901875,-24.611411,-81.72724,-150.364201,-207.923591,-254.75988,-233.680827,-200.481186,-216.140692,-253.386606,-221.706339,-200.005679,-208.095169,-225.811551,-183.834998,-118.731279,-31.945221,-41.420425,-100.885759,-89.588282,-33.145523,121.36631,191.313925,286.003145,283.302779,142.811409,-29.409941,-66.963275,-47.489954,7.59437,185.385292,258.065809,251.387503,181.391865,19.847571,-62.745992,-43.955134,86.220691,166.486102,249.617631,209.042475,58.151275,10.113302,11.184498,57.925581,95.997949,133.044587,135.928894,132.178688,120.412897,85.845367,59.824025,41.350794,-19.310247,-34.88759,-14.70151,-17.703048,-87.867209,-157.946004,-171.884633,-150.986612,-105.243659,52.278449,118.695054,109.9864,49.743464:-120.76737,-272.040144,-304.001618,-175.168873,-51.881392,138.659001,156.554375,49.056191,-48.777192,-46.27168,-10.264267,-8.130338,0.366334,17.241839,5.37628,-28.18777,-93.655672,-162.236918,-190.86785,-188.378159,-144.728109,-14.659395,18.596861,3.554613,20.497424,24.016943,-54.132755,-105.441235,-107.762473,-60.328345,18.905466,25.456633,-31.63087,-122.666126,-139.914519,-93.764935,-40.330483,54.237551,48.163663,-73.643087,-204.636918,-235.273496,-194.302362,-133.287462,-10.671789,16.082588,-20.364033,-56.154275,-119.322597,-226.883544,-287.024186,-320.829266,-291.961122,-251.405006,-257.419357,-224.043992,-139.208951,-119.083489,-72.985023,-29.619256,23.916588,34.128743,61.406489,66.648557,31.621725,-58.133114,-80.046073,-29.360238,30.642169,151.933602,167.297154,86.463019,33.790518,43.023233,45.237255,28.090076,41.78456,82.840962,117.359482,94.118416,37.039011,20.524354,48.670394,148.16067,163.082148,83.988078,53.109976,145.098086,232.598675,183.104352,61.210083,63.968643,133.723679,156.870027,175.605691,175.444536,126.341071,22.597426,-2.17649,-3.140958,0.215676,33.275291,37.534622,-41.695971,-185.564998,-232.802418,-226.914817,-203.527146,-155.91081,-135.594477,-163.35194,-190.150212,-152.096341,-84.791005,-85.693169,-85.772245,-51.015624,50.554432,72.264351,31.089861,-10.533962,-10.060412,-13.350594,-27.375751,-22.043153,7.046401,68.139516,97.0817,154.493137,154.296883,138.407276,152.250644,186.651915,264.02463,283.747052,285.569684,252.433154,201.347282,84.052209,66.685066,108.896522,118.965202,38.145276,-29.793451,-115.643335,-95.879968,-49.603329,68.176348,97.716615,67.068439,44.058789,24.101381,-9.448598,-13.689956,27.595505,41.776883,53.275992,78.740011,110.931944,90.408283,34.077281,24.69441,52.72196,140.338212,186.447556,256.356626,238.40788,116.784279,68.258151,88.703823,170.219484,204.263695,235.923279,256.053284,307.291946,316.405833,262.056887,134.331595,87.606555,32.812262,0.523783,-45.989833,-46.178638,-38.303974,-75.179363,-107.995191,-150.914399,-151.203726,-117.276532,-90.144667,-54.278113,-45.38702,-32.139295,-73.985054,-88.465389,-67.111851,-71.817355,-115.650165,-120.33141,-101.65677,-158.070501,-199.854632,-213.227139,-198.966772,-159.728393,-119.728666,-37.831181,-24.600084,-96.742616,-288.966832,-358.209014,-321.338733,-251.64852,-165.875505,-168.025388,-205.550679,-255.955679,-275.15249,-245.094973,-203.444643,-131.200869,-132.124225,-206.149,-219.960826,-139.818627,-48.103853,-24.24054,-6.845916,3.304556,48.648462,68.067726,72.311841,60.203178,58.276306,40.424866,12.403564,-33.633207,-27.764429,-22.395286,-58.663997,-179.740173,-249.313444,-232.69736,-114.382994,-60.069776,-87.700669,-149.758795,-214.926123,-236.493085,-251.904906,-165.647852,-52.383591,130.12245,141.748401,70.267487,37.137293,-15.378939,-68.36677,-80.400682,-120.735793,-149.661605,-105.859517,-40.014632,19.332412,-6.553944,11.935801,119.752288,158.50579,133.612391,78.268729,-55.376802,-88.728578,-57.920263,-44.188866,-45.14536,16.997176,76.742252,187.651566,207.405866,150.076215,43.3814,25.839181,140.044365,250.64445,424.336044,447.338554,369.538725,291.726406,117.178004,-29.520363,-34.546136,76.007005,102.419874,35.052692,-4.872751,-28.571792,-76.101047,-146.876708,-269.574711,-249.041015,-57.861192,32.839367,77.509312,61.287366,38.710204,-23.333269,-64.420121,-104.507576,-96.643635,-44.411661,-30.018529,-73.564038,-161.726753,-194.533436,-175.442971,-129.901721,-29.596339,2.878685,-30.243438,-75.454138,-134.316953,-195.445828,-221.270899,-206.361006,-182.015294,-165.540614,-179.72912,-211.39635,-229.317678,-249.57215,-250.043595,-214.942938,-149.44347,-132.643657,-107.939077,-85.969617,-63.760692,-156.213416,-204.879785,-266.522928,-300.634724,-316.699075,-276.386059,-214.706504,-271.333742,-293.326013,-240.736108,-196.652145,-128.845231,-81.662882,5.924634,-12.108285,-138.89302,-137.986291,-89.887794,7.689224,67.07886,209.832825,235.632158,65.585139,-178.267934,-206.99475,-82.662327,-4.386112,66.346323,80.577323,71.74215,29.006015,-94.213736,-169.198922,-147.120542,-19.401139,35.63867,110.668468,135.693215,132.562703,78.748111,52.375705,63.409268,101.206266,179.911689,198.340947,168.039465,135.573444,74.509093,4.287787,-27.66229,-70.398386,-74.668643,-24.545685,-1.943139,-62.312499,-140.654398,-127.276261,-19.408113,37.358531,156.824014,211.15005,202.500376,162.714271:-138.941741,-228.772962,-214.115301,-80.54614,-9.69837,49.057716,34.50147,-9.53777,-5.73916,5.018617,-0.020088,-15.821013,5.721821,46.81609,42.282224,-37.730872,-243.380561,-296.715631,-246.728805,-112.590494,-50.902879,69.491682,94.803175,22.753862,-77.610299,-97.956358,-96.872204,-77.683998,-0.678367,37.993606,57.073327,23.138906,-137.890396,-253.457252,-228.751864,-108.610144,-60.157595,-25.924745,-50.041472,-170.895592,-319.227526,-342.40789,-257.786723,-207.302061,-156.833248,-144.12898,-150.739875,-170.757103,-259.695664,-387.994619,-418.067487,-391.95534,-346.405398,-252.788661,-228.844536,-202.108861,-220.171176,-237.717998,-199.218879,-152.388513,-94.552224,-68.51704,28.914233,62.570582,13.153287,-63.024381,-59.122921,18.625081,73.783674,89.920712,33.494728,-56.262085,-29.114311,-10.380965,4.84499,30.169872,145.18592,192.892722,126.567778,26.977518,-127.288456,-101.085292,-27.008213,156.182444,198.175737,113.38586,64.614399,107.998391,120.620211,62.148134,-10.3065,24.057055,157.552398,198.262228,175.346785,136.916539,20.366644,-104.980501,-110.384636,-47.651651,-27.196573,-15.996439,-33.880313,-144.044216,-258.521449,-272.033019,-220.070798,-184.368596,-113.645198,-83.382872,-89.388073,-127.793448,-222.022663,-221.447491,-174.342172,-115.737029,-117.471983,-81.863748,-41.640416,-38.656622,-166.912901,-214.263886,-198.891289,-167.862795,-133.079726,-128.910264,-99.566192,-63.349603,-9.414505,14.761645,44.199138,116.859995,146.0059,173.120774,182.355027,175.944372,12.635093,-63.8828,-5.233208,78.658401,169.812776,167.684025,53.707913,-38.541531,-181.811637,-227.019701,-192.931113,-11.356323,74.803744,93.992738,52.346152,-4.411273,-38.293364,-48.266543,-18.992527,5.332319,44.117434,61.60489,87.386779,100.306087,86.693865,-6.463012,-18.899719,93.026786,179.488953,238.705594,175.215777,-1.444612,-87.249527,-91.946301,-10.468265,63.667797,188.357742,222.278771,254.567676,250.708936,149.77632,-33.479415,-93.996163,-83.967099,-26.696412,70.236629,55.946924,-91.302656,-243.462357,-282.470573,-268.692326,-209.429912,-56.244892,-24.099033,-28.377084,-1.640798,60.794732,-31.100763,-77.200763,-43.975552,11.288422,72.194206,40.425236,-101.805288,-248.62928,-275.489454,-163.461166,-71.364814,61.122089,94.93171,94.645863,64.947184,-78.445157,-247.949014,-253.529483,-128.371918,-78.889215,-96.020077,-137.954672,-214.975974,-310.852426,-343.811182,-266.745863,-187.923268,-64.314879,-24.120059,19.539549,14.37493,-62.24683,-71.088581,-12.624999,107.120074,157.327133,250.923979,247.118307,132.117856,52.953837,53.944198,69.205242,59.982926,71.628199,94.263267,34.626956,-44.374509,-156.545165,-112.897024,-29.342781,133.255042,150.884365,48.111799,-22.777055,-75.474719,-110.863034,-121.473503,28.307844,150.093455,266.09803,244.814294,156.677807,134.601251,97.220609,-20.738342,-60.015024,-25.737608,15.090105,75.591937,99.196566,133.722021,62.143063,13.064328,46.413958,107.816234,187.021594,191.422121,127.932907,81.835763,35.463028,49.258383,91.226742,199.25153,232.58553,274.142847,281.43322,214.054189,86.778431,71.171182,209.164332,316.063624,430.552069,406.124232,241.890986,148.032598,4.862409,-67.144485,-62.595761,19.364678,55.527452,43.584812,24.50223,18.259856,-82.872651,-167.726951,-213.42677,-162.544884,0.887821,90.059835,154.337086,94.205575,-63.248982,-96.654603,-87.909014,-75.348264,-65.578654,-31.391961,-39.010844,-153.624999,-290.903438,-320.256693,-289.683413,-250.38425,-166.383904,-134.891128,-87.29405,-74.565959,-137.770721,-234.845394,-242.428488,-218.280238,-193.996115,-86.907631,-40.454126,-83.462115,-275.027715,-344.485491,-308.626117,-253.012855,-186.524594,-171.003143,-157.427301,-150.974371,-163.963502,-263.33253,-314.701457,-320.92162,-270.368972,-189.106828,-187.739335,-198.269024,-259.135334,-300.946973,-257.403462,-175.974289,-47.295213,-33.467954,-58.252184,-70.006666,-112.727576,-130.272108,-75.045306,93.491935,153.419748,205.266658,185.047555,7.677889,-186.767953,-217.553033,-168.01308,-106.480536,59.359468,122.15029,111.766662,49.717042,-93.643229,-175.367884,-164.136983,10.45525,144.286956,267.273442,208.288432,46.646459,18.698787,22.809303,52.394328,91.186615,159.240157,170.575451,164.156933,150.569044,124.371482,109.845497,79.917139,-38.476437,-72.780591,-2.101771,38.018395,-46.355942,-207.208979,-212.866246,-89.514499,-31.451946,33.148925,60.238729,109.526545,131.930786:-107.139159,-229.872933,-267.318191,-226.592135,-168.093628,-48.029708,-24.232925,-41.075184,-56.824745,-75.083095,-118.790872,-125.656503,-117.100671,-113.496582,-129.168573,-139.29243,-157.91396,-240.377655,-276.608779,-257.789568,-219.668371,-142.994425,-109.925536,-60.365282,-83.268159,-109.357528,-74.351605,-11.696716,81.553259,73.456514,-15.800299,-49.063582,-102.73307,-206.313538,-221.836404,-102.877804,-19.525713,19.558491,-37.208995,-162.063819,-217.608503,-240.693623,-216.974446,-142.617356,53.289141,102.681271,30.424869,-44.64916,-172.73315,-220.968527,-194.458797,-119.618802,-118.864398,-150.572939,-134.190605,-15.941102,79.924221,84.93745,119.145053,167.544701,233.994588,243.397048,221.932456,188.79173,119.079004,75.826183,75.845079,137.788189,180.635608,208.477655,187.004803,166.678944,200.470003,198.024206,145.229508,115.293781,63.980038,51.294587,76.965371,96.599587,105.212582,96.598006,87.785622,77.201442,95.55307,167.038082,185.812663,174.337052,136.898382,95.562749,26.709,39.845135,167.803459,245.132513,261.764446,189.567405,35.339896,-26.857385,-19.17403,22.174038,13.390196,-56.289537,-88.488561,-116.663409,-119.867917,-134.610402,-168.877818,-187.896644,-219.205919,-212.585676,-183.377531,-179.039626,-188.996921,-198.14445,-194.549789,-160.267048,-112.766329,27.04096,71.064981,80.459023,63.665528,36.73904,-12.339233,-2.257731,75.476588,114.04627,114.313699,86.194352,82.391081,177.66423,238.490725,315.895157,322.002317,316.64869,306.465791,222.152055,67.72685,-6.805287,-31.905514,10.127223,3.352551,-59.008858,-138.256186,-134.276911,-113.839963,-92.638448,-76.532993,-45.031844,-18.982713,31.837657,17.820818,-74.756576,-78.836518,-52.410232,-40.505745,-43.601839,-10.609635,13.106301,-2.771663,-22.916347,-13.40687,-40.859086,-60.074968,17.859958,109.182131,247.087283,234.374792,71.744452,-50.621585,-45.523422,44.916448,79.993918,71.599503,60.985994,131.789614,199.496233,273.138657,213.753719,171.246287,110.495946,111.238589,197.925246,222.858834,99.930297,-76.470259,-105.239801,-71.717088,-52.266668,-58.439941,-66.71175,-77.442002,-78.304337,-71.335717,-58.688503,-17.346622,64.606712,52.322311,-7.268696,-24.276146,-72.276303,-137.015917,-174.461486,-256.719346,-275.790394,-234.204923,-196.158111,-154.374292,-162.970002,-243.252883,-376.938049,-416.457079,-376.908899,-323.783349,-251.371655,-250.509276,-319.014424,-476.344507,-542.000418,-487.02121,-385.115802,-254.269073,-273.462863,-387.434181,-401.995395,-258.746465,-99.819064,-100.179087,-180.87696,-176.787821,-20.779016,47.177607,12.985495,-66.9901,-82.703189,-107.252817,-116.85628,-113.618765,-93.429428,-71.787006,-115.409408,-299.468799,-434.860051,-436.129206,-374.481636,-339.095987,-254.460682,-231.313203,-253.027226,-275.634357,-278.953185,-208.484542,-120.707761,76.268242,149.678822,147.748162,91.863225,92.28579,168.137329,127.936951,-45.64144,-90.205781,-56.06756,-19.764085,27.50112,-43.45055,-87.683068,-26.685369,29.054053,6.161153,-32.088076,-65.374061,-73.463772,-71.579654,-37.355851,-8.459484,40.520591,36.348274,-23.398335,-64.462128,-96.272279,16.264647,91.361382,218.117695,268.237314,300.853533,288.553535,266.91867,253.34153,176.956109,61.354807,36.343138,91.747598,127.34125,84.468126,10.956333,-117.491344,-154.115281,-154.957916,-135.089078,-114.005067,-64.687883,-39.299403,27.802099,57.30858,36.152741,-60.373896,-72.062585,-4.79379,14.209909,-29.014104,-46.601277,-19.741697,-10.520579,-27.202441,-53.874867,-47.999102,20.001456,59.188864,102.111424,120.465982,129.841355,31.375474,-31.366683,-114.972027,-136.410532,-153.09742,-153.569923,-151.825386,-187.129539,-219.384386,-195.838346,-137.77444,-93.182727,-113.478256,-114.582249,-88.303177,-61.62775,-146.906312,-208.492688,-228.606561,-190.259881,-192.507301,-253.162698,-319.274797,-217.566463,-170.89855,-125.68985,-91.541465,8.064015,45.718962,52.556962,27.559003,-40.004031,-91.844359,-91.764225,-16.357797,35.594069,132.159343,149.768536,41.912555,-132.494064,-165.661935,-79.741047,-10.434958,67.163428,83.697655,67.995987,36.856396,-21.463082,-101.704343,-111.628902,-3.099506,69.225286,154.664514,153.043958,108.263044,164.200034,194.201065,190.398058,204.751191,278.532225,292.297361,235.123628,208.018335,223.97671,191.537925,135.581775,37.863004,38.874064,121.12254,150.476264,136.912493,120.508544,133.062313,163.268556,180.891341,264.059088,310.256809,352.07849,385.79693:-134.867472,-255.439757,-279.27613,-164.107822,-43.947693,169.637003,200.090131,87.816329,-55.289868,-60.411463,4.034161,17.293689,27.504277,43.052909,15.042849,-59.709908,-297.742726,-433.211757,-384.455143,-186.791134,-130.940672,-109.421034,-99.539945,-68.69191,-53.045885,-49.702676,-77.394823,-97.567598,-52.744056,-3.571554,4.657934,-38.81296,-168.220866,-299.363528,-309.027933,-176.048965,-77.603148,41.034951,15.749784,-181.57293,-356.865325,-380.391005,-287.05242,-200.607611,-63.472723,-30.05423,-28.725491,-71.86962,-248.381874,-373.892118,-353.633308,-195.967784,-134.600679,-154.751523,-199.197887,-224.915893,-198.442849,-194.714038,-134.916731,-56.24336,104.073847,139.526244,130.589112,122.00882,138.652119,120.782239,95.843812,116.923566,161.619303,189.638943,152.718082,58.890607,6.670218,-9.649638,8.314814,48.602673,121.54916,133.385974,95.661917,59.662189,32.895281,80.853441,118.076737,225.441429,288.954851,335.115121,289.992978,161.858842,70.578227,30.09059,13.73532,51.122109,182.811239,250.788894,259.958559,186.861078,13.786742,-79.96784,-81.318968,-5.276104,56.699905,106.306301,38.241547,-177.777374,-272.413389,-276.835697,-264.78114,-250.815345,-181.150489,-137.62283,-141.511183,-201.224074,-342.41769,-345.505079,-262.399649,-35.466085,52.129306,107.358716,73.654886,-12.294424,-68.803081,-116.802279,-169.82152,-140.866335,-30.283758,19.67376,40.167148,19.772051,-1.106288,8.233753,35.531643,143.812274,198.125982,255.909951,237.837281,108.548652,-19.809029,-59.989471,-51.929409,-10.683061,49.420461,39.326277,-87.736098,-166.152536,-222.672559,-171.909225,-120.833937,32.645035,104.379071,133.304657,86.930885,-39.121088,-123.955497,-138.03431,-108.769438,-82.677468,-29.132813,-4.516293,-4.152008,-25.47982,-49.103278,-62.102867,-57.269424,60.700157,145.434899,187.908168,131.127136,-0.37338,-47.634876,-27.291466,83.881263,128.516207,115.864535,89.258312,105.410486,134.980196,112.28,-14.468696,-49.526916,33.921938,120.674599,168.333883,85.591745,-139.793114,-246.114523,-255.15083,-179.162557,-106.293158,18.83698,49.503151,38.175876,22.737585,36.679792,40.279598,25.789057,33.475424,67.126441,123.376064,108.763199,13.486503,-96.526245,-153.803902,-197.167313,-160.122458,-9.278871,78.078522,148.06005,82.772742,-164.318244,-262.956061,-223.431559,-125.758084,-109.235799,-105.576748,-112.492845,-168.063159,-271.290994,-318.752651,-315.54297,-262.035459,-145.180077,-132.147247,-223.078676,-262.749388,-214.724879,-124.507432,-106.824955,-56.777921,22.568622,203.445127,212.932003,90.794192,-6.597185,-38.832375,-77.766118,-81.07684,-31.800112,15.257606,16.888012,-51.996043,-222.37445,-247.036832,-182.537494,-56.432792,-47.878343,-91.156458,-107.222574,-145.846876,-276.851489,-335.800818,-277.00203,-170.198497,68.533469,148.744689,145.915583,95.767994,5.520604,-80.675335,-112.092646,-137.802432,-110.767374,84.39719,184.16335,167.583949,-35.034195,-104.561867,-37.647733,62.023816,169.042283,146.187877,44.606096,8.934418,-30.196357,-16.838681,60.746358,260.371699,287.366637,180.557974,104.459443,-8.540997,-57.392359,-43.827974,141.737765,284.889697,430.080599,400.819008,258.886365,179.265107,-8.699245,-164.724027,-153.110379,18.998277,86.699381,43.850929,-47.695517,-198.159929,-208.341449,-200.994646,-176.593346,-156.595084,-87.469258,-25.431121,49.882887,10.892761,-159.130942,-220.444881,-172.01228,-20.717936,32.089999,48.111701,10.604766,-125.055894,-251.326663,-278.551584,-252.79075,-213.783083,-75.522298,5.37582,55.860947,24.882741,-59.408157,-183.059379,-231.181184,-204.980318,-151.193867,-76.29691,-77.226072,-156.054498,-317.608919,-370.833333,-290.802897,-205.242215,-118.289067,-110.876138,-104.561919,-115.325359,-188.680171,-222.761232,-213.996386,-221.593248,-221.551626,-151.036136,-121.767681,-179.403689,-259.957303,-252.868326,-178.50176,-136.792492,-24.0176,46.711439,88.853173,29.67991,-136.573548,-182.948185,-136.845773,51.395263,144.51682,198.975271,142.993912,-67.748098,-250.934376,-273.070416,-123.847221,-11.01525,101.451705,98.980029,40.213655,-7.145766,-117.321455,-233.681779,-250.255716,-127.442258,-23.878718,151.247622,195.102669,193.182053,117.693671,81.095753,86.583428,118.537998,200.424035,244.602169,257.90054,217.242873,106.782628,41.598901,31.396123,-8.45189,-22.948203,15.623024,25.33373,-50.276462,-89.723784,-70.558556,-11.46009,22.553051,133.126139,196.123382,252.756075,263.106224:-76.544671,-132.885657,-146.778057,-116.705568,-75.052343,7.853919,18.605991,23.617895,35.822501,-5.58003,-144.276427,-166.216372,-112.582815,-105.284305,-195.636404,-243.737685,-239.199883,-219.165581,-215.210412,-162.862884,-129.253497,-65.667486,-32.655338,10.592359,-4.301352,-39.718799,-117.221876,-125.419892,-88.056114,-74.219394,-112.420217,-169.547863,-314.944413,-375.05286,-336.709937,-164.656496,-77.912285,-8.327493,-26.085272,-93.02703,-167.494398,-192.008018,-167.593035,-129.96318,-16.887348,47.353059,60.816907,-3.727062,-130.740734,-138.74467,-105.256445,-39.609418,-39.810859,-47.595188,-12.688011,110.550879,231.939492,263.602327,253.954132,242.450056,246.990215,254.125694,233.231031,211.925441,210.036135,246.729398,266.230121,326.117703,377.435602,458.883668,437.432465,292.569405,183.531039,141.808682,72.238177,66.164296,60.059097,35.213104,30.251104,79.059402,177.379432,169.977677,155.621557,151.845432,152.190007,161.304223,164.131633,143.876671,146.355312,135.901281,55.924385,43.257366,178.972215,268.731309,282.991222,211.729432,96.676661,114.93965,115.889259,26.925954,-18.684176,-43.647774,-48.848211,-57.233275,-54.341225,-76.876077,-146.17085,-158.84695,-154.741847,-170.907184,-224.01988,-226.364301,-191.375238,-189.715323,-193.259755,-191.342293,-179.488553,-59.838593,29.799126,143.460082,161.523133,142.824677,75.847107,57.677627,131.579944,212.319366,264.040219,218.715964,200.368063,286.659829,292.440872,198.346248,134.334308,115.929107,151.400069,122.392319,-47.315551,-111.581495,-152.07606,-169.139927,-246.70388,-269.27623,-207.302716,-154.042018,-95.795885,-75.037899,-69.418602,-45.774679,-10.725195,69.172119,75.67841,28.112033,-17.427532,-45.491749,-99.232088,-103.109641,-85.670139,-86.01437,-102.712007,-92.668642,-38.091796,-74.976379,-97.386494,-53.423835,-10.392566,69.904979,79.891039,-13.130867,-115.718441,-119.091984,-86.361649,-110.319404,-241.356178,-281.804629,-214.159295,-117.117014,71.596562,66.367586,27.879939,50.58002,109.218165,198.122325,177.663828,62.297006,36.233602,43.25135,36.262477,23.506812,-37.299666,-65.630448,-12.728326,54.121711,88.80378,-23.582413,-42.833672,9.856754,35.574473,111.401527,172.552992,233.272522,158.857093,84.969191,-95.647809,-173.96582,-253.418425,-250.704022,-210.242365,-199.299282,-227.414552,-287.124389,-306.355247,-310.811241,-285.182873,-189.848863,-152.947268,-171.962156,-294.835079,-350.876155,-355.557526,-316.660182,-278.849261,-287.804744,-279.731406,-261.259085,-256.789102,-265.809391,-258.848153,-233.25187,-211.476251,-154.292225,-130.205262,-104.301425,-90.344444,-105.581214,-206.720994,-251.700341,-225.059637,-175.793338,-212.952849,-337.045566,-599.558115,-651.418885,-602.158769,-450.32036,-395.647825,-343.627037,-315.274402,-306.968919,-432.575195,-466.028871,-349.467811,-251.741256,-122.536403,-88.599528,-59.018373,-81.088924,-156.157874,-122.26366,-77.469186,-29.401738,-31.705256,-39.495105,-37.505827,-9.647801,-14.933154,-41.286145,-14.298499,29.803124,11.558828,-46.599518,-83.583078,-47.108402,6.252659,-33.258232,-34.33841,54.413682,83.6346,-28.47854,-123.354753,-158.025737,-4.733793,64.309879,152.99823,196.983812,296.700845,326.751917,305.743563,256.21239,100.342136,27.125856,46.872161,103.508139,126.999173,156.895779,123.14755,-47.33579,-93.967949,-40.751972,69.387358,73.099015,5.328536,-2.633821,58.276572,77.410915,52.379046,62.645688,103.518166,171.07639,176.28862,139.931513,99.745928,52.16904,80.037043,58.647579,-56.263869,-79.587365,-31.529096,-7.216205,8.821204,13.501425,15.011841,-15.546839,-40.824446,-134.642202,-176.576568,-120.173749,-57.273835,-21.529668,16.322598,71.373933,130.656241,107.877248,29.726337,17.07016,66.263314,98.734801,106.63171,16.083173,-37.218567,-39.550959,0.59134,12.440768,-34.655442,-119.766227,-72.014227,-21.150182,59.495776,84.611923,103.469565,99.402839,48.321263,3.516327,-32.663518,-29.012084,-58.356187,-110.561248,-86.724585,32.988684,42.808268,-173.553435,-407.461376,-402.673616,-212.610247,-122.22086,-80.192498,-106.171033,-136.408415,-113.31337,-69.700694,-145.345502,-182.466709,-162.576552,-115.600796,4.413773,48.260367,72.723893,76.631929,71.841571,48.645032,55.316754,123.714976,147.063285,122.669155,116.63686,163.656833,179.512834,163.489755,127.302955,129.509556,190.762026,215.855078,195.674533,180.897937,197.038643,232.667828,252.66835,348.515811,415.247905,461.114323,433.68618:16.200242,-94.201385,-146.003571,-127.525528,-81.823988,-67.088845,-103.490947,-117.4197,-62.55282,-81.687649,-167.521893,-188.532858,-187.351683,-172.471613,-171.718339,-194.933654,-233.265016,-262.952813,-250.890999,-137.392576,-94.622528,-108.249848,-129.843389,-169.827475,-199.419341,-203.730764,-177.257695,-153.197313,-126.220848,-112.44736,-80.693669,-97.614848,-216.012693,-312.460289,-284.138097,-51.607157,68.354174,115.530875,63.962749,-61.624162,-194.136559,-235.154432,-154.288087,-54.432185,77.834455,72.243326,-20.553718,-64.212909,-87.809343,-31.230859,5.051511,45.309897,53.965168,89.734933,116.410711,173.239364,232.052621,267.198893,355.596678,371.916652,282.230519,237.093302,240.466873,235.848746,173.36531,126.070634,125.417513,191.150154,248.824082,358.763651,384.798113,368.972596,326.429676,288.370871,174.831132,121.436244,50.558957,45.354094,76.24335,86.157639,92.139015,56.999446,13.360128,-46.081484,-36.843055,26.55588,57.55236,72.690021,13.849233,-21.94243,-29.16598,14.990028,131.248958,153.410609,74.38227,23.049908,10.754452,2.610951,-23.3346,-54.94955,-49.999976,-34.118457,-46.522443,-64.52279,-24.482816,-18.395097,-66.136213,-120.068271,-234.618522,-248.343757,-185.819185,-155.416101,-186.335922,-280.860395,-296.358814,-233.728604,-170.938659,-25.616989,28.118643,51.096651,45.902225,35.486336,-8.491151,-17.650184,-2.792683,25.595995,140.349439,198.360696,254.854959,270.102757,277.0273,250.9402,223.75806,230.60175,248.963068,188.069936,67.36647,27.412729,-24.39098,-39.633549,-77.896628,-101.565198,-134.004126,-151.690239,-173.120036,-95.337985,-34.12593,-5.268953,-39.50189,-65.372789,-41.491087,0.430599,-34.90923,-64.747152,-33.782287,19.60701,38.897789,-9.528532,-62.204154,-19.125455,98.917837,81.675882,41.114383,27.699727,79.70984,226.62528,256.360593,187.27638,134.352786,126.934899,69.5419,32.94354,4.233427,5.145858,42.892379,105.268821,256.05856,239.1516,179.421521,91.356853,77.422644,111.706192,137.937625,131.456721,83.664024,71.081259,76.88793,76.765403,28.631724,-12.620953,-76.286865,-79.710894,-44.427863,-28.959794,-17.079537,23.583835,22.277856,25.104167,65.325787,133.345262,35.865268,-46.214335,-176.984042,-219.700815,-278.106245,-282.271829,-216.408603,-180.816368,-204.10606,-312.881714,-349.292522,-358.355619,-335.457544,-204.743167,-141.547159,-189.730566,-375.824995,-443.323793,-453.264055,-399.070423,-265.017285,-232.40298,-254.634606,-262.324607,-176.832076,-123.779278,-175.252991,-270.40313,-228.985048,-58.436692,-23.60567,-58.814058,-79.2092,-80.502982,-95.572532,-109.814789,-96.231667,-41.842407,7.238807,-90.310862,-411.583112,-512.481757,-450.211292,-276.513929,-231.93536,-210.434076,-185.424136,-98.21009,-119.573881,-165.392954,-132.080216,-46.885502,98.89873,125.280965,119.34785,105.609258,59.545522,8.633709,0.79606,-3.975948,-14.833253,-0.773498,32.858221,90.007179,85.422495,62.419718,65.224146,90.870167,61.145465,0.210885,-104.776909,-117.299033,-79.114432,-68.867117,-75.118218,-66.410159,-53.298796,-36.5003,-51.417242,-117.548325,-103.042293,-57.689923,39.840038,75.914474,135.305022,169.934521,231.312971,250.633066,211.273518,85.090126,65.863012,145.457769,177.625536,120.950309,47.971395,-62.377819,-65.304703,-64.09348,-38.528904,23.370162,145.053214,145.89646,86.24972,76.28042,99.660669,79.165825,89.132333,219.246385,272.89163,237.423511,182.414768,122.698936,145.281698,146.690628,126.459664,129.503772,158.367969,186.088122,272.073105,307.304274,318.098029,208.635049,120.759412,-18.508434,-62.8295,-134.921271,-166.516439,-189.043997,-109.194328,-46.262467,45.179458,53.688223,27.889057,28.8156,90.907345,130.125318,138.304408,-27.167183,-134.724322,-237.885041,-233.376833,-221.400951,-229.140301,-198.930271,-130.308909,-126.876759,-113.899006,-78.812582,8.386676,54.95599,101.741386,75.645918,-21.538169,-113.961208,-146.254945,-111.808804,-41.435456,133.007402,184.023439,100.160543,-125.267748,-202.349931,-214.001179,-164.475939,-71.430845,-71.85533,-120.067219,-102.437145,-4.335814,-91.899758,-163.590765,-130.592977,-49.463833,79.212055,94.734371,57.216671,39.459169,62.304983,172.293265,222.618059,253.67195,238.38301,164.097419,130.878098,110.167001,72.513808,28.742526,-49.832699,-56.121321,-10.430037,20.020407,86.834651,184.533682,233.136891,281.414975,280.992292,313.002023,360.025344,418.345142,421.326358:-199.901201,-244.424765,-232.629343,-113.335694,-22.24129,96.621462,79.620208,-12.208478,-12.140881,0.349849,-6.311292,-15.685984,-5.278921,-1.63463,-114.357154,-207.471872,-278.896415,-211.061675,-176.977342,-151.331469,-147.698279,-72.172455,-14.298085,-1.206635,-72.704561,-98.611863,-139.560821,-137.733252,-44.586756,10.727649,-30.251498,-124.917132,-283.347443,-291.920994,-248.908588,-137.814565,-93.968009,-95.567531,-151.348898,-210.610639,-191.556929,-215.94537,-211.870267,-158.623854,-60.879945,-45.133594,-67.919575,-77.188349,-85.758095,-165.444335,-200.483446,-187.405185,-160.444074,-93.265246,-50.492284,27.245291,92.912444,118.094196,185.482417,217.056945,153.447257,95.685157,134.099442,198.759952,238.3741,191.929492,176.494411,234.941,312.292051,409.273845,369.14198,220.04199,181.521305,175.116986,110.453084,66.895784,37.07344,59.663207,80.834596,58.469082,50.563091,144.474699,191.825379,230.238028,219.794038,191.327905,183.896403,149.630295,63.298139,19.606136,44.237509,117.520127,235.395398,243.447014,216.159782,202.283191,144.050257,42.152919,11.045262,13.855425,29.551097,-2.421584,-59.299027,-132.45952,-139.328887,-160.25135,-169.765568,-133.096016,-85.881418,-111.634769,-208.911292,-239.203558,-225.572028,-189.495674,-178.139637,-108.213457,-42.498694,64.545246,80.403513,60.471869,46.557022,57.584259,88.230031,77.449215,65.417857,114.547815,188.605481,149.360833,50.52467,88.956241,129.395523,189.041681,216.956082,246.226144,223.994905,141.814885,39.009961,-28.123465,-91.034246,-67.37283,-30.048223,-48.719209,-144.870066,-198.483913,-225.808004,-166.835799,-132.865376,-52.901466,-3.677346,51.862161,24.505203,-54.142185,-48.272892,-57.476089,-118.607411,-128.825719,-87.102087,-50.690682,-9.989726,-25.978194,-103.320979,-178.430934,-171.319162,-28.9021,58.946406,143.784167,116.23724,-17.870365,-81.964404,-81.275317,-47.712882,-41.290739,-88.302383,-104.930396,-70.167311,-41.0764,-23.793569,-42.359326,-46.222424,-9.984792,40.497478,153.863507,164.80638,42.961475,-104.325934,-149.595387,-181.606226,-152.713048,-51.382266,-13.901231,44.64674,69.992677,59.753157,-35.586274,-66.432482,-7.978763,58.595656,170.706098,194.722651,154.380315,25.696567,-35.592254,-86.421232,-93.07418,-125.668253,-137.440522,-139.51927,-152.714485,-245.29045,-334.258298,-317.041959,-223.106085,-208.032732,-206.744366,-176.274026,-131.600099,-289.706239,-404.261872,-461.184227,-385.227046,-237.194155,-237.676957,-342.374801,-374.584064,-298.611117,-205.49732,-195.839315,-165.936118,-129.18156,-30.148255,4.527479,-36.601169,-141.320774,-177.471435,-215.370084,-206.762467,-160.644332,-168.244187,-311.145521,-406.759477,-493.742015,-426.543113,-364.422736,-305.068662,-322.022382,-302.878714,-265.589438,-302.576941,-433.99586,-442.310315,-309.874927,-227.295174,-115.260971,-65.066602,2.966068,-6.93062,-65.189366,-103.297893,-91.111935,18.412799,63.305249,80.324283,91.823573,131.366087,69.677563,-1.410162,-59.442163,-21.727098,11.460947,-31.568951,-99.876226,-74.607942,-14.938511,-36.448735,-7.337314,121.022096,147.761526,94.843667,52.144437,-42.151734,-95.856943,-54.242684,132.56442,199.066574,177.1257,146.101835,155.300234,142.145204,2.387671,-99.1562,-104.010383,-62.128202,-27.956232,7.865893,-17.61872,-129.05825,-179.386911,-175.822894,-176.317086,-170.881742,-107.823033,-66.231582,-21.532867,-30.36212,-54.239642,16.762308,52.202053,10.383161,-28.753527,4.809968,33.614619,-24.603173,-52.929198,-47.740207,-111.766311,-144.941217,-115.447476,-68.052469,34.042411,78.194105,88.797989,-74.791194,-153.166448,-169.825616,-139.890688,-74.326833,-67.965011,-142.575336,-172.866439,-160.552633,-141.52747,-139.446124,-134.998102,-104.215327,-19.130962,-17.278631,-87.451966,-179.100266,-213.301017,-161.193209,-96.350354,-51.271122,-94.132471,-167.353271,-48.579409,15.181034,26.646075,28.267858,124.777553,164.215756,65.961779,-27.239235,-101.623733,-74.421693,-41.151833,66.904293,105.893935,108.076365,66.089803,-103.691768,-247.031604,-240.534817,-89.849653,-11.427984,24.722355,2.145766,-38.059784,-64.821235,-151.244419,-239.711303,-249.786589,-165.027609,-101.602213,39.618838,116.182307,180.224518,120.840409,92.266351,92.046861,124.294275,193.796505,195.836119,141.521981,130.361777,165.099038,126.876814,59.003541,-76.899384,-81.99812,38.483244,80.386027,67.982484,98.257317,116.634406,139.65545,181.662284,265.54141,275.325742,299.722763,340.253765:right
39.456145,53.791035,69.586748,83.656359,43.497747,-67.661709,-75.122484,16.180319,107.120811,102.11262,8.398808,-23.928783,3.037272,34.594113,44.77314,15.458472,-33.641844,-16.180606,-11.154563,-70.54537,-145.376274,-322.967196,-370.696117,-293.364445,-50.785701,42.764098,40.835985,-20.341733,-81.409122,-44.637002,103.569521,157.011447,154.01809,64.70123,22.61818,-22.2672,-41.715164,-73.020774,-72.518809,-69.250061,-20.02884,51.481976,157.26384,125.533493,-31.32724,-66.546221,-3.302227,36.391101,61.180063,43.822566,15.788935,-49.845031,-74.059462,-81.158095,-60.576092,-24.951499,18.788514,41.173924,-14.723763,-81.863449,-172.386176,-161.753725,-50.54368,15.481367,116.334027,79.304243,2.854774,-117.142229,-118.437257,-49.148977,-15.789783,25.9658,133.44982,205.994786,203.855252,115.184908,-59.92223,-83.932904,6.147361,81.265769,158.845733,65.664125,5.898656,15.171959,56.702099,54.084879,29.09871,46.143608,115.885683,131.690185,106.487644,83.182106,0.187329,-55.693784,-80.617203,-43.293406,22.901214,-11.193309,-45.585712,-38.501587,-10.373578,-23.488772,-61.01176,-111.251657,-56.868651,15.658446,172.899624,202.755088,108.971154,45.922174,77.340245,152.878628,230.535216,107.784059,15.012761,-30.429228,31.334296,144.489083,154.762618,119.555168,78.55745,83.344842,148.442891,174.306877,88.775125,4.408613,-33.326554,31.380311,218.587469,294.838375,259.647658,129.495889,74.116839,12.831876,-18.85981,-86.532783,-2.419265,87.429413,177.55398,146.654991,18.011196,-23.534465,2.53986,52.195464,175.033784,241.4467,228.069261,157.243879,121.060441,53.20072,31.292214,44.041927,122.574812,176.037403,244.673094,229.805326,150.003277,123.027271,113.530557,135.815809,225.723842,237.862003,206.1267,165.788492,131.332664,38.447387,45.746541,94.549525,41.049336,19.756876,2.87146,-20.422633,-127.346663,-184.594667,-182.572738,-128.645138,-69.972044,-98.636242,-91.935252,-108.04143,-159.88872,-171.215781,-89.882142,72.298389,77.10941,51.957809,19.328567,2.595786,-81.454968,-134.461383,-180.988253,-161.370017,-43.308431,78.358543,98.299388,79.56567,54.228621,7.275492,26.909252,149.471661,235.344232,238.554779,187.506287,147.927505,37.503951,-21.523232,-71.619528,-69.499718,-27.115101,54.624264,56.126455,7.735787,-17.659189,-75.261791,-73.622116,-24.960747,-65.730663,-120.404654,-230.66054,-242.320959,-146.122504,-100.971682,-121.973711,-140.089738,-44.088136,137.224525,180.346504,163.608826,117.764362,-28.560067,-77.182799,-17.645051,101.100578,80.21943,-76.728478,-119.940695,-115.994587,-133.946519,-270.632016,-333.073004,-281.374477,-99.41124,-65.380321,-150.359735,-219.16309,-303.721573,-307.01829,-292.704947,-287.467287,-263.599332,-184.858485,-169.523332,-247.650353,-283.551725,-153.245482,-17.901182,158.701309,150.618651,118.543235,52.797668,43.723884,100.456001,142.118557,176.105066,188.976613,205.769164,148.036322,45.144296,-228.814035,-336.857113,-350.650794,-248.823251,16.220865,103.278066,48.218354,-111.378843,-149.593992,-91.020932,-7.162744,160.227964,184.926181,132.205388,-69.978002,-184.530755,-276.149392,-217.807757,-64.345895,-45.2652,-18.129593,98.655725,118.738596,53.432245,25.15743,44.985338,89.524692,275.137547,488.905777,483.543643,225.568179,105.756507,66.573628,90.127232,62.677267,22.96002,-14.204649,-39.174892,-90.874288,-212.70208,-232.816174,-177.64725,-125.311997,-44.797427,-57.890185,-84.96164,-131.205013,-143.485613,-151.807751,-129.045716,-15.017123,30.375983,81.385355,121.321973,95.802568,-35.98901,-91.762304,-109.343004,-78.805997,-13.661927,-4.999657,-20.592262,-76.323117,-106.910295,-150.850101,-151.720675,-126.2327,-132.24983,-166.839515,-154.751099,-166.229327,-268.685171,-331.829477,-377.706017,-348.620733,-255.283869,-213.826336,-228.017947,-298.530426,-336.834061,-368.968457,-339.922274,-188.530709,-111.565784,-44.647963,-79.906198,-115.336819,-171.508286,-198.837482,-250.235421,-242.599555,-169.327589,-94.153396,-60.584426,-48.573429,-71.729131,-133.361764,-165.575645,-243.231021,-293.657871,-328.024714,-169.36106,-92.44689,-130.781134,-216.47886,-283.826144,-228.893797,-78.123022,66.066038,160.102584,270.190312,243.775482,127.595797,96.649784,152.844125,218.817254,326.543554,378.020299,403.125021,394.951947,299.169434,16.922752,-62.688302,-57.518826,70.341014,129.965662,108.636934,47.442618,-57.649664,-81.40066,-40.435524,16.569634:140.403236,135.136587,110.549837,88.525865,58.427489,-12.317844,1.704219,144.893709,265.787345,251.097467,120.112705,49.892498,-33.272225,-24.680882,88.209025,146.998127,180.803698,184.863898,164.050746,-11.857436,-118.067888,-182.583137,-146.008434,-48.275871,77.13359,151.907072,172.710297,82.366161,-117.449796,-119.565802,75.313369,173.252041,209.115159,104.977867,67.581774,23.010311,-14.554375,-63.924714,-58.444794,-29.110147,30.468859,55.293845,47.229785,22.457436,-51.123191,-77.065164,-59.012264,-19.320123,68.464681,55.923472,8.802116,-69.862964,-84.799949,-60.985764,-28.037842,-1.280875,-28.983363,-48.797038,-81.641186,-101.279848,-200.168474,-247.281743,-197.320049,-106.412738,92.405626,102.365463,3.250749,-156.026797,-129.689599,37.210886,82.953561,33.733824,2.54479,59.530464,192.362007,160.783217,-79.930141,-159.89058,-114.552132,-46.583776,60.49596,66.894278,30.807306,-31.230395,-33.468763,-17.233738,2.35588,81.671955,75.160162,40.055023,-12.819493,-35.437508,-104.227349,-126.481942,-73.412746,-38.910619,-48.485552,-84.232354,-79.217003,-58.611672,-79.825391,-157.564606,-172.861272,-133.263544,-41.419567,14.832389,114.699839,121.189167,14.875712,-37.14921,-3.429482,58.207519,110.920884,14.519456,-21.069546,2.889121,28.36095,59.821392,74.801238,113.090063,113.255645,94.514153,56.991569,35.542225,-44.488074,-73.426361,-20.975489,46.213407,216.245208,273.134698,210.315205,40.786487,-12.754958,-68.104524,-81.99633,-54.620997,34.441928,68.184486,101.076287,82.069511,-64.991809,-124.43818,-80.416063,-10.336829,145.487096,211.972816,174.011863,61.590647,35.177888,42.875118,55.128271,100.14311,200.061775,224.57309,180.645888,140.033638,75.07022,40.595924,-19.481658,-8.822788,82.831045,90.529255,52.076299,24.1774,36.111731,54.812228,61.737403,53.921749,44.297701,40.306408,11.869182,-1.263165,-57.925618,-110.876988,-178.705623,-178.238828,-141.545746,-91.277752,-91.454862,-170.589036,-219.052139,-217.7643,-155.974914,-27.534258,-25.346945,-42.03051,-7.561577,17.249153,-41.920052,-91.936256,-91.335897,-53.356352,13.197579,43.189743,52.020674,57.390297,36.640217,-18.868332,-8.784557,94.975127,221.931925,232.461469,98.621173,14.588486,-82.600666,-99.608266,-81.075013,-65.148087,-65.36238,-48.596874,-36.012643,-53.548881,-103.420082,-219.183692,-209.164264,-38.028154,69.099667,33.897182,-104.941582,-138.336147,-120.497977,-116.167934,-164.903145,-179.734284,-43.426066,176.830368,195.160995,72.602187,-14.124361,-123.908151,-84.591929,129.78651,242.896412,201.641469,0.970493,-67.977854,-95.695762,-110.172076,-171.808721,-185.702227,-131.280788,-72.308548,-76.23787,-143.733298,-205.407785,-272.022356,-233.628879,-111.815889,-85.031145,-103.991198,-100.810987,-71.535887,-120.418137,-187.514017,-90.474175,66.626585,240.277931,180.496787,125.904458,6.904609,-16.681905,47.583009,99.474824,123.849664,27.018702,-5.334299,10.576722,3.357965,-171.952925,-286.635376,-344.863696,-271.495812,-63.288395,-2.001039,-40.705109,-152.042815,-190.933441,-150.446123,-56.263967,131.6299,131.025775,74.740907,-60.018002,-123.22547,-202.545931,-202.341603,-150.414515,-113.12623,-27.770048,40.5721,61.271223,53.393625,34.646719,20.565718,45.892312,264.021444,519.158018,471.556412,125.131211,16.190664,-2.791145,-6.15161,-51.313947,-42.611076,21.701462,-64.955847,-154.664162,-302.157311,-336.643884,-262.66847,-171.266251,-91.45193,-207.415931,-242.187828,-221.167816,-233.559278,-321.720662,-325.419698,-213.953645,-150.050466,-48.776097,6.09684,10.484158,-18.262007,-45.792182,-47.805487,-8.295927,57.468327,38.608758,22.067605,-22.709756,-69.829288,-133.253158,-101.871782,-20.269188,-18.728331,26.927405,100.67244,48.710247,-136.711844,-174.966156,-125.105696,-102.996665,-134.370816,-187.253582,-206.168836,-245.088202,-274.987415,-324.636435,-318.736569,-270.388669,-256.1186,-206.175756,-149.977259,-166.810879,-264.911026,-307.666519,-303.751731,-248.830675,-122.231587,-79.985685,-70.209655,-43.224398,-70.543158,-235.135248,-291.737493,-239.832899,-184.102741,-125.734546,-124.57669,-131.902794,-156.882492,-182.471578,-223.643168,-208.624718,-82.026904,123.50694,212.356593,284.388772,256.149126,130.02297,91.763929,206.40051,335.673966,460.528207,325.645957,259.796535,156.803514,76.453045,-70.198858,-94.288606,-67.207436,24.062231,61.838924,12.767601,-47.669828,-76.639226,-34.730719,54.803653,80.049489:160.08164,199.319516,155.084035,77.682285,58.996112,61.629188,92.267095,186.411498,226.804907,203.055901,111.777723,52.22353,-41.955701,-19.141755,158.07857,231.979812,281.070676,318.972151,297.692008,70.436695,-52.395054,-59.87031,12.590755,114.148807,206.920418,234.318534,160.665631,94.099589,38.494956,61.449593,130.061518,137.990047,120.245139,92.59848,47.595169,-77.338003,-107.524878,-93.886746,-76.416895,-48.340019,-55.301402,-74.88001,-147.882045,-196.161258,-242.734312,-224.589897,-171.130061,-155.217825,-118.616915,-148.700681,-210.390031,-301.852417,-302.29936,-271.927968,-255.478652,-173.933128,-83.790192,-96.097551,-191.497569,-227.596046,-239.191999,-204.409123,-98.823754,-77.107959,-71.549595,-24.592282,-33.359556,-123.673365,-135.668094,-65.982468,-36.531824,13.685514,125.753601,164.06195,128.208938,66.776753,-51.834083,-70.43258,-25.983644,7.250409,40.025311,-24.72365,-71.965196,-111.63995,-101.156994,-10.769537,55.982113,121.517356,64.886745,23.116445,-42.37774,-65.991655,-109.450556,-114.516837,-31.241437,24.213092,30.320998,-90.521729,-145.140574,-195.572823,-223.182455,-290.171123,-296.061211,-225.979898,-67.689762,11.619358,46.621957,-14.041247,-159.982493,-160.636297,20.000327,127.038761,177.005133,35.652889,-22.328938,-42.400458,-19.8026,81.061384,143.233043,191.136008,147.041646,145.99512,196.937767,190.577369,59.840262,5.766791,55.242846,119.183346,221.970858,282.143057,262.331608,111.913721,48.071007,4.226065,-23.935772,-78.991715,-5.285347,49.117962,111.586951,94.909279,-41.77302,-77.121166,9.245729,61.656387,152.790246,250.928404,241.496975,88.039774,22.675267,51.604365,106.080927,179.285814,239.152419,254.007664,177.539523,97.25006,-23.367997,-22.273683,42.803063,49.964994,2.121383,13.116932,58.224293,141.846111,141.977699,68.786579,39.303982,67.698825,147.185376,142.299814,38.210385,-9.271323,-50.923932,-53.769003,-30.680719,-11.868016,28.3543,15.245207,-26.5179,-136.927286,-174.884466,-179.519477,-157.459882,-82.083252,-6.520627,-2.323624,-12.801259,-0.957121,-12.802849,-41.567442,6.071226,98.033749,208.277714,139.025667,111.215144,82.772956,64.573371,50.162856,62.830203,151.354376,212.88909,168.333804,47.592953,34.290334,28.707351,0.884499,-19.402728,13.219547,95.812783,91.088798,41.708027,-68.911956,-105.704794,-151.605117,-158.959438,-109.47125,42.981122,79.257581,-36.216218,-124.793196,-227.926892,-235.798445,-183.069361,-131.608148,25.358236,129.04127,100.051214,-32.39567,-54.708163,58.836796,138.263071,201.193883,179.816404,138.624874,-4.534465,-57.661502,-86.842335,-93.842017,-124.726577,-144.790214,-183.615458,-152.194994,-109.42595,-107.962581,-166.326426,-272.776452,-285.78362,-240.594176,-117.918925,-87.030105,-118.161867,-113.29612,-78.758898,-98.140051,-93.538502,-24.353383,78.671912,37.390516,23.575196,14.297284,-14.223142,-118.669658,-146.316722,-73.465982,16.895008,13.461037,-31.028092,-60.392065,-173.480139,-221.619064,-213.09619,-169.689686,-28.942984,72.458389,54.979104,-54.485694,-102.968426,-110.493288,-55.714027,89.248491,147.280799,113.243865,-36.633711,-108.669108,-220.642088,-239.658074,-151.790087,-89.679731,-59.531021,-59.49527,-19.002924,26.440686,-1.035128,16.739611,105.682457,366.191111,558.356642,500.294362,154.289148,18.764452,-107.903595,-136.794541,-122.013148,-76.292489,32.278704,-66.173048,-202.659249,-346.439642,-312.060644,-227.267739,-219.364556,-237.801498,-301.781887,-315.707587,-278.5447,-285.989735,-407.267263,-461.462773,-414.771197,-316.473887,-97.736213,-39.846356,-69.907288,-160.701542,-193.390191,-110.529088,-11.658901,88.148446,60.194753,54.211074,2.197342,-66.514377,-159.024264,-130.070915,-19.402596,16.294294,96.788313,138.157113,109.318392,-6.023878,-63.635352,-121.22782,-135.045312,-146.942698,-87.659759,-66.782057,-154.796426,-237.354394,-324.970379,-318.087238,-280.747508,-272.304822,-262.363238,-217.322488,-221.168319,-343.362253,-380.733756,-225.283611,-101.27212,-2.057277,-50.789481,-59.521564,-10.833161,-15.593115,-164.87248,-222.146395,-163.404074,-112.565516,-89.280826,-119.470684,-141.449694,-190.055638,-199.117061,-142.446192,-93.627922,-32.489061,57.569756,135.433316,236.295743,223.036036,118.254498,83.370205,170.058681,273.24693,385.642145,230.178049,131.59546,41.191221,18.473817,-70.916933,-120.952936,-121.516868,-30.640837,-4.956064,-40.579236,-101.195491,-191.731253,-167.282204,-23.888176,46.618718:54.460551,73.38731,77.651902,88.357091,57.763669,10.427197,70.163311,250.59712,219.485302,145.633798,65.893847,71.401765,97.691995,95.050109,88.655323,114.507875,193.29632,202.267642,163.635175,21.738302,-31.237944,2.330632,57.955648,126.537597,147.908674,155.436412,126.797335,95.467624,54.923374,49.589847,55.018158,68.280975,126.416137,176.806617,158.896615,37.769997,-15.594299,-17.3659,7.345305,3.114198,13.63064,55.208813,82.482807,40.204225,-53.772364,-66.92439,-57.867115,-58.4242,-50.174584,-86.093313,-153.025208,-303.734147,-348.814154,-332.253557,-270.321567,-122.793172,-42.082675,-36.145363,-101.44249,-155.247228,-242.946138,-243.92314,-110.464003,-34.358897,38.317435,7.834288,-71.113735,-208.23797,-197.903719,-86.417269,-34.944734,41.909511,111.405208,137.130595,133.181646,91.189634,-32.588221,-63.725597,-36.90066,2.673988,109.662797,116.646053,59.120461,-56.919001,-68.168831,6.710404,58.600336,90.833409,40.109608,17.007476,-6.347468,-20.855457,-106.846601,-148.622843,-90.479264,-10.419074,77.517063,42.786996,24.343667,-12.749771,-56.199391,-145.365911,-151.343154,-130.336356,-93.828085,-34.772659,68.524118,68.034679,18.076259,22.994662,153.960816,227.664511,267.848529,224.378605,204.334545,190.668163,180.21908,146.960351,151.360281,199.915678,207.136299,183.029907,130.361825,128.858446,126.756566,87.021905,11.316218,42.134722,224.153922,289.21579,228.65933,48.5466,-17.893268,-92.588285,-117.018616,-102.331128,1.954988,39.172271,33.266608,1.603133,-93.478649,-137.840149,-117.663126,-44.484846,120.773987,186.478954,170.199751,109.284067,85.911934,54.968463,64.754396,153.587981,246.82985,244.888377,118.274987,40.46705,-4.15582,37.330135,141.589891,167.707171,212.163261,239.950876,220.991998,173.515827,157.224966,126.030341,128.617194,202.298792,319.721591,337.860621,207.228051,97.947439,-57.140522,-60.597907,65.41741,121.863028,105.782145,31.977581,7.345541,-37.309998,-53.441753,-31.594945,10.231387,77.795354,113.814636,131.422969,113.26205,85.380567,25.911954,3.497796,14.486807,52.460372,152.356756,177.802915,151.662806,81.073357,41.858271,-14.730285,5.899553,142.756063,237.070404,206.248197,50.980432,-9.844117,-79.544264,-112.819826,-152.475325,-141.613551,-60.960901,7.288395,-9.404558,-97.39867,-136.801378,-171.750641,-158.993715,-110.719324,-49.31659,-37.724163,-135.539103,-201.004475,-214.773881,-177.088305,-119.926966,-95.067031,41.594049,198.555992,217.529045,161.972667,117.736494,90.279908,130.344786,223.016848,221.259325,167.632276,12.161368,-31.272931,-73.195758,-135.826742,-315.720511,-356.757973,-260.700554,-105.090896,-88.970477,-175.31903,-241.137621,-339.789565,-357.811701,-344.479031,-234.51995,-154.147279,-48.366215,-45.686214,-126.918287,-160.791012,-91.361772,-12.37914,100.363182,119.1838,100.551946,39.618307,13.93647,-39.31201,-60.078162,-52.295078,37.830776,92.424531,69.862529,-20.171877,-206.908553,-224.38995,-90.499114,-13.405402,68.352088,108.663222,92.332593,-1.287683,-34.197921,-31.152482,-2.117259,100.293745,211.737598,221.596377,96.36373,-21.705047,-247.331252,-284.288598,-201.294497,-165.869715,-156.807037,-43.955351,22.550025,4.215532,-55.711621,-80.442688,-19.542778,198.657164,386.206345,363.050883,125.605844,22.072315,-85.011575,-110.355358,-101.688139,-83.511343,-48.1405,-63.535732,-106.037746,-184.216499,-208.276581,-244.130264,-246.769438,-214.81536,-173.091873,-174.273297,-282.268563,-370.991406,-463.610114,-441.616409,-350.423017,-298.850799,-155.207561,-97.314182,-141.993542,-263.164975,-291.414787,-225.877713,-152.465176,-79.155234,-92.337251,-91.703535,-98.456498,-106.434661,-124.740721,-143.063402,-181.293337,-181.830264,-91.13784,-5.241933,-39.060748,-181.710387,-238.026275,-259.312043,-213.662487,-88.333597,-37.012096,-59.775753,-196.240814,-268.631075,-340.000558,-324.04854,-212.660358,-166.791825,-137.491929,-155.841488,-207.149727,-358.910927,-384.381013,-284.552495,-230.719552,-214.744007,-191.340045,-162.452164,-111.663785,-101.441673,-188.313986,-266.638298,-310.185549,-265.427145,-164.642537,-158.20314,-170.601186,-157.345756,-165.080006,-211.338227,-190.316178,-60.352972,76.52328,151.934814,236.764328,205.610139,71.592151,41.102788,137.018643,219.540121,313.119007,296.156207,283.259864,248.506319,188.257262,9.553079,-53.545992,-70.760315,21.272972,65.501363,26.024244,-50.382062,-189.412985,-217.718857,-181.72226,-129.169168:32.630859,10.065509,12.154702,7.589408,-13.010028,14.327786,86.636179,194.371526,152.672919,132.024642,123.383255,88.951911,-18.756887,-19.44331,117.205416,181.448404,219.334833,218.572491,198.241886,106.467469,60.490505,43.019858,66.870745,149.036818,248.903321,253.795193,157.395426,92.109885,-5.573247,-15.780305,59.900547,125.217056,213.071666,142.389294,70.58834,-49.584236,-86.953985,-103.256998,-82.844288,-33.96996,-42.640567,-59.799895,-74.085079,-100.244524,-209.966259,-231.968026,-156.306484,-110.465671,-87.393579,-138.785953,-180.752703,-317.011965,-396.699082,-407.930927,-323.789858,-135.754755,-32.275791,-29.505664,-110.642168,-174.04642,-294.563731,-316.403843,-274.374063,-231.050081,-96.179098,-58.144787,-130.98111,-303.020193,-332.626885,-295.697944,-252.983359,-82.269224,130.385054,172.16497,115.009931,50.597951,-77.001998,-103.079354,-71.304067,-33.378822,72.189491,67.050109,-2.156622,-149.052043,-188.541111,-142.55747,-72.635846,26.708488,27.858082,8.13972,-85.569523,-160.279964,-283.038083,-289.6122,-186.520645,-118.11583,-60.242471,-86.11772,-100.495771,-162.49227,-213.47555,-258.330959,-241.049459,-185.338973,-120.596624,-93.216919,-130.305765,-196.290199,-280.847662,-229.327977,39.806879,159.404637,211.509831,137.342437,104.652751,48.698541,21.06434,7.661641,45.357551,142.868088,157.427259,156.447118,154.95909,125.692407,9.311907,-30.817406,17.456201,86.995286,195.147512,169.813714,112.337737,-51.986677,-136.016323,-222.731315,-206.115989,-79.104972,-0.14636,-28.510626,-103.220959,-128.815679,-209.016771,-208.417341,-38.695845,45.832761,88.826101,65.957397,50.236972,-7.753343,-34.470907,7.129167,69.577866,157.460519,167.698612,163.412947,113.212419,48.346785,-79.002395,-80.650322,6.771316,54.095438,131.071674,172.889406,179.305413,103.315974,15.013763,-48.161484,30.007846,200.341702,247.207953,259.866618,218.009642,138.569005,-60.637806,-112.609387,-47.817713,29.557794,125.786152,58.097056,-16.555086,-145.402149,-168.633768,-118.612951,-71.975143,1.601777,81.302311,111.303663,113.215601,92.612085,1.466056,-41.056557,1.938104,80.490311,204.390423,198.074257,183.558611,142.205235,96.507485,38.559456,62.012729,159.33157,250.228998,267.512413,180.708961,80.276415,-105.762319,-122.099902,0.095559,71.13613,127.915778,64.269982,11.946462,-55.185518,-79.372754,-94.298662,-62.326307,31.853581,101.629474,80.535088,-86.907816,-159.779939,-185.891735,-143.517908,10.139189,97.402897,256.284312,296.133588,255.246653,148.397872,129.198829,208.43427,269.83828,322.569638,298.233016,271.465516,186.12838,122.560308,-13.293027,-56.767048,-71.809176,-71.407832,-56.406775,24.516095,41.695693,-57.899117,-139.731412,-222.321731,-212.325188,-145.257731,-55.515549,-35.319078,-71.134223,-92.810819,-116.792355,-127.00801,-73.49695,24.522306,265.319535,234.515786,122.30621,9.938332,13.596098,-56.810149,-106.048311,-64.739958,92.586269,132.337234,70.666744,-7.391981,-149.282211,-150.722006,5.957893,91.328974,167.726777,183.599543,186.861972,126.981585,59.169639,1.622101,48.610018,191.027647,274.264866,268.322518,141.264151,41.259463,-138.067283,-176.994285,-131.251421,-72.546489,41.096197,113.288052,114.692379,-0.46138,-72.665978,-40.898833,69.314347,320.529407,416.677838,354.030189,141.109456,59.829031,-63.869326,-100.428256,-73.369413,-22.1857,110.84873,124.933923,43.496704,-142.917176,-177.941757,-155.498279,-148.758157,-157.48182,-177.945447,-222.023306,-353.623118,-417.305259,-502.16932,-499.17664,-406.553727,-330.354009,-155.355454,-136.863266,-191.120417,-300.456353,-354.89281,-379.375197,-309.518508,-121.171272,-1.139093,24.913114,-25.639809,-94.530856,-189.388508,-166.157603,-39.87383,1.917137,28.208271,13.099516,-22.71399,-138.913354,-183.750418,-189.666802,-173.042148,-109.157917,19.601594,32.28085,-120.775896,-218.020328,-301.605943,-273.815102,-155.77809,-110.439845,-49.765768,-84.870218,-172.264076,-354.092937,-371.232927,-277.146851,-242.689979,-228.823314,-138.19771,-72.280053,15.235949,-7.106645,-189.933334,-264.156988,-279.366893,-248.809428,-134.613712,-70.545817,-95.60104,-177.710228,-204.298051,-185.688875,-127.792797,53.747161,200.823672,207.447158,120.428766,67.67713,-24.593808,-27.457753,126.060889,228.327697,309.213265,243.652973,196.150689,79.222798,6.145191,-112.751286,-126.496558,-38.394565,77.642877,85.025992,-20.313736,-108.944117,-246.603845,-236.621284,-85.394028,-7.349695:-90.156915,-96.998359,-69.083367,10.454039,33.945986,56.747412,77.914471,116.682181,125.008886,112.440526,48.975614,40.963175,91.334669,113.183268,120.314816,98.052434,-3.97036,-62.176409,-39.962512,10.73253,-25.032579,-157.81499,-167.029407,-55.945294,20.203682,-4.351214,-127.291957,-162.885293,-130.425989,-87.682306,1.368546,44.375653,117.609251,105.588513,62.723598,-18.767813,-25.653394,21.165105,41.676002,34.958556,21.82634,30.832014,40.045572,26.558048,-51.60603,-104.251037,-165.10096,-162.28128,-104.334855,-65.948592,-112.540992,-292.778224,-342.498007,-274.452466,-206.113884,-82.83622,77.701572,118.979926,8.010397,-88.06103,-190.525949,-176.194919,-68.58846,-28.882671,-16.360615,-16.40499,-22.577977,-23.828348,-16.843895,-45.396529,-65.980083,-21.532227,83.49492,110.423679,132.486011,136.864012,87.106652,61.390264,98.137898,122.513142,120.698628,137.156771,135.904992,74.2244,29.399872,-52.264935,-54.359667,49.082315,114.605196,93.012812,29.720512,7.446303,-76.98543,-117.078255,-47.790635,35.737796,98.238897,6.545021,-39.838637,-93.997459,-116.902076,-165.709924,-175.276883,-136.072185,-65.582227,-56.679853,-52.214609,-20.895884,30.932026,38.145048,124.574568,194.687558,262.106589,228.25145,187.698903,92.26909,73.685571,141.833246,192.366051,218.305563,165.210951,139.648849,150.598601,188.276182,193.982552,143.907791,76.197562,86.335323,150.765433,171.366263,133.301504,-2.019835,-65.257837,-126.893649,-126.491776,-142.316608,-193.963363,-176.987255,-89.432744,-74.182726,-104.871737,-130.039929,-133.376526,-83.493215,81.699484,178.798322,178.132408,158.987521,141.414261,23.459941,-38.658283,-16.766342,163.984485,218.823157,130.832702,44.571739,-22.969355,3.713687,128.075792,201.287362,275.629076,217.316184,167.184522,103.819182,86.650629,37.508913,25.769092,65.627191,112.195971,114.908743,60.388856,21.180248,-57.635372,-93.537715,-76.883026,-24.841489,62.173723,29.642617,-21.172371,-105.402931,-132.322305,-143.301565,-107.95327,7.227078,78.593521,78.992771,39.16724,17.756122,-71.246395,-126.720153,-163.406246,-145.196248,-50.902266,73.741773,101.507957,67.324639,21.113794,-51.336531,-44.811625,36.201513,110.40872,105.505576,-16.091682,-104.712205,-232.39033,-259.175546,-282.365211,-280.610045,-176.859266,-6.591936,9.2511,-91.230023,-149.324616,-180.293475,-150.025082,-108.843863,-108.491831,-116.35025,-208.088913,-248.465902,-171.627212,-97.507181,-45.258973,-36.220836,113.735766,308.253213,328.33651,263.744606,214.145057,113.185138,96.093756,139.588301,204.214461,218.116854,203.833608,185.405655,94.47588,23.138147,-75.622417,-85.845777,-66.418588,-3.069066,30.356547,26.83973,-25.458339,-193.687009,-260.272857,-272.219607,-162.236847,-96.958394,-36.583621,-57.87085,-174.856134,-211.549029,-61.980767,101.014866,337.769482,330.167155,272.967064,157.816572,132.275447,138.172445,157.93555,208.622497,253.894088,257.419982,155.042013,57.844614,-110.695804,-134.583673,-41.316527,23.992957,110.583022,189.745819,189.056325,57.382747,-8.251661,0.124937,59.2784,205.298216,272.184298,230.137541,70.17242,-2.353614,-97.898285,-108.658212,-91.043048,-83.338451,2.174546,157.540307,174.977113,98.000207,66.68108,87.086567,125.986871,218.390917,350.324224,400.39756,327.957431,224.957018,39.058682,-19.508232,-81.395957,-91.229141,-81.970467,-110.440514,-157.661403,-254.495321,-282.229412,-258.166427,-201.619839,-112.103982,-123.381891,-122.934024,-97.739252,-96.734482,-174.319814,-235.312482,-232.295714,-145.538397,49.214952,64.73171,-4.165155,-167.266346,-212.182494,-181.226751,-120.880085,-22.516393,-20.980878,-48.344174,-113.771117,-132.72673,-165.076171,-175.63077,-154.060152,-156.460851,-183.778128,-141.540058,-139.376435,-245.977822,-320.558916,-356.390328,-280.603775,-81.419723,-68.708444,-113.127307,-177.188754,-209.202598,-269.968474,-234.174302,-16.03467,72.66219,115.74683,89.597857,37.789688,-116.387514,-170.36235,-213.831832,-223.036449,-204.307412,-166.203026,-199.373588,-293.000118,-260.520982,-115.195681,-108.54383,-234.839108,-301.110395,-313.348198,-196.437406,-151.904052,-145.640001,-160.606026,-132.280168,-88.921873,-16.070853,70.624663,106.560538,83.797446,57.118852,77.742531,106.20109,134.549075,139.395487,158.20799,230.54773,283.491441,311.952089,259.811059,114.316777,70.093466,57.350936,123.874294,160.513919,96.636474,4.817168,-106.539164,-96.978329,-25.710559,11.148481:102.985325,157.22215,116.786741,-14.958253,-65.658257,-24.178128,76.673195,277.796045,314.432297,269.738974,162.089547,132.803485,59.165825,19.547555,66.022708,141.932109,227.52152,160.799535,116.143864,36.270696,-14.53679,-59.658594,-11.413546,139.500655,166.761555,118.238263,-29.110477,-82.756314,-88.037404,-53.762561,38.644471,95.294466,216.754527,261.6213,218.408142,21.760005,-62.467217,-55.423952,18.937578,145.528403,127.177695,72.715237,-61.593116,-128.120073,-259.200237,-291.917537,-214.731429,-135.623499,-31.654431,-91.917077,-169.883771,-332.927682,-407.104405,-460.116764,-394.539383,-126.817642,105.641464,124.357232,-72.773415,-228.350381,-435.017484,-427.070555,-248.876458,-151.903796,7.510948,31.008552,-63.645947,-294.385015,-338.12237,-268.888608,-179.961378,31.01669,99.854204,65.21905,-12.857266,-44.542922,-138.235625,-150.270144,-7.596847,99.495267,263.811218,228.909322,127.148101,-95.538477,-159.97061,-151.482838,-106.725746,-40.561165,-15.852132,-28.252815,-101.020934,-136.478837,-182.194354,-189.896119,-145.346426,-93.894348,14.530708,48.780873,9.978838,-170.740585,-259.54983,-264.386908,-194.871708,-70.543518,-0.113092,0.434597,-107.857045,-167.385961,-162.038211,-89.579911,135.360278,234.137216,322.375163,317.971289,285.80717,116.659613,10.475817,-30.057629,43.932545,160.3851,170.784129,167.626444,136.611004,104.585788,29.053027,2.544381,-6.022518,18.845269,107.422223,120.299538,74.884758,-78.289698,-173.18621,-323.919697,-335.353357,-224.36134,-51.136475,0.325885,-67.455594,-160.648508,-311.795517,-335.206713,-252.482205,-152.13307,75.122197,145.972224,113.528059,6.353083,-41.1567,-39.533709,12.255156,119.534717,179.369029,169.826552,21.579925,-75.846641,-161.225644,-133.73923,-7.459227,60.747503,184.69766,211.628887,167.302856,42.447602,-2.722244,-6.644533,42.443775,183.20109,246.776537,229.918842,137.10716,64.828255,-138.418376,-216.546293,-158.720362,-53.819435,87.314423,1.599612,-80.61924,-181.541492,-214.405764,-255.368254,-224.249813,-53.851814,88.995267,96.210828,15.478095,-32.11068,-92.116651,-89.577965,-20.02785,17.752915,89.245116,122.120046,87.581622,-53.197358,-122.018066,-150.500003,-87.45375,74.96114,107.759753,76.382983,-34.074999,-115.87644,-319.807312,-389.540677,-319.923744,-207.402419,-17.853104,15.35529,-33.632719,-160.540129,-206.950222,-255.086467,-240.995942,-165.351827,-80.487159,-57.71707,-143.333525,-225.432877,-294.858027,-268.455615,-187.690693,-123.680597,123.024415,290.89391,259.818446,94.684656,30.190701,9.981281,43.194309,117.137973,188.397556,212.818731,196.751573,150.643567,-25.141402,-113.212267,-147.400123,-105.844394,-7.17206,35.564271,14.009571,-94.981701,-158.387427,-222.446725,-209.163854,-150.193997,-57.740949,-7.427732,28.940971,5.074816,-80.199954,-82.847451,99.606704,228.98291,390.728373,380.993445,306.746322,137.295459,84.970201,21.274659,17.163121,108.855909,236.221407,266.95578,228.167562,156.324869,-8.3018,-26.063186,117.294076,212.273575,340.857692,368.896953,304.678053,98.931244,56.504424,120.121061,164.670952,226.297,269.770122,264.949185,139.339921,28.362124,-161.399182,-175.101269,-54.599109,9.196915,87.97901,134.812561,112.429301,-11.628426,-57.995432,-8.342099,79.572712,280.891465,428.556356,415.058854,201.172184,81.078534,-80.196139,-113.03255,-79.623497,-31.678787,99.591848,110.917534,36.117256,-124.53449,-177.193595,-210.404612,-171.852636,-36.219052,20.133905,3.788082,-115.299106,-208.035203,-353.731064,-367.639024,-270.22281,-178.419845,4.253122,23.252115,-40.555611,-205.851041,-281.133271,-326.345155,-258.632832,-32.674926,73.913605,42.796994,-88.632192,-123.965355,-144.142944,-161.883652,-176.288111,-150.648915,-34.458934,58.647607,48.570132,-70.33278,-148.56453,-200.259191,-144.139093,4.23707,65.47305,54.25598,-86.113778,-195.814012,-351.003742,-340.358886,-160.419929,-58.749166,74.396177,51.342294,-37.143424,-255.211587,-313.98433,-281.447094,-248.326592,-246.669959,-192.63566,-149.974352,-159.895722,-211.054067,-336.013564,-377.633636,-351.038363,-281.046011,-108.38761,-48.475482,-69.630708,-163.332656,-228.276607,-309.187621,-281.430134,-109.179775,108.151036,184.700869,162.817003,83.550293,-41.396452,-46.702907,61.054656,137.578681,241.926335,305.764838,309.208001,195.528753,99.407555,-48.903483,-60.60363,43.117858,185.736507,207.124671,77.389888,-33.929542,-185.656694,-185.516609,-67.545667,2.599022:-24.712511,-38.434725,-58.843175,-93.054677,-94.260151,-82.198168,-85.012248,-94.927041,-52.89373,-37.109079,-41.084071,-27.52336,24.372735,42.213268,46.062875,20.469796,-28.586518,14.039612,23.683551,-49.719417,-101.17154,-186.603612,-215.700761,-210.536314,-130.084335,-96.001435,-81.106321,-84.28238,-102.551533,-106.022368,7.657022,95.25801,131.028343,35.208342,-2.840651,-53.782942,-68.768195,-73.736622,-77.977516,-104.741289,-81.160144,-57.138747,-56.804641,-78.73815,-175.860052,-231.977641,-241.254231,-208.527454,-173.151337,-222.145295,-283.162463,-360.044376,-350.791506,-314.792248,-290.76792,-147.500787,79.398799,137.108712,96.319033,47.874233,-72.890223,-132.07368,-102.866751,-19.096134,90.984121,52.996361,37.145188,72.405381,98.110388,149.697643,174.161814,155.079129,107.670112,102.954649,48.942529,4.418127,20.15618,96.024593,257.037307,292.721221,277.215799,173.986485,94.344239,-2.361055,-0.866532,-23.226079,-62.528789,-73.118985,35.044949,66.372853,43.655375,10.084863,-97.430514,-121.059472,25.669925,132.660872,204.349536,118.532664,41.447715,-139.336042,-197.147485,-210.421158,-194.683193,-165.778409,-168.176155,-165.996062,-99.216513,-58.407451,-33.854431,-26.643793,47.845873,90.565608,118.59423,73.573114,19.392442,-103.122071,-126.097409,-62.593821,-12.97017,61.799925,135.618668,150.122408,101.943142,78.373426,61.413806,42.114379,-22.142538,-39.93089,18.454639,95.2321,83.9633,-15.518181,-83.805323,-204.889125,-229.833003,-208.750945,-146.732975,-116.561567,-87.783173,-84.569209,-90.042862,-118.214032,-167.593138,-134.3325,-14.633395,44.197292,72.434346,90.025358,59.031899,-35.341214,-83.042467,-122.131521,15.318237,103.684798,121.380491,55.070207,-58.279989,-68.472508,5.973186,66.364097,136.494072,119.312175,95.86576,27.818961,-20.044118,-130.343611,-161.743614,-140.318462,-125.687695,-118.886194,-77.849626,-80.184935,-168.14154,-212.818354,-234.907802,-229.946816,-183.306131,-64.187389,-13.212843,-14.053338,-65.101279,-162.497718,-169.597136,-121.752567,-67.923167,-51.445146,-36.02114,-24.59078,-27.953736,-51.607784,-105.321828,-127.436491,-135.438929,-61.816038,-14.753185,10.539517,-20.677727,-114.956574,-125.480308,-34.379949,-3.397798,-52.505988,-192.637259,-249.851927,-346.521672,-394.75147,-409.243577,-348.734775,-202.75637,-137.789631,-115.831482,-85.492124,-98.721219,-166.737035,-178.746927,-154.151075,-151.245247,-157.694112,-170.890607,-156.917316,-81.717383,-57.322205,-54.722162,-36.820391,100.830526,272.940664,307.847577,270.468759,224.437402,148.520538,146.234653,212.3356,303.796977,314.118626,242.796129,230.685556,307.245405,316.60061,203.244905,134.039783,91.944402,144.104888,161.115808,196.146004,206.076176,89.301174,-13.801645,-136.924951,-171.288334,-178.83129,-130.340251,-93.429396,-101.963382,-123.025556,-56.975117,19.551921,144.313198,220.613023,256.28228,341.05893,365.976711,325.193279,298.230644,304.796856,308.362006,291.908103,188.807559,101.985554,-57.406155,-104.933169,-97.19927,-41.234677,98.993161,184.673091,186.901733,144.677908,125.75799,124.824996,146.275137,206.8329,226.12214,187.072371,39.754825,-6.074694,10.954485,20.926889,-26.40146,-33.879979,103.989395,279.978536,298.371469,246.910412,220.032832,222.879484,260.304111,371.784648,492.550662,519.723659,430.076675,357.409518,243.190929,171.492547,-0.956264,-56.022578,-66.063624,-45.269281,-66.208817,-151.787285,-183.864886,-169.475907,-118.015928,12.045719,101.423144,134.338333,200.259206,223.911186,196.843975,159.229844,150.82655,178.970648,208.7562,184.892609,133.804344,-53.053491,-135.098716,-169.789914,-140.022561,-62.037532,40.046992,77.112051,31.438302,-27.90182,-102.320265,-102.610566,-35.989357,-2.615648,0.737788,-2.123145,14.663927,24.513989,-16.518336,-123.803568,-130.923687,-65.965225,-63.261706,-99.144036,-167.83306,-174.10798,-96.777418,-6.431078,241.73947,342.732284,414.246569,377.694487,312.361062,150.160854,85.503416,-41.775201,-88.264812,-109.82977,-151.264658,-202.814903,-286.389927,-269.487283,-170.768832,-167.611535,-256.601225,-286.534707,-251.71184,-104.412242,-31.437064,2.637775,-30.162344,-111.575286,-132.625598,-87.043288,75.960804,147.292453,149.785301,97.682611,-14.470315,-53.767124,-30.63421,30.21882,110.851703,106.682058,117.992357,159.608836,169.698423,135.455231,101.582612,50.949979,31.957088,56.510249,152.071545,181.680529,148.049276,103.000917,95.435459,145.009942:-81.914728,-29.426859,-27.705268,-41.108353,-65.198644,-155.417089,-179.289117,-133.814004,-81.840811,-86.202875,-103.543348,-85.442374,-24.277412,-12.988575,-34.47327,-57.082545,-93.705591,-97.478528,-120.202905,-226.681697,-271.5924,-299.83447,-303.625222,-297.19279,-181.269997,-97.577309,0.266038,-10.397054,-104.836056,-127.075003,-40.942119,11.85227,1.596033,-89.569649,-128.097332,-182.232775,-191.373909,-149.818164,-125.439101,-158.463942,-194.302229,-149.958132,-3.601199,20.950687,-107.027565,-194.122323,-226.63903,-174.108552,-76.924426,-95.204161,-126.667229,-152.270515,-140.615657,-132.082981,-139.333352,-106.977191,17.961415,66.541535,64.667755,44.077495,14.384199,12.18525,62.262891,99.947251,167.581022,191.738828,165.225951,86.271106,62.076978,52.90177,66.014014,110.422997,200.6273,252.590688,263.826512,209.280301,72.806364,54.409158,162.528981,237.141373,303.455838,253.308891,216.728266,204.116519,218.576985,182.638349,145.015644,167.866321,300.269254,344.470314,335.097141,294.283426,150.968867,77.336409,56.47785,96.360393,144.825032,138.139215,127.886061,45.752008,-20.944783,-126.925398,-153.607702,-146.586902,-75.435869,-37.479731,21.909661,49.152398,96.516345,102.129531,79.74404,71.02341,79.893498,71.358517,33.254905,-26.272987,-2.579156,114.495507,160.842923,150.383565,110.302254,128.873772,189.042778,200.134695,141.008331,85.568891,52.19038,102.957845,246.994912,274.835717,244.494697,159.444716,103.732438,10.787167,6.556272,47.888041,91.794638,114.549913,135.240883,123.55905,26.677956,-48.249899,-101.476241,-43.610431,109.674786,136.883676,132.923932,164.199784,162.503466,84.573442,52.39111,86.116729,220.075733,276.708867,257.735049,194.597204,102.114973,108.442834,181.001063,202.897592,237.711812,304.143225,301.460804,199.551833,126.570505,7.124271,-8.177259,0.404997,-68.433366,-106.085905,-117.664721,-103.151688,-102.833114,-127.613259,-151.458716,-132.020891,-98.120322,-65.381748,-5.203846,73.841861,12.458284,-159.097083,-151.658489,14.322218,139.794302,159.607382,107.101663,55.029176,-47.752613,-93.746008,-130.296601,-109.285351,-23.221922,75.484551,128.546218,203.246219,184.884329,58.912017,22.449588,58.891426,113.518554,125.375892,103.214758,63.79523,-56.763319,-119.035263,-165.379162,-139.154534,-26.823265,78.01679,82.413065,42.395761,18.561938,-62.39367,-80.912942,-23.765424,-62.725696,-131.148056,-193.663875,-151.280766,-39.454918,-36.914523,-89.725171,-86.2995,22.978943,116.81088,114.962815,95.598127,68.454509,-70.750188,-107.227759,7.942171,107.700325,75.000372,-11.561294,-1.696222,44.122334,25.517548,-87.402215,-150.20483,-174.471009,-12.114371,46.259884,9.129222,-42.128552,-163.107771,-242.892923,-408.580082,-444.668203,-389.082169,-253.44265,-227.557016,-300.794759,-346.624451,-213.949191,-52.905535,175.574267,219.613358,227.579495,258.981594,269.969157,268.004692,272.876975,271.248501,219.578823,184.812855,60.504368,-22.325895,-156.692134,-201.025654,-244.532887,-226.523287,-101.568101,13.825388,21.556128,-17.933135,-37.025924,0.178649,87.844511,295.228323,284.250638,194.559326,-21.016047,-106.83627,-164.974316,-145.278811,-117.427133,-122.48642,-69.454957,92.760486,161.303733,196.548822,172.107752,150.616642,200.219123,363.588266,401.364038,365.135511,294.733523,291.108844,278.445199,236.792716,132.821754,98.463029,60.623099,3.482374,-61.421936,-175.627941,-180.353164,-129.599915,-82.865135,31.395383,54.74849,47.348159,61.808221,59.925144,-8.20025,-18.490769,152.353945,269.815579,319.577334,200.848047,154.861558,70.378441,2.857184,-125.575569,-143.650042,-93.561512,-55.858596,-90.222159,-228.043417,-268.205226,-234.02488,-197.454531,-168.645613,-171.481857,-165.867444,-171.587156,-177.665585,-186.039867,-220.11798,-329.734964,-343.061032,-250.217098,-172.166001,-195.638252,-336.617456,-391.609695,-360.575949,-287.778022,-83.631886,16.780441,120.15707,101.924533,63.383028,-33.344542,-71.873798,-112.737418,-116.522895,-128.011055,-157.574607,-155.575824,-123.046534,-101.552987,-79.203302,-101.970059,-232.786907,-307.24075,-319.101671,-132.92699,-67.711503,-119.892746,-186.640673,-258.151636,-250.221258,-161.051759,30.198244,126.433298,168.215538,121.272281,31.356041,8.514461,2.084348,28.106415,135.152697,235.953442,262.316531,199.196898,109.785429,-44.76945,-86.003152,-142.969972,-82.875519,-15.094115,19.798814,-10.52455,-53.615174,-54.693021,-12.203614,27.881858:1.767554,-53.462852,-36.333206,-19.908244,-47.827225,-96.878003,-71.913135,46.89768,104.039385,96.970297,87.337254,101.660621,77.05573,19.712062,-50.299993,-24.808785,62.475132,57.131954,26.723241,-49.928955,-117.103221,-220.521717,-190.950702,-67.676476,-44.221083,-67.533802,-142.544246,-170.855258,-171.319983,-133.904065,12.215075,71.707675,54.348374,-2.56767,21.168444,85.384873,78.529329,20.640391,-1.354229,-21.682604,-13.087957,-7.653635,-37.990499,-62.870328,-129.536743,-173.53973,-202.520045,-181.226371,-166.26369,-208.80041,-221.469884,-239.468533,-275.626436,-341.216009,-288.961798,-27.635572,179.779273,210.48908,91.659893,-28.66254,-218.821565,-243.298339,-157.825075,-97.492327,-51.327403,-71.168751,-75.325731,-65.290718,-67.080063,-61.769167,-41.570136,-33.210998,-103.584426,-113.319258,-41.289597,-11.048866,-18.474167,-1.10176,128.640704,185.436769,228.950317,164.982697,67.927717,-107.911637,-137.021336,-133.48174,-114.518792,-77.685665,-121.988238,-163.587458,-209.775385,-214.30995,-229.983833,-220.668814,-112.405211,-42.431541,39.75423,6.402046,-48.924927,-179.878318,-231.436164,-286.489613,-283.212656,-223.913152,-180.584543,-177.555152,-172.623885,-148.542983,-70.482488,-30.070973,39.705786,52.904446,82.455085,182.992409,200.140692,101.715069,30.621847,-34.70679,-8.474196,68.690294,27.298395,-4.27237,13.305502,42.410801,17.745222,-38.672195,-127.659979,-133.209583,-72.932197,-34.489884,-62.876018,-160.691947,-215.031007,-307.835407,-309.381701,-252.238906,-237.508664,-223.986547,-153.982572,-111.944618,-75.458967,-113.18968,-213.703096,-180.056365,62.664932,177.335628,144.70222,88.635077,75.406442,-43.505599,-117.149966,-63.297185,199.112386,243.912608,74.406733,-32.976995,-124.125144,-116.249957,-32.733811,30.435289,156.906026,201.388148,171.193965,49.676475,-21.261525,-87.946237,-48.969548,38.049665,37.224729,48.685187,40.195739,-1.945468,-99.333741,-135.910651,-178.878877,-170.950878,-44.417191,76.996191,68.83225,-6.736811,-55.338085,-187.868838,-217.648945,-105.544145,75.000618,105.919239,56.17492,45.913798,49.234135,11.005204,-50.604708,-16.966933,105.633598,122.9295,74.83442,-55.704234,-99.270006,-117.947733,-94.554565,2.871057,62.514383,28.056289,-106.593803,-158.990979,-251.785144,-305.032925,-342.571004,-306.349068,-174.353154,-52.450989,-34.377673,-89.643868,-137.41679,-193.858841,-187.685146,-170.436684,-161.169192,-130.119056,-98.306705,-135.258195,-234.36677,-252.539114,-190.312996,-104.049969,120.901627,230.453216,213.050741,100.954086,42.324875,-23.55354,-11.782346,90.376569,197.519801,243.670496,293.233979,289.514199,262.923105,228.880088,69.989912,-15.687146,-23.906278,117.066775,134.912727,24.980976,-26.893311,-35.580245,-42.387431,-119.039447,-98.59845,-31.079134,45.890932,16.03185,-97.761992,-123.888716,-69.737003,-5.850156,198.395532,394.030127,386.895907,194.383786,107.84846,124.212906,200.97276,278.506125,227.682437,186.442577,69.630213,1.765654,-132.863824,-157.503923,6.989025,141.207527,296.709598,286.58636,232.154936,135.730984,130.490865,144.656332,151.543404,179.237912,216.404189,203.578727,76.762536,14.125806,-3.933888,37.284327,122.000988,112.340543,23.450307,84.854077,160.321048,229.13645,181.238258,41.574785,62.865675,265.936967,352.83578,332.967034,267.650616,222.661246,79.44849,15.26083,-64.881066,-92.819867,-67.475529,-63.390824,-150.827363,-322.271934,-311.19272,-156.907854,-84.436822,-7.352009,59.731182,106.103214,126.59526,67.494106,-111.673634,-154.652985,-80.48283,-14.882472,85.317499,138.691978,115.158839,-48.869658,-140.983475,-244.364104,-244.478997,-176.879155,-72.900352,-37.322872,-39.460599,-55.686449,-118.454702,-166.368862,-156.487491,-83.359351,43.872365,73.49863,70.259649,17.489892,-31.171865,-73.625424,-39.416914,28.686934,14.04975,-0.160807,-37.845815,-51.07168,-20.095523,26.58271,168.86906,241.355968,312.234298,307.7334,279.307479,138.72993,41.847066,-131.410961,-165.268239,-139.452369,-122.046033,-139.040656,-199.714209,-205.059125,-196.473781,-211.212894,-189.895226,-139.643761,-63.769507,-83.32807,-117.693673,-168.512656,-170.706023,-111.434956,-49.247655,74.684074,131.261299,125.270366,64.821086,43.41507,14.692469,-27.533857,-108.852514,-91.204118,36.461217,146.86287,187.91134,187.675785,136.384486,48.175192,48.371573,107.333397,194.603794,207.746613,89.592757,20.36322,42.671106,82.662621,91.59088,103.476714:right
61.679157,130.228378,158.238959,97.133115,32.000366,-59.179834,-93.372853,-149.909468,-148.334892,-116.818246,-5.915982,43.255855,95.568484,94.642438,-0.403397,-68.537076,-138.970916,-145.603989,-128.491861,-52.857417,-44.954365,-164.822296,-238.080726,-234.464114,-133.318767,-113.371753,-115.284376,-125.211063,-133.397396,-128.250747,-162.695103,-200.899348,-216.35615,-117.139701,-77.482005,-69.253236,-68.926396,-49.89154,-39.980411,26.052113,188.08182,260.086913,329.834178,344.668616,341.878293,319.474383,232.198895,168.303902,55.856311,68.282456,126.253599,231.643993,229.060435,101.852923,20.316368,-42.02769,28.575764,85.32551,232.657886,267.959552,148.900884,41.089615,-115.827169,-131.007917,-78.404663,-62.495897,-60.801233,-41.593031,-49.508973,-132.50958,-190.493732,-230.781082,-121.726182,-66.301518,-30.665935,-36.710977,-50.293938,-65.628618,-129.830002,-147.573024,-70.304184,74.689787,125.37049,214.664546,266.615334,259.589398,177.179731,66.439712,115.689101,147.518299,196.712183,192.406138,123.966186,96.380735,90.670105,110.800152,153.552756,120.302873,75.713859,-6.600481,-15.086359,-0.608624,-3.281535,20.264363,141.064588,235.659575,404.613481,417.247506,281.987938,188.470794,71.644181,57.654254,126.441737,297.34807,359.961225,345.804938,284.630246,97.829629,-24.714196,-215.118674,-188.453336,-120.979767,-9.778681,12.677611,41.991301,42.864547,-43.979376,-98.520623,-113.908585,29.722066,145.098734,318.679822,325.405696,170.469585,48.24299,-113.607476,-56.983,26.769429,209.335901,253.31496,144.972793,34.600516,-110.244009,-111.835053,-4.794647,156.080512,222.499866,265.388713,240.12543,68.254622,-66.978868,-204.38219,-79.018528,-22.771334,-25.166575,-48.930178,-106.104737,-137.935272,-163.903429,-145.517655,-35.714044,134.026197,220.151248,287.688762,220.199533,-52.068145,-162.408513,-167.824656,17.858434,105.01665,210.525068,213.687843,118.563837,58.835998,-49.057371,-84.763955,-26.622264,150.42518,213.380455,222.070254,183.096274,20.402875,-91.304336,-222.974277,-220.233727,-211.376851,-111.956925,-23.228295,26.979018,-51.208784,-183.598431,-161.122146,-77.328306,-40.833241,-6.357863,16.422893,-25.153758,-126.442451,-144.164218,-76.686178,78.983937,169.105146,317.157754,342.919719,354.08359,357.073915,224.619511,97.787998,-18.670576,106.526084,164.761502,153.574733,119.842944,136.638103,175.032155,163.376385,23.636819,-36.174062,-82.885849,-80.140242,-53.615621,-59.780841,-151.813613,-191.652075,-174.460309,-134.017401,-131.095202,-131.106763,-144.691154,-283.683642,-397.069683,-555.155367,-475.807318,-376.348139,-215.018216,-180.539279,-185.257365,-208.751034,-245.822686,-223.656255,-83.307737,60.479605,100.52727,101.131502,87.194515,77.008017,65.728413,64.175394,136.503654,163.061855,184.248414,196.611215,171.359405,104.891937,-27.85033,-19.351079,129.638164,259.722573,286.485357,291.217176,298.277705,304.786155,249.028995,51.111435,-9.590794,11.145003,7.131932,-44.688,-197.581985,-264.431911,-361.272632,-375.112911,-296.645373,-183.120105,-134.571259,-21.624719,-0.2767,-98.524906,-157.269999,-189.805808,-179.013612,-150.451283,-38.597191,-0.602705,-12.911519,-38.658107,-60.341488,-42.915398,45.951652,179.644249,210.353095,78.071806,-19.014631,-46.517777,-5.792674,75.426575,177.33327,196.436299,143.21584,116.301453,146.221669,176.797275,172.922034,159.81746,163.33351,186.016033,217.343333,251.338448,209.24357,25.560525,-45.337639,25.839199,221.07861,261.333526,277.362134,307.829465,347.525655,290.996729,86.226457,30.348468,80.154426,214.732754,271.200999,270.071395,208.770609,72.743165,17.714477,-23.691146,83.35517,131.728659,137.712051,123.538899,148.241789,186.531545,208.379477,170.866262,90.530054,207.872046,326.215874,364.521233,261.901757,115.158689,108.7506,75.716964,7.265141,10.620697,94.778607,111.419282,13.05391,-66.383354,-229.50375,-287.797663,-273.782364,-118.464301,-39.094907,-18.773398,-86.839483,-218.973366,-223.810433,-132.65628,-94.231282,-126.767316,-130.091757,-57.594292,77.175412,78.335164,68.568055,111.797275,198.675794,196.43028,182.663163,70.582078,-35.302377,-175.191695,-163.204073,-62.791103,38.222675,91.828071,168.710624,169.061965,156.468704,171.283899,132.228792,70.69485,28.292833,84.998863,91.456738,16.953383,-40.128256,-81.659552,-56.1553,-29.454793,-118.121609,-132.283474,13.203319,84.245823,26.42845,-27.055051,24.718997,82.261393:-28.227774,69.122065,134.741241,97.471439,5.292166,-136.170187,-175.209467,-276.994663,-295.315584,-218.815446,-46.231196,-18.875981,-29.289583,-32.21822,-51.85512,-64.146551,-80.515172,-115.883425,-125.111008,-172.228215,-247.63668,-425.738706,-439.467785,-281.548989,-139.931576,-104.145518,-52.430649,-53.401121,-108.022423,-129.437225,-125.823766,-103.949395,-54.442459,-76.273072,-98.598306,-70.234601,-25.583019,46.124455,73.865327,165.70459,290.106319,320.631731,251.966371,192.836523,165.735329,176.342699,136.23855,89.527286,13.148199,-1.894339,15.504313,68.096548,64.587289,-38.703575,-95.128263,-121.982977,-70.178033,-2.84587,184.70477,213.719778,72.040213,-29.294931,-171.089068,-190.043781,-136.116152,-87.923654,-86.254114,-103.089962,-133.489842,-206.133715,-206.158112,-130.925182,-53.211601,-28.008506,-0.792761,-1.111689,-32.729273,-65.160347,-127.463268,-124.576062,-20.9637,104.054676,146.147116,255.510309,314.857119,269.30573,169.053137,72.690876,92.655709,86.14472,128.535007,159.99468,76.863969,-23.108524,-94.110731,-22.332235,111.867609,21.504011,-48.535238,-102.572505,-93.35402,-107.018331,-122.245465,-46.194336,86.313551,134.260543,199.720989,202.304354,127.906715,71.720755,14.019244,28.572415,140.671417,305.681565,351.050505,299.090195,232.333142,80.486979,-1.5031,-101.410025,-82.918242,-66.826133,-45.282394,-29.238864,-20.180895,-61.290478,-188.320873,-224.496508,-201.613612,-62.229215,6.942111,95.288605,133.864338,125.430176,52.639821,-74.349647,-9.974137,75.110232,253.565031,274.902858,83.722961,-38.639469,-94.528525,-47.336149,54.730671,121.449573,160.468037,207.719428,167.479579,-65.837447,-213.3327,-368.498526,-232.886187,-140.292372,-66.467713,-79.522466,-193.076545,-274.427292,-322.416534,-245.524251,26.241391,232.207594,276.730554,279.421069,240.5571,61.901851,-38.010993,-97.169965,83.31405,196.463103,250.384011,185.958494,53.355229,31.915917,26.026334,24.74487,103.28114,237.367621,249.737294,172.870339,131.424194,51.31177,-9.569808,-115.573691,-91.46894,-40.101856,84.108095,132.561886,122.015707,45.617379,-143.631696,-181.413124,-125.407265,-31.684855,12.695268,21.419729,-35.362469,-121.228893,-98.976743,-1.973925,43.248033,81.125161,276.240089,366.518952,331.102645,232.349702,57.315867,12.024555,20.614647,95.782067,98.138068,39.104651,24.715187,21.774179,37.909326,163.494603,156.448499,59.872773,-108.412063,-147.462075,-209.61323,-243.070389,-291.472666,-310.185589,-279.430477,-103.244043,-65.996537,-212.192748,-307.940828,-383.316462,-367.23939,-292.573445,-258.325144,-263.862263,-267.646295,-240.82686,-188.484004,-207.7227,-264.564853,-231.679582,-69.087451,56.569416,102.89164,135.204023,109.590598,35.439317,18.125233,53.406271,149.298882,214.270284,322.035047,334.902573,250.336322,162.220102,49.3298,84.836973,232.452383,279.723322,292.528908,322.295146,331.89021,318.982794,252.303386,9.091553,-85.829303,-28.68056,89.500174,62.339991,-111.175175,-174.855914,-172.087505,-122.931019,-35.866002,-2.060218,21.69209,63.046562,37.909863,-88.909857,-121.281016,-96.157755,-101.12569,-96.84474,-7.7718,37.62588,50.886395,33.636038,27.641758,63.810554,180.935813,236.750311,232.264706,185.817801,146.656919,44.381746,12.746255,102.082492,268.430219,281.645446,177.459122,124.505526,46.720871,6.208498,0.117524,57.142628,161.787984,192.729641,228.645573,256.494075,189.783041,-0.749625,-31.741744,85.967841,271.104595,340.349689,369.515661,321.430525,189.581159,134.533233,26.515536,-23.759318,-47.834449,72.541784,139.265539,151.226487,117.161085,102.114409,115.753261,146.369836,212.747027,234.021929,235.997779,235.218933,239.754198,212.981253,86.569621,53.692095,136.181541,312.625506,388.116878,388.589022,304.750007,162.340594,143.910242,89.358171,-3.36637,-16.979896,-5.902318,-5.456348,-24.693354,-56.575982,-179.449646,-230.701114,-203.025253,-26.732942,42.246607,32.47649,-18.527883,-64.332841,-39.125865,-0.356086,-54.561999,-64.296773,52.66846,136.583029,156.250385,81.343299,-17.762601,22.861105,152.413165,132.083278,85.593875,25.868521,3.859993,-83.427563,-112.398636,-34.298807,119.248417,184.258292,250.005464,237.164307,188.747312,168.076569,84.417318,47.053692,65.348078,112.89417,87.867832,-29.278366,-56.047772,-25.556281,1.732188,68.877606,95.232132,92.323936,91.748672,64.996227,-86.100286,-135.974326,-59.848394,7.287283:-105.103442,13.196901,88.782177,67.957734,-32.353517,-217.69236,-245.94324,-217.905534,-129.849812,-41.04567,147.763041,166.317793,9.81578,-91.688553,-127.610083,-56.810468,36.287084,-16.808843,-27.790833,-75.157668,-158.11281,-352.888216,-389.62989,-288.340763,-132.608597,-82.93367,-55.48134,-98.936191,-225.12683,-231.4536,-142.506755,-111.375528,-67.765205,32.636973,61.653909,21.667633,-28.883786,-92.996578,-48.301486,178.284199,350.441924,342.018305,142.402984,34.35572,-65.621289,-86.773491,-123.350206,-129.275222,-99.042065,-36.118432,-2.866768,21.807374,-9.274903,-91.283592,-101.454573,-104.465278,-117.896204,-73.7521,107.909421,146.818635,2.832225,-96.080975,-135.261777,-104.162235,-54.341008,55.657,110.421405,60.735542,-28.77356,-147.137163,-150.791165,-99.156611,-17.636972,16.527366,54.147185,69.769229,82.15028,36.284003,-116.863614,-125.769796,49.804682,199.527095,221.526752,255.124827,270.58867,189.898782,92.3079,-20.519259,13.638194,30.691877,73.353071,102.861165,62.111068,-25.021257,-148.001916,-130.17586,-12.262398,72.625979,77.487546,35.949353,4.616282,-77.51004,-95.288691,-7.108564,95.60769,129.017579,186.836214,184.442949,112.509971,67.736839,-1.532383,-18.548643,28.119152,201.644049,275.855357,263.281893,202.811955,98.550646,45.933054,-62.850441,-103.213737,-118.62539,-157.775744,-147.72223,-60.34277,-57.125071,-196.486321,-240.759839,-135.924061,43.998344,96.321889,83.213667,38.125247,-14.084524,-17.235126,-30.704724,53.026552,161.709118,347.626176,322.55001,48.042036,-76.088086,-129.363008,-95.814565,-10.411359,138.287747,211.472822,158.29193,36.170945,-200.5833,-264.118241,-272.730537,-243.75137,-265.243524,-264.345283,-196.366597,-98.688959,-147.703788,-308.521698,-313.665462,-99.394684,217.05645,296.907546,259.20372,189.201792,34.305062,-19.693926,-16.862582,168.169044,280.88255,313.078228,213.850494,29.105739,-0.821462,-47.110686,-62.306793,58.254842,285.820607,334.42693,285.280341,243.354297,135.581911,61.855436,10.020534,133.321301,194.019641,218.677019,186.219825,124.253129,115.087126,85.851162,60.924591,32.018596,68.68061,115.674825,168.044597,127.264109,-38.1943,-82.092167,-2.261392,117.776365,157.545751,269.328523,310.805963,241.109619,163.748557,29.401313,-28.101522,-45.47626,61.598216,78.022913,-4.989909,-43.392205,10.30879,95.591813,225.794278,37.270679,-111.015638,-172.850008,-101.396062,-77.515237,-172.091086,-330.772525,-337.11544,-319.988793,-257.200085,-193.596019,-138.208547,-166.807265,-240.011762,-251.638354,-243.170118,-240.902396,-225.039475,-170.911645,-168.760674,-237.24245,-277.843113,-260.786978,-170.35266,34.076184,42.776676,32.900716,80.486931,91.915414,7.139853,-45.687447,-9.695749,120.308958,145.133322,100.697441,75.949783,64.478931,28.065417,-75.193467,-50.942006,116.977837,194.594677,202.532849,155.049281,85.847264,-95.677021,-162.582052,-158.778775,-91.362463,-67.021329,-11.824202,-5.070666,-56.021702,-99.991579,-177.859608,-182.080292,-115.999139,-49.104692,-49.189726,-85.9962,-98.866725,-100.718752,-79.657291,-54.13087,-132.444749,-133.470911,17.632026,90.584438,93.241204,38.590284,-82.799666,-87.766803,65.13466,203.830396,206.200454,128.203561,76.601421,-2.605062,-1.050315,141.347041,267.181304,253.08177,182.808048,161.672075,86.201367,28.069339,-49.008575,-51.161726,41.352012,257.863864,344.760045,331.570969,259.197761,150.83215,129.507606,128.390145,196.712076,229.97098,273.292916,272.993733,160.236314,71.738574,-51.659352,-84.798645,-118.421164,-37.26081,44.076988,164.85014,174.408977,150.930227,159.960979,198.406553,148.88291,127.88112,183.069063,213.178045,188.81301,164.875276,170.996029,198.543467,249.629724,313.534343,354.171019,373.005959,326.355012,182.205461,133.024102,77.926292,54.697006,68.565439,91.039585,85.885555,49.883784,5.891822,-131.013647,-176.129553,-133.841372,-3.111357,38.957602,46.448303,13.84892,-53.390508,-49.045342,-14.332268,-6.82782,16.597934,80.040037,81.540486,8.004425,-54.531038,-106.479318,-47.666345,87.497513,70.082817,48.699503,16.733992,-4.509178,-2.591752,37.365476,109.488947,107.142316,122.685368,206.845077,230.101763,169.910513,101.227075,-13.320276,-27.489433,-10.338182,34.890499,56.288723,33.03449,10.001918,-9.557086,-19.151333,-4.59413,54.69668,74.200362,118.021464,123.17513,24.591988,-44.097378,-95.375452,-60.852248:-48.571613,10.603578,21.783883,3.684229,-13.510962,-79.98436,-131.434228,-165.266319,-56.7448,15.590197,138.234552,144.184526,7.176701,-80.936604,-155.644962,-128.900759,-42.346838,2.086827,17.447393,-11.258159,-73.389261,-262.950188,-322.782939,-211.612695,-31.629292,-8.351978,-45.327762,-99.444374,-195.218542,-184.888347,-129.06215,-135.479921,-170.357677,-126.520675,-96.864525,-95.734887,-108.280095,-83.207053,-44.828984,64.024681,188.327708,212.25416,148.34535,104.891293,58.861946,31.409573,-75.394854,-125.05187,-104.573678,20.758807,69.538991,98.836238,74.452116,-25.690115,-73.99709,-96.342475,-39.134127,9.678511,130.560124,148.93143,61.503812,-3.667613,-99.113659,-109.401213,-44.672891,37.343611,42.262606,-17.443593,-45.546573,-58.507453,-67.218998,-94.050603,-63.614615,-33.028537,-12.578843,-29.293899,-29.279781,-7.521198,-2.004341,-6.399956,84.100391,287.426419,335.191985,250.435531,192.712492,151.808491,136.755852,82.326007,20.592155,23.419621,140.705731,187.102531,93.626099,9.185624,1.711505,67.482635,158.89739,191.86054,189.928159,86.699946,22.688434,-39.129732,-42.570674,34.027908,209.730473,285.894839,334.62168,295.682675,151.638347,92.283323,38.224469,25.905692,19.403247,115.017783,182.573972,228.889069,200.693399,78.748217,-1.286923,-117.650163,-114.082641,-92.545429,-100.993784,-140.393866,-154.03833,-103.232867,-42.294179,-60.250731,-93.431736,39.734441,163.31745,290.981433,244.283341,71.251314,3.729558,-72.421043,-4.035696,99.843793,300.168443,307.34918,122.376964,26.784965,-7.398673,33.043391,131.699155,204.838583,220.441227,138.347232,40.293748,-168.803584,-251.256607,-308.166553,-225.869011,-200.438157,-187.596113,-158.730421,-118.748683,-152.883341,-266.262763,-291.47391,-227.018846,3.1889,140.900532,239.991111,175.800305,-17.18948,-82.870421,-86.877473,68.683655,156.227411,253.840303,249.798818,138.562862,52.907459,-64.921687,-46.583138,111.500581,213.786476,230.41759,258.77061,254.063895,141.947972,70.42749,56.157192,98.605831,98.889103,197.685913,280.25369,310.136808,242.736788,86.678251,49.623562,50.384569,127.844233,176.840455,183.189216,138.435677,33.709902,6.841835,92.778112,279.954971,346.339269,399.142459,395.984465,408.547743,418.50587,283.297487,147.155522,0.270327,78.357126,108.668291,86.14866,71.748739,71.601142,82.953717,135.341221,77.786725,0.381788,-83.808353,-68.572529,-33.476777,-62.210523,-189.61566,-245.068308,-249.79786,-96.868159,-30.638847,-65.412619,-135.743332,-265.79644,-319.644181,-358.647723,-285.421688,-234.547416,-124.412767,-76.103449,-75.056191,-130.593177,-216.933171,-175.38356,34.395654,171.865572,180.926926,94.938213,44.80203,23.756821,39.612603,91.01385,142.350398,153.170964,151.375542,151.948753,142.559081,103.060235,-47.071306,-98.814098,-41.470527,132.716394,191.524933,160.058651,99.503211,-6.70188,-49.07149,-84.19583,-99.69263,-114.568739,-91.099016,-77.94204,-146.990516,-208.458238,-263.491423,-241.123005,-178.818942,-172.939855,-154.570544,-49.454973,-8.810961,-16.737674,-35.320495,-63.681495,-141.027371,-157.278695,-60.4383,-0.691098,-1.807232,-64.818581,-186.549374,-180.247773,-28.048038,121.613005,132.895084,39.435298,-17.478995,-69.724568,-57.988617,28.697031,109.218341,130.697711,203.628951,236.572414,161.557143,73.454388,-41.098088,-41.066504,29.671368,121.125438,156.768183,172.924918,163.883595,165.250089,152.886432,96.158055,172.389973,250.540766,362.231174,386.487157,346.323686,249.33685,-36.089957,-135.250461,-127.342089,25.872158,70.781566,40.954433,18.176782,30.873963,29.401645,-14.894725,-14.416229,13.60139,69.351973,77.061421,84.408319,95.625788,108.915204,110.904345,124.628584,199.489732,243.793487,257.823773,230.484431,148.362203,103.436573,21.066033,-31.781672,-14.190098,92.804297,126.425956,106.419154,58.92694,-117.709225,-199.001064,-195.094791,-64.520758,-23.113371,-17.301118,-48.142509,-133.779045,-152.069139,-91.594674,8.997989,33.572029,13.386271,2.946697,49.333471,65.22607,37.367639,50.432373,138.347765,154.202805,142.249926,97.025808,58.666543,-36.093682,-82.266595,-111.652664,-23.761341,39.470912,150.460279,188.393892,223.224175,211.95463,106.784966,48.605881,13.514267,22.143858,-7.433612,-140.99637,-174.642077,-120.861792,-97.617399,-106.178779,-70.726556,-20.759365,60.682581,42.700317,-101.296692,-153.849012,-105.000345,-31.628603:-26.502219,48.476586,32.695741,-60.378269,-85.864617,-81.450009,-82.198456,-97.580091,-29.148039,64.121881,236.209627,222.714494,15.645983,-96.744334,-158.399354,-84.464327,73.919906,87.418756,74.101186,2.542055,-73.659352,-255.981706,-292.572207,-157.065542,43.832021,71.549796,1.729213,-51.177987,-123.739997,-141.331468,-153.277165,-153.199083,-151.83426,-86.268974,-42.04578,-55.982202,-125.491073,-237.087193,-202.419685,7.859218,145.537622,149.450319,88.493101,51.985188,-42.48686,-99.845355,-178.199778,-188.707729,-148.689657,-77.003819,-53.067391,-18.252024,-17.850781,-76.484016,-100.344684,-93.210685,-73.194045,-32.441571,76.107622,63.119814,-111.86937,-185.027353,-177.431608,-138.079771,-56.46904,99.772825,153.974841,57.625484,-52.028032,-175.635524,-160.767979,-67.183524,12.675512,47.991549,86.344052,84.934177,57.508553,10.236506,-89.399877,-62.154608,152.964501,358.289777,386.343214,291.691274,211.684846,64.460759,25.976912,67.474095,139.195123,153.47867,206.174297,224.828786,86.179702,-47.902854,-170.567852,-119.496111,61.731803,186.467479,197.035605,109.870467,46.307098,-38.898188,-46.974733,12.459791,149.716314,243.244715,373.56494,347.924666,153.616426,71.570457,48.534752,65.40662,65.152807,90.586114,110.174547,93.734228,56.62211,-53.1931,-114.25311,-179.183173,-132.61004,-100.80454,-105.826021,-142.57086,-211.718615,-231.392829,-236.368935,-212.851492,-146.949097,2.281528,108.177084,161.26107,91.489348,-63.253365,-108.21777,-115.040554,16.783345,115.347549,248.921371,238.236787,58.953791,-51.575323,-127.230635,-93.551171,-3.260059,124.323043,167.174583,44.071624,-90.911618,-300.553913,-350.065417,-353.623754,-254.904162,-196.662945,-116.839916,-102.405034,-119.381549,-152.067666,-213.850702,-196.31408,-20.51562,205.784258,251.197613,161.687011,87.341127,-14.449181,-53.798573,-86.785511,37.399922,139.453479,236.526782,183.864434,-21.094279,-108.406763,-182.60448,-162.305886,-29.457431,128.820104,164.662635,113.417482,53.883686,-80.548111,-128.790513,-68.314535,167.954977,274.065886,321.901737,273.079093,176.647025,152.379673,103.387602,77.661203,87.871355,222.754724,285.180458,252.227363,163.932325,-21.154789,-53.945716,81.12391,261.731103,315.41143,420.670662,447.216057,342.997679,237.217838,91.095756,85.221346,118.769776,139.698136,155.018816,135.289115,75.724135,-69.853112,-85.585264,21.75384,69.334351,53.98408,43.398096,45.022338,-31.798027,-120.773017,-245.910235,-237.435074,-156.258896,-22.53603,76.157455,194.072164,147.614802,-93.281586,-191.56706,-197.936684,-102.526577,-87.494123,-81.525485,-54.735058,-14.417237,-46.988161,-123.395642,-99.561902,33.304417,179.560268,239.240458,229.067391,144.839719,-71.379265,-121.107723,-2.066048,177.908633,191.706177,100.273751,71.273468,73.716861,23.436183,-170.957931,-205.326053,-65.710679,143.896833,201.211966,157.54796,68.603061,-160.251076,-230.575868,-141.680171,27.794219,71.515483,117.827515,111.364348,21.742299,-53.669555,-211.590583,-245.815086,-158.468473,0.013812,24.069478,-85.718146,-153.700409,-141.130777,-63.134218,62.268305,-3.616121,-28.670956,72.677329,132.577927,77.326103,-23.417238,-153.019034,-122.494434,55.470386,149.006221,134.785467,63.28598,33.306041,11.241002,21.908971,78.35145,140.809254,175.482061,241.379578,241.498811,131.258573,47.020419,-65.023962,-78.234628,-11.819495,202.567055,296.949082,315.148886,270.746584,193.021679,161.291971,100.806394,139.274548,217.71696,362.240062,358.608043,217.948422,127.110297,-48.970154,-105.168052,-98.981991,-13.289709,25.642571,82.967293,107.872052,99.420524,49.172995,-33.206905,13.902233,69.701598,158.120972,157.531962,87.85231,47.580947,8.897753,33.417118,163.463769,275.632316,279.282221,182.899541,134.712709,68.298682,24.095607,-42.230403,-2.042072,55.252088,177.033689,195.312521,73.590764,-43.583813,-225.107172,-239.156445,-126.691624,47.716084,83.824664,25.251736,-16.987186,-63.99381,-79.845309,-98.957546,-67.228194,-32.11756,0.829,-17.962031,-55.004323,-61.323765,-67.016513,-38.79028,76.344914,160.779076,172.050231,98.632924,35.65113,-39.18243,-36.700175,9.659912,88.69291,151.424052,276.191121,302.599688,250.35462,187.464684,54.47114,2.614534,-24.95829,17.269282,-5.943539,-134.7476,-163.692724,-122.943211,-116.53157,-126.743555,-44.781415,13.078402,36.649181,-11.67758,-119.9899,-159.989427,-208.887595,-168.877064:72.277417,150.2753,187.140486,148.881188,75.863707,-19.722924,-25.843278,16.092241,77.972002,78.664441,95.932222,139.012688,175.362851,138.065453,31.154485,-1.801513,-35.455777,-19.903786,16.913089,28.650225,-25.551353,-129.850089,-130.016737,-41.81174,10.645546,-10.426874,-73.169718,-108.592291,-190.466951,-202.09145,-179.959359,-185.334538,-239.539614,-230.479439,-185.322941,-127.831939,-138.19855,-157.229696,-130.537654,-27.406851,49.35249,64.471537,117.633809,163.073406,184.754678,135.683602,-30.349514,-93.027468,-59.754449,119.846917,200.48582,262.066104,239.556729,107.671495,29.304378,-39.346144,41.437629,123.196958,278.768846,298.662665,217.498882,153.553742,32.537387,9.548189,58.147474,89.414189,89.495359,83.47334,63.946595,-11.877635,-50.179785,-59.366914,-1.777565,1.170278,-54.49184,-78.26133,-38.503745,-10.464916,-51.877093,-58.374303,73.194522,205.317811,221.755906,160.379371,128.567119,130.424079,127.827619,93.810828,63.112639,68.307768,131.608163,143.98682,67.384608,8.73188,-37.452418,1.381826,134.121857,167.045417,140.609595,77.963657,67.954654,38.733009,-2.532279,-1.785842,167.48684,258.84578,383.025714,381.726833,221.271728,121.113691,38.919854,39.266845,43.281953,119.767759,166.958732,193.025693,165.533625,23.215446,-72.125273,-196.745469,-137.547667,-68.07035,-9.276273,-32.882995,-80.427555,-91.020043,-76.688997,-18.460505,134.754956,172.384121,180.343851,177.798798,124.147719,-50.383566,-110.423571,-103.073024,-13.912982,45.785045,178.919626,208.279492,128.523518,44.007153,-85.418511,-91.262438,6.516304,155.034902,213.134318,213.466749,136.258913,-115.743039,-221.8008,-231.338967,-98.713161,-57.088728,-26.066572,-45.091471,-157.529421,-225.850977,-308.188801,-281.6155,-97.022951,74.715528,119.899037,92.220834,3.001322,-209.461117,-246.1445,-118.191901,67.702042,121.038929,181.054104,178.040509,54.671209,-17.704082,-52.257335,-13.527549,86.218693,133.073922,150.783496,164.243086,134.00292,11.794211,-61.709771,-179.960829,-181.372824,-130.896282,10.763161,45.216453,3.53096,-46.237327,-145.028202,-151.789608,-62.944868,52.119459,81.891741,3.756487,-80.222348,-169.12439,-148.707817,0.909152,242.863421,333.512959,362.318487,325.420123,260.820795,236.942521,166.562726,126.701806,58.237815,65.315497,96.640944,89.254407,43.74854,-8.425621,20.697817,122.13297,58.880375,-19.274096,-57.301134,-14.560024,10.19073,-48.254224,-207.122871,-243.493563,-184.097584,-97.948734,-100.083672,-155.2276,-175.577531,-239.887632,-286.506527,-287.845815,-145.192242,-70.871221,28.842936,54.592814,61.722613,44.623505,-35.524284,-68.752709,20.860686,254.82357,328.504076,272.04729,192.341963,114.783277,108.596558,112.106445,190.864655,236.517722,242.961568,197.401188,80.873697,23.780009,-86.079495,-96.56233,48.746466,259.924892,314.305172,260.084968,193.324572,128.317929,134.424503,165.907422,158.296487,137.624991,98.978775,56.683664,-113.192003,-188.555034,-248.722357,-253.60774,-191.683742,-33.104972,33.834179,66.502017,41.08907,-15.454886,-33.018936,-59.077281,-59.3615,-36.64943,15.325234,12.552901,-52.054978,-85.594144,-128.352008,-143.94389,-141.096495,-14.509987,48.169874,-41.645714,-152.95756,-223.671541,-180.410307,-93.574469,-41.428098,-19.484902,59.288753,124.544272,204.967491,163.935532,-28.13054,-70.707759,71.436642,229.965049,234.154806,159.459128,115.457054,11.343186,-44.18631,-34.028583,175.8673,280.711188,350.269937,332.077286,302.612252,262.613365,35.272855,-80.482761,-62.85584,127.44751,154.310512,80.453842,42.947693,-2.189341,-30.482923,-66.300275,-66.510356,-70.025166,-27.92612,24.572095,129.26925,150.606234,105.613968,69.106879,31.676007,64.837323,113.675484,167.252347,138.277475,83.499522,100.760216,158.322853,143.090188,133.213031,136.362486,123.703969,61.614117,1.556588,-203.476061,-270.653804,-146.379919,104.69146,150.616828,9.470606,-112.669105,-230.143369,-198.311022,-59.827843,3.438921,-8.216074,-26.045483,-3.827778,46.642444,41.538166,20.32078,50.236471,166.796978,220.851054,207.580195,93.579514,14.755768,-65.643822,-45.625986,56.101986,83.157662,68.340478,115.977602,166.687201,214.63416,214.310305,183.223339,150.531647,69.63805,33.958135,32.221726,-39.004106,-108.150972,-207.713474,-213.820765,-142.713326,-63.516583,-56.798306,10.378599,77.903201,79.61254,9.495765,-86.469607,-73.386367:-37.304707,106.281003,113.782086,24.497652,-24.63326,-101.803201,-150.479544,-189.639638,-37.972459,66.156993,207.247328,213.311583,79.956735,-24.227954,-149.90381,-132.418299,-18.72089,46.77137,66.285691,26.463711,-57.970155,-243.821874,-268.51489,-147.584193,-18.688923,23.604099,99.060865,64.463327,-176.010197,-259.595193,-207.391991,-144.914164,-76.93811,-32.383165,-22.913905,-51.012808,-76.673601,-139.669257,-162.981374,-81.88572,138.109188,205.729152,180.487295,134.700361,42.390756,-29.893279,-183.921442,-201.305294,-88.643234,82.254046,140.263092,150.480749,99.047173,-52.512415,-90.384468,-15.049164,123.505461,182.293944,263.694318,244.091676,48.007934,-72.177685,-173.262716,-134.395006,19.508482,153.43185,184.432762,109.957342,18.14168,-140.239941,-169.265436,-110.837791,-5.933282,25.979418,45.676347,23.507148,-45.454888,-78.012743,-148.770729,-140.595187,61.73417,350.398866,403.847805,246.942454,131.542521,21.755317,10.349284,39.039321,146.699499,194.180822,220.926173,189.98052,27.32709,-68.684803,-138.535015,-89.546157,83.079758,199.823206,211.548834,146.849075,95.816638,8.104976,-19.126879,18.371275,195.211699,310.874945,460.170864,420.2983,140.747183,-1.203639,-94.911395,-47.017878,75.997216,145.951537,168.845663,131.271037,65.238358,-111.699436,-180.053358,-169.417378,-65.137144,-37.671872,-46.163991,-82.227697,-182.57437,-227.430637,-271.588164,-243.260711,-75.516674,172.520525,289.095779,319.134645,199.596619,-110.479114,-196.328029,-133.31334,98.391174,213.895884,369.130604,361.100562,130.310117,-31.127073,-193.760607,-143.692463,84.297446,234.933571,244.359399,99.01553,-26.900865,-252.864229,-321.405315,-299.499943,-138.411519,-80.627776,-21.818553,-21.466981,-146.131541,-255.63307,-369.599448,-318.871557,-110.413861,87.943048,163.884174,150.619739,50.838934,-182.260499,-241.167922,-176.476362,42.523651,158.940099,269.651621,225.251097,42.43022,-36.173675,-138.114633,-138.497511,6.853,152.104985,159.071379,96.155598,56.329827,-43.680829,-103.893313,-144.970778,23.684593,145.7538,273.686373,256.179342,165.376251,112.648499,-15.269215,-52.478401,11.00703,153.710484,179.638986,59.375865,-39.151451,-135.557541,-115.938841,25.238023,252.627784,381.47751,531.668196,486.782812,258.326791,166.808491,75.767277,50.967663,45.883887,136.181423,183.370736,164.498046,97.473104,-32.174192,-25.39071,122.617711,118.88572,50.732755,24.936509,70.324867,45.763526,-62.6427,-255.033992,-252.692811,-116.54429,9.77358,58.847107,80.131714,6.42306,-254.811224,-330.768901,-204.176092,42.295804,114.706215,153.996983,124.610294,1.964135,-62.749565,-152.895009,-142.594368,36.921629,293.675041,374.050933,285.239703,142.046877,-85.761071,-104.906614,42.385223,221.756519,247.567934,227.511383,214.838634,146.975207,49.724662,-212.48241,-264.266621,-56.79874,285.611306,358.310605,214.800072,71.646933,-133.589679,-158.114797,-69.723702,39.837704,69.983786,96.558619,80.680194,-31.51479,-116.443633,-270.86458,-290.429253,-157.179325,49.679059,114.551152,98.393111,28.306357,-92.816614,-98.552375,-36.286302,44.303446,100.77691,167.090712,115.558863,-80.343348,-139.461808,-131.120226,-97.187554,1.368851,160.030337,212.029079,119.069505,3.303224,-176.784943,-202.486702,-92.137332,119.832269,198.097251,314.047191,334.632899,170.097429,22.782298,-116.806773,-68.09669,97.581326,196.972317,223.41075,215.73552,178.232122,84.526607,64.035632,120.299824,220.276892,268.153668,364.337167,387.930716,299.386221,170.163934,-137.855206,-203.491064,-67.608107,104.904042,117.801047,60.830892,29.286969,-65.39208,-128.565936,-129.07175,45.548838,98.352798,50.254411,-0.980493,-53.686867,-72.675617,-124.602182,-127.143039,-37.758003,139.471229,202.004031,155.174803,80.689779,-13.884869,-26.628805,-8.274849,98.738508,172.995026,225.660136,159.696107,-62.199337,-143.280411,-212.024503,-204.742059,-54.728559,121.181964,139.608116,62.256536,-3.225027,-116.411494,-133.394051,-73.902167,42.059836,90.501605,108.179297,82.45755,19.691905,-10.432196,-20.204922,28.4737,174.153863,285.294902,303.51298,171.232471,45.830234,-135.95945,-158.872411,-72.232838,112.731437,187.49668,267.134518,271.479303,197.625339,134.67731,2.453148,-35.920151,38.661836,157.032885,113.90793,-148.431181,-256.893091,-277.125129,-221.5668,-52.440379,99.980578,126.597298,127.688523,109.939499,-5.839133,-92.826792,-198.990309,-159.381199:101.741939,87.114148,110.702417,131.258358,90.983237,35.723546,47.980572,81.595836,122.682854,165.018159,261.9553,276.974479,223.771472,190.175476,166.827517,181.964913,231.604795,223.355527,224.974839,233.951468,210.971588,163.767607,168.164814,214.745241,200.948862,175.133341,160.784889,160.60741,116.521707,68.91082,-57.949194,-114.53925,-142.100724,-63.545176,-35.791815,-60.290848,-91.099243,-127.358108,-129.658127,-101.531568,9.585636,74.4056,135.261135,132.823406,109.039478,72.57609,-50.634358,-76.744667,10.862932,133.618749,184.027213,258.494327,262.02088,184.264914,129.621502,112.024078,201.949374,225.153984,201.678886,167.359788,96.085397,94.226366,152.546322,159.413306,75.404925,57.820277,125.435168,235.985592,221.052421,138.274052,101.110224,53.924408,57.060043,44.468324,-17.408827,-36.775276,13.276167,63.244532,32.422178,-50.353331,-156.789835,-50.111189,45.908878,105.287957,44.805213,-81.243618,-88.750075,-4.65631,35.102275,7.031464,-33.228708,-25.531938,-3.328474,-3.30078,-20.81834,-11.353537,64.255036,102.087625,100.112767,123.5587,129.049231,44.539527,-34.188722,-128.755745,-88.458821,-28.646193,146.595273,207.262791,150.714379,63.147022,-73.33658,-91.865221,-42.956983,49.361245,94.498466,140.556551,117.027851,-11.832762,-72.796232,-94.143089,-8.256332,60.213164,212.232935,247.969542,187.704336,133.609521,117.57949,176.944622,329.941951,320.145446,252.119913,86.740455,21.198687,-44.29067,-63.647038,-103.546397,-102.19115,-79.251092,-22.466159,-9.294927,-35.912118,-76.202538,-176.999992,-187.520551,-90.347284,-80.029017,-123.646453,-155.86469,-151.431529,-213.322742,-269.959437,-275.453736,-134.810163,-89.457125,-86.068737,-100.066244,-107.895695,-87.812045,-50.227616,-48.795267,-8.448488,111.1267,162.443779,149.068097,81.185032,-97.019776,-166.93966,-141.445763,57.883802,136.995269,211.56283,226.432792,227.846301,208.879735,121.548179,82.267895,94.115942,135.109251,137.521898,100.729862,57.415617,-53.827256,-121.715352,-248.586241,-295.698573,-294.632821,-241.097648,-196.822801,-182.871949,-231.927596,-311.249524,-301.684243,-256.467866,-189.349899,-132.483036,-97.52067,-146.833659,-263.429871,-267.63198,-153.53014,-70.935152,-56.144695,-19.342115,-24.41162,-86.924794,-106.201711,-137.979243,-166.54239,-173.170046,-81.15057,-11.438465,75.572963,57.669875,11.757491,29.264328,72.26669,-33.170316,-99.075279,-34.15506,78.530522,180.776309,110.029381,-101.670795,-139.00984,-74.882403,-59.959435,-108.118136,-222.688769,-232.444889,-125.249621,-49.317418,53.154166,71.381055,97.878677,261.502286,326.334108,299.852913,254.603723,171.206046,133.245043,111.270365,199.945663,262.458335,287.428255,225.445487,63.143153,22.755899,60.159669,88.579102,65.066658,61.898437,88.652651,71.037469,15.453379,-109.656775,-134.481898,-63.761542,75.275234,139.284969,172.9548,157.045355,209.258474,258.870026,256.693149,219.994293,236.59097,263.096123,216.958156,-4.768351,-119.122849,-268.752518,-303.825137,-253.485934,-70.620754,11.925653,71.133757,65.376741,80.014747,102.415406,144.820365,147.948701,122.213124,49.950447,14.837728,-74.967282,-136.174602,-264.382396,-292.833212,-200.738707,-33.499859,-1.971117,-127.069169,-231.645383,-289.141046,-227.834828,-69.287679,12.319043,26.437762,62.274435,94.795721,129.840767,107.275597,32.406784,20.142875,77.579894,129.470343,97.539083,-58.495626,-129.21923,-150.441599,-99.966757,40.816263,158.248069,207.421833,284.824542,294.834991,223.697489,132.007952,-109.029294,-179.738537,-102.427064,74.831207,99.51039,6.847472,-58.925857,-145.183093,-167.810923,-154.752339,-73.771376,-30.229674,61.732043,94.748738,107.930437,92.297716,8.648927,-40.967202,-81.180659,-28.054338,15.703401,67.06566,70.61046,111.219351,149.323841,195.702106,166.460544,135.585886,110.866588,105.809018,15.431837,-66.812399,-215.867297,-228.11261,-88.125139,66.435461,103.208195,71.344253,-0.790466,-122.921974,-121.3654,-38.383379,9.445084,15.716741,41.644754,54.926432,58.587212,58.525363,100.839508,145.77668,205.290949,192.252586,202.299493,220.492635,188.237847,65.821973,1.25179,-75.871657,-27.715968,18.088098,75.794415,76.286862,53.116689,52.905889,62.113097,42.633246,-44.963254,-145.984357,-201.963512,-281.054743,-293.839524,-290.571331,-267.114985,-186.107899,-128.931091,-118.101113,-92.715649,-75.436758,-101.040281,-158.772498,-282.512702,-293.413863:165.71303,151.355051,134.186003,76.934874,67.503941,110.914312,116.775824,62.359224,24.546432,34.482904,91.442764,125.488527,213.932363,243.122123,181.29563,122.787401,65.130741,70.678272,93.487272,102.175819,55.826219,3.348106,49.655133,151.065387,73.10884,14.981541,-22.780425,-31.026367,-40.409833,-27.071184,-98.560784,-189.292266,-262.203655,-175.49281,-156.085638,-166.284424,-141.265865,-30.559804,-6.507668,-16.998299,90.251071,152.236509,194.051195,211.549372,254.482096,243.235573,169.105864,144.541238,116.400531,164.290343,250.362459,382.851204,373.99692,259.92402,185.880839,89.608445,132.667205,175.638877,242.027715,249.510387,191.684616,143.462965,58.607244,37.146702,23.441595,29.588276,51.418617,114.921751,134.981778,96.113916,47.837348,30.385543,116.434608,134.184438,100.952526,77.42641,78.587831,78.577944,-9.567054,-62.449312,-38.527407,123.899157,178.522392,163.782824,140.393076,109.640014,86.887547,91.682483,154.543247,169.179678,148.716374,129.601364,128.123343,138.40279,120.377376,100.168372,77.07909,58.256845,55.532733,72.009179,79.137387,45.562832,8.284722,-33.60141,43.882127,133.063577,345.310941,390.2315,248.140405,135.458089,55.806654,80.242894,150.068238,241.919638,267.59312,217.416306,161.597224,21.720968,-54.245437,-110.059464,-3.954387,64.079912,149.554127,159.813725,169.998951,187.720827,210.535175,207.541218,199.434008,224.111781,263.528124,317.743399,277.829697,95.95655,8.362549,-86.310695,-106.971298,-90.294417,42.43531,105.127028,64.166732,-8.030272,-135.031077,-172.495933,-125.262757,7.878997,64.973255,169.346725,188.215921,58.295851,-63.438521,-181.234659,-20.771526,74.469986,106.574839,36.364853,-174.29553,-224.298771,-82.127559,29.173414,112.355435,152.102931,222.474144,307.341642,236.33041,-62.210422,-174.101737,-158.52607,4.199308,65.361226,143.17814,150.230536,98.308707,64.064808,7.285228,2.466322,44.929982,27.33352,-11.834508,-43.680948,-37.031893,-117.768054,-213.286848,-373.236436,-400.529852,-375.359621,-295.434065,-273.467324,-302.672367,-321.394403,-280.935755,-238.953807,-200.893702,-176.54945,-134.425314,-59.457398,-64.575288,-122.613463,-141.883517,-107.905679,28.692993,104.2537,188.990922,185.022949,147.412757,129.729284,52.544363,3.319462,-34.133951,-8.879818,16.340542,84.92882,106.438421,90.821598,58.688708,-8.082109,-72.798909,-99.977854,-68.475108,-30.784035,-37.296149,-82.072158,-171.001804,-183.397242,-105.964067,-4.861756,-19.777814,-155.018036,-185.858638,-124.577459,-104.203195,-157.198325,-210.599153,-195.354049,-60.971312,14.628972,69.05918,55.43541,7.627656,-5.598431,32.130309,149.091114,211.71034,225.643256,154.058844,-11.958294,-49.465083,-18.712914,61.542032,69.69687,29.859829,13.621368,16.74102,23.802352,-10.585403,-35.604075,2.999379,162.3694,234.328016,215.17089,160.576065,191.842223,247.260047,218.730812,109.335292,81.002482,6.16167,-76.988729,-321.682247,-427.891701,-526.64747,-521.755518,-414.857488,-295.974264,-257.561455,-169.776593,-130.526928,-123.278307,-140.168068,-151.889816,-127.36724,-112.056336,-104.376923,-103.2888,-86.351368,-102.887148,-219.333553,-260.678445,-184.427706,10.058571,51.424054,-113.177211,-242.529177,-299.859597,-227.730973,-48.564331,58.511471,62.689628,47.111322,85.476791,229.676122,245.701875,123.930069,83.321685,151.66577,232.483205,219.598892,88.216859,0.320196,-166.764222,-220.317604,-149.953174,60.755859,130.286475,212.118036,255.756952,292.3901,243.424396,74.559497,12.693828,0.461346,125.446404,199.264902,194.726335,101.189466,-105.002395,-176.026319,-213.47735,-69.84365,27.252666,160.47166,166.715341,102.875286,77.2658,10.39702,-40.035591,-88.351891,12.138777,101.814491,172.976745,128.22868,51.687747,66.954463,146.792833,129.654698,71.971363,-10.897213,-15.527992,-38.300744,-91.906936,-259.586136,-305.441269,-207.98613,-13.809711,35.432465,-59.270374,-175.785016,-315.430381,-298.913091,-210.251435,-174.142097,-161.11352,-76.765788,-24.914408,5.568624,-2.948312,36.257229,93.919778,198.741117,203.60394,187.852501,118.693345,57.194354,-59.415737,-94.653873,-100.255718,-51.152493,-27.546094,32.566659,52.508138,54.100465,63.778583,69.382125,38.66238,-33.304116,-60.559979,-76.51246,-156.1647,-201.619759,-221.492153,-198.229794,-163.928403,-156.031048,-142.002013,-48.102928,21.088543,73.504469,45.88939,16.583368,35.35299:-16.084201,19.396401,47.813451,78.514077,55.852166,18.047224,33.213785,103.665306,114.053225,108.750537,187.719547,236.703019,192.915914,119.087585,34.359542,53.494548,166.989563,244.883955,226.55956,104.304012,45.067195,-22.547319,-36.287262,36.501936,178.293003,196.009995,129.780904,75.708938,-24.113389,-44.03467,-10.953196,9.756671,-23.488109,-57.989307,-39.222781,-58.379388,-96.469593,-120.680449,-125.871511,-141.438598,-23.278628,65.413884,112.826941,65.5086,-33.410574,-66.333426,-144.198536,-176.292055,-114.435768,93.613301,172.12825,175.276942,145.953689,133.467999,116.221114,86.512354,204.746921,252.641382,184.815304,112.888309,30.693804,24.885104,21.993325,14.868632,40.988244,103.993373,129.225842,139.449549,120.46131,66.467834,25.495915,-74.881723,-98.363329,-88.912902,-60.132191,-36.335432,26.336528,36.812964,-26.63233,-52.705425,0.24128,140.338585,198.681057,209.631985,169.58904,45.446127,-11.684863,29.403046,157.260825,142.823025,66.064608,57.763008,32.113142,-0.759785,-32.2289,-10.116055,79.209544,165.029775,203.545447,220.511706,176.937067,18.222897,-58.396915,-99.059723,27.121645,130.491709,291.712607,278.695118,118.784047,50.743067,-34.013541,-70.347906,-61.199168,49.378166,69.346191,24.910882,23.041912,68.544091,57.494783,-48.116021,-102.682129,-70.331623,66.989242,102.296019,50.003696,12.460565,-22.722307,-14.084998,55.002037,172.678957,243.058993,265.77246,186.945385,-26.13603,-102.856616,-129.734707,-26.429583,40.486879,137.482412,141.446114,74.236302,20.729333,-96.432311,-107.493731,16.204318,91.412326,85.528277,0.139122,-86.256143,-215.68618,-232.450418,-229.746933,-155.97011,-92.946596,-25.883628,-37.938252,-58.231415,-52.173274,-79.97062,-103.320105,-63.729912,56.438519,104.612077,79.168435,-7.455475,-188.837606,-217.302795,-144.974283,-9.452866,63.263558,152.838095,142.801874,107.078118,108.775307,59.968039,26.415486,70.141794,167.399568,175.916075,109.273485,54.082295,-61.612024,-106.301195,-104.077609,-28.026641,11.423514,118.291501,140.271815,45.538498,-23.315659,-118.001924,-146.234769,-119.330512,15.508667,54.206691,3.112179,-58.716204,-182.744236,-200.475225,-58.973044,150.439373,223.48201,296.880217,269.490446,105.880436,17.119291,-117.612999,-141.118581,-72.631645,14.974793,25.207842,12.889788,7.197845,-21.779569,-43.932212,-22.542447,25.569661,34.583307,57.626508,67.572413,88.250456,75.146315,-69.731717,-146.55139,-179.93878,-187.970957,-206.016403,-220.459762,-216.402175,-213.426736,-216.23795,-167.345668,-19.652775,48.24056,131.108983,145.597206,125.914796,104.169255,35.275219,3.661686,36.976288,171.74703,231.596846,243.144884,173.568739,3.14349,-26.33906,48.458894,145.145064,166.577704,185.347736,180.84127,102.822549,26.970329,-180.869555,-250.730904,-132.362004,154.744223,230.435261,170.646807,88.601934,-20.472032,-33.814789,9.055289,108.817295,156.166899,204.858383,174.002832,4.275018,-84.505605,-207.43413,-241.574967,-184.49358,21.220514,97.952374,83.476953,39.909906,23.681556,44.53814,121.974725,192.029202,188.771765,89.160559,13.469615,-95.270743,-102.091875,-76.617601,-85.463495,-80.542923,51.65154,86.308942,-31.662448,-128.699245,-209.759996,-184.847095,-78.955367,-11.74388,-3.553001,79.283895,141.516286,130.796609,49.36314,-91.633478,-84.586852,63.019877,167.415656,162.91531,73.039733,22.053806,5.971221,31.486216,59.999079,96.074885,148.520569,288.768916,326.573604,272.037836,198.881448,-9.816125,-116.607133,-166.772403,-28.555401,25.792806,49.029755,27.148762,-106.973887,-189.338362,-203.606681,-89.208199,-40.213287,59.898402,95.610167,78.316805,29.678055,-91.340871,-134.919947,-104.660944,79.345132,136.562337,44.336699,-28.273888,14.287273,99.921249,180.489964,122.443675,114.36088,181.285741,187.433341,76.200324,6.68906,-117.420164,-156.122339,-74.513237,102.929473,135.651009,68.955271,26.134532,4.226763,-4.380936,-57.386919,-49.442218,-10.641197,76.328608,100.431285,101.603266,82.700366,31.423222,38.897638,133.385795,212.787354,238.28041,227.481314,168.143848,24.113116,-12.803468,9.211034,71.640944,87.951199,131.362728,154.207084,135.10458,90.866832,-5.415973,-16.094575,46.893989,10.28526,-59.434612,-175.077782,-207.581202,-236.559603,-230.26618,-126.408473,21.850257,44.704828,61.591661,76.342527,-20.314903,-128.951451,-262.208902,-236.910583:right
-320.704917,-389.677469,-383.087914,-247.240449,-152.676248,-8.378298,31.363438,40.881905,-17.650141,-24.705187,31.614728,74.549253,173.375601,229.052347,348.670719,400.82265,404.66563,282.871437,238.047945,263.186948,297.524426,308.928532,299.428913,260.14702,143.089069,102.921688,118.140425,148.916527,211.629152,198.929309,55.746105,2.246261,49.368265,161.185611,192.804506,221.467374,234.621635,240.335931,216.356935,148.805743,204.129488,286.112723,403.754531,406.337024,352.462568,328.224857,368.43119,427.917586,468.817017,380.223906,361.335418,365.570177,347.238215,334.654626,353.990792,319.832066,202.701289,208.471452,356.810549,411.807509,426.408632,433.181373,460.728336,442.273398,325.14109,231.007899,225.288025,246.578993,251.19635,192.687306,125.570856,39.419175,73.168363,100.35914,158.596748,197.774522,223.353829,188.062703,117.783383,101.973178,63.621947,-0.050558,-13.013666,52.307324,74.985867,-24.544092,-94.572117,-131.134303,-99.612913,-56.525851,105.625121,180.023757,236.773652,226.843217,190.967236,171.449837,120.434551,177.503012,242.602361,285.986689,278.889852,262.360692,215.368012,24.550885,-158.969488,-182.696508,-99.720089,-40.609921,40.899654,59.658507,80.499116,106.053093,184.517965,207.011408,178.230307,84.324412,51.990055,54.522768,75.843209,107.878051,92.33055,91.629899,176.348492,231.323142,197.028829,116.395479,50.341406,73.451755,56.05152,-4.711311,7.990749,49.998472,53.313152,46.193261,32.406621,-13.180413,-37.096779,-28.104575,59.637219,131.974244,216.208767,195.635318,89.386914,22.45783,-120.967076,-142.133528,-116.89619,-122.869612,-135.79659,-91.460005,-64.997423,-83.382137,-128.533976,-129.070833,-61.329327,-17.317849,17.460629,-1.375625,-42.437332,-47.568457,-82.166768,-80.40508,-60.93697,-81.722988,-100.352105,-73.154064,-52.75855,-117.08398,-284.106833,-339.152612,-330.025287,-270.849556,-126.272399,-101.772889,-189.598767,-261.890393,-377.489951,-362.618923,-302.56643,-244.072804,-272.129433,-332.043968,-338.294757,-303.414212,-300.420868,-325.723621,-319.67316,-272.220089,-157.306011,-125.141535,-173.722839,-240.729238,-295.095271,-168.129242,-109.759044,-118.393798,-169.652582,-258.628633,-251.243607,-138.846618,-56.22539,-32.870742,-12.260582,-36.489178,-69.102547,-35.897095,41.630521,48.068374,13.790291,-8.256145,18.453724,108.946242,133.64215,126.243337,108.067568,45.019039,-31.031305,-22.018351,68.476306,92.80401,108.227782,113.875409,47.533079,-22.524192,-116.054822,-115.692982,-89.104269,-39.672924,-30.169354,61.171147,145.309147,197.984833,46.272577,-7.965289,15.129711,48.566723,42.212178,-9.707775,-81.711022,-60.52162,-21.708221,-56.82834,-60.533309,-38.983117,-37.40407,-86.237944,-120.996975,-121.719842,-25.409203,16.164693,13.227839,-10.146442,-10.598161,11.273853,71.686704,97.931991,36.324571,-139.407516,-165.251419,-69.309899,-36.543358,-79.663778,-106.902514,-97.935602,-79.727547,-89.506742,-136.340813,-160.058973,-118.962952,-46.475868,25.314858,-30.100754,-175.593718,-108.391784,-54.789995,-114.449078,-182.21472,-217.261373,-198.856972,-185.745423,-210.62671,-230.5133,-292.983694,-310.501689,-239.044442,-203.86564,-304.656405,-390.867084,-454.345364,-421.644803,-391.153961,-281.933375,-209.906685,-128.183325,-149.517324,-243.569168,-285.524178,-246.011743,-60.210017,8.498325,17.907547,-18.980878,-110.654304,-128.748762,-124.025466,-138.074873,-120.702175,11.960524,84.231786,110.475932,58.189172,-73.527703,-97.428669,-48.799544,64.177163,83.010958,64.178665,29.101187,-78.603021,-100.580978,-52.839915,-41.689999,-69.477377,-122.886877,-116.128159,-44.641783,-22.482171,-89.563911,-201.275456,-190.561063,-60.17182,-18.839604,-118.677238,-219.628847,-289.494597,-261.562642,-255.801501,-238.96023,-212.175545,-189.391735,-171.53427,-161.270152,-189.108207,-184.856313,-78.975012,-54.943114,-79.387722,-88.048615,-110.953992,-159.452219,-269.680458,-263.033856,-109.559611,46.213829,65.996635,-41.283058,-124.150315,-182.084554,-137.652078,-52.455453,-72.671338,-59.05594,39.372119,90.062177,154.743206,154.216723,72.780675,19.082763,-46.612128,-87.034539,-126.137062,-180.986968,-157.01852,-70.577902,-60.881366,-143.064423,-257.553047,-265.990283,-148.746332,-81.94409,-61.202701,-64.431482,-3.612118,32.25381,40.268361,8.018833,20.079918,67.951847,77.430102,81.449381,71.865472,-11.020225,-69.44655,-30.849347,102.768147,125.90981,76.707081,49.929078,25.015038,11.546585:-340.937184,-322.849913,-255.931755,-68.175791,1.997182,40.079003,46.656335,70.167247,33.235302,33.187416,124.090143,175.593274,220.615013,225.649161,273.04728,316.086143,332.336605,224.985478,195.015526,269.530133,309.785665,269.443824,232.505876,189.136595,169.37281,193.477273,273.837342,285.032203,238.27406,189.096692,78.565402,63.360536,156.851744,269.884701,286.345808,258.229152,251.831382,293.018845,300.897709,190.966143,70.415157,96.54694,261.705966,324.119009,341.625093,314.270223,251.046977,231.114084,179.772145,190.03897,251.822251,345.490494,327.433404,287.314832,309.882815,284.939353,165.725379,169.748804,306.664458,384.260477,446.071566,412.577579,307.122472,269.168477,218.713493,261.927293,299.335913,279.939,242.075515,172.400669,115.754969,-18.477636,-18.646742,37.777797,187.733042,251.890734,256.117312,206.686501,162.11469,158.115129,108.215426,91.543048,96.675511,91.274005,49.137766,-99.311113,-135.001792,-126.406629,-142.697319,-113.128468,16.209417,59.475773,77.341388,61.498137,24.900165,18.364748,8.629884,91.571235,178.600824,248.247494,202.558548,114.152158,106.8455,46.798049,-82.047589,-99.144088,-70.32487,-58.099219,-52.612565,-41.472031,60.461496,122.324245,164.896786,199.917495,230.810813,194.182885,121.725765,11.104162,6.731281,33.055298,60.002787,68.215198,47.605845,43.625133,56.0305,56.295099,93.456382,119.672245,107.945227,72.501511,77.886099,120.026525,142.044005,152.403621,123.085754,10.070775,-83.713014,-85.993341,61.685482,181.581859,290.703879,245.364793,112.327084,67.92419,-9.132745,-72.426325,-73.258732,20.455895,70.272705,13.342899,-74.000663,-196.289401,-217.739921,-202.435726,-97.166963,-29.127036,-7.764763,-65.105106,-148.828849,-153.727479,-203.828037,-217.248312,-187.21378,-163.816854,-162.274432,-121.317873,-98.555291,-125.734616,-202.764781,-228.203688,-241.320286,-212.036542,-107.225535,-80.692119,-133.787522,-197.127105,-306.00259,-250.080478,-171.642314,-137.54572,-211.769813,-327.278469,-307.745861,-227.897661,-261.130223,-305.526875,-291.777799,-211.441517,-79.231365,-93.399115,-242.171829,-310.780692,-301.419449,-98.715596,-7.285481,9.410103,-36.87732,-115.430951,-134.509742,-150.861909,-108.393749,-57.827428,-26.534875,-66.496637,-96.872035,-42.967747,69.317997,65.686165,-5.00687,47.850115,112.259819,183.798405,177.421652,97.727721,51.787284,-39.45393,-110.259878,-72.545038,67.675904,90.438476,57.412061,37.980805,3.502693,-14.050807,2.817977,89.919193,107.524129,52.412048,11.582504,10.173548,36.536764,39.439493,50.168215,91.60396,164.399989,160.686886,82.8344,33.408522,-36.60591,-58.404514,-97.253087,-85.68368,-60.110076,-25.501218,-38.147285,-132.59504,-153.571246,-42.295647,49.172055,45.118433,29.414121,32.373584,44.071904,61.56356,126.111222,142.016465,89.342333,-41.11396,-74.880183,-41.671572,-32.780483,-79.980216,-113.160148,-191.706555,-191.854042,-140.401809,-60.923785,-54.229872,-38.709643,-4.634679,46.945291,23.667075,-32.012593,-1.035642,-4.697715,-37.000407,-22.89155,16.081225,7.860966,-62.713406,-124.387061,-116.119839,-69.22311,-54.874706,-13.715498,-15.237792,-161.695176,-256.352883,-343.534236,-291.856915,-251.307019,-191.947298,-171.159148,-179.035103,-198.396414,-194.784325,-177.765407,-154.848885,-23.314839,36.409608,33.410233,-6.824934,-79.963466,-98.142381,-76.063611,-73.02952,-109.181843,-117.317025,-75.966319,-59.789844,-89.846868,-119.580082,-95.013508,-57.167505,22.664814,39.326048,70.964707,99.264154,109.281654,84.354225,27.734703,-17.716316,-26.109379,-19.943241,-23.17019,-46.515241,-65.054955,-122.425149,-127.160601,-71.702826,95.495994,147.372407,36.055274,-105.877639,-271.981337,-259.755473,-207.587416,-191.739356,-184.616298,-147.740059,-134.280805,-157.762763,-158.872924,-88.124125,10.000136,46.659826,65.961561,52.358275,-8.57846,-45.623002,-82.597786,-68.178488,48.242431,148.496991,110.298794,-15.797057,-11.574291,77.268155,92.723892,26.163648,-15.785603,25.31911,137.581171,170.685481,148.815663,115.424297,109.763649,105.787044,-0.479092,-102.543252,-123.999911,-114.16844,-88.169288,-31.245508,-3.528938,-18.330568,-115.619336,-120.809455,-30.898851,2.391602,-3.074089,10.996941,80.769792,94.992345,114.512884,152.236331,154.59761,161.923394,166.853377,141.400075,113.512753,18.013719,-59.400106,-23.259849,184.558198,264.916932,181.21333,42.415765,-179.503103,-209.246356:-310.971751,-206.703124,-119.303562,52.008871,121.777404,166.363167,135.371407,55.835815,36.372819,62.226955,159.563819,200.641188,211.917761,185.525571,189.694722,248.224015,353.246867,336.119942,318.400999,315.328097,293.758173,200.761161,185.292706,193.389586,192.005848,227.912215,265.929281,219.455339,152.375199,179.800692,193.689134,121.035726,-19.912545,94.797791,206.416713,317.352373,280.925048,131.997367,72.978027,-1.765221,-17.529451,10.013134,111.853835,166.657425,227.361892,221.588131,152.664921,93.477892,-9.074894,84.953249,188.014002,278.470626,223.11418,87.106016,91.722592,168.110235,161.644889,174.455803,297.095355,347.322193,340.236144,320.047842,300.280915,271.247424,167.530291,141.968307,183.615148,316.381845,351.904627,255.781819,165.725647,103.294846,173.951141,205.127218,262.974775,279.813105,224.82784,179.472394,149.60504,116.019918,-32.212224,-4.804749,88.617673,191.721462,136.201946,-66.926325,-125.845988,-136.106474,-168.868717,-177.574401,-60.415551,48.44104,199.389062,206.765132,170.392051,161.892936,129.407307,94.614423,130.161712,243.232526,259.379231,226.487146,200.786841,73.105214,-104.768878,-130.896074,-59.451236,8.775513,94.7415,73.960449,46.227481,81.397134,140.666414,155.352362,171.858921,179.261472,147.800088,45.167421,-2.59876,-61.365767,-11.477802,21.270208,41.995528,70.302933,158.638439,195.167842,255.688163,252.19109,189.840404,193.779005,212.95688,197.570278,169.905629,140.876805,133.673055,77.356578,9.88446,18.082901,132.181447,214.294263,297.109087,251.526738,57.217789,-26.228326,-86.151436,-30.91512,2.656773,16.819752,1.473836,-22.988514,-26.089175,-121.267188,-302.966338,-322.176009,-207.911065,-130.255764,-57.350186,-83.489599,-196.489064,-244.808837,-240.706454,-159.127295,-140.686812,-113.668766,-93.430626,-100.825159,-136.339295,-210.427549,-169.05787,-134.702535,-142.253301,-140.044177,-73.563418,-66.152807,-169.909651,-243.945332,-304.472479,-187.750794,-97.51613,-39.974021,-119.986643,-318.270236,-354.692568,-360.000955,-352.584714,-316.084496,-179.950072,-120.463053,-130.222756,-194.65223,-295.309153,-303.49334,-251.219595,-39.630891,62.979451,75.527554,-0.368451,-177.603932,-221.55709,-234.140286,-223.67833,-197.61092,-175.873186,-189.258693,-160.425271,-107.725853,-11.760871,2.492801,-29.955233,-1.681558,36.729001,84.418932,91.40447,14.189195,-78.768936,-256.537139,-195.154662,-74.515077,100.956961,113.383494,60.694166,21.43836,-83.463623,-141.814049,-131.629216,79.481183,172.598569,136.458988,40.06573,27.38794,114.977974,152.684863,66.843511,93.656337,221.229959,251.414667,188.702866,117.657858,-19.688182,-58.284967,-48.443712,30.810644,43.324605,11.438268,-6.860808,-52.286525,-64.178527,-33.890019,-35.328859,-48.576995,-7.308617,32.734167,71.708999,69.538557,35.431863,4.670795,-19.287974,-28.416149,-48.767401,-43.66607,-35.535652,-115.925753,-190.826417,-278.829119,-240.182353,-204.410598,-158.334445,-131.814117,-47.479309,-13.80322,21.043079,18.240442,-7.328658,40.723002,69.36122,108.767781,115.941821,35.361871,-20.75777,-19.014792,82.365715,145.483792,237.367239,220.06286,111.512713,49.898022,-101.459835,-173.14858,-222.350312,-115.720302,-55.569353,-16.107805,-21.783998,-73.836269,-124.806538,-213.477346,-208.41735,-151.074111,31.927053,89.033725,34.900973,-17.806261,-21.436697,-0.282118,-11.566842,-101.489524,-136.157904,-53.926685,19.800829,25.636681,-34.464123,-109.542821,-35.514434,17.528632,66.375661,72.657323,76.441642,60.008692,26.379425,35.805536,30.115595,-57.96345,-77.419826,-35.29563,-29.775901,-140.301766,-208.653229,-234.164975,-118.820564,-48.568134,21.11198,42.039268,16.85925,-76.292449,-251.984077,-270.724068,-242.449086,-163.752269,-98.441931,37.950645,77.324799,55.478109,12.787795,-17.707449,87.868244,126.109265,77.850154,44.148077,42.551436,45.945074,23.938283,24.494943,119.535397,252.872865,239.329133,116.432337,106.347732,130.659282,107.13984,51.726356,71.106106,91.447311,76.851579,74.078809,160.561949,194.256672,111.004815,19.58718,-113.756756,-100.875748,-65.026483,-16.942451,-8.477593,35.062505,71.765735,61.29979,-52.93656,-77.109539,-24.192242,17.546163,59.787161,70.738475,95.8829,96.992122,95.889955,86.154914,57.628327,72.363189,137.442315,185.25963,123.421927,-22.90809,-13.107999,41.11788,171.995035,223.975365,164.893617,49.677245,-96.743902,-82.01799:-292.072823,-253.479252,-198.65258,-134.923445,-127.6825,-48.71843,15.41656,49.679385,-40.0483,-43.794996,90.589376,167.53958,203.745973,176.57271,176.55383,222.530005,308.209531,356.988649,383.365821,379.543241,341.102127,281.669977,275.312705,241.0242,186.945466,189.159662,180.182298,138.721307,64.065736,38.979961,-45.082255,-95.091871,-134.462583,-27.472493,53.37579,158.636873,162.560273,94.412006,57.285812,3.840136,-20.068115,28.901787,196.841334,244.115408,232.937363,211.404247,179.372977,153.549657,101.670818,188.309787,257.462242,283.659136,248.45048,247.508284,293.668095,314.759162,247.283288,258.771914,385.300884,449.908459,524.033633,528.757701,447.722567,383.131004,302.493054,302.331166,301.79538,285.83413,282.623828,242.765885,197.636244,126.092456,116.660122,134.270509,187.217882,206.86384,217.918324,204.688348,120.761758,57.599833,-22.452174,36.785667,79.859117,99.08504,71.834443,-8.857445,-39.48334,-80.890319,-82.304963,-15.94219,190.379965,249.747931,262.051641,243.858105,193.365315,170.672428,125.188931,146.955915,208.753137,345.326554,379.564892,363.069779,326.086281,182.688398,-25.223178,-77.924463,-30.650396,36.805001,168.439436,215.804013,249.694642,226.404886,151.974291,191.644551,247.467689,288.490806,258.363894,159.240066,111.559717,78.620518,164.381303,209.97595,231.381112,231.648375,236.836667,228.51237,221.653377,221.648209,173.970387,123.874251,136.824645,194.650749,222.429916,259.397124,234.74874,55.98018,-125.220061,-128.427125,33.556203,129.889532,191.187762,148.711595,36.347322,-4.004708,-92.531858,-178.724846,-204.772547,-254.456552,-275.281305,-250.701154,-206.135959,-185.398881,-275.362885,-277.085969,-147.501635,-69.36004,-13.975183,-48.001988,-155.094204,-185.967343,-185.513944,-150.585046,-117.965562,-23.112601,3.50384,-62.278454,-115.316595,-140.473368,-149.141358,-184.670309,-209.803067,-158.308598,-42.587224,-52.489822,-193.983897,-274.604159,-398.592118,-367.311547,-283.902984,-213.837132,-270.302788,-390.525243,-408.982854,-412.202181,-408.518727,-377.154248,-264.684849,-225.079691,-182.432097,-148.232912,-97.068504,-117.949562,-187.652155,-103.52499,-26.611919,-1.320664,-65.276164,-190.525386,-206.138992,-180.882394,-157.064024,-121.415374,-29.792864,-24.853344,-62.528449,-66.575079,-26.243555,9.335314,48.918642,49.961048,56.178761,44.823453,23.198796,4.192508,5.307247,-50.254731,-96.243281,-59.282706,26.554336,40.908969,79.984028,91.145074,-11.44403,-102.07599,-189.687476,-62.067672,30.540152,90.641385,61.996351,76.826961,126.446527,138.114836,32.568618,12.049039,76.475279,117.736844,124.328167,82.845678,-17.373734,-23.886091,40.054523,43.511658,6.567129,-69.920963,-94.941936,-166.545063,-194.988648,-149.287498,-48.189644,-10.239892,16.69354,12.625881,0.300768,-9.533095,-33.963733,-49.744114,-97.843144,-118.019406,-102.535645,-48.557257,-35.882127,-87.970366,-145.547886,-249.87523,-269.605436,-253.420491,-226.757051,-211.516469,-135.283361,-86.823255,-10.605224,2.515005,-12.842506,13.093058,31.663477,9.843374,-21.094498,-102.445359,-142.222236,-142.307164,-93.740172,-82.617448,-63.942641,-58.374908,-45.079836,-55.504457,-160.874105,-219.165449,-270.143056,-242.520647,-220.383766,-166.287978,-111.474688,-30.042451,-58.494458,-171.909983,-178.761095,-132.240472,2.049231,45.41013,20.67066,-21.259281,-81.409881,-91.332127,-71.826784,-87.1496,-116.508632,-83.141318,-18.936332,38.311759,7.851207,-76.500878,-62.294324,-11.004983,51.642278,41.756383,31.80296,27.978993,-30.266708,-47.995073,-46.66156,-103.317604,-122.862872,-91.679395,-75.830693,-112.001435,-139.008721,-174.037636,-190.157549,-144.55805,23.362367,72.051371,-18.436366,-122.613892,-248.502735,-262.527904,-287.032061,-228.851485,-160.106515,-62.223888,-56.065058,-72.033022,-58.039041,27.458547,61.396199,37.846905,-30.081093,-48.570876,-22.423285,-10.315576,-104.154245,-157.72843,-100.903592,-10.280674,-33.024525,-93.4932,-87.342043,-94.590867,-107.92153,-71.476915,-70.817505,-107.064482,-144.687592,-114.353235,-7.22421,19.83269,-18.714237,-63.400501,-157.949483,-179.25509,-154.947493,-118.150127,-119.80759,-121.545723,-102.722715,-115.427988,-275.673565,-312.3954,-176.666044,-86.983111,-61.766693,-88.583777,-77.993422,-54.887823,-24.690131,-6.556676,3.02809,31.648112,38.83945,1.442943,-42.942692,-150.272364,-178.235678,-129.075675,36.555873,99.615812,95.725166,35.44071,-93.966843,-133.923003:-315.132923,-201.660719,-164.421715,-86.788372,-29.979054,22.264399,-18.83598,-180.626033,-234.35717,-167.718858,51.438348,135.58663,161.660087,108.479571,9.568034,19.376553,153.098832,315.686982,368.932514,418.392793,410.147411,309.199332,245.891877,149.903959,121.751971,152.11401,192.687345,156.861569,55.717748,14.871222,-85.526234,-129.265199,-120.703792,10.033337,99.359851,252.819769,250.606869,47.799284,-52.63551,-91.216294,-72.701961,-63.770906,24.562118,104.897348,241.181101,250.003208,138.783138,62.906534,-2.54739,135.794184,248.983127,376.816676,355.064749,253.576074,239.097324,270.667855,324.034339,371.336717,475.366217,515.080602,522.469056,466.392922,285.727645,207.683506,149.70062,188.410232,207.160787,272.436787,319.077009,327.139597,271.497917,126.125597,48.600452,52.454897,115.89718,149.468141,144.332417,101.31055,19.289933,-11.808008,-104.068959,-99.953707,0.239174,223.559265,232.150002,49.655398,-40.443924,-79.055768,-38.633489,-6.596034,117.663373,184.759898,229.179019,216.539552,203.869866,188.094504,136.818079,154.135754,185.681591,317.982124,396.479618,401.566983,314.819743,112.526311,8.992427,14.163736,96.434813,142.845457,205.918102,219.258986,232.498379,225.023549,170.004409,205.999611,268.553923,328.341253,287.321194,133.380507,83.163116,90.171606,132.484329,135.937987,156.399429,205.036993,285.423223,270.399405,205.350902,197.07212,216.684884,255.217466,267.395046,258.246689,265.355596,303.023032,275.549011,110.929124,31.380022,52.525231,162.333974,238.714394,304.529234,243.311975,47.3099,-19.120353,-98.014948,-140.716045,-123.112764,-36.556538,-17.851723,-36.862138,-33.55061,-73.168604,-232.386622,-263.320989,-142.220455,-51.973304,0.256773,-60.072901,-233.624593,-280.718587,-239.461193,-143.01331,-116.50993,-50.073528,-0.502537,62.653169,65.738235,18.450197,-76.14494,-118.967741,-135.251587,-97.935988,-24.756815,-40.562975,-183.065453,-271.266748,-371.846058,-330.71877,-294.03545,-282.923877,-310.308482,-359.559403,-378.528529,-425.275701,-366.599668,-292.690784,-184.378739,-159.833203,-136.762051,-137.548816,-143.959966,-166.113552,-243.908182,-181.235328,-105.022964,-2.586642,-5.636984,-114.0557,-174.914944,-240.681411,-238.021644,-191.975536,-86.800263,-73.81135,-75.456507,-57.115825,-13.077557,-12.469897,-30.320562,24.040518,56.488244,65.657123,43.030033,-40.544448,-84.392309,-159.567795,-122.639869,-47.353206,84.546911,118.451576,133.54285,104.577817,-21.993168,-90.507511,-169.65344,-80.870916,49.530038,251.158431,227.045319,107.598454,106.225477,121.74091,74.067905,67.398462,93.362605,114.752377,116.561647,79.43101,20.564534,31.515555,78.495473,98.275105,96.384926,108.209424,118.384015,55.985017,-6.241567,-111.350147,-148.769299,-117.199923,16.571732,81.31769,156.48426,157.669741,48.201941,-57.313647,-202.399513,-118.636746,-35.586385,70.33518,61.464577,-44.970364,-108.577416,-202.815205,-204.137256,-179.500637,-113.698596,-75.665852,3.272206,37.786993,63.83229,45.016244,10.518114,103.489411,165.293531,213.714863,214.827904,170.973435,115.518297,27.682108,61.699433,109.881417,201.601818,234.749019,234.544109,177.601337,43.711832,2.328455,-73.938586,-93.004876,-60.93074,38.416264,80.744633,83.29023,30.997547,-123.288367,-133.780463,-42.604689,143.912534,152.117835,31.247819,-26.265917,-89.297742,-123.876598,-180.588873,-183.192859,-158.782034,1.380989,81.89608,40.761663,-44.336322,-119.558419,17.523028,103.316448,154.458392,149.821305,161.207675,134.48578,-7.10111,-72.804964,-141.267816,-124.882226,-88.832631,4.306195,22.855643,-70.592091,-135.659501,-184.231951,-171.247383,-142.8453,-12.045699,73.929255,141.538432,85.453563,-78.979551,-126.148653,-173.717277,-202.534894,-157.826163,79.22409,157.477336,61.138274,-14.171157,-43.135275,-41.95134,-45.790573,-38.53367,-24.565951,7.958575,6.506133,-49.413073,-90.383709,-105.463265,0.741779,17.793716,-19.599513,-0.119791,45.142087,16.898648,-83.808905,-148.483835,-145.397647,-107.112576,-74.789166,33.15003,59.359989,1.100663,-47.873375,-132.499197,-112.896199,-62.034022,1.438733,-6.959051,-29.660809,-15.874813,-49.264043,-216.545057,-248.597997,-117.299145,-27.957733,10.958308,-18.348788,-51.005813,-62.694395,-80.78962,-30.704319,1.367466,48.598974,53.883086,-1.225637,-55.458404,-190.075017,-246.372264,-199.619064,-15.016366,56.060399,41.301445,-14.426592,-67.312312,-63.262699:-344.009665,-355.536798,-351.0633,-260.215781,-186.441062,-76.372825,-39.401141,5.145438,-26.756558,-28.183674,27.074867,60.820647,144.538799,197.621829,267.997635,272.944611,283.1734,330.988174,341.193151,331.359458,338.647988,350.294831,326.565597,230.831674,151.795362,146.664794,140.210168,105.124415,26.445074,1.537927,-38.523598,-60.857733,-70.49168,28.040865,80.452392,85.254294,55.731782,26.041281,22.251086,7.210759,96.013077,187.056862,272.869391,253.169429,209.901594,207.566619,220.280329,222.008709,210.698332,217.218242,225.430841,246.655825,276.606171,373.298132,401.144816,348.962086,240.628077,248.865285,461.383915,589.153997,659.832451,608.222153,461.764409,383.866086,258.006292,237.723431,246.523911,243.096903,222.229049,93.815533,22.580265,43.985009,147.496056,128.320363,0.762695,-19.783436,60.795906,85.903773,18.665477,-26.846684,-32.211472,-26.172328,-30.288136,41.183671,55.896649,-92.116927,-161.995559,-94.474485,12.343235,22.081346,76.455961,135.012578,219.35847,207.198233,103.089187,55.622777,1.263107,43.879172,98.088802,178.711174,218.6789,303.140283,296.665563,167.228249,16.640169,-17.484616,13.795577,60.169068,172.180246,222.737431,253.221367,232.450261,223.595786,297.541751,313.943867,282.141065,258.241842,210.175321,202.751098,273.1572,318.522092,295.998062,278.740369,315.683962,371.78795,324.450917,146.505641,89.865308,32.394163,-14.914873,0.984116,113.971913,178.035912,250.731498,232.573991,105.656508,15.083284,17.360713,70.824218,95.704712,120.537196,123.742303,107.833218,65.791114,-107.957593,-199.489534,-187.392676,-156.390616,-144.669232,-133.471931,-140.229806,-172.029148,-181.164031,-142.843284,-53.122546,-52.087179,-91.59652,-81.404407,-16.749735,-2.111273,-27.560549,-23.193371,-8.165667,-30.166535,-53.238015,-78.737172,-87.990976,-140.446501,-256.717535,-315.082795,-306.031827,-230.065903,-75.896572,-51.878975,-149.697412,-232.969615,-340.332059,-345.958896,-328.050422,-319.009887,-327.26633,-309.801433,-281.779867,-274.244059,-371.559364,-382.978687,-241.497172,-143.79329,-61.742216,-91.512145,-188.181459,-209.974364,-206.381533,-169.790798,-142.193209,-148.463975,-199.916704,-309.138289,-320.264758,-246.835747,-112.007041,-45.51091,-9.149102,-40.521583,-54.675623,-23.950494,18.84851,24.383466,-21.325118,-110.876408,-110.048683,-19.643575,23.810703,49.13305,39.936162,0.345553,-86.963506,-120.918947,-75.678134,-3.401176,147.80332,163.436489,-3.969814,-127.007777,-238.854824,-148.350287,-78.459854,14.188296,36.857251,104.752205,157.53761,207.393426,87.288915,4.462059,-58.773244,-23.491976,66.939631,71.968002,13.228418,-9.799532,10.403651,66.747917,85.280412,76.520738,53.173279,-8.808578,-41.876532,-62.878039,-0.28557,36.296394,62.431017,60.903971,96.168353,107.68326,24.696494,-34.935881,-84.872974,-84.691214,-60.259536,58.081298,96.824431,-35.597382,-148.082424,-164.612017,-50.701467,-61.060707,-133.752875,-139.396643,-109.312541,-92.614958,-48.634813,-20.892445,30.688715,93.949362,122.096465,94.261348,41.636926,-60.243261,-87.028676,-103.84482,-110.156963,-85.783985,-3.645623,18.687556,20.643927,-8.655255,-144.047827,-208.649824,-263.172618,-185.841921,-110.271941,-42.894545,-45.58924,-17.341644,-15.997177,-80.946536,-72.982865,-4.8711,144.419458,165.825159,88.704006,34.765783,20.598501,39.991218,-37.10497,-125.500532,-60.603839,186.373939,251.863625,209.448028,163.327807,99.433784,71.167233,91.814915,168.825075,178.346489,107.200886,37.968773,-70.302529,-66.682818,7.120848,19.297812,-21.783433,-135.649805,-145.07027,-48.70918,-22.221416,-124.650523,-184.131738,-127.782554,-48.794278,-70.786378,-100.805943,-91.934924,-112.353963,-157.19022,-228.387255,-140.376669,-85.541897,-66.459727,-71.006086,-63.26468,-56.797087,-7.914124,-11.594874,-81.979467,-206.15461,-172.291083,-24.48915,-41.833135,-254.263476,-298.920847,-114.448402,34.054452,-9.651864,-181.489531,-235.526325,-245.29137,-203.581603,-104.54731,-147.486555,-181.316695,-139.478098,-80.577907,1.9668,-3.074392,-79.83949,-107.697183,-123.861685,-176.317487,-211.134453,-244.862116,-228.541631,-179.895278,-185.808061,-258.319716,-293.496732,-260.355307,-126.493632,-82.134934,-67.047766,-42.157415,36.40905,37.230149,-7.790042,-21.602587,-31.252074,1.812823,54.489251,72.737669,-6.000781,-207.351261,-214.761927,-124.860528,85.107682,138.663773,156.866911,142.680564,54.581174,-10.998776:-328.504064,-294.89704,-248.526563,-125.588075,-68.793241,-43.942242,-80.326582,-178.091915,-213.186599,-171.450977,20.361609,127.419621,228.446623,193.409942,47.182545,17.943745,129.34116,272.20003,297.848016,334.561995,358.500243,331.070041,264.632238,106.622554,54.894525,66.05068,37.082523,4.375974,10.42113,16.906388,-76.88422,-142.174642,-157.531642,-19.000467,52.094445,116.52957,104.464083,35.318755,4.928501,-52.963154,-66.619982,-9.347306,160.549285,225.278795,283.74722,270.076382,177.306543,123.81695,46.46316,79.510064,137.491173,241.235954,277.0161,347.663201,376.494417,363.500537,284.172102,281.64338,402.894493,487.150259,574.735405,545.458068,373.320053,275.656888,158.717266,208.851309,254.417217,274.282734,258.30998,198.020527,159.27381,117.04254,97.868871,84.052806,87.496126,114.061983,166.409382,157.484882,37.510016,-50.849829,-168.0259,-99.273086,0.498004,177.571926,172.031762,-7.473839,-81.246397,-116.035608,-123.736001,-83.670052,145.136128,264.240703,313.128833,252.165438,140.327012,119.195064,103.589563,125.387411,152.074613,277.253531,375.260579,428.795012,322.836066,39.753603,-12.397804,46.66641,173.890944,221.212949,297.7624,305.946575,233.560567,184.815792,127.533628,191.15595,263.737468,356.764505,349.241287,261.036156,214.527777,155.106205,161.489713,199.840571,298.097451,349.052213,377.268743,323.767581,214.062957,196.408649,154.858834,137.215617,173.269414,263.129778,296.861914,345.756119,323.742285,120.52354,-64.255801,-54.726968,126.592436,229.281258,301.239834,259.309043,112.114312,30.642333,-106.259599,-133.733135,-124.516986,-77.734769,-48.09625,-61.956659,-97.533913,-185.61439,-275.072484,-258.273672,-89.675898,-11.299906,1.75566,-42.543831,-107.970782,-117.629102,-135.722908,-118.675938,-78.476601,31.141084,76.694758,85.122435,39.746428,-96.520768,-183.211672,-181.929017,-108.557989,-58.556815,1.68942,-31.640253,-215.066456,-296.127525,-359.822019,-339.808725,-298.62745,-228.491289,-227.886245,-255.235058,-285.457749,-392.415465,-423.79561,-370.285238,-222.924088,-173.489394,-132.80434,-131.429211,-156.248284,-182.108751,-222.056756,-145.680197,-94.360984,-93.978186,-133.217876,-188.946775,-194.333072,-204.452553,-189.723496,-135.61167,-19.294249,-9.203171,-30.796982,-37.535321,-60.250125,-66.548321,-53.847072,-66.632107,-85.492277,-76.401805,-46.421168,-15.643225,-24.496891,-100.217674,-206.640467,-199.214289,-28.514587,82.613122,191.773556,150.912318,-59.99561,-166.998176,-246.392889,-93.424145,13.494224,149.458072,178.93077,209.468541,199.437169,69.602169,-77.031875,-73.460359,55.84794,114.99141,146.709736,132.71728,62.176811,8.029692,-68.277784,14.248475,92.230443,192.844368,178.997035,16.244947,-69.774525,-107.322215,-22.701806,10.148925,16.866096,21.689394,78.882631,90.611915,47.429018,11.536301,-79.860726,-91.343505,-22.538958,159.121734,173.628403,-6.185416,-99.681819,-98.925846,-31.39319,-49.790051,-130.484974,-134.302499,-44.283797,-3.315533,-0.872085,-23.102909,-41.511399,76.272142,161.202146,236.195992,225.987081,153.647645,80.631009,-48.914478,33.607588,125.585407,231.901734,227.250847,175.384896,136.465385,29.197755,-30.239347,-120.353837,-72.953442,-3.060452,148.982234,196.56676,162.248382,103.057648,3.184153,-28.04783,-9.795014,70.5625,116.348416,150.531857,113.233267,-4.184645,-52.261633,-131.006761,-117.537084,-47.675986,139.176055,201.048196,199.301847,144.454843,2.695614,-13.41056,48.44931,193.651507,228.729604,174.585738,92.59978,-61.294736,-94.509162,-111.044702,-97.632429,-77.07448,-29.237009,-16.053364,-50.967803,-100.211966,-207.222003,-222.688164,-166.845865,-22.468736,23.450204,33.697705,-16.831298,-202.457566,-289.176951,-329.824122,-179.095059,-81.670631,48.908914,72.775091,56.285734,28.084685,-44.791155,-129.087724,-155.575223,-157.733079,-114.645946,11.291164,5.906456,-187.863033,-272.466986,-238.817578,-114.333804,-115.308503,-176.655924,-152.177351,-45.505059,-42.211137,-158.745941,-297.611504,-308.941185,-179.53149,-89.362551,16.704959,23.730953,-31.711828,-91.57247,-245.080371,-267.393427,-210.651454,-110.735731,-85.678169,-77.951946,-101.805267,-202.266106,-294.580507,-273.462935,-131.614623,-82.742047,-55.040591,-37.236838,-22.090913,-58.237468,-150.103752,-91.403836,-13.298215,116.773376,133.905471,30.631935,-75.677439,-268.768539,-253.822167,-150.677665,74.365398,131.303816,126.997678,82.709757,-46.020417,-111.212469:-427.302017,-322.875168,-223.380727,-58.942302,-25.091126,-13.262446,-18.654713,-55.218599,-79.86069,-45.477165,90.820362,145.976462,213.45137,241.193435,278.038316,284.466904,287.832809,271.795967,245.89551,192.718883,187.565131,224.091214,251.540221,216.932218,37.412914,-17.635542,-12.549382,-7.299273,-30.580945,-48.139024,-94.116275,-112.784943,-104.695066,-42.012461,7.30942,92.615799,81.358012,-101.841888,-200.1059,-169.952983,55.162965,141.134175,160.785637,98.468859,-38.455689,-67.636989,-21.917772,44.884836,162.62749,201.053836,209.495267,179.574857,144.201709,137.907821,168.85597,192.470651,147.678653,157.268737,306.31416,390.979404,436.769327,399.229551,280.161971,224.84657,156.579874,146.513124,144.71172,73.877042,2.428962,-121.57417,-133.656345,-79.333795,-91.289207,-115.617586,-117.855536,-117.480399,-153.515958,-158.681056,-143.01804,-155.94031,-235.891053,-270.887787,-237.226129,-164.679274,-179.467926,-293.307007,-348.749518,-373.390496,-289.348952,-225.644473,-104.750344,-76.337611,-78.673386,-91.29567,-110.479754,-103.300624,-68.123695,-48.386395,-37.807238,18.494888,84.836716,243.03831,264.446127,110.306717,-94.18268,-106.455519,26.478825,81.53083,85.367963,82.583861,156.775952,218.694421,291.274443,262.632236,240.576387,237.872057,257.866152,282.349305,264.95459,207.281775,224.507288,257.072152,279.684823,241.740757,118.185088,70.593843,21.635457,10.052398,-32.128833,-108.799488,-125.291092,-54.347577,21.969458,152.823291,182.562781,168.75913,47.851073,8.632705,118.783995,212.808792,269.896449,247.061523,222.122408,209.807849,103.469539,-46.511527,-93.441347,-122.426019,-107.867088,-48.562944,-19.354696,16.507353,-12.818821,-37.355136,-96.758584,-143.437265,-183.400221,-151.457311,-55.721311,-12.986692,-0.128781,-106.355059,-147.221674,-139.724278,-120.212746,-163.568557,-220.952934,-292.934014,-306.535121,-308.310708,-294.141508,-281.897405,-262.284001,-248.775336,-210.512871,-194.59392,-195.316361,-190.459988,-173.893201,-151.276881,-135.493397,-109.435301,-112.159219,-95.082543,-92.36266,-107.928388,-112.199141,-116.465915,-153.629875,-144.244021,-60.747312,-42.779235,-116.563184,-222.863005,-251.59559,-295.716175,-324.671305,-351.36842,-319.736824,-202.254372,-151.213465,-142.016202,-121.452612,-133.029793,-144.869216,-100.972352,24.189698,57.367394,28.967865,-36.832006,-37.79786,57.096095,129.451683,185.94616,155.727763,53.24513,-70.920388,-112.963377,-74.783243,-3.546258,119.006587,105.51267,-74.415976,-164.120314,-204.616379,-101.73418,-44.472891,13.831365,35.797736,147.181312,207.372983,207.088987,32.584681,-60.629635,-119.935176,-112.629463,-118.047876,-103.163542,-10.985533,22.897813,21.834621,70.959422,127.647592,188.41411,174.75226,93.829023,51.573993,57.358404,167.113951,182.054923,76.469007,15.667917,2.553338,25.452022,21.593448,-2.358918,-39.733373,-57.450701,-52.415095,5.431344,43.601475,27.423166,-43.928809,-134.186028,-39.921067,8.549038,15.262413,3.619911,71.792379,135.639617,179.118631,157.66507,139.130314,177.580205,188.434326,198.978456,189.959612,73.310275,-5.694757,-62.959079,9.340265,56.464391,81.24986,46.664218,-21.184978,-32.47212,-34.970432,-30.597766,-54.342495,-108.827215,-92.825765,17.02304,64.896315,74.568057,40.800822,-18.616555,6.530699,40.296402,100.028053,110.87489,85.578897,63.100875,52.147823,59.69738,74.248477,154.045287,223.889717,331.848754,355.41072,403.164146,429.776417,411.673999,307.032839,271.508956,278.287777,281.198768,211.938283,157.854817,66.635722,42.071458,39.757755,59.414548,74.539823,95.436413,99.749192,117.316601,119.829676,31.669929,-124.785298,-149.000672,-99.767549,-75.520513,-59.441299,-76.095662,-180.719323,-226.298146,-156.536129,53.125332,87.481014,-46.095604,-108.124462,-71.273498,-9.239381,111.973138,100.903759,22.842412,-149.991276,-180.693693,-124.432144,-113.444303,-219.583273,-258.653551,-188.559367,-119.274942,-135.973985,-206.606644,-227.70528,-189.349626,-127.966833,-44.544841,-117.795027,-132.357919,20.076359,141.17228,257.108052,203.447284,-12.652867,-82.287115,-87.778232,-94.958857,-113.809329,-104.930462,-90.696114,-99.95811,-97.815623,-31.991367,0.600542,-5.237615,-13.722415,-15.997106,20.907624,59.789415,102.360278,106.165954,112.682888,82.516902,54.906367,47.171513,61.561997,13.031956,-49.164275,-133.701459,-78.210815,7.401857,157.956875,177.501505,201.82161,231.076788,172.538959,57.231661:-377.630655,-343.218157,-310.88525,-212.84077,-163.487012,-100.953772,-87.341753,-92.190721,-96.707661,-79.701947,-30.432653,-6.301846,43.733407,81.906497,204.102633,253.134393,233.966546,184.329724,187.408216,220.349188,246.995557,280.261341,265.083143,182.773513,64.556764,5.387696,-16.079206,43.010596,168.828596,140.49631,-70.399505,-135.325964,-85.350471,17.650074,47.792398,71.657523,77.268399,69.463721,53.464384,15.467677,67.787928,163.551778,336.772103,347.649801,279.322165,247.24793,239.042989,265.615076,264.962483,191.879174,205.477615,235.844229,198.438365,140.14849,137.781978,72.198833,-14.673444,4.213352,212.451016,342.586373,447.622778,405.943629,255.008708,194.372955,159.480739,172.300396,143.203804,26.94023,-21.993672,-91.89602,-102.418471,-6.260528,73.006706,49.694892,-26.521426,-43.345131,-58.055878,-79.959641,-135.659072,-136.837082,-122.068094,-217.468244,-258.213263,-191.153615,-136.466787,-162.697372,-232.694416,-323.560701,-229.263689,-138.454835,2.09965,28.249936,54.438428,67.442025,61.885981,46.629452,7.750669,36.413935,96.216954,223.514602,274.352291,312.972065,269.687237,83.525221,-59.47951,-43.489096,124.398528,188.281701,179.70053,153.52623,190.826664,270.988756,400.922423,307.499136,240.88668,194.080959,194.495263,226.573385,270.958943,326.991108,221.796672,164.436176,145.459929,147.80887,68.431949,-10.940006,-88.178527,-47.855283,17.80086,-65.66883,-96.506171,-62.621539,-5.368508,135.959959,160.450544,66.88561,-15.628285,-6.331275,54.02263,93.905107,192.504359,232.606764,240.510562,196.303414,44.971252,-40.461102,-49.226373,-61.475705,-60.383764,-55.890332,-68.553908,-109.67133,-120.955419,-106.861713,-97.904635,-119.096376,-98.225747,-39.506319,25.759815,10.721123,-31.660409,-81.566178,-114.842569,-124.700541,-87.587269,-27.168931,-39.591635,-151.452426,-316.554141,-364.286443,-335.706354,-280.522974,-152.51685,-130.808408,-242.926745,-311.11536,-309.149296,-183.264495,-130.274625,-122.612009,-145.782221,-131.086558,-100.103789,-102.446548,-228.493022,-282.927766,-263.844513,-213.152117,-125.270984,-97.851775,-95.531648,-124.665465,-203.221417,-216.168657,-196.809804,-167.889637,-172.292165,-227.916943,-247.93139,-184.798596,-66.687624,-21.233755,18.780181,5.102204,-14.108293,1.625058,43.217915,53.315597,34.04876,19.590424,31.053095,90.876323,137.416402,193.886101,199.16306,213.903969,111.795367,26.036052,-7.674582,46.652325,121.600129,80.252216,-98.572496,-155.87483,-177.221512,-172.338562,-145.889309,-62.449978,-34.139264,37.814346,93.988144,132.151944,-21.739033,-107.16949,-165.496324,-175.915978,-255.597015,-284.146192,-188.402761,-108.085064,-77.096443,-100.889925,-66.91024,4.861961,-9.284146,-117.702109,-161.113374,-138.850574,-11.642335,36.766536,35.130583,1.060485,-58.927711,-56.056701,0.794988,5.004844,-109.174126,-243.248618,-254.663278,-233.014897,-239.864449,-278.735825,-279.355021,-214.17399,-160.787926,-163.463531,-204.023126,-215.031463,-138.976835,-60.02829,23.86035,-12.193912,-134.866194,-147.662835,-132.992415,-127.120581,-120.831655,-112.5182,-125.571282,-169.068891,-226.706165,-259.414004,-339.886544,-358.611501,-257.06718,-191.417523,-226.385802,-301.541542,-399.146582,-321.945489,-242.226741,-125.993623,-100.316343,-114.678415,-141.270316,-128.883234,-73.352906,-64.507938,-24.078611,17.423829,45.357192,0.924056,-107.727678,-124.765329,-122.618102,-90.300247,-34.536576,114.122342,172.912649,252.488939,256.374366,127.419935,12.852074,34.202095,112.78504,132.505178,135.566467,100.14359,-3.113363,-27.541924,-39.003368,-69.590347,-81.850885,-70.579308,-34.277382,42.092648,29.406534,-107.641847,-214.673607,-210.013931,-160.82199,-152.212261,-184.093225,-231.767775,-319.918096,-303.819674,-140.857507,-0.598938,-10.541409,-127.883509,-168.438564,-180.567668,-152.586443,-20.843227,15.253029,-46.326774,-153.944143,-139.798377,-92.230575,-129.062251,-238.819523,-241.19861,-147.589205,-38.01995,-13.431388,-64.321929,-113.669385,-119.259728,-56.785863,32.093687,-18.209731,10.563807,223.493284,320.233294,370.353869,335.055869,210.516141,144.686378,12.975399,-114.394813,-141.469814,-80.761167,-21.879554,12.5074,-17.447712,-58.63993,-57.742074,-46.760998,8.126826,21.05218,-10.244236,-7.038473,88.76968,144.764953,152.557813,48.292119,30.69504,122.172024,191.074389,235.710282,182.502985,37.502553,51.801429,106.325902,183.817828,199.22996,227.607756,228.62614,151.797123,82.660827:-208.227168,-241.771097,-188.47646,-48.506783,5.174689,32.47942,-30.54279,-164.694559,-93.011874,-23.227549,100.223285,151.484935,182.233046,161.673404,109.35119,97.943718,138.968189,158.921437,121.817942,55.065301,77.481692,185.027581,204.101558,147.526788,96.55295,100.769028,117.872458,96.834038,-9.113753,-67.568057,-149.781615,-175.214675,-151.00011,50.955066,140.302555,76.985325,-24.74283,-129.749515,-107.03424,-10.06696,18.584205,31.241302,54.898978,44.096801,19.837258,12.885426,19.706852,44.035465,108.675402,213.545857,260.537519,231.521836,203.913455,260.203267,299.240904,293.965872,254.384227,267.621169,387.745836,449.887483,478.203393,431.475853,229.380451,124.634077,71.275037,207.773928,244.142507,150.153971,100.045141,95.284481,103.461383,105.606676,24.136243,-39.766875,-68.429891,-36.263301,-4.422002,-25.614948,-96.905915,-115.497534,-142.660915,-184.043288,-163.686041,-48.38833,-4.069695,-33.523242,-95.618518,-184.063064,-152.968233,-90.139832,69.489897,99.96196,55.666369,46.323632,79.77381,66.992683,-35.13226,-48.017332,-16.824716,24.422213,44.426794,78.426797,69.501517,30.043175,13.898258,30.331584,85.392755,80.832131,28.775083,35.263454,133.352313,183.595194,218.733386,249.945507,272.259812,249.990687,215.082681,148.86179,129.525081,136.632166,164.654276,197.411777,233.448202,196.988745,96.928993,81.532191,157.452525,204.864698,134.078732,-9.14823,-0.301601,87.204304,109.662762,120.565145,126.622566,91.556363,-63.372547,-105.362335,-11.374947,73.17699,222.61877,265.579306,188.925045,76.559728,-113.47359,-134.664687,-127.654326,-136.974783,-126.630047,-71.461578,-62.997712,-103.662611,-105.822284,-75.829425,-65.777351,-101.414782,-136.028024,-115.712857,-71.353767,-64.55293,-86.919971,-75.201908,-44.239357,-22.321272,-29.816782,-63.534156,-96.918213,-138.727229,-142.073371,-154.010616,-184.659098,-188.088274,-156.385289,-152.43929,-199.808446,-219.634795,-221.499926,-197.083732,-193.141269,-225.966822,-239.092636,-214.151693,-196.674876,-194.554239,-154.915159,-107.859677,-81.360122,-119.253207,-135.78192,-83.572652,-35.619423,-87.403569,-238.695861,-259.726581,-230.990633,-232.029771,-255.792193,-253.538402,-236.649384,-248.324441,-204.254394,-128.938632,-70.290128,-109.118892,-97.243788,-42.425924,-21.627919,-22.773413,61.808072,82.116997,38.345989,-2.167092,34.830021,92.856787,59.05201,-66.573787,-108.190023,-82.929463,6.692056,45.218466,109.86763,123.565014,44.975417,-32.361873,-135.718116,-71.461917,-6.572822,84.895363,106.496043,115.474922,114.343043,103.630165,9.725486,-34.922123,-12.268474,32.607313,104.066769,102.651835,-3.227289,-49.22415,-8.509234,64.771287,94.066121,157.467066,173.55463,101.656903,-2.020171,-181.057299,-109.920009,-27.306359,44.995322,24.689338,-23.52891,-31.149446,-23.79209,-15.093469,-34.259974,-74.668856,-74.539756,-54.332417,-61.000087,-140.230036,-174.04346,-99.335713,24.959745,24.395352,-74.309111,-115.961345,-69.173997,-12.938716,-26.318778,-78.946509,-66.151517,94.379546,153.225996,185.827312,172.549048,70.751889,3.539349,-61.755744,-23.99223,10.442545,4.236689,-28.226081,-38.429574,-21.848145,-8.658451,-27.791314,-115.905903,-162.007894,-131.147433,-7.954436,39.889262,54.28812,32.644138,-31.931714,-64.908844,-32.064546,59.725625,68.416536,76.3877,108.946348,145.604573,112.475663,-40.91052,-79.996829,-0.616509,171.739723,210.742162,250.22012,256.56356,208.061978,188.398574,225.948949,282.882626,259.975585,143.444595,78.946109,-1.339842,-11.964357,-3.864423,26.655636,16.150681,-43.755846,-38.707301,13.260197,-4.022151,-107.536061,-71.856734,11.535985,117.412036,102.522384,32.691067,-3.11004,-105.515718,-146.788489,-146.869905,-51.496175,-1.229879,3.5315,-21.42692,-11.797721,21.990232,79.083175,8.766203,-81.175915,-230.534698,-223.977665,-106.325419,-110.928926,-306.94424,-387.265433,-340.724923,-172.447958,-119.076014,-131.133823,-166.408837,-172.321567,-156.769458,-188.400512,-272.826264,-288.8343,-188.025062,-83.06043,89.872946,90.190839,-45.668942,-94.026631,-100.102211,-121.117777,-146.751926,-160.695679,-123.148427,-15.565125,-8.410282,-90.890314,-148.656796,-149.760768,-105.598258,-61.424224,3.677217,-12.482928,-78.590309,-71.924048,20.394572,92.666672,86.59335,47.010577,36.091521,-38.784325,-118.937884,-278.859176,-268.24755,-164.262831,96.298634,171.687441,172.955399,139.105499,35.057068,-36.80127:right
-134.542847,-154.734512,-151.154451,-143.085541,-134.380313,-121.384133,-111.159439,-8.392177,127.723247,157.502038,134.306601,95.262909,-6.04332,-55.23713,-112.326432,-111.612572,-60.631116,30.662061,66.115664,106.04236,126.042737,130.681271,107.959123,66.196671,45.30499,57.095507,164.5981,238.713044,288.592988,231.982509,101.49652,97.032921,185.437676,302.162395,319.781383,214.109972,150.649144,157.34616,217.626125,296.850046,234.278654,203.53771,207.517278,220.600906,195.783236,153.258782,111.420061,147.569825,242.401738,231.928474,203.880971,159.866434,140.163917,51.999455,2.877669,7.233887,127.240406,179.670044,212.197206,219.903108,251.505097,247.801328,176.251118,127.857048,62.188026,81.963575,97.33543,77.679291,60.877473,-9.576039,-71.827101,-131.417566,-90.284571,-93.2856,-157.520987,-180.847371,-185.471027,-182.181156,-149.110246,-106.041892,-6.452387,38.54375,28.260056,-59.758292,-108.426046,-142.50293,-126.282372,-107.485023,-133.005196,-105.617903,-17.150629,-40.737704,-206.213959,-260.982924,-224.863949,-165.743002,-108.217685,-148.700495,-163.243781,-179.461314,-197.197837,-231.067584,-221.437781,-153.332326,-47.806428,31.499184,106.900925,45.914374,-130.609642,-169.077983,-163.846162,-160.177256,-137.408211,-21.561169,31.117532,51.502897,36.143089,-3.697337,-15.269589,-35.176014,-57.434255,-31.185827,85.807476,129.102755,102.646456,35.958161,-82.041094,-86.350428,-24.970118,3.008367,-21.236747,-118.3541,-161.217573,-233.809993,-270.100248,-306.972281,-296.153326,-260.343717,-109.580615,-30.851934,27.405541,-1.821132,-85.075506,-99.265115,-72.973397,-52.752533,-49.810531,-15.243435,1.851321,-27.903284,-41.170157,50.740007,207.254405,260.859339,307.669201,298.237329,207.618558,146.856033,76.496585,70.839393,80.657363,166.386686,208.933869,160.545242,89.943939,-24.667848,-46.98137,-23.785341,30.695015,74.208969,166.293501,167.156613,14.85117,-118.406324,-355.489121,-411.054747,-397.045887,-330.550482,-312.841736,-317.558813,-346.481981,-457.920041,-484.156718,-395.919268,-302.174496,-276.055541,-234.475703,-237.997316,-298.055032,-328.886876,-296.632381,-228.830174,-110.871046,-53.130229,-24.323857,-6.67458,-17.466327,-36.700631,-33.808734,-29.148773,-105.159641,-146.771554,-154.966037,-111.857614,13.566801,29.651216,-74.076912,-127.090032,-133.650659,-87.80047,-98.37665,-249.540376,-352.453288,-446.987948,-425.288775,-380.280232,-404.493669,-381.70036,-272.411374,-235.956096,-268.195665,-323.221201,-370.70491,-338.931385,-225.744867,-79.483767,-34.495932,-85.276081,-133.64623,-164.438682,-161.998363,-136.59663,-78.515605,-49.858966,-25.406892,-22.637687,16.220658,42.281379,89.354317,123.483231,202.353657,264.531041,274.774527,220.648027,167.505989,59.26836,34.646665,61.717764,55.812327,27.395291,-55.700563,-120.325114,-251.723233,-288.066137,-284.179183,-240.711754,-75.086989,121.288834,183.896408,146.584514,62.980805,-82.246392,-110.122436,-105.847463,-39.930591,13.134228,46.196127,6.205587,-85.273417,-104.658117,-31.929579,64.059299,235.317901,264.861826,238.359184,98.44666,9.09264,-114.35589,-134.931153,-121.187613,-145.109788,-171.727787,-203.841635,-235.032181,-326.702224,-325.84826,-164.4758,-59.942828,69.440204,151.273108,170.834175,106.630755,42.130068,-85.864241,-113.492841,-53.882772,-10.27216,-36.453816,-94.853568,-89.910489,-13.923757,31.720276,100.401835,113.368486,93.267176,117.696926,143.980818,136.824183,83.602713,-95.677108,-164.842795,-169.772144,-62.869606,3.110216,56.087968,13.043896,-123.113703,-163.964796,-143.641282,-93.949643,24.919051,166.001526,215.18838,152.580764,62.128658,-22.46295,33.054869,204.515509,274.536887,286.419983,251.661935,206.695352,133.085003,74.282314,-86.902965,-99.891064,-11.092404,-24.740095,-49.914818,-23.846599,17.057412,63.832852,62.209358,90.508822,195.676795,238.231556,254.62977,234.047018,145.718728,92.605944,33.813926,18.377914,-60.902084,-52.318455,10.574596,25.378651,-58.513881,-233.919939,-249.30449,-138.148336,25.26845,105.935629,180.331079,155.960469,74.474101,40.094718,6.919622,14.793716,42.507126,116.844789,175.763126,220.208823,194.180478,140.353613,139.924394,149.036831,107.551892,112.467957,193.160276,211.674358,149.668019,94.883692,20.935556,32.876333,138.528065,216.774285,217.061836,157.951447,115.627625,24.367843,-17.849425,-26.008907,77.150593,127.977195,138.285056,103.879543,27.93572,-18.614789,-135.367358,-166.629689:-133.98453,-43.602978,-59.574793,-185.418908,-244.968398,-239.98263,-159.038341,-4.304493,36.68085,71.189082,93.123831,41.243242,-67.605709,-91.474697,-104.870935,-91.933826,7.648789,109.378964,107.382839,22.563856,-33.055026,-102.792266,-81.403197,30.898457,99.80104,138.592825,250.321487,289.225695,285.605394,241.638855,145.010453,147.888081,245.784809,296.441299,273.408997,154.761842,97.092062,58.03636,65.313293,86.551104,137.893745,179.32714,180.147927,109.321489,-88.74043,-157.957691,-156.751495,-96.49805,43.523651,71.123611,37.705272,-60.785419,-118.082216,-236.366274,-261.030487,-176.816116,-50.137042,-31.29567,-23.640275,8.362868,63.943602,43.216306,-41.035922,-46.854856,46.39156,125.189009,119.354467,54.423158,11.711445,-83.097633,-115.580722,-109.123294,-31.977591,-6.639201,-77.890611,-148.948961,-233.156671,-243.264485,-213.050065,-156.761377,-23.273083,-16.010667,-37.766063,-59.442639,-81.277402,-192.584663,-241.20048,-219.167044,-128.809041,-97.060491,-79.200325,-94.058463,-166.501308,-215.192171,-245.494826,-200.28112,-88.963228,-59.56321,-59.112845,-93.138713,-142.428922,-204.991215,-162.183748,-15.135136,57.640702,93.954685,137.688124,93.63115,-87.36506,-151.461434,-149.751807,-113.549744,-32.701177,46.563801,44.874456,-47.52676,-100.911681,-154.336857,-129.868441,-28.27346,3.965506,11.578793,44.644929,33.268594,-86.067491,-150.575343,-154.11843,-107.421179,-97.997693,-164.813099,-165.349105,-142.748254,-157.305964,-244.999066,-271.067416,-267.922736,-271.233785,-241.19635,-133.581037,-99.927087,-115.707949,-149.186176,-183.519956,-171.66806,-119.398091,-59.787527,-34.760504,-8.070444,-13.994515,-32.98142,-11.071603,88.033965,189.006113,218.089737,212.659312,205.624261,211.672272,197.95374,148.893383,147.08978,215.047947,308.795129,317.373343,244.611453,188.905612,82.691079,58.29691,89.385521,139.091733,161.578467,136.549416,78.628218,-44.856842,-101.828854,-184.730197,-198.517601,-219.501818,-230.554157,-212.621015,-198.797186,-247.242815,-373.20347,-386.083215,-340.268571,-285.93255,-237.846214,-148.550302,-156.548915,-291.842805,-365.354499,-357.900828,-289.072045,-173.552959,-112.443493,-93.658577,-84.581879,-94.011108,-122.837188,-120.59771,-65.635586,-19.694373,-10.268186,-19.295366,-43.974172,-128.606127,-170.560534,-188.010872,-157.23663,-83.88073,-46.649916,-56.644402,-136.844208,-185.964889,-294.726097,-322.250265,-251.080492,-218.052517,-250.488003,-303.152181,-311.31893,-312.016967,-298.257069,-220.115829,-162.946228,-51.933867,27.521432,39.917444,20.451698,0.175262,-35.212925,-33.384652,-18.254365,-32.365003,-27.787103,14.133079,33.575484,24.551132,-5.621817,-23.415212,16.920023,112.18856,112.363564,106.844671,152.900215,153.558051,9.717241,-71.462624,-109.912896,-49.937542,-17.359465,-32.555325,-100.897943,-284.822918,-350.303546,-342.250916,-267.221991,-75.832188,40.476452,42.126074,-62.813437,-122.550011,-175.305824,-175.23955,-145.055409,-36.590527,35.767967,82.99078,59.332557,0.817979,-13.639835,74.476749,166.485155,286.287265,260.516983,203.418263,52.693142,2.394273,-51.541127,-70.098488,-81.425662,-66.917114,-53.360727,-75.728361,-129.454208,-239.05266,-254.506026,-185.336507,-114.461488,3.570652,35.406591,53.368529,85.464291,52.035291,-103.927886,-142.587872,-60.064784,80.583505,133.94766,128.218945,81.124882,54.948266,76.513021,111.248674,128.99728,145.20149,139.548375,146.732367,128.863177,67.168449,-95.065428,-118.379207,-47.990411,18.964482,45.162157,66.660398,46.917769,-33.130897,-77.144204,-110.550351,-78.575051,81.76038,256.696009,281.336318,187.958923,112.743291,30.700246,57.628354,203.034235,319.194995,352.049664,386.144332,377.492905,229.463696,99.36992,-57.764939,-29.345595,83.663684,91.157074,74.94115,63.54908,69.044115,55.222019,41.371462,86.286424,191.877425,224.315509,215.625925,171.076075,25.996328,-34.197289,-30.571703,6.563636,21.45105,50.412073,107.437046,149.179179,84.548287,-89.479234,-121.824885,12.15284,268.084744,325.536929,235.67858,164.681717,110.333388,101.839653,78.313675,102.18567,225.126964,284.536086,289.672438,285.686514,268.27384,213.053408,202.765374,246.738295,288.714838,284.127856,200.190555,135.133518,72.32791,79.559311,119.551839,159.947788,233.609664,183.770546,150.900326,176.187969,191.792185,120.403012,72.894916,66.334168,159.070895,198.137271,144.197111,60.062334,-39.834838,-29.114481,26.39876,58.162889:-137.982283,-65.352735,-72.021089,-196.271196,-282.173066,-317.940387,-225.374474,-5.761992,59.431339,77.612728,54.104278,-22.666004,-191.176204,-232.917076,-206.197699,-136.741131,51.109489,122.733244,72.30859,-83.833608,-126.416938,-132.499957,-105.412597,23.486217,202.378935,262.771913,280.490677,259.214152,195.459397,165.293937,167.05884,202.648787,296.394814,335.626054,297.822397,152.602315,102.938081,86.977235,101.161703,138.153664,151.513388,142.738583,85.977101,34.722732,-114.854113,-173.840415,-148.639176,-103.130056,-40.055054,48.713405,65.887595,-92.083789,-250.983718,-484.310676,-474.810334,-259.986891,-24.896592,41.487171,38.862347,-8.090541,-122.116552,-154.773209,-76.065847,8.369045,118.770877,142.693903,117.633708,-22.318227,-90.131374,-132.051096,-128.66681,-144.752583,-124.646534,-86.991851,-52.501188,-71.077651,-123.037195,-143.844186,-169.40509,-157.247087,-68.662055,9.544914,9.295856,-78.366767,-144.118114,-255.97177,-277.776866,-209.65649,-82.504249,-43.274366,-33.592928,-66.234098,-168.321622,-192.364175,-128.55449,-73.686824,-50.888551,-119.996044,-143.831621,-153.691761,-164.976786,-207.309881,-189.40823,-58.264014,67.345709,120.562922,146.714964,80.949534,-148.210409,-229.212931,-203.457666,-135.019274,-3.034124,54.901887,25.461488,-92.595901,-140.439596,-164.85637,-138.210701,-85.610921,-103.491024,-84.902131,23.69884,37.535654,-113.93942,-218.650677,-259.390864,-201.008414,-152.27969,-200.194096,-188.144607,-155.54936,-182.843402,-259.225264,-260.627981,-196.678052,-121.921741,-91.105345,-48.88384,-39.121277,-77.74096,-113.278412,-104.471524,-64.3953,-17.143684,-1.102868,20.508596,39.517185,8.133707,-38.32876,0.980292,108.812389,135.961922,145.399515,158.205373,138.701434,60.228458,41.027918,113.307668,172.982791,217.317643,211.458469,221.972353,240.660078,214.572493,82.684486,25.409227,-3.700722,68.646866,145.453863,222.175823,172.076294,4.887684,-52.628333,-95.038439,-116.298042,-181.185227,-186.822491,-179.797568,-199.052544,-231.714616,-312.096868,-323.768018,-262.3399,-172.475938,-134.365325,-101.766167,-126.865026,-223.419137,-254.345365,-220.730127,-177.205014,-81.28999,32.113877,53.234593,24.84494,-13.315426,-124.898404,-148.965222,-95.794032,-15.665776,13.487118,6.578565,-29.416643,-111.425779,-133.717007,-104.246891,-64.445164,-12.02309,-26.087731,-44.404847,-83.387149,-115.407884,-199.209494,-211.879865,-143.502543,-65.761107,-44.690614,-65.761433,-112.99208,-203.92857,-211.334322,-117.759283,-35.459937,122.418216,196.938382,180.789291,105.359898,81.667512,20.170908,-33.23025,-93.908695,-30.142655,7.17787,17.656688,12.395197,10.727727,2.297181,37.57149,101.810339,209.211108,190.697622,168.47635,95.818776,24.473223,-92.846183,-101.121123,-80.360742,-57.36946,-37.110656,-64.437307,-134.22103,-279.396269,-312.117347,-296.712088,-245.200209,-70.674656,-7.283346,-50.864109,-160.547431,-196.914703,-220.419939,-190.268554,-71.499528,64.78824,125.579464,140.61641,84.924201,-27.262184,-35.245345,55.282188,133.34574,281.922923,301.559004,248.690306,83.543524,-1.271831,-100.747296,-96.849502,-53.678824,-14.464774,23.239656,51.384854,-9.257565,-205.696263,-257.364398,-200.333422,-138.473553,-62.490249,-49.453393,-54.954095,-87.658158,-113.921663,-139.970764,-96.171589,79.264087,198.857158,203.664757,119.977485,88.469382,102.993803,101.281974,57.237329,58.31096,109.611719,127.663909,111.853535,12.364159,-55.749284,-126.829356,-117.441844,-56.901712,48.516802,109.194663,143.415183,106.935612,0.704478,-43.643102,-66.335674,-36.757888,80.579529,185.709682,190.146292,119.740828,72.059626,26.515742,64.422052,221.713528,386.691668,458.827297,471.312004,402.247257,215.202389,114.415219,-44.515979,-44.541551,113.294945,193.884836,151.506752,45.568994,25.831966,-0.325272,-19.500101,3.637278,113.470847,148.529088,122.978659,79.856985,-20.704678,-70.719859,-117.826671,-94.864177,19.601738,137.23957,158.290072,106.82222,48.904153,-40.796921,-23.387381,99.123223,160.606577,174.291155,224.177429,237.030994,141.350533,56.803532,4.490294,57.705297,217.168439,352.467951,380.191401,306.95065,233.952699,105.866065,66.627671,71.937494,168.060392,210.86486,201.54311,155.295711,40.540004,-11.053323,-41.762357,-12.821764,74.848981,138.862232,150.493765,139.00157,130.365968,93.799525,66.685617,78.018122,159.565634,173.004826,98.825322,36.605876,-67.89304,-93.148232,-44.807974,8.385214:-121.949209,-103.460558,-132.254766,-221.116637,-263.635237,-286.903038,-241.416867,-66.260471,89.822822,135.155363,89.965219,15.060314,-100.277451,-125.419652,-138.039484,-122.332322,-39.472168,27.064188,31.497125,26.862779,23.427467,-23.579484,-41.725439,22.31945,146.734934,194.056162,263.589146,289.110989,287.167275,249.000401,166.986545,163.640468,248.221985,338.470501,334.206958,251.558554,203.450698,145.506629,153.532681,213.263462,227.238144,220.755018,191.745387,147.30396,-13.283152,-76.492891,-23.262625,63.139049,177.011469,187.165564,185.984923,110.976348,8.360322,-203.142634,-227.230899,-85.804746,56.994235,80.45432,99.53466,110.205101,76.032255,29.57833,2.869755,37.437136,72.97688,74.224295,89.912264,59.09968,-9.130875,-167.050202,-206.26769,-196.272055,-160.661731,-153.247401,-187.475285,-205.067839,-146.349763,-105.665448,-123.774468,-139.792639,-67.859683,29.784896,48.558174,-19.782792,-97.777872,-219.076252,-227.10322,-155.773959,-31.059433,29.545374,67.920553,45.22398,-44.85053,-92.699593,-104.785984,-79.916934,-79.069714,-98.49105,-102.618285,-133.830297,-167.568257,-236.439329,-212.118428,-45.54238,29.378653,31.865565,23.261942,-6.050436,-109.048365,-165.689934,-223.691154,-210.242197,-119.840855,-7.58915,22.193783,9.64785,-28.710239,-113.284368,-122.441825,-103.699999,-102.742054,-77.681897,18.573572,39.107016,-36.948326,-95.463689,-135.723299,-115.963277,-64.04561,-16.660378,-12.218712,-97.685228,-164.148788,-264.013432,-284.873502,-252.412557,-202.034309,-167.983626,-28.960225,30.551639,-5.056516,-71.550745,-125.073094,-99.423156,-25.630864,-8.055705,-46.357577,-121.296267,-107.875395,-34.457192,3.668205,90.391521,147.172691,174.158844,267.296535,311.505536,314.367152,261.942362,166.467431,181.392133,285.200107,323.399231,309.502034,249.333371,198.40872,77.032804,52.255096,77.66741,128.634222,181.670775,234.285274,177.861001,-32.277504,-137.588705,-281.062933,-304.578043,-265.234808,-208.057314,-208.685778,-228.465293,-237.43301,-250.67385,-235.026417,-167.248448,-123.055285,-107.164283,-56.471934,-35.377424,-41.877522,-67.47002,-96.263319,-72.623714,13.539955,87.125372,93.871213,44.787748,21.187287,11.691897,17.250456,12.553268,-1.238564,13.099787,34.993834,20.298733,-47.283042,-102.9951,-196.750608,-181.558558,-28.997777,69.715506,32.699309,-143.956071,-220.167731,-285.930088,-277.869502,-201.10029,-111.895964,-86.955835,-109.445189,-136.676657,-128.69742,-101.607239,-55.582229,-31.669788,41.374191,126.182231,126.047414,26.455233,-22.585011,-76.599641,-99.843224,-106.767178,-38.177804,-0.683046,54.157729,71.503832,95.781147,103.783753,134.277104,167.177689,257.059115,346.06147,349.547455,231.994396,158.932186,76.397493,65.51869,67.640869,65.365843,57.933794,-16.342971,-83.626882,-196.482991,-222.02853,-204.517746,-150.079849,0.311056,77.004318,72.00007,-1.438451,-51.430079,-128.488918,-136.202555,-105.194048,-19.437425,54.155251,127.534119,83.537953,-77.897605,-123.859275,-50.079004,33.897021,139.9581,148.271448,137.246162,41.328351,-41.014582,-182.598223,-211.557721,-169.719533,-111.683718,-111.254078,-154.402492,-206.279583,-336.74499,-360.456246,-272.482605,-199.534389,-85.68354,12.934108,54.354332,27.130047,-52.215978,-242.841403,-278.97533,-174.648836,-48.427605,-22.846112,-27.678203,-45.813375,-45.320799,-15.189784,42.763219,44.937708,4.657012,39.192709,82.541644,77.401603,25.871806,-104.34187,-168.588653,-195.442717,-20.63429,88.542176,174.475834,117.859067,-66.083046,-125.050171,-133.699635,-90.51045,62.109674,219.991795,247.18389,183.805888,125.844707,49.741187,70.001255,199.74526,279.564067,298.153809,299.996711,260.340794,104.245026,11.415251,-115.503987,-116.654276,-15.464105,58.499929,43.436246,0.878526,24.638954,84.046766,60.647265,-14.798906,99.183028,201.154262,284.136364,234.699894,43.82294,-47.08003,-147.441755,-158.965321,-157.056549,-105.675289,-63.749019,-39.001252,-71.528775,-171.037464,-193.875173,-143.418286,-66.270875,-28.763157,75.857496,111.046325,55.828811,-4.251157,-57.059613,-38.483007,65.649199,209.564246,258.039025,250.931457,201.209715,65.674579,17.06208,37.54827,189.000987,255.959827,236.239963,152.110435,-38.070092,-101.814162,-112.55833,-62.062913,59.954537,138.799488,161.658686,156.473481,115.520569,-10.021263,-56.489175,-44.596874,70.990588,113.095734,82.395402,20.165861,-115.100911,-164.069989,-165.783194,-117.203695:-124.837853,-133.505857,-153.329469,-221.209178,-283.292572,-365.608201,-319.126136,-121.27979,-2.304152,18.577832,-24.338221,-91.43984,-221.39027,-247.082005,-233.851567,-208.0529,-96.52358,32.809519,40.874705,-70.379126,-143.87076,-207.844221,-168.330482,-6.0187,136.329471,206.076304,311.972038,315.042204,239.570261,200.567089,191.699811,219.144098,285.777745,318.443941,320.521776,279.933543,222.20145,100.749531,83.39883,133.661296,196.738635,200.476725,140.543471,88.614642,-41.062286,-88.98882,-87.650733,-66.476335,-7.97547,109.862181,152.699322,84.61989,-44.518015,-327.508416,-369.540565,-222.123476,5.786216,76.249988,49.920477,-17.877879,-137.682679,-168.620069,-145.234082,-92.773518,30.217607,89.515079,71.711969,-32.60715,-88.454007,-192.1643,-231.149886,-200.773617,-71.646584,-52.070054,-130.790224,-166.788049,-179.826569,-190.974896,-226.803212,-211.27535,-82.676006,-10.655632,-41.36364,-124.899553,-151.552301,-189.30216,-186.155717,-98.225512,79.439175,143.166802,80.37242,-4.292864,-109.360974,-117.052101,-91.306886,-79.735877,-71.931558,-64.613669,-71.059046,-124.535252,-176.466352,-275.797149,-263.170663,-98.661772,31.631669,42.632007,1.63798,-42.221692,-171.531463,-219.996462,-212.978926,-192.732925,-150.875569,-30.98312,9.131133,-30.890308,-86.942247,-165.899718,-161.426692,-108.413418,-53.421784,-9.079717,30.628228,-23.908024,-206.095852,-249.532598,-193.669678,-147.0585,-58.481675,9.850878,-6.31227,-126.350876,-197.377773,-313.947022,-342.557626,-318.330974,-187.927477,-76.63265,98.211889,100.49197,-27.587802,-99.154511,-112.285071,-55.108005,63.603672,82.595485,44.20394,-52.768947,-66.817875,-15.874039,26.973436,111.329313,182.945015,206.438836,204.244674,200.532765,197.054537,164.185048,100.232779,133.755398,280.978003,321.668914,301.021996,247.363497,206.202778,105.125389,64.952414,15.040289,61.975761,122.977769,188.302673,155.21465,-16.585279,-119.130497,-246.853532,-254.697063,-172.113255,-40.883066,-26.798027,-132.980511,-209.791567,-306.057551,-309.159782,-226.943191,-56.980722,30.089222,108.801976,76.794436,-70.038261,-122.508481,-81.361091,-9.057944,132.624228,215.031616,193.950837,64.621343,25.21355,6.368634,-6.771121,0.360209,105.312156,159.188425,164.709328,113.984462,-24.59279,-87.616167,-127.964468,-93.543011,11.546717,53.797624,18.802344,-121.369117,-182.856167,-209.488447,-169.26074,-57.573476,1.049592,7.850997,24.475438,34.052717,-28.63501,-95.097452,-107.014445,-21.483281,154.703547,187.723359,166.548268,66.79844,-11.516924,-177.330487,-218.17069,-141.665316,-0.824356,23.808296,-32.741347,-74.726155,-74.737171,-19.112082,133.340533,177.686475,177.922486,209.298408,250.321014,267.823093,195.529248,-25.361554,-73.424694,-0.019334,99.078887,114.178766,57.405356,6.021281,-81.085942,-110.079853,-97.254983,-47.218009,65.853056,113.336936,106.835943,35.903978,-22.910281,-135.764269,-148.0563,-45.294023,104.481425,159.018814,163.839028,106.375294,-48.308407,-96.046931,-66.223773,-10.262247,112.271215,214.906881,215.765105,55.017606,-66.647851,-208.994642,-187.347008,-50.268553,33.599028,44.496722,-17.812826,-91.321785,-198.012925,-181.396735,-95.80961,-89.720325,-99.907737,-10.867955,36.742797,33.582381,-28.539395,-168.260414,-159.015626,7.914346,130.711618,169.140423,200.140813,171.329719,85.273475,61.32292,78.893983,107.127035,137.248144,165.099276,166.873902,97.683095,49.625561,-34.32756,-64.206183,-39.079098,118.619907,197.580586,219.120593,165.65213,51.226614,26.861925,88.156764,139.337381,151.903461,116.219451,109.464958,104.455141,100.919718,108.742663,134.934683,218.371595,308.568434,346.154434,326.958959,266.621468,144.644334,99.913456,36.644557,15.431835,8.398383,80.434714,90.950355,-29.357363,-104.72378,-130.599908,-99.892152,-74.154783,-29.4842,21.184474,60.290885,18.913128,-131.991921,-202.894155,-239.921549,-201.680593,-105.463288,0.31237,44.313973,-3.493298,-100.889958,-260.28151,-256.733181,-146.557763,-24.145343,35.912404,134.402439,140.700877,-3.680669,-106.147731,-157.228929,-79.001703,154.212327,261.229678,233.565015,108.081914,63.971077,15.210546,-10.732859,-38.170057,70.951395,154.880701,192.827799,128.481237,-58.869476,-142.383463,-195.561988,-148.059723,-6.485577,74.370764,101.315186,121.736072,94.74248,-14.438305,-63.279117,-75.267923,56.6181,124.347189,121.398144,50.120813,-118.476564,-166.887499,-152.366464,-105.50411:-109.126162,-190.003141,-207.986468,-197.370837,-200.550238,-240.138616,-231.05563,-45.790077,178.677428,192.357082,40.931842,-40.930128,-100.632589,-99.049042,-97.585504,-106.298416,-112.435961,-39.580166,-4.004106,-3.59507,-2.795886,61.584158,96.644011,115.633544,103.369932,119.48108,194.693375,229.941274,223.989347,159.51803,19.537368,28.820451,184.091097,292.561221,289.462699,184.917126,128.667567,86.996568,101.145597,173.643512,234.525778,262.911,304.98897,284.548763,146.5718,78.928176,71.917656,140.8556,300.768049,309.336796,274.204409,171.526645,106.280016,-2.481753,-26.347012,21.220285,114.287781,139.239629,160.187622,158.561908,138.428859,124.906175,66.221369,7.373726,-112.16322,-73.80114,-14.280323,-14.70205,-89.027011,-243.993985,-266.456581,-186.777998,-160.823678,-201.881758,-237.90782,-199.627278,-79.101909,-37.024224,-13.097219,-12.968828,29.507508,114.656327,131.358963,71.549314,2.142332,-132.69588,-153.594451,-116.654561,-77.589022,-39.073401,63.307151,66.752735,-45.727484,-106.302646,-137.320203,-116.016248,-102.743578,-159.127702,-175.4874,-163.200363,-164.739824,-233.597277,-266.905419,-231.375726,-73.680209,14.488963,74.666286,28.936816,-115.949632,-178.641792,-245.717474,-249.442914,-201.43868,-72.377464,-12.651232,39.103812,18.266925,-104.644429,-150.697757,-141.263932,-130.659341,-119.007275,-24.488242,22.017916,45.485929,23.423637,-71.206774,-114.217642,-120.740452,-80.38776,-86.673678,-175.730883,-222.242277,-306.718878,-377.751406,-497.914906,-410.016907,-289.006847,-51.889214,-4.852581,-48.425051,-81.264968,-75.258607,-57.301771,-45.141847,-71.433675,-107.973134,-152.517887,-126.930693,-23.233202,18.978427,72.729694,163.174233,218.873447,260.432153,251.435531,245.710524,226.398569,131.616327,101.600478,129.041562,148.871182,107.082478,17.588496,22.192952,55.058653,46.070199,10.871024,12.305957,35.72395,70.156262,59.10343,-1.801761,-65.261513,-279.112558,-366.175927,-343.353632,-157.367269,-94.804789,-145.042219,-224.722615,-295.9387,-253.61394,-136.71258,-61.800537,16.050525,184.98317,201.834591,99.410104,23.297903,-45.268357,-8.619323,115.206007,201.036575,217.977078,189.766285,182.014979,203.826093,189.08313,87.405493,82.200692,116.782422,72.111087,2.888461,-86.709985,-108.671516,-170.71182,-186.93254,-111.341312,-77.082552,-138.770488,-258.795109,-256.406,-221.667611,-242.37488,-320.708606,-275.346793,-181.911905,-41.259679,-67.174614,-200.190802,-214.967853,-136.801276,-109.846629,-64.393781,48.181379,41.791097,-149.877503,-237.50927,-243.125047,-195.977298,-111.797662,-31.087588,18.837187,63.364246,48.296794,57.63442,93.293845,147.157076,173.146627,301.567211,442.135906,436.310168,257.388121,166.029955,111.370431,124.562259,127.611866,34.781455,-16.583122,-94.593071,-127.630494,-162.987404,-174.927716,-174.310345,-128.615493,57.993469,265.107419,309.70612,216.867848,134.177901,33.713042,16.8348,4.505425,8.68831,24.861732,25.533504,-14.995967,-126.303194,-152.297083,-94.783597,-26.334241,127.008793,219.224891,197.435968,3.35122,-108.747446,-209.353364,-192.422889,-130.016737,-163.751091,-201.872613,-247.154436,-247.75747,-198.95108,-166.569096,-122.315473,-89.316281,35.122575,172.993942,180.172048,35.369383,-49.641779,-139.387744,-123.816244,24.811418,68.431917,4.885203,-116.128822,-92.913944,76.196287,136.057278,151.320494,142.635268,149.987582,220.437414,242.410311,205.893612,167.84475,47.696745,-23.788429,-64.69801,59.881787,126.406398,98.033461,13.598252,-90.60828,-69.36678,55.903363,106.338001,140.161023,177.039071,199.388511,198.915162,174.464014,132.631967,155.506497,270.808683,295.32949,266.78078,176.981799,119.753912,25.058225,-19.491833,-104.667755,-104.253903,-19.086273,37.142272,30.083668,-12.77569,-21.483378,-37.101095,-75.566462,-123.829236,45.082362,149.799192,170.269397,93.664997,-37.113749,-69.834607,-154.938453,-208.79456,-269.565665,-184.582032,-120.684396,-149.931945,-252.911231,-454.038922,-483.510818,-351.592863,-156.891686,-100.900126,-27.929168,-9.604183,-80.58096,-150.081028,-219.417869,-195.897125,-48.188283,136.956051,181.289935,119.415353,62.055503,10.740652,20.787741,86.046011,163.20886,213.302539,290.595914,275.515891,118.73188,7.847858,-127.750897,-104.489528,66.698434,166.191066,165.614979,125.655528,77.241983,-65.23139,-111.275359,-100.685283,-50.052916,-6.486668,81.066092,62.912587,-97.24715,-178.704169,-225.274136,-184.074307:-38.65455,-8.940242,-44.55901,-232.453336,-346.842871,-432.121152,-365.260617,-109.787842,137.802377,206.558216,118.015956,-16.528063,-258.335005,-302.140885,-236.626539,-178.025998,-53.465113,84.298719,113.99921,67.701434,13.28936,-90.798825,-93.692956,17.344539,168.911672,241.403178,289.576205,265.057799,205.044752,155.826344,40.394852,41.365489,210.269887,357.947251,341.40474,215.704425,161.383263,121.569543,153.961455,269.015917,334.749701,347.807135,277.832035,182.155345,-32.281773,-89.070586,-3.607664,101.90023,268.596646,345.84226,326.091241,106.116349,-48.7762,-255.675725,-263.742867,-130.984338,14.963478,44.930809,51.009509,41.678752,-38.041637,-100.559134,-162.730889,-146.224182,-82.476442,-36.161017,-46.004974,-151.879129,-220.694969,-349.429282,-381.756765,-292.651362,-117.071268,-82.361879,-165.920399,-236.456703,-298.176937,-304.529727,-319.854975,-301.963801,-178.798539,-43.207715,-20.728363,-94.737188,-179.316571,-343.091457,-368.145818,-254.145165,-39.695563,43.493622,65.318256,10.389664,-133.758449,-189.355056,-198.401839,-150.111896,-24.124892,11.082509,-30.367648,-192.973743,-288.27824,-422.432341,-418.997909,-269.465668,-94.268555,-22.080684,26.849674,-23.132125,-187.051113,-264.328868,-356.274038,-357.18756,-253.286368,-42.883872,28.700704,2.792826,-73.03406,-240.335395,-277.865097,-226.075078,-122.331432,-70.976452,-42.489291,-92.321518,-213.206398,-232.165162,-205.025162,-184.432781,-113.733901,-36.667117,-67.318677,-263.33403,-347.138988,-411.389328,-426.051105,-405.785848,-229.228366,-110.549072,25.539103,5.93842,-155.023063,-231.43126,-257.446044,-213.073288,-86.383206,-34.037926,-70.509568,-178.829442,-204.78369,-203.473279,-173.223097,-6.940612,219.818639,298.839354,304.925712,241.62282,107.207648,78.796515,101.103857,130.229847,206.357176,238.294078,209.136935,112.46621,59.935609,-48.187908,-73.724314,-13.941891,149.757471,233.081726,259.233157,183.016707,-63.054267,-185.466572,-310.950224,-303.946299,-211.381935,-46.295322,6.090355,-86.295154,-177.252326,-235.023954,-202.283062,-85.32357,113.270026,215.679813,277.728658,224.20679,69.955307,10.733973,-16.490471,30.988642,200.869251,353.194881,366.82976,209.470971,97.655483,-34.214526,-44.445938,-1.91006,81.31291,132.385786,143.1566,84.878353,-83.622695,-163.570902,-226.485814,-202.917957,-146.294125,-105.816765,-87.061835,-114.441168,-158.553616,-233.360712,-239.513424,-182.731441,-67.000538,-11.814187,-7.036298,-62.296645,-176.265661,-198.386583,-166.255288,-122.045262,-5.91929,57.921281,30.226896,-130.11042,-212.647941,-289.487271,-292.395781,-235.073641,-92.056859,-29.211149,4.117509,-13.809288,-64.940363,-89.111869,-81.783444,-25.824934,191.829087,384.997905,387.22345,198.836937,79.484125,-71.881246,-88.954824,8.581021,143.672857,148.15793,8.89255,-90.97353,-224.812119,-243.064611,-202.01649,-149.34927,38.284752,240.214139,245.345868,61.368737,-45.922158,-137.562547,-98.803929,48.180094,106.47305,110.112434,96.27812,68.598852,0.561807,-16.478351,-3.166489,23.01182,121.470557,270.089217,306.820376,155.085085,-3.617392,-230.618022,-233.961943,-77.935016,87.170689,117.916572,33.982734,-54.551826,-178.879788,-190.737014,-138.842367,-78.077002,83.152214,215.263549,233.468498,113.087327,-15.566039,-233.936538,-223.144043,32.961081,209.731509,212.106082,155.136268,125.407076,92.252487,84.425199,84.528305,107.840218,205.763957,309.034692,324.540469,248.399914,170.705035,18.485093,-8.521896,61.406962,220.863602,301.102636,332.77951,274.609621,133.603435,92.516128,100.717757,145.584003,264.02907,316.564519,302.448192,224.76401,176.066537,125.697537,150.673976,278.748699,414.704279,455.077653,402.84919,308.60138,117.370035,68.128918,67.590801,94.733205,145.102815,159.611075,146.269969,52.090135,-10.213271,-103.795414,-125.823582,-92.748163,45.977356,113.935759,107.938888,23.646526,-174.509241,-238.287069,-240.762783,-188.934657,-85.206174,-27.593355,-8.633986,-36.976902,-99.852733,-266.335614,-316.311833,-266.632178,-104.946333,-37.823349,43.636874,56.052541,-30.096737,-110.858302,-166.317727,-103.390268,138.233516,371.510656,401.268649,231.838189,98.768062,-50.349267,-36.82096,75.458201,217.381387,305.167653,345.906608,233.684498,-56.464033,-129.482764,-103.9278,-33.660263,129.938203,213.602148,212.423784,140.951216,74.310862,-91.636844,-138.132234,-54.437323,172.312853,260.457453,261.841922,165.759856,-113.041787,-212.887825,-211.075218,-127.946634:-118.054973,-94.984951,-73.971943,-109.461806,-139.786705,-156.022591,-146.884606,-83.509203,-25.796817,-25.108158,-58.163209,-82.223297,-121.50024,-133.585971,-139.365293,-129.789182,-122.509615,-114.056827,-90.973017,-47.60089,-37.42684,-19.178506,-11.067275,-2.437993,42.650159,85.189693,151.808845,165.114536,150.289502,129.511213,95.482606,81.40306,68.397658,94.73211,106.883809,81.348921,51.498172,-5.722597,-13.644666,90.940996,274.010149,339.232092,427.573436,434.306512,317.828973,245.194531,197.513465,209.157954,271.676534,347.391909,343.8618,209.564843,117.666303,29.982361,36.835331,64.209043,65.659154,77.094817,131.562067,145.773123,120.547484,104.356407,99.454331,74.839097,-96.810582,-173.788245,-102.469793,-18.106274,-90.233394,-287.385106,-318.391903,-246.004194,-169.309288,-149.374981,-92.523588,-39.14792,89.486438,120.384536,101.608546,99.98293,148.23661,189.677209,188.891144,130.946607,84.509212,-15.436814,-43.017706,38.206334,159.555165,166.962803,154.498709,162.148815,129.413058,64.031207,-59.96569,-77.43803,-75.266769,-109.745624,-126.297276,-129.490626,-146.26917,-235.081165,-274.40515,-248.12719,-63.57773,26.228517,54.040874,14.474263,9.852177,53.969259,85.800104,41.708804,-81.244002,-73.112902,-22.618457,55.800873,61.043424,1.992386,-41.517108,-107.220827,-126.825667,-106.967026,-85.125989,-95.364007,-90.966583,-97.430029,-189.574006,-242.021295,-270.121631,-242.024936,-242.496273,-291.352493,-323.47141,-411.529114,-467.267056,-519.451081,-418.087315,-317.224937,-156.50116,-140.009818,-160.19355,-152.747606,-93.093375,-67.904552,-63.74308,-50.471407,-56.020585,-136.323213,-165.199948,-121.097608,-75.274935,8.564134,123.863818,182.974714,184.991058,115.674245,-42.403988,-86.116099,-75.241999,-49.921441,-81.452105,-124.30605,-92.527555,-31.488528,-56.804902,-165.52162,-182.750651,-122.685897,-25.056673,51.159079,161.99246,128.015707,-54.169656,-136.374537,-221.936133,-213.965948,-106.495237,21.974689,55.966769,31.413682,-18.514986,-90.261953,-63.700522,116.356093,270.713295,288.510008,267.801446,267.976515,285.640333,253.519479,109.880054,77.655892,132.784937,204.304457,249.302319,348.181346,380.106176,356.9346,309.930259,225.820691,178.826115,173.661421,189.088132,183.480511,114.257602,64.043456,-13.126474,-18.432763,18.237202,3.831507,-15.622053,-38.351317,-70.054366,-173.005213,-190.857131,-143.62063,-134.198785,-131.730947,-95.912919,-84.608331,-82.60681,-99.960948,-190.033417,-219.262649,-114.735723,63.615438,76.091809,-2.871136,-25.248505,-25.249874,-23.769055,-3.201624,60.236347,95.670085,135.632249,133.900785,84.557413,43.740493,-18.29185,-8.208698,108.634268,255.394813,283.813728,189.655667,111.174453,3.962735,-24.993813,3.973816,108.571108,132.70149,79.828207,2.70642,-194.60853,-278.853108,-296.466292,-194.58228,88.387871,241.27529,255.076242,174.448463,106.964689,34.962514,50.48146,117.528774,72.484193,27.234203,34.408309,68.403387,43.887808,-15.308899,-41.408232,31.1281,190.582978,208.3791,172.219695,76.552308,41.85515,-32.758291,-70.291856,-65.018326,-9.676472,-9.177699,-66.339701,-97.792186,-111.287114,-94.800797,-18.141174,55.169599,184.579877,166.946827,148.116521,132.568314,90.984885,-63.698567,-104.537736,-11.925624,100.166419,86.617296,27.877697,45.294739,145.052771,181.235938,215.718829,239.01401,284.48857,234.753481,184.162016,142.467116,154.48315,132.05523,78.255637,-23.372048,12.232184,82.947026,184.202381,180.136215,129.477192,116.65663,174.622943,244.078647,327.637458,236.623702,180.501321,146.284575,156.169062,195.24128,211.987901,199.777597,186.537512,197.492053,177.936569,113.630222,-87.008919,-161.870379,-124.815135,-24.973553,130.107501,135.496348,111.945413,28.601241,-3.24327,0.205235,10.661245,-0.414726,24.123299,68.654724,74.725743,-7.385739,-181.675785,-209.144306,-215.311055,-227.277219,-258.556736,-245.11724,-222.878866,-272.148667,-369.57708,-566.821109,-604.111892,-551.748404,-410.011789,-338.173775,-288.642121,-307.815673,-313.845931,-289.087652,-225.031196,-180.555745,-91.33044,-13.484906,37.530638,97.373317,85.005262,33.131283,16.800872,2.205921,59.015961,136.498408,252.726152,227.927783,51.767362,-27.015481,-50.788823,-8.158037,69.342714,71.35303,75.280759,84.972246,62.096199,-56.062189,-117.197188,-130.381268,-75.299877,-56.857467,-18.825563,-10.762902,-54.794217,-93.333784,-141.100307,-140.567337:-37.791562,-89.154492,-107.646606,-110.834444,-96.458451,-60.217573,-49.640417,1.537972,109.682099,150.968672,150.264594,124.224531,43.556582,-17.824709,-101.611846,-107.158503,-116.00392,-103.538548,-63.55106,26.429702,47.382791,33.848949,17.729482,20.780778,56.053746,71.462028,135.807525,206.454483,294.823513,239.489379,53.661458,24.570107,78.573094,105.039764,112.224238,106.154611,78.906645,50.689422,79.182856,147.954706,167.13635,205.929804,326.19745,348.021898,274.559406,222.062813,192.208662,225.477685,304.16754,287.109067,267.428101,242.473596,211.452034,135.551529,142.831589,215.010625,212.381677,195.515033,201.85747,226.607098,280.858515,293.757763,235.985815,164.251595,34.242278,7.897421,20.786208,49.485218,49.01145,-21.36137,-73.545512,-129.762438,-117.588656,-101.427662,-89.295903,-98.817739,-87.797638,-51.198235,28.392571,55.254828,92.019054,116.398649,135.963728,175.590671,176.527424,96.792589,37.344644,25.357092,101.008557,110.915571,73.041432,43.400381,-4.391328,-16.806872,-36.099843,-60.503374,-145.507027,-162.902433,-135.22039,-123.844924,-152.531054,-187.47826,-165.816589,-81.703597,22.6792,84.880256,139.33792,110.55741,-29.648835,-107.830476,-135.748152,-92.389177,-86.543172,-98.288051,-30.74444,94.965088,87.087119,-9.190462,-35.653739,-36.922638,-69.756288,-77.00811,-73.337976,-84.99012,-109.612253,-110.865232,-107.259144,-106.925584,-103.425306,-99.86147,-105.814003,-136.130525,-171.839463,-307.413022,-382.40687,-433.04052,-336.132174,-271.514538,-154.237041,-103.698293,-42.276292,-46.88599,-109.397057,-135.882352,-113.288343,-3.630043,15.889395,-68.265492,-102.344971,-72.547567,-43.818043,-2.877682,10.725179,37.677587,136.030957,152.947658,81.046832,20.72379,-70.986524,-86.924493,-75.407851,-10.258543,22.014537,35.154534,29.481604,2.061098,-24.387157,-47.229652,49.233727,121.116402,162.929763,101.853927,-92.962798,-178.055065,-282.249388,-307.027448,-316.077265,-216.021387,-158.314793,-187.890797,-267.109586,-382.304375,-369.44728,-249.667299,-157.375615,-120.261775,-34.846835,-13.436154,-32.336091,-43.436574,-42.906217,-40.178112,-24.694071,50.532294,107.372144,150.330023,128.751882,80.612424,67.707795,40.48346,-17.43621,-31.838138,6.965718,59.211511,163.199079,155.357015,8.203048,-51.253549,-14.939818,88.236089,90.610086,-61.00951,-168.273379,-297.572077,-314.675916,-338.368213,-373.636176,-331.74982,-152.166716,-108.022715,-184.065713,-239.791985,-283.748064,-291.619364,-275.713534,-153.269671,-107.90763,-116.760862,-107.16033,-16.60637,15.076944,56.558105,105.053457,121.172003,158.358103,175.679449,177.522832,152.870805,104.670904,116.578683,184.254558,257.865822,295.839974,289.509322,243.451061,143.051901,90.056143,24.53795,49.811982,65.277748,43.130685,-13.136806,-180.857004,-262.70111,-359.020332,-327.996594,-83.463109,187.333145,243.584078,157.920419,66.022695,-60.864593,-86.175834,-114.35407,-113.808419,-88.863373,-4.197129,16.188227,-47.030623,-103.26256,-129.49945,-79.841277,73.709962,242.919224,293.255647,234.628525,140.613302,-77.612661,-156.710989,-192.89502,-150.702497,-133.479329,-127.427198,-147.636506,-186.899417,-163.997015,-25.663167,46.504018,121.373006,188.552324,227.03236,205.799329,137.605249,-24.651696,-75.642826,-69.395174,-23.902927,-33.064383,-89.584265,-94.982866,-18.81074,19.616416,48.545403,76.306058,147.341436,128.271456,107.383572,108.954258,102.654237,8.415661,-50.283951,-92.474734,-83.447167,-90.843556,-124.73811,-147.249813,-200.14067,-218.195561,-186.202866,-124.290322,25.076781,109.118217,141.000133,191.254067,186.107839,121.556875,98.353197,122.255963,119.540608,91.014679,73.475994,75.579075,-22.841456,-123.563734,-224.490941,-162.044872,24.127281,24.346567,-18.728989,-56.45657,-36.07682,9.735831,14.070931,37.790857,105.53375,141.840215,146.84099,98.213068,-28.18137,-71.86833,-98.327133,-100.817914,-171.477701,-203.114342,-162.103286,-146.740996,-230.437332,-454.145057,-490.313809,-357.123778,-149.918145,-79.565981,-75.165138,-121.951028,-185.26831,-194.585625,-190.597793,-166.458914,-115.307259,-63.459514,-6.296273,85.918693,83.049574,-0.096651,-55.38934,-80.97169,27.176904,87.616439,161.864463,170.910637,118.664844,47.546558,-81.66237,-65.424278,101.585915,170.144735,150.549227,112.013301,79.062945,-66.728568,-121.107494,-83.521187,-26.130048,-23.021592,-21.259421,-26.604134,-104.095391,-177.226372,-306.168761,-318.535797:-68.960572,-67.319182,-93.816536,-175.320064,-211.514485,-228.193275,-209.734587,-119.283119,40.553461,76.28823,-58.180061,-151.618125,-159.18546,-103.265949,-68.003871,-94.007302,-95.376456,-3.792252,11.855355,-45.466279,-72.277667,-70.197862,-52.956981,-7.258069,44.328488,70.832862,109.365176,129.986142,169.926481,149.032873,-3.802047,-53.235856,87.224051,238.105758,193.167182,-0.57769,-42.304319,30.884734,69.882726,92.645457,188.566967,268.831938,365.139326,341.604878,197.551693,131.097246,119.003999,169.993229,248.797893,235.694226,223.356261,135.733044,62.447204,-19.459875,-38.472921,-83.644503,-11.739086,42.731503,38.245316,-6.870544,-46.03908,-42.768236,-61.715009,-85.642186,-163.340597,-182.071396,-162.793429,-177.035193,-219.897568,-332.032386,-361.677127,-313.601092,-229.980185,-170.951491,-35.004814,-27.596326,-88.213105,-89.534216,-70.12708,-57.060574,26.873373,95.292433,75.023988,-21.465583,-54.806851,-98.763312,-114.787189,-82.032297,-9.07124,13.441338,62.827687,85.002755,42.077581,-13.579039,-78.248762,-94.506942,-181.548232,-212.157487,-168.237328,-109.464684,-143.647434,-275.990468,-307.052815,-220.527729,-22.031586,57.402599,24.244762,-60.051705,-142.689028,-130.573133,-75.898028,-45.381635,1.407641,74.544441,120.350365,141.912874,105.359637,-23.069547,-76.838172,-68.696247,-7.670363,5.263933,5.706306,-13.838216,-55.696508,-55.258444,-54.856468,-77.350144,-115.2502,-147.335228,-195.360411,-339.678497,-395.701655,-428.123915,-422.827226,-362.780321,-228.574592,-151.070007,-32.539351,-24.677437,-63.289246,-44.816797,21.683505,10.81765,-27.489189,-48.009352,-95.341607,-193.671793,-199.847073,-136.07703,-91.738728,31.339106,226.385002,314.682609,339.144492,293.326871,230.405188,204.274211,149.336528,151.825976,148.26667,50.420415,29.030544,88.078221,98.303097,-27.007556,-96.000023,-75.594906,22.352982,41.753295,68.848933,80.125482,18.66834,-65.037153,-194.690098,-185.06958,-80.051385,34.412141,79.533711,123.954813,121.534674,80.697988,75.882835,190.689991,360.591246,407.802726,418.642977,396.416699,344.674273,314.218716,218.977444,166.296709,108.475307,193.221351,272.50036,311.37795,261.374413,154.040568,122.876484,98.953051,96.895739,84.196079,38.928879,24.829924,23.169183,12.131244,-85.883135,-141.671483,-113.627775,19.652135,12.96291,-128.313034,-155.586796,-73.825496,-46.786638,-54.15853,23.272625,94.546308,142.522746,90.30386,-52.705576,-119.640829,-267.070627,-295.17343,-127.087714,96.968337,106.45312,-29.689947,-92.683422,-167.972405,-196.13397,-126.520493,43.119672,62.98505,-11.866435,-42.857544,-29.753144,-14.155879,9.339722,48.28469,184.139707,259.836282,239.992182,131.921881,81.491992,-0.728708,-32.442472,-12.040463,46.121429,44.862761,-42.60945,-112.791514,-196.684691,-200.052533,-142.744809,-57.913006,159.369654,294.336068,309.769773,199.893869,113.636427,29.73426,43.200271,93.210794,102.325203,130.332096,213.44386,208.484104,84.950181,7.733326,-50.936018,-8.8639,116.409452,167.752619,157.870882,79.199309,27.906579,-67.496752,-109.508542,-143.868689,-92.507631,-64.07063,-67.397698,-76.796532,-41.571719,-11.981639,37.447389,65.50217,130.274559,170.85817,164.598855,63.118076,-30.570591,-178.607299,-154.867343,66.064376,191.328021,172.983375,111.864634,102.539249,118.840972,131.301376,151.389594,149.219036,95.04335,110.75297,147.175992,129.812314,97.797776,44.061347,-7.528919,-89.5759,64.496712,184.394171,221.541722,130.900541,1.128708,30.637698,178.557271,217.015764,161.731786,117.659693,136.552991,144.674246,116.916765,112.528265,164.540793,293.475912,338.054678,321.481787,204.718681,107.421069,-70.982432,-101.057969,-43.281745,-4.742977,33.949436,36.849371,6.07915,-71.874907,-79.463061,-74.747289,-84.38755,-102.975553,-70.209374,-18.946353,68.138705,47.883792,-98.060852,-168.2191,-248.905988,-263.706219,-224.869931,-104.326448,-72.08454,-162.622839,-255.998259,-423.822406,-476.48528,-472.113961,-293.679495,-185.115346,-102.045191,-129.737188,-142.50409,-107.27471,-69.108235,-67.495612,8.917542,125.942323,135.250364,65.051933,22.274084,-41.927472,-39.70166,65.185779,181.797579,206.278376,202.782312,178.034372,59.823713,-17.758035,-132.12408,-140.335237,-36.224384,111.079372,150.938707,130.846937,84.073481,-50.900287,-120.132238,-159.502411,-62.352335,14.651045,122.115993,89.860537,-120.249037,-202.740573,-174.091831,-94.104721:right
1.035905,-45.717174,-54.054499,-31.92013,-25.304418,-27.651859,-1.639683,93.855159,60.65061,-0.260022,-107.390927,-154.780543,-214.115347,-202.083067,-78.103024,27.681738,171.320745,82.449474,16.780831,-58.775397,-57.527689,63.841841,134.940417,152.460463,105.790542,101.991105,57.007809,4.465148,-12.626565,48.992824,190.17681,230.855375,264.590314,288.113339,279.581407,199.303346,166.353964,182.094868,202.131852,240.515024,286.621082,273.041444,166.772968,103.165095,22.901955,15.585364,38.74578,47.458998,-8.68422,-130.196042,-170.614102,-197.661225,-196.819581,-182.574697,-155.40963,-38.854462,25.291501,8.712901,-42.440324,-40.391599,70.74301,128.717335,126.272401,112.368997,111.058974,40.328949,-6.694512,-17.231375,19.292498,68.034832,63.517809,47.55321,16.636224,-8.157679,-10.899717,13.169572,42.149805,50.872763,141.829655,213.475021,283.071244,299.611402,314.361172,267.996652,239.299404,282.183869,295.817352,191.895424,79.341694,65.430435,37.517176,-4.693936,-45.673461,9.543415,219.233416,307.736819,355.58954,303.883805,265.997875,125.62564,48.048521,-13.655157,5.744756,103.172561,165.217406,152.634877,103.745416,81.469124,-9.125697,-76.842769,-132.927398,-82.823378,45.685135,60.841839,60.934999,59.721026,61.38639,145.650846,211.848092,250.604558,140.977202,72.397537,-93.874675,-189.026466,-268.212778,-224.769458,-135.855895,-156.774219,-257.733324,-276.084435,-257.234438,-232.741525,-226.583474,-221.711899,-225.894503,-158.023946,8.121808,56.054581,17.791806,-31.203453,-71.507172,-83.201619,-170.629149,-207.682915,-166.113422,-34.21655,18.874744,51.295331,52.421503,55.975193,51.683269,96.94337,147.291865,92.55967,-85.601484,-131.291264,-127.598721,-114.11008,-80.609697,-54.941591,-29.686634,-100.825469,-144.933472,-130.015385,-54.803416,131.348413,185.909992,194.999154,97.49582,3.315324,-197.204878,-238.054025,-146.079078,-76.965209,-22.084933,1.761228,94.028235,68.027208,-25.174464,-213.996381,-240.140919,-194.531215,-151.248416,-28.941699,-56.613833,-150.536799,-287.129095,-292.81978,-220.06777,-159.393905,-53.475187,-35.667884,-62.561383,-120.796118,-153.669664,-196.687933,-201.969961,-179.731126,-138.04815,19.674846,116.188808,92.103178,-41.004521,-95.085867,-47.458245,33.707941,70.916836,5.282161,-74.514424,10.238887,41.80394,-7.88572,-61.783299,-149.343047,-180.438652,-201.530505,-187.598056,-196.991749,-237.107953,-256.029751,-292.568648,-310.359526,-275.552893,-212.621641,-107.901137,-97.803668,-127.655385,-234.455379,-261.07017,-199.829323,-143.353008,-48.901728,-80.967189,-134.014044,-164.163856,-152.62052,-138.071679,-110.141639,-26.689692,5.039559,54.361936,59.634754,56.334449,100.65735,133.389073,173.140888,205.365669,315.468387,325.692817,270.956344,120.628836,61.136937,32.794885,57.848754,121.517788,148.312594,152.132816,58.681725,13.646594,-67.028619,-124.246544,-201.415109,-187.012552,-106.169832,-90.984366,-118.019298,-193.303411,-223.421808,-205.091123,-146.928165,-42.235775,-48.070691,-144.282932,-201.317958,-213.911234,-235.165995,-219.41707,-123.602854,-78.106334,-72.002375,-91.689421,-77.754434,-93.649498,-131.253044,-136.418961,-78.128789,76.70763,123.92614,120.163378,73.81231,36.382947,-109.49566,-178.620379,-195.308268,-149.847838,-83.326576,-137.435289,-160.056571,-163.174191,-154.825677,-76.896084,-40.468257,-65.501953,-76.933043,-4.180788,76.607865,85.273637,16.190807,-51.869974,-133.419017,-106.214813,32.083255,45.100609,-26.353036,-186.296869,-237.603295,-238.119188,-188.558822,-98.547349,-84.401397,-73.2723,-75.278072,-105.445966,-214.19282,-259.602682,-274.306348,-247.074255,-173.469959,-113.206843,-85.361532,-49.863978,-46.426491,-34.261869,-11.819263,57.111306,89.57411,88.014049,-20.250964,-84.793652,-161.810551,-161.430129,-134.979864,-112.01481,-12.063826,10.755167,-22.870304,-57.885812,-54.145764,-56.524326,-72.240159,-102.386574,-81.273876,24.397567,56.023622,28.799934,-55.548491,-89.901761,-98.646359,-70.296639,5.316416,-13.520429,-52.485976,-93.742449,-111.151156,-200.837373,-249.078378,-232.473319,-155.08914,2.508275,-60.084372,-166.319677,-292.134471,-252.494679,-107.318819,-82.870457,-100.179512,-87.76266,-68.85595,-42.423963,-62.312557,-136.040129,-136.277267,-16.244678,67.697175,114.608596,-19.100257,-68.699326,-46.589432,5.63367,113.383302,146.143538,212.249385,282.431573,280.018051,161.969924,64.217531,-73.740502,-79.133054,-56.892236,-77.690099:-80.378823,-67.380027,-62.022819,-87.102045,-74.967842,19.577069,63.090276,86.410097,2.892017,-59.617309,-130.089703,-116.673019,-50.471789,-26.035515,24.29373,67.644869,161.111635,165.311339,108.351578,-46.010987,-75.411272,-28.794984,-1.124893,30.345837,45.037155,31.896722,-41.308358,-71.334945,-31.473562,32.931998,179.107425,252.277054,357.979401,328.457936,275.925395,228.832317,263.800737,368.936135,406.68019,434.185419,366.530186,298.422542,146.902003,94.696181,109.624107,156.184293,210.644949,221.54885,236.231232,157.473591,96.015751,43.346163,50.572326,64.182115,90.756024,208.143803,232.340539,171.210603,50.506648,65.221022,201.384965,234.549362,177.990216,151.730818,152.713143,126.152377,96.157216,46.483582,56.374604,148.275733,185.145945,164.266805,55.955288,-5.851769,-49.504438,-9.212014,94.851361,110.551585,130.786213,178.730645,279.380535,263.840177,217.331568,87.194046,62.281859,176.941275,261.94288,330.10292,253.980283,197.878051,70.09074,17.354712,12.231509,55.081613,199.742721,277.092231,325.222496,207.777191,124.008835,-11.584426,-26.929688,59.867245,138.939512,338.22508,445.527926,417.523582,298.182895,233.589463,87.077181,28.740655,37.210524,93.997678,125.918182,-7.430581,-59.96372,-12.389704,68.61426,169.611008,165.290178,159.082568,142.225662,87.116677,-62.118973,-115.550194,-140.910518,-117.80253,-13.015738,27.257689,-46.092392,-225.466033,-270.241051,-200.977355,-125.706383,-36.279649,-37.377889,-50.103512,20.651363,50.540801,-3.090334,-47.748368,-46.671061,-23.138968,-5.117235,-6.861231,-56.386718,-100.350176,-66.372936,36.916379,57.290404,68.053447,76.597811,108.318258,105.425504,50.46899,-118.474663,-179.63171,-174.00117,-122.763426,-37.038717,-25.821004,-63.474609,-127.514009,-135.005864,-95.529936,-67.835225,-19.989036,-8.367513,-27.770106,-94.35887,-131.677739,-189.965277,-209.167945,-202.228778,-178.931052,-106.899074,-50.8109,43.148805,-41.67078,-135.836257,-254.288993,-242.361192,-129.595109,-57.004581,66.601254,21.084683,-56.960475,-152.419506,-131.711238,26.54524,114.309821,192.358661,175.856219,74.322474,-45.236434,-92.504286,-137.594058,-139.349853,-103.742494,-54.532423,76.786179,84.923065,17.871302,-131.56445,-153.879215,-58.684179,1.811289,19.561894,-0.92104,-37.333039,-81.611848,-94.329757,-117.398079,-133.735876,-130.845913,-103.926757,-61.534402,-146.232626,-234.649065,-408.432824,-446.092527,-380.728972,-316.544084,-188.772433,-122.94329,-79.911563,-164.050766,-206.522108,-295.425865,-325.218596,-277.634688,-214.732531,-126.770572,-167.649686,-208.064183,-257.679968,-274.558916,-287.068983,-259.344948,-108.832754,-21.822247,51.391149,56.306331,62.622546,59.323313,61.765324,110.128082,151.399196,227.089182,193.362712,130.792449,-0.206736,-45.69738,-88.698721,-81.239475,-6.837545,27.569802,14.17607,-57.365342,-104.92793,-228.986649,-261.019818,-182.253369,-110.276078,-84.386159,-183.847308,-194.652437,-165.010379,-167.384191,-175.274358,-169.48736,-196.670265,-227.677036,-252.620144,-231.453543,-226.875494,-257.130806,-283.453021,-261.724464,-167.344771,50.216898,-0.867886,-76.814649,-169.613789,-205.303684,-253.191479,-222.029368,-48.281292,17.467505,-3.423801,-81.061745,-106.505091,-146.48419,-144.912034,-105.478654,-91.278613,-59.603076,-38.372836,-57.802441,-113.484366,-106.80136,0.077064,48.215606,33.580762,2.782117,-48.273448,-72.942453,-80.058847,-122.845721,-125.060018,-12.798623,69.099769,126.948162,36.769908,-17.134316,-123.897079,-162.454269,-153.078538,-128.108747,-96.156175,-84.720897,-104.448816,-171.089145,-198.86691,-262.706225,-298.143814,-292.605221,-242.679073,-152.029125,-105.367348,-79.55602,-66.577976,-85.161755,-94.034406,-55.889934,78.401402,131.051197,110.096384,-35.216851,-102.349094,-174.544723,-171.447705,-88.392236,-15.687732,130.2701,136.282031,85.157506,-13.857866,-45.194979,-114.509447,-141.692402,-134.774817,-117.30336,-102.68777,-110.38529,-131.737001,-213.166421,-238.481263,-201.503476,-138.213266,16.257022,14.028395,-57.289464,-198.040632,-233.349732,-248.987164,-236.179605,-154.246709,-95.508203,-38.111504,-178.805199,-313.260435,-501.297138,-464.982062,-194.844113,-79.559703,-53.372436,-167.637634,-197.708875,-189.037699,-200.05597,-273.863834,-267.051553,-87.691012,-0.242255,-32.215669,-165.470909,-196.906765,-178.111939,-125.194417,-17.327285,13.712594,90.554156,155.688892,147.214333,23.530431,-64.364074,-146.090921,-126.889882,-74.293289,-65.678255:32.330669,-35.306147,-71.252693,-44.009129,-9.857532,34.400812,58.026259,111.508876,87.900294,45.961734,-20.466936,-23.192585,40.181173,93.403533,187.463962,198.411017,126.69065,35.858497,-17.555831,-131.944176,-143.770174,-65.358979,-10.710286,47.617822,-52.437141,-120.310973,-185.161439,-194.447269,-144.823366,-69.755468,99.184255,149.997296,160.708963,123.802112,117.796636,177.395556,223.815741,255.753761,263.63921,314.385538,272.162339,194.299691,81.705449,96.03219,213.549587,282.012973,387.098147,401.034561,354.921881,259.279657,184.628131,82.179688,107.566846,231.754451,266.721155,224.986397,133.640905,119.682333,102.391494,80.356305,85.590097,117.636222,175.209797,184.180373,132.867825,26.365877,-27.233443,-84.972044,-51.484789,103.483403,149.006232,89.705289,-8.480557,-19.610988,-12.639636,-7.417353,56.641764,104.91188,182.723568,217.156745,222.346113,149.671848,119.069701,88.605854,98.678502,168.214713,211.048239,266.378252,242.734412,201.681453,77.358815,19.435493,7.449967,69.365685,273.204731,361.296472,401.721758,284.769969,188.869781,35.703236,51.160359,239.668261,336.337064,430.286857,399.641667,374.386191,333.739416,302.365148,207.359223,161.60502,160.70929,191.807692,157.318666,3.095825,-68.536445,-108.199755,-62.997581,45.632401,69.111755,99.519142,115.417349,79.835809,-75.51623,-139.427187,-153.25076,-122.704302,-21.733859,17.496721,-38.603903,-161.534811,-191.460227,-162.112908,-117.751258,-67.010606,-51.38118,8.464084,-15.032141,-70.481249,-166.977401,-163.643677,-75.376055,-27.449629,58.224936,81.692841,43.911709,-18.908166,-14.873678,75.906023,126.199712,146.933024,132.252337,127.711671,120.487224,74.974942,-68.082714,-105.120164,-73.533122,-54.02617,-61.539246,-71.402421,-90.815345,-108.53101,-117.077333,-94.072914,-52.92081,16.442022,32.938894,54.063733,17.046895,-23.829954,-100.424484,-120.921625,-81.796679,-21.218552,126.065529,179.641244,176.272347,30.192836,-59.89018,-122.206137,-75.366641,26.854703,52.174169,108.256186,96.783226,44.012868,-40.794112,-33.876363,68.395178,139.626292,258.43112,271.905202,138.4237,-53.098688,-79.410693,-12.237598,32.345324,72.003741,79.74007,109.919048,82.55405,27.911929,-101.792163,-140.134367,-135.902177,-106.758813,-34.903114,-9.738184,-3.55553,-44.089063,-73.217467,-118.329194,-114.192707,-41.888791,-2.947647,54.112069,53.888563,-16.692541,-222.501863,-264.090428,-159.048223,-75.454327,9.211899,12.710259,22.828675,20.371613,-38.028584,-194.052722,-208.973604,-137.272439,-109.378803,-95.599425,-78.478825,-73.793049,-124.804589,-170.302416,-226.119029,-200.700756,-18.073653,77.390957,104.020222,-18.584673,-71.651417,-73.925701,-2.096061,179.716098,231.548108,243.316112,179.247912,134.869872,18.74938,-51.691898,-128.586348,-114.561849,-34.37336,-3.065107,-13.948006,-70.549471,-96.332765,-151.932208,-162.640632,-96.10696,-39.456067,-17.284179,-117.031924,-151.223346,-191.072462,-230.122689,-291.146529,-265.5027,-141.305313,-110.373524,-166.263777,-212.583609,-216.120726,-252.862463,-262.948398,-172.310174,-88.681311,18.800088,-51.459988,-126.796578,-231.864776,-240.530349,-175.635262,-113.733772,13.216792,41.498371,27.06164,11.289558,-22.153014,-107.674433,-97.797013,-12.984824,7.009457,35.489612,91.848103,88.700422,26.082555,14.109386,75.640753,110.572448,104.994697,85.412425,77.695127,60.407922,16.428697,-65.053158,-34.025742,127.837098,169.314828,135.281682,88.912273,62.173835,-10.376323,-45.646943,-102.148538,-117.701449,-105.837637,-79.58248,-36.120045,-105.037482,-192.924892,-351.194638,-378.000381,-336.310076,-275.281689,-109.634517,-56.052437,-100.216755,-189.632928,-190.619267,-154.494401,-135.258175,-47.570984,8.468616,-21.077297,-240.752531,-316.000126,-281.615272,-215.075012,-118.818759,-77.902571,31.624356,109.937392,103.775806,-52.359987,-157.187391,-245.099019,-229.78038,-196.54092,-192.360083,-181.000135,-190.26204,-218.774069,-297.933186,-311.314179,-248.372034,-190.060801,-100.085945,-115.511482,-155.65504,-244.856995,-279.847388,-307.735251,-284.856755,-197.425017,-183.503882,-277.985361,-426.747763,-471.440396,-459.475959,-408.841853,-296.637608,-273.087958,-307.251757,-306.843816,-283.761249,-363.098485,-434.899027,-394.739862,-277.62685,-40.904091,-8.221799,-145.274013,-276.943467,-305.779849,-313.19363,-266.49638,-124.462961,-70.535457,4.507189,12.637612,-23.375122,-148.571527,-196.978342,-148.539373,-86.556394,-54.300854,-93.19321:11.721058,93.196446,74.881514,-18.282066,-34.115554,47.823882,103.198317,113.070127,19.538561,-22.008666,-71.614628,-84.652507,-92.686845,-80.533496,9.080655,78.530827,164.024739,119.58879,58.846724,-87.29471,-122.41757,-99.000935,-71.53872,-14.361042,-28.663371,-75.2171,-190.983548,-226.236265,-186.506954,-126.039791,10.737984,72.743066,112.685549,65.877715,66.775736,131.175301,153.659013,140.081493,149.359666,260.841817,293.528154,244.219518,147.164434,128.730442,122.427265,114.285181,103.950897,117.864248,125.390028,69.36251,42.704452,9.409735,-7.848715,-53.860546,-58.959903,-12.667092,7.458762,-7.529983,-49.995276,-54.604119,-1.297939,29.92826,39.567266,45.602808,83.290196,-4.565242,-81.269509,-96.541766,-17.448583,117.746756,103.197575,-16.118458,-92.646184,-96.608714,-18.716303,42.162867,117.49134,133.267705,204.548077,258.310732,284.684727,246.48694,239.139506,172.46568,131.210719,161.937732,217.735592,284.614717,267.692935,235.333015,99.456234,8.835572,-105.070209,-77.62238,155.791782,283.445225,378.697405,316.071562,249.079173,86.041424,53.285693,152.679481,228.602975,346.171087,402.626394,371.409611,228.810925,163.386583,57.421586,15.116793,29.655706,88.043649,148.36503,27.870924,-38.973589,-41.640903,4.575338,70.098075,82.657848,126.549533,159.137859,126.134243,-45.966019,-139.494299,-196.334381,-160.297925,-107.49608,-125.442191,-237.530145,-330.764521,-332.796801,-286.951025,-261.242574,-248.406079,-249.732876,-155.607641,19.141019,69.577086,37.290897,-25.093973,-132.80736,-151.185979,-125.025236,-86.604088,18.48308,51.974716,32.172855,26.884889,67.314533,155.384182,173.090439,160.292852,64.978515,3.357901,-67.071664,-77.075705,-52.505594,-23.418707,7.094754,-2.644383,-66.79963,-148.468943,-163.050732,-70.81061,18.618929,126.586824,131.201348,154.65822,181.889521,150.679189,-2.935713,-76.780242,-90.191214,-53.029264,31.076717,96.120787,201.894778,77.051583,-43.698752,-169.313718,-133.792231,-11.662241,18.476668,63.040494,25.912411,-48.04123,-173.892489,-181.216556,-83.32853,-22.573812,54.732437,89.122043,112.264844,22.476686,-2.12776,18.775258,13.668752,-15.576179,15.190333,149.963598,182.239318,143.474002,15.743705,-43.151954,-24.149169,43.500074,93.778378,65.225823,44.658918,49.380639,14.555814,-92.623029,-113.698008,-83.123962,-64.375149,-29.53322,-10.71979,-43.79834,-176.019308,-203.676828,-109.284586,-53.460453,-45.362702,-57.713086,-31.969464,34.045235,33.650949,-81.290036,-129.196679,-101.976173,-71.806471,-55.372736,-69.574304,-88.45314,-144.139731,-178.746801,-234.499517,-230.33338,-146.203131,-89.601684,-33.521728,-62.565184,-66.597128,-19.874717,16.435092,86.420458,135.015463,237.872758,175.355519,98.309093,-9.477378,-35.668749,-42.41761,-12.95309,103.719566,164.058525,176.100782,30.246327,-48.483342,-142.604539,-160.468824,-151.934508,-130.166486,-117.43769,-175.195707,-199.569812,-213.510055,-220.752774,-233.66364,-202.085492,-56.961574,-7.974801,-59.184503,-197.250262,-244.721996,-270.804448,-246.022934,-140.260847,-87.593426,-51.820832,-87.968166,-110.672915,-223.928958,-292.697431,-266.104783,-177.476144,1.777011,60.382607,72.804939,51.586671,58.878197,3.827013,-43.387883,-51.501158,-23.943704,37.083473,64.328067,38.920592,-37.24333,-33.562681,96.48215,161.991725,160.020873,115.92328,41.470568,15.044155,12.669902,-2.833408,-13.397994,1.029596,29.3694,73.885403,44.741226,6.034384,-99.344037,-146.374648,-134.764145,-75.551908,19.774106,14.769037,-78.610724,-191.828315,-222.032102,-223.987672,-215.295179,-172.024824,-138.484778,-116.888016,-127.564882,-126.554179,-156.799459,-180.061736,-178.21157,-149.837412,-22.253658,60.1823,81.410556,-135.54185,-238.889359,-290.345659,-252.713699,-171.346443,-132.652619,-15.292298,0.406832,-74.092367,-228.224653,-240.974259,-210.205056,-222.096311,-230.045027,-173.824579,-20.808171,-64.20829,-170.959337,-341.895761,-330.388466,-188.043699,-128.342552,-93.92927,-173.371758,-224.414595,-292.558045,-319.731569,-387.021329,-409.658093,-349.284276,-273.567418,-189.465923,-289.379372,-349.578397,-359.413526,-321.941575,-273.549934,-275.643604,-290.7653,-302.724563,-299.826872,-269.572795,-258.218281,-245.784683,-220.367284,-92.190829,-18.619258,-2.894756,-166.291065,-230.747092,-227.969765,-184.125713,-108.006577,-74.862218,44.037575,135.418582,127.491928,27.637136,-32.949754,-99.84075,-101.921971,-87.017742,-86.202548:76.608042,125.815765,98.291858,-0.917633,-6.829845,92.430432,135.286327,116.226004,34.175984,-3.981676,-66.82341,-83.475134,-63.685154,-35.729419,52.176437,106.1141,129.341143,9.013052,-66.503436,-175.72097,-185.257521,-94.388365,-14.473208,67.56512,-54.051633,-134.245282,-237.270831,-248.474664,-162.926381,-87.980776,7.932341,11.710959,20.36932,89.142501,99.826033,75.271139,87.797554,154.970308,185.123908,226.155859,163.692353,107.587654,57.762813,71.816284,130.889034,162.920888,229.256765,253.514465,243.835509,152.379362,86.976987,21.769924,50.620007,128.366677,142.460197,140.528772,84.678087,19.789317,-124.061627,-138.388414,-22.562951,46.910374,150.621904,188.504539,173.571986,29.393399,-52.141728,-86.657273,-27.983081,94.390455,125.525881,133.573937,37.72603,-11.087222,-4.531733,32.77086,103.39952,143.299691,260.313964,309.856053,308.054997,212.607318,162.422216,98.972945,103.102659,177.497437,213.162572,223.279115,225.418545,240.402499,182.716526,94.84277,-46.540443,-35.723998,160.349153,278.712556,374.525385,277.434997,190.184924,44.113527,39.988333,172.053792,262.495351,391.342716,380.717612,330.127746,216.980182,178.868696,127.671997,114.805045,171.795716,224.425696,246.55715,107.455003,9.645072,-86.105708,-48.519654,57.780355,77.705516,96.529383,54.739321,-0.921502,-114.494191,-165.567677,-242.094288,-235.146973,-109.055206,-44.145029,-66.382246,-232.837728,-301.170094,-314.02301,-253.613222,-95.547296,-42.437608,7.062768,50.951829,49.001617,-48.591775,-96.399709,-82.562651,-39.466075,40.059134,70.389701,86.072051,-9.870704,-55.673878,-28.782019,24.854731,114.119797,137.284004,119.205124,-13.244387,-92.956131,-169.530785,-156.059569,-104.555075,-105.393039,-116.402956,-77.622132,-2.408272,-99.674124,-166.267728,-163.984162,-90.406732,62.478343,113.792562,163.2588,95.936437,33.559142,-94.721875,-152.981551,-189.659977,-139.400764,56.327128,150.240911,194.044101,33.998966,-62.075391,-142.736605,-127.914746,-70.671762,-21.462676,82.817237,35.090588,-15.841191,-80.888529,-99.776487,-63.368804,0.251413,152.750876,207.260522,190.622721,60.77019,12.263351,-17.207421,-10.75211,33.650471,86.891517,197.072264,152.695287,82.178394,-39.272485,-61.416828,-22.521755,15.921093,88.849763,121.787275,109.170479,-64.89139,-152.863989,-198.0361,-156.757198,-33.617649,17.626186,63.50546,14.354854,-37.012573,-123.854964,-111.172863,41.319203,116.878813,190.428621,204.610023,163.46517,37.292382,-24.620411,-128.666217,-156.014237,-97.333721,-30.077826,30.891479,-11.558302,-25.739029,-104.202797,-177.649118,-235.928769,-187.35142,-29.077519,21.429608,-31.809845,-166.517212,-183.607081,-89.680863,-15.852145,113.046419,191.241175,328.713241,269.240094,181.725623,-30.455517,-121.787654,-137.77355,-58.143131,122.374372,154.31158,79.745716,-34.496048,-92.439453,-172.283227,-151.631366,-49.810772,-24.689836,-17.677312,-42.23154,-82.936223,-196.075267,-234.975388,-209.084086,-131.092962,90.257427,148.102974,41.255399,-178.048331,-269.995401,-351.261182,-314.237153,-117.66906,-3.140455,128.940578,91.115148,33.46742,-124.229239,-183.415136,-178.761043,-120.373687,79.63138,168.344158,149.823731,43.85396,45.714793,50.134791,23.600323,22.536707,73.988508,193.771657,197.627743,161.849554,99.890309,100.644525,176.130061,215.357862,241.492228,239.872752,231.580411,188.733919,129.342053,36.727894,60.032729,149.722721,160.744249,159.841562,144.975921,98.766888,-80.763777,-163.01009,-164.563789,-90.752312,79.326543,118.469198,59.74424,-55.604099,-112.517279,-221.190383,-236.535781,-124.849456,-29.593782,93.628814,68.137326,9.666689,-163.082313,-235.100663,-245.004981,-188.070732,-67.204788,-33.148455,-43.181806,-199.250491,-300.332304,-381.873453,-335.414829,-187.900351,-131.362717,-63.601863,-59.437564,-100.288104,-250.778027,-296.099677,-272.802133,-261.675148,-258.529006,-227.400279,-150.061306,-197.593031,-276.057884,-384.979906,-358.256353,-219.608213,-164.631678,-106.673033,-144.446051,-211.444938,-348.900362,-365.902505,-306.609906,-283.44873,-287.823095,-288.500767,-305.885792,-391.633502,-414.659301,-362.863475,-323.080561,-273.286512,-256.969335,-253.692722,-251.583129,-254.282617,-348.150563,-394.895693,-299.274486,-179.763428,2.540645,30.446122,-27.400441,-188.445811,-256.365468,-230.87915,-139.493938,34.030152,67.832028,92.720537,112.151447,91.297624,-40.674806,-105.823178,-102.30429,-64.553499,-44.279655,-51.691149:87.718111,71.998804,38.073173,23.684463,36.881253,27.222146,6.47604,-16.251757,-34.088196,-51.993631,-123.496741,-173.5423,-239.042624,-247.176205,-195.83405,-119.019744,18.931547,6.078878,-23.841378,-104.882506,-133.163031,-51.542457,42.492894,135.726185,-12.601346,-83.467169,-79.666954,-63.661376,-77.925526,-76.524861,-10.540491,54.642582,181.284411,143.513003,64.713762,-51.278864,-47.477938,-19.793334,-28.636526,9.033361,78.378776,72.11561,24.761667,-13.868213,-143.200389,-187.729338,-137.779345,-80.245576,-57.617088,-147.6101,-195.55071,-241.426598,-240.21018,-253.58581,-252.659997,-149.614565,-60.785537,-93.519036,-203.219648,-201.947443,-93.624935,-59.311886,-64.515458,-41.50114,50.707956,-7.826697,-88.93341,-166.954266,-117.735246,58.99644,107.630625,110.907636,80.990327,61.005924,73.424931,103.829514,150.568909,170.960716,233.551935,272.63035,335.645874,364.815481,361.243652,313.562469,296.737018,280.178368,245.53693,174.320102,184.435541,181.185401,87.681895,0.183305,-127.770963,-105.431812,114.519889,247.404638,384.461009,309.88174,224.443984,25.186772,-61.676087,-136.16678,-97.391474,90.419816,158.321622,91.602582,-75.307352,-107.9453,-98.45238,-82.553472,-16.623735,27.712773,62.165444,14.900881,-15.710286,-67.055405,-58.106997,78.380214,158.540791,195.27564,67.177665,-1.465928,-79.921352,-116.483729,-180.720733,-189.23441,-202.104748,-226.947528,-306.310923,-387.916133,-405.195283,-403.686004,-412.807665,-386.062303,-303.192869,-63.699739,18.811919,6.80002,-14.625252,-47.560984,-142.953939,-160.237788,-124.353799,-91.79223,-32.280402,6.827487,39.515542,125.94637,148.935291,133.05235,122.428869,130.184255,64.016425,-1.407005,-108.63092,-125.945923,-71.614854,-28.848292,-9.840167,-30.077179,-91.164599,-200.331575,-254.573737,-225.112445,-117.926464,127.826182,197.281725,211.780965,114.943794,35.274337,-149.666156,-212.260803,-158.184635,-69.13353,76.873566,127.727978,169.615815,25.081328,-105.513705,-284.878561,-269.809277,-139.556726,-94.963793,-47.666336,-100.203698,-170.18282,-274.203511,-279.744266,-222.27824,-184.485979,-112.769994,-75.288169,-44.588654,-70.767589,-88.292527,-148.568244,-165.605165,-104.143214,-44.000977,95.181739,182.472995,174.340301,99.327352,57.258743,58.687022,120.664872,229.899068,238.916344,205.839994,111.413017,53.569906,-5.874326,-3.814774,10.296011,0.930601,-59.959729,-113.88968,-118.20964,-109.97304,-101.052468,-42.734118,-8.737769,45.825307,80.382561,85.483623,-43.249658,-100.101019,-121.455541,-83.467923,41.803982,90.660804,99.490032,-1.428615,-54.022866,-80.571867,-81.700261,-88.222841,-55.237484,68.098758,97.975116,60.195172,40.822293,69.970707,149.515841,169.718314,187.745243,210.378796,267.903503,264.97801,225.621072,69.983432,-9.35415,-43.270068,7.262808,145.410246,203.320079,231.59492,104.141354,29.408783,-64.660051,-101.662663,-169.499529,-157.88133,-9.645943,31.639201,-40.001602,-134.412338,-105.591575,-21.987947,-9.23777,-5.790618,-1.929334,-41.266399,-120.631321,-131.487977,-113.781106,-96.978348,-16.272229,28.265567,39.39314,-2.121766,-1.354382,2.137774,-21.727322,-33.760647,24.803046,197.925953,241.833315,206.199932,124.753223,94.675508,47.247724,17.40699,-34.789049,-22.827607,67.18819,57.802656,26.058068,35.154831,72.987313,152.419662,160.522035,128.108885,129.078794,161.326539,161.900746,136.425724,19.338077,-39.442085,-67.147644,-45.376991,1.86723,19.22262,6.710775,-70.970826,-114.551253,-147.579554,-149.663066,-159.65005,-157.024556,-117.539007,-90.303908,-118.788564,-219.800615,-221.444256,-80.370513,-6.611492,43.155791,28.238537,25.32219,28.781295,28.908409,9.695484,-22.730402,-66.092346,-28.698201,81.233857,10.05472,-87.3892,-254.749763,-277.950482,-194.348487,-125.612841,-64.840391,-151.073679,-205.27165,-277.138145,-298.414914,-286.141065,-242.445236,-100.649959,-11.117586,159.24492,180.618935,118.164129,-36.11021,-71.509414,-29.992339,6.941912,7.501563,-18.259608,-24.494912,-104.203726,-166.220869,-208.821141,-168.945089,-38.017933,7.645479,-2.000484,-122.084613,-167.748099,-138.971999,-104.900638,-122.239491,-149.004234,-131.961194,-93.938541,-81.608855,-36.270385,-28.711003,-40.456562,-15.830486,118.292332,186.175149,169.138844,7.108223,-39.262213,-61.155038,-51.41035,26.284724,66.396588,122.013021,171.19905,168.477665,105.423009,60.781549,-34.843237,-71.912513,-109.506911,-125.393009:125.830455,127.728926,72.816426,-14.314304,21.893906,152.564602,171.010788,139.695322,94.88246,38.526886,-105.371551,-138.792365,-120.665427,-103.239852,-45.2279,21.019341,146.509274,87.234945,1.499036,-135.822775,-141.224723,-38.222666,31.465572,80.027192,-72.330349,-166.752459,-248.197865,-233.590392,-124.013559,-45.216399,71.91192,99.477692,116.418048,65.859679,13.353037,-57.72408,-47.571851,-4.379445,13.407081,86.221177,112.443954,69.439586,-85.587376,-150.340112,-147.808844,-88.152942,55.508615,108.631608,109.658578,-3.725958,-69.65432,-166.990653,-168.148772,-81.520702,-35.221781,-6.823823,-59.404637,-106.752827,-190.276308,-202.235176,-160.96174,-122.520709,-39.423019,8.259559,55.117933,-78.11992,-155.430447,-120.829874,-3.33589,238.893538,288.530314,223.018991,26.227668,-43.832465,-34.728101,2.689358,81.857395,138.389537,283.804788,338.492676,336.032531,257.259723,208.367721,97.989688,81.297512,144.239084,184.627155,269.507774,320.919762,294.862089,115.188051,-12.094829,-165.052771,-114.632462,201.77015,339.82007,343.043427,190.239813,139.046832,24.318472,-12.984658,68.909587,164.615106,356.652359,384.057786,296.840064,75.072627,18.067714,33.724681,71.768086,178.629563,238.339047,288.255412,205.535259,106.101814,-111.469216,-127.307804,79.813498,204.887124,285.840794,170.580053,77.805484,-114.491493,-172.408087,-184.849006,-159.945889,-87.792604,-71.745898,-179.500991,-382.210121,-428.251256,-360.122715,-283.378768,-160.613601,-130.192855,-57.199209,41.029583,62.4908,5.852956,-63.647314,-178.473235,-168.48437,-7.35106,77.76553,114.292766,35.569701,-11.797612,-95.73488,-92.62895,54.65443,160.650698,248.032353,58.692455,-70.72012,-192.578316,-156.636982,-13.999139,21.850861,13.315544,-3.156913,-70.983497,-196.600643,-248.326768,-212.944045,-125.648734,46.057204,101.667468,157.791343,54.677805,-56.565011,-258.192413,-298.345985,-233.878602,-149.400729,29.988604,88.468647,86.502228,-99.763885,-227.646496,-346.53344,-292.939046,-87.798965,3.161918,93.24423,-32.926811,-138.510542,-287.180396,-327.2493,-307.897981,-222.098602,16.185766,91.804557,66.691528,-62.826378,-112.362158,-153.753571,-130.794391,17.638331,111.785924,222.80674,184.64492,139.287602,21.925553,-25.093825,31.442199,120.72167,260.373225,288.725147,256.737643,74.790229,-31.268671,-121.277587,-100.842111,-48.375809,-21.714625,65.283658,66.844083,12.730215,-130.423436,-168.929723,-99.752562,-28.755422,67.599471,88.190624,77.6932,-21.830495,-72.419685,-78.141609,-40.942922,24.288087,42.578751,71.332074,42.166164,-4.291159,-148.644817,-233.930862,-298.300895,-224.467571,40.495597,127.169966,72.190838,-116.571207,-177.492755,-177.191585,-119.683047,37.097772,116.828185,229.83192,142.000339,49.44829,-86.303807,-112.307491,-56.643076,10.784057,140.966339,183.159437,170.111052,22.858602,-67.031853,-175.048597,-177.408437,-135.254314,-106.116832,-24.99606,-13.667049,-61.199337,-161.921215,-172.245526,-83.910656,10.241379,216.620856,251.357401,77.629158,-173.942406,-248.986027,-304.186322,-262.664153,-35.481399,79.642191,185.990527,142.476327,69.287023,-111.915486,-165.856775,-116.147708,-42.379168,104.951114,163.089897,165.180412,53.755321,28.444928,65.822559,100.520821,162.899652,202.214994,294.496496,298.743767,252.093088,116.699198,71.332952,103.632191,157.047984,266.28185,306.392699,257.924118,98.691623,44.938334,-7.387216,4.623887,119.419741,173.616374,186.837633,110.379198,40.593371,-148.067731,-208.032733,-151.353041,-79.990458,3.642441,9.637084,-18.444678,-74.238216,-122.797977,-231.035846,-221.703929,-23.66583,77.85909,132.751687,90.073719,66.647945,-14.846176,-65.548698,-78.261897,-35.41581,79.293133,124.077718,91.006816,-115.261916,-234.716234,-381.42349,-369.383852,-234.951816,-163.724117,-59.543556,-114.511451,-205.186527,-338.577271,-335.182503,-260.631626,-238.528948,-202.758177,-150.906055,-19.968206,-25.025663,-98.803174,-254.087733,-265.273152,-158.816918,-86.106204,12.805331,-24.770236,-91.451451,-261.750661,-317.466926,-297.198598,-256.704193,-159.587716,-99.187008,-76.463931,-225.022879,-285.92532,-292.963758,-256.957622,-158.133919,-111.459624,-74.635458,-118.765113,-138.925881,-177.189215,-201.111254,-168.774674,-92.503226,93.519372,155.549553,144.291706,-8.185821,-89.944296,-175.210191,-145.260494,51.778029,174.185052,339.990955,257.179873,153.561725,-8.236347,-64.237701,-139.745921,-134.766825,-56.848104,-14.655813:-17.212525,-33.303883,-18.509902,10.813934,-0.765009,-51.981702,-94.161476,-204.379838,-241.841428,-206.275809,-127.389579,-139.185103,-210.228365,-226.363341,-223.754552,-206.640379,-135.147823,-44.936989,-12.785029,-13.245826,-14.12885,58.74845,106.007912,133.820733,87.841453,78.692173,88.867324,71.943883,17.264276,15.851565,49.451958,54.351968,7.079605,-63.282141,-107.643958,-232.19755,-274.584073,-277.782534,-273.218432,-262.783939,-241.056297,-239.384737,-198.161721,-180.566561,-237.780827,-273.662176,-264.745065,-230.912672,-171.298152,-122.597683,-98.333485,-129.013134,-176.228016,-207.493545,-177.953562,-75.976235,-34.979756,-76.517793,-153.434594,-129.8247,-18.40307,10.88423,-8.034358,-10.287869,26.51117,-6.757469,-40.236691,-62.761706,-42.626431,33.914401,62.232446,70.058758,41.315433,20.952923,9.607506,33.690887,93.255568,100.950123,127.995033,173.473315,252.713913,234.679261,221.245203,220.803721,214.633462,154.145179,97.642286,6.974067,22.014198,37.235207,2.074662,-51.225631,-121.188091,-98.020089,39.692947,119.645489,198.267947,127.046571,43.923237,-192.014907,-295.733855,-326.671971,-260.59774,-69.971254,51.275852,29.80826,-100.854074,-127.558456,-53.395397,-8.399444,5.004364,8.386383,60.130766,55.984133,44.5372,49.240755,61.466012,113.987941,141.920084,155.565659,47.519367,-34.033489,-130.650676,-138.660315,-130.698443,-140.81617,-189.451385,-212.561405,-268.208445,-321.584648,-316.578858,-274.418093,-267.801093,-246.774882,-202.232656,-74.477059,-5.327428,1.954192,-61.857916,-133.590575,-188.796501,-142.470199,-54.593012,-51.324415,-85.658897,-69.202898,-26.690358,47.62432,57.510037,19.756144,-27.364303,-129.922102,-194.129266,-207.009707,-208.813536,-201.808962,-168.304314,-148.783432,-148.281332,-182.100581,-297.018745,-411.106289,-444.740044,-398.616136,-317.576417,-146.122105,-86.896891,-57.670153,-175.70192,-241.386895,-270.819691,-236.360146,-110.542552,-51.616889,2.159273,4.789564,-51.768706,-157.163122,-174.978647,-164.392994,-175.977413,-206.346132,-198.49391,-165.398363,-187.509704,-210.454015,-217.455568,-214.324225,-285.009943,-342.954127,-332.567494,-251.446745,-128.322675,-176.078471,-227.724481,-312.070967,-322.878196,-262.268933,-216.876623,-158.948026,-105.500852,-63.900119,9.200526,30.054687,139.220604,245.64638,400.275223,396.46849,282.791715,149.93031,92.965386,36.218937,38.011864,8.232405,-48.78593,-140.25925,-91.312606,-54.636958,-32.010824,-47.42595,-72.009167,-43.481631,78.995251,127.098467,118.167702,24.23848,-11.055752,-44.860224,-34.723155,54.853417,111.254085,203.96289,204.904811,168.914516,123.804564,124.299261,142.392313,174.239457,296.603873,333.574862,260.47132,185.000887,204.206144,300.974289,351.100974,417.529001,425.295777,378.132699,298.910528,269.750834,188.315706,110.834774,-15.412806,-5.785092,119.116096,177.507159,189.391958,192.661657,213.640694,143.47092,70.553731,0.8682,0.851952,12.459053,32.903907,45.00843,65.057973,73.045564,64.882434,46.592841,47.463994,106.089264,290.457587,342.454974,298.626167,98.855561,-13.596785,-61.786703,10.794303,173.9757,235.446249,255.98905,273.001199,228.433377,110.191415,119.697752,272.890552,338.130694,329.498624,244.429758,228.854428,211.941064,164.719786,6.197085,-35.887514,38.724986,96.838079,81.005199,84.40354,112.146418,164.796326,173.49787,178.307436,190.806066,199.851212,195.832455,201.42502,162.957868,116.863531,18.009061,-2.296122,81.400419,83.123561,-2.550996,-88.387301,-26.238613,131.471978,124.184098,-49.800046,-121.432588,-136.366608,-63.634622,-17.137845,54.559759,76.35627,123.892776,147.253301,181.224539,240.211267,288.432726,349.002551,321.447927,189.474175,136.3131,119.848155,157.514384,232.942487,156.168231,70.50756,-120.044605,-200.203592,-237.021807,-179.858826,-45.066104,-78.665022,-137.544247,-187.671325,-173.871713,-112.646975,-67.66718,20.75358,66.096051,197.86501,323.63908,326.174798,234.994625,209.95973,224.010528,231.240023,276.451489,337.992546,311.093353,167.076093,101.951206,44.205336,38.505457,38.145392,76.341121,235.019988,284.115594,242.432914,118.748592,73.643468,117.846459,208.80031,371.744929,337.974572,285.347774,228.676562,219.599513,237.084668,277.736593,388.874046,420.373507,390.7564,330.15343,299.842637,240.246624,241.253129,298.231617,319.048104,313.755708,242.270244,194.847652,157.024978,159.318906,138.043248,114.574253,30.948708,-38.309544:-151.277135,-214.646392,-232.565134,-182.331315,-130.389253,-74.195177,-86.683613,-103.174427,-84.320547,-88.151351,-159.729849,-224.598792,-324.813589,-325.635595,-211.492783,-122.640808,-26.408429,-56.60019,-55.909367,-24.813051,-19.11872,7.327969,31.881522,51.672679,16.619795,4.558819,-5.026806,-32.289479,-86.468474,-56.450481,102.137383,158.567958,154.684526,87.779886,39.537124,-59.286625,-74.736083,-64.584825,-69.756483,-53.741709,7.649017,23.875806,0.450326,-54.331031,-202.094306,-239.769858,-220.296741,-195.407816,-192.953328,-252.16156,-294.682326,-395.429578,-423.258024,-399.58433,-360.960517,-232.304941,-103.449112,-73.060513,-42.648523,-27.813526,9.646091,40.738191,118.022776,151.350878,170.787766,91.967714,34.420605,-36.489705,-31.863143,-5.215523,-8.897574,13.898219,63.671959,66.456327,86.379079,103.621089,63.102831,22.605781,37.346526,108.465311,267.92581,329.32198,324.144941,259.749345,227.692262,187.397531,149.241686,35.949937,-23.573385,-25.024215,-44.114476,-81.614613,-141.093282,-112.345779,78.74724,190.454632,300.740731,232.5647,162.875701,-14.991588,-108.407563,-217.0518,-204.235631,-99.841128,-100.158321,-146.445038,-166.686703,-142.867182,-141.503162,-155.868619,-122.468364,-64.470845,47.093139,87.469223,96.133609,68.520175,63.578094,161.39785,217.338557,222.857779,113.645775,38.059905,-129.314941,-201.387082,-234.217552,-214.952748,-250.193264,-296.904151,-332.593743,-274.960107,-244.351639,-226.463504,-230.04531,-196.507542,-157.572242,-61.954523,8.493528,0.029237,-109.58835,-170.809963,-222.026137,-239.91239,-291.92987,-280.760754,-224.92276,-201.234425,-154.336183,-16.900131,28.037056,4.305334,-50.807905,-94.295918,-51.301849,-56.131737,-133.739169,-188.932781,-246.587933,-225.657773,-122.222354,-85.381163,-131.19173,-235.718152,-250.954072,-178.324894,-98.385212,71.778045,122.929696,114.550453,23.859312,-21.846939,-95.794015,-105.750782,-37.661394,16.549383,87.272002,111.875107,181.57067,171.460937,115.508264,24.062648,13.881816,-16.135145,-52.137813,-113.358705,-137.958797,-128.431491,-98.708461,-119.947381,-212.683221,-236.613245,-179.386824,-104.371422,14.461012,-20.770668,-71.369685,-172.628185,-204.220242,-214.448532,-190.534241,-64.638038,31.522081,22.638442,-36.485221,-58.313385,-16.675135,63.92584,218.107482,229.436598,144.531501,44.344751,10.721923,-38.505005,-68.729761,-123.277815,-139.971235,-156.084517,-121.586856,-99.090117,-104.178292,-122.013585,-160.385651,-183.513323,-141.276992,-47.440822,89.149201,-35.563232,-105.041005,-96.382139,-47.746385,28.163683,54.340432,134.569575,157.698867,130.664015,84.294488,74.335431,99.256859,151.613004,297.257467,344.5709,331.254759,255.310732,235.166406,260.001566,288.741666,348.324614,391.407702,484.71024,463.209758,398.181067,228.896014,156.45957,103.391274,121.315158,170.051115,181.592355,207.556144,245.817274,219.085905,25.526259,-85.698618,-188.747061,-166.480043,-54.527373,-37.507496,-73.037942,-96.955099,-61.257847,9.294809,2.348206,-12.564121,26.046528,115.967527,119.071784,101.460575,13.85395,-43.475715,-73.199626,-28.043481,109.098459,194.102622,220.555183,241.339842,218.659101,181.756112,200.907547,274.13751,313.185149,366.498329,303.511893,225.146635,43.429155,-24.186413,-106.4943,-129.196225,-100.147924,-8.481614,34.906275,56.719613,24.822225,-2.839253,28.939381,75.049568,74.543795,112.811699,203.337216,213.625238,96.502638,7.7689,-93.924342,-89.546538,-24.80007,-36.941589,-77.799809,-107.034768,-95.625105,-98.290828,-107.937676,-98.463313,-83.815187,-68.686977,-21.247894,12.717596,30.178154,21.25925,10.875744,8.74036,4.577713,48.857796,97.494185,175.386194,183.451227,162.872081,143.576715,87.976077,70.658529,86.055606,71.372166,20.863074,-119.2537,-162.107001,-150.69478,-103.689507,22.17111,1.852854,-56.289929,-102.118644,-98.503256,-104.204916,-87.89846,36.779676,124.448283,246.858879,239.955729,201.577768,148.296288,162.527561,174.428344,136.979508,120.295019,207.748627,211.28521,130.774895,66.073672,-62.378541,-100.888972,-72.188565,21.389589,232.176165,180.636148,93.360656,14.123004,30.92056,66.269675,77.918155,139.274633,196.680749,223.112643,272.289246,260.307598,152.786601,116.834932,183.162201,242.934231,282.902329,278.768534,279.045622,250.421516,243.397293,262.659756,259.018607,233.03558,193.670729,143.626087,19.390833,-21.385554,-42.208664,-52.831191,-159.252262,-235.173545:69.914605,132.508764,103.151406,11.559801,-7.530449,6.109588,-3.482405,-66.668284,-55.921327,-15.644826,-21.321659,-76.94265,-111.976947,-67.532666,12.977292,8.846689,-44.778163,-40.745623,-34.294133,-102.458262,-136.293158,-77.413361,1.863676,158.080996,144.679418,77.367454,-45.773938,-91.782903,-87.101602,10.538927,207.725675,187.987599,-16.215252,-131.438559,-142.201324,-179.57073,-216.07074,-245.673079,-213.560628,-84.538517,-48.201009,-92.644471,-174.34426,-181.429234,-136.4106,-111.548885,-125.74578,-126.917022,-56.934998,-99.023361,-180.942551,-294.489505,-283.733251,-183.505205,-138.521294,-67.337265,-68.595447,-116.343902,-169.224987,-130.11322,-14.556369,-4.732866,-65.690392,-67.646964,7.894101,-21.842697,-75.595088,-109.859765,-62.871352,94.71765,139.460001,80.118454,-18.067054,-12.467823,50.123702,53.054575,6.029046,4.841089,93.931719,151.965945,232.984571,252.138991,227.280525,145.268377,110.360082,56.316601,46.925742,113.576489,179.165322,157.73093,-5.474865,-136.590998,-287.482192,-219.937324,68.792443,179.938402,245.392563,170.503632,111.693256,-38.484781,-130.976363,-249.748901,-211.92585,31.607824,166.680981,142.625471,11.664574,-56.394617,-61.974882,-12.459645,42.6266,63.585747,111.908922,70.096424,3.968559,-145.946314,-156.83649,12.675756,124.809025,197.41321,54.699617,-33.545308,-136.739675,-148.954228,-119.052339,-105.385316,-139.203875,-167.759366,-225.206639,-303.630217,-341.751182,-379.281342,-367.026392,-290.20066,-226.744779,-41.954689,77.728752,68.247613,-12.299131,-50.72351,-105.457063,-123.234534,-139.731463,-126.015784,-53.023377,24.764711,62.434607,89.875937,71.72905,36.346787,29.131462,37.979052,-22.104238,-97.695358,-198.431708,-204.354256,-191.613543,-165.21715,-72.915496,-69.882927,-218.088927,-361.75125,-388.177555,-348.452598,-261.179448,-87.939357,-76.710867,-101.148084,-83.583823,-103.706274,-238.771558,-293.357244,-227.275041,-147.034918,-40.957416,-18.909998,-61.931911,-196.904485,-239.947316,-259.187054,-253.303526,-187.726555,-121.387231,-58.808476,-193.220828,-243.763162,-234.12898,-239.511209,-284.461527,-279.777206,-207.286708,-155.884663,-147.537673,-296.25522,-323.885744,-241.776629,-183.257593,-60.980973,-11.54243,39.332399,62.21001,58.508569,36.503003,40.744511,126.771793,204.298611,315.87093,328.391191,316.431775,206.594509,121.246996,16.107449,16.976795,65.64842,88.282376,105.40297,38.593454,-13.523063,-73.146916,-75.631927,-29.586644,15.062956,75.44044,82.651468,77.7478,-7.814417,-71.324175,-87.335743,-16.025778,138.990762,151.274887,35.740487,-67.380856,-57.906796,-6.838974,-25.376034,-93.020019,-70.441273,58.1738,100.065961,72.61887,7.610293,10.750585,61.101401,98.33053,176.680556,192.275339,186.053168,208.815161,227.925532,172.369765,84.288162,-44.385709,-24.392094,111.747506,159.379857,133.790049,53.615524,29.57738,-24.57966,-50.197021,-99.189522,-119.086788,-47.129371,63.820832,50.108119,-17.00393,-16.986906,42.647005,97.823557,212.726162,218.754741,63.509686,-91.912687,-99.858947,-77.500452,-64.454842,-8.368422,-0.348889,-15.821146,56.073764,79.383626,24.291996,-16.392311,-26.58667,14.353376,131.367568,161.929649,142.384152,183.168303,237.292041,222.451465,136.792512,-6.978908,-14.889985,74.6728,167.264129,169.742333,89.312316,46.779642,47.126691,83.67883,191.894757,240.105011,197.128779,42.800791,2.383714,-9.346031,3.751795,12.693038,-7.796835,-40.611669,-32.673036,-26.919977,-10.223476,-2.647275,-12.72057,-40.48709,-128.242828,-158.225424,-176.392948,-186.353183,-187.267953,-183.675691,-155.00264,8.638864,102.826566,215.755163,198.178941,172.376276,177.163718,178.205031,80.55317,3.574445,-3.614088,94.67617,207.061929,24.612869,-84.356345,-219.284447,-237.242089,-160.754316,-84.768348,7.179907,-93.408982,-170.290327,-265.69385,-272.262387,-209.333756,-173.169868,-132.909877,-81.468922,113.299154,206.222776,171.401661,11.985099,-33.448495,63.578695,159.810559,287.943308,213.617654,121.214569,-17.584925,-29.371591,31.742037,48.847647,11.635106,4.575564,1.639676,-65.3768,-79.167499,-64.047702,-78.018616,-56.341343,14.050288,102.992928,-11.100676,-85.424846,-131.725474,-100.583172,41.919252,122.860244,221.890356,236.849261,189.086783,85.839209,56.188266,33.198927,30.973854,72.098612,120.369583,241.530219,251.932641,184.987159,11.971236,-54.032444,-106.788592,-104.971654,-81.136284,-48.926603:right
102.134764,105.038997,119.837788,111.83667,100.686535,121.16036,150.273775,188.848697,203.053395,189.728041,102.080543,39.886012,-101.278463,-156.566417,-199.541084,-213.202955,-258.134711,-248.204488,-194.108896,-19.541395,66.366444,186.1202,205.611887,120.559453,-19.943304,-46.622541,-14.736124,27.396894,115.662765,135.775875,114.130122,78.701584,-8.714086,-102.170831,-138.738192,-122.00439,-89.238647,-33.696003,4.538938,115.253617,230.145064,266.285227,278.595229,273.540585,264.400322,268.971932,314.087942,302.827932,91.99752,-123.693821,-122.965455,-2.339179,31.42427,23.209388,0.481132,-129.165024,-295.785994,-326.876609,-247.394579,-164.239052,-10.820402,67.126352,236.018922,278.677648,265.016845,246.952946,242.178407,220.49689,201.058361,188.334116,218.734329,267.081327,172.660811,86.084278,-67.960024,-96.675995,-37.13679,15.85184,42.180284,5.315503,-53.64655,-33.161205,0.813308,142.689615,219.575258,294.115931,298.936632,273.338404,203.808677,170.593125,189.438159,222.993074,189.779713,131.506849,65.045332,58.517307,18.80876,-16.007874,25.221747,255.737354,389.461275,505.339201,474.032434,374.157075,317.884045,280.434017,212.962091,212.244286,224.007924,207.342265,117.417126,58.891006,-42.59231,-154.019821,-193.404901,-177.119759,-153.506415,-155.594752,-169.622257,-170.986397,-138.089804,-123.396733,-67.990202,-1.999288,157.00331,212.344905,236.938237,213.416138,146.827135,140.994069,190.267265,295.57845,295.478426,235.487133,217.572817,208.090449,187.619825,146.200102,43.384661,37.702249,110.863994,132.60302,122.592255,121.8201,122.37623,43.718119,-9.122875,-61.886583,-66.891914,-39.405037,-14.940956,-38.160723,-107.819531,-128.294568,-171.887697,-177.866096,-93.60834,-17.487449,88.761242,86.467997,3.097378,-70.618384,-62.323439,44.960995,108.474545,166.60666,141.014506,-0.174899,-153.256,-191.743913,-145.548334,-103.018583,-139.495806,-196.243206,-275.626287,-307.687815,-343.27938,-292.013648,-249.497219,-174.426861,-142.09793,-57.680266,-24.853544,-56.684927,-90.129527,-74.744038,-54.278371,-55.214818,-55.018369,-51.866896,-75.770139,-109.864586,-135.208784,-65.117362,-9.423703,127.222365,166.305263,140.507873,104.479316,15.518306,-124.174781,-199.863563,-236.012772,-184.363914,-88.776672,-90.773629,-149.856607,-177.698624,-221.128821,-298.103203,-348.131609,-372.178737,-321.595601,-155.850857,-83.5494,-31.544921,-76.431627,-84.62543,-40.018703,-25.892203,-62.504163,-83.185265,-94.651006,-112.595229,-227.180867,-338.006591,-309.725407,-91.405002,14.554215,90.118953,75.177941,16.151264,-28.820034,-49.621275,-82.021016,-73.858635,-23.721282,-12.884941,-39.183593,-55.826145,-91.859921,-164.992374,-188.881098,-169.98229,-150.491322,-92.000845,-40.505466,17.356584,-52.418271,-96.652571,-94.987904,-46.00661,39.026492,58.198297,115.707476,150.418951,155.204999,70.881311,34.727132,76.336502,151.51359,282.378504,281.240394,134.223481,-51.433929,-127.656975,-187.270149,-148.987911,-26.473137,39.931777,188.355448,217.000812,120.651906,5.032988,-2.398293,56.559098,91.519584,149.122769,179.881393,233.123584,279.705887,290.063291,229.447164,188.050532,199.465816,236.683022,214.548731,148.461607,70.247695,80.503916,80.029663,76.550687,76.237804,95.2335,113.299524,119.153155,81.132659,54.668868,37.10184,66.772557,196.119508,262.338089,268.88828,209.682889,102.770904,28.443074,4.601904,39.72414,69.907805,85.033398,77.013036,52.841435,2.97902,-18.610142,56.483063,135.82647,176.69513,135.991735,102.318168,109.115263,51.330726,-78.034447,-111.050384,-62.58798,-8.173865,98.169023,146.633976,210.23983,199.314196,166.953582,80.159075,45.81927,16.991466,27.253761,73.753579,67.061225,-16.428456,-35.050085,-10.770623,24.408529,22.003574,29.695763,49.142965,80.665585,61.820196,18.999064,-86.674454,-94.964565,8.450478,60.156313,57.839584,21.881896,-48.890619,-62.322475,-15.909894,130.949324,163.699037,132.332233,119.174664,130.111111,103.09254,55.459111,-63.97475,-95.564248,-95.080093,-96.60021,-105.069626,-102.256966,-113.111104,-157.398501,-170.370229,-138.058561,-99.459165,27.343207,100.37052,129.122156,-9.083779,-61.807323,-46.103119,3.794723,109.010747,129.160208,66.927229,19.435844,-22.545519,18.592467,59.393139,96.1935,68.020708,6.761024,20.874402,97.501032,65.638541,3.804259,-72.303031,-65.337558,-59.189724,-76.978051,-105.348604,-121.628:14.22742,-55.680118,-39.980474,21.837477,51.268552,149.154101,191.376156,172.660421,109.745003,94.533914,79.21927,53.53279,-49.492762,-113.260503,-244.845504,-286.660576,-308.612013,-333.051077,-305.321464,-116.768146,-3.698887,166.395258,208.119906,192.087881,108.291252,86.846742,147.355991,188.796067,128.282295,43.534435,-95.00143,-143.564277,-219.809543,-241.813379,-223.421262,-156.381786,-140.338131,-138.229428,-104.958906,54.909322,154.824082,161.396399,200.070873,236.99255,284.482448,297.046018,295.62223,255.859795,95.114413,-54.969058,-77.832353,-10.116077,47.081799,89.098977,26.307555,-203.036058,-334.941151,-363.288549,-358.903913,-298.00549,-111.175658,-9.122625,174.201535,217.313156,220.667499,282.107928,331.630955,366.159199,345.160796,259.260284,217.216449,159.002981,72.787531,10.735901,-130.193904,-187.068997,-187.323206,-146.862569,-119.110688,-132.216096,-97.949489,-28.217042,-11.045129,90.007271,180.765417,299.486446,309.518569,316.023898,276.399243,211.281325,161.637625,211.072243,253.962772,204.493125,76.292861,28.67596,-31.443972,-40.773954,-11.842432,145.886136,264.264881,456.316163,468.370341,346.16119,261.147064,263.259437,257.362301,225.13472,131.871254,83.256026,-32.775814,-93.389426,-193.169335,-293.714785,-327.503583,-296.921019,-245.574981,-165.126258,-162.048651,-222.633733,-269.019411,-244.824309,-105.938766,-25.368821,105.069009,154.227597,188.548713,173.562135,139.437147,97.28505,74.58067,111.605265,168.086815,230.382474,210.269087,149.452466,141.621136,132.454974,105.736859,98.64247,87.047516,90.408748,88.048909,55.361139,-37.374444,-37.570618,7.718739,97.174199,115.556799,124.028796,115.607266,67.594426,-15.49662,-60.367941,-66.076837,-21.082756,64.547239,89.662829,129.562057,142.357868,124.321248,32.03293,16.951614,155.032936,260.040723,337.619475,276.238089,56.702972,-99.640412,-138.51638,-139.866265,-98.980593,-2.765692,11.228766,-75.151198,-156.545526,-287.580491,-328.335871,-295.695428,-120.771753,-48.889486,-47.162868,-65.689232,-59.460297,-118.399396,-161.359316,-166.208652,-138.525673,-74.636307,-44.784665,-42.383084,-91.082052,-195.487192,-156.158224,-88.987366,50.35354,82.9552,55.247875,9.289717,-77.793595,-92.699345,-103.457804,-117.134188,-97.366488,-50.684289,-51.064542,-114.111603,-153.810293,-198.928515,-248.185154,-275.831482,-270.037439,-224.554037,-118.353191,-80.209865,-37.293764,-85.137633,-114.147048,-114.041885,-113.42636,-140.562432,-157.127383,-170.393205,-158.000878,-151.922659,-170.568066,-116.507207,97.418573,166.022109,142.513269,93.630634,11.012799,-30.206569,-55.891589,-69.12973,-23.234162,101.673845,148.781366,185.991897,149.217082,-12.901368,-83.548875,-52.317127,67.005389,123.903575,140.989178,101.583679,59.488406,106.529562,116.295111,68.626363,39.681211,75.003219,142.935451,247.88546,242.932608,156.537335,101.520908,112.369381,166.389882,196.456731,278.190249,306.217483,232.918975,43.557619,-32.039268,-52.570468,0.256856,154.472035,235.348736,333.863185,327.860305,206.958877,10.647944,-32.206311,74.332352,164.507643,274.608788,281.795806,259.281395,242.580101,216.833652,192.674112,213.434407,251.844819,264.422516,254.60242,211.558453,92.826686,31.82824,56.972879,142.31094,137.709816,98.926921,112.691896,100.353267,-41.353092,-80.768419,56.721235,194.506893,371.307031,363.470535,241.606855,181.552767,66.882032,-61.832637,-89.280751,-21.575606,41.589391,96.039811,77.975408,23.808506,-27.218806,-35.077678,19.366728,55.521171,89.224174,90.713196,38.799548,-8.409749,-57.070874,-45.270858,-43.137704,-10.858904,41.097102,169.7423,195.384796,135.344137,108.564475,127.529498,151.998743,151.261273,123.392541,101.755618,111.405846,151.005776,189.323307,91.872249,38.267997,49.950512,96.851262,131.765836,109.606676,57.368175,9.96144,-34.559115,-106.706091,-85.896789,68.057677,133.902099,125.372104,94.082708,78.247428,37.404887,28.459135,122.10935,162.590707,127.852652,100.149637,73.282278,22.838551,-5.092347,-33.362611,-38.283844,-78.046205,-103.630645,-109.093288,-102.698516,-126.81845,-173.645366,-169.720574,-81.427524,-8.27925,141.40466,164.914403,59.258345,-66.330598,-82.311547,-15.830779,46.415091,122.824558,113.576207,48.574157,18.732652,-21.796395,-22.647362,-12.1038,-42.580746,-65.543393,-12.312494,49.086958,97.593183,-42.423543,-124.001004,-128.867628,-70.445085,-17.995842,-27.141262,-24.981959,-28.297462:9.329035,-39.781487,-23.060908,12.057624,30.819012,89.244915,92.806997,3.612773,-52.436077,-42.941016,-37.169608,-61.23326,-152.854895,-208.505779,-324.006834,-395.001179,-516.518772,-409.548169,-280.045892,-48.089743,36.058643,149.971136,174.846112,206.823348,212.797858,188.365152,139.131569,137.543468,155.61095,135.860709,-14.366619,-100.804913,-198.262444,-256.963194,-293.635661,-338.537122,-323.101763,-231.658498,-181.932354,-74.194845,96.454616,176.616061,255.290693,267.816555,283.741068,293.502936,312.940855,292.743565,122.178935,-53.25496,-41.657705,73.918672,63.903617,-101.957671,-201.925942,-406.398534,-548.938285,-545.822827,-371.358652,-262.103919,-150.325958,-110.471548,70.002969,183.592292,316.862587,316.489763,318.907287,333.44594,311.293977,244.251668,232.572889,192.209648,7.80748,-110.996477,-277.458779,-310.145198,-267.056689,-210.768197,-175.037341,-210.784014,-263.635014,-240.798804,-192.116385,47.161159,201.457809,366.559225,355.745236,281.551324,176.165528,114.554999,106.327054,155.651107,200.385676,162.81272,14.175955,-51.054146,-114.968194,-136.442737,-112.54032,50.069711,155.043952,292.008132,291.584455,177.318803,77.788799,63.472044,112.112405,164.180486,233.73723,220.156634,114.280414,48.945031,-107.419853,-281.95618,-329.541749,-350.323298,-357.018019,-357.785759,-327.975208,-211.146309,-136.373857,-135.452894,-107.524414,-53.182935,82.604386,132.260913,155.438239,137.596524,86.0617,31.138639,38.24899,159.063865,228.646263,248.147343,172.95308,-24.77061,-83.138695,-78.963178,-69.174797,-40.400358,66.284807,105.221233,110.352169,88.394712,16.746328,-46.947296,-46.166461,13.1055,56.061428,149.522204,170.823017,113.457576,6.458809,-17.993159,29.247262,80.436286,204.473746,260.134572,279.697655,245.909611,139.782443,42.610721,59.492999,202.236311,271.59532,311.937134,259.424867,75.834349,-70.252563,-99.873371,-47.178226,-15.517237,-60.680751,-95.287501,-99.299408,-114.028881,-259.053439,-385.898372,-359.288185,-183.013174,-117.542798,-98.006311,-110.826572,-129.106901,-168.707521,-183.022777,-118.171452,-57.69888,34.641444,68.537481,81.213188,46.359001,-53.861304,-110.220737,-89.715102,2.255213,44.956542,110.674168,104.525885,15.197219,0.328199,14.504097,8.811346,14.045378,58.147314,59.53394,-19.861405,-83.343436,-231.860772,-365.89447,-368.324169,-242.656394,-177.897404,-116.14899,-97.187368,-44.191704,-55.668103,-110.499132,-228.588818,-251.529356,-174.623229,-95.922558,-3.911177,-9.05029,-76.106926,-93.333675,-25.41884,159.235289,208.069775,210.798407,166.912146,6.834449,-82.942199,-80.144428,-25.392807,3.431729,22.608298,37.647742,119.905661,146.286428,99.958367,53.613176,81.383853,191.244871,240.766947,280.091397,254.96564,169.329633,116.151354,82.354673,12.057608,7.978108,67.5285,109.61847,191.070026,213.126735,159.200381,45.237784,15.465875,23.763272,74.104746,229.296795,246.996566,105.211888,-3.356129,-9.907669,35.745972,92.318145,256.384635,334.025515,391.480827,351.582749,161.903531,-4.778907,-2.503383,138.053228,210.410189,266.0902,261.61518,297.681219,365.004108,336.696025,235.617855,233.725868,263.942147,254.141794,219.14786,212.390515,179.150267,73.902735,50.989099,102.9383,128.085667,142.501545,145.423926,122.687645,54.943372,32.363399,97.535825,187.214068,369.033261,407.611269,315.535433,205.406885,9.355702,-28.276791,0.840538,59.354689,56.109934,40.288576,63.934756,100.304733,10.136722,-41.434932,-49.080341,-27.682085,-5.004589,2.831259,-9.324268,-36.59637,-73.799398,-33.657499,7.258242,81.179553,108.126458,178.419259,220.929503,230.743322,115.933891,63.210545,63.156374,104.898943,145.80952,139.580392,174.554713,213.980064,257.615814,209.136936,165.656954,136.546735,176.561014,245.30231,202.530626,31.301079,-40.315061,-48.281284,-29.009689,6.557451,68.252454,78.641406,102.034763,127.555437,142.70121,45.41409,20.708973,96.526696,129.842499,102.394295,76.727249,40.47129,-51.982364,-105.143391,-62.172612,19.485462,58.405465,-3.689311,-101.014568,-92.917826,-63.281879,-104.7681,-90.617079,40.695178,94.502432,116.870253,110.162179,74.15314,-36.370747,-87.060648,-53.461,20.430059,130.350167,139.013512,147.322003,165.725881,117.377209,-74.850636,-147.972127,-135.11385,-71.49602,36.084862,47.870114,-15.258046,-132.819889,-168.314962,-161.217455,-125.791311,-11.98735,24.440293,-34.591039,-88.522836:106.433142,29.182267,8.408635,28.802625,49.351687,61.51238,70.309552,92.594681,58.010684,14.731554,-80.143635,-118.895613,-193.219574,-234.720503,-333.772413,-388.85076,-455.953531,-368.841282,-266.819285,-68.245885,-3.497378,112.884809,181.589881,267.087603,216.861744,186.148306,187.535278,203.773417,229.129017,230.800295,169.114102,111.759777,20.590088,-70.315369,-130.882061,-217.586387,-227.550777,-195.607734,-164.433808,-49.339337,107.857154,163.553665,240.757354,270.039446,313.987293,353.903817,395.020213,310.519533,-8.19978,-137.466907,-85.778664,39.317597,40.631421,-10.04687,-36.057577,-170.695428,-348.742842,-381.201502,-333.591419,-289.130136,-170.682026,-88.530897,49.303863,90.005873,195.979985,277.136619,285.760245,291.866603,275.370384,222.456942,217.80771,197.377479,70.858759,3.170433,-31.298652,-15.124558,-24.525234,-46.780449,-83.055768,-101.628588,-127.024202,-93.432766,-35.128364,145.877405,223.61062,291.059663,293.06982,284.701331,248.29464,194.605852,119.110348,147.185216,221.686358,200.004265,72.468899,9.98183,-53.830338,-8.561551,32.676652,141.845283,224.118355,369.556515,376.217413,270.124319,177.266563,162.585896,205.209608,244.875899,273.885263,251.463815,148.436747,80.179853,-34.600347,-109.895544,-138.846245,-115.958331,-78.431912,-94.691516,-153.037586,-241.038789,-201.571803,-155.067761,-49.75046,4.767432,108.879335,165.490997,270.267426,277.049062,173.757142,101.668293,123.675434,221.742336,257.856777,239.234866,198.691895,131.641461,95.263418,85.764609,106.413992,133.930874,180.98465,196.178706,216.506341,217.986535,174.559282,66.968113,20.808146,-15.259784,-19.29812,-19.23212,-21.533289,-48.006546,-57.2367,-51.835467,-18.055208,24.960047,137.444164,182.361228,243.347489,254.243597,187.861645,85.566452,94.677944,197.702628,229.470637,232.74183,217.038844,99.633225,-65.389753,-89.307114,-9.551608,34.348829,10.737373,-37.530667,-131.718421,-186.595312,-303.738425,-355.964362,-352.719832,-303.011886,-253.776945,-111.151888,-53.113575,-53.114441,-139.943618,-168.333852,-132.703006,-58.20839,75.910663,65.7208,-56.283007,-105.461408,-113.566097,-23.96003,33.422091,135.057736,166.792575,195.031329,188.138207,139.731827,95.076205,46.035168,-42.551436,-19.291483,73.728391,79.278274,7.944186,-46.744381,-160.9552,-269.257511,-290.06113,-247.254713,-217.69917,-148.492582,-94.491417,9.270334,-27.382178,-94.442152,-159.026679,-132.464208,-43.019916,-22.041781,-101.648052,-172.068784,-212.265251,-106.896052,-47.406394,31.642965,62.607219,89.389853,54.123416,-69.976742,-154.096665,-199.169423,-225.039191,-150.212535,64.439079,116.765795,55.891379,-15.216808,-91.704351,-72.223005,-51.173008,17.772533,46.144699,51.057598,48.583537,42.792892,-23.52971,-58.214827,-23.997144,40.428401,113.979975,95.699209,72.759612,100.816579,146.616017,88.159327,51.271447,46.57725,75.794925,132.996471,131.049976,0.768512,-187.690156,-230.030353,-175.401159,-102.036989,42.11097,94.081663,136.209565,113.483095,2.137241,-96.88538,-114.771717,-50.098612,8.019847,51.582256,48.956418,90.562384,158.695959,164.031591,129.931323,108.568789,95.876036,120.20341,162.457796,142.250883,63.410932,38.503178,56.512026,93.785873,93.62923,104.303406,123.229012,113.357664,28.707424,6.988202,105.589193,200.399098,329.653584,361.287255,364.918548,305.12864,126.023349,45.084652,34.911529,22.597703,18.455137,1.436934,-5.833227,-1.150192,-9.896513,-8.513147,17.310937,11.987912,-28.868239,-28.232677,12.49467,22.565125,-21.379641,-150.859617,-196.625841,-110.905829,-6.587449,140.293218,149.243595,84.767724,56.497008,83.02229,167.967163,191.621154,123.180811,57.988579,13.158679,39.544994,96.595897,64.396821,13.982296,-42.293198,-21.946588,61.519195,100.807444,128.597587,56.497389,0.938446,-64.958749,-63.890163,-7.757089,55.707169,208.975313,236.824473,121.961856,-32.771461,-46.77567,9.006238,30.822104,38.404959,29.895014,3.414677,3.704172,-11.489464,-80.801583,-96.308262,-80.887674,-76.592583,-81.844723,-79.348182,-62.209111,-88.261133,-108.694016,-78.410806,-33.451843,59.384497,91.714147,80.259884,-27.060038,-77.81669,-74.43144,-20.071697,79.843082,102.847235,103.917866,62.37113,-67.249812,-80.378816,-52.263208,-43.155648,-58.464179,-63.823954,-56.81964,-64.099673,-108.512205,-130.85896,-153.675713,-151.802355,-117.408304,-83.78056,-49.891264,-96.681043:-13.034109,-45.748627,-12.577559,65.380781,81.484414,72.41465,55.489004,9.190844,-49.016608,-86.619243,-147.644921,-171.818314,-239.557954,-292.854099,-430.243368,-480.694733,-493.752967,-440.517525,-391.509057,-230.059895,-129.440797,92.478643,191.442065,271.580044,242.104591,229.58371,225.001011,233.559773,298.574542,347.098387,336.158711,246.403852,8.719341,-182.807334,-256.32915,-322.91835,-310.637412,-259.808635,-253.766045,-254.612163,-173.378445,-109.8118,67.02009,170.872924,299.474031,321.829864,324.53516,281.554825,68.777709,-99.54381,-73.050476,32.20659,32.68661,-20.790815,-76.20583,-283.784378,-418.875798,-423.957383,-391.980557,-356.375224,-217.942546,-131.211221,18.14147,79.541997,166.866926,189.620738,211.167226,293.115272,310.47545,273.88381,251.237965,195.613562,36.137825,-60.374838,-163.104867,-175.52669,-184.830902,-174.766177,-138.483012,-130.04251,-129.371277,-143.055627,-131.15792,4.988058,117.415777,328.502444,367.035955,266.447279,140.876865,107.230362,75.607995,89.665376,170.514144,189.458607,74.044402,-36.998784,-191.418743,-172.466378,-129.028005,-21.235308,44.816504,178.917087,207.078307,147.873999,75.78452,70.147878,100.976799,131.281236,219.796517,254.88328,214.053844,144.456227,-18.005575,-184.285281,-249.123062,-269.397799,-229.011353,-171.7826,-192.325201,-269.304356,-243.368365,-188.352946,-76.455307,-39.919431,43.612322,118.340505,216.527428,176.104737,14.4392,-9.390228,33.040051,99.000933,98.622938,46.987307,9.097241,-62.650663,-126.988591,-131.831925,-75.555707,-54.999897,-53.355252,-36.98915,46.066786,61.094475,-63.873873,-247.979815,-286.50513,-232.342169,-172.978054,-95.938102,-93.206574,-134.806496,-168.123239,-159.038407,-78.454681,-2.359421,202.858616,280.245542,269.528921,208.205042,76.885568,-15.263295,-15.351467,73.670746,139.440212,240.124481,219.823234,12.682482,-176.690027,-203.487847,-171.307007,-154.64725,-158.923895,-163.22088,-180.321536,-222.805301,-354.769985,-406.891316,-396.446821,-349.486939,-310.69205,-211.799127,-179.719863,-187.575548,-238.144875,-246.464032,-158.175204,-57.929193,122.314941,149.353672,80.230283,10.416248,-118.964761,-101.399454,-18.592901,146.127231,180.442302,228.248565,244.800587,175.074053,22.239146,-45.748247,-80.527335,-31.779906,93.248325,120.514475,82.876854,21.810848,-188.293305,-400.118383,-409.353316,-216.943311,-113.748365,-13.442949,8.054508,-16.424414,-139.433466,-197.034381,-174.941426,-86.266531,94.693352,116.81489,10.563713,-63.010612,-113.726936,-22.767125,47.9589,156.438862,173.364397,142.044427,92.329229,-24.44764,-64.419576,-87.772205,-134.624112,-97.863162,98.134084,179.92491,158.499167,75.815727,-67.045992,-69.540802,-17.756449,128.441306,182.040103,208.044632,185.51776,105.810811,32.599057,3.861739,11.7429,60.196169,150.192698,160.856569,191.773715,233.440151,235.475354,75.522485,20.491591,41.151768,96.340518,222.615065,238.845258,82.452387,-139.345565,-190.080289,-117.552305,-14.479434,199.604734,263.043012,244.721673,190.565718,101.167789,4.643119,-44.133398,-16.03757,67.17936,204.653866,204.47722,178.612855,261.271552,279.242229,228.58643,199.871892,192.427996,217.520573,248.893267,234.540841,179.480149,111.874407,116.523545,214.674305,240.970711,221.407317,212.190214,164.11871,58.615363,30.63193,78.207456,136.352129,276.719265,349.399491,413.800852,373.457147,220.217451,111.454834,78.277112,49.171495,47.822718,55.476242,78.103861,146.264273,86.433157,15.467564,-25.819466,4.923728,40.851352,27.21341,-44.805789,-68.746319,-39.429286,-1.397054,6.701263,28.571538,37.798757,43.726309,44.270515,67.844188,93.435529,71.883615,41.69914,58.671456,71.087742,58.693963,53.130444,63.665362,50.816611,8.870416,41.154392,186.02066,214.96225,157.527149,136.80849,136.392577,49.599928,-18.881364,-64.541842,-34.257311,94.692918,182.093823,268.017937,231.009434,82.464719,-19.688435,-29.392437,14.050266,43.188411,67.219563,63.044321,58.733512,19.497767,-43.34005,-114.287306,-75.723011,7.767285,-0.781142,-59.578786,-65.251579,-32.490503,-45.547073,-61.082751,-12.855246,48.174809,150.755296,166.834181,150.908923,60.16578,-14.070593,-55.92696,12.584135,182.83845,223.505444,207.109261,166.597423,63.166076,17.434086,28.839396,49.43756,55.78823,91.688193,89.477131,-11.784389,-129.230709,-158.835975,-130.463773,-83.88115,11.976704,50.91476,42.791668,-21.889028:21.418601,133.963454,155.605802,140.062298,119.692728,119.966475,142.771065,117.118646,50.080549,32.218002,-15.883848,-43.968048,-132.725116,-190.503952,-267.098339,-295.247801,-344.72271,-339.843534,-293.762646,-98.682147,2.790648,85.783638,72.583705,49.671501,53.744508,29.650371,-4.608981,39.214856,219.680927,288.405218,291.299984,254.253191,155.659542,-14.962309,-98.441892,-137.611296,-94.712533,-10.700628,3.837446,42.493844,98.527123,111.012461,155.428034,198.998765,293.200292,324.043052,217.857541,61.094622,-211.23599,-186.362605,-116.982993,-10.883738,20.099135,69.384372,72.782963,-24.964253,-163.212834,-206.938611,-229.069295,-202.782401,-104.008103,-39.285623,75.533626,75.281013,21.284848,102.433351,158.230819,179.02865,158.849646,124.333869,112.814943,111.574051,131.525459,110.612336,20.84423,-0.457777,48.973995,88.569378,64.542539,-7.240688,-99.424647,-49.36187,-3.485705,114.140999,164.398473,188.815656,180.500096,178.717616,121.919438,73.006972,47.94128,76.687623,128.185785,118.902464,1.656091,-84.82672,-162.093129,12.530266,144.535062,317.818447,338.155812,331.91425,328.894188,327.218488,293.117829,247.764262,220.769257,253.038549,246.339703,193.853225,110.924868,100.06365,89.828419,-13.217229,-70.278234,-47.255122,8.329043,52.716046,5.847374,-181.263367,-261.877305,-224.871516,-75.66375,6.993511,147.420257,204.714305,257.846216,220.491251,67.636326,35.369018,89.570939,191.122476,183.20343,110.974464,96.266379,146.844062,231.532755,211.966655,82.64796,60.057805,89.207015,88.505794,65.247985,63.169938,52.73073,-30.211097,-84.654582,-140.604863,-141.164781,-134.508286,-145.236279,-221.271676,-283.926499,-275.836781,-194.893009,-136.682393,-30.957789,3.251086,58.9091,85.628839,79.519558,27.925653,43.555157,147.321879,177.853354,147.804597,103.383939,0.885382,-49.971677,-68.168533,-115.461021,-128.264357,-117.041775,-110.159306,-168.466334,-227.963758,-296.276619,-280.183987,-260.750962,-174.065503,-113.61311,-30.930274,-25.617292,-106.082645,-203.233629,-202.241673,-99.532513,-23.062353,63.800636,50.10068,-24.888135,-49.028945,2.060341,116.008612,149.979496,232.142697,291.940888,344.861223,301.605605,119.952987,-4.167927,-17.712756,-13.133661,-8.965158,-9.004795,-11.293281,-27.86364,-60.995012,-158.473092,-225.397844,-242.990416,-254.724727,-240.272545,-133.202122,-66.870423,-11.829133,-63.197692,-119.695303,-186.944904,-156.275372,-39.729096,-13.895572,-90.251222,-165.889036,-262.18612,-245.175227,-220.655148,-144.768006,-106.58296,-89.055052,-110.363761,-181.880786,-174.347755,-144.079014,-146.58343,-141.999228,-33.468843,6.497841,-41.266303,-89.930298,-172.560059,-269.037649,-311.692561,-316.828064,-277.383523,-179.256266,-140.456123,-62.451059,-13.730541,-17.402027,26.498193,92.981109,143.528488,86.700296,-24.611991,-11.564076,116.835814,160.068853,115.121843,37.185269,53.820574,153.306405,165.279897,6.768967,-255.84783,-363.007766,-423.393788,-343.66198,-90.275229,7.307207,102.398232,95.941842,7.842477,-37.314116,-22.02644,41.991425,71.598105,134.153063,165.043811,183.023032,184.248203,158.547503,4.835873,-56.371583,-15.142211,58.804307,151.083524,132.792936,58.945246,68.371315,98.654541,148.062146,146.462502,104.399142,85.070591,45.320558,2.016867,2.569608,64.97537,127.684125,280.703217,334.168157,308.80812,245.39669,146.009885,67.98386,39.742672,70.716021,85.047712,22.070078,-13.40434,-2.535255,75.674159,91.9764,76.810724,70.702199,54.592616,55.044777,117.54967,129.0979,-28.607123,-184.762459,-156.154311,9.485885,69.109988,124.749518,151.374089,201.642212,197.360709,169.835368,131.114987,127.24173,71.920901,24.216021,-34.280466,-46.080161,-96.597545,-158.569477,-131.712556,39.122648,93.87408,48.98925,27.505703,123.827985,160.03497,119.283328,95.367628,109.32561,81.340179,65.364439,100.374636,117.217476,97.018171,44.147904,15.844942,-13.884471,-3.651206,58.361924,85.944194,75.438087,15.118082,-9.017346,-51.194197,-54.39593,41.270739,107.057924,113.311248,48.860392,-101.764218,-176.347666,-161.219576,-46.851861,3.247521,46.621143,62.575419,70.587094,5.537073,-21.911499,73.60591,171.79814,236.873017,189.503924,74.785285,32.484214,-32.536799,-22.213123,13.044167,43.427697,25.631008,-7.261672,-21.041604,-58.586541,-38.448626,-38.331343,-118.466779,-136.768543,-72.767185,-54.993617,-119.146516,-166.824288:57.837683,14.986666,26.044611,117.402943,156.659734,153.077691,117.250721,-3.768942,-125.647601,-160.348773,-176.45018,-174.385374,-243.111021,-319.573094,-450.976652,-481.634655,-487.171117,-436.289434,-388.51643,-239.312852,-152.189381,-22.766366,4.70501,25.930761,81.489755,117.480471,170.586348,204.064952,339.150462,408.697688,409.035863,341.859117,173.589285,-26.5058,-130.198327,-261.630251,-285.003694,-290.844747,-285.679472,-252.802736,-158.360794,-87.718368,79.951668,154.829966,253.440131,280.244593,224.109111,112.744829,-148.536331,-194.704055,-124.358019,36.31318,79.092964,98.224208,66.871575,-113.883175,-317.499137,-371.419395,-364.953865,-327.435923,-245.24125,-195.550418,-80.39622,-42.417751,-19.660215,25.905828,91.889959,239.071659,255.743014,186.26367,149.373384,88.172913,35.340734,25.776557,26.004971,34.828598,67.544502,50.892363,-84.097556,-135.745817,-127.313393,-138.983845,-152.205193,-23.038306,98.687018,226.811569,200.45325,53.132357,-73.666771,-85.992635,5.391579,72.735163,137.934244,115.957376,-11.887182,-94.468319,-208.759697,-143.845546,-54.801001,109.49672,160.871603,227.344813,222.501775,109.759975,-6.994103,-21.430006,98.861698,193.856556,279.614453,267.484161,195.986549,132.881226,-26.41494,-125.60058,-138.116155,-96.81157,-57.401536,-27.982195,-73.13439,-252.355934,-329.930603,-271.993788,-74.966115,2.30431,107.175955,157.993835,213.189838,180.446737,52.660196,34.695707,68.119358,133.450955,154.245715,153.432135,117.045262,3.65507,-33.667106,-21.61934,34.310163,67.626931,86.449278,84.366853,105.445546,93.101741,-73.114715,-286.849374,-318.700137,-244.315277,-203.121254,-206.274806,-255.569808,-376.675937,-370.695673,-313.162384,-136.856532,-30.371627,119.735231,128.354005,81.299972,65.206824,34.134316,-23.995255,-37.331973,24.774245,81.968101,125.450438,70.510547,-129.969749,-203.404091,-193.477965,-182.847113,-175.462469,-152.748365,-132.545445,-120.810409,-183.461412,-381.042776,-425.442003,-372.355122,-223.939828,-174.589649,-146.628984,-147.366383,-179.781965,-285.604349,-330.487075,-241.253384,-104.499237,118.087463,137.944375,31.577572,-51.395467,-131.730836,-34.263583,53.230127,215.581687,264.252199,305.326138,286.464934,122.883388,-103.081761,-162.598743,-99.523778,-8.241447,133.702416,143.257531,59.447873,-21.004547,-219.80412,-331.428985,-322.663307,-216.066238,-142.233214,-17.12587,4.639601,-7.593746,-57.091501,-114.363352,-188.257315,-141.871678,60.332745,117.178607,-11.831488,-141.946575,-279.564823,-202.385281,-109.627826,79.111771,108.620867,31.685372,-31.440825,-138.989801,-175.59547,-176.471834,-135.175708,-57.788305,147.346708,182.795058,69.503476,-8.781952,-93.251745,-76.768052,-36.165845,51.074112,76.296871,112.062216,128.675558,117.639297,38.06298,16.761826,129.360769,232.501111,302.623988,240.380682,113.315597,118.374869,204.743902,256.59929,273.009771,298.3352,304.835697,308.296506,282.806438,121.662957,-76.541933,-136.968389,-123.09991,-38.871004,196.711218,286.071138,318.878455,274.030057,144.087762,60.005872,67.941485,158.599363,199.437071,236.431887,239.680077,194.293323,111.180189,87.634026,91.846803,114.400559,172.782595,200.820519,238.065169,239.129891,213.650916,163.048788,148.753158,160.878813,169.407632,188.362793,192.764254,136.399187,40.894457,38.879774,174.124346,261.386306,375.764434,416.704736,445.544785,395.325794,196.868867,46.878809,30.00506,84.051752,105.901546,92.186881,86.802861,92.389256,47.042636,11.790311,31.00655,84.952108,135.334509,109.078881,20.08412,-16.964261,-119.786309,-229.848772,-196.513695,31.643386,121.090046,144.259983,112.197102,54.796905,65.297871,73.003111,87.505709,100.545772,79.140701,53.662774,12.47221,-16.298309,-72.356428,-102.591047,-95.88288,7.214925,73.592372,144.081211,150.214287,142.545287,95.680388,67.822289,79.116165,96.186415,105.495936,144.383016,257.1863,247.472134,107.565374,33.004224,51.48879,157.009249,211.112474,252.303248,229.020504,144.314138,129.696782,142.363852,135.538962,119.991884,87.58822,60.073721,-12.524342,-21.54357,25.795816,19.155867,9.808702,78.707658,138.503807,187.921308,155.928201,77.864247,85.415783,101.911897,163.460205,214.081309,281.644233,275.090599,159.101403,59.495869,-46.119492,62.538273,122.57883,179.631723,196.984688,185.67321,131.948502,13.973479,-5.71476,-17.501581,-60.784333,-36.536448,80.505201,98.214398,28.606924,-10.744782:-167.631695,-38.012672,48.316049,131.341872,129.745857,154.904795,198.638831,259.616494,242.674332,211.234495,111.914792,59.250128,-35.779908,-77.469828,-148.104523,-178.3819,-198.663259,-176.825888,-155.434031,-45.062784,21.722355,60.160115,20.971197,-73.387598,-68.351516,-57.143577,-77.394684,-77.876081,20.472115,100.507529,205.44999,211.873912,156.003116,81.405564,83.356023,204.007373,285.651378,362.776619,348.74948,317.285068,360.350277,368.268675,325.978518,311.178371,296.664486,251.571128,86.678557,20.127735,-37.465985,-67.169466,-58.388295,29.578883,69.198698,83.444459,72.816952,54.612123,39.85308,12.92997,-25.706436,-27.054206,-68.489587,-87.455134,-22.093109,26.242961,47.181329,49.039219,71.048498,102.29559,88.269494,60.653644,76.883696,115.025267,82.485274,57.379996,47.97396,72.555854,174.326877,220.966286,199.129149,123.746672,-55.292787,-152.87461,-144.097876,-21.256148,42.275467,60.706124,11.411205,-110.367092,-132.10469,-130.550372,-127.7652,-101.639271,-35.741722,-23.979985,-52.651403,-83.979383,-53.624875,181.58315,288.51991,352.051326,342.12196,303.255877,259.540137,140.587081,53.773995,20.917035,-16.722893,2.219745,83.346619,111.007302,100.576591,62.052135,-22.5257,-54.15242,-36.904133,95.177567,176.605293,238.59046,176.195674,-75.143934,-183.414876,-139.230896,42.245338,118.217474,156.412147,143.761192,85.279015,33.898427,-22.443602,9.194381,26.758838,18.244812,-18.950832,-88.843174,-86.560791,-9.735293,30.137933,-22.085083,-189.428352,-225.716982,-207.845689,-192.324862,-138.543612,-108.929285,-127.826037,-247.623901,-301.046112,-339.005297,-359.768978,-443.073293,-473.753191,-491.437874,-477.973285,-465.821083,-396.355343,-348.353981,-321.110395,-326.911929,-261.402178,-214.551835,-190.248601,-165.321695,-108.037569,39.457001,74.960573,84.215698,68.852127,-57.211231,-148.62054,-136.901573,-111.121114,-100.965128,-47.797922,-32.706054,-130.084025,-218.590251,-268.633537,-131.871501,-72.344524,-19.379055,-10.538491,-12.997725,-31.623736,-117.611154,-133.618818,-88.659062,7.325128,34.199494,47.932501,41.547893,20.897953,14.841263,45.202601,110.725075,124.441632,152.013845,186.090606,216.233338,181.740907,58.920771,-64.005853,-110.755241,-123.905372,-96.373385,-94.941844,-139.159462,-235.386035,-271.703212,-304.491086,-299.850513,-317.148812,-406.352614,-452.751827,-417.78602,-329.217638,-170.629033,-175.978542,-218.358034,-225.305705,-177.71937,-120.466172,-134.28824,-209.796716,-271.653041,-380.954707,-354.926068,-293.511406,-175.213821,-160.051848,-178.354222,-173.164338,-123.503419,-99.29858,-123.512548,-140.140232,-87.297006,-8.076148,-52.240695,-223.755682,-287.074131,-351.221253,-433.970286,-491.077122,-540.771892,-518.791467,-409.016682,-332.903911,-201.497643,-168.221452,-165.354956,-59.314663,30.262029,77.283131,26.192513,-32.592956,-16.898584,33.546218,102.71326,145.06706,204.425367,199.289733,149.982016,125.203717,35.383138,-151.060734,-234.658756,-243.938801,-185.165921,-99.610456,-95.53127,-90.246689,-73.534134,-16.210142,26.189261,33.551623,101.739393,163.809474,225.037958,210.166997,216.834343,248.881032,191.640702,1.428772,-41.733243,-7.490435,21.532896,79.029768,107.638285,150.084162,180.79033,187.214954,151.510139,118.288847,100.407298,112.489367,90.908346,5.396864,-26.876394,-48.918785,-38.166866,42.497468,106.628721,177.901232,165.560067,153.176142,144.421512,104.991535,78.344036,107.895047,131.790881,119.158177,103.145285,101.494201,103.34882,95.078015,78.948655,40.877205,24.297106,12.281646,19.719913,14.100492,-39.59261,-50.960705,-9.872445,-1.726502,-38.307072,-22.708649,56.782593,37.314039,10.587369,-13.145566,-16.060143,-17.957426,-19.288938,-77.311491,-147.573886,-294.50062,-311.550469,-252.66069,-55.558717,36.12439,138.423871,151.868381,151.199912,165.213808,175.392508,195.373865,209.523834,207.836037,175.901232,121.044939,125.093118,141.522214,150.136489,182.657668,278.056209,285.93997,223.127938,204.968766,187.210984,163.140075,166.01563,163.753318,153.707645,130.592488,107.149895,21.350384,-24.498821,-73.659924,-114.182611,-133.094619,-95.716962,-78.264266,-99.683486,-71.034209,65.929059,91.456399,80.298404,119.519952,146.286667,136.209365,104.875089,17.950689,-19.081677,-48.695527,-89.63577,-129.558029,-198.971877,-215.011896,-222.912957,-225.215252,-237.051282,-225.221505,-215.387084,-189.451049,-157.562943,-105.326089,-98.95778,-80.626059,-87.313667:-17.141266,26.055801,60.244162,158.106078,177.883354,162.40179,188.834266,299.469058,267.769383,191.204176,86.995389,76.419643,22.700019,-31.547057,-84.890967,-70.640089,-46.838204,-51.602344,-22.056772,69.20811,101.615536,157.880585,165.667204,58.075167,-94.97629,-132.636409,-143.977809,-120.015164,0.302553,72.970199,161.419209,165.464695,111.557779,7.145077,-17.958856,65.10423,128.678461,173.814877,169.12774,201.696261,263.431679,271.159198,250.675364,247.431706,272.557192,275.746451,207.623615,144.048256,30.401494,-30.323164,-33.058819,50.898061,114.522368,197.187671,190.872815,51.683202,-126.677128,-180.653806,-199.640051,-166.409794,-47.235933,24.391287,142.294148,176.588783,200.928052,150.206445,120.821097,117.956174,132.487532,161.535699,184.219109,234.640109,222.851963,170.050133,39.296525,18.026077,71.813548,104.478376,72.670601,9.220526,-70.321344,-21.500093,24.152164,118.131633,145.15473,178.969466,187.475029,143.627995,121.52672,118.978272,106.784669,135.646015,233.288068,238.038794,119.386709,39.244626,7.854681,195.65115,286.429029,366.986371,395.159657,463.50313,473.132904,412.234936,334.621559,312.083299,240.373883,179.393908,91.179228,103.042224,163.407707,138.267931,-5.85314,-40.709274,12.220909,145.345721,163.10205,67.560512,-15.85832,-185.136279,-254.234427,-244.389051,-180.180046,-125.653693,3.407569,65.497748,151.888226,147.388419,63.2732,12.444312,12.618027,24.039233,29.71742,52.093008,52.631789,9.315541,-10.983734,-10.576599,-64.989265,-106.689444,-161.485426,-173.474751,-157.968729,-141.235212,-121.025616,-147.785922,-183.745592,-246.031258,-256.601983,-244.611605,-238.931031,-253.988894,-241.546087,-230.585307,-289.455462,-352.864275,-425.691671,-380.743887,-141.737079,-44.407967,-66.064428,-184.557603,-178.736323,-33.565057,48.842649,98.908702,46.495588,-110.691864,-184.82226,-203.597868,-180.845595,-125.741478,-25.492102,-23.705475,-156.680004,-259.501422,-324.880367,-126.932252,-27.018179,22.348033,-7.041122,-31.564413,-17.524458,-46.990216,-104.765589,-97.699193,-19.686947,16.713345,9.362699,-13.151305,-33.721297,-30.525129,17.292386,90.879481,110.745081,162.314333,201.993369,190.764192,102.468874,-165.303056,-297.508882,-277.920521,-195.175087,-192.2572,-289.132782,-308.872129,-203.152104,-173.881609,-260.419942,-355.599721,-386.025711,-445.504371,-461.198086,-359.702011,-252.579071,-104.169904,-95.057205,-94.944488,-64.03089,-59.407594,-111.138851,-135.304761,-155.151986,-193.773335,-341.335686,-396.424465,-355.169465,-205.969108,-133.907767,-47.384034,-30.776224,-18.185597,-36.675527,-74.719962,-179.185102,-200.817121,-171.428992,-160.96997,-204.831932,-248.094156,-333.331564,-419.66517,-447.621282,-419.837392,-402.506289,-377.621909,-327.255184,-205.818283,-188.816768,-207.260621,-188.484893,-133.990488,-38.066919,-17.165372,25.647754,47.756755,61.108795,16.050209,-7.361966,43.189909,104.174465,200.113855,217.907683,141.128472,-60.353524,-142.276167,-163.059043,-111.384753,4.976584,36.602724,68.250409,71.279847,17.917654,-62.956326,-67.149449,44.052873,116.816064,205.59793,222.357457,208.946918,202.808313,195.074146,123.812279,96.338367,84.359648,80.842605,79.722182,76.851274,81.353105,93.696871,99.060277,120.264066,114.557365,60.983567,37.844365,26.325316,32.263565,41.087049,87.796278,118.895182,169.395099,186.179399,197.0023,181.678276,134.710345,97.190573,77.018718,79.565437,101.565795,124.161835,114.670261,84.820942,90.132639,87.471039,47.697481,36.263645,51.521285,84.644041,191.537346,200.734501,51.362947,-118.672497,-131.281693,-17.927453,46.776123,126.844435,160.294415,210.160874,204.807957,162.451762,31.201225,-2.660986,34.469695,65.363453,65.262618,31.457195,-30.046528,-52.205241,-74.443472,-120.409711,-105.680664,45.546727,130.934805,194.65487,178.769127,155.520836,93.059298,79.861811,113.537991,142.246301,126.968079,82.192707,30.028925,64.595838,127.706597,290.109345,309.086473,231.687243,200.603829,149.615931,98.918877,105.547631,120.164964,81.195684,-62.099586,-94.394882,-1.151016,63.784972,73.345999,-64.638421,-128.55805,-164.514847,-157.694148,-101.045909,-30.05828,56.034039,-80.739272,-153.120696,-91.110877,36.696552,196.909153,135.123196,-105.396891,-168.381746,-149.633324,-51.868948,-17.532145,-38.384164,-72.587476,-100.889618,-94.522859,-100.517244,-142.404623,-172.038888,-232.936214,-228.979985,-150.882598,-115.203055,-97.081666,-119.994808:-54.985916,8.145624,18.120425,-6.473326,-15.32753,35.022983,80.123681,87.286363,21.934124,15.184139,18.717505,-6.290002,-102.207151,-145.279919,-253.029047,-331.19401,-395.429851,-328.437834,-292.541451,-148.061604,-66.178286,-40.156903,-72.325782,-61.942182,28.530837,34.973678,-17.306579,7.814605,218.393542,322.667436,380.86637,348.322263,257.72537,133.696215,51.247512,-1.012164,40.60635,99.620328,91.238864,94.411007,141.095653,121.160668,113.216779,184.765811,308.515964,285.06929,75.070442,-62.125087,-212.034683,-146.39033,-100.466007,-64.134003,-64.526651,-39.886629,-14.777047,17.986439,11.082353,-16.608089,-98.88539,-125.717289,-161.229719,-187.556232,-201.13457,-164.042224,-44.932035,27.838665,57.499361,107.405252,93.430102,39.24201,46.178852,102.300146,175.222244,202.456587,220.982163,224.948101,185.651202,150.304987,104.272196,76.697627,-6.838639,-75.038213,-79.462458,7.166172,64.401297,76.624949,35.46211,-31.260473,-37.778246,-39.339069,-8.369585,29.473631,36.855408,7.720426,23.195578,55.36158,25.917656,-53.155619,-34.18715,106.939818,170.528691,218.580291,206.648368,95.7267,-40.654359,-70.757286,-24.722251,33.380982,95.319579,93.121204,95.207937,83.354868,20.151886,10.498994,24.162432,83.077727,137.595042,158.47412,62.512035,-198.929897,-206.820111,-109.753703,151.930787,252.066086,259.218357,213.123001,142.239335,87.908673,-31.947481,-3.324752,28.97678,10.164548,-13.827628,25.882131,76.336295,126.106736,117.965403,99.992846,33.384748,14.847538,26.425626,36.421755,39.252087,20.742141,-60.409604,-186.56014,-249.623568,-252.356039,-205.879412,-190.991458,-260.388287,-470.428323,-465.384993,-363.295044,-145.214445,-67.643078,-25.571486,-54.114249,-107.025212,-112.990032,-90.705332,-41.264384,-12.925352,83.815583,121.008573,48.639055,-20.485048,-98.055285,-155.21725,-162.285753,-93.816048,-54.319938,-43.40262,-67.565285,-138.56164,-178.923239,-253.993804,-256.063567,-213.907712,-98.912201,-63.894168,-54.009908,-65.347302,-124.29995,-189.120938,-195.83614,-118.979312,-28.530697,132.117323,154.063538,148.749218,154.994807,171.314084,142.442044,142.980234,263.180643,320.263637,282.248729,218.796031,116.167111,80.477765,65.259698,33.96153,30.012879,16.183522,0.860668,-39.776426,-78.77253,-170.728399,-226.397069,-260.459204,-306.003649,-262.877527,-86.698509,-29.378968,-35.085055,-89.69356,-105.821211,-110.673509,-101.276683,-83.340364,-94.230784,-173.917465,-235.42982,-319.073231,-242.596877,-155.971936,-7.699561,-14.235427,-154.65969,-198.816554,-190.637266,-117.649114,-75.84426,-57.306347,-55.404311,30.647222,75.776982,-27.115938,-166.123537,-340.417053,-259.987525,-240.729761,-345.858587,-397.12711,-355.030815,-283.200629,-174.322033,-155.57428,-142.502232,-19.191971,73.328757,133.680695,70.748555,-68.345456,-77.04078,3.634516,67.392444,73.506064,97.714665,129.215258,170.500994,138.853878,-26.231804,-184.980707,-227.79292,-203.619117,-137.538844,13.318348,59.412921,38.924029,-7.979615,9.189934,121.217488,113.270116,42.75895,48.091261,136.422529,167.934821,137.883041,64.118849,19.837549,-46.560286,-40.946203,3.155038,25.858572,107.301305,163.61969,239.511565,169.287866,95.216458,42.685956,95.716743,216.399081,206.453567,78.771509,46.511914,71.29421,67.835768,56.74775,155.082387,229.788768,242.32175,171.541054,43.663191,41.948842,46.222088,37.479605,23.627802,-19.086515,-26.472413,6.407945,25.654513,9.016565,-15.591059,-12.714485,-7.274514,-9.762523,3.049857,13.097981,-27.865738,-108.422422,-106.158084,1.549465,56.283566,65.205536,31.482218,-5.198776,58.790113,83.664704,65.042583,40.780517,-26.097473,-65.786243,-116.263015,-139.830007,-203.275639,-237.087237,-219.195502,-62.998634,27.549161,70.520579,54.180371,101.801898,183.370114,186.709756,160.003437,163.931716,240.273938,284.159952,263.71797,197.531707,95.654663,71.444987,54.85083,85.010766,138.097633,177.431251,136.652958,49.4613,95.93893,147.266859,179.112081,147.223254,73.882241,52.11428,-11.326879,-50.648385,-67.044755,-87.850607,-133.844691,-154.202111,-114.911605,-39.353512,-1.490096,84.11793,128.031787,134.847283,124.666469,107.869263,87.301994,89.865763,69.76295,29.357398,-65.390241,-51.05323,-11.058674,36.398219,25.02033,-61.701797,-93.287701,-46.830005,-20.723243,-70.095867,-159.033463,-149.634565,-96.600308,-81.650992,-93.465371,-121.824592:right
-104.803051,-35.904758,-96.448546,-269.867582,-283.609161,-139.592448,-52.312628,94.615936,208.859924,206.903638,121.102726,69.125364,-53.327504,-89.609136,-39.511951,35.24536,184.221781,169.901923,115.503232,27.943159,-1.022017,-55.30503,-71.287562,-92.860104,-171.115804,-214.14096,-211.128021,-165.899886,-80.271119,-54.25315,-12.257578,6.731536,27.941666,-15.626199,-59.372587,-106.628624,-122.431876,-194.085909,-182.728197,17.477516,92.812464,4.896336,-177.807775,-182.189553,-95.731784,-86.077849,-130.254596,-109.06386,45.017629,117.432118,106.745058,103.647204,114.716163,112.429763,112.978893,187.389484,257.989815,215.797185,38.288003,-6.341986,51.774598,95.985519,155.282085,181.353006,200.096721,195.20916,192.490365,159.55857,133.036339,117.547935,126.516593,126.003161,104.960149,97.467358,75.554478,50.367101,36.660526,76.193538,186.03106,213.313698,168.910066,97.371278,86.80485,30.00513,-39.756783,-147.442492,-149.217428,-131.65089,-206.590783,-270.486664,-343.834373,-333.330335,-314.593294,-325.868272,-271.721404,-184.013316,-10.0808,-6.474304,-64.57007,-177.441284,-186.076358,-94.546334,-50.340589,-46.138476,-54.903464,-54.87905,-45.891149,-34.316758,-40.46687,-48.367155,-71.579833,-90.816413,-34.563239,66.889878,41.042802,-109.47079,-149.514694,-115.342981,-80.704936,5.538665,99.289294,82.422509,-113.783698,-238.292464,-371.223138,-340.554615,-161.132352,-62.494494,61.722647,-33.109562,-97.818267,-54.965641,19.174082,137.315822,163.680864,235.066891,361.041666,347.836586,153.857159,42.667518,-104.717951,-141.40427,-176.351445,-145.299912,15.17084,19.125284,-42.137321,-143.282781,-172.303316,-147.908019,-83.445767,91.700464,174.622424,158.761221,95.335063,33.475748,-145.16655,-181.212619,-74.92632,8.161904,72.558693,-10.470673,-38.302812,-38.86661,-52.286031,-72.531035,-38.819014,106.679914,193.800437,176.926511,113.811006,96.974037,62.270841,32.68251,-73.715949,-128.499504,-143.795223,-124.779315,-149.83467,-268.595396,-337.687039,-413.513732,-401.873986,-270.18734,-116.415796,-79.961282,-40.382656,-29.273404,-7.700104,16.912338,54.830444,83.014844,162.46854,149.352207,134.453202,118.923393,97.156798,116.75868,186.107747,314.001706,290.6148,230.91521,31.46356,-81.821172,-110.755947,-5.302073,155.770099,136.256251,18.721847,-38.166594,-43.926389,-46.093324,-31.045875,36.222033,51.108674,32.575584,65.062631,58.325669,-84.432302,-168.196751,-213.872543,-162.912981,-13.515354,40.566325,115.389765,162.284052,181.077053,170.185363,120.740649,44.835998,44.879932,79.426618,164.252252,195.82655,213.89794,243.519075,295.401915,272.422701,207.91923,202.460904,175.59188,60.639184,8.995009,-47.34784,-60.625425,-58.636938,-55.045003,-91.815839,-179.196264,-219.335976,-237.661878,-214.455139,-114.674862,-44.897468,71.284286,85.324695,-21.14113,-187.548089,-232.28114,-289.222928,-327.248443,-372.363893,-352.968112,-252.291378,-167.7096,-165.226991,-225.127977,-245.441158,-191.32784,-118.241412,62.86144,131.868853,121.49696,-83.988035,-193.236308,-293.769167,-267.780892,-136.11875,-102.112473,-136.491278,-137.420436,-127.531924,-150.060146,-174.586987,-216.689721,-206.468849,-99.437757,-39.997643,-9.731121,-61.539022,-48.563638,61.634877,112.340241,186.772052,206.713163,233.611456,295.583196,283.201441,128.13431,45.973642,-47.545509,-74.463512,-59.80816,-18.399778,38.82819,-27.154488,-101.618263,-248.5048,-285.259775,-235.53978,-152.117641,61.726431,193.125255,190.729028,111.621817,73.679932,50.949883,59.785421,54.560011,49.856929,104.072675,205.907782,250.373182,225.235095,112.88088,-184.383293,-262.657415,-211.30222,-109.524704,-107.876665,-165.1144,-197.009099,-221.683501,-184.366701,-53.551493,-8.740634,64.143845,141.29565,136.253359,22.166077,-31.660264,-20.458633,27.29772,143.597888,216.10322,183.743755,-25.755525,-124.666046,-135.689513,-72.638535,22.438488,46.993504,108.724201,186.733542,214.906202,175.27601,115.16736,44.946031,67.650771,153.423215,128.110054,54.744885,-129.742248,-217.916102,-318.793792,-299.550811,-163.65831,-87.638783,37.59828,75.893074,42.603635,-72.661362,-100.410523,-10.835114,78.338085,179.414061,199.707731,232.155033,279.062308,250.886884,157.807779,149.091345,168.051093,166.32946,172.168083,144.647885,114.159554,83.98985,87.586327,128.143479,142.656907,115.181488,152.988806,198.833777,174.271109,89.961449,-65.14129,-93.917522,-76.555207,-24.372658:-64.034589,-42.445496,-73.236424,-181.590476,-172.441781,-11.484254,70.539288,160.121957,122.635007,89.933423,66.483715,44.171191,-14.387923,-12.234384,47.001354,83.357894,161.489783,197.334867,173.686762,109.620885,108.893874,137.747718,130.903903,45.883611,-60.874029,-71.824269,-48.311097,-58.328408,-74.225342,-55.386805,-6.098298,1.328957,-60.722237,-159.256605,-180.562657,-185.941403,-194.061977,-202.186029,-153.543707,59.294556,110.916051,21.919914,-202.422844,-292.016044,-388.487196,-365.791891,-232.493998,-183.025313,-139.070921,-84.335076,-67.083067,-61.417626,-38.778152,19.116305,20.627216,26.218543,117.465441,143.836722,25.396513,-75.925177,-115.263703,-47.456452,123.232343,178.043178,97.00491,-73.985654,-67.750748,78.903034,136.384656,132.507741,79.817955,-11.182638,5.744528,32.507129,70.701657,45.410067,-60.42869,-67.550886,15.975397,40.545443,2.696825,-14.517446,-14.9959,-152.982575,-260.244231,-281.314793,-200.294559,-115.732223,-170.777634,-214.760611,-331.181719,-373.07378,-378.04221,-364.976013,-286.307987,-193.598059,-12.896365,-70.385218,-183.464607,-333.689436,-306.920349,-164.698279,-108.99088,-35.174526,-7.38253,-9.227463,-41.55906,-90.869611,-219.231956,-234.062985,-162.958064,-130.278998,-55.466056,35.883044,20.27413,-153.698222,-213.17718,-174.640889,-154.540802,-184.574673,-149.157634,-134.248859,-256.615858,-367.465325,-519.282306,-515.003524,-339.195982,-198.863951,30.058401,-5.099215,-101.957114,-209.328313,-162.042261,54.23064,158.190059,281.648586,254.933067,165.046716,-57.634461,-129.057739,-140.998685,-98.474728,-16.478276,32.661343,144.580177,15.472463,-102.666461,-216.906559,-206.12915,-53.06731,75.689115,287.659073,300.794818,253.048823,122.058677,34.025142,-149.234916,-162.560693,38.128744,156.86675,176.672407,-15.506724,-63.822242,-76.894921,-115.73913,-176.205612,-136.269187,18.443402,75.251054,44.04438,16.388611,46.660116,66.106216,32.474741,-45.753537,-59.978887,-52.272935,-73.921048,-96.69532,-190.252359,-255.468776,-316.721369,-280.452312,-115.785999,-91.318703,-149.320001,-182.328351,-161.110535,-93.91068,-31.962132,91.181101,146.544176,202.48608,93.810568,35.611472,3.09466,1.13241,30.234165,79.758816,130.610042,-11.315675,-91.998663,-115.944251,-97.201424,-113.14586,-108.632202,-33.329897,-8.633901,-40.987945,-131.898407,-145.711555,-80.564157,-47.95572,-43.673149,-42.264113,33.235388,121.607727,110.114334,-79.061079,-225.927762,-377.364201,-309.289414,-67.705666,1.323892,62.044175,84.614373,62.671492,4.786674,-14.944789,-50.889497,-51.001641,69.757255,176.155656,143.702529,72.529072,88.777609,113.041406,103.368409,112.285767,128.270693,127.575463,38.046012,-7.604425,-43.909205,-28.877759,81.238308,123.212089,56.367576,-45.142402,-60.698622,-105.208997,-121.222623,9.954287,126.277897,208.379108,162.217965,37.411246,-53.48781,-79.109627,-146.021036,-192.155062,-188.738157,-125.793447,-8.783141,-6.645941,-51.798866,-160.38759,-164.734438,-52.456731,17.357982,159.832822,234.201271,266.230069,106.73274,16.664632,-111.982558,-118.940717,-19.563199,22.682012,32.013075,32.053403,10.807979,-85.453481,-129.895493,-162.834272,-148.994569,-82.279864,-28.651897,29.337088,-67.55233,-102.336694,-61.371045,-11.050387,87.045209,124.421733,226.128515,362.013042,366.923525,185.021163,81.532735,2.492983,-2.071409,27.283593,52.813975,36.005967,-90.147297,-192.949635,-390.697944,-394.311891,-190.847123,-80.707372,21.358393,4.97378,-31.990061,-76.221865,-74.621268,-86.771354,-73.869646,41.903485,90.890344,70.635084,39.353633,79.787727,180.621675,165.551318,-36.374661,-152.093403,-191.630485,-122.266049,-161.701857,-305.748121,-332.116754,-283.310935,-229.044819,-70.013155,18.386243,159.233701,145.509058,64.796942,-78.237726,-92.257223,-77.783791,-69.59138,26.91084,201.797182,229.116428,45.625077,-94.968203,-200.584309,-153.169615,9.451054,86.642366,155.972999,134.808319,128.194786,52.766544,-16.157214,-42.579605,7.089236,80.266284,99.322506,89.545974,-64.386791,-183.350639,-282.07229,-235.417153,-61.26594,20.712645,81.569106,53.541476,62.681331,72.615986,56.713881,83.596602,151.881445,296.353164,281.765071,232.192554,143.410753,111.229486,114.898681,149.849089,126.596841,75.596088,90.00968,166.811788,171.917289,99.00925,41.0911,-14.256517,-5.106257,43.608812,120.689072,151.013795,118.269061,45.693334,-59.476314,-26.061861,130.887969,196.562219:-121.924424,-116.131217,-123.144716,-169.504213,-186.563363,-98.179649,-6.778652,128.337555,52.494851,-17.258717,-54.555029,-29.662999,34.862122,57.248194,104.067628,152.041172,229.503038,125.937736,53.883442,73.037973,140.263085,217.612554,222.370045,166.622607,22.947837,-32.460966,-76.984528,-99.999707,-158.728382,-159.355963,-85.261841,-27.290325,50.80141,-43.65934,-123.800672,-165.877388,-133.336742,-89.564743,-56.820491,87.39251,128.286793,76.455507,-69.393571,-163.555386,-364.552031,-390.052428,-182.074023,-44.611264,-12.093727,-178.197712,-210.483002,-154.365364,-109.470448,-46.559258,-23.253599,26.824897,46.816464,24.65945,-66.565725,-105.780309,-116.032851,-110.232852,-122.100346,-106.241702,-38.499849,-35.064735,-27.242138,6.579777,-0.389579,-49.361215,-82.057501,-98.828469,-6.10988,33.498562,45.510134,17.141443,-66.508753,-90.737093,-83.554948,-61.849705,-17.228242,13.759762,9.697912,-103.964087,-169.183156,-158.154459,-112.254852,-99.434709,-137.894783,-142.117295,-221.82677,-304.025253,-411.251616,-406.692628,-281.986694,-170.90758,-0.530646,-115.723852,-234.012457,-328.549461,-273.156132,-134.885512,-92.624408,33.023516,60.963747,-0.802384,-69.124588,-57.530159,-132.490916,-207.36385,-223.781899,-191.297007,-165.877723,-98.937978,-81.544034,-177.845878,-235.282949,-234.944842,-192.312507,-104.669144,-67.686967,-95.657132,-307.397459,-440.739401,-465.077838,-344.660136,-145.437531,-94.916139,43.92752,58.292018,-21.912607,-159.409051,-141.426368,40.970168,146.942935,365.539386,423.253714,291.270724,-35.625397,-88.02474,-36.011073,-4.675809,61.959086,111.327073,156.602057,43.299908,-21.035892,-86.760325,-79.909996,59.23909,165.059344,285.513232,227.90094,154.81882,-35.123382,-118.936277,-139.220824,-46.289081,193.205422,236.96614,140.209947,17.248278,-7.75555,-80.878713,-143.014335,-169.401545,-102.390658,54.175883,46.366823,-6.947866,-56.471363,-45.698384,-52.054274,-71.037762,-91.9743,-96.678734,-125.056731,-197.064801,-242.008821,-291.393554,-289.859467,-293.557785,-284.879228,-162.33938,-79.863212,-116.135504,-218.331728,-228.240818,-111.729525,-21.633523,106.013857,146.404228,176.903091,83.726778,20.599971,-30.332638,-31.484387,-48.131399,-35.37031,78.751996,88.30406,6.845424,-119.706128,-121.734941,-94.452237,-79.419147,-26.151873,12.353835,48.226361,-21.107632,-59.633454,-63.65536,-31.822654,3.21058,5.7443,94.302681,178.755411,120.135588,-144.821544,-245.789326,-244.841793,-167.192157,36.22382,135.47863,246.631032,176.024476,132.093194,102.92408,69.173523,-39.318183,-43.781005,98.471535,212.324181,184.601311,38.599676,-20.325465,-44.97192,-17.751581,39.668971,48.875362,48.101628,67.843088,88.235622,81.994068,76.589517,181.555708,219.479679,87.482321,-3.133945,39.525261,98.785624,66.172792,48.884377,115.577598,240.027785,229.554603,109.354507,-13.345845,-62.96827,-159.962036,-206.648601,-225.478091,-176.929306,10.716614,95.649028,39.413308,-78.858689,-71.393005,27.020309,79.824225,209.022228,294.597586,325.739424,108.089649,8.172656,-53.15394,5.301197,209.480691,251.920868,161.141829,83.848395,65.775697,-40.763454,-116.824652,-180.936799,-152.374865,-62.249462,-22.514892,6.455302,-91.436071,-143.495735,-141.579385,-94.29596,40.011562,127.063509,319.078076,344.854784,255.492867,7.749385,-74.049228,-105.822191,-91.194154,-17.082523,32.962596,56.323013,-65.572214,-174.875402,-329.405463,-288.603582,-49.62428,58.788199,174.037684,84.068133,-9.303109,-95.151713,-87.775199,-69.419866,-57.472963,-17.274165,21.393209,128.549009,93.556154,20.418072,-18.397734,36.30186,51.320464,-7.780405,-3.080008,49.249873,-21.906525,-245.309996,-321.239218,-328.072499,-251.631987,-3.108506,111.170804,234.807118,159.681595,61.400381,-43.477871,-14.784955,63.419095,79.143814,121.937487,217.894365,234.974478,69.45357,-67.336626,-143.717643,-66.765628,42.48697,31.976377,17.294715,58.229253,82.002197,65.176578,-4.503872,-115.579899,-63.675192,213.763081,315.730815,231.311535,-86.498362,-220.711674,-209.694661,-99.586645,29.636387,11.315363,-2.094184,124.008303,144.851628,13.027587,-20.874005,137.927713,241.058623,336.946317,249.96977,157.735466,9.186811,-37.978294,-104.954157,-71.547699,118.220377,175.642632,164.134559,156.362032,154.67913,40.43643,-30.111107,-38.899063,-25.404392,-30.408757,55.477798,80.623932,-11.342455,-68.276144,-67.572047,-33.245352,61.641206,131.597824:-70.149039,-24.124477,-75.916806,-267.075047,-303.508329,-178.755275,-89.245522,41.475425,111.91828,132.084366,158.270509,139.724452,74.798098,71.377756,104.942072,132.111809,191.705192,130.923711,69.802623,10.897196,-5.439541,-42.935089,-27.993281,28.737635,0.675146,-25.604609,-74.751891,-106.819603,-174.966594,-184.972678,-87.027503,10.830816,146.886505,64.245088,-12.151741,-74.033195,-56.056281,-2.717535,28.173672,123.05715,133.85633,78.940082,-51.662776,-108.213946,-171.257724,-152.874733,-39.900694,18.715273,57.38741,18.568617,-3.146143,-51.096567,-53.883384,38.095427,103.243286,208.373502,216.360613,148.870671,-23.904625,-71.943618,-88.071066,-72.01115,9.074979,73.001481,147.296787,49.379998,-18.375502,-47.987771,9.183052,162.315007,180.539101,117.191177,113.898489,127.521286,105.840786,58.391724,-49.740474,-60.214501,5.235496,29.227626,18.570714,-5.408845,-16.073688,-75.999023,-131.801709,-210.954273,-200.078476,-123.0748,-134.996136,-189.645512,-289.591227,-302.716216,-254.893007,-202.488642,-92.119865,-52.326334,-35.890176,-131.726472,-184.248546,-241.391339,-242.895964,-164.72596,-92.776808,47.692198,63.498501,20.803761,-46.542573,-57.546971,-97.666256,-105.381676,-26.064651,20.734997,36.375463,-6.272559,-32.622143,-111.021385,-147.994855,-141.972283,-108.190288,-54.235837,-24.027839,-28.598907,-155.150032,-268.838043,-386.587,-338.612384,-163.077113,-80.937697,51.710225,62.544039,26.673694,-44.637419,-46.561819,69.559008,164.698396,329.906783,340.067833,268.553683,95.708334,36.406748,-29.275912,-37.478013,-20.470913,2.802997,59.873807,31.195826,-7.473326,-92.032709,-116.373325,-39.76043,44.252325,159.259661,141.729319,100.392327,-8.874527,-77.455992,-213.156992,-225.638261,-103.227729,-18.578045,66.315318,35.309744,17.265669,-54.901178,-107.889076,-97.125298,-25.120961,102.555577,153.366466,154.32781,97.008824,32.953026,-102.570392,-116.963121,-77.949768,-90.773972,-146.556837,-150.284477,-179.355427,-314.243513,-374.878056,-401.255703,-365.56391,-219.261636,-78.253718,-60.074668,-99.223536,-115.201101,-66.105335,-13.966381,52.415439,87.330425,204.851153,238.028763,206.468292,140.843747,137.825872,210.242576,276.32817,385.102869,315.197408,221.042208,64.555199,32.507712,69.533592,111.339765,133.854483,129.129569,138.783755,121.024286,117.546774,118.335216,108.304659,106.67364,121.644286,156.757195,177.08107,156.126085,33.579991,-39.598854,-106.345541,-71.075896,117.178907,231.589112,378.353984,326.884645,274.505796,216.800978,184.948735,88.728064,61.919431,114.491705,230.767823,269.021169,267.673443,218.181064,85.650684,69.811625,158.758005,197.275869,160.63804,61.266471,32.154653,-23.414949,-52.783794,-9.645206,42.290024,22.408984,-101.780267,-114.416469,-46.260464,-26.588122,-16.400114,17.120279,88.13498,85.614863,31.182361,-49.542782,-107.311616,-271.955244,-339.701884,-327.391188,-275.704971,-183.673373,-114.167282,-103.052668,-108.653196,-115.676292,-150.110667,-140.205631,24.070643,129.018911,145.818296,-93.158353,-188.055271,-199.458516,-139.421728,-6.238514,8.429934,-67.024421,-63.176386,-29.36607,-47.046033,-119.533085,-267.270471,-273.419755,-138.53637,-43.287198,58.698285,-31.637994,-82.318595,-33.773337,49.532319,160.748753,160.93947,175.440986,232.866104,206.710788,50.616927,-17.486606,-37.980486,-16.076013,-3.992068,-13.71692,-30.238894,-29.993879,-35.266955,-107.345024,-152.98489,-112.272406,-14.241583,164.458815,116.823929,39.568262,9.540903,72.009959,157.52426,140.063919,104.03875,129.739609,176.293075,108.831388,91.161474,151.074928,153.4932,-24.830244,-135.929142,-169.921945,-80.06006,-92.137631,-196.54898,-236.622432,-252.849741,-225.635521,-88.475383,17.509511,222.124096,202.964064,109.221063,-60.909881,-97.950502,-32.38368,60.277936,219.889198,261.871586,247.419452,125.100015,34.761249,-65.48339,-48.285257,36.00183,70.408357,148.951419,233.471298,241.309749,145.953083,61.637933,-31.0505,-3.888238,125.813659,123.278666,25.309908,-210.591583,-276.805918,-265.413803,-223.812179,-161.687664,-129.353571,-30.682575,74.262188,92.526991,-5.144129,-53.236733,26.790417,121.954462,291.763343,353.835279,324.660036,154.687489,61.583663,7.72794,51.795159,160.61821,188.629672,160.826157,75.7945,66.719815,69.043409,49.331781,28.040448,24.976379,3.384705,59.973878,104.057,112.695525,66.859517,-47.843534,-76.47789,-55.887975,-5.838569:-56.044831,-97.148223,-164.50742,-287.765338,-291.717616,-118.034644,4.367467,148.755091,143.993941,143.258413,180.976195,171.828925,72.665786,18.961535,-9.214884,43.47659,189.848094,142.909204,65.903373,-4.807547,18.431046,97.379484,122.692847,103.397143,7.689701,-47.297861,-171.391306,-232.804381,-266.090482,-222.807054,-54.851379,46.647288,171.964576,84.289564,3.674718,-76.782815,-49.244701,92.831401,156.678462,236.249946,256.402508,200.067394,-45.888193,-159.123464,-213.239568,-171.39103,-41.745469,27.855623,80.224966,-9.495372,-49.598865,-94.061171,-107.730596,-86.985635,-43.754177,90.239177,102.841271,30.020014,-124.552746,-165.22186,-165.311975,-132.445059,-38.797305,11.351478,46.813572,-78.582761,-141.262769,-150.685547,-121.007302,-62.282965,-43.787036,7.204542,39.270023,15.629772,-62.850864,-102.892663,-166.044681,-171.789673,-125.215983,-77.358951,34.391596,12.563207,-66.42128,-233.630434,-265.861362,-204.285731,-153.236711,-107.074581,-120.256794,-152.771121,-307.462849,-385.117897,-356.525336,-270.057652,-129.367351,-71.655702,26.648261,-68.818214,-175.57043,-304.393385,-284.228227,-155.340613,-87.075413,38.789329,64.836819,29.511669,-32.477226,-60.505593,-150.102254,-175.369968,-136.920665,-99.53034,-28.19877,-20.184625,-78.405215,-225.167729,-224.691298,-71.536653,-2.487565,25.645312,-58.663166,-134.948647,-314.732131,-383.0753,-336.834334,-237.361616,-128.842485,-121.590866,-46.282629,12.222018,-0.019247,-38.40152,-30.566941,74.647082,165.457387,367.505942,366.841776,255.676879,23.198687,-32.676593,-24.912242,26.049612,151.349232,194.777518,214.908146,110.098166,35.094867,-106.386408,-152.896822,-93.831212,9.046579,175.370996,135.945388,52.601432,-153.50896,-219.876262,-214.976993,-161.716594,-11.421804,48.622429,53.675822,23.499536,41.078536,18.640422,-44.497534,-102.354346,-59.47694,51.212183,38.649905,-24.722333,-143.560104,-172.211513,-185.357662,-173.02302,-143.901692,-132.274599,-119.44916,-180.99639,-243.139172,-378.912524,-421.7241,-397.743687,-336.361381,-202.842714,-158.688197,-166.77334,-203.474629,-223.140473,-195.305015,-137.223558,8.319983,76.154385,143.940602,90.5469,33.199738,-80.884757,-98.730984,-13.9852,73.19468,253.394289,238.079599,134.480789,-69.604757,-115.629148,-96.229176,-54.514775,30.38926,79.793881,162.589776,118.958294,81.885021,37.86391,37.427789,90.336916,121.074271,149.482454,123.252492,85.471193,-1.370245,-30.665042,-24.072318,19.226821,142.159832,206.444685,302.821441,266.40793,212.67818,121.092474,97.349533,81.160419,85.162199,159.419792,258.575893,248.793584,115.879421,41.014635,-20.027807,6.508608,105.508684,145.314877,166.702454,130.736449,101.356326,45.070465,51.39775,116.802168,129.449113,106.70484,91.830968,92.40333,87.134328,59.148347,13.085634,40.94168,166.802072,220.129659,226.674035,110.717055,34.168825,-133.837405,-202.596104,-231.844281,-187.850556,-20.124712,85.814513,68.106239,-11.646543,-48.595726,-108.00837,-95.36121,85.241288,214.644056,288.383636,63.419482,-34.964535,-58.25925,5.311753,164.051679,206.723638,201.170237,117.919497,66.603478,19.170541,18.146764,-50.812168,-114.81513,-131.635478,-54.072728,103.745615,54.710844,-5.498826,-28.143627,36.272856,220.237045,272.145348,296.565473,276.237761,219.374798,25.682277,-62.242282,-107.339402,-64.063029,52.603987,77.695227,40.130235,-2.315936,-45.849483,-196.588733,-222.224861,-61.040128,90.455143,324.822388,217.644951,105.669498,13.121485,13.198689,-18.725297,-55.81894,-73.287073,1.249716,200.53367,98.574493,-18.568215,-67.963594,-16.461812,-33.610273,-104.144611,-103.072296,3.164393,-33.141727,-270.353595,-373.957764,-362.249873,-282.06761,-119.690313,-38.315901,80.656293,55.854764,-0.928208,-141.786173,-175.112276,-57.222137,57.095947,192.967892,175.716316,150.400336,54.920296,-14.721411,-114.155917,-124.712276,-51.764123,35.437688,176.522255,91.064498,24.422145,-32.087767,-56.588361,-102.253082,-75.461486,78.5319,95.525048,0.90639,-247.667646,-330.4739,-310.170852,-235.559021,-133.808025,-97.760851,56.006502,183.239015,154.317413,1.969041,-6.771736,138.722296,212.190812,322.790906,347.74022,274.26765,32.845388,-65.535013,-133.885881,-84.041268,159.935715,284.353471,353.813758,266.602863,237.311881,146.467639,91.958697,104.365096,149.594416,214.446339,263.365607,252.291141,106.895217,24.702084,27.574068,98.96103,214.664236,246.249666:11.383401,-35.730331,-128.330012,-298.810773,-302.968088,-132.254095,-10.346976,169.867194,204.56191,179.325019,138.826922,137.259956,125.852779,102.034015,32.352884,26.694219,85.905423,37.221103,-39.88066,-138.220925,-134.7099,-87.417931,-55.365177,-36.380565,-163.185645,-254.149346,-347.406969,-331.965306,-274.631611,-236.591333,-104.678531,-44.123575,19.388252,58.623951,68.233405,53.548214,42.813625,57.915532,83.423007,143.19223,119.601624,37.042752,-145.390677,-169.099818,-99.580876,-63.532086,-15.813487,20.760927,108.096794,116.996629,91.248651,74.283372,105.005724,175.454485,191.090911,247.415068,265.797893,175.233042,-76.827396,-115.299404,1.495581,68.279617,99.968971,96.081026,134.344107,137.268037,92.598904,27.150932,41.10484,124.668899,167.485844,207.138781,200.33728,185.995353,105.702678,37.289327,-93.607953,-107.320645,-2.718342,61.999355,105.426687,44.08647,-0.287119,-119.367589,-189.859119,-221.605516,-181.060881,-186.043915,-331.686985,-383.521724,-362.501299,-313.854406,-258.155407,-244.787985,-132.771294,-42.863026,32.031345,-107.000001,-183.101174,-233.608834,-219.53963,-152.215931,-128.538535,-135.148738,-137.142426,-164.409406,-253.25299,-260.91666,-185.213064,-121.247112,-21.319071,-26.757212,-84.282421,-56.193909,-46.063993,-112.14247,-139.518695,-89.118881,-53.140607,-46.698582,-54.089337,-69.043943,-172.149557,-241.681313,-351.307496,-360.604184,-204.459868,-62.761202,89.950342,-23.995718,-87.353688,-153.59384,-160.809863,-40.221928,66.957461,190.841674,207.229494,205.167274,135.865715,66.813721,-53.165521,-70.683229,-41.51416,-19.90446,20.848087,19.759948,-11.450322,-107.266576,-141.864789,-104.796909,-40.101895,48.361872,-5.188049,-59.815382,-144.768034,-175.591733,-254.590263,-283.997483,-211.935489,-102.520722,52.053836,-34.507626,-70.9358,-58.915654,-66.308755,-96.030252,-77.746365,38.635623,157.566533,160.355414,34.884643,-50.144559,-166.908693,-182.003798,-184.023303,-197.791315,-196.525895,-180.052596,-217.463293,-384.069772,-480.184483,-577.242768,-545.8681,-375.986777,-225.596769,-205.47131,-260.700395,-282.421855,-208.650463,-139.385796,-68.45115,-59.639942,8.73301,86.014806,82.31481,38.645949,47.814181,156.225402,219.61676,303.601512,332.379512,300.166248,120.75182,21.76641,-7.630679,72.591792,208.062518,194.963045,74.606943,28.484732,70.055318,170.639703,161.976799,73.74204,47.164311,68.866727,166.5422,176.785308,16.478987,-96.356822,-118.906164,4.046885,283.781579,343.498342,329.265417,296.869586,294.661999,253.868404,198.223504,118.691572,129.406682,210.626291,280.570292,280.212525,261.990929,271.550823,264.20354,248.747296,259.149026,256.053182,153.787013,23.006915,-0.498804,7.851862,-2.177767,-86.384031,-141.180382,-160.856488,-33.285061,4.422257,-84.691486,-170.574439,-185.074309,-81.13883,118.908589,130.646107,11.05637,-111.90655,-131.244226,-179.222771,-251.208251,-371.703299,-364.278447,-270.460565,-174.899094,-151.094256,-153.677301,-146.093272,-61.582832,1.957985,115.817931,154.048626,158.056172,-0.44401,-101.841241,-203.933367,-182.780901,-35.780374,18.403991,-15.39919,-47.576554,-23.972586,33.604501,36.710396,-51.786238,-97.79278,-54.437478,9.642804,75.905102,65.819448,74.581305,128.841635,170.471011,253.508175,250.341682,161.283036,149.152828,153.576452,59.95796,-9.458381,-86.723698,-92.554811,-46.836871,-13.283569,4.553917,16.466964,28.761179,-0.231091,-39.125652,-76.554518,-40.794271,112.550317,220.867595,215.576875,174.061791,179.014885,191.819466,178.184331,151.110603,163.743627,214.979788,210.947954,203.653326,161.678578,99.081512,-71.36634,-154.944374,-242.290096,-153.767467,-101.910078,-114.796904,-174.912185,-234.281806,-178.722478,-28.993125,-1.677233,18.70262,20.663682,-28.127406,-166.197645,-189.707217,-68.444641,38.721412,217.421961,261.426809,198.27717,-20.01107,-83.002438,-52.295092,-24.639543,-17.404669,11.058529,144.579658,195.665334,168.658204,61.873565,-1.791088,-70.525713,-42.964915,76.933583,69.418466,-18.938656,-237.632875,-280.139699,-250.57906,-247.954532,-241.366822,-192.683316,-28.851168,63.493265,51.069437,-42.316922,-74.403811,15.593095,132.544918,357.182802,376.599218,287.126303,83.086352,54.663342,172.116136,264.41923,341.674912,304.520189,200.052996,188.632974,204.116308,214.425973,204.600038,218.264655,249.252505,280.648984,266.998497,259.537684,206.530978,151.454791,38.172441,6.897873,13.293941,52.845064:65.813315,-51.442873,-193.835449,-392.09222,-372.944081,-175.266477,-62.178161,118.263778,203.840091,217.84075,213.870866,177.043388,62.135759,42.756357,126.028157,187.096221,228.456074,117.040401,45.08155,-68.16917,-112.199443,-104.942464,-35.427875,80.838666,-4.625261,-95.016903,-245.65004,-274.344224,-218.8131,-159.614363,-25.344338,54.687387,196.07905,192.6178,138.565046,54.661292,51.299374,78.014739,102.14344,218.994009,256.289459,160.824279,-133.586626,-227.414879,-180.867936,-80.975409,97.244174,148.980748,148.337354,18.392705,-38.021722,-70.433359,-63.676434,-9.598375,55.714583,232.105597,245.924099,151.87369,-61.757586,-108.367491,-93.407309,-71.841538,-9.575615,45.523197,162.551897,98.919316,-3.135431,-89.862929,-18.85289,171.193463,199.648512,156.841838,115.159488,84.041087,-36.871383,-114.649277,-205.821644,-187.681641,-59.729318,21.176039,140.956457,82.607136,2.770926,-154.403755,-209.766217,-235.386212,-208.493678,-152.224445,-215.007882,-296.202736,-428.392649,-434.850287,-345.145385,-278.87218,-99.838408,15.369369,129.577184,-58.634213,-195.103412,-347.69988,-331.767215,-171.898191,-79.842953,11.675522,-73.645515,-131.244584,-153.922943,-138.458865,-105.5565,-60.519872,60.747035,82.245527,27.437232,-70.524383,-120.994956,-206.013914,-201.476923,-60.494215,15.901225,73.999909,30.067211,-33.98592,-225.390586,-318.018291,-400.306695,-371.953013,-197.98135,-76.879488,69.757705,-31.132778,-99.101679,-159.556597,-149.873519,2.704967,124.637735,284.256446,259.048627,210.570142,114.114043,68.870434,-33.815955,-67.852914,-33.953799,22.032971,98.330826,24.046633,-48.159532,-180.52405,-200.050356,-51.27557,79.11677,227.584734,85.151113,-44.926035,-212.519625,-243.612453,-300.115809,-303.113737,-177.428311,-74.088257,62.45326,-33.839328,-127.447222,-211.133676,-185.024118,-68.197898,-9.211082,53.184795,39.282442,-7.212716,-153.33033,-214.08869,-238.641055,-194.956961,-107.733576,-110.240479,-166.784825,-244.122451,-284.96917,-366.582788,-414.305751,-465.530513,-434.652103,-271.428241,-133.839424,-140.370513,-267.055305,-316.250587,-246.661338,-140.13396,47.803478,92.777174,110.862917,35.806644,-21.539257,-74.011269,-43.947064,107.054864,188.766445,291.692971,276.33972,195.594699,-19.46366,-79.445835,-60.576195,-15.836834,54.595881,76.291654,115.565132,118.397814,102.417472,45.337085,20.82538,60.724811,113.642914,187.281652,172.362824,120.690029,-13.332583,-58.52111,-61.621894,-0.74716,221.891494,327.767725,397.945538,260.515852,173.272044,71.640183,57.868096,73.588741,102.920851,208.402855,270.021815,257.611996,193.262694,147.799225,77.116897,89.220036,164.152359,185.979005,194.153906,142.780585,84.586431,-43.555598,-61.524296,15.313501,55.741779,92.925336,81.527354,46.655523,-32.071147,-77.953364,-134.173603,-77.630393,147.672412,213.858516,166.019595,10.622159,-72.284316,-219.648183,-257.143941,-217.934311,-165.291332,-68.341379,-20.789683,-13.147817,-1.830757,-2.863944,-43.030208,-46.208857,100.308758,221.163474,280.14149,0.804808,-131.295417,-201.562259,-152.183769,36.065503,122.328422,179.764881,122.495208,79.876738,7.361099,-22.713119,-88.185503,-100.060921,-3.543642,83.750705,154.472889,67.780566,40.416789,47.743842,77.870075,226.630088,317.763158,379.67072,225.019118,105.670753,-78.656386,-93.805912,4.03176,45.93817,55.940417,77.079545,167.202009,110.454769,18.097736,-138.951617,-159.055833,-67.356114,31.316676,225.553856,237.55136,172.639044,57.599488,50.379017,84.181026,88.515285,83.711391,115.519833,204.960813,126.689544,47.742506,-62.086743,-92.353807,-128.376826,-140.98751,-123.66423,-75.495048,-110.605967,-300.178177,-383.612888,-373.215248,-279.170975,-90.480315,-53.661174,-56.771284,-113.983624,-180.969476,-340.924817,-367.316391,-198.708192,-40.710671,192.216738,160.793549,76.295115,-93.276546,-132.6015,-110.350117,-75.952085,9.668913,77.671782,195.849862,113.65966,33.051677,-87.070231,-117.390772,-86.258947,-33.292986,55.886079,23.408017,-45.363389,-205.764943,-262.363626,-288.044429,-257.6967,-142.39442,-65.854256,101.588348,191.072448,163.502929,11.230256,-35.924207,76.887416,217.323692,456.515323,400.114352,286.884523,97.818381,59.614403,81.366457,148.411481,367.568143,455.083091,459.886435,305.325167,228.940712,112.288039,94.073093,199.905109,278.402636,344.783348,305.028784,265.510855,131.130248,42.406447,-46.96242,-6.313779,151.87509,208.187519:57.654532,85.838182,34.029853,-104.507894,-151.613781,-97.762291,21.424899,259.496069,239.999178,189.525925,202.601595,231.613482,211.023947,185.642568,159.305108,151.983213,129.715684,38.540638,-20.192744,-85.735852,-96.302497,-124.034571,-155.004229,-242.713162,-323.957115,-368.551728,-453.521225,-462.831071,-367.382692,-280.021047,-147.305802,-115.303154,-9.750203,107.269449,102.617408,61.983269,78.221223,95.542526,55.447712,-21.498162,-54.550916,-114.263668,-202.041373,-161.850259,2.604209,74.833494,134.698127,121.163557,107.520641,110.726492,84.291908,7.368427,-22.101308,-8.65441,45.963869,182.504783,216.231498,149.452513,-47.389991,-70.857885,80.824896,176.141122,262.986258,255.815444,215.681766,210.953715,203.466617,146.428387,126.55626,157.563738,174.988349,156.411724,164.399403,171.832389,80.590513,-19.292768,-159.999789,-132.747629,27.375017,80.179789,91.851697,51.85171,12.581821,-151.880528,-221.871159,-125.465036,-21.331331,-54.757358,-359.289034,-473.086484,-527.569895,-494.155261,-344.320784,-247.53507,-131.55787,-129.571996,-148.66224,-162.562723,-183.602784,-232.187702,-238.896282,-199.21715,-188.230946,-214.065194,-204.207055,-193.402524,-152.365201,-122.565246,-100.025376,-87.213173,-39.384024,-32.649744,-26.901927,-31.764831,-68.017788,-168.787466,-181.38197,-71.445697,4.585747,27.638934,-89.019131,-134.096651,-130.370645,-104.460763,-121.864246,-144.096958,-43.52562,68.677429,182.256516,65.99847,2.586097,-16.495885,-0.006171,-13.01063,-32.273125,-0.415684,106.417305,140.751585,139.536845,111.123597,23.001446,-11.127649,-0.525063,31.686433,91.764195,69.462362,15.511035,-110.927208,-129.677236,-49.124723,-3.244958,41.48362,55.227229,29.343361,-61.94934,-106.373946,-211.185307,-257.230326,-207.650409,-104.56415,56.024164,12.044073,-22.463073,-24.455021,-15.093093,4.352572,26.529284,98.160921,158.274214,146.306922,68.202857,42.440463,25.951766,30.784561,33.730922,12.69075,-24.983009,-61.879029,-115.995238,-276.616747,-370.017227,-506.062116,-496.357252,-349.331952,-244.537509,-252.869296,-302.420484,-299.499031,-239.443088,-186.25183,-32.597926,44.990796,131.006139,91.698247,45.404585,-33.219496,-31.967157,100.020466,185.388901,280.102368,281.7646,246.24304,143.808222,99.90884,57.402113,79.195145,169.868283,192.41855,169.316414,98.525651,69.693833,38.074773,16.089691,-10.618993,4.954013,49.38379,14.360069,-44.949403,-141.940856,-145.205507,-59.309773,41.044944,263.009926,294.497916,209.065662,204.390191,245.886527,291.697935,273.784491,165.816882,97.687632,61.386084,214.775738,277.414433,293.065995,305.264602,362.470426,363.260885,297.84232,260.784465,182.674282,18.71526,-67.295614,-154.882332,-176.359075,-224.683422,-230.425522,-153.110867,-52.606616,-50.866964,-149.337808,-209.07161,-211.786865,-121.793764,84.753893,95.722708,-75.414904,-142.680504,-74.314436,21.575747,-29.627723,-228.626889,-313.876846,-407.248107,-348.159926,-256.993958,-20.189134,67.381609,97.342361,83.321197,127.42205,178.897449,218.550895,52.313746,-73.313921,-189.878053,-151.612557,-32.046804,-21.185198,-115.974236,-171.237878,-158.612194,-138.047745,-141.070755,-143.088415,-128.553574,-99.084096,-92.13377,-25.325635,85.403713,118.662007,127.324614,102.585118,18.075851,-8.560439,22.984318,52.270757,14.419489,-85.497487,-114.22864,-177.092151,-197.788986,-77.070024,28.678969,83.776158,21.497078,28.465132,48.077624,25.355991,-15.77515,-8.408033,38.413962,113.884884,148.829034,184.193235,191.562991,209.522062,205.241854,117.485573,84.616217,175.853394,239.923027,206.637552,127.641537,94.930911,34.657462,10.615906,-49.513547,-86.611367,-78.769909,-43.322236,-10.298314,105.801952,159.310456,169.098873,136.356187,91.7489,25.899907,-35.328888,-87.15393,-53.347893,75.592976,150.157293,227.303286,179.845356,144.628188,59.675379,21.617743,3.444254,16.380001,61.090987,92.292758,162.080403,176.931501,156.078898,123.049249,120.344741,113.12215,117.98411,165.45539,143.072736,98.656242,60.477065,64.970944,-14.745751,-84.260358,-140.640731,-134.995431,-110.433052,-34.262781,-3.63819,-32.479304,-59.969508,-17.42367,44.926952,105.596559,24.076212,-26.723117,-31.767038,7.476307,49.836056,55.612685,68.056466,55.669097,11.917785,-5.22701,6.220495,60.948748,81.777609,132.624291,166.282498,183.633092,173.265109,171.820194,122.910554,64.340459,-48.175458,-59.998464,-14.295835,10.536846:-8.00709,-9.161226,-51.004408,-177.502848,-212.188247,-144.124507,-35.708971,195.026957,215.946915,160.14804,67.341982,13.436876,-131.094605,-143.829102,-25.327377,28.289236,68.394249,48.061557,9.568691,-74.624355,-95.30016,-97.42651,-106.244511,-183.019563,-287.421237,-317.436698,-281.131982,-240.666194,-181.709231,-148.443559,-80.338506,-56.609661,-23.93993,-61.174454,-85.797252,-53.768417,-37.917229,-85.716889,-102.858277,-45.477657,10.1809,-35.342844,-177.965281,-164.055791,27.522671,95.197942,70.81639,19.325718,-29.563998,38.587256,73.82704,56.577969,24.273409,60.903059,125.147849,201.775746,184.68376,134.757599,-46.864937,-105.684473,-19.555169,80.027269,222.053328,240.596355,211.260299,193.980931,183.047174,133.132973,118.827252,155.230191,182.518201,181.990901,132.2425,114.449623,96.146875,64.235481,-40.898399,-39.364657,140.464454,237.496588,284.890377,210.196157,162.378812,15.823604,-81.280986,-199.143381,-204.868839,-224.304889,-332.899218,-385.634,-404.434851,-385.71539,-343.625707,-292.009979,-101.994487,-23.075224,36.233636,50.025216,29.691691,-57.638366,-69.72125,24.107544,62.344393,-14.343179,-131.208527,-147.193518,-79.811252,-31.344115,-7.073096,-3.580385,32.9116,38.6482,42.185195,88.869011,100.830373,33.976904,-22.574507,-35.942307,27.557158,164.739182,159.785493,107.843163,-22.706297,-93.296021,-236.636828,-259.510516,-96.637725,37.313886,154.21062,79.761989,61.33815,78.809373,76.107045,60.196689,87.510946,208.051798,259.745307,246.838236,165.854454,92.349211,-28.424658,-47.617086,-85.543418,-96.14709,10.748909,116.719282,77.205649,-76.87013,-89.035374,38.804434,100.308837,162.29557,193.714441,183.098186,125.072291,59.822661,-141.097763,-190.335153,-113.511674,-61.202419,-28.128939,-21.66879,10.448906,79.850775,70.932631,45.773532,86.495495,243.039764,338.147872,331.560601,248.704676,190.340752,84.067429,61.905713,57.473997,45.996267,-9.421518,-77.835445,-108.112964,-199.746216,-274.249584,-413.93887,-439.83985,-350.007137,-153.11336,-113.692181,-159.984162,-163.387606,-99.797381,-82.048727,-100.680223,-89.321945,36.076305,142.185868,151.921942,91.916557,47.626876,119.835091,241.831227,406.2727,381.88971,349.683897,250.154011,176.152666,96.089062,126.197746,196.60743,189.636563,134.288812,104.963102,128.379067,196.068248,203.534039,197.242862,178.459787,62.884486,-37.879924,-66.714049,-121.414265,-140.188627,-95.00874,-15.809823,133.328854,161.034659,200.536902,243.474204,229.714776,160.028692,131.21972,89.235317,78.056499,110.807724,169.226551,175.989828,194.373469,229.77076,280.033944,265.893985,194.373726,159.654825,64.254498,-106.132272,-177.244522,-237.749576,-260.730533,-341.213673,-364.671011,-281.329677,-191.326525,-227.0823,-354.074374,-376.879813,-275.342207,-174.567751,-42.77715,-46.279806,-156.59311,-286.471945,-272.499891,-120.993804,-88.193894,-183.337691,-253.10805,-324.843496,-285.824042,-258.915224,-221.382422,-201.501007,-133.403852,-75.583985,27.242061,42.462751,6.856139,-105.11211,-183.111269,-272.534622,-253.039746,-161.000791,-155.509216,-221.742636,-144.822043,-76.779517,-30.398671,-46.370263,-115.174246,-147.031771,-146.067345,-108.808886,-51.811335,-48.034445,5.796127,128.839843,108.881602,10.13193,1.996326,54.282007,121.528942,122.606968,62.685272,26.787338,-107.461093,-188.680378,-168.726126,-83.010837,11.251459,-20.395166,-44.856681,-103.193732,-142.560324,-156.333847,-96.247686,71.271224,133.919805,129.522872,183.434552,231.268568,234.634984,205.298576,189.997398,218.928082,307.144588,308.59321,290.837147,239.079162,177.687683,24.583144,-28.825289,-81.378524,-54.609869,-13.449767,54.803313,76.392384,121.452823,154.638951,185.480604,165.771108,159.672505,194.982156,190.559524,139.502462,105.09829,90.088369,116.476219,170.25135,181.273671,166.06456,63.938946,-17.638233,-124.948825,-104.627928,28.751175,81.609148,106.136745,93.949571,113.404375,149.02463,123.691736,46.598438,35.972815,57.971245,67.088689,35.27677,-65.547395,-101.285615,-184.50732,-246.307731,-303.58721,-260.943312,-136.641535,-130.950963,-127.522691,-91.059068,-106.072527,-146.888285,-106.718855,38.618203,98.769013,106.543663,98.22194,81.261695,80.176354,106.531011,98.991712,47.42463,-15.569336,-5.594919,-24.594684,-81.724531,-77.121906,19.701728,65.797405,69.228064,94.736079,130.153545,102.687014,30.543224,-106.755776,-144.074844,-165.280569,-145.477322:48.940293,-85.559162,-163.658782,-235.600117,-215.38295,-58.15098,54.599688,234.811882,269.026518,239.487837,186.214427,189.654003,218.810364,226.002171,245.633785,264.272533,255.333051,90.379436,-21.014629,-136.679656,-120.596567,-54.492764,-66.023783,-165.756369,-187.4,-196.241526,-291.515634,-331.171727,-301.938039,-254.038177,-176.775752,-141.336614,-17.021253,97.173627,106.991553,68.708833,53.68863,65.503475,85.297854,92.416892,15.971947,-29.70539,-115.251035,-137.518392,-52.39059,43.748425,190.084088,189.266315,76.970504,-39.12706,-63.213328,-55.098991,-56.317467,-23.32972,48.425522,195.965274,192.642488,134.309516,-13.202468,-50.733128,-1.833235,67.618603,208.853913,248.666501,248.282916,137.190782,78.361913,93.277004,145.333633,205.053419,198.467382,155.007932,115.455304,100.702409,51.346659,-6.635182,-79.047677,-17.739544,153.201365,154.194026,68.128369,50.086955,27.687854,-107.582038,-163.234632,-112.998755,-52.025876,-28.205225,-143.794142,-235.232098,-341.195639,-299.793717,-128.56733,-73.711195,-29.43317,3.26508,83.39865,44.634358,-14.069635,-135.039652,-164.287703,-96.366093,-43.126521,-22.607654,-103.500048,-158.346073,-132.001843,-40.968861,64.96631,48.361277,-8.914962,-31.501715,-40.735564,3.333041,2.466804,-77.197035,-103.73583,-40.156974,0.292429,-1.033998,-47.33417,-89.474242,-218.998463,-261.15891,-256.844304,-248.683058,-177.726915,-69.146543,127.904718,56.503624,-23.08789,-113.40871,-108.640864,-9.538941,43.036031,114.60964,192.641809,204.205499,127.446542,73.778136,32.683814,38.555934,43.140274,49.561784,99.777528,88.386928,42.609163,-76.287075,-117.015209,-73.894585,-21.407485,6.751935,-37.084912,-69.289823,-171.27214,-232.779532,-302.349074,-271.164858,-99.480987,-20.625859,35.427846,-7.346105,-38.795356,-82.361266,-82.283693,-43.792779,-24.614399,7.652672,65.93071,84.549044,46.51514,-0.225872,-101.1297,-142.334113,-208.243414,-226.939847,-172.30362,-101.910152,-131.692021,-255.70644,-299.868097,-298.508697,-247.505135,-116.71445,-70.482078,-87.753646,-157.977441,-178.645521,-126.260388,-63.56081,45.395498,77.738758,124.447508,106.224661,64.099298,-5.40991,-6.282874,88.930059,168.515517,268.366654,213.52172,155.98685,74.714401,57.498417,36.951576,40.722246,87.503704,113.064983,137.164738,115.957216,103.869495,110.913668,97.033933,9.25078,-13.211275,59.013337,160.572892,148.30897,22.872797,-31.601387,-9.135329,76.723327,270.737537,313.316774,286.047688,229.239991,203.302046,118.224273,60.100065,-8.944029,-2.974698,74.06296,136.049669,110.773576,82.767139,141.396929,222.777382,198.618949,165.985988,167.556378,92.945954,-50.178882,-85.717489,-87.590232,-87.648502,-83.943786,-80.352508,-124.571778,-154.126387,-134.346065,-120.773888,-155.792177,-192.324481,-135.97662,-21.526338,-39.009517,-105.490408,-106.301614,-118.020028,-180.495706,-233.396828,-370.675903,-414.599752,-340.485674,-183.099701,-168.723113,-167.029329,-111.186311,48.184964,102.269588,142.942345,159.919201,160.033309,-51.816783,-180.267794,-244.750044,-182.421651,-36.687681,-15.359542,-94.722664,-125.142595,-89.608793,-36.606066,-52.517124,-152.040013,-172.549593,-73.515439,-6.668961,64.906878,67.873862,77.401234,114.472036,119.068659,127.891427,136.63441,149.33355,143.58442,109.333528,23.52126,19.833346,87.217896,120.36206,151.378174,159.185001,186.841777,139.368139,76.546431,-23.639316,-42.484029,-3.246854,52.425056,164.646922,186.469846,153.211251,121.17047,158.556919,216.03507,188.179183,107.139128,121.908708,255.961627,296.565056,250.191094,118.769766,58.696291,-29.399892,-50.495452,-23.399476,31.272261,13.892618,-101.57601,-152.75203,-166.941401,-134.965742,-26.825518,43.907208,116.357494,-54.024226,-178.218855,-308.577874,-286.459819,-78.517729,58.997132,230.095121,200.432905,128.226513,-23.292262,-54.168925,-38.064473,-24.897745,-1.711292,23.275563,106.227169,115.450443,80.081693,10.110018,-10.122957,1.226285,30.022195,57.890109,34.661852,19.529224,-7.691269,-18.268325,-73.036381,-112.964887,-98.807908,-28.434851,82.495885,32.085362,8.131642,6.735897,-9.837229,6.689094,88.062971,279.870476,268.722041,192.267004,51.831105,22.379981,82.32641,161.588096,271.969593,267.493505,223.955271,193.706975,206.77499,256.564993,251.51105,233.699829,230.216464,196.130414,191.207294,173.261169,57.741353,-2.57581,-52.127168,-43.113768,-16.440448,-2.89071:right
-42.317614,-15.209493,55.362379,205.905445,240.968321,241.4543,237.444632,180.33682,-13.557818,-106.125998,-102.847633,-18.014641,106.361774,112.090281,83.651071,43.241055,-120.969855,-238.681021,-230.777686,-116.693069,-50.057598,48.979717,71.864179,44.594566,-10.593852,-37.651454,-103.599083,-122.197939,-102.472626,-70.332994,26.104211,69.979741,68.439204,-16.240785,-33.226043,29.92237,72.074106,102.885769,105.861591,126.31466,137.614702,112.910881,67.33079,100.216352,239.679039,270.689477,220.301772,183.003297,117.009501,42.318942,34.788991,77.756185,86.185423,106.647039,139.250758,146.577457,-4.859537,-84.386477,-92.535173,-46.931293,-32.318786,-64.819677,-72.708073,-32.741483,13.51184,-92.096441,-163.633571,-220.238517,-194.087034,-60.770606,18.063072,103.338682,52.866596,-11.755302,-92.296968,-51.277168,127.093583,210.314359,330.277016,348.996969,266.061591,161.664916,174.013881,260.703495,267.834597,232.78331,240.213139,278.009432,211.519161,150.781434,83.026778,87.96502,150.065264,208.833209,279.880658,216.328603,-22.460799,-65.942609,8.886339,186.714136,228.648306,233.308704,234.554909,228.718625,147.246707,87.898845,-17.092556,-49.754743,-35.298894,10.460148,52.561009,5.516118,-130.344964,-187.696673,-193.791769,-163.071543,-126.709509,-59.80435,-60.440221,-150.18704,-211.04595,-221.193889,-257.819549,-257.521417,-175.26186,-101.790195,55.523748,108.437799,148.816802,101.933888,63.425691,79.230637,139.60621,277.870332,334.816598,397.607907,344.511046,269.130003,126.414593,125.356669,267.184566,336.710565,339.412731,298.483658,228.784912,83.8253,-7.403355,-65.3074,-44.369318,-28.765562,-32.531495,-42.701367,-99.749411,-169.664113,-328.500032,-348.794006,-266.782348,-216.201513,-170.970325,-168.060399,-167.582914,-212.7715,-232.448857,-174.329761,-113.028684,-8.877645,24.505632,45.629479,-7.223855,-52.825005,-79.115935,-36.682606,43.314721,53.674962,86.283006,111.649393,122.696681,82.821097,73.009737,47.818032,18.676762,22.660328,66.004005,102.552976,-0.59274,-65.059895,-130.687399,-118.093274,-52.713802,-10.219304,78.550857,83.642955,7.354756,-15.392856,8.169922,63.637085,75.740766,68.493843,73.009638,70.971252,-1.036834,-30.857252,-26.03293,-2.298488,72.895949,111.72771,121.457487,101.965302,124.00711,137.653731,92.309703,52.085001,94.772061,170.972697,156.320461,66.971191,47.106763,59.833069,57.634468,54.132217,55.145834,32.588061,-46.474321,-57.679944,-9.83017,-45.635797,-104.351237,-170.290571,-166.131903,-112.378258,-65.608686,32.419068,77.012397,45.25558,-96.219566,-145.450268,-152.607853,-117.148096,-19.240647,2.389045,27.067427,129.511913,170.103548,167.275309,140.025034,70.050112,36.864191,8.710816,-1.764532,-35.747601,-104.602245,-86.244264,45.638197,120.1315,225.019869,230.657579,142.849764,50.042393,39.432409,50.847683,47.417647,34.206021,36.201032,52.759094,43.967491,-16.913797,-196.996371,-213.74423,-61.588425,11.369516,-7.024825,-90.143927,-262.303828,-254.731073,-188.097024,-61.57257,-40.806631,-63.090602,-74.23803,-71.936101,-105.45668,-155.938107,-211.243351,-165.618971,-9.830524,37.520672,63.830903,71.833585,90.293741,74.880022,57.255633,28.729028,0.1252,-120.594589,-172.221389,-166.182973,-91.271669,-72.16306,-30.739816,23.603639,134.175702,151.522883,126.525247,116.674342,90.931197,-31.207109,-82.772286,-61.676105,-32.513647,-38.123725,-44.690532,7.72314,66.093348,41.919557,-40.359802,-36.994267,1.214358,2.329583,12.905403,-1.778189,-146.738776,-283.168809,-275.559692,-108.811189,-24.347916,2.755689,-31.630294,-122.951481,-261.054748,-333.989568,-403.609416,-396.893908,-381.742294,-377.253807,-332.836653,-318.286359,-328.827021,-282.777548,-223.42405,-45.789266,37.695694,109.043259,107.009393,45.654418,-44.171116,-86.547247,-170.483055,-193.576057,-194.870452,-168.100515,-56.660214,-20.606024,-92.396879,-238.852932,-272.400427,-219.830635,-152.424668,-24.123258,-11.234529,-133.672619,-278.31002,-309.049433,-301.568095,-294.714237,-348.479534,-376.12004,-325.612298,-280.915519,-250.128185,-297.284461,-331.048999,-357.027174,-349.358349,-281.533597,-218.332498,-115.281819,-141.518314,-181.826362,-183.309498,-126.568207,-9.278336,1.121082,-77.542376,-135.636889,-160.333455,-87.150049,-70.167604,-2.604242,68.451705,155.229063,140.922722,81.36001,48.814977,18.255939,-56.006632,-73.809035,-95.687431,-109.230916,-106.057858,-93.473272:-60.420304,-0.657337,37.539183,118.438154,133.608444,130.378951,144.481822,134.146435,-37.756537,-123.958558,-130.300314,-77.353207,-8.198511,8.071555,10.715923,-27.203883,-154.645111,-235.092877,-243.713417,-210.90433,-173.434507,-54.268618,9.234121,46.223329,-44.65175,-77.324635,-57.377944,-50.51579,-81.957585,-66.499514,79.686791,154.187009,152.453582,-9.233694,-73.050408,-45.872153,10.48577,39.014538,12.905752,-22.18367,-28.800858,-35.404623,-0.6794,66.989124,234.458767,266.208063,171.036917,93.158904,-34.230915,-158.497716,-189.429796,-123.046483,-56.450598,61.911696,89.316839,55.688783,4.392749,-16.595293,-76.024315,-96.866789,-68.907939,-27.111829,11.437675,-17.957455,-115.670817,-203.797943,-219.526629,-155.986766,-97.039195,23.404509,70.14138,89.919973,-29.521629,-100.187098,-94.939806,-23.418084,77.498491,94.735903,158.171832,183.365365,116.069755,-13.28632,-12.904973,116.443167,167.772916,195.079284,196.58567,163.229439,93.396677,60.62928,40.514485,59.254583,111.629906,144.501228,166.121842,106.917596,-90.004276,-120.837375,-49.435269,99.05878,133.020058,196.591269,231.140804,176.156679,19.73767,-38.72828,-99.700478,-110.186589,-110.706646,-93.332033,-46.618726,-40.417173,-81.524256,-186.225391,-215.740444,-138.645853,-70.229352,27.458885,55.318666,38.7798,-119.237839,-227.486026,-328.717715,-291.161189,-148.634179,-67.956902,88.824112,123.723961,63.221715,-70.73173,-90.202179,13.04696,85.046912,200.809055,246.823654,296.063726,212.524918,116.253365,10.977808,61.39776,208.326724,228.045672,207.972252,216.435258,237.482575,134.759638,63.263098,29.487255,63.113302,142.090713,167.697206,109.606312,-113.583389,-215.839705,-269.486193,-229.920192,-112.14649,-59.448302,-26.050833,-57.566764,-126.515144,-155.457111,-178.226099,-168.831159,-114.07124,6.258645,23.558302,-33.686918,-111.752556,-137.217173,-128.284906,-89.08867,-14.895271,0.299618,7.473625,5.656448,3.423568,-8.923193,-26.276825,-59.93666,-52.713781,41.089988,85.712544,58.082289,-91.005346,-166.171991,-195.843636,-140.825228,-43.078988,-42.359136,-72.889514,-85.118291,-108.578203,-142.025282,-139.217555,-46.054595,0.239196,49.101223,82.484409,128.383192,21.278562,-58.926803,-114.61348,-77.625106,40.502158,95.721611,152.367342,143.753986,116.688892,108.732965,110.959967,146.304805,168.944686,189.403735,170.069309,86.824977,55.734512,68.216628,114.781737,124.396602,68.0297,26.122065,-30.881197,-48.809379,-32.673279,-51.54178,-103.911568,-156.396242,-128.872715,-54.531036,-55.016004,-109.622121,-123.949165,-141.604843,-187.940597,-183.705291,-167.219559,-160.824636,-90.06265,-52.706195,-88.683455,-139.869649,-101.23429,5.278451,21.902424,-12.244109,-55.44512,-149.745543,-155.645299,-147.150882,-144.462749,-119.998964,-4.520617,55.459735,106.654399,102.77206,84.832376,38.647513,7.424488,-30.84337,-23.429473,29.415973,25.32115,-45.856846,-38.326526,-35.879783,-109.312079,-136.200411,-76.131545,-19.225601,29.061675,4.303109,-89.433068,-96.908327,-48.498101,35.039068,38.540473,43.984442,64.640897,88.739175,46.720776,-3.420386,-50.326696,-11.4136,76.744702,85.987059,88.203229,100.792379,93.179966,-7.053927,-42.203603,-55.095494,-66.594817,-106.816512,-125.695573,-126.777643,-34.949263,5.037261,-0.462353,-12.036964,25.27784,45.94549,28.185518,7.088073,-18.957783,-43.795544,-71.91023,-169.48233,-217.279443,-225.397902,-174.104284,-93.001569,-150.679408,-173.301241,-125.456769,-86.315131,-53.737799,-44.686156,-17.041839,-32.528457,-178.392407,-328.963634,-321.682275,-166.038562,-90.633439,-60.34713,-103.299796,-215.549667,-276.782316,-322.294627,-413.062767,-404.561872,-327.078195,-293.761523,-245.23736,-248.239298,-294.967243,-212.57901,-106.059411,88.649903,132.989684,149.663955,147.705959,109.94026,51.883048,17.721151,-82.090128,-129.731933,-164.856083,-137.316355,-60.623513,-63.485114,-134.587895,-198.812993,-199.432447,-45.742024,82.677487,212.004855,168.047173,-26.202354,-164.626054,-196.280945,-209.028135,-195.56898,-183.247202,-199.588622,-250.087484,-270.321806,-295.493104,-312.340998,-306.964498,-264.345169,-238.244705,-181.964879,-158.766824,-134.652683,-114.762838,-118.105358,-133.609362,-121.673758,-74.60616,-48.382817,-13.04272,-20.565626,-36.78696,1.456582,17.422068,34.468094,47.830536,83.96886,91.687403,48.308137,-53.972807,-109.198207,-168.632141,-142.894668,-4.291047,38.700712,-20.813342,-84.918201:-44.540873,-67.852394,-55.088366,60.792634,120.490485,154.596752,133.544412,59.160251,-31.362385,-82.156106,-95.693188,-63.953837,-42.027577,-29.816322,18.772535,-8.512915,-193.358063,-336.790239,-329.99414,-162.11638,-54.600082,44.013526,14.402389,-106.634417,-159.753729,-139.223793,-82.527575,-89.04332,-112.285085,-75.77987,69.218565,112.486242,52.258876,-60.136136,-69.202737,-16.467478,18.535634,122.242043,158.589553,89.741913,-38.597386,-67.707547,-6.675654,66.361108,172.499793,173.998524,83.22706,10.127125,-133.051534,-193.03058,-180.21582,-98.738492,-45.045095,62.038441,90.704378,53.660483,-59.94744,-122.347219,-154.454123,-99.485851,27.353641,51.655234,30.889491,7.056259,-47.447471,-142.485957,-165.706412,-138.53855,-119.55882,-60.765633,-36.505154,-54.191222,-54.510711,-52.091689,-80.709897,-74.169446,2.049847,48.489317,114.950156,123.902049,100.999152,65.01641,61.877243,89.974826,102.701147,109.769671,110.654496,110.748038,62.544332,9.794586,-75.515067,-76.787735,3.664973,52.400745,45.236377,-20.958478,-149.155388,-179.302045,-150.734112,7.385485,94.464276,195.365871,204.684692,122.706675,-35.502511,-102.526022,-135.00703,-107.380548,-42.088176,-20.010093,-50.510824,-108.975223,-221.064983,-244.020316,-234.512688,-206.570907,-180.79793,-68.04453,-16.161642,-78.371257,-242.064895,-268.114129,-224.502835,-205.993368,-198.063879,-161.68965,-30.26642,-7.889913,-98.458766,-197.075836,-210.040859,-195.749514,-149.081486,59.077972,143.568933,149.247361,41.586349,-38.558386,-137.439672,-101.693724,66.012177,135.823542,214.916894,241.588889,207.891799,47.108437,4.342635,25.040223,45.740309,86.801726,106.979957,61.448412,-139.899176,-237.838622,-261.536483,-203.782993,-117.939412,-103.531762,-77.082845,-63.640917,-65.680193,-113.843813,-133.59421,-124.133536,-88.939659,30.515115,66.605692,20.771727,-48.930358,-57.378522,-36.529504,-23.243276,6.904135,30.169811,68.430192,64.082323,-29.740066,-164.180119,-176.40405,-84.363586,-24.928953,81.157019,104.228206,12.421904,-164.880363,-202.080513,-148.572679,-110.844951,-67.484026,-54.584322,-82.175736,-118.735931,-168.214392,-155.125519,-128.017269,-49.025766,-19.762553,19.020323,43.000896,58.762527,-40.349407,-113.695939,-156.759298,-107.489159,19.678899,61.546429,76.750644,54.557924,18.023252,52.734571,92.342163,172.645332,198.00937,211.983064,188.043019,78.764149,19.357152,27.230556,61.596413,90.49222,152.948454,150.066982,72.602533,26.426714,-29.061758,-66.503728,-91.682907,-82.954301,-40.269965,39.18672,47.04573,-11.998339,-133.984424,-206.492276,-238.011986,-168.284293,-23.729891,9.464243,8.978736,-36.50636,-153.633809,-171.06753,-139.807092,-73.446179,-58.379954,-49.83141,-56.572268,-72.894049,-71.391505,-94.81016,-142.44808,-108.502734,43.49806,94.101152,108.72154,94.381645,26.764464,-49.784749,-54.804706,18.370747,66.268293,93.053607,72.991383,7.383016,-76.930636,-85.036428,4.577786,57.286815,139.096566,180.474113,193.013166,148.312811,58.182618,71.558027,121.559601,196.035678,174.111763,115.013108,124.416632,151.286966,86.69512,25.953814,-3.268103,52.365984,154.511222,167.274643,171.878626,161.947843,41.100452,-109.517363,-110.083071,10.51761,60.659449,31.104168,-32.421373,-124.88947,-116.382329,-99.443703,-31.301391,27.282613,120.90125,123.602476,51.225257,8.547558,-68.435395,-162.269019,-187.183424,-173.486415,-157.536394,-130.172331,-136.766553,-232.824627,-282.054237,-243.604612,-147.936155,-131.99865,-109.020043,-73.974916,-55.577908,-101.721551,-213.001991,-250.42753,-231.310517,-149.982949,-116.413998,-114.62333,-162.06373,-300.826235,-328.285279,-310.258894,-278.876034,-250.806516,-187.357094,-182.350996,-221.918312,-243.002479,-258.836993,-224.921009,-164.792527,20.319723,104.346368,194.860421,189.28689,98.876953,-7.88027,-63.790936,-130.536794,-103.589994,-14.449102,-18.022565,-101.30284,-112.200672,-58.373222,-100.807201,-128.123629,-30.186287,65.823802,170.97302,141.673236,-58.042617,-223.260664,-212.928009,-115.59372,-113.350014,-169.88476,-167.45366,-151.383142,-179.52787,-271.019222,-321.789199,-310.346294,-248.220933,-215.140537,-114.953685,-63.052123,-56.138454,-134.773206,-154.510251,-84.07378,-7.659086,104.799022,105.163072,-4.302311,-80.577917,-161.996399,-98.95479,-46.602331,26.361429,47.698807,87.407139,96.518708,65.916481,-38.837827,-123.486817,-222.032363,-192.659764,-62.509508,-20.888119,-55.642671,-101.315771:9.13927,-47.283595,9.066514,228.291827,312.843102,344.119744,325.499475,256.862296,91.751072,4.055201,-62.119084,-50.430978,-13.586847,24.453283,84.189654,50.617802,-95.401999,-228.451093,-269.36611,-212.243641,-124.199611,53.23984,97.212843,12.113756,-119.81422,-118.753539,-82.688639,-90.668577,-87.049423,-45.49765,63.326112,79.862951,24.344918,-5.995316,1.082925,52.35974,107.901896,220.201368,230.183821,170.276018,175.960076,202.630979,208.165484,197.939909,200.21285,204.959672,172.943092,122.988888,6.625656,-65.292427,-69.280868,-16.571069,18.148185,105.510989,145.557409,127.131975,45.176244,10.772595,-29.342354,-25.781602,-27.141797,-28.84836,41.430841,96.819367,120.363003,-10.999314,-75.063774,-83.038064,-50.591357,-5.348791,18.029297,104.792008,84.453504,-22.451148,-175.083586,-116.174258,75.678965,119.098281,182.701589,226.663841,277.36492,209.705194,161.538968,153.841711,177.783337,229.38336,253.556958,252.956972,233.464391,228.416051,184.23503,153.901135,133.104303,152.433943,207.701656,199.94235,77.821115,-52.730832,-61.138152,62.856066,157.441913,282.766812,290.686141,219.990564,116.768857,55.479202,-45.454908,-47.159786,18.441114,47.393979,29.969721,-18.571669,-123.708539,-175.180573,-166.375569,-86.973981,-62.140726,-77.193964,-76.249546,-71.997024,-204.027522,-305.860125,-400.522153,-358.909566,-193.87474,-103.372815,15.436181,-1.07133,-119.234387,-180.923566,-179.352565,-125.990094,-73.392743,88.402614,165.873681,218.169957,149.535312,82.025501,-18.642783,-0.026196,119.308804,155.882627,151.969354,151.39992,178.746219,112.229401,31.337719,-90.791837,-92.832902,-14.965353,22.753885,16.907293,-80.228918,-148.169072,-292.450723,-326.035854,-275.747526,-216.652796,-109.457721,-93.292188,-141.885007,-197.120711,-199.202195,-123.457469,-65.953848,1.91124,3.611612,-25.312416,-44.681558,-45.944483,-50.709062,-40.044402,50.841176,115.024228,167.598611,132.137307,47.837055,39.443493,44.737557,52.147865,60.229001,110.80059,141.244423,152.862479,77.194815,20.89211,-58.532147,-76.79637,-101.164756,-95.699432,-27.003796,3.708979,-29.775632,-108.850058,-106.735615,-46.998375,-33.236343,-33.189105,-8.733393,57.669516,24.545766,-23.921506,-80.454975,-48.354669,98.471357,152.34465,145.153051,111.504539,69.270006,48.387186,53.576588,157.160751,222.080663,220.154854,150.756818,26.902732,22.692744,39.003168,55.220921,60.838597,94.193074,110.165936,61.250559,-0.656437,-60.608499,-13.849018,6.235367,29.92122,36.364178,44.945785,49.570615,40.975878,17.709671,-2.538939,-63.848113,-97.146036,-135.735682,-117.654594,-18.75873,33.617903,111.502491,76.61628,16.413733,-21.08462,24.053905,95.173473,74.445971,-54.346019,-168.249054,-190.284385,-149.009008,-86.42438,61.195206,117.453503,152.671853,124.301533,6.949608,-59.011059,-38.832557,31.842761,41.226601,31.95603,41.33906,88.262896,104.307891,78.874715,-9.667453,-23.981384,76.498518,155.828204,205.561168,145.228956,-26.963793,-72.722334,-32.580883,82.362314,103.317688,99.251788,125.435715,165.802018,59.849569,-8.997582,-89.709926,-88.106377,6.888158,77.466736,189.765805,214.389903,176.139261,20.809071,-47.347339,-49.872754,-10.502164,12.561437,-26.77047,-134.89757,-100.957464,-47.302495,8.234195,26.773588,101.621694,142.848125,167.603753,139.271311,51.558887,-33.613785,-62.806554,-58.318264,-51.940341,-74.204228,-85.189187,-109.506673,-122.958343,-117.462804,-119.232568,-125.973352,-123.325398,-104.033422,-79.285319,-111.609052,-226.769574,-289.221871,-283.44429,-203.625009,-165.951543,-177.220267,-204.506992,-245.48383,-317.41042,-375.010885,-438.004832,-410.489483,-285.14047,-227.328902,-206.590553,-240.914969,-275.787121,-203.983156,-145.357884,-5.215406,55.663772,137.130237,156.115187,88.350257,-71.221627,-137.826713,-213.568003,-215.250175,-162.503287,-112.555309,-8.162859,-5.092582,-108.169665,-252.775614,-289.301998,-184.385921,-91.76414,-10.346349,-30.668843,-172.523231,-340.731908,-366.056225,-306.018793,-270.982471,-242.656605,-227.582906,-205.954679,-234.432297,-290.92934,-247.5463,-259.873657,-360.946827,-367.639881,-243.931418,-172.95348,-99.741064,-124.423881,-165.175635,-207.314341,-174.329394,-64.893374,-40.817109,-103.824187,-158.688564,-195.247071,-152.717221,-118.893361,-17.812059,32.441189,107.241491,123.980549,72.522224,-80.643356,-161.531706,-207.104691,-172.330693,-124.882003,-136.011633,-178.627775,-198.598469:57.659237,-63.011762,-46.831916,140.772693,218.645933,245.98877,233.412882,165.38099,-26.343654,-105.993043,-52.089297,23.534774,43.323217,29.552715,71.591705,84.149082,-3.106202,-190.942125,-246.395036,-171.233788,-72.359377,98.038539,106.842255,-56.317641,-175.611065,-169.632295,-116.232607,-91.174536,-54.351792,-31.722762,1.87696,-16.797353,-97.284373,-128.56273,-113.300621,-31.565759,32.642579,175.901914,213.544027,171.640352,80.59889,56.067643,94.807636,148.482548,248.881656,289.953061,331.941027,299.131891,125.216521,-82.822403,-147.82585,-87.998605,22.243772,203.315402,206.299851,79.887282,-18.102092,-39.417756,-51.175556,-40.630912,2.825361,37.681097,92.962778,78.005278,-23.489764,-120.649209,-135.61425,-94.820582,-58.489645,38.758197,84.974601,75.980526,-75.326483,-165.174719,-237.294562,-188.360882,3.771129,104.229426,209.647348,190.169676,100.492037,57.231363,69.410349,159.405556,205.943565,266.664511,282.650654,250.194041,162.898027,127.825755,105.49209,119.594949,178.372985,199.36194,149.826263,79.615836,-56.221315,-106.949696,-102.168309,-10.940595,80.541533,264.3295,292.731076,190.521818,-18.636417,-126.743635,-194.922567,-141.802436,-13.291418,22.161686,13.665858,-32.716244,-176.838936,-279.292071,-281.436581,-219.109935,-184.5905,-111.247075,-82.449086,-128.250328,-330.724614,-429.218574,-462.554729,-407.85639,-237.371004,-136.68736,-52.196684,-110.037484,-255.11349,-256.70845,-223.367476,-149.658965,-108.620207,26.599901,85.536437,70.362123,-26.646123,-70.765463,-118.394931,-114.955669,-44.944636,20.122232,126.007203,139.495245,73.690698,-66.411737,-95.540376,-28.508747,20.396141,77.69769,76.174684,-4.254816,-142.164762,-205.856935,-248.204735,-214.174627,-99.123511,-54.006011,-23.722245,-39.844326,-148.338054,-228.965581,-196.279961,-61.308128,-6.90253,65.934274,70.811387,-22.862978,-141.230377,-175.2473,-167.922414,-124.844029,-21.477837,5.359526,3.707272,14.228452,56.736906,-17.14769,-71.058773,-88.100103,-40.612986,99.433423,125.394873,42.930743,-87.849223,-141.486515,-165.215664,-136.774232,-57.89707,-13.277174,13.472049,-34.612889,-184.089643,-258.682688,-246.010254,-168.743373,-128.611697,-51.524267,-17.547961,10.186028,-49.155014,-102.870162,-141.963697,-99.504567,50.656168,125.53271,170.344165,100.803268,-115.620042,-142.298918,-74.265569,53.517816,72.521554,70.799497,64.617822,21.491323,-0.875923,17.896672,90.855212,120.777358,176.507575,211.219773,196.20659,128.097679,-6.900884,-34.859041,-21.475364,19.199818,58.650789,172.926947,210.00287,184.374819,13.399778,-89.513183,-129.184959,-57.191022,86.031056,114.138409,102.395176,69.824818,-14.668349,-36.889335,-24.171462,27.857234,63.045555,91.548343,67.370028,-29.931852,-128.949447,-155.029502,-127.413702,-80.497351,61.178929,142.375879,204.743554,146.143838,-45.372742,-68.137447,8.218417,153.522359,148.847818,41.079765,10.367302,51.416354,143.018292,159.253579,127.406535,127.730934,221.731258,284.943515,327.280556,287.868315,156.666349,67.20337,70.056354,139.941581,168.58427,252.089342,316.573321,339.209021,120.257498,-5.310957,-58.074772,14.447257,172.920114,226.246697,288.624782,286.81263,209.419211,59.594889,-5.704302,-5.880463,54.564748,123.107142,74.838635,-65.224393,-89.093069,-85.297047,-83.29508,-63.390571,47.990578,123.884074,225.233418,230.886413,151.092053,-35.084975,-117.877066,-150.301925,-120.564742,-77.030812,-88.997688,-194.664685,-284.900851,-289.445181,-226.290183,-176.390565,-113.389376,-96.997817,-75.062564,-101.268868,-282.118825,-426.533985,-408.359784,-283.168454,-225.107447,-148.198542,-154.66211,-251.130589,-310.762453,-320.217796,-290.932019,-250.085794,-174.55535,-142.529531,-114.5824,-148.577794,-256.172835,-252.658681,-195.232722,-51.394954,11.568337,113.4305,128.26948,37.499427,-134.752105,-192.778785,-167.812083,-122.960345,-88.764589,-72.467665,30.735325,55.808079,-75.230704,-255.055101,-263.822193,-103.189972,-4.193169,82.739985,65.207333,-42.634574,-167.038245,-207.984394,-205.99664,-183.298887,-151.827734,-126.023341,-42.704713,-32.254355,-149.269585,-293.837494,-303.593224,-208.674082,-143.738109,-52.470044,-41.909361,-54.474416,-111.345227,-152.514519,-121.378409,-50.313047,73.295063,97.63069,36.048619,-23.972024,-67.689278,-33.928872,-19.232734,17.490736,52.474972,148.231647,168.216461,70.907445,-114.518138,-190.842305,-216.728641,-160.152495,-60.62689,-59.131313,-71.066982,-59.433174:31.885299,30.558868,82.959422,270.019759,320.853252,299.096736,297.473177,293.321391,114.797719,10.935638,-36.480619,23.925886,174.484179,226.153939,232.939089,166.852589,-52.986579,-220.208073,-230.007814,-117.901555,-44.415457,82.136034,133.958141,139.553994,-25.914032,-113.735256,-178.382268,-159.642401,-113.26855,-92.786983,-21.108303,-6.548457,-76.926207,-128.794652,-125.137063,-97.053874,-60.441218,69.850154,116.405936,135.301911,153.612626,151.940136,121.408839,110.814867,108.677215,130.828784,213.768026,224.501135,136.27402,3.309525,-39.818783,-12.880525,47.324321,153.687995,160.882189,84.371138,39.118158,69.229912,133.050044,115.331197,3.565253,-31.260641,36.648684,100.164339,134.570894,10.817678,-78.225626,-209.341181,-223.311862,-109.963032,3.17648,184.075209,131.178709,22.35223,-116.499413,-64.619676,169.055258,281.696597,429.752105,419.501117,253.094993,150.765971,156.815342,194.313692,190.756847,180.967274,209.990251,305.971998,325.208235,273.678491,160.880653,175.682371,313.140201,347.788826,252.789079,154.819577,15.497693,54.496193,112.606821,245.088949,302.125439,349.817846,338.635037,266.183638,167.660221,111.033387,-15.226038,-57.547306,-21.608292,41.646405,90.232479,46.891744,-69.587303,-157.647786,-182.458752,-172.570825,-152.403791,-115.903935,-103.253073,-152.614585,-310.760164,-385.469046,-384.501482,-294.675247,-106.379853,-50.732443,37.947203,62.829687,-12.221713,-158.452073,-169.538069,-35.382431,45.707581,173.502891,248.823223,361.064095,243.725851,127.666222,14.419172,69.055793,249.71108,282.591839,220.427979,179.1473,155.548553,100.783796,17.707167,-113.932067,-97.095123,17.447615,38.791898,-38.764126,-149.752538,-201.09336,-314.999391,-337.552911,-223.388096,-125.642247,-25.82693,-41.431277,-103.406224,-110.119077,-90.299563,-30.164822,-15.120424,-44.942063,-59.993565,-27.451474,-17.948874,-60.393198,-136.023244,-109.471743,49.828121,132.445354,245.229353,269.568372,260.003041,144.630866,54.908259,-66.147517,-85.311767,-73.148056,-35.49849,29.582849,-39.964346,-87.122159,-107.012109,-86.745406,-32.907285,4.94366,57.76274,23.442307,-152.736817,-214.517826,-168.880888,-58.264816,-28.833141,-19.297926,-15.637728,-3.525721,-9.09473,-10.596396,-32.517246,-36.18024,63.816427,146.447777,180.789027,125.394998,69.014067,43.676346,9.81722,45.591232,103.672027,133.582546,102.277762,26.15499,-4.479865,-14.644205,-40.150893,-37.716374,-47.280211,-74.264898,-116.331369,-130.014734,-141.520999,-110.317157,-98.270236,-54.362621,-22.753473,-8.417551,-12.553012,24.696598,45.931799,11.595476,-100.090195,-137.474073,-139.074508,-104.218171,-12.004582,19.138871,78.494053,163.188268,182.715258,163.934371,142.164213,121.828148,134.339388,142.604176,35.911492,-31.929601,-63.563765,-19.35284,79.683186,106.630866,159.221288,176.554658,108.011731,-6.226993,-13.680895,46.540257,76.825671,124.835602,133.42329,96.144215,60.251355,27.144222,-105.627666,-138.492205,-38.531107,44.669806,120.979463,86.58057,-70.947696,-157.681537,-137.209629,-20.230391,33.321046,83.134943,95.054605,65.774971,-78.082526,-137.864253,-121.951334,-66.855736,31.731405,70.802118,144.554123,160.153051,147.744625,67.289787,-18.569677,-126.758126,-114.44473,-115.819971,-161.064981,-222.330639,-150.486637,-110.573365,-96.298137,-81.756394,7.666806,53.16682,110.933345,109.366776,23.998668,-76.701005,-95.463775,-41.992811,8.025247,54.152884,33.815939,-43.411622,-57.750566,-48.035606,-63.591851,-73.56318,-61.432383,-48.36617,-33.959608,-69.045333,-265.642465,-416.26812,-383.39621,-162.989909,-90.73062,-119.485436,-167.038031,-255.901457,-319.347297,-345.238841,-360.813814,-329.695923,-256.041789,-246.268374,-274.612183,-305.505083,-348.495547,-285.957382,-204.011141,-4.041527,50.49518,30.029075,8.261636,-26.496811,-120.883768,-181.085093,-235.988933,-221.564842,-175.101653,-135.334949,-27.463507,-25.713238,-174.914298,-350.89656,-391.120146,-326.449827,-243.930195,-116.974146,-106.401181,-189.362733,-332.196032,-383.470674,-411.935015,-397.396513,-350.152976,-319.805621,-258.452709,-242.791711,-225.906679,-244.117257,-253.395311,-182.132464,-121.358283,-42.945837,-33.794391,-49.165446,-45.843381,-32.432136,15.539043,46.468425,88.722569,83.242645,-27.111852,-106.921759,-175.777842,-106.075344,-42.409443,78.759407,110.608913,166.469055,203.170161,162.814915,-17.278909,-90.451716,-155.006898,-150.161562,-125.476682,-127.833506,-190.503372,-243.681822:58.357552,-7.550665,24.699833,201.022288,295.127503,426.553795,448.154398,350.895702,97.03026,-29.028769,-94.874035,-20.583264,137.52355,167.691127,193.153948,186.126948,43.31098,-209.310123,-271.070217,-148.590121,-24.866894,166.042222,198.614287,138.112856,-14.883445,-107.842174,-218.741679,-195.399713,-70.39914,-16.705825,39.549343,23.024314,-125.547178,-252.939396,-235.833975,-56.335361,57.221387,225.000844,243.88716,138.936735,21.902633,10.108782,57.03712,101.324593,195.700872,236.098341,274.406671,242.378733,46.689232,-202.652826,-267.222258,-184.995286,-66.55141,151.239112,184.373793,97.423993,-17.757246,-52.020118,-53.086716,-24.009618,23.953776,47.716267,119.591255,131.19091,50.939407,-81.156403,-132.894326,-157.018856,-118.994072,24.9076,96.576626,130.171627,-41.383561,-165.003333,-291.34556,-244.140698,-6.681607,133.056628,337.332557,338.663357,174.743623,57.141742,59.147282,142.854236,189.984304,229.569739,207.333994,131.097275,152.188867,185.761649,209.490812,202.966389,203.332627,217.308952,222.497555,182.417631,34.825542,-31.160516,-5.79672,136.334212,237.256241,364.22812,344.100729,215.607714,95.653233,8.062078,-152.47446,-135.445528,76.937285,160.986961,126.988848,46.771298,-109.474324,-236.090179,-271.331663,-248.700458,-222.074875,-157.30995,-114.41867,-116.137053,-322.91304,-448.352851,-514.190206,-429.844694,-210.237249,-141.446987,-108.231464,-149.180211,-286.088977,-302.006474,-246.010564,-95.457251,-30.756071,81.982436,131.532025,155.521174,12.969963,-81.050829,-101.105363,-15.532976,142.365842,171.877797,181.4812,177.010987,118.820221,-45.844383,-117.031041,-103.181706,-36.013913,72.048669,75.059313,-5.344851,-182.968577,-279.451533,-332.139953,-271.725545,-103.697369,-51.136679,-32.490446,-48.444134,-111.294261,-242.60285,-296.73587,-234.753503,-130.163915,57.443829,85.923811,-25.286078,-231.139688,-281.942192,-201.996863,-106.507949,53.536299,98.145656,155.793202,156.691094,73.021968,-52.48767,-81.028304,-36.311641,0.620816,84.624824,138.812383,157.617303,-26.302782,-127.788001,-165.750823,-112.667386,-40.392981,-40.035038,-21.261818,-9.616438,-76.958477,-213.136276,-228.012096,-110.418795,-41.729025,28.247186,49.389125,61.255778,-15.757445,-76.617535,-107.4802,-43.502102,131.839697,186.456124,183.037334,121.776735,-46.850064,-124.668081,-114.67815,-23.612443,36.244029,89.357544,58.512092,-26.741909,-31.723212,-32.766641,-60.400607,-57.08443,19.3741,72.830856,94.056887,30.952137,-130.064883,-156.462014,-121.500669,-22.976452,29.865033,156.546448,212.065549,187.761905,-36.875626,-159.704618,-225.005956,-149.651417,35.033487,95.034191,151.889772,147.451539,113.902484,96.15227,93.825187,119.633501,137.751741,160.251225,166.758227,117.938561,-25.399217,-73.406014,-28.721218,38.952194,157.828202,195.599083,207.539375,173.401619,65.71204,-13.856024,-4.640511,117.323496,177.524042,242.564809,262.332861,232.938046,92.902259,31.971126,2.521585,39.662506,215.309704,321.302096,388.990916,321.18884,124.026052,3.948118,-2.177241,95.159296,150.435765,215.754839,235.692987,184.688838,29.575161,-35.468404,-88.255537,-52.680715,145.484479,255.499861,344.665616,313.174429,193.759134,69.289298,13.527342,-19.658784,8.569598,64.167543,46.778525,-70.102461,-135.528612,-131.531715,-88.914059,-48.401412,75.975912,155.925061,254.537471,226.604392,47.790356,-151.572973,-197.375615,-166.751114,-138.849613,-78.926436,-58.210358,-115.583911,-180.470528,-177.988207,-159.401164,-147.773287,-93.368504,-66.61205,-95.387056,-158.047291,-283.129285,-304.715012,-277.174651,-166.641224,-122.791738,-115.372701,-130.219934,-176.911503,-285.327665,-342.618304,-348.0312,-285.985762,-151.525116,-121.309683,-149.025707,-201.954668,-318.606432,-335.266185,-274.502632,7.800186,161.575406,282.48837,234.389906,15.315244,-168.674458,-211.633927,-219.464578,-193.151863,-113.173234,-63.641499,22.682392,16.424994,-113.165734,-304.426304,-365.993414,-279.825866,-162.130562,21.377651,49.247593,-61.580499,-304.266601,-376.302941,-304.856711,-212.266326,-95.605179,-70.918297,-47.677796,-61.439456,-127.337539,-232.4917,-284.042134,-256.683251,-172.873818,-15.294358,22.801676,16.930112,-96.172314,-134.411711,-40.337168,57.431462,184.429739,183.91291,71.919054,-9.422005,-127.841435,-134.443821,-82.099033,85.462503,144.956433,182.840381,171.724488,88.067543,-56.057625,-149.642281,-255.317487,-221.631012,-108.581903,-87.554957,-107.931524,-129.508529:-51.912325,-82.385376,-28.416551,107.049,144.14229,183.14011,208.910696,199.74689,52.370904,-5.978271,20.889521,78.298999,162.320016,181.536936,197.118186,176.202891,51.095722,-120.194327,-187.103968,-190.113267,-114.979245,51.323821,83.002312,70.298516,40.076173,7.027929,-79.922282,-101.737094,-111.330427,-124.207157,-160.29141,-177.342401,-230.432668,-313.597582,-338.926785,-282.263798,-216.236612,-107.660724,-75.255894,-21.546316,26.170916,25.20485,3.655743,8.367122,9.625278,2.006846,54.928342,104.766187,101.801162,-40.674566,-93.386236,-107.537235,-104.298474,-102.071223,-62.139362,62.067386,46.432428,8.065486,33.590848,101.574942,179.188276,143.010974,57.067219,58.081198,52.952153,-73.034488,-146.626661,-177.817883,-127.627068,37.639623,124.596122,234.792666,212.742275,145.321532,-19.172832,-33.265406,166.5164,320.243241,490.175225,445.688962,227.933395,108.599621,79.877185,33.539481,22.331695,30.490567,57.062949,125.533761,106.048144,62.738289,-17.938922,-28.17103,6.686082,15.312936,-42.363114,-102.886194,-235.331916,-249.32324,-184.562078,-8.136002,55.216567,125.51005,141.81246,115.839765,10.394328,-50.94311,-112.765517,-90.185714,25.991029,82.896647,110.074014,65.420523,-50.982111,-145.376891,-188.099035,-199.157766,-188.19872,-229.302644,-262.10165,-297.085484,-324.29905,-358.294379,-430.093474,-411.312595,-256.902316,-174.005754,-64.836739,-36.926572,-31.569215,-87.69714,-102.570002,12.088148,110.302082,226.838942,246.121526,240.032051,157.742541,105.052563,62.293412,94.693353,194.175112,214.911125,194.928074,183.761854,167.650641,49.583633,-44.437619,-165.631343,-167.619541,-98.160721,-61.810923,-63.454413,-130.97054,-153.858326,-159.186072,-140.624365,-63.858505,-13.178901,73.465011,98.074218,114.382587,34.033153,-28.900211,-47.569644,2.010009,55.677779,32.413788,-31.411026,-55.738049,-61.318369,-87.293747,-98.423335,-97.830358,-79.723128,14.407411,55.80521,14.77657,-94.700293,-113.856448,-72.141849,-47.136278,-41.522076,-62.171068,-142.873324,-169.870608,-130.548724,-44.839671,-58.264563,-126.807524,-99.185553,43.957413,65.094398,-50.177531,-162.729194,-155.229583,-37.187554,7.960983,-17.367834,-42.790627,-19.205126,9.476234,-18.366659,-83.025358,-68.658688,3.903642,21.844299,33.595149,33.22346,7.327978,-33.118291,-43.966843,-20.398535,4.88108,24.210985,11.301611,6.5683,57.905989,56.01528,7.65334,5.195304,-10.929774,-58.586355,-154.575714,-168.008874,-145.284844,-104.801923,-82.807664,-50.548472,-45.118977,-39.139144,-16.208368,105.907206,199.196686,169.093583,19.92432,-29.439345,-51.237149,-43.392741,-13.940579,-1.962424,29.367423,18.902143,-20.19842,-19.350042,51.157966,155.322077,126.674333,10.521975,28.113727,56.657746,44.524682,30.70157,55.694913,91.236193,159.18489,157.774466,83.512037,41.174635,40.545409,64.410203,94.20763,173.640519,194.21456,151.737818,59.130484,-4.30287,-154.975004,-187.206066,-83.252849,16.745345,114.248927,65.520434,-78.862583,-54.470636,21.653185,188.017388,235.481771,261.439637,261.933737,202.290571,60.93686,-2.634639,-64.23259,-45.397617,71.738627,130.424356,181.820939,190.433466,238.21828,248.59526,181.537414,-14.149047,-70.397355,-71.593822,-55.402076,-66.504846,-97.125317,-84.701513,-29.094166,-24.756235,-78.15956,-81.097121,25.45932,62.893642,-11.452713,-91.107881,-87.660509,-46.002431,-29.381063,-22.374307,-22.445698,-42.737818,-49.212193,-26.274174,24.188913,30.40064,3.519616,5.707634,58.657217,55.193804,-67.380802,-190.160164,-181.222653,-72.896686,-43.57456,-74.383089,-115.407803,-220.181038,-229.348385,-200.874022,-197.248829,-208.08958,-199.823978,-191.659525,-189.081755,-193.680723,-180.759698,-84.335163,-21.172706,78.433537,104.013742,85.197918,55.925547,15.366984,-18.895565,-58.975911,-150.938095,-161.568458,-112.968212,-73.999333,21.089709,37.082849,-91.201292,-262.742288,-273.38115,-172.996528,-121.898473,-23.844859,40.257181,87.590467,-70.811729,-155.273889,-192.305252,-164.241422,-82.821906,-27.997765,74.042965,89.514164,96.076557,90.009044,41.573647,-74.198312,-76.271802,59.818626,146.894302,234.03401,182.996585,144.014781,125.229021,129.172784,108.03067,89.629117,39.714729,-0.175534,-59.418669,2.8799,53.636209,106.291498,95.783004,37.812499,19.992511,-15.537292,-115.850067,-174.579534,-254.235915,-244.976865,-151.53015,-111.049272,-67.709152,-69.102549:-73.33736,-29.156151,18.274565,136.23829,187.176004,231.845831,242.243007,232.434514,99.037686,11.669471,-72.338144,-50.308338,19.981094,31.551815,25.595818,7.221897,-79.212429,-156.125256,-155.065909,-65.636784,-8.95538,70.017517,93.50269,86.602079,2.06101,-47.771044,-104.72054,-86.798625,-27.569989,-29.514099,-42.355205,-28.751073,9.457655,-27.194407,-81.36178,-100.904926,-38.087999,81.388183,78.89152,22.404186,45.655164,60.632781,95.923978,134.103726,167.12453,138.13515,87.738051,109.218383,194.73443,118.954774,40.547573,19.441569,59.987127,94.798625,97.434341,117.230964,68.246704,20.455991,6.396029,36.816885,42.763305,15.198377,20.195085,72.89965,143.730638,14.876723,-73.875757,-96.58403,-29.939568,114.936217,159.901326,167.962752,79.327824,7.725409,-122.182575,-109.537585,101.683066,227.599435,379.876015,376.846044,242.37188,154.344143,161.611799,194.565972,187.646683,151.239843,156.224764,204.515471,222.020363,207.848126,153.152466,128.924315,116.386548,141.120932,167.993182,115.745769,-27.309545,37.334399,147.853483,343.107817,358.967713,238.189128,167.190407,105.415974,101.120205,68.045013,-46.769131,-69.333471,-6.396759,46.228793,82.221592,41.661376,-52.702897,-107.965972,-150.19495,-219.233501,-222.542208,-188.625773,-171.463982,-191.957735,-250.003547,-271.044212,-307.87814,-314.906922,-248.205823,-158.236835,44.994938,92.230307,71.196951,52.302882,67.346315,133.706817,177.497847,259.300167,286.386408,308.016246,285.115325,240.304206,115.189066,95.374704,166.350572,211.34335,253.29143,223.304486,78.777131,-34.206573,-75.139673,-122.687477,-132.832867,-142.696943,-125.689896,-66.237464,-64.709869,-103.724609,-167.650629,-156.288281,-116.147769,-101.379452,-36.31271,-4.803373,-22.714187,-102.482126,-115.882422,-41.827489,13.802208,82.170708,99.295686,113.947255,81.923005,50.728969,-20.86576,-52.724835,-72.102685,-36.750263,110.955373,173.754572,216.457607,188.516179,140.022615,-1.983841,-45.98674,-27.784016,-18.283452,-78.932056,-94.441797,-66.345776,-24.946889,-7.514928,70.140484,124.321929,170.576433,123.597146,-30.198072,-67.974535,-36.145749,59.039389,91.156595,95.708806,77.82131,19.368553,-37.403821,-54.755309,-97.627534,-121.650948,-127.366571,-104.606811,-29.56199,6.590875,33.165206,-6.045632,-17.642555,49.83748,108.375994,141.918188,97.133157,-13.768969,25.6682,69.344605,60.165184,25.17434,-32.248182,-58.531956,-104.196113,-107.093879,-60.39934,-20.705154,-11.398534,-14.984873,-46.482549,-73.69947,-17.392549,140.543281,201.185714,178.399559,53.040992,-8.576852,-68.369264,-59.321066,-0.185437,15.560741,27.241881,44.36246,48.471529,49.029913,49.917354,84.106741,95.451514,26.444047,-93.233729,-137.353723,-160.68768,-130.762572,-35.45771,3.389472,81.48945,126.679488,153.698311,48.952358,5.735354,28.406497,42.569349,14.261114,13.270583,31.741019,-16.675194,-91.902705,-308.163439,-367.041555,-311.615505,-241.626443,-137.902431,-150.204746,-254.828227,-276.042217,-231.421811,-92.066834,-57.172961,-106.294803,-144.075707,-176.296061,-181.65512,-173.033366,-127.177529,-95.547261,-28.290974,22.658303,178.363996,232.723751,209.623957,85.586691,12.191177,-95.614141,-137.026271,-224.453282,-250.237453,-241.666547,-159.525073,-113.266504,-52.997413,-24.20693,30.511071,45.086593,50.321051,42.517262,7.426873,-52.662128,-71.945553,-37.349538,-13.104552,-19.678836,-25.698897,-10.278082,13.459613,19.289466,-3.278844,-10.259046,18.412939,33.830183,22.293252,-26.970628,-174.134037,-226.815647,-212.262019,-128.180718,-73.56095,-31.578528,-58.727366,-164.183926,-251.696523,-297.662693,-400.193464,-410.03156,-331.88566,-286.42658,-240.477026,-244.965341,-235.549132,-145.246164,-87.554386,18.591162,40.019698,-1.688844,-33.079016,-94.949626,-162.675672,-185.347389,-221.820419,-233.489829,-212.491511,-159.378071,-20.362231,-7.272792,-126.873356,-234.687869,-234.477062,-157.208382,-114.234298,-47.116559,-27.700336,-83.601325,-194.009789,-220.743025,-231.540444,-239.206842,-252.484557,-225.591373,-107.398482,-64.013894,-26.80225,-22.790159,-60.866651,-129.042993,-124.484469,-111.794296,-98.221513,10.224077,59.92825,15.502068,-71.40408,-47.320648,85.884749,114.349411,28.876078,-37.810109,-120.38824,-119.58487,-68.347764,110.736776,174.649923,158.505229,99.268008,-25.88901,-50.566721,-36.042471,-55.65688,-94.806158,-133.590174,-98.933604,-29.977914,-77.461547:-54.426905,-33.637338,62.950386,257.977074,286.94297,256.160473,232.0832,139.214082,13.49813,-26.735368,-13.336734,49.579047,207.127392,248.062942,254.334982,235.058505,134.651626,-13.534953,-74.294097,-135.707649,-120.222775,56.151194,175.048622,225.241259,43.983702,-32.585235,-83.552099,-81.969232,-91.508017,-91.966219,-91.017637,-134.502854,-278.567607,-289.027305,-252.807181,-195.073969,-161.151072,-34.279956,24.427404,61.716796,76.46133,82.20716,77.796423,72.516622,45.260543,40.470407,88.893446,97.191296,-10.000158,-129.26419,-146.577098,-121.128798,-101.600724,-58.200679,-14.074736,74.093218,46.451276,11.717623,-0.22003,25.940363,52.141998,36.448138,22.095413,31.491403,28.974574,-71.873829,-147.102748,-189.390994,-127.897567,64.557178,141.310377,158.53273,13.335032,-78.20212,-167.76787,-109.156879,138.883476,240.472313,304.817203,289.838833,213.244835,88.287893,49.978233,110.775775,159.706039,178.42681,180.606881,190.79844,123.06678,70.148618,5.553028,24.295609,114.932575,146.003386,141.238326,85.106125,-67.823752,-59.966178,13.671901,164.141703,197.618696,203.485402,203.75929,190.033936,94.039128,24.634051,-69.376052,-62.377811,44.495852,100.050449,111.7123,63.147796,-67.598353,-177.517556,-213.682321,-207.222554,-182.004284,-178.790807,-194.503714,-254.95135,-312.788702,-315.978455,-328.239275,-310.573916,-131.10421,-36.178716,-48.814185,-126.696625,-200.75687,-147.856902,-123.402348,-42.719919,22.114959,151.246788,202.738592,219.903232,114.463675,56.618097,13.924055,31.633509,123.0009,187.304676,258.387643,236.655329,128.611124,40.815112,13.596874,13.328698,33.085103,10.928887,-19.329834,-20.576009,-23.14213,-49.34899,-86.153516,-75.479686,-32.351647,-25.347924,-16.984846,2.908589,21.633814,-79.869644,-125.314033,-26.047226,63.557645,34.763643,-63.822874,-140.799151,-64.449279,-85.504219,-211.253919,-208.0434,-1.152728,120.595636,214.090787,187.064695,119.887318,90.111877,57.050332,-33.910867,-67.17697,-49.333492,-4.130953,24.074897,-29.935437,-34.274598,-20.690498,-24.128124,-14.777683,21.997413,98.115349,83.197069,-54.167829,-177.09613,-174.811082,-25.593061,45.716549,33.609936,-15.231221,-67.734899,-17.173095,16.20991,40.351628,49.010865,103.63524,141.184037,153.277772,98.852991,-55.150139,-107.455218,-95.839229,-26.266635,3.557398,-30.371302,-55.28922,24.020243,108.905308,61.601721,-101.669756,-140.074176,-126.720371,-99.254979,-60.339777,-76.444455,-109.16529,-52.776406,-33.745846,-50.458604,-55.420955,12.723597,71.165398,106.117003,32.589625,4.773574,-35.621706,-50.121847,-62.284869,-57.447948,1.099483,38.44015,71.559441,76.241406,72.383303,81.81454,102.862656,88.571064,40.417832,13.801333,77.683988,56.895812,-36.333882,-40.081585,18.407293,39.636337,69.733133,80.145946,50.964209,-37.573067,-60.533693,16.517765,76.031004,89.84419,58.718599,86.886743,167.424129,134.960627,-6.578422,-41.229051,0.201075,51.399104,118.88212,84.959519,-63.258308,-77.477009,-36.463417,33.945929,62.867982,123.205034,130.330551,72.702081,35.953456,27.757158,-31.832693,-47.331575,8.1687,51.220785,134.804084,169.516604,189.69927,98.866681,33.412302,10.590442,49.087293,89.817905,63.742059,-62.929668,-118.71141,-84.893618,-29.826145,-42.068995,-58.303278,-28.366963,55.860691,57.494501,-39.19392,-145.044954,-170.4781,-157.03626,-115.951996,58.390078,147.968837,133.936863,-49.730272,-99.052885,-48.653712,7.714863,35.118539,0.610626,-54.460623,-77.963277,-172.720985,-222.549761,-183.079977,-26.356643,13.67126,-61.82332,-123.641108,-199.624046,-228.866269,-248.317883,-304.510824,-304.994348,-218.08669,-158.578879,-82.492563,-91.503487,-160.600124,-160.202686,-112.252862,41.828313,91.747824,58.058392,4.059102,-79.44056,-105.635794,-125.156289,-173.391321,-182.649336,-178.071184,-151.794104,-46.097728,-30.014102,-168.349083,-389.977029,-454.7572,-372.119631,-231.605869,38.528744,71.001772,-61.248531,-187.205429,-201.247856,-200.791942,-201.631692,-178.353077,-149.067552,-89.628164,-63.959605,7.362724,6.552118,-51.130726,-129.774545,-106.024569,-10.633929,30.313206,64.11265,63.547961,84.156148,135.235977,141.89693,128.289952,118.015884,61.687889,5.661656,-65.906876,-25.872284,-16.150228,-15.428182,2.796211,61.431287,77.289529,-24.896202,-248.019442,-296.189982,-199.785611,-118.037164,-94.158399,-141.2036,-155.292056,-114.982904:right
-152.888313,-188.18791,-179.369704,-113.032234,-80.272311,0.062751,43.517785,13.366585,-171.225499,-239.535885,-247.464833,-197.442089,-52.442722,-3.766813,-35.106219,-95.362524,-164.131305,-102.555638,-65.585087,-26.197777,-4.138748,59.318209,64.39243,-26.385364,-70.203768,-32.740853,37.975862,37.821898,43.102609,82.327963,186.467587,206.240885,160.395349,71.080048,63.444494,201.934117,290.477028,346.285973,323.052075,231.924525,90.294903,8.356752,-84.685359,-58.1868,34.337738,26.842588,-66.724324,-87.297285,-25.827847,27.140554,19.581194,-27.28117,-60.481818,-54.897163,13.515482,134.860104,72.201845,-7.854113,-126.213896,-126.000822,-59.270741,-23.997033,49.851427,87.987905,139.641233,61.132066,-28.771009,-112.751917,-71.017339,71.798176,127.910873,148.893882,51.723141,-9.353139,-31.527366,36.853815,188.801121,195.309083,100.692142,63.995472,44.942334,-30.314375,-77.30976,-29.475101,49.747912,101.809843,50.154731,-75.963269,-141.126301,-176.290298,-219.197619,-179.491112,-5.984424,62.077423,52.89921,8.819405,-22.754759,-54.552695,-81.104134,-50.162839,-5.785902,67.32733,120.188813,268.372355,311.869278,274.007758,150.583861,116.821952,133.817779,141.269933,95.627565,70.508807,83.197217,92.162958,85.09409,117.583851,154.101164,193.782408,176.521498,83.64036,38.23126,38.228245,62.343341,108.205714,177.557546,133.257459,-52.786835,-118.508585,-97.6022,-1.972195,-24.572641,-164.033776,-186.004139,-80.959606,-31.292404,-39.361278,-44.286249,-31.815113,-48.771062,-60.566017,-17.321271,32.584136,145.330554,191.746847,241.137779,242.930215,245.229672,263.465773,269.376411,303.932899,321.532726,271.958854,211.723791,209.051075,199.909898,196.546258,241.209976,274.364034,260.047853,214.187936,172.607275,198.707334,176.415812,56.211021,17.220801,48.223885,64.040752,19.671705,-12.711519,-37.929234,-177.997345,-231.728826,-89.921317,71.517867,212.073054,135.499789,-40.270962,-0.67275,63.250178,171.698753,187.884336,148.330904,106.57572,-8.824922,-103.698175,-152.118664,-234.364934,-227.354253,-121.505795,-62.384542,-54.4984,-125.751458,-237.384679,-188.862688,-166.994919,-137.144745,-120.188492,-147.956208,-186.476526,-224.306638,-205.479143,-195.565261,-161.213065,-126.877217,-38.016131,5.717892,84.636925,126.532507,150.602994,-59.396843,-180.311193,-207.777858,-145.415966,-23.382487,25.87211,41.487882,-16.607606,-17.316384,10.155032,16.390919,30.391353,45.179073,55.015159,29.678439,-82.757917,-203.625594,-228.886569,-168.391457,-116.135312,-24.844727,41.011668,178.295417,136.657887,59.141875,-53.328953,-76.215525,-82.522915,-45.786602,63.256992,73.876168,20.989146,3.909044,-22.788941,-159.944513,-218.812829,-235.251944,-240.352712,-344.874883,-459.914304,-478.397115,-434.091575,-380.796732,-344.892406,-407.651274,-552.828077,-545.608454,-413.965266,-421.346234,-476.49332,-515.082218,-482.915094,-388.133542,-362.172463,-389.097578,-407.044583,-390.932467,-313.232651,-249.381591,-120.933265,-63.825487,2.686337,-18.6669,-111.600465,-145.350163,-132.234,-51.988032,-7.568792,60.169136,79.934559,59.405849,-23.100964,-67.55336,-113.352894,-110.069606,-78.253549,-48.313582,43.079971,65.288179,13.268778,13.0924,68.148321,119.329215,72.006997,-14.646387,-9.320817,43.428705,100.489299,109.9103,99.709379,89.219254,33.274704,-1.856719,-47.338678,-56.851836,-43.602617,-28.267249,-44.539999,-138.537282,-188.888168,-185.262187,-151.894593,-197.104802,-391.527309,-504.976273,-633.105486,-600.848414,-450.098531,-400.426293,-409.599513,-449.474598,-503.204963,-514.464998,-504.697512,-424.465493,-376.943478,-303.612078,-279.21323,-289.40941,-297.597599,-281.667295,-285.423382,-284.445964,-210.552913,-167.285949,-121.391506,-108.307568,-67.935496,-51.625871,-68.577012,-58.061623,-7.848127,95.133808,115.05097,111.086928,75.761833,16.488312,-107.707626,-98.318851,47.739564,135.768673,274.49698,288.907142,217.524453,189.00091,221.584843,342.557057,393.588507,414.133733,381.164092,244.868975,148.416816,149.521316,157.476932,144.490356,131.788759,133.285216,124.365221,107.047373,27.452341,-37.684931,-26.254016,11.655127,0.815948,-26.939186,-35.876096,-100.123251,-140.871937,-127.680449,-108.749488,-117.264891,-108.83778,-83.865135,-66.663694,-80.893805,-92.341534,-88.738988,-77.106165,2.318111,30.478641,-4.004803,-33.056698,-51.298731,16.650576,67.780406,151.624968,178.46248,181.142279,176.866437,207.155314,228.63911:-172.074777,-171.827076,-148.514244,-67.542083,-15.523258,99.401085,126.524884,33.024325,-164.757024,-205.420418,-70.112848,41.979486,153.104498,142.052976,60.917144,8.07278,-71.347985,-19.743279,42.930209,111.469709,102.771666,60.868608,37.56252,-23.969384,-31.873099,-10.637994,-36.851403,-76.273027,-91.569263,-64.877993,38.832927,105.05994,170.559649,76.968846,28.768365,72.450035,154.639553,278.687306,273.150205,155.768413,-31.484849,-111.027584,-132.869587,-84.313429,27.22248,61.502016,64.982145,31.289107,-82.020627,-159.282111,-176.634044,-180.047874,-148.009831,-19.697962,13.997702,-69.496817,-133.446333,-129.010954,-146.872839,-147.39847,-26.273341,55.129264,58.167816,7.390595,6.604774,52.087435,51.396907,68.068891,83.726732,103.805631,110.201097,87.57293,-5.92225,-43.278062,7.287987,83.85553,218.547175,258.415287,310.932355,302.351906,160.193643,-16.123028,-44.711629,28.313564,74.726011,92.418585,77.173743,47.715034,-36.867426,-111.798236,-199.620416,-164.638417,16.364167,103.296332,143.792825,111.149965,64.519508,19.981914,-9.162965,8.695193,64.247685,187.387652,228.272199,288.178713,301.74989,257.239785,164.858503,178.757615,267.909441,273.295872,173.29592,111.252549,28.01393,15.524656,57.379588,157.24591,153.890947,115.895624,137.764243,179.440363,56.467678,-28.134597,-57.201108,-11.15976,11.286143,-27.360682,-90.880971,-103.992633,-127.779283,-146.282327,-144.848244,-123.734705,-115.289288,-134.946749,-167.512833,-220.932117,-185.078725,-161.92401,-145.057109,-119.849181,-16.230378,35.206108,84.77649,82.840624,101.413383,192.463689,232.280334,257.96989,259.433684,250.751814,223.798436,167.516567,189.461465,195.011335,135.554392,114.034508,180.707508,244.138406,293.336504,252.069066,99.612025,-21.936628,-37.072645,17.274159,41.925708,14.71934,-19.09025,-80.181803,-120.606569,-139.111223,-161.149178,-142.56387,-27.924459,33.427137,35.709944,-21.230839,-112.276394,-79.990984,-34.890734,53.051314,92.424181,161.181014,152.886929,-26.894366,-203.300818,-206.103955,-114.542797,-67.503262,-5.529124,13.639735,52.271645,69.549215,45.790325,-33.929903,-34.798899,45.756717,60.71812,-35.707978,-105.75043,-168.912257,-122.928613,-104.536566,-118.421282,-115.511073,-4.276521,58.512044,20.078885,-57.226425,-140.629396,-183.580654,-227.359403,-243.7222,-198.545889,-84.522997,-55.903795,-105.024788,-209.162766,-214.813805,-107.026504,-62.152588,-78.095395,-87.24144,-90.447493,-126.257368,-222.318525,-272.2448,-277.539169,-237.293589,-197.686304,-72.087219,-4.265245,34.464284,-61.307909,-115.414511,-126.34077,-78.383576,26.573121,55.160915,53.766928,12.988224,-107.367233,-159.256767,-151.542212,-64.655631,-18.807242,-53.071626,-131.349431,-290.8692,-341.209196,-348.294482,-373.887728,-352.449306,-228.812887,-199.505779,-274.775143,-321.8023,-327.354268,-311.997336,-319.532333,-331.18044,-335.051198,-305.044943,-284.207628,-366.447441,-532.082104,-550.120575,-429.997569,-353.359685,-271.58193,-234.80527,-146.309011,-140.128498,-226.720017,-318.674667,-306.486024,-147.911564,-53.415827,71.045003,100.16124,61.149826,-101.407328,-162.148489,-170.952496,-155.729573,-110.421031,-57.818317,64.496494,84.26348,21.527254,-3.110103,41.492977,157.499319,187.18465,186.233528,159.353794,79.158479,71.554617,82.702401,91.529128,97.916178,94.249473,69.035082,1.191593,-4.870028,-2.530022,-110.375244,-163.369578,-188.840985,-179.662759,-131.042541,-106.900524,-187.562652,-397.595751,-463.701826,-451.876098,-394.869433,-272.462318,-245.5877,-279.993328,-330.054467,-455.905476,-535.86107,-521.177659,-389.014401,-321.11265,-240.677485,-212.72406,-200.78067,-259.252627,-289.803907,-321.526873,-289.589605,-99.76466,-10.91337,8.385649,-26.490809,-61.851111,-121.518491,-150.119737,-70.699122,9.690092,102.887044,107.13203,42.349569,-77.074072,-107.613744,-59.313756,13.987013,205.838504,275.355677,286.380046,248.790659,198.587215,263.463341,309.245117,362.88012,390.033829,444.480247,414.650239,216.028313,116.233762,143.818645,197.474685,181.48364,152.718924,180.8119,214.689764,180.64211,108.212251,92.986672,98.871656,174.564237,220.694658,202.986778,153.194629,92.022494,58.427494,34.22695,18.93067,26.877456,47.982415,64.785927,73.067507,55.855369,3.374941,-91.484648,-130.550237,-75.519458,8.719608,129.784719,131.798822,88.402194,73.199812,67.440548,106.271177,172.077946,296.145396,312.772197,293.228856,293.026649:-239.802176,-229.586639,-205.047062,-91.089856,-23.652761,74.379372,83.18836,-1.207886,-127.671071,-154.335454,-52.279589,41.709813,171.583433,201.780223,184.810192,130.892806,14.912603,1.256685,27.361776,85.743636,114.093011,138.509136,119.541904,51.957199,-31.075696,-65.267402,-78.78108,-54.727541,18.450661,40.159635,48.943578,54.883577,51.585572,1.519497,-5.078039,65.748954,119.977663,160.29713,112.590638,-40.226994,-145.865195,-194.270134,-242.783263,-215.060435,-89.063255,-40.679887,-72.904238,-123.463525,-161.899335,-181.707525,-206.655623,-218.666717,-207.801063,-189.717213,-197.926372,-260.13742,-290.98505,-279.435171,-232.847704,-199.699512,-67.810214,8.154135,31.76127,5.486238,5.466686,-67.940153,-122.451494,-84.90802,-10.661247,132.025257,175.726589,160.23652,88.474621,74.401054,111.288095,160.514979,283.122805,329.570332,347.008093,310.29858,180.193277,25.6137,-38.812455,-38.201604,35.750647,206.733509,238.351993,144.253341,33.681678,15.482802,5.203922,9.188234,61.983576,115.563709,184.269056,160.270292,61.686251,16.1071,11.622296,23.869852,56.779294,192.198775,245.664905,220.006953,90.820251,12.479424,-79.680686,-41.545961,117.463309,150.764078,86.058536,42.655889,31.480121,36.071344,31.382279,77.139011,105.383727,104.917687,100.873118,116.414477,63.095249,0.868874,-52.837254,-13.730303,49.9615,23.464334,-79.219579,-115.610901,-181.459399,-225.517536,-200.211717,-130.970473,-120.496484,-103.801725,-99.581868,-132.94612,-177.461302,-171.616324,-81.062311,-35.491712,21.409134,59.141901,110.982567,96.001942,35.344412,47.174625,92.397286,178.706908,181.839637,139.160987,115.447154,66.289832,26.996722,10.506472,13.026463,30.361775,88.709713,128.602108,162.342457,147.667861,85.371579,38.705998,50.935316,80.561643,70.635976,61.289899,54.624186,-36.117852,-165.449525,-199.357461,-148.651028,-82.948166,24.882812,42.493988,-4.007376,-50.076475,-128.346224,-164.113698,-149.181883,-45.634956,5.297953,26.118189,-2.410898,-123.088397,-262.32071,-299.561288,-260.86025,-195.270406,-50.541735,12.843733,88.608975,77.977574,-9.326925,-69.996847,-58.312517,49.349132,102.814869,109.114883,70.452646,14.904351,1.03906,-25.422097,-63.360502,-49.942545,10.076764,35.5175,41.674464,29.507854,-21.873701,-202.620836,-308.206791,-368.047515,-312.353879,-169.047013,-162.746077,-283.218613,-292.695606,-245.314153,-187.328512,-183.106814,-172.976137,-158.465793,-158.428648,-183.13302,-249.321635,-305.818351,-297.289727,-177.519777,-107.977447,-44.213048,-39.179415,2.797719,-11.114887,-88.064145,-191.721792,-155.505088,-22.974459,18.709876,48.796277,35.542954,-40.766736,-85.500666,-77.420407,-52.351549,-62.971469,-91.879626,-85.433549,-65.207086,-90.653894,-110.71388,-117.931947,-97.499631,-36.763644,-26.480923,-69.938208,-94.161089,-102.080963,-136.682545,-163.008492,-182.758526,-189.674143,-246.484824,-285.484184,-295.246258,-290.557154,-329.297421,-381.230563,-359.941088,-257.770534,-200.086154,-121.511313,-117.630294,-189.795814,-247.849339,-223.511386,-68.390779,27.256097,130.546663,107.976402,-45.847763,-191.74731,-210.937951,-136.71269,-95.028104,-75.088462,-61.782071,-14.382222,-28.459892,-87.99501,14.63114,100.782258,169.475983,131.815858,17.452539,-10.966915,-4.020756,-15.006918,-35.903702,-4.954995,50.803498,126.371095,123.947821,89.969616,85.954532,83.262963,3.481624,-46.513856,-112.291893,-128.705261,-133.609211,-149.163797,-284.216853,-415.606423,-423.807368,-384.747271,-357.953159,-241.845962,-172.746207,-169.017686,-242.249716,-424.160334,-492.177205,-456.77155,-301.811625,-217.627632,-92.121119,-60.743316,-70.85561,-149.508248,-183.357004,-172.971951,-116.106388,59.488996,125.932091,98.510717,17.161019,-115.390593,-105.41685,-63.389874,66.346146,114.059863,124.468542,114.976466,70.746203,-41.947004,-92.794971,-97.763559,-42.65685,107.262768,166.486456,233.812707,237.355542,193.95574,168.138219,195.646039,278.994313,290.134494,261.816167,242.75555,166.811667,57.069024,29.605573,41.233295,63.17325,122.432142,155.108438,186.010609,165.882156,88.040744,74.796636,100.713783,195.834629,247.702279,303.565165,290.021632,204.303447,150.325197,128.645956,79.848039,78.045243,143.183986,190.457943,200.744692,147.576592,18.834282,-45.186065,-22.869414,120.641358,181.298996,172.580233,122.820364,71.503074,143.195121,182.110546,216.000349,224.05961,246.567681,260.436628,305.708242,337.890139:-358.6484,-402.81408,-375.312728,-228.434691,-170.253427,-137.105751,-129.65403,-167.287922,-348.594659,-423.063425,-369.609066,-270.585444,-106.937337,-68.09321,-82.57084,-126.258096,-161.1301,-94.14176,-75.480066,-75.857897,-50.698184,71.387599,121.427411,86.646392,-28.528141,-33.372701,63.763461,117.95904,179.784159,188.548309,159.864307,128.205132,82.33237,49.687001,43.014848,124.949493,196.245995,267.35393,241.775964,114.446662,-55.196697,-147.790512,-211.226957,-152.478633,-46.410102,-65.80575,-169.719166,-198.474634,-192.212301,-195.709783,-218.51668,-254.101269,-238.953102,-132.078204,-80.28359,-55.849236,-68.027236,-74.299409,-73.865153,-40.070352,100.564299,161.039418,163.101251,130.511879,98.477302,18.986311,-47.584053,-71.970786,-17.685661,115.895233,157.991865,132.497006,71.614847,75.033628,116.278505,153.164882,258.002749,298.253596,264.214372,171.131202,-55.528625,-129.740374,-105.515199,14.322755,94.602017,229.096451,240.011127,133.088112,36.841556,14.838961,8.250682,37.622266,135.265887,172.09565,175.044235,163.659656,168.913239,105.960172,59.344502,40.955275,51.281952,66.405129,92.518087,176.81824,187.572004,144.92009,47.485346,53.620655,153.712141,171.575461,80.888277,32.659346,82.367648,188.912584,185.08184,127.352312,123.596481,170.791981,200.344256,219.592415,133.078394,64.997446,25.951026,76.420238,132.686724,88.791789,-13.824462,-25.765056,-7.366578,1.029056,6.93096,16.790863,1.667157,-41.769023,-50.881515,-60.277895,-21.297802,16.51751,24.084584,-5.065051,-2.810174,45.061255,136.887814,143.779984,107.896531,65.906926,52.997331,84.335085,115.084534,174.475332,213.132381,266.140708,228.403185,197.11612,198.471888,231.049832,302.012285,336.893238,362.631186,333.354642,251.046448,187.792427,160.902319,163.260614,189.53535,221.061499,215.811378,162.90716,79.164048,34.171554,-31.630981,-21.169437,99.154368,154.588408,107.921335,19.548003,-87.812931,-37.545595,-8.203964,1.488578,-4.43802,20.939057,35.695443,-70.421366,-300.556784,-357.029487,-247.466536,-145.410854,-48.228379,-54.606539,-120.849064,-161.323889,-180.822305,-143.888504,-116.540734,-17.554643,6.211767,-76.776438,-129.483031,-145.637563,-107.179835,-105.720598,-114.342943,-103.469664,-51.011252,-19.684027,4.887755,-13.838439,-73.176559,-172.382051,-233.468276,-238.127729,-159.319469,-3.466459,-4.323295,-133.169031,-156.726483,-115.364882,-53.581957,-39.659902,-9.763928,8.993576,-8.781271,-63.231868,-165.510363,-163.125721,-150.092312,-111.879277,-75.61252,-16.763229,7.10863,76.182994,59.509125,-7.119499,-145.747153,-164.58727,-104.399794,-54.915402,24.754455,32.038232,-8.023638,-71.722894,-97.411822,-102.475588,-100.306984,-144.242165,-183.974993,-248.903856,-268.525623,-291.748961,-339.138043,-315.248211,-234.086852,-236.278404,-291.580682,-304.504482,-308.247771,-324.9506,-331.86831,-358.831977,-373.115082,-316.343948,-269.842649,-314.971271,-440.965008,-444.086236,-333.858622,-270.836696,-211.83235,-206.547045,-217.881373,-237.065139,-256.436961,-227.783914,-212.56361,-150.206549,-80.997613,83.870364,113.849608,1.32563,-148.969754,-179.973837,-200.355468,-206.588972,-182.799342,-156.530845,-138.908336,-146.700754,-120.114564,-75.267975,-63.772369,-49.366119,-62.044582,-86.347775,-72.39471,-42.913777,-66.208993,-67.57663,13.215439,74.177097,120.818361,80.909812,-40.342191,-49.603182,48.912417,27.818485,-51.147448,-184.25943,-205.877245,-180.256216,-166.273454,-224.863512,-360.218698,-427.991139,-510.725779,-507.757861,-437.137326,-389.857009,-358.635727,-392.509569,-461.549934,-469.791268,-455.07629,-367.950771,-319.804421,-282.972736,-288.465507,-282.588221,-249.808822,-265.706115,-327.324838,-293.297924,-82.418788,-6.150534,-28.138802,-79.954377,-130.56316,-80.914126,-43.512341,37.639267,74.927136,85.650648,58.431905,22.615234,21.638262,0.745349,-61.947075,-64.404676,47.815426,151.140801,309.573894,309.995974,212.021699,204.917888,252.817589,326.270981,326.931068,292.146237,258.80686,148.882002,73.880884,60.592647,43.336899,43.523765,78.230493,105.594986,122.78407,95.787685,-14.767171,-122.194421,-118.119269,9.087466,59.45383,48.136166,18.074678,-17.027894,-25.488388,-40.783449,-81.705079,-83.410345,-40.303094,-9.295625,19.744818,1.155165,-65.013969,-81.996761,-59.536522,42.474507,85.772725,109.300382,103.098605,64.447089,83.943569,120.48043,161.026657,180.637608,271.125481,319.2151,342.231574,323.123002:-208.01316,-249.225249,-257.88821,-176.079611,-101.744075,-0.094681,5.170171,-49.977145,-147.50717,-193.249749,-180.407884,-100.83413,99.448898,157.736206,125.393033,69.069547,16.059599,31.873644,35.443862,89.295497,145.691415,203.862907,173.541919,68.71699,39.162733,59.749391,159.130314,211.96305,243.71051,222.168967,153.722441,116.085766,12.966817,-89.102706,-100.054275,-16.490133,52.308888,134.392518,109.374546,-54.600053,-214.368051,-265.283669,-298.949795,-277.000489,-178.817799,-141.595909,-195.098483,-259.15822,-316.363462,-318.884257,-326.362062,-262.480597,-184.019719,-49.95429,-35.983804,-89.403445,-124.388547,-119.786656,-58.073849,0.96473,134.732518,186.564403,189.655004,138.494396,-5.028604,-141.654624,-164.143133,-78.832864,0.309109,154.032169,192.858878,153.02638,43.337777,-5.383181,17.422312,96.606689,266.728148,308.393253,231.727862,129.73273,-67.72192,-175.965503,-182.223845,-47.452764,74.869738,272.399727,280.606037,132.403943,14.013442,0.588019,39.382352,72.659414,87.766898,99.678023,207.39107,240.671359,117.894133,-108.401157,-148.357508,-57.813256,1.379067,63.021711,84.638169,111.324232,40.37242,-17.085345,-39.807654,22.212979,161.663728,172.443965,101.041633,75.50189,66.022713,16.025952,-6.343226,41.469004,102.586401,193.555054,202.560874,159.742285,60.237332,25.829003,70.033182,116.664539,151.424606,149.492676,117.776061,77.22179,-11.521846,-56.081318,-46.07941,2.094847,9.993747,-2.481812,-17.006499,-28.715754,26.278276,48.124938,64.715329,66.379014,60.582108,68.619114,77.217613,63.673959,28.030022,7.097488,11.281451,27.007411,40.707684,140.47263,201.020789,238.72859,150.389692,68.789759,-16.544314,18.511106,147.812522,192.330598,200.621531,180.475688,150.467893,155.239425,162.643655,181.109218,193.717173,219.207724,220.247957,158.003561,20.335771,-55.153784,-123.908877,-96.544647,31.995788,106.385616,155.218389,90.201414,-89.036944,-107.631212,-68.36843,-14.786926,-0.332957,55.262463,63.546905,-56.608499,-236.2549,-296.368952,-297.313205,-240.686545,-110.316078,-57.815203,2.517238,-13.116173,-98.679923,-77.146985,-19.486709,83.741983,94.677103,33.528674,0.237343,-2.904691,-16.548573,-63.664616,-94.933365,-37.898874,80.049084,91.392501,35.282979,-8.878927,-69.373434,-197.091382,-302.879696,-353.822125,-247.52938,15.659965,54.163512,-75.456886,-197.388831,-203.00901,-133.051758,-96.075756,-107.814834,-140.775972,-159.357548,-138.506187,-134.254814,-234.932172,-256.66119,-124.866283,-27.551564,84.293717,105.343848,76.622518,-38.08608,-88.467255,-113.723881,-99.214844,-42.880479,1.660988,47.118575,24.336477,-9.18779,-10.375848,-28.923544,-34.169018,-14.364868,-10.003086,-34.396688,-100.067051,-136.471847,-150.367067,-168.729092,-141.508063,-53.770636,-33.52679,-33.665564,-45.35854,-80.164165,-105.146645,-135.42629,-247.895914,-274.709717,-167.772476,-85.622678,-59.392056,-201.666691,-255.514211,-225.99113,-175.110597,-114.436319,-94.488943,-43.619038,-43.043871,-148.568789,-267.672925,-249.114419,-63.696184,37.791519,134.860372,116.2932,-24.14215,-159.600132,-172.953791,-123.062536,-111.21793,-144.422154,-157.098365,-136.846975,-124.417626,-164.266101,-234.878674,-218.376391,-95.009425,-41.336254,-12.730424,-28.158226,-56.223598,-73.262673,-87.701328,-52.186907,-9.574196,28.783394,39.07027,71.209113,73.24386,23.705561,-113.968789,-188.770815,-254.651586,-244.663084,-179.059611,-167.879577,-280.810025,-451.089047,-504.222785,-514.614232,-463.881831,-296.379883,-242.701271,-304.661776,-383.268658,-479.068753,-484.359786,-475.173598,-391.228963,-304.97543,-189.391661,-201.803009,-234.156121,-222.618452,-246.795841,-265.848393,-210.693836,-70.280156,-39.811024,-43.822506,-64.355035,-137.198859,-204.234977,-206.47964,-103.502309,-13.57688,100.650854,84.71007,3.280673,-47.062592,-96.664979,-177.120529,-151.377558,22.590831,133.818248,256.90073,240.926833,168.813695,134.378101,124.997634,122.265823,135.622597,154.976854,113.618423,-53.989768,-77.213812,-27.641024,12.952531,-2.285569,13.17456,49.260557,69.44622,29.841612,-66.923354,-66.249191,-31.595224,71.866702,115.30935,155.901855,155.342924,112.335427,37.624835,2.327398,-15.893231,2.300922,66.766119,113.349396,175.467316,150.284171,-0.555678,-87.3898,-59.435494,49.26733,90.343641,151.355823,169.251838,149.526286,121.513189,127.680285,173.474004,214.114503,297.625055,308.881685,267.026456,244.039633:-165.322909,-202.611742,-187.752396,-85.166143,-45.999499,-49.21657,-65.972854,-121.623811,-213.912227,-250.70708,-222.85064,-155.77642,-57.550967,-68.149373,-150.132824,-188.448048,-208.811585,-129.884102,-86.573871,-26.633704,6.338119,76.303437,92.704069,72.414796,59.932528,71.774977,71.126711,51.331494,46.348232,84.621853,148.665366,133.349751,90.734641,92.589529,105.803524,218.990586,289.033652,310.829757,248.503162,48.351891,-90.70154,-130.003699,-157.010872,-111.936918,10.47457,-3.391223,-195.85564,-274.483345,-206.700513,-51.063491,-38.654634,-81.112302,-97.65195,-64.603438,7.075227,152.08927,101.162694,33.72106,-16.521927,19.121194,99.683167,101.584297,62.375595,47.924414,35.277203,-51.406222,-117.05222,-134.463992,-81.491222,17.865124,32.858794,41.666812,50.285121,17.360416,-57.318456,-39.414081,48.958821,52.245033,-35.994394,-79.401793,-91.84763,-121.797918,-166.276094,-147.060983,-45.033871,187.919398,218.502505,51.349738,-143.958055,-161.29917,-46.608406,34.957166,103.287047,80.657414,-11.785236,-40.689013,-12.133026,-46.003412,-89.229211,-70.282441,-25.188947,34.671689,49.356258,91.323429,138.487307,95.687163,-87.082422,-108.441469,29.286522,80.660414,23.913996,-27.242964,-24.478147,58.650448,89.805933,146.234704,165.395552,158.270546,154.767976,171.199756,154.804075,124.735556,108.814153,140.778765,191.326298,188.07071,129.774452,73.481277,6.449079,68.960551,80.991925,21.483777,-5.227287,-14.792646,-25.252729,-65.172494,-18.173767,20.136381,45.377134,30.533193,-8.547374,5.822989,98.667183,132.689464,175.635504,223.592611,229.049534,233.892537,246.248829,238.335019,205.815953,142.550143,93.762154,81.640436,181.5727,268.045059,343.924342,336.291977,309.815946,281.925015,237.700757,254.599031,246.488737,234.346189,266.572724,344.243271,347.121815,253.040889,77.067821,-3.218003,-74.589161,-46.707787,93.94096,163.400471,202.664455,151.699535,21.983593,51.650248,110.732149,205.400627,216.823134,201.814376,192.30695,122.624991,-34.821241,-109.323017,-192.175695,-196.641167,-154.724745,-134.509174,-153.149505,-191.533731,-252.187861,-259.91366,-257.426157,-198.707934,-147.522746,-109.252498,-132.240112,-172.915235,-142.320713,-105.016258,-57.17359,-73.481463,-86.642008,-33.922222,115.735548,152.089277,105.72155,-59.216143,-137.413707,-108.615532,-8.749513,150.639911,165.700198,111.007581,54.694014,50.749149,112.606084,171.80071,236.253007,221.703067,157.778116,104.931251,-20.497197,-61.909733,-44.913076,89.804245,172.344216,194.986373,153.479566,121.738479,150.578319,150.421717,79.822405,17.83084,-65.587005,-47.577043,50.153739,76.18096,47.557165,-30.725039,-42.758832,-2.128378,-4.170799,-101.507795,-162.070748,-259.561395,-293.81943,-298.496977,-299.97439,-270.862369,-241.9802,-295.68627,-407.163985,-389.275652,-245.503873,-191.670432,-224.188735,-328.122582,-365.860742,-353.167262,-324.918301,-294.366757,-224.297815,-174.437451,-122.0956,-102.006396,-5.708617,47.852269,82.792071,65.039471,8.184258,-34.799296,-22.58665,106.604089,180.16932,196.388731,144.769169,46.445894,-13.388016,-53.881562,-118.378807,-101.363147,-12.396787,3.716079,-53.963684,-87.579158,-79.844217,-62.502906,-60.550186,-24.595311,-19.851111,-58.775771,-67.688944,-22.644975,69.201897,94.040054,58.86506,20.301995,-65.431701,-107.976045,-140.402023,-119.585873,-53.089975,-58.454242,-80.504126,-115.641782,-141.231147,-172.49371,-156.606305,-163.893759,-329.450232,-430.682591,-552.863634,-557.799222,-511.313966,-483.532133,-457.816724,-472.589061,-517.322867,-480.69964,-426.259375,-336.387294,-314.046493,-284.979916,-294.817435,-362.502779,-333.542608,-285.709248,-246.015622,-239.85178,-176.843572,-132.14117,-51.227813,-18.292573,44.916889,96.813935,102.448712,117.426182,124.657007,91.274107,61.519309,10.806828,-34.169028,-50.830576,-37.325409,-20.724773,6.545734,51.746783,192.234663,222.771125,165.801389,116.438731,145.561106,254.623462,280.686125,240.14891,190.893419,89.379726,62.075699,75.181584,78.374444,55.68555,2.3077,-29.972288,-134.496663,-201.777754,-319.203983,-331.532257,-284.706879,-164.007557,-150.831061,-237.006884,-278.863724,-261.318908,-171.906674,-162.154647,-215.316025,-225.141913,-164.404163,-125.742788,-94.17685,-90.850064,-69.95603,-96.747403,-98.110485,24.657561,79.242489,18.294075,-45.064191,-80.715563,-25.343077,-10.533431,20.815485,63.452726,122.449877,111.344142,86.189328,90.246711:-251.524031,-215.671133,-157.79163,-45.789225,-21.036932,-2.731214,-17.527121,-137.709058,-213.731449,-204.266511,-157.023095,-128.958717,-73.968601,-54.337989,-45.097369,-56.671186,-79.059993,-69.944841,-44.838073,32.491917,57.414999,95.591576,118.558329,106.807309,61.409541,68.597205,148.492662,199.789741,247.724661,221.666028,89.989751,19.378049,-47.999556,-10.289654,38.183051,157.491255,203.110934,252.165527,236.332995,86.040305,-81.780062,-129.788957,-106.547711,-54.51703,-51.040044,-124.66507,-294.921394,-337.448249,-294.384811,-173.849202,-139.077959,-109.880074,-68.689157,78.861963,116.061908,37.657334,-52.577955,-32.281432,108.73536,165.669342,173.027166,161.725002,164.225035,148.076075,65.926338,-39.585839,-80.732045,-41.995119,35.67173,166.215773,177.071742,138.819522,120.045926,111.399029,82.936927,77.497962,113.10143,135.922947,72.919979,-19.22889,-175.629457,-179.278847,-142.552967,-17.469731,89.148045,317.472801,347.453672,186.536491,27.794242,27.90552,149.365027,223.608336,265.140975,220.562331,125.927115,126.98805,157.667542,13.624911,-72.386032,-47.991574,33.626394,105.932515,69.066507,13.411533,55.960078,35.191112,-47.29717,-18.805834,125.041962,146.220254,68.834176,30.854157,34.308838,67.608846,70.518237,81.224513,104.273745,160.340834,182.984751,191.122344,87.642592,42.147905,98.00438,172.835304,255.61555,238.90967,151.984784,113.659476,98.908567,111.535016,90.845716,15.042884,-19.927012,-36.211118,-15.319758,8.339664,-30.154065,-43.725034,-34.391675,-17.603263,38.045591,57.864644,49.564535,47.468804,88.131042,67.03866,28.938723,69.041548,154.198349,284.489158,288.734722,208.969412,137.357009,126.924572,151.839387,195.84942,292.673611,305.506991,269.539817,268.935359,317.697491,272.859654,230.0803,221.663275,256.350985,362.850166,388.062997,268.248618,82.090202,34.712675,-3.941075,-2.149389,79.089335,137.10216,154.204589,94.730757,-27.736147,-3.833664,35.835283,99.123561,115.88746,79.914954,29.994797,-75.430013,-195.306305,-251.947822,-257.565992,-206.760894,-92.8187,-62.094342,-91.364526,-131.411992,-165.383657,-121.701454,-85.496172,-1.680315,23.616772,-9.127329,-55.374313,-100.390067,-43.709218,-33.663182,-63.209316,-55.596993,48.607943,105.956938,100.521347,51.442645,-17.413126,-117.419379,-180.34235,-155.811289,-63.230283,70.264045,56.164225,-51.381315,-108.752515,-98.341366,6.65241,71.982482,110.642298,88.895894,34.97191,0.434608,-82.938346,-145.224909,-143.591523,-10.18437,93.707737,215.520196,210.415626,120.378157,14.118442,-19.497598,-36.707343,-25.367126,-3.716112,-8.270571,-11.472949,13.029264,47.488768,-22.650582,-45.126824,7.896019,41.877276,4.967237,-54.203769,-128.591921,-111.880306,-126.126457,-221.664525,-235.950602,-165.591328,-153.005554,-239.331721,-279.925109,-229.906527,-171.802664,-206.437885,-294.905405,-299.648941,-229.930919,-190.310344,-203.118868,-250.319541,-230.238485,-116.483577,-36.270563,97.480976,112.009243,40.314801,-12.633999,-102.46992,-126.135859,-82.805895,79.103125,142.01103,185.776915,180.883356,87.318743,-77.084968,-126.265421,-110.813258,-69.192837,-16.087742,-17.622763,-61.97167,-106.657757,-185.475913,-155.215007,-104.642048,-28.195522,-33.571472,-90.553245,-115.205602,-141.933202,-84.599233,-27.023162,57.711605,76.980761,66.787003,29.25548,-75.008303,-110.802199,-122.393678,-152.234666,-179.563786,-176.525601,-162.615519,-175.926952,-205.730333,-320.189398,-480.971061,-556.109046,-595.550363,-542.904256,-424.564948,-412.855299,-451.795899,-472.058221,-528.50254,-589.062603,-577.626731,-473.435694,-413.455998,-314.047569,-289.786135,-328.809226,-399.559566,-411.166511,-373.738135,-340.467991,-279.136891,-239.003086,-201.18877,-229.433698,-229.686682,-119.943223,-85.954646,-66.018716,-64.780878,-69.449977,-93.94665,-208.73402,-259.606641,-241.343669,-173.666746,-125.846137,-27.101087,9.366201,80.035305,109.666458,99.55215,47.487427,52.155056,132.274313,171.872288,191.17648,170.86639,72.492612,-37.532933,-58.687778,-62.740394,-65.386758,-65.80179,-62.390547,-85.70214,-126.937199,-239.364164,-285.285729,-248.999805,-105.992987,-60.07984,-64.601289,-92.730641,-137.224397,-87.174926,-35.36025,21.673155,2.342052,-57.130277,-41.759327,50.906392,70.453936,17.265658,-53.127358,-37.807455,124.57171,216.281443,233.877348,149.046123,-41.48877,-66.483506,-25.038797,74.345499,122.151853,194.990539,205.832611,159.676535,118.132123:61.003296,38.423256,73.684848,185.977847,223.064576,244.36273,242.127222,193.520809,133.475512,130.355145,124.269981,100.86628,52.615504,50.861707,65.067351,51.744882,-16.89732,-43.341628,-24.003918,68.239995,118.317548,158.106135,134.442858,64.629604,114.00544,152.750184,161.202239,152.651946,129.690054,103.538272,11.940289,-53.986714,-155.168652,-123.401559,-81.042617,25.662228,79.16498,78.013458,17.986981,-105.429667,-157.562497,-179.046981,-185.942492,-155.56754,-172.129432,-244.635344,-323.718551,-273.382315,-108.457008,-42.727464,-35.3582,-0.279923,22.998195,67.318015,101.427741,164.954035,162.86179,133.951658,65.547256,51.410512,44.313568,35.722894,25.824993,30.751573,35.207132,-53.909408,-121.348503,-144.478836,-76.369034,77.93889,91.45391,-30.85381,-155.014843,-150.807918,-81.653667,-66.479829,-55.816021,-43.050743,-111.613349,-205.483134,-245.73893,-56.087256,-11.792634,-15.541493,-8.052493,16.612482,28.910114,29.161588,-57.914893,-117.007295,-167.251212,-142.216399,-80.788071,-71.354328,-93.488745,-131.462808,-218.917932,-255.412403,-269.666579,-273.040929,-250.934188,-231.405016,-250.251546,-237.540801,-160.241814,-188.161802,-340.640882,-361.524108,-261.71995,-205.286836,-110.209421,-78.985513,-80.339166,-48.054422,-10.947967,39.875939,61.678884,142.924536,190.805757,274.888619,339.179348,327.710926,247.710441,240.035481,279.813287,286.150614,280.891155,265.565256,154.890284,67.409529,73.136587,69.495752,31.363085,-28.48648,-22.764561,5.69017,26.984977,36.222778,27.213345,24.956699,63.598501,83.352947,89.00676,109.117449,216.913569,243.899648,229.215481,239.575576,249.708357,207.03368,148.858234,27.457601,-16.467115,-24.824862,-7.975458,35.786465,123.005657,144.767792,176.276154,177.99258,151.002215,105.462349,71.327022,66.89583,113.323046,212.683042,223.067455,160.962018,97.981534,68.351621,-11.935716,-48.586693,-55.40122,2.727671,130.251211,115.932758,22.885087,95.525208,151.877468,182.269126,176.097151,161.699481,155.41075,149.206411,126.786253,116.693936,106.558651,98.150013,84.877195,76.774172,-4.572893,-84.75366,-210.358411,-165.864984,-106.494206,-21.504355,-7.64357,7.280024,30.584309,80.055191,88.024416,86.17117,75.399329,71.350545,91.760044,119.059204,173.617567,188.249285,185.675934,135.998624,96.895281,79.92732,123.179341,216.489793,221.008564,171.059707,149.489335,160.437109,242.243307,301.607056,338.609813,290.35708,141.97749,80.971833,4.545699,-13.142824,-12.073859,5.54328,29.43328,105.28839,148.448815,184.498781,124.200122,95.728984,69.175034,43.882086,-11.101319,11.252785,144.649597,195.793936,188.70473,107.054239,85.140424,82.824873,68.186418,-11.098086,-44.696427,-56.544309,15.10064,40.434321,-33.364494,-95.027923,-146.80596,-162.47143,-245.974979,-278.29152,-232.624008,-134.860471,-135.455846,-218.163869,-223.074986,-85.786619,-5.053549,59.599238,41.922915,38.953973,145.133601,257.743457,449.110159,470.481711,365.50511,286.951658,197.06438,214.609526,233.9907,280.598469,303.896494,310.942506,284.040443,199.759513,156.164948,143.413069,120.284772,107.708315,53.435768,23.831687,-5.204405,-5.848865,16.646331,12.186694,-5.511113,-24.211553,-19.621455,-23.124468,-36.755296,-0.172581,144.837931,177.484044,111.670963,81.850872,67.344473,30.09156,-105.79434,-138.182509,-45.479607,48.387879,30.04683,-70.702832,-121.962345,-157.643175,-135.0382,-132.097339,-264.405577,-334.578167,-377.860872,-348.730418,-295.342829,-307.926301,-400.339518,-437.236308,-417.454816,-361.814951,-330.664784,-197.901343,-127.962218,-141.704108,-211.133271,-252.875704,-73.222326,29.993949,133.37111,127.521361,5.068045,-73.329298,-73.197709,16.440028,208.942965,257.422511,230.618513,175.857614,172.004321,169.455311,142.70113,31.906364,-83.533554,-122.082413,-152.126734,-150.407899,-129.17632,-111.258559,-71.55803,-42.385051,47.796061,74.217525,54.130203,50.9554,75.099045,92.958287,65.126962,-32.007358,-50.02139,-33.946024,-67.63505,-104.205559,-153.171502,-178.618749,-229.915595,-250.920449,-303.64817,-331.586532,-320.527441,-268.463145,-246.694388,-246.422151,-257.722856,-289.139094,-299.21209,-275.167453,-246.015439,-259.102093,-283.126124,-269.700415,-175.682903,-124.34348,-89.411955,-102.818931,-99.125988,-67.335492,-58.807487,-97.911901,-140.280217,-203.041597,-160.504228,-111.456306,-74.02754,-112.248028,-188.254153,-171.783844,-100.340806,-96.581148:-23.766636,-41.673063,-36.594002,15.962041,54.251902,139.678369,173.028063,138.524194,17.512315,-12.575868,23.448348,61.803203,58.306201,-2.924516,-124.883671,-144.290343,-114.860015,-54.070102,-41.352384,-24.133216,3.920084,72.092278,83.266855,33.040667,12.009403,37.005019,83.474933,88.943028,103.240887,126.307846,169.774787,174.833212,136.973522,65.134421,59.135816,149.501988,206.155783,238.324785,218.496488,114.928288,-47.040959,-94.914452,-87.658657,-56.724126,-24.810201,-55.326488,-175.552106,-207.859912,-150.237843,-90.771384,-93.592923,-84.768399,-67.229759,-18.468744,23.427049,140.022429,198.815965,152.281915,-30.41356,-62.546548,50.34879,90.494636,28.336106,-5.236893,7.113226,-28.885843,-64.994501,-39.21689,4.255954,55.645094,70.280937,69.804875,19.366934,-4.232354,11.419171,59.903754,133.900734,115.569393,6.295304,-43.009363,-67.190272,-53.119988,-64.572211,-79.04389,-66.794914,-35.312355,-30.153474,-81.256839,-220.699962,-280.831089,-280.555066,-227.435214,-140.492335,-121.501147,-110.975326,-127.133082,-168.76554,-201.886847,-222.360605,-225.781233,-194.43077,-96.346928,-60.294271,-12.814842,21.928801,-25.10298,-191.98883,-222.466204,-185.927418,-174.839826,-163.792305,-139.604448,-95.125509,-83.95418,-51.602405,63.524899,101.424275,102.061897,96.315041,106.746542,117.27082,123.021479,166.652459,208.884925,266.303431,257.861867,193.163513,146.803325,75.278197,61.428241,34.873201,-65.476347,-81.978846,18.734228,83.778399,118.428271,84.672639,62.166169,-17.764209,-60.245511,-71.627723,-17.740015,129.243268,171.614979,249.041636,338.465041,337.727782,289.833401,270.960213,260.645239,257.507223,171.604697,22.361718,-26.717694,-38.858244,-7.457655,68.564747,107.859292,183.573494,188.706677,154.124871,127.25805,91.836738,32.15563,42.704311,96.151623,104.387452,61.472941,-9.962543,-44.011389,-149.228436,-197.10693,-125.878848,-25.498481,95.019992,89.896617,55.70948,86.926993,113.903478,182.516799,226.2241,261.306088,232.159419,142.69012,45.762662,-20.144572,-112.877886,-107.943791,-63.843396,-63.659759,-141.192073,-213.70098,-303.188279,-209.999827,-139.358905,-110.157063,-146.207495,-195.214469,-198.056446,-207.07011,-227.370339,-232.16005,-190.311779,-149.03473,-75.909397,-15.677685,160.219949,197.558295,134.575533,122.51642,136.375261,119.626327,95.40797,75.676539,86.347948,84.156444,69.49337,77.028062,138.503038,194.836983,266.926674,249.744757,153.437645,105.787082,59.431442,-0.922466,-63.016537,-124.176482,-82.688914,88.182041,161.846099,196.932536,145.254332,116.83395,37.093138,-2.100413,-1.924012,36.419031,121.265045,129.497596,72.272614,35.403591,19.951652,-80.690775,-148.311668,-209.568316,-195.210773,-170.882115,-186.744218,-187.51123,-164.935752,-143.177077,-132.65982,-179.398583,-334.772331,-367.305051,-256.830889,-158.351484,-192.873839,-314.825014,-331.516652,-274.745516,-227.736383,-100.766232,-48.281649,-75.234992,-70.294557,6.559678,205.726977,279.861276,343.218865,327.474882,216.532656,31.952523,-43.53944,-9.179144,78.746683,230.939918,268.217244,252.827096,115.653758,38.606333,-6.720056,29.334651,99.827296,99.035616,81.980711,93.389153,102.684492,29.506019,0.713692,-17.990627,-26.634416,-14.260159,13.254273,67.741767,139.401074,174.233956,131.508024,63.204102,-26.273559,-37.944796,-71.787633,-100.206216,-119.930415,-94.152867,-81.649368,-72.697818,-99.928525,-157.117516,-130.267977,-43.008512,-153.614178,-281.206498,-430.584776,-389.495625,-252.793424,-231.286636,-267.75141,-312.173773,-410.33355,-416.593622,-364.170543,-221.891727,-183.615317,-190.389904,-214.192573,-259.010063,-173.84492,-95.389812,-21.497604,-49.409697,-138.474611,-127.958174,-3.82641,41.450097,57.714991,57.569067,80.04729,154.916394,162.345177,128.412145,131.498707,154.08308,95.932132,28.237882,-94.092255,-96.801833,-7.144019,41.552111,90.844411,100.779011,164.311132,184.676326,139.142859,94.089955,120.247924,132.87388,104.558385,93.186491,109.197464,61.874545,-76.413226,-94.881115,-64.381948,-76.166943,-145.437326,-171.975887,-198.870032,-176.007691,-140.095745,-85.796347,-92.349572,-143.786548,-180.263822,-261.242603,-260.661661,-240.662808,-263.042134,-288.418634,-261.500391,-229.156732,-207.794528,-200.849893,-146.832684,-92.307718,-74.79382,-48.941315,-64.774682,-128.304329,-145.593506,-164.564374,-138.719259,-110.444242,-102.157448,-122.81874,-143.658489,-128.830289,-70.037938,-44.51734:-109.718066,-111.198693,-73.407943,70.239743,124.47836,74.552451,4.703305,-60.154688,-60.301309,-61.466004,-35.795612,-19.448522,-38.994201,-77.097767,-160.300145,-173.757196,-94.870789,21.64313,50.070766,104.801904,135.76018,174.16741,176.961168,93.044756,0.398644,25.969482,151.514308,178.58241,114.397191,65.401031,-5.268812,-50.379751,-163.522632,-148.162651,-80.113411,38.256413,48.719564,32.634806,23.394858,-75.371533,-181.521369,-189.472383,-181.98571,-180.379519,-201.572637,-214.02541,-178.441539,-144.000474,-79.057605,-15.762059,-2.632138,6.696657,30.081596,107.865735,137.136828,173.154298,225.903739,221.957585,136.044713,98.795516,58.423313,53.256069,89.133921,88.610899,8.532519,-83.246875,-106.06082,-41.013624,16.880439,13.926742,-36.892818,-58.342243,46.197047,75.19802,65.82241,63.473016,66.447551,56.791182,-15.288061,-84.553407,-167.135447,-77.191565,-27.56723,40.587357,87.211525,184.183997,189.959743,93.691776,36.629694,60.64556,147.30504,181.762813,170.893696,136.44317,93.969986,65.259964,-39.533157,-114.056644,-137.238384,-131.366264,-103.736228,-112.251455,-153.705132,-134.65022,-10.654123,-8.928782,-109.95441,-147.519069,-100.179488,-32.329793,27.094354,6.510934,5.076734,33.24313,31.796811,77.258861,128.486965,172.362801,160.948874,227.593312,326.211076,294.880275,200.808526,224.570725,333.17098,343.205893,272.107555,217.154752,115.14584,128.860098,147.459775,85.773113,24.888745,-29.884878,-4.618672,70.522708,67.864543,37.944474,-2.327282,1.864721,23.578621,38.45393,89.376154,121.84092,200.015362,240.302928,216.105865,151.160351,165.095715,242.791522,238.963034,134.205464,37.259365,5.53029,34.632971,109.44668,226.527473,225.729639,200.51464,189.661692,158.182122,210.495719,255.235006,269.562046,260.335028,310.513054,325.179456,248.285082,166.664772,136.101388,55.8333,15.551307,11.03424,57.085525,110.513541,77.589786,12.080968,67.892126,111.829659,162.41435,153.575085,106.230021,109.294463,125.469989,52.485591,12.63389,-29.053046,-40.228993,-73.259736,-100.08027,-93.95083,-36.378985,28.032934,-51.806275,-53.417481,30.359026,24.659079,-45.711967,-20.187322,55.326828,15.400453,24.602829,116.271159,129.947573,58.580013,25.286046,43.921243,81.957202,135.504845,53.388539,-18.741552,-71.137431,-34.890171,106.473293,166.483922,137.93819,28.230076,44.040567,188.977801,247.331633,231.790911,193.34305,183.317453,177.177675,58.293113,-59.745691,-85.150814,-58.802314,13.985894,213.274672,266.074206,207.280092,81.153966,44.20101,39.682806,42.134473,-44.173324,-106.948106,-110.124559,-38.248785,109.589138,93.703774,32.202451,-41.929382,-26.986632,-21.501357,-56.368862,-91.356551,-80.828303,-91.59582,-121.01183,-126.163914,-136.442179,-157.817641,-203.718538,-199.438874,-119.567552,-82.312061,-125.343247,-246.713953,-266.55761,-139.284522,-42.509749,-16.987707,-94.336839,-63.275451,103.978978,176.245615,196.254351,171.734947,181.109945,192.34196,132.028615,81.439166,100.070227,208.020355,266.28928,274.083497,212.986831,71.075343,43.451561,56.89638,46.171017,18.268837,-79.299062,-127.257111,-132.928964,-108.74506,-83.154651,-81.584021,-59.335137,40.893556,59.410011,-64.464306,-148.718349,-182.946462,-50.765467,17.389895,60.59753,52.205454,31.394101,8.359975,-56.225805,-74.840888,-84.283123,-101.000843,-114.07115,-109.656247,-90.801395,-98.993573,-147.017803,-272.185109,-368.775718,-400.685188,-391.122338,-360.552456,-340.519174,-354.182407,-391.346236,-400.917507,-371.275909,-369.927949,-380.713273,-282.372843,-194.316293,-153.069296,-210.179997,-292.941581,-213.380989,-171.796968,-181.21647,-193.385802,-162.341199,-151.140136,-154.879011,-121.486191,23.521719,60.300506,27.048996,-9.165395,-8.883241,-11.388105,-21.264255,-74.822283,-134.61134,-153.399946,-175.724602,-169.133156,-123.704758,-86.895599,14.835783,47.523086,11.814738,-32.946355,-11.065364,55.561926,74.035583,117.257829,131.412986,64.251047,16.556274,20.138053,-29.918902,-80.388595,-162.764652,-177.68791,-214.223904,-278.949507,-408.218538,-378.459422,-330.342998,-232.579607,-197.346511,-176.238419,-186.904022,-236.927526,-287.858761,-277.500085,-181.026328,-139.520407,-101.833405,-73.930798,-4.738469,-10.996838,-101.344414,-115.502019,-67.279295,75.961976,102.693548,-7.171197,-72.593534,-103.076202,-59.863374,-33.341942,2.00613,15.948714,39.804164,42.371286,2.526099,-43.555955:right
52.575141,-68.31674,-86.780776,13.114321,111.164919,214.754889,187.416724,70.210751,-53.422618,-107.886184,-127.165186,-69.093161,105.124346,169.478745,212.409051,175.341286,-29.934016,-246.556968,-291.784196,-239.601934,-182.206263,-131.63862,-161.432451,-314.515262,-450.086758,-440.704891,-291.245083,-208.582437,-131.646978,-136.791225,-155.212876,-166.248559,-245.253488,-247.594029,-179.537567,-30.399589,15.609405,6.616922,-35.814184,-62.386104,11.807361,66.60295,149.269239,145.220042,100.21459,95.082495,108.862663,96.200684,-3.575648,-43.804022,13.359516,197.308814,248.846088,156.459236,50.824046,-89.054453,-70.4607,-39.343373,-26.921914,-37.374123,-2.346336,45.950361,117.424564,94.74905,-71.019151,-149.812534,-99.775553,36.286778,63.974306,49.926752,23.337202,-61.500865,-149.879292,-143.265444,7.821126,109.697898,269.016268,289.157049,184.469495,116.257221,72.731976,148.865879,201.647606,274.909344,289.620855,268.36207,237.328209,161.548115,82.410186,62.490958,80.588397,98.730164,105.627614,86.406195,8.345828,-27.411539,-44.929794,-40.465792,-32.578408,63.715862,153.420936,267.155718,257.060773,200.515173,154.456924,127.395353,71.767326,60.108067,78.340281,71.751473,-22.377809,-93.429723,-227.953938,-249.093952,-218.221158,-159.199775,-137.557798,-107.847657,-96.131413,-49.432171,-27.246215,-36.593473,-66.443783,-74.695711,-33.092572,6.888127,52.895009,48.824383,23.424374,73.273406,128.029727,211.750402,228.146574,200.470152,159.869921,69.657498,12.562299,23.183425,70.95502,74.246378,90.502996,102.230121,42.74328,-5.625204,-38.635488,-16.273022,-1.584401,56.080938,112.796053,222.507589,231.164752,138.384298,91.579117,152.624591,326.75741,363.640699,357.828532,357.671248,347.051102,309.11605,244.880607,310.261815,328.869832,281.247901,261.653222,217.004725,166.709359,90.401352,145.914936,207.886776,264.29414,243.228607,209.327359,196.646577,102.115583,41.402396,5.808961,102.759513,155.346555,208.52683,228.060231,215.266242,153.651475,-1.441434,-97.111563,-123.120049,-186.427436,-221.130392,-195.877548,-132.766843,-48.572368,-76.092495,-237.98167,-332.839847,-321.013437,-294.372282,-301.592028,-316.367711,-324.506268,-392.019859,-468.297717,-431.130022,-234.84089,-155.003089,-65.546893,-34.394535,-46.300348,-106.283783,-228.977531,-172.318258,-99.842564,5.671504,38.239266,85.360782,98.675336,95.634446,56.329764,43.881394,41.962908,57.109288,121.954975,137.41628,74.46496,20.394992,-23.885131,13.760001,9.739978,-12.911175,31.622881,177.054567,197.97371,134.759197,92.175219,90.482586,62.756572,38.913637,-5.988967,-49.64233,-166.253734,-210.494465,-281.529156,-310.294657,-293.380784,-224.048806,-171.836747,-57.597003,-34.891606,-95.547799,-156.495758,-142.110572,-86.643636,-78.356103,-84.470584,-90.423719,-111.674424,-118.975299,-132.88216,-133.577644,-121.535456,-55.16587,-2.286775,54.447536,46.211376,27.305876,26.662757,31.342938,64.638134,88.845466,112.07771,95.972627,54.868468,45.890621,-8.313434,-49.437249,-10.389983,138.422432,199.900247,265.186558,269.454655,189.061302,31.104914,-5.359132,69.43854,136.736919,221.642365,218.19372,115.480641,36.881475,-95.008847,-81.757693,-28.199012,80.306704,116.788147,95.607604,35.580868,-58.221184,2.960255,52.292549,79.118828,59.189838,6.550429,-2.074586,29.956715,32.530882,-49.083973,-111.337601,-103.244299,-93.222336,-112.879657,-146.031145,-120.981059,-8.051457,27.237188,16.178365,24.799773,49.376853,72.788518,43.48229,-39.154067,-44.279117,-13.03455,-66.158004,-102.894754,-77.074878,-20.884215,64.940546,72.507762,25.773442,-61.805782,-70.151298,8.691458,61.941857,151.698569,165.355281,83.176567,5.268278,-143.505765,-187.793434,-159.450593,-55.98208,-5.5691,60.569894,61.204725,-36.280983,-134.012112,-110.436436,35.199169,118.187911,236.100705,247.724387,191.756119,130.622902,-22.859676,-99.79686,-102.705361,-68.353667,-39.334085,-12.552114,-16.442317,-11.248448,-10.79075,0.184104,44.105539,37.563763,-1.428363,12.347499,47.200154,5.115535,-176.982921,-192.500892,-94.443985,119.150862,150.093113,31.814564,-56.105102,-148.088671,-71.966188,15.66998,121.249501,103.55059,88.628551,113.124932,107.680341,86.63244,67.036474,31.163286,-0.152745,-46.830596,-51.525091,-62.147011,-82.337965,-130.608536,-135.935072,-114.0639,-80.989943,-74.394068,-11.37594,38.420599,56.034573,8.277133:29.335733,-15.776127,-36.70014,-9.968873,13.525396,6.490449,-0.227816,-35.931426,-215.931304,-284.959237,-207.462658,-93.077205,119.444531,176.298529,178.800976,133.580778,3.547448,-88.230988,-103.21554,-68.765414,-22.675659,70.252933,62.831266,-106.84016,-210.835894,-168.409909,-33.152851,-1.215482,-8.088703,-16.438256,-16.171462,-23.686932,-85.420833,-125.512636,-110.930266,-32.658897,11.930903,59.147751,46.853327,-55.734856,-152.797526,-128.988857,51.055514,137.217929,164.598155,107.10381,-15.638514,-55.228684,-125.043672,-91.813113,-22.303124,120.356205,153.749999,85.005733,2.818228,-109.182594,-45.040873,16.6818,83.444064,78.777054,51.249757,64.128411,108.981955,76.505301,-99.262556,-118.785167,-47.411932,54.216867,39.778712,-65.509711,-109.541794,-142.424177,-140.574866,-109.941647,37.046304,141.948752,329.042834,333.491895,153.969122,74.03691,86.21893,211.369547,244.962799,252.782043,257.131005,220.018237,170.247626,85.391678,45.633976,36.294481,65.157955,116.50424,219.485649,210.723387,53.006021,-39.126717,-82.576818,41.798809,74.483541,49.666482,57.407429,159.796483,188.268194,117.862744,58.262999,71.230835,77.838199,41.759634,-26.905683,-39.815261,-136.995132,-239.46077,-367.189595,-249.633643,-172.25442,-69.826863,-24.926282,25.403354,15.631873,-21.949914,-38.815359,-37.129638,-9.599207,19.564476,106.693297,133.737844,96.639386,47.533982,-28.097371,6.431038,38.370407,98.378948,151.231294,228.445431,190.82437,-2.553352,-109.084535,-86.761508,11.313858,45.73643,53.132356,14.602502,-118.847179,-174.57465,-193.675224,-68.215452,4.852005,104.167961,139.646169,154.860684,127.350406,24.628487,-28.186973,24.185641,213.314887,267.008892,260.624189,249.676114,183.338293,104.034168,3.180425,92.494702,136.760873,126.742297,100.439029,28.209433,-17.395404,-58.97731,-23.73641,8.689302,93.423752,133.083501,163.70702,146.446874,66.741622,26.67841,-4.576137,44.001527,68.621974,80.877749,83.69125,96.291284,88.149927,1.105559,-117.73516,-148.352513,-152.747955,-131.072596,-45.414202,-15.399246,-60.265155,-130.272824,-252.014119,-245.055271,-226.177005,-212.834303,-213.542038,-236.419466,-254.437356,-289.118009,-309.122308,-282.715222,-143.03805,-59.848967,42.286591,38.060782,-36.561422,-74.272465,-125.8901,-123.924002,-97.954764,3.819787,57.859959,76.4908,50.983234,13.647834,-16.223757,-28.719377,-41.400576,-29.978836,6.52738,3.785528,-21.461626,-26.860433,-64.302732,-111.13808,-101.31776,-24.230551,13.330392,28.885411,15.423043,-40.545081,-99.311733,-101.106126,-33.624284,14.52729,26.267554,-31.842948,-172.737463,-205.579192,-211.087107,-157.395221,-122.252892,-80.930582,-52.28115,20.891428,23.243715,-70.953036,-170.63736,-173.807131,-70.70103,14.440059,102.48386,44.4996,-128.044325,-137.540669,-36.214944,62.843382,104.248564,197.892188,232.770226,197.962349,164.740806,180.39468,184.636466,163.203182,161.773102,187.537755,241.619886,258.150943,264.699957,258.457222,232.467796,210.10921,227.819501,342.062193,407.581266,449.22588,405.012034,207.883201,24.01909,24.189704,211.68456,302.18538,309.314132,256.20045,143.531816,83.719379,-21.150719,-53.169807,-40.262851,60.086357,112.788825,93.666442,25.649251,-115.346361,-109.594048,-36.617885,119.373001,144.917243,94.95867,61.900968,38.56231,31.240149,-28.634061,-103.44025,-103.001957,-18.067384,20.572189,-0.416892,-41.387742,-71.63875,5.646896,60.699031,133.072202,144.526687,123.01046,81.974351,-9.213456,-31.384303,-39.452545,-44.025735,-54.100767,-49.20139,-7.582491,124.013913,153.094367,62.059336,-37.191155,-13.319877,154.704392,246.496262,335.687532,313.989263,166.042176,70.125617,-72.917011,-68.054998,-43.004549,-8.866897,18.806003,69.720062,49.509331,-92.479053,-140.494928,-91.192543,26.128592,71.974117,146.314963,161.177629,93.017717,10.054096,-142.477077,-123.853578,-70.882794,15.036077,18.309838,-55.436105,-76.570714,-40.851931,-30.141966,-22.247131,43.921113,86.745742,140.144493,121.122819,-29.480644,-134.750146,-271.811496,-170.144074,-59.102462,123.426684,145.50956,48.660692,-15.229622,-92.716352,-90.718937,-34.004982,126.087985,169.927023,170.660024,151.455312,78.34267,34.842737,-25.748329,-66.45365,-66.448217,5.33694,52.441775,80.242894,37.141348,-117.78253,-177.269737,-159.026927,-132.006769,-124.97686,-31.094445,38.935336,76.743663,37.943424:-157.373975,-163.583491,-152.341874,-37.460549,27.204542,28.356721,-18.757576,-129.901188,-256.181872,-279.349097,-159.763561,-61.236089,56.96371,61.980919,4.706758,-42.987434,-135.392641,-163.181329,-134.271921,-5.81504,50.894092,59.713483,24.436853,-66.034198,-137.22544,-140.402569,-39.033093,49.82107,169.808006,157.101597,35.470732,-19.138521,-37.241733,44.371385,72.409867,75.972477,78.438103,70.639272,37.254463,-83.395162,-141.453986,-92.193565,78.816955,135.451367,155.489738,139.220921,70.602201,8.832638,-114.984333,-107.827315,-64.927719,44.576692,77.676095,20.770188,-44.145643,-129.24407,-89.186551,-32.105587,70.827774,100.320426,145.066399,160.045226,125.89959,65.940407,-57.051442,-90.508269,-93.52143,-49.508818,-4.793636,-11.159141,-88.127285,-260.025602,-216.342691,-117.505579,56.697923,116.069917,183.580725,168.740942,76.193914,47.553146,89.285001,199.361356,241.540849,290.16971,297.194161,232.663254,173.315762,73.206071,-3.368359,-16.68619,68.040946,130.673707,149.113329,94.693348,-64.797761,-115.828258,-97.07946,-37.369644,-17.252071,48.593584,100.112092,158.284067,132.299355,14.573916,-47.627858,-55.051175,-62.664634,-53.03329,-64.555917,-114.374389,-211.919603,-240.085387,-296.644432,-278.66055,-227.54568,-107.663529,-62.494346,-47.082225,-79.41521,-143.110054,-145.413379,-134.346322,-59.042483,8.698327,116.029369,136.963052,128.173186,86.168235,-43.74254,-55.62005,-1.635446,109.566716,131.393531,109.548201,69.49916,-49.701514,-69.586852,-25.061891,29.951383,27.055328,15.909475,-0.532463,-87.105397,-143.696731,-217.643643,-210.890995,-181.639873,-41.921019,47.977229,96.544347,36.604257,-120.65518,-130.49928,-60.244783,109.667114,185.741037,278.801586,255.275247,82.134427,-12.96214,-108.643594,-38.855015,12.92585,42.136532,16.339841,-77.73224,-115.504194,-153.408283,-147.914436,-94.081929,50.340309,81.728869,47.701755,10.14301,-43.567591,-61.985053,-87.355668,-5.099572,60.64024,123.681478,114.97254,56.745774,23.763723,-32.993338,-94.220685,-111.321186,-88.980553,-62.390221,-50.134974,-62.186582,-92.284625,-129.065703,-233.288501,-243.77624,-197.329724,-64.844911,-26.895721,-63.278629,-105.001995,-200.459396,-248.678769,-197.805181,-7.295975,75.236883,161.010951,167.496742,114.365095,59.929812,-31.159529,-65.999236,-58.282373,33.049397,82.990244,129.058054,133.112032,105.234928,65.286744,48.281062,39.804897,76.239589,127.185442,83.517683,-24.191793,-38.532017,-54.468118,-65.699382,-51.08219,26.003473,78.165848,129.777496,116.314753,72.885581,73.547482,59.164686,-44.558052,-79.762795,-52.581875,-42.855237,-90.314016,-118.602897,-122.934516,-30.410778,25.616449,90.427974,122.168713,192.378015,175.417468,6.077453,-73.260083,-26.59177,111.558591,170.957243,207.471838,151.338926,-12.394497,-47.895707,27.294314,202.470393,265.331496,291.836637,283.924426,276.947793,276.250219,240.080079,160.169383,145.415984,200.244049,255.6108,353.035613,354.802478,266.046878,229.996443,246.522285,264.625414,247.083385,253.818372,300.249188,369.664257,346.28371,193.170231,38.947659,25.972595,163.162516,272.494946,360.161617,296.93519,93.288406,22.201547,-27.989997,0.48689,40.979084,156.175767,189.972239,119.669572,50.600624,-20.609471,29.31538,75.241675,112.362464,111.291211,155.818639,173.629042,125.572684,84.010185,38.602654,64.549226,77.943589,54.861063,32.111533,23.811115,42.290933,56.305267,62.12754,91.839897,145.521837,157.967447,160.064721,136.975087,74.25786,60.34828,54.044251,43.151694,46.408822,101.68371,140.584297,182.260815,178.871147,101.165816,-21.063537,-27.394398,116.122658,210.197554,259.746048,200.785627,27.712973,-45.791424,-113.395891,-47.689343,11.131264,149.707723,219.767741,242.515699,172.506777,-21.379974,-91.634062,-55.831758,65.943304,120.373314,188.857302,196.181116,121.431118,26.690118,-154.991198,-120.105151,-49.78359,44.635754,51.171905,20.372551,4.947473,-18.738799,-3.689065,21.780729,45.604173,52.588678,79.060388,63.071177,-60.822466,-133.631581,-213.538208,-158.660338,-86.199276,105.269099,171.370333,126.843209,49.516278,-72.133181,-80.152868,-35.157275,88.6876,137.008054,161.498607,125.46776,8.276787,-44.56872,-108.996265,-120.435177,-142.201272,-160.83886,-104.578559,32.111881,27.270223,-101.448361,-147.392537,-122.975427,-46.293867,-15.750657,29.681453,55.987795,41.031781,-14.500878:-115.177355,-163.56383,-150.115713,-76.351176,-21.001392,58.962094,51.197547,-22.137013,-120.092272,-158.430116,-123.610739,-67.244921,-8.610749,-15.905814,-4.898247,13.202646,-39.623168,-169.846311,-215.863798,-201.838954,-146.35212,-74.361673,-96.820945,-241.783799,-358.928463,-329.629207,-164.833708,-105.362812,-69.01378,-68.93899,-86.86781,-104.15212,-142.258501,-123.372503,-88.651766,-25.741157,-2.461557,-27.112284,-92.726847,-214.550297,-157.146909,-82.080035,21.572664,47.523309,115.03025,136.495286,99.837017,55.797547,-45.163575,-80.996039,-51.037997,40.485955,75.379158,82.619836,45.332932,-72.041247,-83.203733,-24.007353,102.225246,129.802607,131.162622,120.746801,84.036333,44.127667,-97.308138,-210.238287,-220.251266,-150.105711,-85.985579,-9.370061,-41.539314,-210.003225,-238.756891,-150.010161,82.588729,182.757839,308.067824,290.395016,132.983056,85.461121,133.481111,239.709822,281.057369,333.642925,345.137762,300.46138,247.515504,149.652144,104.07509,94.061668,65.631077,58.877121,76.443366,69.678707,-9.943079,-64.913703,-162.806113,-170.083001,-136.104513,-47.741733,-1.617553,69.880928,85.876795,83.104238,34.147457,0.19259,-35.203343,-27.839298,-6.078323,-13.867912,-70.446375,-119.600172,-233.615411,-223.450883,-169.133097,-63.54935,-32.995831,-32.672484,-44.08385,-37.289271,-12.624669,-2.002561,16.286047,29.104993,95.337292,136.317667,148.886486,121.838589,80.256319,93.376727,98.249503,101.932729,117.487004,123.082435,83.489586,-30.829342,-50.590321,-9.498282,63.984263,74.451904,69.895334,44.991546,-66.700203,-123.524976,-178.252481,-157.23529,-119.273544,-5.940152,71.241978,165.666699,123.999172,-42.694841,-35.96486,58.298265,271.634508,321.584414,315.696506,315.09462,330.969313,294.441607,120.000769,38.309861,60.961778,134.135229,153.906061,120.485479,89.629425,57.457994,27.734303,41.777765,141.98844,176.850286,155.788,119.034731,49.05306,30.607146,47.670238,97.919568,120.428297,201.79106,252.20908,245.786858,183.16222,59.927213,-11.72413,-24.178329,-26.836769,-34.14038,-17.3514,25.68299,73.97217,29.147634,-115.486816,-132.802549,-112.524598,-127.918535,-162.202961,-218.522278,-209.608973,-167.795879,-225.394541,-236.319859,-98.278398,9.108453,124.161525,109.07811,36.739244,30.098384,66.312659,77.813846,79.892583,147.680755,205.222041,232.8782,192.251587,127.213546,130.676169,138.732508,139.937428,145.117393,176.460826,175.283799,138.739796,112.937261,41.43304,14.581458,13.858791,35.477709,83.161678,194.470125,211.774526,148.770972,72.305418,67.357069,76.941934,63.498736,-0.533314,-47.970325,-177.651291,-243.314725,-314.812442,-243.340518,-177.986605,-82.285462,-49.589575,-22.635164,-44.608226,-77.418665,-6.618728,25.116787,8.203364,-8.960519,-9.731623,-32.074976,-129.874503,-157.434405,-116.014504,20.031063,70.242896,102.266441,113.228434,125.152366,121.354168,121.427582,78.716562,39.991389,18.849263,55.688378,188.247692,243.203821,264.714735,235.826634,160.511262,125.405119,134.430852,196.396762,227.081933,251.905625,244.893652,163.118959,5.498854,-35.230125,47.314257,135.91493,267.429652,270.057012,122.598065,15.90506,-83.287994,-30.837497,-7.657167,33.977207,62.806994,59.786503,17.968135,-34.732918,45.162336,99.379779,117.952577,91.181126,84.10015,107.719834,112.310737,75.655442,-25.052922,-73.22189,-64.50815,-6.683886,10.806644,-9.1657,-15.690541,2.296194,-15.448282,-18.867952,41.622073,89.052889,130.810477,98.673231,1.463,-11.516743,8.711631,2.66911,-5.663706,-1.353281,17.973688,91.530356,126.374172,72.703947,-76.284686,-75.835331,60.406349,134.421218,207.27742,185.793276,54.99992,-27.114966,-147.53527,-95.957353,-22.232057,84.907774,93.37327,55.892398,36.006135,-16.222656,-70.535142,-49.171757,91.6121,172.753526,255.582975,227.999902,60.845421,-30.638442,-149.70839,-167.656103,-133.422383,3.388924,63.020628,59.676945,37.831475,78.502956,102.297538,77.431907,9.557304,-9.825224,14.70625,36.980818,-5.790616,-82.175855,-212.549992,-113.89917,3.10547,153.879373,136.56936,1.70042,-62.291252,-145.181844,-123.396378,-55.536962,67.972403,83.522295,82.100248,77.537181,18.288532,-32.994812,-107.413877,-128.283009,-138.999781,-119.301379,-84.681797,-73.634557,-111.114964,-211.056464,-228.590751,-194.590783,-143.881511,-138.143591,-81.339812,-30.935134,-2.10723,-43.449183:-200.330318,-248.886843,-259.434221,-188.448755,-129.825764,-60.167293,-54.915354,-101.606465,-167.717945,-176.837942,-136.184366,-92.839571,-45.593522,-67.134658,-118.012065,-124.846988,-151.386483,-186.085884,-179.48607,-108.675155,-68.591763,-65.256248,-98.6718,-193.346316,-279.250314,-278.161774,-195.141696,-132.662973,-9.409381,25.634042,16.236804,-31.532788,-140.524422,-100.575331,-36.207915,48.113096,45.698349,-20.511252,-60.236558,-150.832953,-211.30627,-170.199688,10.414882,86.171379,143.901374,125.345667,-1.798183,-75.766674,-134.970507,-119.742343,-109.652434,-35.938334,19.628542,21.295046,-48.094757,-190.969492,-194.897356,-145.153699,-24.151896,25.224439,110.907396,135.522403,84.745234,11.378346,-162.172998,-239.745909,-219.625554,-112.979501,-61.805603,-41.597699,-78.580704,-207.161457,-243.907609,-191.556841,-35.328861,44.920771,153.176945,139.652072,12.298133,-46.993322,-81.077026,31.119233,113.971797,225.447403,230.574072,158.712909,124.118088,100.389693,74.479452,62.577597,69.339033,93.075568,112.519961,63.277036,-125.821793,-214.177323,-297.598299,-253.947894,-220.775444,-171.028026,-141.979397,-87.068184,-79.60728,-98.206422,-97.340237,-103.84145,-138.628332,-132.937123,-87.432339,-100.473306,-248.560903,-341.241798,-417.331445,-338.734384,-283.255741,-148.948443,-82.901557,-51.697823,-80.669613,-110.506806,-47.527625,-5.192522,17.447006,12.901167,90.456126,147.850451,158.4849,109.202605,9.694017,16.965944,37.245165,70.013753,74.553657,43.14663,26.282598,-23.061107,-77.048824,-43.33903,73.631448,86.206642,26.915608,-1.586031,-70.11405,-148.982738,-321.611368,-288.612594,-211.608149,-79.687963,-35.21947,-14.05499,-57.805921,-185.144569,-163.432079,-82.679193,83.275438,129.728214,155.4273,139.473201,50.27233,-10.197787,-84.861801,-50.806601,-38.122097,-35.72093,-20.957084,-22.503057,-60.94837,-147.205091,-136.898488,-84.522253,58.099311,110.26323,124.968424,103.308576,40.429864,-15.450025,-128.208648,-24.331612,82.327998,209.393647,218.748159,174.819764,142.794746,68.133682,-74.196899,-126.127261,-85.42992,-24.794104,62.992008,76.426768,30.965386,-20.704681,-95.876377,-65.691467,-56.875482,-99.640107,-104.983953,-79.531049,-97.236631,-203.721283,-234.983547,-166.147832,74.281956,179.824994,252.041624,232.856714,195.809948,177.659361,120.41526,141.295582,205.040057,374.209281,409.95401,301.079293,213.341355,109.396864,111.791166,127.919133,133.68265,150.168394,235.757716,258.903187,211.012915,157.400346,87.793096,100.457665,102.497737,118.164165,148.618565,191.066723,173.935088,55.808953,-18.229486,14.387899,105.087189,118.579632,109.859705,89.478455,-40.283288,-130.718527,-223.423924,-97.549607,6.301823,141.148694,158.053799,128.593351,105.335794,71.672478,88.216359,135.149631,236.471399,259.886687,214.756127,145.232449,14.424053,-15.062819,6.661937,127.526371,182.79787,229.577558,236.289676,229.242595,211.678938,142.439994,74.94793,73.534631,140.744879,213.31501,386.941167,429.853287,355.703917,282.66678,238.908925,299.518517,313.838809,360.309896,402.213242,423.221206,384.55139,229.291643,77.094054,60.102511,173.830205,274.188505,384.508902,340.200372,127.977275,30.029903,-48.469354,4.619679,55.893842,196.563534,239.974872,146.491555,43.035556,-74.031941,75.050336,179.203446,237.878246,212.667704,196.854012,196.979612,130.510316,82.019511,31.303506,49.174945,78.658784,134.015779,128.838986,75.533713,62.840502,72.120684,108.338394,125.917329,146.561748,173.916479,226.293318,196.513714,45.897716,-12.49347,-44.448495,-2.20963,47.521111,170.035549,217.009134,251.732804,233.56821,105.492433,-16.877781,-11.198288,119.853019,194.108332,213.355301,158.995044,40.948794,-1.241473,-37.875318,31.449813,95.595549,228.158495,252.913254,148.643574,61.55924,-55.548638,-23.318184,40.814057,169.330428,207.522229,222.306556,196.907319,66.178787,-29.633951,-162.231845,-129.745743,-81.103316,14.793446,44.544839,72.264983,79.732653,61.534659,38.414085,55.328713,124.583387,160.041933,190.30584,163.247824,22.094769,-63.095412,-149.120233,-35.643315,84.719355,269.241949,251.395796,99.926586,46.423501,-76.644361,-234.943091,-231.420325,-35.065092,87.502131,214.432332,187.599974,39.023513,-33.581947,-132.760056,-157.805395,-151.713987,-102.077825,-61.460174,-16.465764,-27.915113,-96.52125,-134.147212,-124.115266,-64.458374,-9.588344,108.896552,130.996123,62.066037,-11.271992:48.635584,-56.92185,-49.051475,53.475678,98.529985,100.825707,85.731587,93.778293,27.043509,-48.948241,-96.806173,-41.046343,44.10392,34.032365,33.864481,46.56456,-60.767723,-276.520648,-320.568126,-255.351381,-203.432463,-162.481207,-187.649675,-322.499533,-481.960223,-502.808596,-361.0051,-249.850984,-112.477948,-118.259521,-230.770193,-293.073203,-354.062222,-270.40793,-191.536028,-48.256121,-8.205644,-50.948583,-119.629195,-193.225788,-104.043144,-33.179804,41.899164,17.528012,-19.928909,26.502201,145.613091,138.714198,-12.512361,-90.776477,-42.021782,108.253533,131.352347,60.254369,22.615207,-26.365588,-34.982976,2.981207,39.420284,6.444407,-11.018614,24.743801,85.247418,74.473877,-80.303402,-203.260392,-182.321007,-107.823135,-87.358874,-39.54014,-28.113419,-88.17861,-159.065033,-131.890482,33.489996,125.288744,249.017219,245.768799,131.785231,91.800504,101.962913,145.589109,175.060603,249.182365,281.674829,292.748198,275.353081,197.228995,53.113965,-1.395258,-26.237081,-6.709788,71.878644,86.746926,7.252404,-29.05209,-11.669391,-24.316518,-61.576798,-72.78784,-24.146543,74.296116,92.406241,96.700818,57.146495,36.318166,40.275734,58.40346,87.115842,82.152769,27.961578,-11.896937,-103.900592,-150.744148,-148.091624,-123.520827,-98.370877,-36.818156,-22.357811,-33.388048,-18.778644,16.086375,56.949556,43.304184,20.42967,29.278141,74.898086,106.071749,165.147005,180.926624,168.216465,138.915757,128.520264,68.14873,30.104344,7.702544,-30.844382,-47.040424,4.680234,29.493416,8.038826,-28.889871,-127.071187,-168.718907,-219.153929,-146.643803,-69.235289,29.496308,44.821001,48.936797,36.218296,2.867758,43.626701,109.404215,272.484653,336.55161,420.234204,423.534063,307.170957,233.936813,210.739342,285.775461,289.777684,254.491969,249.161479,214.274471,159.632741,34.298303,-2.597131,25.643185,102.093991,121.36062,131.786516,115.137594,34.693384,12.614588,73.054323,134.805162,130.583298,137.019115,163.308713,194.808169,162.211412,-12.381246,-161.098238,-162.24809,-89.404463,-85.879477,-134.644561,-126.667093,-29.97109,-6.378596,-121.951423,-260.438947,-287.754036,-330.914044,-354.587292,-398.75589,-417.99909,-402.799841,-332.44082,-283.434602,-144.45597,-81.532543,-5.765619,24.914009,82.765194,81.640724,13.332906,38.373312,95.726567,191.897579,223.200141,239.749533,222.457753,195.415105,215.29603,235.818074,254.187286,244.677108,208.75321,184.69746,153.878982,164.060256,209.138444,210.969447,183.00472,136.607837,163.890861,269.423416,276.740287,195.560954,153.137683,151.917214,99.271087,53.42064,11.465468,-0.163163,-101.846925,-189.557947,-334.558494,-322.293973,-285.798321,-233.880575,-210.094072,-205.88662,-227.972447,-181.000254,-60.384455,-41.16603,-52.272696,-58.778677,-82.350766,-113.591934,-180.598541,-192.490712,-235.385852,-261.137692,-213.659925,-53.77029,19.164947,57.106599,12.167643,-77.181479,-77.89068,-45.357094,52.30922,94.684731,178.730467,203.569806,162.659338,120.355979,33.291535,-13.420267,18.172818,171.648662,239.246741,274.854505,248.954083,125.818779,-39.918855,-79.15081,-25.221671,27.819122,146.075356,198.90449,153.346685,36.259941,-209.153161,-237.849125,-189.673036,-104.321512,-94.467453,-111.600192,-104.387879,-64.911572,-59.868048,-53.999011,-21.264984,-19.450249,-36.995018,-22.560488,30.605519,20.614975,-85.611095,-119.589197,-88.916079,-58.834085,-70.473339,-74.967988,-50.770848,-3.12453,-84.661014,-145.775103,-134.360421,-49.662058,118.722195,133.114506,60.075688,35.531268,10.075414,-91.790886,-142.034749,-107.290995,-30.041106,85.964777,93.17767,38.405882,-36.046657,-37.455127,30.896898,68.262863,98.454115,69.481387,-59.652558,-111.126269,-133.358921,-97.870477,-76.533595,-24.042346,14.468351,71.414138,78.170379,64.665379,32.436161,44.555197,113.02514,134.518328,174.118795,191.867601,140.505738,53.646558,-163.378541,-194.349421,-132.065864,-47.183757,-39.401531,-20.082708,-4.974947,19.294036,21.203435,24.241656,54.335077,80.424735,138.201138,157.534551,155.728077,117.489402,-14.007241,-49.542666,-16.966082,48.222413,53.690357,-19.011435,-73.205533,-112.7535,-69.665532,-41.201071,-10.291713,6.022034,94.297055,127.692924,89.219807,48.841391,-10.51402,-62.842007,-92.511059,-140.5774,-151.766397,-192.961703,-221.756932,-209.488992,-171.616963,-183.851686,-204.429531,-186.071079,-95.794786,-42.43108,-3.595144,-40.744773:-172.666759,-240.671384,-231.182596,-109.812693,-43.409275,-3.138871,-26.882752,-99.857999,-153.966167,-152.290511,-80.217292,-36.70895,15.706154,12.208141,-57.01051,-109.570599,-230.956486,-304.622943,-287.788666,-169.446928,-117.10042,-134.951353,-204.899482,-341.774137,-339.363663,-280.841995,-137.530086,-94.199131,-72.761018,-83.579535,-134.831416,-170.441904,-218.301315,-199.735564,-205.185402,-238.054693,-211.600859,-121.793728,-122.249297,-213.182182,-251.718724,-203.254901,-72.76493,-40.18558,-11.591583,-8.541605,-22.412051,-22.011921,-35.85343,-73.293935,-59.039605,71.474402,134.570314,53.742018,-74.760836,-255.567614,-150.322811,-17.285848,186.127928,201.698815,140.671683,97.272375,-5.141624,-56.766728,-161.006112,-263.599915,-292.708489,-262.925501,-214.588738,-117.586596,-97.252989,-163.950677,-234.38581,-187.600944,0.76079,74.389641,116.640204,85.24988,-13.983178,-31.919407,39.101995,134.557673,155.252031,204.588784,254.069514,283.109136,223.206843,68.33421,27.74707,28.850106,12.703206,12.295063,11.505573,-20.933082,-124.639196,-162.613948,-204.281322,-235.311544,-243.669425,-183.082302,-102.236747,-11.96966,-57.889518,-173.271906,-161.615049,-133.594262,-89.076744,-73.775615,-62.370671,-72.09647,-137.859543,-192.926051,-281.144912,-244.685525,-205.184123,-149.4224,-104.87661,16.831213,41.740871,-13.258435,-11.867376,50.476294,131.894823,111.740232,69.358869,76.930144,98.465442,95.995938,70.781305,70.324054,79.043537,87.799836,77.602713,4.98738,-48.373444,-129.264355,-125.390117,-96.608211,-50.331291,-32.618422,44.246403,72.775187,-25.005605,-146.492882,-353.766648,-283.636231,-172.696997,-38.284717,-34.506503,-63.282509,-87.240648,-150.637725,-114.04658,-26.737727,153.374391,201.923567,249.695305,235.300991,108.070606,44.959692,3.589602,33.344557,45.817582,72.098065,91.264534,77.421707,36.498742,-52.268345,-89.818205,-72.785502,19.419564,66.049934,114.913524,101.572739,-10.317772,-67.867053,-67.063729,61.986545,116.325457,169.081085,175.769827,113.99767,55.278991,-53.915092,-165.970279,-191.29437,-128.531674,-61.524821,47.574492,35.361228,-78.23403,-106.30034,-87.328008,-72.140161,-95.047309,-192.812852,-227.448597,-235.189211,-231.390833,-254.333027,-279.636358,-240.050402,-43.900854,70.324164,200.67976,185.249654,93.429993,78.458908,103.412874,135.817304,172.953381,290.989589,337.954862,330.84683,290.649793,236.082193,231.464161,237.951375,281.468733,317.852864,346.320821,318.020647,246.061692,220.941665,181.1976,168.141173,163.877479,180.022409,219.000036,291.098835,268.693578,133.847211,87.488723,122.382646,206.73411,226.808671,225.498573,189.37944,9.141702,-101.060028,-243.605593,-196.484777,-105.159949,67.7311,100.175887,59.487411,9.840023,-51.438135,49.785542,143.135074,242.356973,216.873573,102.422326,41.687311,-59.702547,-80.296891,-44.503848,55.690753,123.138914,271.350876,320.02263,290.455639,229.468251,128.818417,73.1255,56.860249,95.902864,171.063123,357.223422,393.514977,329.461163,279.379247,215.09634,208.957806,225.406163,316.615776,364.583795,361.555514,344.128255,347.420868,203.188456,98.292763,99.762323,220.479642,441.008653,432.172164,180.622599,37.083198,-82.777878,-30.784181,-4.837895,71.324189,118.000286,59.642393,-37.942977,-136.991464,-45.484474,14.917571,107.368211,139.572988,180.541993,183.53378,104.874514,13.890319,-173.465918,-142.444073,-44.521239,79.376277,48.957913,-42.348645,-18.096433,60.383912,-77.090747,-148.40949,-97.783198,-19.448445,69.674404,56.880854,-51.077009,-101.114802,-102.056948,5.461636,54.443829,144.034535,194.720476,187.568653,127.081661,38.227193,-9.199939,-22.472501,38.004549,91.163391,110.501434,69.460062,-23.150542,-63.766996,-138.685115,-107.960593,-47.248306,89.434717,142.5069,158.88751,121.588749,6.946551,-48.977252,-30.914671,68.087861,129.40697,160.568536,107.022586,-54.683732,-126.459225,-189.275099,-122.146332,-73.077041,12.599201,34.672582,-23.471766,-77.902535,-79.590185,28.479444,53.481741,79.162484,130.953729,267.332105,278.705705,139.157733,27.82484,-157.372591,-95.502195,40.277557,268.044701,267.710169,91.174072,-0.591129,-82.856539,-54.556056,-5.963753,122.55674,174.575735,220.385541,205.60918,100.172934,29.829571,-90.868003,-147.473632,-142.869616,-60.256595,-12.208211,-42.671709,-111.743563,-192.398223,-149.909356,-130.080925,-150.772231,-144.895454,-20.350132,44.485293,9.959486,-96.257733:26.509786,-68.494767,10.572667,235.24438,280.3729,214.6165,157.242909,74.662771,-23.077912,-89.772873,-190.877139,-193.275557,-103.459842,-45.574675,20.731563,8.756309,-121.04136,-251.384704,-265.837339,-271.753145,-294.561787,-320.394238,-292.903159,-226.895522,-316.500931,-362.959061,-247.559882,-131.649921,5.603663,4.302214,-84.307703,-132.015007,-165.630008,-142.890451,-133.91124,-127.935787,-119.63852,-114.329343,-136.53201,-158.371156,-53.007277,10.300453,46.348438,36.650438,55.963962,72.341326,69.265277,65.238973,71.314591,48.980515,54.054648,165.734871,211.954364,90.401039,-31.970855,-167.116361,-165.937374,-151.192688,-102.216561,-75.326957,-16.86176,15.299228,62.251789,65.499838,0.66091,-55.584944,-45.874153,-8.604564,22.820324,121.128793,145.980253,97.477959,3.032737,-41.277575,-97.41896,-78.290695,57.435164,99.595957,21.166816,-33.353836,-58.413257,-54.553392,-41.162459,18.475888,67.75101,166.885869,158.722441,2.576431,-136.608588,-141.821338,-66.887851,-35.520093,8.745057,26.546185,-0.864053,-37.514321,-97.924657,-136.995233,-172.243293,-210.471356,-139.867624,102.910526,162.706536,115.397944,35.809048,12.206982,-10.850102,12.57796,119.610388,140.282384,80.42502,48.334676,-26.926063,-150.093278,-193.705806,-249.864579,-264.998343,-216.785086,-157.96035,-47.127889,16.322506,32.416529,-14.989104,-65.941166,-84.189022,-36.717247,96.107719,150.510912,150.992067,29.588887,-27.264206,-41.848291,-6.81557,-40.40668,-116.706201,-195.908401,-206.686091,-228.534679,-264.156448,-260.972536,-217.168928,-197.459544,-180.659298,-171.940289,-153.203591,-111.978359,-67.257304,35.292457,67.22123,71.688289,71.550254,103.635223,125.035527,154.349088,293.707669,361.697883,415.665738,410.988777,360.308461,327.195005,250.610549,145.17086,80.125617,-32.05859,-49.734308,-66.590366,-97.133998,-163.31266,-201.506855,-205.288098,-175.46987,-155.08081,-112.46288,-84.206938,-55.570298,-67.657397,-89.416137,-52.169092,-38.208753,-61.642583,-59.412494,-2.523904,-1.950235,-99.858208,-220.119309,-252.061911,-283.55375,-299.328665,-257.87987,-203.9904,-198.222115,-266.635098,-426.835614,-496.335856,-499.251293,-482.030528,-464.36405,-391.174739,-342.555934,-296.863321,-331.052615,-307.689457,-134.771242,-52.791412,-40.01981,-89.297474,-140.832118,-116.265442,-27.519637,46.975693,62.262711,39.834401,26.859158,61.351212,119.184948,241.520794,228.097058,192.847635,151.45418,133.231386,78.11827,52.837061,12.890626,-7.316584,-4.762449,56.171385,70.054658,65.521411,73.087111,89.815674,68.253024,-0.797998,-10.606822,-0.889496,-23.645329,-67.961552,-151.453333,-163.664859,-190.101807,-242.541369,-374.42214,-360.931334,-310.394886,-220.924471,-179.25334,-129.929807,-140.997819,-173.834777,-130.049026,-81.074568,-1.869339,0.39776,-34.280275,-60.105071,-146.732131,-195.465218,-263.097313,-223.957214,-181.268118,-161.895636,-167.613183,-119.168977,-71.032891,-29.521919,-86.939988,-104.304058,-49.47065,20.498891,164.743785,184.731814,105.138286,64.659724,40.495352,5.790295,-12.343443,0.85619,30.400035,88.067868,111.596524,108.557571,-40.903626,-103.99831,-60.683574,0.033124,59.368517,46.971466,-44.077688,-110.398522,-244.301481,-322.237737,-336.678633,-310.451374,-267.72509,-170.278851,-126.986711,-49.133162,7.816589,31.978941,24.382708,-6.630723,-33.342513,-25.418999,-16.567797,-14.091975,-20.549279,-103.085132,-151.488197,-168.464444,-145.459858,-99.135716,-78.95062,-43.031471,-106.577023,-164.49739,-166.215734,-102.364131,3.386262,6.429362,-3.886562,19.959488,32.246141,-52.743136,-65.685641,-26.64426,-7.412079,15.786507,9.304577,-45.296232,-40.502102,10.363425,99.191976,95.080656,67.710338,63.054266,6.854496,-44.058011,-164.704054,-199.363792,-138.832489,18.454042,53.974427,57.939294,49.504323,39.551887,98.525999,159.323662,269.863312,296.420973,290.389547,245.417618,85.423786,17.776019,-25.244182,44.573074,102.285043,133.119487,96.545861,47.58135,70.617922,162.841426,145.228365,96.271155,99.167573,164.816413,269.301916,293.074182,359.899884,370.481991,222.48772,28.119868,0.215151,-3.69238,-8.968055,-11.278917,-28.777002,-94.560888,-99.629483,-85.049155,-63.642566,-32.939047,92.627944,141.158985,156.244671,134.933733,26.544871,-51.748436,-53.575174,-91.441831,-127.266216,-166.112434,-158.260421,-85.191227,-34.408337,-38.473708,-52.729785,-32.853844,65.712106,94.740412,36.955319,-17.967624:122.23475,-57.681059,-33.724237,170.253494,277.470856,345.307262,298.820438,176.134768,74.969189,37.150417,20.487939,30.608331,79.099066,123.565899,209.702114,210.236957,70.022197,-118.700402,-171.7189,-228.299597,-245.257548,-242.870008,-248.594732,-341.335783,-452.442251,-451.715035,-327.131861,-252.223595,-158.378739,-145.491218,-190.411436,-235.404002,-294.169057,-223.237189,-157.790316,-27.427852,26.760189,25.106954,-30.48919,-70.569342,68.75087,149.53631,217.628729,202.6836,161.937677,158.579404,163.130161,159.86196,105.873654,71.211477,118.523734,239.243398,238.578418,92.387701,3.930639,-91.579944,-86.179357,-67.34122,-82.889847,-105.352989,-64.242195,-4.196023,100.894083,106.662241,-10.664188,-96.934136,-59.632352,84.148289,130.058787,123.724282,94.033773,33.976541,-45.167421,-72.82594,-51.706981,-13.724678,110.621451,176.879276,205.199372,172.054667,81.766834,36.2279,60.373925,119.89099,118.752788,88.882632,74.052329,19.42346,-92.456802,-130.377815,-65.212162,4.20493,75.503544,60.732694,-20.566269,-50.303124,-38.281016,17.104477,32.223768,56.509794,93.208844,244.667017,330.692158,372.760016,204.515925,111.744235,35.254648,63.579317,195.087922,221.350897,81.38241,-21.827179,-109.099363,-67.152574,-54.573773,-110.654586,-145.67899,-108.522894,-44.156976,45.166489,39.64036,28.031587,-47.995118,-92.464709,-61.630182,-16.447677,2.943385,-10.191501,-5.340189,66.8943,104.74671,168.985439,198.75217,167.444148,115.551276,69.865861,26.78098,-4.791782,-35.945996,-51.181383,-63.225711,-48.328281,-40.962043,-65.800056,-116.738187,-60.472089,-6.472202,74.392037,103.030226,155.340065,169.808731,150.068998,163.013201,213.977365,345.167833,406.680932,509.443752,519.613922,412.912649,339.049444,291.549706,332.376545,307.48962,182.359033,138.711089,99.788947,91.619366,89.048812,88.7432,103.605665,118.156184,89.118992,51.765766,70.670296,93.484709,71.442344,32.873925,77.908005,86.519221,30.457188,19.130328,34.730689,-1.829284,-153.504465,-268.193864,-305.290959,-385.922358,-417.492092,-390.014462,-353.504727,-321.799017,-331.225171,-408.660138,-476.212288,-484.459894,-499.864249,-507.287223,-523.579238,-531.089891,-491.40045,-410.228337,-373.486835,-288.735211,-241.550069,-165.092778,-142.119168,-130.840714,-150.509847,-234.136587,-206.564946,-130.58932,-13.314987,2.414403,33.176687,78.405994,173.100497,143.946044,118.681046,111.240123,105.913829,88.833064,77.64033,17.07025,-14.991411,5.131093,98.861614,127.760951,147.842651,151.782933,121.308191,97.85309,89.651398,59.013657,24.828291,-37.01074,-54.538324,-71.037349,-96.560645,-200.993895,-245.666265,-284.279957,-324.234948,-354.264344,-388.125174,-367.562339,-296.342902,-281.356723,-287.741765,-271.465908,-221.20142,-74.803963,-30.570809,-74.988838,-152.667266,-296.440998,-320.513798,-328.745508,-342.121439,-316.941967,-216.027543,-182.68958,-186.828086,-195.65434,-170.503159,-187.961912,-214.016858,-189.924332,-137.761984,-26.811747,5.171304,22.437787,5.827307,-121.859068,-198.107318,-153.016254,-30.943797,-0.922432,1.846224,-13.468829,-42.256841,-119.408466,-163.810308,-138.392595,-70.661895,66.271654,89.931812,-27.54436,-138.684928,-278.509319,-228.309479,-192.11599,-151.789826,-120.048303,-77.332441,-81.410492,-68.000813,-18.220283,-8.788328,-84.026272,-131.255444,-90.105892,-33.479734,1.714929,-10.464076,-45.009148,-90.803612,-122.816361,-155.88444,-133.351317,-86.161731,-88.139947,-96.919708,-79.308594,-59.155845,-28.00698,-18.724683,24.597816,45.395936,65.431151,82.142779,65.742903,-90.118434,-162.478562,-162.388406,-90.943507,59.870519,83.090643,56.608187,63.92948,70.617776,58.673952,72.52631,145.150141,148.561125,67.525844,27.041673,-42.271141,-125.358555,-132.390105,-46.036804,23.264156,124.519514,122.596691,40.588324,59.416825,133.537445,228.877415,218.956297,202.048966,213.005688,218.620403,195.173708,102.06496,30.240207,28.808943,95.03251,142.221693,165.91924,144.315702,116.818112,101.416583,107.448409,158.749308,179.353216,178.381078,171.721128,206.95413,216.446069,83.673428,-41.414811,-7.759397,121.791719,161.270879,165.35902,118.111015,-30.809685,-61.398043,-8.302319,75.188768,80.36833,135.626557,193.876943,245.363733,204.411331,39.988134,-42.639482,-45.410723,-107.095104,-163.44868,-221.535339,-227.407681,-274.017573,-300.060912,-265.379165,-155.372318,-112.243187,-50.228795,-29.180333,-42.024614,-67.786278:-106.159554,-147.124187,-104.561085,-13.943216,7.16574,1.04303,1.435158,-10.58055,-166.172663,-250.777441,-265.371941,-194.224251,-33.775662,-3.495411,-56.682978,-114.004467,-262.755002,-334.279458,-300.301238,-204.653147,-188.832982,-216.956732,-252.155664,-310.841204,-282.109232,-248.389211,-210.882937,-190.497678,-83.701955,-35.416879,-45.865538,-79.417965,-124.348175,-138.714979,-146.349281,-173.459311,-190.703062,-229.718188,-230.404813,-184.339254,-186.175786,-187.040072,-109.478156,-62.331769,-30.801581,-40.192109,-47.611422,-38.584756,-74.719595,-142.559999,-127.367539,-27.533153,3.979705,-52.995429,-116.698554,-170.555475,-92.82329,-32.91586,41.620169,43.166605,38.355977,37.424193,-13.682887,-52.672205,-118.356764,-138.801082,-119.58667,-63.6965,-37.056373,26.676621,32.050769,-50.700724,-91.835394,-70.176132,-29.853689,-14.81361,64.512164,98.084298,45.184791,-20.569212,-121.932324,-69.797595,4.343751,119.84566,137.932179,141.455726,149.741672,136.244772,104.005156,126.424135,151.987589,108.032692,12.697999,-1.959935,-4.842649,17.573935,75.658506,-52.691484,-161.037988,-266.248857,-235.154366,-96.435893,-36.108693,27.546336,20.138004,3.124401,-44.509481,-55.911113,-25.836746,-18.704469,-23.066722,-7.249549,-6.342365,-96.901288,-144.474143,-156.135992,-115.798327,-18.822369,16.037917,62.668808,100.339474,128.649186,165.487796,161.353231,122.667096,80.787437,2.985475,15.639691,95.582716,102.625688,83.364208,36.123566,-5.290791,-146.687616,-203.664289,-206.236731,-170.22432,-153.972586,-84.799482,-62.127036,-115.33633,-165.174017,-203.730876,-192.150128,-161.898678,-155.024996,-177.61481,-207.556954,-170.000947,-58.957181,-35.407563,-31.576978,-3.12467,31.784179,150.425861,227.547353,344.851775,336.525497,234.350001,198.363952,131.260914,64.548585,61.528557,99.062814,120.152292,77.523934,15.674603,-51.835448,-65.093762,-89.363729,-135.231128,-131.842593,-70.934275,-37.372754,-10.204673,-14.56063,-42.900468,-65.1289,-60.109062,-10.941091,32.620041,103.9458,89.245406,-64.532886,-186.565969,-168.8756,-79.439444,-64.721185,-48.552318,-23.500363,-22.87186,-76.570278,-244.09854,-343.17195,-354.88124,-362.530397,-339.108906,-228.491373,-195.618349,-235.161759,-286.860163,-247.796484,-63.536113,-5.905153,-44.167781,-69.802544,41.20685,140.956718,203.580552,126.803009,109.399085,135.382348,165.500908,199.462222,188.302934,153.737761,163.090181,198.690058,287.748874,302.280663,239.25723,186.423381,83.546652,32.254953,13.693599,129.159127,163.687037,157.64684,161.637179,178.008547,160.945403,88.16031,11.986997,-3.890407,15.543954,25.406813,27.048765,14.222302,-95.148137,-177.940782,-255.26189,-175.106385,-125.220696,-71.633172,-63.319787,-61.502828,-58.224863,-23.304433,-27.655135,-32.089768,17.444121,36.890597,-16.735654,-71.210887,-120.315266,-108.791683,-114.482705,-102.808335,-67.310126,-28.009422,-11.72259,43.946959,29.731211,-72.959093,-19.085843,65.256992,159.651218,154.013248,176.065196,222.726704,256.086811,208.357878,63.698556,18.610074,40.390632,125.021544,175.591811,241.993171,252.922612,208.067318,43.206461,-10.935949,14.356174,36.43827,27.873857,31.048743,49.08291,12.292787,-132.885691,-200.888381,-205.011225,-154.564489,-102.061498,-59.822486,-82.208917,-109.90224,-49.163247,14.226799,136.732555,152.780146,129.338966,121.643335,71.622359,20.416776,-63.242822,-102.97118,-112.480623,-100.887115,-105.151741,-125.550945,-84.195685,71.423096,0.329766,-119.315252,-249.82359,-216.576561,-77.050415,-36.404859,-35.97936,-36.421584,7.297317,86.023113,103.873076,58.865973,47.411138,85.13841,82.534845,18.833384,-13.285477,-6.118672,5.161921,6.447691,19.995984,16.601711,4.719345,11.452993,4.710115,-9.23749,-5.483548,25.43526,56.921543,87.210685,59.168348,-10.812839,-12.006302,17.235635,125.852049,161.62223,86.004701,4.126072,-76.766205,-79.946575,-144.49833,-158.714404,-106.228138,-41.525282,-57.024432,-98.286732,-81.305773,51.544015,114.819638,75.96897,53.485422,107.744774,193.564893,190.510551,170.627107,157.550144,65.801979,-10.499704,-6.629046,8.007075,6.444635,40.665229,70.677518,42.7977,-80.215027,-78.244775,13.046367,34.278906,109.306206,175.791742,214.038103,175.165551,53.607943,-37.428174,-51.806227,-60.968152,-70.043584,-95.331533,-107.934518,-84.678648,-12.694996,-17.233277,-99.782845,-113.737509,-24.64997,27.231818,23.229241,-29.416598:right
-26.492696,-71.915994,-80.317699,-28.555664,9.975335,25.735143,6.137734,-33.026327,-26.247748,-27.259327,-84.785033,-100.437912,-55.112812,-33.303373,-10.686174,4.989387,-24.673425,-202.703662,-298.871063,-325.001392,-254.580824,-111.740197,-81.903598,-92.140016,-125.140471,-151.869423,-212.802295,-214.276613,-128.74601,-70.090191,-11.368898,-16.295767,-71.784807,-199.158271,-255.774872,-219.571145,-139.649364,31.083121,109.138487,166.619642,61.553795,9.031142,-56.357152,-77.178479,-90.494923,-77.629926,20.021071,81.977022,116.817097,75.017828,59.715095,33.127033,27.389367,112.59298,206.970196,316.701261,226.369074,182.470726,167.126952,162.758038,133.66002,142.002093,200.868369,204.279719,132.888315,50.244817,38.684066,144.817902,235.281478,336.955522,316.125761,174.084974,93.132844,78.157674,9.581328,-15.083836,-17.72418,-20.129332,10.018541,42.907269,70.9936,16.482123,-16.338868,16.828765,60.918522,126.543515,155.066491,124.579241,-40.476965,-108.136143,-180.20006,-189.088981,-123.509971,-67.395655,-35.574714,-71.558291,-112.457137,-55.743811,-38.768465,-16.704141,32.090358,161.9016,187.568835,90.067294,-110.761551,-176.823196,-237.98338,-242.932513,-129.956326,-20.289601,166.589106,202.915183,162.111689,9.869525,-75.502528,-137.793241,-95.787236,102.907569,220.193948,292.451059,121.7603,44.351339,-40.357969,-77.259616,-104.457014,-54.936071,124.974203,185.706005,201.322107,123.796127,46.30668,-61.097198,-43.722588,100.840744,182.62675,217.245979,122.081114,87.887998,38.536745,38.878427,108.209014,145.196807,219.416857,255.264088,254.601802,144.557584,82.050742,17.86697,16.623765,82.468543,136.68066,163.035081,103.327825,87.679103,64.350467,69.465953,128.523125,138.581706,101.528958,87.635928,76.180088,26.745204,0.134142,5.903858,45.15242,173.451054,212.768612,137.576927,61.618382,58.061491,15.690917,2.659447,53.167127,105.268417,275.865707,339.246031,214.270909,-63.46632,-141.174597,-160.336298,-142.413001,-78.116525,-23.24664,35.763023,-19.127145,-29.523571,40.527443,98.189411,186.601665,210.256873,198.250408,156.744771,38.79077,-134.145952,-227.619899,-254.112678,-171.105563,32.101226,108.233733,176.327994,147.628471,120.08387,75.450355,68.677938,89.418406,117.799361,201.105039,233.516968,217.225676,115.192475,70.660223,62.109039,91.261338,162.586031,209.298082,254.740209,133.059337,66.698202,28.854084,66.507775,198.977652,247.749828,303.375808,320.690853,267.762798,84.74185,12.020871,56.45012,135.577708,213.362213,218.809715,242.010674,226.989255,195.948414,169.091717,182.069775,199.726251,196.074485,164.808435,128.418535,14.064574,-90.751253,-114.159305,-106.074518,-111.244726,-160.221587,-167.273479,-126.663522,-94.396076,-107.295469,-167.300255,-168.890781,-108.9291,-85.468647,-80.968857,-95.606363,-139.289256,-210.367435,-248.00039,-179.345861,-58.73638,149.404608,161.213999,61.185646,-14.849273,-54.821511,-141.364907,-111.125029,122.160072,212.983614,190.23918,138.071707,111.44719,144.026897,133.949495,38.900431,-21.317438,-60.905744,-23.064331,21.275428,-68.73252,-119.278506,-163.789333,-139.418099,-32.389365,8.518576,48.262665,55.668191,2.470264,-119.802444,-151.200219,-94.144411,-45.926399,-40.97749,-83.009001,-171.117975,-145.314668,-104.996402,-93.99907,-97.608472,0.029919,80.441026,112.616343,35.487977,-115.085046,-125.801807,-115.803814,-94.965497,-103.319767,-156.643464,-150.262461,-75.10593,-60.129331,-79.693321,-125.416604,-135.940024,-122.526384,-89.851377,-13.999214,-20.38189,-128.932008,-264.182541,-295.686846,-210.565589,-167.321568,-271.02855,-352.491156,-418.663356,-406.504145,-371.125776,-260.474102,-223.910473,-237.411242,-238.588682,-105.133559,-24.480053,29.856155,28.006193,7.880784,-100.123617,-159.946291,-165.393406,-106.416907,-7.748656,-44.726865,-108.088732,-256.980388,-312.50955,-317.374369,-260.33041,-136.786198,-124.365137,-137.41303,-88.100716,-90.177782,-171.698255,-204.840304,-202.59479,-171.076362,-104.381155,-131.228784,-168.410861,-210.498788,-187.903197,-91.926201,-63.721943,-83.204095,-124.139883,-248.662327,-347.617141,-374.48223,-399.033757,-379.712825,-238.953685,-150.633678,-63.48099,-63.886434,-62.220633,-91.221616,-109.404395,-63.137406,-10.708915,38.390546,13.947875,-48.687382,-90.804318,-158.368161,-299.602898,-301.760204,-212.724387,-158.083006,-45.329846,-30.483857,-99.488064,-278.190914,-290.779178,-155.728183,-103.278285,-113.824602,-149.343186:-55.876502,-28.375967,-9.3037,-27.700233,-49.404198,-77.364003,-99.366177,-172.730997,-182.366967,-168.756107,-192.469905,-196.372085,-77.652005,12.954655,93.264338,51.916163,-121.508813,-225.446936,-204.830418,-67.338957,-14.699969,12.289503,8.640822,-16.11618,-7.504317,-16.103105,-97.488002,-109.621509,-2.71261,59.10411,79.126421,63.665699,21.695745,-119.706731,-175.038348,-96.533547,-14.865029,67.683445,75.191417,36.128916,-15.952423,-15.28527,3.801646,-1.069442,-34.043763,-30.636938,49.667821,82.147111,72.331548,71.817537,60.323787,-15.498292,-25.02298,139.775599,262.305963,303.676675,119.717664,71.908555,115.983274,152.220433,168.312538,163.123876,178.649899,178.625893,84.23229,-59.160374,-70.224852,76.46677,174.339572,290.343228,295.614972,224.115421,122.249658,61.824864,-45.403216,-57.615143,-44.885885,-51.498605,-24.35742,26.213674,92.62972,-3.552883,-34.727913,65.550967,117.411942,151.718358,182.422562,160.425459,-67.801601,-166.97938,-233.746144,-219.518347,-147.695167,-94.668962,19.843271,54.613515,49.553867,-40.173517,-71.826107,-7.053944,84.074954,259.187954,274.42534,98.877273,-189.754306,-276.204745,-250.769086,-182.456551,-17.150869,65.939659,124.77735,80.962232,-29.046208,-131.509979,-184.60696,-166.193863,-82.145263,161.623279,266.759537,244.338265,-10.955628,-93.661487,-135.517919,-133.342271,-50.112353,25.028926,111.577286,100.913126,30.194994,-7.701499,-8.196904,-6.224992,-16.875868,1.629971,56.26286,129.903954,76.761213,47.542423,-10.144146,-30.280056,13.00506,64.502036,130.851334,124.950239,71.529699,-21.27155,-85.640122,-181.35174,-183.312683,-48.885094,47.348444,96.770613,-25.360268,-75.945586,-120.160125,-121.111078,-69.838645,-45.076126,-66.058516,-91.561865,-144.347153,-191.211925,-160.931354,4.097006,54.254057,13.849906,-23.990541,-128.259689,-220.56924,-207.482034,-134.403476,-102.34378,-47.505989,-15.080528,114.606974,183.318039,171.071835,12.124458,-41.899504,-63.469414,-57.310883,-25.160466,-4.563381,15.843777,2.970253,-27.289271,-49.227403,12.829573,156.452328,167.849157,113.709155,68.684698,-55.990286,-198.05284,-255.30221,-269.685149,-212.540355,-22.637214,54.289049,93.465866,87.136056,66.439315,12.235835,33.878413,134.844586,169.750605,207.265207,214.055738,188.884588,144.895714,143.285975,162.239355,148.213178,142.982088,188.641149,179.465982,-30.664044,-93.132661,-84.156813,-61.164731,1.908327,47.404252,101.560222,74.825091,-72.196299,-197.55635,-216.664174,-153.078283,-83.948232,50.348706,85.025121,55.796303,-54.397877,-87.158083,-19.191625,40.701824,43.952096,23.904271,106.736736,150.153469,69.663792,-45.996861,-34.709255,35.256145,4.653891,-142.668217,-166.06294,-119.258526,-106.836231,-113.803224,-126.122355,-131.530796,-110.569575,-68.643289,52.905712,102.69465,112.236359,-24.082689,-71.501088,66.471766,186.269253,268.691562,243.683235,196.074931,171.446182,148.905638,126.445068,160.472422,327.046711,422.928617,494.006375,432.247007,214.315884,104.212397,113.256159,162.816393,155.649201,95.146904,80.648399,31.616276,-84.448082,-131.363999,-182.983314,-179.03842,-87.257418,-8.969964,106.747838,98.992426,7.503953,-64.6979,-99.944902,-111.633152,-59.533962,68.934755,77.923382,-36.495199,-121.399221,-119.507835,-113.043177,-99.03348,27.331176,106.591307,138.144714,91.639546,40.813979,23.810547,-24.783428,-120.764987,-135.911079,-85.477285,-38.248215,-56.011626,-164.929798,-172.360531,-153.782949,-157.511278,-110.034542,-27.048249,165.621741,199.672144,74.090041,-181.784773,-251.440486,-169.250868,-130.73609,-190.735674,-195.784135,-124.927103,-153.425792,-207.028068,-288.132417,-291.671662,-266.168091,-238.367304,-130.684047,-76.191443,45.644971,165.192961,139.396623,-31.555753,-74.021593,-4.006587,53.033215,90.183287,9.836881,-60.119922,-176.280064,-215.721468,-279.811226,-272.331176,-151.562513,-93.29463,-24.561132,39.368035,49.211102,35.607926,33.422762,47.389629,55.441013,-4.583596,-149.761423,-177.666222,-124.359857,-76.286748,1.726983,10.037436,-29.591036,-48.966424,-94.892048,-220.163839,-262.514997,-219.153739,-170.06508,-104.901134,-78.824203,-18.499357,-2.207373,-3.09292,2.252926,-0.549063,-19.763964,-16.445975,23.785487,29.784317,32.776939,24.933238,-33.147656,-122.603061,-99.911333,-39.13534,-31.747869,31.455539,88.420859,40.126714,-82.727657,-59.745297,90.788193,130.87999,87.07697,28.139196:-73.272062,-127.912582,-116.699888,-89.680803,-111.552766,-189.547996,-202.941221,-164.157733,-106.396177,-121.326464,-260.065203,-277.726501,-34.613353,113.394912,149.570276,50.493939,-165.180341,-167.861007,-97.664252,24.383981,36.759965,0.754578,-10.56204,-9.730101,29.058128,69.745101,111.95487,88.031732,43.582698,62.470898,133.516282,154.542416,111.388998,-12.58133,-64.185813,-100.070293,-68.516915,79.766125,130.540074,71.714312,-38.496119,-69.684251,-109.834853,-128.228734,-144.087565,-116.502911,14.541511,69.828667,83.378115,12.761722,-56.92213,-198.791815,-199.164322,-4.154587,120.411546,190.674806,62.281412,6.833479,-10.590174,28.838199,105.910361,106.66268,93.608141,94.495775,28.215301,-80.677076,-74.636031,54.446875,117.199926,152.613368,129.51361,53.726929,26.274369,16.056452,-41.926013,-71.665979,-122.770085,-139.437097,-82.523445,-4.883689,64.217236,-62.141454,-49.681179,207.085748,297.34664,215.295224,138.280445,49.66483,-90.25732,-154.988983,-148.150786,-108.738194,-77.521944,-51.141461,97.165776,164.586803,152.916899,22.087835,-0.093946,107.022682,200.928366,350.128798,345.577555,119.10302,-163.584931,-236.738343,-235.288707,-187.915543,-62.393422,4.785276,71.756038,33.115567,-97.95952,-137.753786,-133.202162,-77.669885,-31.96232,67.02004,116.347191,135.018506,33.949954,-37.107887,-173.757185,-181.246018,-35.651544,55.547011,151.760243,154.627486,129.20763,103.444003,61.348167,-45.958343,-64.251477,12.027686,79.476227,117.617245,13.659744,-37.633072,-79.902929,-63.438648,4.122288,22.716933,13.483069,6.092296,-52.980303,-213.148419,-254.881121,-207.857831,-163.586636,-56.514328,11.734517,83.307373,-13.993978,-87.021691,-146.862296,-108.432201,-7.325146,-13.725949,-135.27523,-186.311892,-188.667374,-245.807141,-288.432499,-172.780245,-57.881808,16.125713,1.936728,2.413781,-66.852888,-116.428134,-134.027687,-95.043034,1.752762,33.844291,67.816153,66.02234,39.974007,45.539413,36.462776,-39.352948,-55.749529,6.733576,25.948492,-30.124251,-34.321256,-15.220662,-5.759315,14.929198,42.761106,28.585939,79.11534,132.79264,67.389074,-208.227642,-285.740183,-189.129724,-83.909044,65.943699,91.656685,114.250231,190.953423,195.09404,92.871125,65.372501,163.230677,246.170922,312.221517,269.52257,155.940768,113.082066,94.38041,87.163021,115.858957,217.652726,249.161241,146.732676,-49.2629,-94.895201,-76.872846,-57.797329,-32.059615,-7.084257,35.991686,19.429309,-84.242547,-199.738339,-247.768087,-286.476958,-256.441904,-131.812207,-86.706377,-82.811601,-123.158833,-124.689806,-75.196602,-54.158904,-66.152714,-42.394071,125.9059,168.502516,29.263935,-91.222432,-53.247132,16.037583,-43.360794,-216.964363,-255.863961,-268.121106,-228.727712,-212.736095,-220.112557,-223.999108,-159.736452,-95.314336,0.958599,24.988185,44.786504,-22.333222,-41.165181,95.448091,200.314644,285.068329,252.576959,165.464793,266.166342,334.89125,298.983252,260.533737,333.378587,415.638629,498.871454,453.733397,288.276098,220.251847,216.104151,190.639427,165.556887,143.290302,129.240374,-10.605026,-153.096878,-163.591164,-141.050603,-138.039438,-104.762864,-40.861361,87.625968,86.966183,15.27349,-52.41265,-93.373116,-140.012538,-113.370052,26.004191,68.847616,4.315106,-117.361255,-155.278797,-186.76177,-170.421648,-61.845097,2.641171,51.002473,9.000741,-93.04753,-63.504159,-34.223749,-8.816319,-14.93685,-34.20637,-40.361187,-107.45925,-185.722292,-185.879438,-147.984131,-115.024025,-12.349334,55.666108,155.382969,134.321168,3.946026,-112.523366,-164.975413,-181.781437,-137.4053,-29.140034,4.414708,-11.210191,-100.874718,-149.736133,-190.558346,-162.818489,-66.738132,-44.081943,-68.257807,-61.064174,86.0611,210.675627,197.848891,144.718861,141.820663,136.355588,116.853941,65.999797,27.581688,-4.910973,-83.172354,-105.954112,-109.110853,-83.498624,4.719605,30.348246,23.060387,35.114492,60.809687,104.215517,115.602346,138.394027,135.491576,53.750406,-55.486217,-99.624345,-207.278083,-260.197614,-262.907114,-174.483594,81.122855,133.343798,0.493539,-219.721833,-276.38035,-212.961338,-133.705833,-11.14799,32.109499,84.685263,43.813724,-4.245824,-81.252606,-74.39222,3.617378,30.181628,50.965265,78.893329,166.338307,92.169691,3.640659,-62.695242,-29.109785,46.861502,51.837697,15.91423,3.856982,-12.834514,-57.624721,-28.352677,116.452519,164.317189,148.49155,95.373016:-144.104671,-175.926641,-179.489171,-130.187553,-99.013925,-77.417734,-74.014735,-36.770345,62.095654,70.740915,-92.551906,-160.133119,-55.7229,37.889196,66.200482,0.207448,-153.298397,-233.69764,-232.273885,-115.089442,-46.407637,-13.895732,-35.54011,-117.228334,-168.172857,-153.866551,-115.141687,-101.82259,3.131579,95.598828,191.419771,164.216877,50.64769,-24.864779,-49.143728,-59.150583,-18.003676,136.395558,203.351687,213.130808,104.980542,32.162716,-128.26187,-173.386681,-137.599274,-89.947919,17.353829,68.055828,97.862347,26.005237,-32.188565,-123.843369,-126.17074,14.585985,124.438506,200.156518,91.618063,53.551899,44.952046,48.96162,17.738505,-11.419282,2.386739,44.613402,63.43867,-1.590203,-3.466346,58.951334,93.663083,164.149238,199.83058,200.042843,109.111748,73.104545,29.595889,1.038138,-66.668362,-76.294212,-20.634018,0.768655,-37.238169,-78.503923,-60.499583,50.667182,96.612922,117.462217,127.254989,102.244805,-86.237064,-171.401537,-196.107393,-150.193849,-25.11635,23.964985,83.710156,100.791261,101.444233,78.329233,51.514731,24.145121,73.724857,268.023177,324.578789,171.037454,-153.665229,-237.986183,-199.838287,-138.251032,-30.699191,7.287046,12.396083,-24.418263,-106.501192,-177.662406,-204.585439,-135.196915,-49.035275,95.49264,138.304451,107.877404,-60.436642,-121.799426,-158.697896,-143.623061,-30.1496,62.150824,237.312887,274.228811,235.212056,144.661231,77.153602,-28.810031,-23.913074,76.109971,136.514041,165.407114,124.975739,128.645342,98.8855,55.052862,6.530941,14.188367,59.54678,84.525927,119.373822,107.782642,73.935835,9.927161,17.815599,132.003742,196.362576,212.930339,178.668223,194.249043,217.158033,202.06622,151.306527,132.340152,114.08503,109.063575,74.516272,-42.877905,-84.612499,-2.559184,71.392352,127.624184,116.761273,37.047041,-37.365066,-23.925354,37.226139,58.444118,105.479995,131.290993,203.055254,230.098259,144.796769,-49.20106,-114.324235,-111.365609,-54.162541,58.374887,83.364679,80.863001,9.957398,-39.870003,-53.961327,6.871085,141.436645,169.764154,211.927594,239.772587,178.027101,-103.783513,-214.661398,-164.281241,-53.998084,133.616086,179.839821,187.224441,215.544048,229.955331,186.572942,159.891844,143.063942,156.916221,236.018419,259.242771,196.35634,119.143555,99.180434,80.609765,102.828757,221.94825,284.368309,280.223732,129.407362,82.561625,91.859363,117.648695,164.812434,185.196529,207.616513,196.740577,126.889909,40.459335,5.739917,-19.909386,-1.675678,81.75387,116.428054,91.897021,7.87237,-10.139907,14.142541,39.757495,74.370722,103.980399,198.832335,191.320896,-0.092456,-165.644571,-157.625789,-69.938241,-86.335226,-221.438519,-266.532843,-277.677349,-232.262538,-226.883794,-267.440795,-270.571088,-206.884744,-161.699654,-110.968183,-121.750625,-164.260511,-153.863655,-131.103414,-41.191538,22.559517,156.217003,198.954665,169.578711,134.359585,155.512858,154.663718,145.753522,260.442274,348.996182,385.957847,317.800921,148.773449,98.106011,110.350491,127.344764,106.654179,75.163497,88.369887,47.529431,-84.748326,-126.905121,-148.443066,-127.541719,-32.486996,25.790029,88.38524,76.630146,22.015811,-32.274471,-68.508365,-140.457241,-143.762236,-55.420729,-19.388266,-59.488382,-121.19012,-150.965392,-242.897751,-255.226642,-137.064897,-71.08222,-86.563219,-157.556179,-260.316788,-246.959102,-237.233151,-200.464503,-172.968891,-148.020231,-148.43827,-170.149726,-194.966816,-195.433641,-187.413069,-177.785464,-100.056297,-16.572012,124.283975,111.763544,-44.281031,-234.889373,-313.694333,-279.99096,-190.362788,-118.97519,-144.621152,-207.27267,-263.512721,-286.743825,-308.599135,-290.704597,-204.350986,-149.95143,-15.57385,36.642819,86.535758,114.921469,89.454204,-20.610285,-59.907655,-51.859047,-15.198791,27.968891,-27.997381,-87.132339,-220.670035,-261.437323,-254.901469,-221.305695,-126.927485,-74.186522,21.246287,49.424813,20.605311,-50.861793,-62.198243,-35.12412,-11.949255,-37.456316,-144.679801,-184.595456,-263.962435,-292.596946,-255.027469,-201.943093,-115.529223,-120.811428,-209.527966,-248.372138,-247.268889,-241.918532,-219.792498,-130.961833,-85.198973,-35.221457,-80.21634,-129.186986,-186.449002,-165.889973,-54.845324,4.959858,74.143463,58.513416,-43.291748,-114.937034,-141.905056,-174.794075,-165.727371,-124.480238,-102.427866,-38.571136,-7.224589,-49.900046,-173.949741,-168.03929,-7.669055,76.056089,109.501662,49.00375:-115.813613,-260.666309,-295.000932,-247.94463,-200.691623,-86.769221,-41.390387,-22.9178,12.331334,-7.949139,-169.772217,-202.234695,-44.100218,47.238661,31.615624,-38.434854,-122.136939,-152.32717,-148.593424,-46.227274,22.16446,103.724151,105.441857,51.200306,1.597449,-19.595526,-53.641372,-50.777483,-4.5749,27.050366,92.079752,117.878224,85.866209,-32.958113,-54.581122,-4.057361,46.657336,187.328838,234.778704,173.852058,21.282442,-65.053888,-256.306535,-320.936778,-276.917207,-166.412421,66.218869,92.481856,-25.904607,-102.820453,-112.919592,-151.299399,-165.894103,-61.526917,37.825827,106.888008,40.439661,11.779577,-41.577034,-51.085965,-18.540219,1.08463,38.166656,60.609896,19.931502,-131.029187,-136.53155,10.183806,60.981329,85.13711,114.44987,140.051525,-11.808273,-99.035116,-142.257435,-110.443036,-76.356046,-84.630601,-70.847732,-37.656565,-1.392023,-88.476972,-109.56939,-19.814314,29.987232,89.593735,120.09744,95.130267,-85.446308,-165.111163,-189.369788,-133.751167,-2.463432,43.822513,114.048606,127.740254,84.61537,6.05984,-3.65175,97.986688,180.658005,308.169456,332.534725,210.665456,-106.824524,-225.085823,-243.221468,-190.766401,-81.708534,-24.719718,29.918253,-12.467761,-168.571369,-262.921401,-275.160469,-225.836399,-158.1211,59.099467,158.083854,126.444836,-74.237434,-130.125264,-181.796568,-177.15522,-16.309133,121.04546,291.364158,255.011832,81.742891,35.720341,25.261397,-12.441864,4.382956,124.879872,176.271291,139.777307,6.669957,-33.583977,-53.089804,-60.258938,-86.74792,-80.763601,-33.924525,-20.384207,-42.070602,-118.232735,-138.771104,-75.543911,-17.34603,80.240486,114.921617,136.85392,80.464666,41.568424,6.055488,1.831056,5.1463,20.376341,24.182304,-5.650256,-131.865745,-287.53428,-292.467375,-93.25002,19.446033,114.679936,145.406071,200.400788,84.650149,-12.844155,-101.767645,-69.077765,57.273012,113.622531,138.520158,93.49631,-4.455687,-67.688906,-125.570839,-208.948515,-177.514178,-36.089151,-3.376772,-70.719134,-149.01955,-174.329301,-175.743556,-116.852077,23.719785,50.187642,51.047744,58.247197,32.672682,-120.706007,-167.54321,-56.953248,39.991657,155.726742,169.212556,151.303493,143.369275,121.198867,28.858022,16.495034,129.035758,208.052115,274.832515,246.178063,148.206948,90.00709,78.798856,85.334392,93.469929,175.023692,242.474766,269.170639,150.357778,79.380409,-4.94964,14.908028,142.653475,199.738188,204.266644,152.001394,29.629802,-47.697317,-54.230778,15.507984,60.16591,114.611816,127.797188,93.611236,-22.959647,-79.582527,-74.774108,-9.195329,116.046965,163.835772,263.412398,259.040781,94.697063,-32.810974,-31.254703,-9.18993,-45.03576,-124.732389,-118.391065,-97.934455,-191.100268,-252.844712,-269.112564,-219.737978,-105.083905,-51.699074,16.967005,2.879557,-61.201913,-84.946775,-75.961274,44.072525,138.277769,296.262249,333.721077,317.778337,301.145216,298.541504,253.00073,256.022634,384.852492,478.348745,582.34161,550.360622,394.035997,269.35709,241.759662,233.480632,220.91559,226.99708,265.372651,265.061213,124.61487,49.85237,-23.036549,8.675126,115.940569,148.741723,198.811108,203.635023,105.246719,-43.962668,-85.146927,-77.561641,-36.091519,91.845486,141.069897,109.645612,-58.857536,-147.285378,-240.16938,-216.191423,-80.818622,-26.529879,-29.805888,-79.078831,-148.384413,-151.43918,-171.075054,-198.961549,-179.766159,-94.748889,-65.595714,-89.455087,-119.127354,-133.269782,-195.466482,-190.062032,-40.763538,55.061625,159.728429,130.91114,-36.41168,-163.196444,-197.680048,-178.704085,-116.735772,47.313368,95.895322,14.578028,-189.238288,-250.073689,-213.750848,-142.513254,-27.21947,-0.705862,17.028186,22.762765,48.183387,30.383647,9.303799,4.802758,5.042915,-21.677329,-29.752426,-25.863803,-30.876723,-74.50223,-226.174808,-255.901401,-171.100798,-110.613198,-48.850504,-44.384791,-60.294795,-101.872122,-96.349753,-34.869999,-13.924757,6.347228,2.783716,-74.008263,-195.380365,-256.693432,-395.074537,-455.591729,-434.613291,-308.060758,6.034111,48.691035,-124.022102,-310.578956,-337.967758,-267.408759,-199.819671,-66.179773,-22.463022,-27.505629,-120.276224,-161.641052,-160.51988,-109.678849,48.046489,130.809487,212.041992,183.160648,86.748587,21.281439,-26.490846,-126.810347,-133.97559,-12.211483,66.072962,128.708925,73.454459,20.086103,-36.175925,-14.187068,47.367357,82.648558,158.074241,144.536614:-81.270172,-200.297046,-233.252365,-194.535086,-143.650503,-31.865676,11.429822,46.885338,80.129758,63.927861,-72.145438,-106.476622,-26.431947,19.233962,28.100756,-8.486487,-172.59272,-310.490295,-313.342936,-243.460559,-210.291098,-131.608595,-78.549235,-55.343064,-156.909974,-215.455652,-291.871501,-265.755636,-77.287965,-1.482465,-25.808474,-67.815233,-76.522292,-107.009016,-156.635728,-176.232164,-115.476182,70.683681,161.487956,219.000726,56.552228,-42.787515,-146.141484,-135.346623,-32.748814,10.863329,13.067985,-15.447437,-71.232092,-100.308159,-122.472891,-183.82304,-195.015562,-90.307395,8.949622,100.294814,-10.000975,-78.489127,-119.263902,-67.974076,49.617146,60.010987,40.783628,38.470983,34.325899,46.036653,73.702173,139.8395,153.926224,156.251999,155.651248,148.679506,141.572837,131.470532,103.836266,105.74549,100.043597,90.628648,131.371924,153.580246,83.959756,-73.815517,-100.322571,25.666563,102.51537,140.228678,130.298348,91.786879,11.692908,-39.515796,-162.357341,-191.655126,-103.133503,-25.952611,55.804885,52.431442,21.947553,50.520236,88.761306,158.039423,180.499016,201.825014,193.370645,88.243042,-123.500454,-195.208709,-152.169966,-73.595548,62.741025,114.953737,197.066533,202.738876,133.44701,-48.252482,-148.139599,-158.103941,-59.714619,163.301134,237.246695,228.76381,54.496531,-14.295125,-106.268294,-141.030006,-115.374861,-41.26936,144.688415,197.209798,182.284433,107.016906,52.067373,-3.230227,37.934538,167.978655,207.009974,201.90827,142.111979,118.500628,65.77128,53.237808,93.586281,130.283853,239.954609,275.13948,189.289194,44.67444,14.741048,44.417137,80.256862,133.947938,140.115941,135.940584,203.49378,236.258521,171.44363,112.135675,104.091929,135.516897,123.098181,78.922491,4.463969,-64.301232,-86.286622,0.821825,95.626046,262.719636,299.881955,206.843211,28.745042,-9.842546,-14.894651,-5.938656,26.829262,60.647397,196.063805,250.779092,150.210492,-107.58917,-174.604905,-147.275974,-102.77732,-2.276698,45.776701,63.143318,4.053451,-9.186564,18.394584,66.594193,204.168135,250.133212,194.365151,103.384201,-48.083183,-124.170263,-174.640846,-199.681333,-127.995045,90.080132,169.495249,220.264714,187.193137,153.230966,109.388739,123.679364,181.690315,199.897432,257.41223,294.544979,287.850699,204.296543,169.249307,133.327219,144.252461,268.287354,354.728318,388.517598,259.297539,216.022021,160.484885,150.241199,241.417434,325.466532,449.482774,430.162222,223.315542,86.964095,95.433285,198.134673,256.784732,313.072108,321.510222,308.350105,209.697865,159.479957,150.869826,182.158171,234.447831,250.961686,262.791742,240.967416,134.24812,33.567908,18.439708,26.696489,23.3641,11.325692,4.767639,-54.404648,-138.942288,-179.378101,-258.263316,-271.997562,-235.390775,-214.11328,-191.811908,-189.795252,-219.092669,-211.003515,-160.133239,8.893812,92.787188,202.218539,214.182509,116.609051,2.235835,-22.118903,-52.163164,-14.608339,190.416841,260.528253,251.451565,235.495987,242.549589,194.207626,156.804058,136.270463,132.922854,124.840657,147.809096,192.663957,138.420967,76.957037,-20.246295,9.669265,156.475753,185.0769,183.511717,187.811065,133.98802,51.715744,27.138547,-17.047499,-27.079678,13.865695,34.533395,-19.499903,-119.734965,-152.753017,-187.067185,-169.812673,-51.314137,11.332634,19.636354,-30.269947,-109.954816,-174.891721,-220.499737,-211.514328,-149.372353,-62.971211,-60.31852,-72.318666,-92.929893,-116.953548,-177.106114,-188.676217,-109.729556,-16.016415,139.548525,115.642143,-111.895123,-310.098613,-361.663321,-330.28234,-263.296299,-191.909551,-205.705074,-260.588082,-266.817675,-256.609158,-277.18361,-294.493966,-253.474523,-182.876276,-7.829868,45.327413,81.187998,98.907067,57.635901,-75.307051,-93.614357,-54.050233,-45.42287,-60.976792,-123.87223,-171.701691,-245.680581,-275.427395,-324.621087,-318.059875,-203.498202,-118.17785,-21.998876,-76.177309,-120.936624,-170.0783,-165.062812,-122.423738,-93.598386,-89.990538,-196.882791,-241.31607,-314.722232,-345.453484,-320.056356,-264.066234,-140.118156,-122.979794,-265.550055,-386.350577,-348.136633,-207.010684,-170.918818,-134.834124,-78.530943,23.90296,-75.222063,-140.894097,-179.509371,-154.725603,-70.786282,-26.892283,70.143521,103.365785,112.24959,85.809975,46.178502,-25.665975,-11.672523,67.811642,90.716062,73.138801,-5.885669,-65.634456,-184.018837,-182.382611,-30.063554,50.131766,98.554611,69.049676:-98.121569,-263.19058,-313.534595,-250.56499,-161.387437,17.609242,74.763504,71.40181,-0.298986,-30.841738,-105.383199,-130.781995,-83.768537,-26.182922,22.432129,-20.202668,-173.03484,-283.623366,-287.235288,-154.650325,-48.40182,87.129664,85.768114,13.832665,-61.160053,-104.205977,-154.781148,-126.702845,-1.536497,48.247758,65.473337,30.321898,-60.459601,-59.421197,-45.883961,-17.19441,28.648117,174.593167,228.85425,191.905024,-34.209262,-183.20114,-380.322139,-353.963373,-126.097329,-12.83837,106.902356,89.183911,-75.873326,-237.375296,-283.766276,-276.354035,-223.625714,-18.912751,99.335871,142.440956,-24.394727,-97.871689,-164.048972,-136.403301,-12.510066,40.234677,120.716282,133.403906,37.430017,-65.37919,-52.250826,44.811937,98.508742,185.645498,193.024822,138.475286,61.169599,19.584862,-27.722358,-22.455212,5.574183,27.455043,81.703852,74.847466,-19.383806,-103.229165,-103.628722,-7.876366,49.33544,128.222991,152.409034,122.72188,-6.9009,-70.884635,-138.490759,-125.392934,-16.810092,47.523689,128.589143,149.795647,174.987444,130.86351,88.616371,67.382739,107.523286,252.201347,314.762549,246.524413,-57.665953,-183.101143,-211.81671,-121.172481,84.207932,131.946038,117.04864,63.324518,-82.834886,-226.087446,-290.584531,-272.545781,-160.724112,111.406711,177.250537,90.216093,-89.196859,-150.800436,-253.915355,-273.775267,-95.874,80.482478,333.277559,341.276827,202.72315,35.522244,-20.577549,22.356529,105.967458,219.170329,228.019633,205.858531,136.945847,82.469388,-23.432764,-58.252074,-80.068998,-50.582202,71.4038,102.021583,20.950712,-99.458309,-102.9176,22.054021,100.129645,212.090477,257.293585,277.945254,186.473927,133.883158,19.820154,-18.964943,30.858553,92.347951,118.824485,65.590295,-85.624913,-193.893329,-188.683627,-47.580661,33.794948,155.527253,213.966365,248.492215,54.746452,-76.231835,-157.33146,-85.449197,65.861278,104.198366,148.770375,127.064929,-36.199237,-221.357437,-279.34953,-245.209826,-166.197159,-31.103087,-8.644281,-45.861608,-125.107979,-168.966363,-220.317151,-184.093439,8.536133,96.527262,135.573022,106.159334,4.494195,-169.589024,-241.634869,-186.411346,-68.467095,139.943206,176.701426,150.568677,77.174765,44.218522,52.441057,87.314506,163.856468,208.626875,272.971586,269.922921,221.530999,150.28794,119.683734,138.477196,188.318315,324.488985,384.815118,373.270945,208.670313,157.098705,175.596421,213.192482,306.055334,362.492118,427.707659,400.499088,248.927406,105.655625,68.018941,114.223112,188.946425,309.821561,332.820106,311.39201,174.810536,77.212816,1.313573,73.140995,306.560874,391.389143,418.610918,341.989933,68.294836,-100.984622,-84.648872,29.399517,49.339991,18.023533,7.974999,-17.778886,-84.656308,-118.72641,-177.816467,-184.111091,-89.171985,-15.343378,13.788846,-51.775496,-186.856117,-191.206007,-152.688892,14.233487,128.917805,327.731367,382.410332,343.485232,220.162345,188.81573,170.982138,196.916963,367.883899,465.176088,519.853286,464.590846,317.942087,228.518228,189.377013,160.357894,182.204241,285.870963,337.466782,287.569358,89.41168,19.59707,-13.173122,29.783418,205.147729,278.458661,302.96813,255.917502,103.269611,18.565358,14.80312,28.872299,42.134458,83.3248,95.595874,65.261639,-32.303047,-96.112714,-181.303827,-159.157119,-13.234639,44.930999,36.00402,-11.856781,-117.67707,-220.225429,-240.532754,-168.0489,-118.514939,-57.700945,-35.169819,-53.768078,-156.749988,-204.087722,-244.943166,-216.805942,-80.68766,14.392838,181.716936,165.323516,-104.796858,-397.711034,-467.179673,-354.971294,-228.485641,-89.68388,-86.315414,-153.301323,-305.490228,-377.951025,-403.878717,-341.800549,-177.70019,-110.245772,-17.380852,-15.772455,-86.155496,-135.438854,-154.175043,-180.432127,-168.838689,-94.565996,-65.635834,-108.823757,-217.43927,-263.825899,-343.422273,-365.232871,-315.719282,-240.091336,-114.04268,-110.071778,-138.129643,-165.656282,-194.560276,-177.467828,-131.617352,-90.47227,-103.479547,-153.879738,-256.416568,-323.928177,-429.527002,-446.631447,-385.602466,-304.225849,-134.037426,-121.736211,-271.970214,-441.727977,-446.45437,-263.31943,-158.006036,-67.333339,-47.111626,-15.00996,-100.470309,-190.705168,-283.159526,-217.329394,26.194032,118.774412,205.241264,201.154395,138.34983,97.365116,60.643954,-28.290877,-21.828771,136.120437,235.841322,302.393853,150.671576,43.108623,-70.56071,-29.768458,149.790277,203.702346,150.10276,72.257566:44.04563,-58.061263,-125.153232,-116.808123,-57.900332,30.641571,56.026465,68.973077,29.149158,16.959436,7.747393,-14.540444,-76.287148,-76.543625,-6.030357,5.172287,-98.187428,-197.691313,-221.675708,-272.016305,-287.68106,-237.488818,-180.424381,-103.823218,-91.719951,-97.008261,-154.965719,-182.408002,-156.447764,-117.253105,-51.157869,-44.580232,-112.569777,-204.516756,-218.293293,-177.206493,-132.338804,-0.409144,70.967613,113.084712,-13.747924,-69.014914,-97.219254,-111.481887,-141.223596,-101.771675,18.828454,5.524091,-150.640357,-244.380793,-259.127464,-230.02038,-194.660268,-160.018637,-151.709366,-144.816352,-202.915144,-232.60529,-234.797178,-193.625485,-97.823341,-97.579528,-154.454393,-162.42957,-137.837122,-115.490641,-113.023274,-67.074357,6.791181,165.942744,210.598987,279.082818,337.226077,315.989017,183.563628,148.278005,215.125492,268.992985,296.123034,254.836265,128.81379,57.128008,39.227985,31.490338,53.562762,132.248752,168.917325,186.505978,106.334809,46.366746,-84.299321,-152.617355,-262.007076,-271.534417,-208.522072,-183.180996,-173.570944,-160.58381,-136.732307,-50.580101,-10.908354,48.461309,89.749269,167.378028,141.45905,106.123948,80.114863,112.588054,247.468232,317.480561,413.54575,423.433194,350.288436,250.536989,214.321273,174.255652,179.876982,284.363119,368.939917,401.778995,149.945991,16.15436,-136.363268,-170.781793,-196.303739,-184.241762,-85.153537,-21.752365,48.910116,44.852129,7.639418,-82.433618,-89.387444,-28.949438,23.845656,117.744437,74.297418,9.829319,-134.017811,-187.051173,-176.198656,-104.76304,87.44771,157.166992,196.867529,103.647891,27.192269,-35.362611,9.471689,163.920969,224.251055,220.570567,89.475368,37.050986,24.430178,64.593545,139.690308,143.899334,129.175954,102.536572,-27.672398,-122.939889,-117.476206,-10.988346,74.706732,213.95959,242.598895,208.007535,119.282375,91.28371,22.869737,-27.413568,-71.979101,-35.940952,98.499656,136.104969,61.833191,-82.065497,-115.737185,-107.378899,-98.665061,-87.278577,-39.177431,131.032959,181.255267,158.258961,148.976883,183.274384,288.51081,327.3479,277.475569,190.212051,16.972976,-132.771051,-193.679838,-133.971717,-22.578552,149.811591,167.304719,109.31164,64.73387,69.294426,81.853029,90.691888,143.018471,170.033095,184.716968,179.445836,168.616814,161.159118,157.369359,191.809118,237.253491,355.106651,410.145915,409.517711,307.003422,295.016105,301.021278,275.747914,216.532077,212.706965,223.048534,199.13571,95.63069,48.75046,54.511545,118.529756,178.305665,299.664991,347.945614,361.90025,225.994216,166.171655,123.051131,111.08726,107.019536,141.04387,280.844326,327.01263,220.092622,9.308425,-44.163088,-22.312991,30.069199,134.299574,152.855044,62.738252,-65.366975,-85.936028,-108.059838,-132.441651,-186.739792,-214.159504,-253.677333,-251.36148,-194.108557,-80.655771,-26.904124,32.703062,54.752746,116.498561,142.931618,112.808908,-41.306174,-128.664772,-243.954741,-222.293131,-54.889477,-3.825725,-23.248311,-34.045236,29.95422,106.855349,86.27969,-25.934016,-35.613468,105.227636,197.843005,239.584124,87.656118,8.106219,-61.282194,-50.567022,-35.149113,-54.072938,-62.646257,-28.304919,25.28836,-11.000054,-22.617882,31.954571,65.130384,-2.428738,-93.166041,-189.048028,-129.300803,-116.021974,-132.550463,-105.647273,9.812128,45.632285,53.234767,38.902601,-23.767631,-105.752208,-123.313431,-71.890211,-24.241295,53.973194,74.479034,58.975565,-14.457062,-44.543408,-78.316879,-97.503569,-98.659105,-48.640645,105.380066,120.858916,-75.243447,-287.338867,-331.954858,-344.436906,-333.176852,-324.467904,-326.681963,-341.664529,-346.987122,-334.785519,-285.941928,-243.20998,-161.596944,-140.233365,-50.031117,25.907362,83.946074,-17.87805,-57.13971,-46.900932,-35.493293,-68.933304,-90.970611,-135.001693,-217.286823,-240.810368,-208.008615,-170.616609,-154.653978,-191.857793,-229.091646,-181.880128,-48.739291,-31.804839,-73.65039,-174.827124,-174.293862,-39.019521,29.193027,-8.704217,-205.434858,-263.581425,-284.428151,-276.133713,-240.400623,-228.544815,-212.529339,-195.98981,-152.757839,-73.042868,-13.122798,114.381276,158.84261,153.011425,119.292471,83.521729,79.690524,56.131503,-47.266324,-81.057129,-12.505622,69.286809,204.294489,218.84609,200.794176,254.374426,262.080242,206.314261,182.50316,148.132154,135.077447,171.580256,197.214011,146.049513,-3.5609,-35.13904,34.786986,95.817552,154.738412,132.728498:34.983248,9.663038,-15.709557,47.089945,110.453724,161.447562,157.827999,144.979225,95.257838,63.699527,57.963508,81.793128,103.425576,101.065757,113.041225,100.371885,1.99822,-109.099982,-189.683719,-317.307074,-310.264684,-220.794553,-179.515689,-149.567145,-174.402815,-201.195674,-279.235681,-305.61818,-273.105339,-226.931384,-151.951027,-142.600109,-212.181101,-334.331148,-367.625837,-330.269077,-258.830106,-64.829854,31.008787,125.08057,36.076609,-5.506202,-5.120028,7.887637,23.859063,34.977194,87.280416,116.324567,143.232233,89.823771,14.87674,-115.378098,-111.574234,37.766525,141.338812,225.925275,124.683222,82.282107,49.803929,49.82325,70.161631,81.55467,102.905101,101.290583,72.850022,29.299571,-11.409794,-0.781249,86.265111,258.154557,290.49208,261.708376,186.698366,173.563637,208.709482,222.475512,163.95972,120.12652,110.260995,114.134515,57.040254,11.47385,9.127576,22.979004,24.735365,48.933636,93.583364,151.490387,85.299725,23.936791,-100.505101,-121.835565,-90.446404,-86.651236,-132.496574,-147.547042,-71.880386,36.083939,29.145911,-38.186106,-35.712642,38.158261,78.13945,109.844392,31.936817,-28.208695,-96.092879,-61.604945,173.20348,315.619406,432.408819,389.257119,282.342541,218.851771,162.321139,43.461596,23.282714,154.48221,294.225705,455.093552,309.831688,209.189429,29.280309,-50.027139,-119.55555,-82.829002,101.174858,180.76445,191.39343,46.38343,-25.687777,-34.302076,10.805327,102.783342,152.427846,214.208574,138.8701,70.819802,-53.476468,-76.172946,0.850146,80.360092,240.826223,287.900015,291.958367,180.396012,85.486805,-45.182951,-50.264959,32.382441,96.267318,136.121746,37.842182,-4.035291,-34.591143,-18.828203,65.280154,103.241912,135.341098,132.722375,110.442162,96.839984,92.598425,145.030395,215.003073,359.377521,382.705998,288.405291,187.029691,172.313037,132.915061,99.820825,78.501047,130.473852,344.136102,420.686316,337.971443,101.838534,13.222193,-56.313041,-30.534845,122.772754,220.671392,282.229163,129.589642,81.045099,139.036518,207.602292,323.10024,354.088167,313.292525,238.268869,60.493597,-86.181379,-142.343224,-136.543079,-58.400049,109.639582,135.905292,104.757139,97.148907,83.045446,14.529643,9.352901,77.448213,115.871082,207.346742,266.531519,321.448336,202.851611,112.192137,33.285331,63.323093,165.361231,220.171128,285.02287,231.731528,193.749263,122.163613,101.778848,141.865128,188.239205,229.941289,191.421188,71.794369,46.220646,49.911265,61.690939,93.515374,184.197143,219.382478,256.868785,219.007907,178.649706,111.643841,106.260798,155.912998,175.74734,176.266365,156.63444,33.21185,-107.82638,-133.912028,-95.355685,-55.228177,5.735268,10.223953,-57.554899,-162.606641,-197.082879,-244.523192,-257.494042,-246.468563,-245.644913,-291.180956,-317.426494,-296.73929,-226.007995,-208.502637,-162.107284,-124.223492,-45.133873,-10.113185,-23.971223,-170.693558,-247.783861,-314.146435,-277.922325,-148.91093,-118.21149,-150.362592,-169.183563,-140.587517,-137.357086,-170.491453,-200.605646,-176.154029,-128.313031,-97.972418,-4.294753,-39.999057,-101.992437,-167.822608,-153.333193,-113.423115,-111.099312,-89.038554,-62.300056,-41.261908,-114.760153,-160.010016,-166.502411,-133.860575,-97.990294,-91.797478,-80.149624,-174.328069,-243.711262,-292.971918,-250.408952,-82.286475,-4.922875,55.821987,31.499786,-96.628739,-233.615665,-256.195682,-190.986225,-153.530582,-118.147053,-87.329955,-34.400981,-40.684913,-55.601903,-148.627536,-191.23247,-124.675717,-42.689969,31.344634,3.789963,-130.075135,-288.340057,-320.396479,-234.276259,-180.171282,-225.145745,-297.954547,-398.627525,-386.377588,-343.733516,-227.78828,-186.30715,-193.274,-206.400759,-128.465835,-63.990534,-6.586067,-10.965668,-20.870673,-75.80347,-116.418486,-155.891313,-138.893197,-108.651944,-133.991357,-145.875343,-156.072256,-162.307561,-177.830477,-158.385816,-19.732424,47.719845,91.742631,78.163471,23.398385,-160.001024,-216.293994,-175.999992,-121.208764,-59.448667,-48.370475,-54.908733,-111.583246,-143.820994,-166.162928,-158.162745,-130.438307,-126.472112,-134.830389,-118.080037,-123.134103,-125.583519,-96.478721,-27.239776,5.733719,68.793192,72.379614,47.680722,-27.742737,-51.455381,-10.559778,56.917551,194.495385,199.478249,78.464145,-36.167473,-74.064538,-139.898747,-170.580508,-210.176485,-186.914216,-61.664386,-54.166044,-124.167583,-251.513333,-251.894188,-148.007457,-84.989878,-4.884882,-19.70106:-22.169165,-38.92035,-71.714146,-150.584732,-157.747942,-41.457394,47.07638,117.44246,79.899844,48.105998,-70.889424,-113.181355,-99.463367,-79.447764,-69.156665,-91.508512,-147.960543,-146.338051,-158.893496,-193.885654,-163.77637,-39.33009,3.16408,29.468068,-5.098913,-50.574558,-148.449298,-147.241211,-9.854379,68.981723,97.348137,45.715753,-54.912067,-89.352876,-113.8883,-107.38932,-37.480579,143.478811,189.888552,149.257977,17.474726,-47.578728,-132.533114,-139.28847,-82.378424,-52.012682,-82.935895,-127.394288,-189.482422,-239.629759,-257.840032,-218.668837,-162.488055,-16.180736,51.559793,51.687332,-157.633595,-248.236009,-262.41417,-197.201899,-72.691251,-66.094623,-108.85598,-127.435995,-131.443981,-34.726677,3.761678,19.955732,44.56746,123.265924,133.130094,73.978199,10.144235,-9.37365,-26.877407,10.469441,147.224417,172.628245,77.423543,-5.432693,-128.678545,-160.957501,-144.993791,-61.787315,-25.366547,-4.294974,5.307767,54.154629,77.563773,55.631912,-92.465609,-175.031372,-185.694139,-116.343283,9.328296,30.047844,95.233416,177.232948,141.995459,-7.253398,-10.599423,177.241497,263.461109,235.548784,62.92318,-8.674628,-1.388317,74.887994,203.614763,220.795153,196.887494,155.438268,43.622859,-31.811085,-68.447844,-71.720151,-9.839826,104.473142,108.455186,49.894178,-24.193815,-67.70433,-152.833473,-155.494484,-109.344105,-91.29384,15.220876,99.242975,153.642787,33.329665,-26.966977,-44.930018,9.051403,166.921453,215.304643,157.808409,17.437678,-6.900549,-7.658453,-29.375707,-67.123891,-31.557905,106.090557,136.35327,76.972902,48.01551,73.856542,161.910517,219.036492,312.062525,327.154809,297.961633,268.162256,239.109976,106.17806,67.663856,133.497934,175.059601,169.166651,136.648939,59.259113,-36.778249,-71.587046,-2.008451,92.367467,246.621106,279.444798,243.714849,87.044444,20.908096,-37.790991,-42.546969,0.634306,44.123303,160.769711,199.301219,119.376325,-45.674623,-93.392062,-96.378388,-59.983042,39.49652,77.556456,99.184024,66.950057,40.314111,37.886405,92.193902,246.809124,271.61502,144.407721,60.077879,-11.019728,-72.071478,-126.645128,-142.619805,-77.335095,48.101152,68.302125,62.765142,21.831102,2.591535,24.623252,79.802482,201.217138,220.30369,195.865333,198.968264,239.390586,186.320259,138.54331,135.877391,187.91247,332.948546,402.279087,438.442731,342.771667,304.23577,254.768096,243.158973,277.900481,306.245075,323.987978,303.958779,231.362811,137.437629,99.990466,124.301344,178.598294,292.745186,333.914349,335.410963,267.505331,232.301563,157.351188,129.308673,99.351249,96.023678,137.473369,157.306904,91.626828,13.361697,28.231356,87.231739,85.301475,27.589347,-7.730133,-91.989334,-145.843033,-141.53926,-136.302602,-158.736383,-234.369701,-254.380243,-216.688335,-192.84361,-176.881924,-152.38865,-151.159745,-159.843469,-131.112231,4.777417,70.609671,99.841228,16.398178,-36.829176,-99.966059,-78.674093,22.834047,67.832042,151.784035,171.777557,138.347413,56.715101,11.713438,13.438943,74.599022,188.203282,187.720032,118.336737,104.344516,67.712568,-103.986067,-135.155492,-25.587835,46.164324,107.777895,68.570204,-65.502249,-26.6392,35.170982,84.889555,78.164106,70.526013,74.737416,40.922149,-66.776241,-103.501432,-101.335898,-72.325316,-20.332301,-21.224555,-36.36326,-34.793594,-69.155932,-124.290348,-127.827371,-63.734696,-22.341553,-7.32407,-8.021492,-3.868031,-48.377265,-72.220007,-124.818727,-159.584974,-170.96568,-108.888977,67.963558,96.822266,-57.086678,-340.267748,-430.643293,-327.372704,-194.594075,-94.303278,-125.235007,-179.278505,-264.374871,-327.566194,-362.457975,-305.02672,-141.104783,-86.40438,-30.91649,-18.929373,-19.865695,-3.825027,0.161195,-26.847355,-39.262644,-44.190218,-59.660183,-140.105562,-181.476603,-193.855777,-287.394586,-331.989933,-284.492434,-214.674114,-126.834302,-127.830122,-163.583321,-209.95997,-227.635472,-161.631597,-91.76578,-57.407996,-97.433429,-145.523777,-183.177914,-244.306206,-368.678185,-374.481305,-303.8642,-269.315851,-180.276366,-130.709519,-139.80737,-225.894899,-212.823071,-119.031177,-118.47699,-174.694395,-128.211142,53.15534,-31.39661,-156.017778,-289.345882,-241.70496,-5.891657,101.372786,197.407313,192.853816,136.98382,82.561761,58.790534,44.931488,78.500869,230.144827,303.731731,290.80548,62.997049,-54.394077,-169.895831,-143.753109,14.780681,76.507852,99.318738,82.279471:right
-9.323046,-23.288919,-43.59978,-56.707302,-63.513816,-127.082775,-177.853136,-226.833832,-85.762763,-4.075464,-0.097822,-42.567111,-47.271714,1.517529,120.814364,154.710363,199.308511,260.461009,250.046188,122.372299,37.70147,-103.112306,-146.02098,-207.019738,-223.608799,-200.093464,-161.567462,-162.860119,-147.121629,-105.815223,2.358556,29.046444,12.607864,-18.180985,-50.641583,-154.627402,-200.269361,-254.257304,-252.844057,-219.831649,-185.51726,-146.298712,-102.131016,-122.560088,-161.956781,-155.176419,-117.438902,-94.846959,-1.811642,145.773912,197.261019,229.44653,210.664909,84.761373,5.599452,-24.610944,156.254443,225.694272,133.440255,16.57042,-144.090157,-153.38584,-25.355776,72.752737,176.757217,50.078316,-76.668437,-285.958415,-330.714111,-358.434201,-358.370406,-332.123614,-307.944291,-316.875766,-384.325905,-412.00825,-449.579354,-481.567547,-498.215388,-446.206091,-294.400256,-253.453195,-278.099568,-317.576878,-313.649219,-266.768958,-234.744559,-207.484342,-187.693893,-135.082322,-18.850033,8.2859,14.779893,0.738152,-57.898493,-89.68658,-100.135443,-58.944517,-53.246095,-86.137248,-133.194488,-289.751635,-341.770742,-278.545735,-182.440575,-212.738756,-373.662197,-433.486239,-479.587816,-490.722012,-475.89211,-446.510936,-375.13871,-325.902305,-312.705544,-310.877512,-353.581398,-526.298279,-598.178586,-614.533683,-495.040721,-407.226526,-281.869304,-268.729008,-282.682237,-294.857003,-291.343289,-260.154028,-161.859462,-74.864048,-66.948475,-115.53881,-142.489806,-149.242793,-115.991084,-14.311998,21.979931,-5.548041,-149.943947,-230.622363,-325.714076,-344.53663,-369.538235,-395.193498,-423.566695,-356.245871,-316.022476,-280.241644,-312.800093,-427.090232,-426.145774,-271.066728,-139.865942,-116.249735,-70.413241,-49.410485,-117.751689,-188.949505,-183.937257,-82.919525,100.466321,86.650304,73.908817,127.192467,121.568165,-38.161889,-95.126932,19.776807,221.638397,241.729456,174.460787,159.678758,103.014606,8.172485,-196.214996,-233.232523,-177.013018,-106.243631,-106.037445,-94.8838,-53.913619,26.167518,33.96643,-15.821123,-50.233426,-37.628713,-30.639191,-41.801442,-86.42276,-142.12027,-272.846616,-307.868031,-276.553297,-152.737874,-128.685269,-204.928437,-248.320947,-232.776257,-193.216514,-156.173017,-120.319672,-63.399435,5.638801,-19.283309,-73.15478,-59.050572,22.001167,71.166232,191.151392,241.655605,220.66401,238.982478,281.977909,245.494659,152.361789,-12.433764,21.007364,84.447072,172.279886,172.023897,45.056191,-41.647858,-83.707518,-48.662515,0.784368,-10.731758,-14.126472,-27.976928,-71.206374,-225.657338,-293.806627,-338.075119,-272.890068,-234.759714,-220.962169,-234.22601,-296.875759,-342.316819,-351.965104,-296.098666,-141.339798,-84.561114,-109.202496,-145.080991,-126.508928,-86.55539,-80.138506,-29.135356,98.117305,151.106763,142.387868,108.434028,82.560192,73.476982,21.573902,4.114513,7.393278,-22.302942,-37.624071,-48.2099,-77.296283,-153.691678,-146.766784,-52.381886,29.836698,44.693577,-49.563129,-143.048505,-261.44972,-253.56453,-151.356531,-91.187189,56.857853,229.047447,268.556834,285.758636,268.167356,105.511262,4.512581,-40.510466,83.106004,130.36367,144.998017,135.86686,87.568608,44.318715,36.982625,101.36404,258.442075,286.411725,245.342328,130.407509,69.523153,-5.941511,1.053353,5.402498,-51.548874,-42.427237,66.528799,122.818441,186.374871,212.701868,292.519017,336.320223,385.783991,320.54225,273.583335,290.242468,321.65307,275.563803,235.54661,282.914365,449.236091,528.109378,576.514236,535.708066,409.26211,370.229512,385.961471,404.904795,416.649284,445.123942,454.649404,409.153892,343.651384,184.626451,147.449117,187.239565,259.543452,276.799305,246.431042,231.128638,232.068383,220.321794,211.26223,240.971244,291.459566,232.733887,183.554394,160.128713,213.27048,356.243649,368.254749,229.137928,172.510002,230.945832,289.039107,253.574226,151.315298,90.34392,10.994619,33.550843,189.155812,326.032621,327.323432,245.417785,212.382351,160.700728,130.603641,118.480013,154.705011,160.536746,208.435994,274.214591,362.465404,349.885153,326.322859,326.79056,280.913334,270.029117,312.611826,426.464224,448.205899,400.273476,375.479825,375.971237,405.286658,434.31889,480.846259,474.330415,411.041622,379.365132,375.229072,415.578704,567.793529,660.108887,619.000929,468.647938,436.186085,448.17017,456.576454,487.527054,573.800396,611.709871,596.534596,550.282424,438.37015,404.179522,461.620514,528.447821:96.189041,41.712593,-7.271187,-66.639367,-73.679626,-56.462218,-55.771248,-88.643972,-43.335273,-2.317075,-5.654863,-31.02564,-40.894509,-20.629866,47.404463,87.137027,227.561603,364.173418,350.690012,194.702482,111.557083,60.71143,92.216632,130.760224,83.118211,50.142057,-23.464353,-51.735824,-85.304139,-81.8456,14.643794,72.607491,78.765982,44.550413,41.933364,-32.967001,-87.412649,-81.441382,-36.657749,14.962652,62.999894,64.936908,-47.312383,-102.546472,-103.926412,-63.035918,88.724417,174.985233,258.968986,172.334064,77.665778,-61.33536,-62.900748,-13.529723,-1.685282,25.021117,90.780496,114.52048,70.392285,-2.044002,-136.081809,-141.776036,-25.001264,56.018973,137.349566,10.167543,-107.356404,-263.346523,-281.573269,-312.947706,-324.223018,-277.475567,-240.013992,-252.370577,-270.060684,-257.799104,-240.491479,-238.067174,-218.848141,-219.136761,-228.348064,-192.221788,-171.915215,-185.13857,-229.962503,-323.000874,-336.491023,-350.908332,-321.137655,-239.542496,-61.401841,-37.665536,-101.103768,-117.217442,-74.95852,-73.474123,-121.032401,-90.615177,-65.749501,-80.584626,-129.276814,-261.508186,-304.101686,-276.982322,-110.249422,-55.442389,-153.031843,-271.12174,-423.879371,-408.199402,-259.170608,-195.898163,-211.350597,-303.040442,-309.873999,-298.251267,-352.144188,-588.585022,-681.553205,-662.153509,-504.767472,-449.055246,-390.413256,-356.398352,-282.373846,-257.803874,-204.868662,-173.168109,-113.832061,-84.448264,-86.232794,-117.302504,-150.589644,-183.795346,-141.553434,13.042581,17.939951,-55.909323,-184.480544,-214.916104,-269.876913,-289.975904,-304.895665,-326.997288,-367.308465,-300.277385,-243.778746,-210.402236,-267.317017,-382.133575,-367.142904,-247.649955,-158.823409,-125.066522,-83.29405,-97.108678,-191.318384,-231.728946,-226.452904,-194.284101,-92.03823,43.421931,103.22471,141.522976,91.264056,-29.287546,-12.911997,173.872621,292.594385,263.818126,153.487848,125.984462,72.508588,22.400886,-78.471269,-105.325244,-85.801635,-29.932252,-26.329688,-53.753583,-72.029067,-113.335005,-130.764865,-144.05993,-79.28304,-19.739014,45.283447,22.175794,-100.364142,-159.008185,-219.372363,-230.2515,-198.893157,-115.143745,-102.941519,-170.270674,-214.255328,-211.759632,-157.946384,-19.063523,64.172174,76.640693,61.569084,25.850397,-80.105454,-84.443847,61.303295,145.852249,245.965634,278.375702,277.393354,266.02682,241.039163,146.129553,108.382407,69.853455,85.084302,116.944161,172.536624,175.217225,64.968033,-28.597064,-108.631956,-93.359642,-91.533339,-41.495603,14.26547,13.599481,-57.273365,-190.660073,-204.398507,-181.994192,-200.608995,-220.281724,-243.990725,-238.272525,-241.189387,-265.064091,-282.298836,-249.666851,-98.453532,99.99726,147.737373,88.5391,31.612968,-24.743211,-15.322451,55.145924,117.19818,118.324371,92.081595,96.493774,159.495763,179.89945,142.664028,116.392596,85.691232,55.376261,56.104879,44.140683,2.382385,-80.832914,-76.928674,10.847076,90.193145,85.124309,-8.398404,-59.621366,-141.437793,-168.904745,-151.145041,-109.190308,-8.638457,59.670207,65.236657,48.977195,38.945636,1.443328,-23.487256,-39.281541,-21.981581,-33.431881,-44.587613,-28.865919,-50.200974,-76.79883,-17.643457,51.566885,126.874804,161.810768,179.786092,126.818294,41.559955,-135.598657,-155.355548,7.665721,180.946729,162.787613,21.573242,16.012786,167.011067,244.477748,343.585332,374.91283,408.210093,380.992313,332.148205,256.933417,252.438305,228.381969,200.223135,223.534923,401.913501,487.721534,510.649939,465.207588,379.953619,359.745413,334.960306,327.997355,371.156556,422.13969,415.299493,344.242111,282.237203,115.513208,62.677455,119.892227,263.936351,281.765453,196.321786,158.642059,114.084266,89.724761,121.031308,186.69798,344.342302,400.551931,363.283155,253.112377,239.144577,331.294797,377.771408,305.192997,151.104184,127.848919,126.739351,103.261711,-26.061169,-106.62596,-114.862011,-29.73895,137.918098,231.508721,257.138368,215.361027,165.436608,118.621305,118.941915,80.803583,24.869571,52.166078,214.897078,270.007648,217.689176,174.863213,193.116778,222.069033,253.210177,271.729215,276.802701,270.670262,256.919303,246.922108,274.703454,367.7156,401.114095,384.3057,345.97409,328.064664,267.657394,253.74536,333.36319,409.792363,543.910337,543.367383,481.105339,313.042099,250.6616,239.473553,266.777218,273.296666,280.445718,308.139776,344.061684,347.755303,329.440051,310.524192,303.050458,300.508356:26.849255,-53.91145,-93.12712,-93.209261,-73.646793,-48.044838,-33.94938,-9.167882,16.091458,35.440486,46.689644,27.609463,-17.975677,-13.878756,98.549962,193.933433,356.924879,379.53339,336.516393,221.143897,170.337805,141.047703,180.387175,275.128032,229.59799,149.726388,-14.977154,-75.093657,-164.87328,-171.133688,-34.466233,68.817518,154.122003,54.735485,-18.929953,-141.561434,-151.564373,-37.235943,19.257763,7.468497,30.923432,75.800721,84.634335,42.294562,-52.535633,-66.939213,23.926331,101.433096,197.39747,153.30417,84.375341,-80.872287,-127.030973,-110.027672,-89.423568,-41.618162,62.462849,64.486594,-56.18515,-97.885213,-89.352815,-84.466854,-110.374914,-111.246388,-79.454872,-143.915923,-231.512746,-401.426252,-433.195568,-379.383047,-336.331474,-285.158038,-220.387091,-209.178672,-309.314131,-373.276864,-370.487717,-306.305132,-206.330961,-205.670051,-183.027801,-68.393167,-15.331301,-5.748048,-71.333714,-219.833937,-229.982041,-155.141865,-126.278934,-130.85843,-130.1542,-116.458047,-62.632494,-34.496787,-37.490312,-63.777526,-61.844794,-33.222137,-65.735212,-183.509694,-221.836021,-216.517965,-196.909517,-166.750116,-104.042441,-94.536292,-223.808304,-320.644742,-387.623918,-347.621332,-268.90312,-251.732402,-198.451134,-163.462396,-169.043127,-226.652531,-301.529281,-529.282677,-615.085894,-607.431524,-432.320527,-349.366214,-303.661858,-339.437958,-423.632683,-423.879099,-335.982392,-299.784643,-262.869517,-178.205892,-151.360492,-198.54427,-246.437247,-277.971529,-245.326576,-174.182617,-228.779751,-285.248082,-345.570796,-348.445696,-367.307596,-379.066968,-369.256779,-373.06945,-427.102137,-445.503062,-410.414717,-313.579754,-325.806347,-438.929129,-458.636978,-402.835602,-339.542402,-300.842288,-173.28422,-142.310955,-268.62013,-376.029866,-464.602916,-403.82992,-181.900182,-48.096732,-23.886379,-27.266711,-66.067819,-135.938269,-96.124228,97.452462,155.224922,103.568564,43.859873,65.100946,42.048065,-21.782951,-123.441905,-140.717351,-148.630574,-130.066822,-119.910185,-104.744373,-108.838281,-184.980396,-233.216922,-239.278388,-130.411674,-84.364728,-93.259101,-148.504496,-269.413068,-287.031818,-262.586895,-254.782926,-185.804333,-78.190149,-82.192728,-157.5054,-183.059059,-213.980203,-224.154295,-202.257103,-129.738707,-89.839604,-43.124291,-45.842185,-95.359064,-119.283129,-96.071935,-51.565371,47.152401,115.557401,125.124675,105.38447,68.691439,-54.105038,-102.676394,-117.169704,-26.654593,28.347541,46.286914,9.266212,-59.624631,-73.174677,-106.28038,-131.637345,-111.508089,27.549073,66.830374,-35.000572,-120.857547,-153.918924,-117.899533,-125.615672,-177.40975,-152.430313,-54.900015,-33.272151,-83.787388,-131.740287,-188.775162,-173.483089,-31.232843,113.681015,134.583269,136.515665,130.626306,100.853152,92.06299,117.647483,214.954017,253.392726,211.635092,166.266051,148.525504,176.820182,247.542387,278.681907,326.303795,305.28401,261.161837,145.781058,85.697641,31.658615,70.731726,216.620783,321.421011,340.243611,245.064183,129.390855,-54.617861,-50.662752,44.206149,65.977157,111.05275,218.959736,244.762178,197.239794,142.982306,63.107214,69.854973,157.58649,225.462854,214.054686,140.084367,119.330901,89.26724,57.990993,59.595495,106.515885,164.636303,184.512152,202.553699,171.744589,118.940286,50.93673,71.545519,168.912288,181.733119,153.650515,132.393932,151.075096,174.529555,185.498449,297.168341,368.602703,409.239798,365.718194,343.377429,284.639959,231.191018,116.170708,107.146384,212.039986,316.552505,306.884203,215.176723,208.222932,295.868148,340.165147,343.874651,309.212184,301.107884,384.919994,393.330486,317.210786,251.571336,139.767852,126.203973,180.634736,249.295127,250.588409,184.053226,121.370756,-32.215325,-60.738812,75.962389,183.132487,328.838618,358.229683,321.366644,216.576255,198.014335,255.384417,295.812182,268.560089,138.51198,107.585603,115.036464,88.866688,-97.936291,-190.694339,-135.523556,-1.275858,210.20368,220.587235,194.596904,111.142917,57.134049,16.363765,37.927614,62.211007,36.433188,42.281284,117.916423,169.303076,212.028334,204.41672,242.828338,290.540332,332.321555,293.815211,283.768455,281.907898,263.424664,224.032293,240.319685,335.448331,430.081247,457.18392,426.831773,360.951536,224.35789,214.085453,340.363931,436.605244,556.989859,514.573992,462.901157,358.244013,301.202482,216.253768,232.234526,393.62003,532.592539,528.23152,437.114201,412.282459,388.725886,352.845834,290.282709,280.686368:-9.3139,-44.416736,-39.816488,-21.530612,-36.963551,-118.244016,-138.266879,-82.874322,13.220806,34.967093,-12.39079,-46.416669,-40.341739,-3.359078,106.300981,175.917829,353.326794,422.716462,347.492913,111.560145,31.331171,14.626078,60.241084,138.430152,103.079989,45.589049,-90.36891,-136.857843,-150.328584,-117.538769,-14.884763,38.113245,118.958926,70.60106,-7.231054,-170.609536,-223.656832,-213.161354,-153.35053,-66.581766,-47.832303,-29.172686,-38.170073,-60.529486,-64.264564,-45.457929,4.987849,29.398105,105.611923,159.560723,130.588419,-3.911654,-63.568005,-96.452157,-84.067751,-66.344626,-30.180584,-15.932737,-69.802487,-117.835699,-191.892046,-216.638496,-215.946415,-189.56408,-129.347771,-154.677765,-236.019073,-487.495331,-592.991657,-632.139444,-578.066763,-487.172075,-478.049641,-492.997342,-568.741078,-585.865679,-503.718989,-445.806516,-377.23811,-351.376532,-225.493836,-46.6996,-11.605343,-75.920477,-134.188274,-213.65426,-229.744195,-217.765526,-114.27127,-38.901964,61.589681,70.011055,12.419308,-25.321561,-32.569677,-11.55126,28.633434,62.424081,45.843407,-81.334977,-162.913623,-297.847222,-326.175763,-259.665311,-120.559405,-106.180485,-239.991936,-333.630606,-444.40457,-453.835083,-414.074118,-378.672096,-331.978527,-359.560315,-369.593551,-341.161328,-355.589334,-521.936872,-615.443045,-653.160666,-499.787255,-420.569656,-360.289574,-363.525512,-382.559112,-386.107042,-349.317415,-315.827057,-229.815648,-121.907723,-97.625031,-153.579628,-214.57604,-277.139373,-242.23092,-131.081998,-112.58397,-138.791924,-244.870497,-311.936888,-407.278985,-435.313624,-462.716215,-443.45831,-331.783363,-236.931162,-242.407042,-357.648843,-421.335267,-440.581661,-400.575618,-321.764932,-304.367658,-286.730769,-187.468347,-162.638448,-260.037729,-325.111397,-340.344724,-294.349441,-169.108682,-66.742062,-40.398384,-47.325084,-82.959065,-148.700173,-134.014462,-8.951968,97.992524,92.360586,25.326583,25.225402,42.727707,1.244298,-113.96211,-138.1112,-149.869216,-165.404543,-178.768428,-195.803445,-192.609739,-169.535984,-168.487783,-225.998723,-216.887686,-171.797227,-138.451488,-166.855182,-287.640645,-360.753897,-428.73315,-403.572637,-273.147381,-178.135302,-197.363852,-275.957906,-295.653173,-314.530451,-303.777685,-228.231343,-147.732704,-112.374904,-91.664031,-103.900924,-84.365869,-40.686068,49.886948,77.656463,112.347627,108.847649,75.201669,19.795141,18.458,-15.75316,-71.714274,-176.478993,-91.739931,13.50686,149.59073,136.095553,12.503297,-47.714106,-115.318853,-135.707395,-127.321929,-68.538987,-80.824146,-172.094035,-194.308351,-178.040475,-190.176354,-264.917103,-243.8381,-198.290862,-134.730462,-146.183497,-268.819008,-331.523438,-323.655009,-259.910265,-115.731566,-6.89685,19.387917,11.36889,-30.356232,-146.247305,-143.131222,31.022,211.396851,245.488244,208.140447,184.808937,208.343158,220.208538,195.30356,191.309959,189.519823,132.079471,124.090037,131.152043,89.615183,-4.166383,23.338187,199.704914,320.721673,317.501239,188.159933,87.702821,-88.903018,-119.36359,-58.316745,-11.60928,76.574782,165.782063,188.481539,183.308264,175.663667,149.801108,118.593816,92.659581,226.960759,307.11415,350.0517,311.234725,174.997047,120.320935,122.858061,157.540237,212.30011,209.612166,170.166686,41.885373,-8.7691,-18.000207,9.947869,71.731502,121.811895,138.81031,147.594997,152.636287,153.801966,151.898924,246.438828,338.323552,453.361299,354.403174,263.241125,178.219883,185.647524,183.131585,175.120134,217.068944,327.75344,369.794671,362.008553,331.102135,276.09642,263.027555,273.431721,285.853647,347.231624,431.057191,426.995011,316.959562,245.947278,144.44172,125.247816,164.691168,277.942422,293.900448,205.618535,161.709282,95.741498,44.722246,-27.138247,-4.856197,149.175336,251.971393,229.977522,131.663608,97.133684,108.573117,157.341178,232.389275,174.386893,134.7763,103.708136,89.20828,13.630417,-19.116103,9.851616,53.809861,159.536817,274.470379,290.540797,221.472071,173.296517,81.418146,30.591741,-12.87172,107.278352,179.483994,240.507122,250.11658,267.374819,270.789976,290.474134,300.710773,308.917366,334.28455,346.032893,377.129261,395.830305,392.947258,382.950084,396.99425,441.146184,474.49751,570.889813,611.215082,586.435505,536.247524,507.841622,554.359482,684.228746,677.198762,629.058549,568.791534,548.578705,522.291251,553.872744,661.836571,684.254249,670.08811,667.396922,675.089956,619.376503,554.345294,488.927391,512.83007:13.486039,-67.458976,-126.500432,-205.866121,-191.961018,-101.092566,-65.137343,-36.842537,21.042412,60.248143,41.757082,-5.701231,-59.399943,-60.664293,-24.507985,41.051424,283.357162,366.741647,282.098758,72.255223,26.100905,79.773212,150.112042,245.695156,232.586724,200.677777,45.713255,-72.255756,-252.758879,-257.286183,-102.795047,-8.305467,74.848654,5.056219,-62.176991,-202.910991,-237.545137,-151.675762,-68.731256,16.101894,63.104212,96.5487,108.299188,92.383177,66.874616,63.715877,95.304936,124.748196,193.902772,194.248493,131.355283,-96.375713,-210.946723,-254.584056,-163.972578,39.211546,84.832418,46.363198,-103.96016,-152.36447,-138.263754,-119.750032,-116.233523,-108.380336,-45.422769,-127.756931,-261.502607,-499.882728,-541.847168,-509.381321,-473.618601,-391.610284,-331.551771,-355.637803,-468.362797,-483.30368,-409.893699,-370.731485,-275.708765,-181.700091,25.327344,55.008072,21.133072,-44.960339,-90.7803,-169.465994,-153.734891,-42.390771,54.830885,80.020974,71.969345,44.388426,-9.683183,-11.726448,-2.835695,-19.850699,-34.685292,15.371723,10.512068,-115.59057,-189.109863,-217.200788,-181.601828,-141.347667,-159.216057,-162.774296,-179.436225,-211.402111,-311.793106,-353.148374,-353.644667,-299.247509,-140.585151,-112.279791,-150.600702,-185.312116,-180.096367,-243.386857,-298.15427,-293.154872,-158.319082,-128.331781,-178.288045,-221.499347,-300.631763,-319.492652,-255.22831,-179.353651,-5.670936,66.877571,45.497082,-45.195638,-115.973674,-246.275741,-244.985772,-127.159064,-47.136202,-54.197024,-144.942682,-211.137745,-312.303394,-312.517278,-216.804342,-164.240233,-120.653846,-146.208217,-173.329303,-270.443197,-338.244506,-374.10089,-315.448093,-213.107336,-227.663362,-214.044505,-116.696101,-97.971719,-187.485067,-251.018091,-319.403625,-290.140664,-82.609906,63.58451,50.890484,-33.226674,-64.650615,-41.151376,23.728181,202.169752,292.865467,253.769181,119.685759,85.845098,15.850659,-27.982077,-1.859353,58.443874,88.269958,-45.850427,-108.312514,-151.704728,-146.971995,-98.084592,-62.555226,-49.144146,-31.642005,13.15552,37.810919,-18.165902,-180.216335,-238.334796,-255.465568,-221.470705,-107.972571,-0.037577,18.972587,-45.639554,-115.211524,-220.137596,-215.589611,-68.550047,167.882901,241.642446,190.954101,106.037596,22.259085,71.933064,271.229575,341.656471,354.666329,272.510943,210.58878,111.153296,83.253068,29.144757,4.776036,-16.253792,42.137786,95.107851,165.626269,164.22549,86.632839,31.622623,-61.329809,-86.450672,-38.867565,78.465471,103.380202,25.55228,-50.831009,-149.326255,-164.849052,-154.957243,-49.808114,1.138209,-13.65206,-67.231731,-155.304832,-142.04083,-19.644302,32.8749,108.80657,148.964629,130.46508,35.060957,-16.654267,-52.977607,-22.927056,83.114403,170.470386,210.128345,217.703503,155.741416,18.605385,15.413372,118.15246,174.504999,228.145441,157.144025,106.588353,47.487018,26.311982,31.320664,78.560829,203.614662,314.198987,344.212242,261.313339,152.847108,-69.468174,-120.040864,-50.891428,18.326442,114.369254,150.512016,147.293651,92.12023,42.681072,-23.22645,-7.710502,85.374969,182.821535,221.490565,222.289531,171.59159,61.571047,51.867086,72.31128,50.96628,28.696878,103.966485,106.448163,-22.371631,-105.883323,-130.851582,-63.52541,97.320531,157.326519,126.022184,31.106588,31.016857,72.103366,78.735564,178.224648,271.13256,348.762242,216.975973,141.176413,59.696333,38.524333,61.028441,117.987308,242.26962,333.52004,342.13587,225.371505,149.763723,92.748266,104.122506,158.919121,192.8632,244.58198,268.093296,264.402762,203.490382,146.144236,31.821808,21.023956,118.006352,248.003856,270.136295,187.532736,111.558974,-10.590583,-43.83935,-48.9643,-7.122834,103.146253,60.289137,-24.931474,-176.896447,-192.121083,-102.762923,-55.432487,-46.369856,6.956596,47.881852,-3.414864,-91.599118,-256.863182,-273.696128,-161.807036,-96.386792,3.882194,81.659399,63.415972,-78.963991,-154.052376,-231.333445,-233.520654,-223.402753,-164.144741,-102.328894,-17.153941,-21.101482,-81.565605,-96.586007,-18.500996,49.586984,105.476314,58.13815,38.597176,-3.925965,-35.221459,-56.551356,-26.479941,88.256881,234.888346,283.091931,262.570878,209.382131,87.833825,52.132105,56.543391,99.058211,297.585907,424.781544,379.153293,219.405838,180.772414,202.911277,238.801245,333.18024,395.906304,389.186217,321.847938,264.267398,117.957527,69.48608,96.7216,154.563411:68.957344,94.146979,72.42529,-47.41085,-134.098996,-232.377801,-227.663459,-199.559413,-152.469009,-116.971492,-89.531093,-100.206488,-91.871123,-52.250668,72.927889,143.110611,277.499434,292.483993,235.937954,105.354667,36.091902,-72.747892,-53.208332,35.632476,-31.794265,-94.55248,-187.055243,-202.645923,-182.104773,-161.70058,-88.483356,-41.725212,-10.907049,-58.37748,-87.142471,-161.266947,-193.878986,-186.595503,-159.66451,-172.783685,-218.251278,-196.956896,-140.47612,-136.56096,-124.299115,-100.128881,-62.197743,-71.922853,-74.071103,92.930168,173.177675,171.167307,123.468065,31.436364,3.039912,14.742989,46.753734,35.20658,-20.519185,-48.327767,-130.090362,-170.623158,-118.046934,-28.294562,91.334818,-12.75074,-116.26527,-312.844706,-399.299731,-536.034075,-562.338811,-535.510697,-496.814646,-505.356427,-601.804676,-643.939312,-563.893844,-459.823153,-292.110483,-242.958209,-117.215569,-20.281733,-38.219975,-107.812461,-116.64133,-111.480943,-106.576553,-85.284916,-13.138412,56.692273,146.739865,137.662591,116.23894,135.333115,184.367038,181.459834,115.975183,59.739888,47.661943,3.227057,-53.178947,-208.726455,-254.874218,-198.035532,-88.523208,-91.780619,-210.918249,-254.894592,-248.227873,-253.680922,-311.359356,-321.816963,-276.565524,-204.049703,-166.513038,-120.238579,-134.118285,-224.723612,-273.912252,-315.691903,-213.589078,-142.681052,-125.512708,-169.862761,-235.163037,-236.672233,-142.759586,-60.494052,70.975975,63.617671,14.469063,-16.750473,22.197774,68.246952,55.354802,49.518903,93.287232,108.057382,35.073069,-46.437734,-155.640449,-148.130996,-70.945602,-61.387562,-98.954893,-76.915499,-70.442885,-109.255003,-139.58415,-174.953374,-147.875099,-29.6899,65.188172,128.78023,275.219739,279.229997,70.958637,-50.617773,-28.371525,115.347131,329.25824,227.311743,171.509153,194.716713,190.065397,53.866827,-2.629055,29.075757,180.420581,249.67774,312.077928,318.938772,320.865739,296.26287,201.728788,171.624359,170.094522,145.149756,106.371273,101.917252,164.101646,278.388149,258.385729,84.726281,63.481824,122.568482,138.003722,96.042642,35.527991,2.785012,-111.989238,-160.562674,-141.632273,-33.787359,-4.480506,-6.711268,-20.311674,8.8026,65.562388,178.668127,286.77201,342.362559,345.395442,289.877622,224.488146,256.122634,372.48236,429.891284,541.970321,491.346357,417.77327,418.394971,473.189255,443.753118,361.750747,284.505312,380.558957,429.166636,415.114943,363.050314,243.939033,205.945286,214.080699,245.236408,298.698128,246.902252,174.43546,28.847396,-21.526288,-94.284752,-125.75357,-135.471622,-21.198701,32.563293,-10.693603,-79.544494,-165.186918,-175.992442,-155.284981,-135.488226,-128.111413,-157.785087,-174.623636,-190.612878,-182.356545,-165.179187,-157.8792,-71.819396,133.938998,220.561332,218.532655,155.818281,60.105931,44.247937,62.78343,88.203928,89.239274,-5.984277,-42.617519,-58.131894,-65.011636,-84.73197,-69.285024,46.552493,179.469966,184.144154,37.578988,-46.584877,-130.615382,-151.960574,-162.451904,-135.366028,-25.328322,85.111983,103.862343,79.342052,55.393355,-17.670064,-57.173322,-72.101839,51.465236,147.7525,238.49907,183.295325,-7.225379,-69.277665,-109.811779,-110.153235,-87.830169,-25.421704,-18.399805,-149.592806,-241.50259,-286.913191,-237.483866,-162.461441,-209.761407,-225.991571,-160.647574,-93.988382,14.196686,31.836147,33.413568,36.36225,36.5499,-35.92005,-76.808872,-57.05336,-9.307374,58.701853,56.703523,31.357442,100.621505,149.818083,207.8073,224.688186,201.840173,174.678305,168.893998,165.484807,133.169012,194.690066,243.285695,249.072432,188.374848,5.739266,-38.665976,19.272749,56.045387,38.351915,39.747406,73.89257,67.182407,0.920322,-100.015972,-84.221243,32.034142,13.836496,-74.275648,-169.598337,-129.928828,-14.28419,15.358163,26.570989,40.043042,60.414359,56.120429,17.818368,-50.118371,-67.465572,-98.516073,-102.112375,-42.476503,19.679157,20.929954,12.188169,-1.863025,-91.440994,-137.165091,-128.831946,-28.802106,3.205347,-22.840542,-37.439197,-1.241304,12.779379,-12.080138,-35.890909,-23.290975,69.986023,72.94327,-30.56203,-84.094625,-135.951467,-135.329101,-107.038734,-71.785953,-36.909284,42.62496,49.000247,-53.228529,-124.939876,-151.184289,-95.849498,62.767616,159.204969,149.30777,65.979416,40.638299,78.103216,128.828764,200.774094,158.985356,123.296854,113.118915,123.259063,57.735179,4.781901,33.807982,98.477264:40.799598,126.581385,112.915364,-26.785334,-110.461864,-203.323672,-193.284693,-98.716076,14.69288,52.438868,25.309293,-32.758982,-126.484468,-106.61274,79.36818,183.664417,318.630321,322.319239,250.616307,61.84303,-0.906674,-26.817804,14.275614,131.812661,165.713164,137.185979,-15.062021,-121.041018,-260.262568,-243.901997,-58.627223,42.324769,109.768049,3.932752,-84.931537,-237.300513,-266.079955,-230.881168,-185.379937,-90.576185,9.558138,38.747758,-36.934429,-106.914645,-153.531256,-119.108448,-17.085309,34.052812,145.589749,179.438705,149.007813,22.161516,-56.371657,-101.932545,-53.729843,30.18627,116.793342,160.598707,93.822411,1.428652,-160.770712,-209.116571,-191.355852,-119.406221,-3.568345,-70.958513,-158.822055,-427.237515,-578.143932,-672.54831,-579.095019,-369.400228,-321.576834,-355.494453,-526.668059,-607.92681,-603.951016,-516.900643,-281.287763,-169.540658,19.767081,117.352131,101.137834,-39.394928,-124.403372,-204.45577,-170.531427,-33.857821,66.836271,106.178489,132.934294,106.205816,9.862331,-20.94433,17.559878,68.496838,160.0818,166.381566,113.117031,-45.014878,-104.769829,-182.992393,-215.052892,-211.598774,-90.50882,-56.310013,-133.745004,-209.943966,-353.431163,-400.27448,-379.389254,-302.909928,-126.960556,-123.382416,-160.567219,-152.491541,-131.097588,-193.160645,-256.465667,-299.735382,-206.848626,-170.862904,-203.530011,-244.67222,-312.246878,-323.34775,-232.383825,-135.349723,54.643086,113.180522,85.426106,-21.45942,-79.801054,-149.239316,-138.160184,-29.645409,127.23133,159.48208,38.071426,-65.365066,-205.839059,-226.399469,-173.518871,-123.302051,-10.615746,75.706792,51.810063,-114.513085,-196.268471,-258.912509,-225.142633,-89.827686,0.09985,16.86398,29.128972,11.973367,-124.908879,-206.657991,-209.229294,-117.600528,97.337202,154.116453,109.299453,-1.518555,-30.85922,-47.849284,-32.908272,85.764863,226.764029,249.054325,226.591922,208.030959,120.752784,58.521774,19.043806,55.8302,149.956525,128.982163,63.240351,-58.259067,-65.507007,13.521136,44.922873,21.746636,21.283858,36.71246,-3.501325,-50.284286,-141.119061,-182.20848,-222.547777,-211.620312,-142.615199,-73.215294,-65.611523,-137.781818,-204.826209,-248.042016,-191.536207,-37.186964,105.897634,175.739438,227.9695,207.861467,167.84194,180.243251,295.198235,376.473203,498.470602,454.288669,358.85136,163.968197,118.74329,115.167222,123.619389,151.282938,262.900495,318.05785,295.39184,237.413968,147.05054,120.99528,87.062426,89.171819,137.080843,111.134374,42.201195,-84.73567,-108.406188,-116.75786,-122.001212,-95.50998,53.446448,119.451224,97.581548,26.368954,-129.624019,-167.264986,-105.624029,-47.113456,30.893603,63.159973,48.839255,-68.571871,-153.117109,-231.249083,-179.756504,26.474915,202.080733,244.64995,223.415009,176.962154,57.851045,6.151994,29.100057,113.91739,219.113674,96.378842,30.406703,-35.229339,-63.483505,-90.180932,-59.98375,89.424096,291.342293,341.03401,204.111114,53.993832,-196.401135,-225.605445,-112.838179,-47.569508,32.534509,64.885831,63.841923,54.57741,31.2409,-63.152811,-94.238324,-23.808287,159.651618,208.041575,121.892221,31.171061,-97.006015,-115.616807,-105.942619,-99.003431,-66.228781,-5.771139,-4.312,-130.850864,-235.051481,-320.244694,-265.828137,-97.056541,15.698337,39.02058,18.232558,-11.973476,-39.488074,0.658178,167.021717,226.954742,223.630955,107.365277,39.428248,-40.688228,-63.43667,-83.782843,-44.139637,115.575821,257.750497,295.018259,231.871932,143.32571,-7.529659,-13.805703,125.414823,208.252468,288.31487,282.005621,255.17797,201.586719,175.634222,63.282936,14.682001,84.211429,241.683037,254.415205,174.391085,129.738501,-0.031125,-85.944258,-170.300794,-138.847224,15.900088,88.631294,29.672137,-148.09449,-189.337099,-147.586023,-84.019343,60.937204,149.766492,146.532093,43.029217,-28.145205,-158.934483,-193.583421,-127.443171,-49.513952,77.820784,116.076545,92.716788,-24.364243,-102.705587,-257.829835,-294.063311,-206.275004,25.196462,107.167295,97.856986,40.191826,-96.593885,-134.095073,-79.794752,-32.887978,25.44529,51.247289,21.8451,-108.607056,-166.773212,-177.180972,-121.632071,-1.572853,41.800864,71.89317,151.763347,155.758956,60.635705,9.63373,35.627895,105.724915,250.079761,264.483979,190.251559,11.327836,-14.968747,89.093531,162.851399,222.849952,222.760857,228.067731,185.829344,111.159153,-103.517624,-169.46284,-92.643176,10.193144:36.801204,30.243518,22.466565,-47.197674,-94.168634,-161.2452,-193.083252,-238.486436,-179.505127,-151.371741,-160.116205,-155.403987,-28.402801,70.95883,179.30577,159.63185,100.656308,116.438182,118.515916,69.372893,28.350152,-53.482536,-81.810953,-111.333745,-141.337302,-164.508781,-189.223478,-159.12435,-85.519508,-100.902089,-156.544853,-136.939367,-73.337383,-126.215887,-170.455513,-207.412511,-223.323757,-293.707866,-308.975032,-272.333966,-229.631858,-201.584303,-163.824585,-174.726685,-208.361328,-203.631287,-136.07824,-78.715329,45.298002,136.974631,157.73092,172.72448,181.298567,145.780267,88.233641,-1.734098,91.961975,154.908667,123.939666,54.437315,-42.449253,-64.561093,-77.955378,-58.010944,66.742161,117.0562,30.765031,-221.880843,-315.344836,-425.591464,-453.275148,-494.707591,-577.903979,-604.381309,-574.766935,-535.41096,-455.517025,-408.021317,-292.860223,-248.000871,-172.346328,-90.291873,-76.979564,-103.166508,-110.343487,-111.155025,-123.203476,-145.120531,-79.734787,-8.094401,113.544652,153.359353,212.594034,199.877699,118.133439,104.288787,93.4334,30.556564,-0.40611,-70.104044,-128.285757,-267.793286,-299.469749,-229.466926,-145.15507,-146.742333,-198.289137,-212.082897,-162.238618,-114.154161,-100.568685,-136.655268,-133.783281,-51.782313,-26.857962,11.11423,18.931727,-16.918478,-26.482707,42.547939,120.664376,124.212048,78.154368,43.645867,-46.74998,-91.990121,-55.142811,48.821182,291.701429,377.302549,364.374099,348.94194,345.670764,296.822772,271.148196,255.272234,293.537749,319.011031,253.326929,171.101703,99.270711,139.776578,245.631008,236.067756,130.607503,116.004179,106.478639,15.876883,-24.119283,-49.210529,-40.309678,58.825936,247.695067,323.836995,401.837986,425.953273,425.865669,381.204899,294.12177,298.494912,345.718217,241.402353,159.854408,138.206458,164.955774,89.946136,20.841891,-13.469122,71.632235,147.156566,281.742448,298.552009,270.687492,251.631262,198.727122,172.940145,187.518348,260.625923,266.295948,262.84312,291.692516,315.582599,276.828965,197.95576,237.134609,274.117826,283.424012,262.401815,204.944728,150.802191,41.847628,24.895355,3.201171,-31.788803,-34.002954,-19.850785,-5.743701,36.097825,61.753394,92.122335,149.392987,235.725616,391.09933,376.679646,227.579735,192.292202,269.990293,314.847601,324.849166,284.375629,252.675072,202.24931,187.411888,132.111816,94.325247,81.787118,123.810286,108.099169,10.080581,-30.553831,-82.200589,-93.638721,-43.057082,-4.844835,5.187506,-45.97441,-80.482446,-115.887214,-105.725016,-89.866667,-96.371057,-107.167186,-40.229789,1.999689,-41.822102,-118.615464,-161.219693,-98.703065,-19.507466,-56.907405,-145.612993,-173.491433,-217.534708,-333.028111,-360.890057,-342.774382,-302.857166,-183.569742,-35.589275,35.115601,95.149363,83.828446,34.33009,6.672245,-18.769701,-17.456861,-52.966959,-103.745132,-113.870263,-162.782126,-205.934944,-228.419522,-167.046386,43.286305,137.42817,111.346334,-12.71603,-73.676816,-147.823359,-152.781531,-93.657905,-52.299068,35.496695,121.463388,139.791259,154.014766,142.915007,69.78393,48.333458,73.225345,147.699773,190.606672,178.095401,116.96889,35.250908,30.817524,18.977311,14.964723,34.412133,5.657079,-46.652182,-183.346818,-234.217062,-220.854574,-167.432881,-84.421046,-114.194907,-156.76318,-203.568245,-181.436624,-104.488002,-76.049226,-19.619232,2.962895,-23.988081,-110.300249,-118.914404,-40.34022,5.167436,41.722771,43.351248,65.519685,132.922562,154.902495,131.832262,119.456161,140.681991,144.048159,108.437072,83.816693,56.245256,88.322509,95.42836,62.207893,46.432144,19.507065,4.957042,-20.981724,-46.835815,-44.796,-7.755748,22.755308,36.343547,-0.626329,-44.718362,-28.425515,-18.270114,-126.848483,-208.527231,-263.189755,-212.179305,-143.166268,-191.729423,-326.687836,-225.971642,-121.025151,-39.791306,-57.763115,-103.955582,-139.315206,-217.978392,-221.441554,-143.998762,-122.024533,-142.050799,-153.115287,-161.104722,-244.287736,-283.073142,-252.881729,-148.645774,-118.219682,-112.479463,-96.128444,-50.29472,-77.930705,-183.449664,-203.078944,-208.388519,-245.352813,-257.925526,-235.633178,-215.347927,-214.610391,-226.362947,-230.548875,-183.720531,-154.282351,-168.736895,-204.940944,-271.021517,-293.164986,-263.280341,-206.685175,-72.929231,47.410924,73.753551,26.232733,-22.507709,-61.110817,-28.785483,54.263704,57.667567,23.967016,-90.082465,-134.954548,-164.598908,-163.064924,-97.577691,-26.216813:-85.080271,-28.831028,-11.564504,-79.00395,-141.284843,-198.070169,-194.925862,-221.531446,-219.457362,-183.475779,-136.926085,-126.131317,-48.256679,7.818958,46.976382,16.061786,-16.257419,56.754756,64.758045,-13.408584,-71.475217,-170.242031,-204.116447,-259.034867,-320.597879,-342.359907,-339.752438,-324.65276,-282.694078,-245.583118,-147.470643,-114.634677,-102.98942,-105.921327,-111.788604,-120.359551,-141.278269,-286.503345,-353.445714,-351.07081,-251.569554,-196.312388,-170.437428,-188.275884,-194.764023,-188.899656,-136.634374,-84.381067,27.347504,144.348564,191.594418,232.52368,226.350456,138.613107,67.597746,-26.934749,-3.062874,29.747521,70.785907,49.453985,-100.229759,-151.239237,-23.096153,78.898168,123.967815,40.736717,-12.805007,-179.826648,-280.432044,-382.403722,-371.879664,-365.56339,-438.575582,-466.738334,-472.865501,-457.229553,-448.717015,-465.195292,-436.212031,-365.318515,-185.929192,-116.081777,-139.689752,-172.997042,-150.808617,-103.775222,-104.811432,-134.576489,-92.235687,-19.846309,94.518429,97.686872,56.449315,42.400042,38.024172,20.02038,-82.247324,-122.716301,-103.900926,-110.57334,-161.968522,-305.988472,-339.051902,-278.013843,-224.304018,-241.286019,-277.616565,-277.475176,-300.012712,-326.811889,-347.961624,-336.950125,-286.277467,-202.977505,-157.682632,-118.642564,-139.113536,-173.284918,-159.270896,-134.586832,-131.33453,-119.810133,-117.956641,-146.664841,-224.248027,-234.943837,-133.151663,-38.780115,113.472367,148.650028,130.300572,115.849757,132.558361,131.116569,120.615146,147.821452,165.56553,140.637892,19.899958,-41.097807,-71.576936,-57.868645,-92.071533,-153.685006,-222.216844,-132.984276,-107.101518,-179.617933,-254.846095,-360.541044,-344.262007,-204.567905,-46.481491,25.546705,154.104998,202.095886,167.009979,76.838827,-38.786304,0.485449,138.744762,75.803864,5.775094,20.156833,66.6039,-0.411971,-97.870059,-178.218348,3.997526,110.324503,142.213213,83.267854,-33.776174,-64.193676,-62.93954,-48.335682,-30.438459,-45.569347,-71.103493,-66.635055,-12.880141,104.684083,115.237749,19.839601,5.358377,58.10728,91.960004,61.331503,-14.438958,-67.986931,-195.635903,-233.755406,-226.450756,-193.41288,-189.322195,-201.320188,-221.9916,-244.820472,-225.288315,-187.28879,-119.695308,-38.310717,119.429823,147.616519,101.727162,47.010839,-30.908463,-14.535432,106.739328,178.96345,180.859085,206.294374,211.272611,85.285992,-10.450326,-72.568108,34.952991,77.3319,62.225276,32.417588,-29.574382,-51.743704,-19.64703,13.828457,-4.30882,-96.842021,-111.942662,-56.112066,-36.119467,-92.582223,-135.990033,-166.137343,-101.17559,-55.402448,-46.761773,-86.897135,-155.659816,-172.139098,-169.2937,-137.627683,-21.569554,45.716997,35.042647,14.641987,6.806122,-98.508493,-160.483821,-114.398081,79.876769,142.621442,146.236368,124.889448,113.362617,104.187966,32.769399,2.99339,15.261696,17.994771,-6.983887,-95.042017,-163.61129,-281.561221,-253.002018,-3.674968,176.268284,169.794494,52.316172,-3.084866,-50.111017,-53.384212,-3.759063,66.08509,255.19627,412.016486,434.467528,423.978883,434.618078,390.72979,299.119731,138.618345,202.983949,275.23974,302.432477,252.582516,211.003796,238.171209,273.022833,275.530594,320.535704,430.53418,455.633034,327.89803,208.734003,80.733762,105.99431,166.463358,57.695717,-7.808312,20.676143,109.730917,273.867939,302.246406,272.23638,244.321157,215.416554,230.725294,240.483649,269.458473,272.800395,183.489059,120.592196,134.221366,327.352316,399.212324,393.706935,357.967164,316.536743,313.039171,314.223332,301.606713,281.511422,332.283081,346.595872,265.018222,184.265427,93.501399,111.803282,169.412527,168.730994,169.478745,216.914373,261.401534,314.120505,304.101775,303.55248,333.216551,341.527233,193.925934,123.233265,129.562678,191.089154,268.488228,230.783348,74.531324,97.340201,180.557726,274.718902,269.190143,221.407233,176.489815,91.393134,93.762594,151.937349,147.247759,137.000296,155.181918,158.095987,96.137326,55.418158,41.81501,78.434244,80.847775,94.487245,128.843401,168.262366,137.202756,64.363736,65.847353,75.905435,30.319905,29.84301,141.227373,200.994642,155.731242,81.192148,-1.389005,53.950986,104.966371,165.358547,165.797781,135.027824,117.413763,140.68866,186.916856,272.055347,328.840068,337.241104,302.046684,284.063699,277.792777,290.283662,349.016873,403.712519,392.255323,301.738438,262.375249,202.114279,167.96145,213.830425,314.140303:-7.704306,21.642842,29.757434,-44.19134,-104.512814,-192.974305,-195.246831,-128.052145,-76.390886,-81.667947,-127.327136,-133.10928,-84.780183,-55.914921,25.812096,105.219757,244.654137,171.451623,97.911283,76.81436,106.960172,97.490882,77.378614,55.369171,-10.788189,-59.434881,-97.52297,-63.835402,-11.889263,-34.928609,-72.966567,-55.259304,-36.432813,-128.33038,-194.475707,-284.884982,-295.669947,-257.203581,-205.899251,-132.298949,-163.783978,-162.152828,-98.731562,-88.079482,-191.554604,-260.062948,-246.31887,-169.275538,-26.97364,52.165114,70.353226,32.668558,-5.235957,-21.665511,5.33642,57.043924,78.123,84.322778,20.616171,-50.630635,-175.736885,-199.388147,-134.542277,-62.491126,56.321996,-8.824038,-123.270308,-363.585371,-461.993107,-626.277719,-635.234981,-457.400441,-365.994944,-430.473042,-603.17348,-627.38324,-536.520045,-468.672647,-337.280281,-264.923038,-124.878587,-138.115613,-210.11431,-303.316142,-291.908834,-212.585649,-186.637937,-203.658304,-177.6093,-131.105203,-62.321523,-29.834843,82.024345,108.732899,61.021652,47.914356,57.589025,31.599335,9.158829,-42.40459,-79.51849,-173.140275,-194.409614,-171.851846,-160.813491,-174.177171,-233.61478,-268.931373,-291.849672,-276.9333,-259.244911,-270.340535,-313.362905,-291.811159,-228.431686,-86.834813,-72.765523,-140.058538,-170.735176,-215.676328,-171.625596,-110.413058,-108.636663,-182.164488,-307.997124,-316.190469,-186.605107,-73.458524,84.278966,64.517174,17.598004,-56.320661,-60.701809,-21.772998,12.381904,111.615782,185.683127,174.550375,59.008863,7.10575,-43.956733,-61.305364,-49.838848,-39.98451,-52.177173,-27.987207,-29.613024,-92.196816,-140.960148,-235.564958,-228.346626,-75.720308,25.758647,38.457412,85.847007,94.255948,11.08774,-39.474628,-63.789298,-38.841755,51.441338,53.276019,8.429698,2.407523,34.921358,-18.785218,-90.371687,-127.930638,17.520771,106.389416,226.643701,252.900633,261.843163,253.708337,207.726511,167.833421,131.823954,150.908814,111.316331,23.412393,41.046118,100.314043,101.215439,118.397545,144.096921,133.294652,86.108452,66.068148,29.26228,-3.706993,-88.617259,-120.468535,-117.143142,-80.543845,-99.675759,-172.333373,-172.062532,-46.113752,35.684408,82.995138,104.194451,176.572065,292.312477,277.862342,197.67059,189.477543,269.787721,324.712364,369.00743,313.945856,267.525397,208.650923,195.171085,121.770178,69.659679,51.246439,214.614922,290.576052,233.514045,137.413136,-25.172707,-84.221555,-123.432563,-76.390047,76.703441,64.05465,-16.720629,-121.016331,-108.250965,-76.930384,-80.813793,-88.650212,-83.700124,-43.100524,80.576214,101.792385,7.649395,-59.253108,-100.531455,-101.235028,-160.60007,-196.48462,-183.662633,-149.586868,-149.587861,-160.3192,-132.54995,-7.832267,145.468899,206.413659,210.614388,182.018256,166.604989,164.146093,141.827999,136.046786,130.582602,101.504752,77.073853,-10.282933,-49.885702,-22.194057,42.944676,165.56875,207.044298,215.767311,165.842337,86.923255,-109.88182,-160.469942,-82.981973,-20.972211,26.387408,57.457834,66.078361,71.366563,78.457708,73.812014,47.866515,-10.159019,87.618622,170.945217,202.8387,167.897014,137.21807,128.224577,42.927511,-1.832763,-40.543442,-96.430367,-136.928687,-214.127307,-224.758557,-139.55625,-76.989268,-42.03599,-115.237637,-140.210506,-119.322376,-70.231884,66.695261,113.175706,112.762928,81.909722,27.827546,-2.294307,-14.004547,32.842228,86.54767,113.614093,88.048231,101.948817,233.205278,289.883388,223.490144,119.811758,13.575193,47.710862,168.423172,200.596923,180.781836,167.607942,189.477806,192.527307,146.355636,34.657588,31.198142,156.599556,267.403196,268.445028,211.616335,185.568438,92.656868,7.725146,-112.237874,-100.601096,-29.344635,-50.531605,-74.16518,-79.793233,-72.176679,-48.70887,-34.481991,-28.271121,29.620484,68.787936,20.954671,-41.846678,-104.833512,-117.862542,-113.048266,-81.679162,10.748533,85.950331,84.832854,21.453963,-17.98758,-87.840697,-94.036901,-28.753271,60.837922,94.004584,112.85868,93.681493,23.38965,6.636707,61.06002,97.751837,122.134351,80.585764,22.42789,-88.489422,-94.71331,-70.922631,-78.809383,-87.094783,25.789418,105.831516,182.459937,157.888257,23.379094,-31.841136,-0.176207,52.98148,130.349948,219.577064,236.110646,179.123709,154.390789,169.512153,191.28806,226.826939,242.475793,232.312439,178.438827,141.79982,48.183733,15.820428,61.280802,105.135945:forward
140.639681,63.565165,15.056168,-7.578041,31.805546,82.84336,52.770018,-97.472687,-213.539286,-211.08792,-154.684369,-132.989843,-109.067944,-120.628258,-159.676128,-153.401012,-132.724041,-148.186411,-147.731853,-100.452109,-49.617903,23.30631,21.635838,-10.212523,-51.723667,-44.380076,9.044866,-0.45666,-121.846275,-199.07421,-314.575282,-353.904861,-377.148139,-238.663133,-138.118737,-1.417002,34.197356,80.0471,85.240933,47.338816,15.617575,26.509722,89.70034,139.105899,227.695462,218.773399,78.909339,-11.634987,-142.525717,-115.990971,-69.098055,-22.511702,-27.887671,-73.698429,-109.036925,-129.492462,-47.363562,-9.678327,-3.488405,-36.919545,-134.645362,-161.233231,-116.610434,-76.49371,-55.728742,-147.646976,-219.178918,-283.691647,-248.15919,-147.928291,-135.604966,-190.505355,-232.631545,-218.619914,-132.117964,-86.477337,-73.350733,-112.836891,-216.498046,-248.656739,-259.795129,-262.818026,-285.359407,-321.408088,-295.329118,-220.493564,-218.313668,-244.089467,-198.505484,-143.959693,-31.26383,11.098441,17.239301,-23.433627,-69.206665,-35.491862,62.718316,42.228436,-14.152125,-123.303172,-142.189769,-123.764573,-105.932145,-43.731717,25.303073,48.589434,71.960296,70.56551,38.870769,-9.467041,-169.987232,-234.160121,-212.093781,-50.458903,-12.067219,-35.362217,-32.742098,52.868465,120.316295,191.369976,55.501054,-41.613827,-77.645784,20.772754,249.8672,280.590962,201.397957,140.240615,9.242808,-53.094051,-33.614534,42.280392,62.990563,72.177433,100.564704,181.780677,135.791139,89.744896,53.77804,44.62607,-26.334395,-71.82148,-92.71576,-78.394781,-89.040948,-107.264873,-93.844223,-62.798257,-73.732776,-147.72741,-195.676297,-299.699421,-347.897433,-349.383811,-331.308549,-285.533754,-155.388727,-138.909978,-191.446648,-197.912439,-159.858041,-92.849493,-40.003102,72.734614,108.455131,107.138352,88.486732,52.222946,-6.762305,-14.489374,53.509196,94.225751,131.286652,125.010856,50.546582,0.742543,-27.636717,59.469799,115.926906,201.923509,233.043974,279.16931,288.073389,263.637005,250.120251,250.701027,206.814324,179.491846,166.917035,161.663368,104.422619,52.521765,-93.606352,-179.178567,-135.318596,50.30946,92.337285,-38.513163,-147.851516,-258.564029,-210.546637,-183.52018,-184.676784,-190.983859,-168.539533,-137.983367,-65.395278,-48.807732,-85.425814,-121.46087,-97.174544,29.939474,91.673013,102.139049,65.224488,12.851643,-0.27622,16.278068,124.254922,192.474712,260.811309,246.204433,137.652121,76.89073,65.919866,157.981992,183.649071,211.896985,234.076715,206.253832,136.934917,-7.294427,-71.178476,-74.50615,-30.780856,7.062835,62.602557,76.618634,100.215751,86.769798,-10.057162,-14.798871,46.15853,176.351413,192.129763,89.064656,13.634024,-112.489536,-175.806732,-129.228045,72.264251,136.380803,93.334754,22.536972,-90.741565,-117.824656,-142.093463,-64.490756,10.301303,67.227847,15.579579,-168.352799,-250.408492,-332.459458,-286.731089,-227.783863,-129.431868,-95.553736,-27.387884,-14.797429,-36.523501,-51.853388,-88.592128,-71.53732,-42.129922,-24.516585,-26.895277,16.239621,44.314249,-10.763837,-156.052338,-177.765097,-110.636047,-66.811745,-63.449644,-116.077166,-234.871739,-269.798117,-294.103818,-295.236113,-301.893503,-266.315228,-207.375579,-87.509722,-66.352637,-116.052448,-191.65007,-210.105507,-210.735192,-187.806267,-131.257463,-129.524347,-144.902509,-140.632977,-99.390704,-1.911755,25.083239,40.3872,62.477581,75.519584,46.818254,-22.083892,-57.971146,-49.863203,19.638633,77.693158,183.813041,184.822848,65.78353,-13.275009,-95.404707,-17.851856,43.259965,169.591439,227.281468,200.206179,129.475506,76.533327,146.065541,180.376877,204.822957,199.698538,178.77872,161.356285,79.715461,5.415018,-131.642263,-171.471582,-181.833555,-188.117205,-173.380048,-155.426976,-171.759392,-240.720732,-263.325328,-212.763437,-17.353051,69.844959,91.663404,24.010996,-128.542639,-173.263695,-198.606899,-116.906094,-56.032763,3.898972,-12.248332,-109.214019,-170.170274,-293.607797,-338.616184,-297.915286,-145.695985,-68.419294,52.098063,73.24153,33.332267,-1.941952,-74.534924,-52.914134,36.81214,306.878601,408.987577,398.498224,318.325987,170.070728,85.187831,81.186627,174.733014,231.688441,214.675211,142.571915,11.918171,-33.406651,-81.850295,8.990296,77.916333,147.883225,133.105225,50.259076,32.19644,60.791391,25.358009,-3.160896,-10.070499,-3.819249,2.890197,-3.270679,-83.427353,-156.198804:-62.152214,-88.048986,-72.104759,37.351801,86.119986,65.041044,13.30299,-99.064949,-146.247771,-109.90811,-21.720469,-13.707154,-7.117243,7.631525,16.446494,4.652403,-9.301661,35.821051,55.309297,41.367471,12.964739,-53.411208,-65.334079,-53.855849,-100.013184,-116.267404,-70.47702,-37.197713,-42.433226,-105.979072,-300.625644,-356.345171,-285.704582,-123.11094,-53.971749,67.902037,92.273045,53.477915,36.34315,32.644098,12.849717,32.418418,176.167192,252.058715,278.348692,229.6236,150.886098,136.905872,65.358151,-15.685918,-23.347728,-5.933845,-13.188311,-64.68059,-75.789933,-43.592197,-19.38545,-36.474469,-101.239886,-109.738848,-56.448391,-23.948925,-26.538444,-70.00718,-141.621749,-93.026876,-69.598291,-66.28116,-67.303737,-135.047071,-217.166791,-353.555225,-298.598253,-223.896006,-121.206243,-105.954386,-77.030794,-66.611655,-113.963585,-164.612757,-238.894823,-236.817203,-216.711544,-158.265837,-138.428704,-144.014989,-148.962103,-129.139728,-105.628303,-88.241158,12.712884,82.620641,117.203074,61.560884,-79.377582,-118.912984,-122.386262,-87.500238,-73.347849,-29.486354,4.499237,28.182035,-7.408293,-128.231856,-131.405089,-68.923449,65.183198,100.707338,36.286874,-57.37142,-202.083358,-219.93781,-172.670128,-13.98796,66.870275,111.551275,84.032067,7.783107,-14.741055,-2.365386,16.220017,11.790093,10.997204,40.013607,135.814701,162.508741,108.093632,32.847691,-66.798974,4.837668,32.357734,18.314497,19.824979,47.740726,59.466059,68.396514,18.793785,-15.951975,-24.795277,-4.578763,1.499742,-14.147263,-57.314107,-104.161547,-214.428186,-218.955315,-196.611735,-141.596254,-122.110762,-151.492781,-192.289217,-307.927674,-380.389905,-356.484724,-254.926344,-215.464597,-178.359511,-179.389116,-215.350304,-231.82942,-174.940398,-34.476687,9.173338,25.274719,2.689019,-42.045817,-4.761484,119.197348,65.924214,11.928635,28.586367,86.748936,127.704846,85.783384,-8.663617,-36.506907,-105.08502,-106.128505,-21.469922,238.684954,331.538327,366.185479,340.026462,283.377957,270.01364,275.844909,255.001415,224.83791,157.061479,127.802383,99.345337,93.988994,82.785377,93.469524,108.663344,139.849956,138.605194,26.00486,-89.011714,-268.010836,-182.121581,-105.8019,-74.305543,-82.522865,-2.59181,60.022018,48.018587,-30.503254,-147.402772,-101.99439,-58.105974,29.907521,84.591649,165.013474,150.789933,4.911281,-62.408827,-11.505759,112.476731,141.775139,143.579979,136.665609,172.862942,203.615248,220.693013,258.581945,297.205357,298.462773,253.514789,172.763587,160.295916,157.991095,170.766427,179.533263,207.127959,230.60812,205.723291,155.575044,111.325121,106.400581,72.502115,146.091617,222.766257,284.424332,232.152924,50.937523,-9.214615,-55.482352,-64.704782,-42.173951,46.88748,92.267528,111.393197,75.568617,-12.389779,-58.277075,-134.078497,-86.466228,-45.640184,-44.95527,-82.243173,-161.832765,-207.360217,-367.141114,-441.480921,-368.724915,-153.470922,-103.495255,-105.273898,-113.069918,-170.212091,-228.496567,-283.08283,-195.88606,-139.001885,-18.682947,37.984319,51.014102,12.95375,-49.517809,-65.564364,-62.344085,-82.234804,-109.043508,-126.362332,-111.675661,-100.055642,-129.018952,-255.43962,-363.550565,-381.517069,-270.187142,-162.518994,-54.315421,-70.840846,-152.304158,-205.898892,-180.075787,-62.329768,-13.247995,21.625066,-3.613653,-77.866373,-77.869002,-5.156945,31.231729,42.380075,139.67457,182.987937,141.246877,73.478068,-91.088073,-156.390974,-116.552742,-5.118142,32.701703,85.678056,94.945402,60.044201,14.645408,-73.201174,-21.571701,44.838712,161.838418,191.437396,143.666891,97.160979,102.792753,132.820631,104.84682,107.834693,185.026036,305.000781,269.111994,93.361894,10.561478,-111.95086,-164.33522,-164.987702,-139.181316,-125.203879,-137.562371,-172.987755,-230.353517,-190.679822,-128.592666,51.860973,119.592593,104.565973,47.442273,-48.618077,-85.288165,-168.045746,-148.722329,-71.622395,90.557554,115.111932,35.552898,-24.797679,-113.721558,-158.446261,-157.976243,-119.999554,-81.140829,40.018109,97.537273,143.089016,115.634982,-0.294719,23.62738,118.793488,358.55057,439.487066,396.03031,280.481547,72.286475,58.142769,77.390801,122.554428,168.272192,224.766169,184.312185,30.373711,-41.080169,-125.905318,-57.554202,2.480969,62.054451,43.806793,-74.648112,-132.612536,-177.794566,-158.572787,-147.676377,-127.871908,-101.131257,-68.617925,-100.507968,-224.743054,-274.575609:-58.730517,-107.877931,-108.702397,-5.470859,66.371613,95.700001,44.113396,-79.12281,-124.794893,-113.916678,-16.474796,57.454454,130.093922,100.34108,18.382925,6.42889,31.739191,117.115751,158.989121,181.848626,162.686564,69.711554,10.203805,-62.802246,-47.541843,-18.058598,70.396751,107.455857,55.934028,-35.756117,-205.311274,-247.039158,-231.193588,-62.967719,38.010015,123.463997,98.480035,42.188486,36.388704,-7.087758,-32.244799,37.653635,311.251127,421.51118,394.643855,292.414187,148.339512,111.507543,4.718139,-29.826646,7.352674,66.643099,62.117793,18.75237,-19.98124,-96.039301,-34.94253,30.811311,87.636544,68.800197,6.499729,-12.783473,-43.038842,-72.327927,-108.424847,-37.040702,0.124618,-32.39934,-82.412424,-160.403543,-184.919787,-236.824589,-276.861019,-250.158504,-100.528835,-26.309556,10.473152,-31.712685,-159.790964,-211.541941,-246.419553,-187.852424,-132.387442,-36.178571,-25.764124,-68.748265,-92.352795,-108.189221,-71.817559,-27.46846,81.954033,118.963537,77.165531,6.126522,-106.619308,-140.337155,-179.557692,-100.057085,-42.44709,13.644666,21.104549,9.024345,-14.83037,-61.516021,-41.532525,-5.894391,90.681498,161.329304,255.09345,203.476308,-60.816885,-167.391476,-173.792387,-56.667628,-19.355245,-29.829762,-73.076084,-105.586303,-54.342175,33.126385,-58.959114,-87.948423,17.214311,97.337361,155.037153,127.511014,2.547683,-77.176767,-154.886489,-66.979207,-24.172546,-38.664609,-76.585306,-134.115404,-142.428445,-140.132308,-116.155821,-85.796321,-11.108107,3.141157,-50.569031,-91.664175,-148.092262,-170.492365,-181.979225,-125.675336,-94.98734,-74.330685,-91.721119,-187.379194,-260.902434,-410.825656,-497.602817,-489.527749,-386.973633,-337.654659,-293.868756,-275.202167,-217.684378,-202.939352,-198.105218,-106.464194,-42.540602,-14.751637,-39.229003,-15.571459,14.347068,-36.338941,-113.334704,-104.658046,-32.937028,4.924266,55.765113,65.787752,24.450688,-21.018825,-65.834476,-19.981388,20.740844,134.690833,194.842216,271.404603,277.07946,240.27423,213.521463,204.522522,209.636286,238.530418,259.204543,220.010488,133.454934,107.018894,56.558902,52.20128,68.005695,80.802093,56.606095,-75.954182,-176.121334,-320.067277,-239.637317,-151.983053,-11.468408,22.119697,32.563042,41.407571,81.007221,69.603877,-39.559697,-76.929643,-40.730123,78.683087,133.266792,135.969952,75.213556,-68.068396,-96.859615,-50.536729,117.535084,211.979955,336.536773,349.848395,341.672682,338.733556,304.578296,261.281136,269.897595,322.107609,315.079429,222.201963,181.864459,143.939335,132.017345,133.439158,165.43096,197.294084,230.276734,208.541197,112.109127,65.507266,49.664731,148.261488,194.604703,197.922608,158.28877,58.896515,27.864596,-23.016586,-72.808754,-60.277284,14.967587,46.873684,62.301882,31.104382,-68.251601,-90.525466,-63.440419,-42.809784,-38.287608,-27.155584,-47.905009,-147.61588,-198.453373,-282.485513,-288.412448,-238.713247,-100.509672,-57.533665,-57.636192,-89.157208,-191.851302,-243.074626,-257.273683,-165.603343,-124.181963,-59.818301,-38.312977,-32.121676,-40.052088,-92.221824,-145.026777,-121.069607,7.76928,58.869597,66.087221,48.866682,28.719427,-7.786348,-121.924074,-117.000374,-88.521473,-69.240573,-65.721965,-29.805068,-12.441699,-59.549331,-176.239836,-193.856277,-74.844259,21.843271,127.474847,114.309384,28.379053,0.521099,20.761216,50.233222,43.604387,66.083342,106.716318,154.548612,119.643894,-52.888689,-129.379616,-100.907552,-29.253448,4.261813,91.900137,116.257987,47.955064,-31.514925,-123.464147,-30.959271,45.275092,168.34626,193.581881,169.609609,126.644389,26.462922,29.372665,65.484313,122.974109,135.856769,116.921374,81.638792,-7.588356,-41.655295,-67.311551,-57.106051,-50.369097,-25.750281,-1.309675,30.456122,7.191385,-122.965788,-152.832478,-76.815067,120.639296,182.517695,175.643064,116.537169,-16.595541,-61.785135,-58.90416,70.549572,124.267018,144.562208,119.950642,28.421531,-8.143017,-13.742383,38.930536,64.491663,62.10992,44.943977,58.630063,93.595453,118.540037,66.987533,-73.098743,-2.039678,100.763892,223.845557,220.036078,155.364477,99.445866,-10.239164,6.282495,50.946236,138.059456,165.457329,160.074166,130.35829,28.068156,-41.227439,-131.195917,-100.983255,-85.009087,-62.847015,-52.278719,-130.807363,-220.631799,-333.803433,-259.559056,-193.801998,-74.957315,-39.645144,-81.323717,-139.816274,-211.586555,-221.631121:-140.557088,-145.403577,-100.321885,-39.223746,-46.476981,-101.761099,-121.754542,-183.050355,-300.917132,-300.650266,-167.947199,-85.881522,53.488348,66.801324,-38.622101,-94.728551,-108.511918,-19.884427,26.662189,79.371803,85.289062,59.879167,51.628141,41.556875,-35.702375,-43.369843,62.375088,113.414834,53.138489,-55.593322,-258.897606,-305.469254,-263.216337,-47.424241,61.002653,153.963644,156.011851,153.835004,155.025421,130.101917,91.126404,101.33656,200.380126,259.6094,275.420148,219.874399,99.678916,64.76336,-12.371445,-32.268676,28.382367,140.056411,117.40549,-35.916946,-105.189921,-158.774151,-129.164641,-105.006979,-72.696576,-74.116566,-106.648129,-118.90969,-117.180384,-115.305999,-93.482333,-38.175365,-30.877797,-35.498655,-14.789891,10.96951,-30.503089,-193.855021,-234.988428,-162.487336,-3.115352,1.809492,-111.945532,-166.066102,-206.070306,-212.313288,-236.702169,-223.137205,-202.458288,-187.731346,-182.94621,-130.171504,-87.2967,-54.112689,-129.500541,-137.298291,-1.45463,78.530801,65.160842,-17.023366,-100.843751,-65.665328,6.498949,-60.433147,-124.260402,-141.427452,-81.515752,-1.050053,-0.896915,0.217843,-9.174916,-16.983666,34.395654,98.816521,157.479087,97.045065,-122.513562,-200.137631,-173.798692,-24.029601,7.366272,6.921694,25.691755,79.687259,97.760124,103.084242,3.895696,-72.583255,-101.214201,-18.505473,151.136102,149.373634,-6.723462,-100.140854,-200.453587,-162.130704,-123.162564,-74.69147,-71.66242,-62.408512,-42.095013,-35.074999,-114.359524,-124.17114,-40.099642,1.685426,-25.930907,-87.388708,-197.296716,-225.692746,-238.887869,-176.300847,-141.234943,-141.41496,-172.64459,-285.874192,-360.105184,-475.112351,-524.524727,-518.053563,-426.276938,-355.887598,-261.282632,-271.786148,-312.326504,-277.044569,-140.809101,-33.127908,9.141292,34.850153,13.381789,-19.505799,1.070257,36.65848,-24.907171,-35.173655,5.758735,8.003855,-26.52819,-22.828762,21.771395,29.320758,29.320086,84.903273,118.672833,180.636082,222.788461,284.134947,276.307471,203.085735,139.524147,143.061949,208.608378,230.584672,192.721941,138.403615,37.471516,23.98078,-10.095332,-102.068357,-92.223718,41.788702,75.697468,-34.629455,-133.921304,-242.488695,-162.751421,-107.684221,-63.544432,-50.556665,4.198975,35.747503,47.755424,4.899209,-100.667204,-86.788026,-46.257223,67.767699,122.287661,126.643241,78.557492,-36.904576,-91.359383,-58.648095,88.684014,169.72873,314.955546,350.340659,296.145346,237.865609,188.733637,256.236658,296.184544,339.790722,338.597428,256.722331,173.338167,-0.092608,-77.459163,-75.870262,-5.277986,47.806776,85.448839,65.596586,67.360099,88.390415,59.049834,5.658589,23.434395,90.108036,92.238978,21.010818,-18.018829,-62.841399,-74.840368,-40.252189,41.351293,39.375447,-7.485256,-35.178608,-121.346753,-173.388726,-226.570946,-111.671711,-30.026824,-20.430637,-93.585646,-230.60812,-264.221606,-322.859611,-352.5502,-308.83777,-146.71497,-77.109336,-13.73982,-25.336964,-97.273,-125.530511,-139.162736,-119.210596,-107.062638,-68.791363,-37.710601,15.278859,28.719307,12.182938,-55.967896,-81.11519,-88.103412,-68.214843,-15.174164,-14.955379,-82.768041,-124.439646,-179.907682,-221.380147,-241.046005,-196.349775,-143.908512,-101.897504,-96.317428,-85.827241,-131.804285,-131.862449,-46.58028,1.24004,22.353977,-0.369275,-11.447845,0.981267,-0.555921,50.012105,97.580563,133.708327,119.46416,87.40846,66.297633,-40.865013,-151.074221,-147.889759,-10.266293,90.642226,236.52876,248.510837,169.037136,95.410036,-51.200674,-43.145982,25.834456,218.041179,291.259299,258.331681,172.253139,50.502973,41.069103,30.863687,9.836416,35.750396,121.166417,133.308562,60.881389,6.207768,-48.47635,-69.984554,-85.772809,-55.943827,-16.020301,-7.665574,-58.92682,-201.596828,-221.669833,-145.807949,62.31715,137.543512,175.251639,132.668211,-17.934496,-88.283072,-149.355519,-96.521377,-58.654238,-7.601469,-2.359771,-28.42706,-41.368922,-72.228225,-101.854587,-64.528678,79.901116,116.175098,99.269137,97.880471,126.178377,115.212013,48.796612,58.082064,106.016925,263.288913,338.403446,341.889897,268.686728,126.254174,119.637035,165.235777,278.88742,310.917873,274.253091,214.07873,93.741168,44.484699,-44.918243,-50.245792,-12.200545,51.670181,56.0774,54.756912,43.603586,-58.194546,-133.836126,-106.86821,-1.661168,40.655557,66.081924,36.884611,-70.338789,-120.268856:-169.357777,-160.701279,-119.432965,-43.107059,-40.489671,-124.460203,-162.727737,-178.49495,-197.371983,-192.014521,-78.804391,27.941244,192.404466,178.347835,-8.303193,-106.521891,-158.076637,-19.295261,61.112188,184.523831,209.702419,133.179332,68.185024,-13.500384,-31.252398,-0.64753,104.496088,127.318218,32.591451,-64.497433,-223.327717,-256.853051,-219.212805,-35.410745,65.366497,140.055138,106.829304,12.227409,-4.831499,-11.949859,-5.557459,37.091706,194.72678,275.169667,286.682691,204.146817,40.760806,0.650589,-23.743753,40.085364,93.993846,166.472979,139.588901,-41.150914,-130.40005,-224.846137,-243.296647,-208.838391,-39.396554,35.480424,59.939904,44.083838,-22.78421,-88.986415,-168.305995,-91.201287,-34.144271,30.478831,21.13811,-51.821467,-95.140988,-187.065757,-221.875436,-183.097884,-61.254251,-32.519351,-71.812405,-110.537814,-179.346049,-210.360053,-254.125607,-222.311369,-206.944406,-213.81782,-201.997085,-124.472076,-90.91945,-96.15051,-144.774051,-136.487184,4.871559,109.574483,194.314039,125.554947,-100.183556,-173.567378,-153.68719,-16.685139,21.230342,35.527585,49.358484,75.668784,55.227053,-44.893045,-81.834118,-33.86806,108.827261,149.457432,141.666215,103.130054,-15.383638,-80.10275,-139.949681,-74.176141,-16.008333,113.897527,142.045135,107.327595,97.486911,87.589577,-2.784093,-36.038477,31.291833,119.839113,241.503745,226.015483,90.657958,0.55369,-133.924222,-112.019542,-68.293761,-7.96511,-4.309583,-34.054669,-57.280959,-120.97203,-180.207442,-178.301754,-104.648356,-59.990893,-34.351481,-66.475238,-207.355216,-292.682373,-379.739412,-289.313853,-220.692995,-145.738079,-157.373324,-284.004642,-378.366402,-564.652449,-648.020486,-614.300922,-466.653019,-404.783659,-344.022908,-343.628161,-368.220399,-354.937621,-233.915639,-102.524552,-56.976505,19.943619,36.703327,28.219263,25.693466,6.753903,-38.508032,-52.935869,-60.171209,-36.684647,79.653637,126.894733,94.617818,34.86347,-30.532109,35.827636,90.532495,200.001435,236.726654,250.981918,242.09491,168.3338,69.906117,78.678208,165.253769,189.830386,173.065344,141.213347,49.08925,9.636821,4.38444,31.139489,33.463783,73.520074,97.255384,16.580266,-84.224882,-224.225352,-159.459311,-82.294701,45.174794,69.476861,47.470952,41.064213,52.085646,18.085625,-126.037619,-171.225127,-118.618277,82.722732,156.037626,74.103798,-53.616311,-233.914002,-117.150217,3.331142,148.542862,182.067926,292.264718,346.397652,322.057887,253.778328,179.146256,268.502978,327.27157,385.770377,375.609923,273.980768,199.336276,70.315339,32.716257,60.074224,153.805897,185.66727,182.801341,161.157305,116.085739,91.148673,56.168373,115.447803,166.295014,209.357905,181.00275,58.068824,7.678139,-26.755417,-27.879869,-13.639757,38.850642,57.032218,15.152378,-44.587309,-168.163115,-202.83798,-182.086493,-69.193054,-22.699384,-48.887776,-118.316898,-233.771222,-261.94309,-319.334228,-283.935765,-216.870507,-97.213205,-49.205839,13.161268,-4.836771,-133.563129,-209.498408,-281.864075,-187.918185,-111.512431,-20.233568,-23.289782,-62.05553,-72.407695,-99.769232,-117.94538,-95.700378,2.914201,55.621947,115.57695,124.977187,99.999445,50.802461,-79.548853,-109.495859,-78.730041,6.079339,24.990061,-31.359699,-75.385229,-118.770908,-87.332041,-45.158581,29.753544,60.589862,133.085414,148.779264,96.887701,60.802293,19.518828,34.14378,86.005532,202.49916,211.489817,116.757316,44.380963,-107.47591,-180.814988,-162.841424,-51.403634,41.031527,242.628569,282.719026,166.922867,56.712452,-57.759876,15.538336,74.791478,246.382631,305.846837,215.50414,118.647167,9.857726,18.164214,38.458164,109.238563,157.477116,159.90729,82.31617,-91.148056,-114.222981,-38.76109,57.7305,90.707991,139.737178,144.990177,107.831396,64.73102,-80.170185,-103.471624,-31.381153,138.487924,207.420295,275.012177,236.729261,38.425626,-49.336708,-74.936451,25.852655,77.681426,161.578485,173.897749,89.291365,13.054717,-96.772885,-71.280203,-19.041755,93.19156,124.029382,119.158383,107.691892,88.19364,54.807407,-37.581217,19.717255,113.447909,304.860276,341.140848,212.458617,98.586435,9.443644,80.925075,103.011019,142.288632,179.45322,201.96123,154.429813,-12.888711,-103.542987,-227.032704,-168.187854,-98.608983,-35.787178,-62.35746,-133.521829,-148.245628,-202.633076,-255.15669,-217.456461,-39.561602,41.543788,106.372364,97.848247,7.277183,-62.262818:94.867559,-34.354415,-82.09307,-75.458787,-48.749214,-93.751761,-147.68766,-188.110818,-176.402912,-174.012983,-189.517179,-200.052205,-169.69162,-143.713589,-116.449458,-118.957877,-175.489029,-152.285712,-77.113021,53.379027,62.2332,24.520559,36.306711,103.499747,79.277253,68.265002,115.663681,127.648984,18.758142,-69.315123,-149.211315,-149.579761,-158.252409,-34.139766,73.002879,197.013087,214.355371,223.339316,215.598501,168.635528,113.394454,115.833712,186.485186,224.069063,203.136981,122.423588,-63.324924,-105.7059,-128.580015,-152.48454,-148.996347,-109.601641,-94.877285,-166.607013,-237.874454,-276.02797,-150.258795,-95.055594,-110.792333,-156.959939,-181.190259,-153.621637,-104.10078,-103.353159,-121.980758,-86.382126,-65.224911,-79.794725,-84.272456,-37.991498,-37.823695,-103.561379,-98.223792,-86.827665,-114.004209,-145.122973,-240.715112,-283.20707,-280.615655,-256.363361,-229.253576,-211.502157,-213.867543,-208.804664,-165.073759,-59.919815,-65.806373,-192.462091,-215.041986,-125.368879,125.214849,198.105956,117.530379,-1.73914,-96.237134,-17.322618,148.131023,109.704687,58.012071,-54.590083,-100.619993,-83.138504,-21.710105,82.275677,63.928097,37.919637,37.202593,59.722014,56.099183,-8.011241,-187.152479,-215.456944,-98.505222,12.889966,7.739532,-41.023723,-40.322794,1.179911,25.590553,50.778357,4.261976,-31.100388,-71.400953,-57.152538,33.215527,81.349685,120.65827,103.448787,39.302961,-26.719806,-70.56781,-59.012004,31.648186,164.146457,142.36698,31.571026,-39.646119,-34.641714,19.186531,16.600353,-74.596288,-114.258139,-91.812271,-66.593288,-91.398491,-134.990649,-126.326705,-67.875967,-51.164585,-136.164692,-232.752312,-398.537273,-366.607281,-308.446125,-266.282205,-273.08514,-252.098738,-240.378907,-263.448743,-271.134987,-212.304819,-114.374064,-81.078771,-26.682281,-15.835011,-51.866241,-53.624049,-22.84315,-92.114907,-106.847146,0.416432,71.191195,121.960923,97.766057,7.675273,-31.501323,-27.488413,74.999873,119.382164,193.269487,219.884704,168.942202,111.569221,63.02923,84.185902,99.443611,120.973127,112.153099,79.496209,65.05488,-25.593698,-99.504369,-176.180456,-112.314552,-66.246359,-39.321617,-73.086261,-182.234087,-229.717196,-264.143957,-204.789478,-172.28339,-185.368079,-219.532541,-250.951169,-226.864678,-119.216003,-92.975554,-166.041482,-174.7012,-103.339966,109.970221,201.870626,213.229337,131.998989,-21.962967,-19.319159,22.25009,114.886478,166.541933,251.784364,253.729923,163.260631,103.199882,68.730381,148.248691,175.364266,164.276421,157.297313,139.238434,89.395456,-117.825446,-256.266049,-228.293738,-72.104058,1.484828,75.757196,66.520719,-4.945943,-45.165372,-95.02767,-55.202319,-2.939071,142.958796,200.364544,148.635257,39.220424,-186.551984,-200.10085,-115.067038,63.766452,98.392388,44.020144,-29.094365,-147.144884,-147.120607,-67.248102,-7.189449,-6.35113,-46.187205,-96.275876,-265.004407,-353.664203,-423.125645,-297.670977,-216.661395,-144.257505,-142.195997,-116.541289,-89.99122,-62.102228,-65.750476,-68.611119,-56.241225,-62.098743,-65.638472,-53.299899,-52.808396,-53.169279,-37.024881,-95.998377,-120.655437,-112.470314,-104.245806,-81.816758,-67.490314,-80.719694,-109.670064,-160.884209,-203.844191,-214.388254,-166.361626,-117.834799,-61.351808,-66.061972,-61.811898,-8.391534,2.772854,-10.923525,6.05117,99.560994,102.280006,-58.256761,-142.553321,-132.291555,75.804526,168.312665,181.218156,119.96351,-17.097849,-61.805705,-104.352345,-110.225493,-77.82081,36.533542,91.111319,145.477305,128.561196,45.014824,2.349734,-64.60934,-73.504732,-46.292972,90.510922,167.923701,167.4712,91.190036,-24.848923,4.208804,54.353286,131.678879,125.208606,76.867178,70.796312,75.517224,65.696084,-7.038622,-98.174923,-111.304515,-49.51522,-9.982336,-28.148556,-64.288698,-116.888777,-138.066579,-82.210868,115.445995,177.230757,151.213547,81.727621,-41.011366,-66.941798,-117.953197,-140.859871,-104.690737,-6.036022,1.633103,-69.45656,-104.287691,-180.870618,-271.846617,-244.428722,-26.970168,60.990195,47.111851,-10.870814,-87.77402,-90.495358,-33.71776,75.006616,118.461768,182.73804,229.694518,300.881968,281.56736,184.209672,192.43198,239.819462,301.43229,290.197316,180.021307,101.969561,-2.201144,-21.981385,-44.536437,-12.257237,34.543837,128.728977,148.34839,122.637283,99.199658,81.415359,115.079083,148.493904,197.480193,192.476617,139.417614,124.314051,134.091499,100.579598:-88.809075,-63.079652,-29.640581,-11.944344,-31.371347,-116.366619,-163.71759,-230.907447,-257.0765,-231.149701,-125.041089,-80.950319,-23.990934,-14.525732,-44.175213,-78.132287,-133.924932,-59.232147,26.046949,174.251242,174.527949,39.552316,4.541413,88.18554,142.237785,143.554861,177.409284,186.20112,70.921315,-22.352776,-111.960048,-127.3419,-126.912822,45.111067,154.914253,288.336334,311.000105,278.438323,234.525527,134.805075,55.038357,55.463543,167.232458,231.596513,189.804388,78.142283,-128.926673,-178.808908,-196.723189,-82.861812,7.362836,88.617817,46.053708,-100.892982,-158.852365,-247.864805,-283.339069,-244.240027,-75.116603,-10.934068,-34.923762,-82.051977,-122.508893,-133.596768,-178.189762,-148.816961,-107.314308,-59.375939,-64.112249,-106.587004,-127.814931,-157.904507,-157.632025,-128.367585,-30.937141,5.159872,-61.113633,-164.020651,-314.812427,-315.531979,-254.708215,-253.016993,-264.951685,-202.616675,-133.10345,-35.150446,-33.550627,-141.287188,-252.794331,-217.640193,5.92255,104.508852,125.953953,63.921133,-38.344765,-43.597591,-42.115225,-32.466051,-2.685894,37.972999,18.584279,-42.172542,-35.575938,1.980821,-17.349957,-3.395202,93.164611,140.343352,133.041484,58.260122,-141.650231,-200.992012,-166.256081,-2.477832,79.781212,192.039367,203.28416,98.687422,28.354968,-23.436637,-15.503725,-1.779084,77.340976,141.578703,273.441185,302.110801,220.477793,120.075225,-63.50816,-81.661046,-44.743609,62.418621,113.27263,169.845348,170.365035,71.941927,-69.743431,-73.173843,21.874998,54.336014,31.443254,-11.587524,-118.701152,-169.64877,-227.338934,-166.836862,-114.603586,-51.858059,-51.731116,-133.072269,-214.42931,-383.563163,-415.184347,-366.121195,-280.353992,-281.383577,-321.439752,-333.827222,-315.881108,-283.513362,-191.913464,-117.426811,-89.2796,12.524952,82.376739,153.226923,151.37202,116.193342,62.332368,62.00586,106.514293,125.798566,119.351937,87.430244,15.294652,-1.024264,-1.959416,37.45044,92.942152,263.222461,322.73215,308.791234,255.063456,86.494543,-3.324151,34.331823,150.564545,180.137969,145.055491,89.146037,-27.598326,-79.887498,-145.953082,-80.538509,-7.185824,109.721738,100.418298,-51.142784,-131.854581,-207.71718,-202.271125,-174.631702,-67.653388,-10.571558,24.616871,0.187305,-55.444641,-72.155317,-88.006379,-73.318969,-55.749097,32.672878,90.613743,105.499438,40.476088,-133.755017,-149.3523,-87.329464,44.709669,100.96475,227.860225,273.888858,208.959351,121.123721,58.724422,203.508377,267.358087,276.356075,245.466551,156.396084,76.537072,-141.34882,-194.591973,-119.886242,53.029456,101.460532,119.082934,93.479296,47.142268,23.976321,-82.76081,-69.881834,9.85502,144.221429,147.230294,28.007491,-45.218735,-121.23145,-102.085568,-54.592509,50.924011,66.424558,22.756434,-17.135635,-116.78818,-156.076976,-158.208859,-100.643047,-78.629783,-73.982686,-96.158751,-192.457828,-265.439761,-421.027668,-388.119612,-259.914398,20.897295,91.68182,83.057723,28.867443,-120.693584,-187.72485,-228.96104,-149.982298,-110.571664,-75.537473,-76.096921,-105.256488,-117.3201,-118.114967,-99.558218,-84.68092,-51.257228,-20.16342,33.030435,16.683142,-69.586289,-112.834688,-194.796433,-184.065419,-144.656936,-87.1741,-74.703008,-91.546719,-122.970974,-165.342654,-132.393464,-96.298158,-13.818617,22.996402,36.901835,2.879901,-56.205399,-61.524003,-59.347719,55.606366,134.90794,155.591289,98.037278,-31.951058,-81.824483,-173.638245,-208.494548,-169.207326,-44.438739,13.129889,145.455925,193.632392,137.842357,41.182287,-144.194084,-124.493963,-26.348926,183.467148,218.87746,108.372935,10.925036,-139.449071,-156.930783,-115.965829,3.344057,64.021401,116.050168,85.340281,-6.99453,-33.717283,-56.824875,-19.300736,37.365969,158.614719,164.811786,41.139189,-33.441791,-129.243652,-140.552496,-87.187901,101.671999,190.985312,237.062689,172.495555,-34.825581,-122.297646,-180.399422,-27.551882,76.263658,167.777867,153.493891,71.383188,23.571399,-45.851675,-68.643912,-37.690163,105.658852,160.945116,150.094911,109.235442,65.497729,60.506932,6.347918,-17.193003,42.504667,259.994817,334.801376,280.882644,200.770463,103.940215,115.620543,156.687361,267.0453,296.493769,252.67599,193.707652,62.781725,-3.417864,-102.252004,-88.127657,-48.628284,45.097909,68.517683,23.648667,-23.296081,-113.730315,-136.982959,-90.545845,61.875369,124.124533,139.385586,73.731267,-123.036125,-189.962222:12.105841,28.87087,9.552601,-75.373246,-125.125864,-216.271718,-239.063781,-227.068669,-191.062105,-156.40125,-87.474831,-89.53758,-127.451144,-117.997809,-33.342567,4.113837,-8.281724,-42.351667,-14.497972,66.245355,78.158892,61.873617,66.652398,100.211704,97.238055,100.333735,149.809158,165.525071,100.145339,30.389158,-72.38883,-88.883959,-88.301394,48.551981,148.896023,236.336153,229.523489,210.226503,208.648182,174.849922,77.914975,49.165547,59.620658,64.570622,-7.112474,-65.868601,-136.885712,-164.712906,-257.393504,-289.809853,-274.272709,-259.416033,-274.507401,-348.663877,-388.033894,-401.534832,-301.287904,-234.926077,-157.883332,-150.215801,-152.45559,-162.737115,-181.450137,-176.661958,-175.336213,-229.236362,-269.640276,-309.522113,-295.982259,-257.682104,-255.351936,-304.256146,-358.420632,-342.054495,-288.900396,-295.753195,-321.405235,-318.147664,-296.061972,-280.992971,-241.850444,-218.577465,-224.971806,-234.032514,-219.316051,-211.122422,-229.407467,-211.048,-114.556685,-67.204792,90.704224,197.906591,257.063143,175.43987,52.853148,96.764243,241.610446,208.093303,127.697657,-40.881549,-72.272691,17.839977,92.557412,179.375061,168.485545,156.223767,179.055148,194.811391,143.417271,67.321845,-87.886669,-106.210213,-18.076547,33.564468,7.853428,-24.100912,1.589652,89.987357,131.456224,162.879458,140.031075,131.611247,128.595775,144.143942,232.031897,291.920501,389.721273,394.923493,281.754773,144.34283,123.725035,203.747706,284.975536,403.743042,390.912104,247.966288,146.97667,145.833335,187.297792,208.452056,218.288822,195.699863,149.271209,146.326844,100.021414,71.705383,117.537916,189.974925,157.320906,-21.789654,-110.28885,-180.093733,-141.970282,-119.819992,-169.176306,-250.629488,-383.315931,-393.037796,-377.425948,-377.55013,-358.496816,-259.746882,-198.816488,-115.796966,-110.602374,-180.681604,-210.046976,-222.345121,-267.668,-251.758579,-85.248006,2.907574,66.634578,44.342933,-43.053376,-86.217217,-119.047901,-12.695244,65.253137,158.934684,177.503472,201.77884,204.882389,191.502461,220.785985,276.040879,373.526097,363.849434,280.950192,237.765795,124.599722,64.369253,9.029463,1.306608,-13.049003,-46.672463,-61.833459,-130.675466,-177.750749,-205.591721,-197.263891,-210.979084,-237.669041,-236.147502,-186.148007,-164.53058,-224.715038,-290.624266,-338.738102,-192.380081,-101.070699,-8.685724,5.130989,51.180124,76.844762,56.579447,-21.4306,-24.892182,6.463974,6.398518,-10.151163,-22.059629,-43.759285,-46.835325,-76.447294,-103.902094,-86.018232,-24.916217,6.505087,58.784494,65.269922,-0.307252,-168.203175,-222.30626,-144.893586,-50.193689,68.527459,58.137009,-10.389792,-23.245231,-11.339437,3.923072,-9.808513,-27.257587,-3.530269,-43.611969,-124.114751,-189.639877,-88.221588,-28.879191,56.297748,68.99172,14.159232,-44.160862,-109.368432,-89.758034,-49.620967,-50.192202,-55.797915,-132.159599,-205.455322,-348.606738,-383.502431,-364.224654,-349.218562,-348.971251,-257.314678,-181.411318,-95.814352,-105.224329,-160.840767,-171.290969,-159.644235,-112.668435,-79.044282,-64.011916,-104.255626,-209.095052,-211.535026,-127.486061,-134.345682,-161.423539,-133.324256,-89.22331,-61.537988,-99.778229,-173.153368,-156.848881,-79.917217,-59.127001,-38.722162,44.393668,65.795632,64.032955,94.780316,209.012136,197.478602,151.409878,116.995421,133.963349,144.276332,110.039953,-35.635881,-113.673073,-173.397711,-41.971223,59.23292,119.5314,46.846605,-123.15189,-139.984649,-81.239311,-90.904945,-96.669449,-9.117097,60.865095,127.844144,92.620537,-36.945719,-67.036625,-37.178981,17.054808,22.849172,-14.436335,-23.891879,-33.007561,-55.667277,-71.1341,-11.795854,27.557834,75.278624,57.77802,-3.109755,-0.666335,19.294691,-1.495643,-45.700137,-73.610885,-99.948027,-56.52715,15.065307,40.425077,-8.760589,-10.702107,37.10172,38.015656,86.107635,114.177963,95.454995,62.005201,-19.711971,-85.021264,-203.266606,-124.559469,-50.274289,40.47239,69.46913,92.863908,58.621349,-84.207791,-152.102642,-110.590269,23.562197,42.183615,-36.550918,-83.376549,-132.787348,-144.342265,-136.759889,-41.414834,26.821759,135.62722,164.532136,170.199266,154.42249,138.441974,186.404464,219.681392,233.307497,195.11367,51.841655,-18.332796,-83.331362,-84.85904,-87.033807,-57.246605,-14.259161,91.507219,137.918788,179.563835,180.440749,161.583567,97.803755,84.2823,122.447998,127.538745,75.021698,54.739554,49.238367,26.170815:106.732809,24.642228,13.948817,18.590766,30.747734,21.343515,-6.532536,-49.861608,-44.827753,-42.999569,-105.391159,-133.837483,-82.03299,-54.780679,-97.274615,-133.826384,-208.674018,-248.653379,-237.290621,-174.108051,-122.69921,-17.649744,13.173687,-20.500985,-113.651194,-91.639335,58.419515,84.551097,-75.941833,-190.493474,-258.315494,-227.717435,-178.607026,-114.049103,-77.535261,-39.795028,-14.148197,48.778438,72.392075,148.878539,163.150756,124.209343,93.682676,123.06592,142.450639,87.04709,-53.102384,-86.937137,-142.513205,-185.377089,-171.247496,-144.023019,-154.227335,-193.057748,-208.094426,-183.692443,-81.779793,-52.76782,-70.653115,-78.925993,-81.847965,-94.831151,-66.340096,-18.182565,-10.356292,-104.804959,-135.74248,-182.135264,-202.352417,-173.355579,-122.188871,-74.537655,-144.020632,-164.921367,-150.586986,-141.081079,-170.20603,-213.708041,-270.790187,-245.639578,-143.39858,-138.842092,-176.489322,-221.028272,-199.602199,-135.795721,-145.029426,-217.429687,-139.62693,-38.895055,110.974121,137.286993,111.839991,67.191677,7.600715,35.230277,168.169898,210.958196,171.146018,62.836591,30.423031,24.943548,53.82467,122.318124,91.819963,62.645599,27.219811,1.584601,-77.453651,-118.126704,-160.169886,-141.201651,-49.817137,1.768455,-12.014714,-37.415826,-5.461627,109.784854,147.78091,122.972196,27.264518,-6.816792,-5.918735,47.296708,230.157671,319.101457,417.722905,404.331473,252.194948,123.191833,121.524547,184.777579,220.870623,279.342855,309.7339,338.369677,215.310907,138.950917,110.390663,143.072514,156.646876,128.454141,67.527646,16.693822,-145.27733,-158.398196,-86.76385,26.823716,12.472713,-130.485638,-195.468548,-242.39253,-246.677614,-231.233983,-220.525632,-251.000249,-325.150659,-352.466226,-386.702821,-389.64662,-360.664857,-249.392803,-186.084234,-112.811079,-89.029238,-52.834106,-45.097765,-52.33185,-79.100798,-59.309562,56.181165,108.505642,127.838986,97.517561,-5.518283,-62.177382,-132.565489,-81.378927,-17.033473,104.710708,140.625864,188.718653,203.479992,165.852791,166.310931,216.237066,247.169711,200.431648,167.223509,209.343613,196.168922,93.767533,-125.676991,-158.096758,-134.071534,-104.499521,-99.559302,-116.167096,-155.928738,-272.804685,-303.482277,-285.28327,-267.037871,-259.78229,-207.301027,-180.031006,-179.370319,-201.886156,-225.990693,-165.360052,-121.54886,-40.182133,4.472912,92.71831,123.183962,96.801758,17.965456,7.202367,-9.019907,-21.393767,22.757629,58.184351,5.944658,-70.556339,-141.361714,-44.273237,1.470335,-0.592042,-16.355388,28.301361,68.883048,19.694149,-115.338547,-124.907407,-61.143513,-18.799039,60.691195,76.941683,29.145165,-18.533687,-88.13606,-65.047259,-19.912418,97.062177,131.600576,79.946754,29.983642,-40.272958,-63.693763,-6.809945,135.298622,127.446564,-9.33442,-65.095785,-68.044716,-42.781876,-48.373994,-67.400993,-37.047769,46.692135,40.947623,-116.047658,-220.412734,-337.035632,-315.650174,-285.501173,-224.298074,-182.61046,-65.317687,-19.64036,3.595606,2.711951,25.136756,9.824554,-35.336073,-110.203154,-91.321316,3.011839,13.214485,-85.015692,-192.718843,-189.339092,-94.310023,-56.393826,-88.664832,-140.476882,-203.197609,-203.39324,-175.783744,-129.230018,-124.725405,-144.470141,-123.267851,-48.91363,-44.274269,-60.967539,-18.192866,16.866754,62.605365,69.076523,39.278013,-20.658838,-179.169984,-213.685348,-152.910807,-62.160666,-51.070051,-61.970291,-64.562943,-103.83565,-125.983551,-86.26442,-7.878939,22.509929,94.789932,132.781332,139.82342,81.593454,-58.977295,-82.861119,-68.966588,-51.146952,-32.373247,40.36572,86.156781,94.099388,56.646721,72.43824,244.422277,324.782749,355.516929,297.591085,160.492352,132.414105,137.398281,129.584341,19.265113,-137.873901,-169.491374,-98.630156,-30.966005,57.804899,65.913113,17.259131,-44.733831,-1.296699,206.557605,274.241438,215.036332,119.11865,-62.222055,-114.834155,-129.802866,-87.717643,-77.859955,-44.15711,-3.894217,36.729285,-1.246055,-204.128564,-373.041942,-354.437503,-177.968563,-93.472457,-16.47995,-11.798812,-6.612161,-22.509271,-126.38291,-140.046689,-61.755512,177.150752,263.502742,263.476652,204.866671,88.967176,46.674558,63.871671,123.104444,136.808531,98.340916,38.223631,-96.313077,-136.865989,-168.544617,-83.422058,12.117852,176.095761,197.600984,143.451046,111.408191,104.683627,150.354004,173.306681,180.546617,156.702767,94.797093,87.164814,99.987106,59.511156:-91.206599,-122.402882,-88.851453,-43.422397,-84.520358,-239.817124,-292.722872,-307.608928,-258.194305,-217.630888,-164.330579,-157.549732,-121.271302,-103.92975,-105.72983,-117.041999,-126.627503,-38.679175,17.129141,60.979926,62.575974,94.220414,138.390634,210.577564,174.674778,162.938465,228.076478,263.963188,172.782224,44.341048,-135.633934,-115.512255,59.095758,176.037282,172.842574,171.962647,207.357101,221.182023,191.346218,168.608463,104.588915,57.919272,34.917092,24.898933,-51.097601,-93.456197,-166.138473,-184.395143,-141.770661,-79.814868,-95.096032,-160.546414,-167.861734,-214.564961,-276.458082,-340.860862,-270.6454,-225.533319,-111.437824,-52.992389,-41.291289,-86.993039,-161.150002,-169.886935,-148.060136,-89.664226,-85.216578,-139.55286,-146.429897,-73.672094,-44.633569,-91.34908,-139.728327,-108.08716,-24.040566,-32.995123,-133.748548,-171.826742,-190.807676,-205.496915,-272.180213,-265.559777,-230.404736,-129.786232,-57.002268,15.650917,-32.38887,-151.553458,-95.990399,-29.155203,98.124645,150.420971,181.711044,126.909609,-15.285427,-18.573825,82.914889,122.979546,93.599421,4.548618,-23.784313,-46.83213,-27.188399,81.998316,71.422237,10.165003,-32.276611,0.336708,6.312185,-53.778459,-111.28505,-64.100905,26.396118,34.111395,23.941665,-44.174516,-86.447395,-80.395031,-21.124296,77.011025,50.077162,32.578206,54.23016,85.201095,161.819202,196.39526,223.841252,208.43071,120.753905,10.208643,-18.824438,45.20045,137.489052,304.078017,334.677303,300.536025,158.821709,78.758244,18.441166,58.197202,175.490017,199.484857,152.059045,84.4677,-70.777621,-75.073453,-11.773123,84.729979,74.017962,-7.167185,-47.188713,-141.447957,-221.490734,-202.590145,-108.313278,-101.859438,-169.051355,-207.063652,-244.001396,-222.986522,-134.871941,-97.751251,-83.073877,-2.680163,34.19972,23.963558,-5.671742,-18.264877,1.427383,-4.257337,-10.784344,20.317459,140.864703,160.825308,73.644346,36.572487,62.274193,141.362356,171.908234,208.167671,221.25619,223.442486,209.831676,161.320844,66.020877,36.952917,89.390891,134.830759,130.042043,80.624725,-24.079248,-55.015274,-49.5113,-40.631659,-61.933613,-73.65723,-42.923139,-0.67645,-19.539493,-71.020353,-76.463689,-81.032608,-94.23103,-104.866137,-173.332125,-203.545221,-180.112916,-159.306615,-159.634019,-160.504356,-148.250625,-49.83902,24.424697,68.841606,15.099842,-125.090341,-157.022386,-140.741999,-103.415185,-78.583372,-18.811254,1.776863,5.397389,-10.468494,-46.730726,-15.874508,21.093775,63.052721,78.311932,93.146554,54.399635,-78.687858,-151.107014,-139.683433,-49.688628,-14.182945,-26.90578,-57.405655,-55.073085,-21.605586,-12.0155,-80.475719,-118.953853,-130.427297,-76.662562,-0.719739,-39.131874,-130.200392,-65.872071,-10.652669,20.598897,-9.833682,-110.485399,-168.434223,-247.009568,-247.682643,-186.932249,-108.599464,-89.233541,-122.09097,-184.641445,-385.474741,-459.095031,-403.282144,-248.643645,-229.2384,-238.375548,-196.949743,-86.989782,-97.780453,-202.005561,-222.545229,-211.065584,-229.358262,-221.788793,-120.825999,-64.616639,-76.224208,-129.353861,-193.5199,-159.835212,-118.818813,-48.304368,-41.692463,-62.557851,-65.748882,-66.297744,-78.244057,-122.827501,-137.51967,-119.962627,-62.640172,-37.449018,-37.646117,-50.351971,-16.227422,0.881194,-39.085269,-93.329117,-66.087302,22.628909,26.874562,-36.225773,-52.098919,0.783924,110.261986,135.476212,136.955157,144.886026,92.009306,-3.526011,-215.689918,-235.544515,-165.138761,-5.260849,35.453123,75.173284,95.940185,53.290579,-19.841257,-131.336731,-79.952557,-17.732035,61.990264,58.365554,5.556431,-35.152259,-146.028648,-160.748551,-101.188006,3.618006,8.647216,1.756894,-5.595862,-34.160293,-8.33325,89.592489,51.076133,1.486317,-24.169541,-5.69953,-35.068566,-80.118469,-112.479072,-67.377544,-29.724349,50.439232,76.702256,71.391705,36.163303,-62.996645,-102.319473,-122.659299,-59.15716,-6.019367,76.428244,80.389214,23.981057,-19.341324,-121.294534,-151.676184,-122.864377,-53.289227,-32.742507,-29.092792,-46.777955,-77.900957,-70.499209,-36.374318,-16.162165,12.552917,160.528622,246.571408,298.710397,257.063846,161.217862,198.12662,258.575781,342.37662,338.026933,247.15988,163.185383,-9.265203,-40.909662,-15.872993,-22.52309,-39.69344,-39.505277,-2.837334,116.775554,147.362945,78.110746,-19.749341,0.923762,151.860862,205.13192,178.571677,131.549071,65.599169,38.040334:forward
-76.904993,-46.548325,-66.496166,-180.011776,-228.383712,-228.151427,-206.958744,-200.442808,-124.276745,-38.452801,127.683496,182.1875,180.66496,136.481917,96.121666,114.528608,168.454393,151.879584,104.248367,3.735192,-42.406965,-104.38277,-102.92239,-57.568404,69.176272,132.700775,102.686235,13.017056,-187.939147,-243.500454,-179.049462,-75.636284,127.910083,154.773924,130.744693,128.473087,135.829226,183.12338,267.194088,513.709709,643.624593,608.15407,437.234545,387.362131,340.007322,293.407581,175.736209,126.821168,94.509199,136.103098,151.049871,133.757384,90.00144,-4.011506,-9.367556,48.488563,154.775675,217.0268,282.544445,259.228797,98.918708,27.818431,87.749542,188.976592,360.055399,437.846715,413.805543,208.876864,79.109229,-57.64098,-58.275131,-64.715122,-90.049152,-75.25108,-54.212083,-63.624461,-84.635777,-77.258937,-18.140639,-6.06795,-85.404818,-148.298967,-141.787022,-160.699372,-211.01998,-272.460703,-228.130023,-59.471971,22.381238,16.485871,-3.163803,2.251297,-28.518887,-88.948085,-155.924517,-70.025861,251.486027,287.391434,188.129413,111.116156,167.64858,286.449452,308.298874,313.176372,333.637068,322.988443,217.130209,169.504843,173.420113,215.2493,308.461059,330.783428,331.165142,294.436216,252.655524,159.539031,145.024634,228.112201,291.076616,323.383003,238.485278,187.439669,123.086124,130.523137,172.578288,170.622595,141.500321,134.529626,144.103816,173.756305,181.028622,169.667461,155.850046,158.442336,172.75828,162.034414,205.312931,254.804538,270.781355,246.143203,226.151098,234.459948,226.988438,192.974414,154.171266,180.643754,171.034531,119.315815,97.854072,46.785038,26.424042,36.654943,86.961176,108.218757,156.67356,178.813647,128.559765,78.749489,97.953045,160.335056,254.412479,241.303986,221.617258,252.490212,286.661333,289.843989,249.777515,193.486831,363.976309,479.503694,523.813657,456.144823,271.678877,193.756691,111.681677,103.158981,170.209823,247.853214,218.828156,119.163098,101.85023,104.719389,112.023789,93.727184,45.53397,54.491066,115.589771,141.762432,147.79502,134.442817,125.883785,114.625485,64.547718,42.575872,32.632196,24.621161,25.388122,11.406798,14.230882,60.629642,123.701607,139.068522,115.257157,82.62406,-18.766276,-86.810772,-198.925567,-207.789273,-102.18078,-20.261829,-54.096588,-157.653236,-179.070117,-217.228817,-244.808379,-230.31646,-123.567666,-72.892984,-30.407341,-56.42234,-231.166139,-327.011691,-343.96463,-277.173514,-167.009275,-213.244364,-274.423103,-359.379561,-362.465869,-305.534502,-270.204419,-249.178333,-212.707445,-179.460633,-142.173305,-140.510847,-189.29207,-217.828106,-173.246466,-133.617738,-177.948506,-279.755885,-297.719006,-303.226216,-315.069906,-332.381274,-313.333924,-256.991323,-253.84334,-261.947975,-280.720422,-319.29393,-465.40717,-516.351471,-491.196555,-441.798159,-332.709775,-258.299537,-244.254194,-248.805027,-273.438336,-315.054634,-297.10686,-222.168064,-156.571076,-135.370532,-155.99325,-187.174061,-256.776875,-287.311367,-307.434627,-302.962828,-295.510781,-307.846184,-320.36598,-362.983485,-415.876161,-519.540105,-507.458909,-362.069096,-157.058982,-75.576069,-56.258676,-114.022855,-278.25753,-342.408574,-401.865526,-427.740383,-478.980406,-459.209595,-428.223349,-373.795286,-368.619109,-365.17734,-347.258444,-287.573185,-135.444005,-61.711775,-54.342407,-94.525465,-206.393207,-272.35771,-370.78673,-398.154365,-391.777218,-335.295541,-343.444814,-442.046517,-486.833465,-460.221281,-389.610154,-255.608282,-232.464748,-252.914911,-283.096833,-280.866679,-325.808962,-354.986408,-259.857032,-150.491671,8.371084,-16.03729,-66.731528,-153.473985,-189.05298,-224.335194,-205.58612,-116.717357,13.561648,77.216513,125.62378,112.474666,32.560102,-15.797348,-3.123506,55.555394,132.516438,98.692051,79.894792,91.219543,93.200026,60.660886,73.004586,204.38355,276.549624,246.64506,172.385702,172.653835,194.869529,167.905725,40.343149,-1.111325,46.31376,80.90305,42.217987,-31.106088,-54.492292,-133.902457,-163.217516,-139.844652,-39.917525,13.183848,48.711389,13.700753,-168.163668,-273.559154,-361.253793,-331.205042,-177.83209,-22.262891,12.212082,20.658619,-2.159298,-127.189128,-195.813456,-187.771334,11.190306,97.84689,119.040332,72.045354,-25.520695,-58.834582,-118.976477,-143.048129,-128.514128,-50.53071,-42.590893,-115.625956,-148.074189,-108.599621,-47.464349,71.136617,172.977412,209.895126,201.532265,160.337249,57.525018,27.934549,49.764181,86.237882:-37.101041,-39.253652,-73.365846,-142.270398,-148.866356,-138.248079,-133.153852,-76.433202,71.90984,141.914554,189.567581,201.946616,256.110483,254.691769,151.927159,92.447385,87.792188,75.855008,12.779253,-60.567253,-68.767612,-112.835785,-120.982851,-59.340275,89.573251,128.744497,7.54339,-84.808137,-187.740319,-194.666878,-130.704573,-83.797758,-1.421169,29.705879,12.609692,-28.915375,-17.810144,129.933982,245.439408,371.570463,317.862401,292.146709,281.91969,263.468703,177.35869,136.883375,83.861337,67.035166,94.143706,143.589726,129.127726,66.056449,52.887831,81.424961,99.684225,106.260212,152.548479,182.742376,190.409684,162.882411,36.22726,-12.107926,82.139024,187.259332,281.084823,246.929126,237.80854,136.590747,15.204553,-178.878375,-187.666117,-100.894872,-28.242538,-29.0443,-57.87292,-48.78071,-12.730859,-1.852357,36.954615,48.437344,28.537694,-10.483102,-37.914504,-109.103453,-173.355078,-303.480609,-276.261632,-16.355679,184.085386,190.415855,110.324518,76.753707,0.460283,-72.887231,-168.551193,-96.730399,198.094463,288.972374,238.571429,94.968363,43.892515,40.705851,70.511025,128.907487,188.326264,214.914551,244.530118,230.167231,141.086009,125.586056,260.063648,357.114,408.266972,267.263435,212.521215,204.009962,204.722146,187.664273,195.986132,255.794512,268.8726,231.040945,150.129482,130.263102,103.885924,106.100972,144.132016,162.56808,226.176346,285.99957,257.041307,121.304751,74.618785,99.045824,139.339002,180.935459,206.44353,212.990508,183.648027,163.872937,145.088816,147.137714,156.725624,150.95768,154.87297,196.033201,204.984125,167.784446,116.541654,27.350648,35.173645,148.570697,274.25634,293.617557,215.762799,145.244483,70.330994,115.065881,325.672753,414.05708,455.761969,381.716686,331.267916,254.315338,244.475704,255.218318,238.245072,187.958621,299.992909,374.007672,345.327404,269.185585,163.465743,144.842682,132.477087,130.691309,149.342004,162.105538,151.333333,120.628837,107.791673,99.210728,120.021766,179.401345,156.700838,126.367515,95.037484,77.468594,5.35357,-7.792346,73.083162,130.765161,176.744602,98.686629,40.910902,-50.209889,-69.487418,-26.628888,17.419732,98.446541,165.324956,156.493677,38.531287,-20.391077,-98.585084,-127.913298,-127.221108,-96.965514,-29.499564,-10.595504,-18.074228,-33.629768,-62.132309,-183.352799,-219.264243,-134.561229,9.971894,38.765478,8.239745,-21.452005,-109.914199,-180.090355,-278.442457,-259.670091,-137.676312,-135.620824,-187.417032,-279.017018,-299.434991,-283.04722,-260.249739,-262.324176,-272.943309,-252.039918,-210.131072,-202.451189,-226.282843,-221.273538,-97.658075,-51.512062,-130.276114,-236.273032,-259.183671,-320.390157,-350.788087,-345.032832,-328.640689,-318.389983,-287.216763,-277.506036,-315.316196,-352.481777,-402.397688,-398.735081,-358.277556,-320.759589,-181.549824,-104.951676,-133.256236,-219.522496,-243.761698,-247.101936,-237.608877,-184.97068,-53.709937,-13.967628,-103.487665,-196.466343,-328.011701,-334.875152,-245.149408,-191.084635,-136.377737,-167.312789,-205.075607,-256.379632,-262.006982,-263.160864,-270.056523,-241.32505,-54.225317,51.258476,79.327683,-30.699463,-339.037817,-436.429641,-461.761841,-453.393629,-460.456055,-431.394052,-419.460833,-395.542721,-363.929242,-300.46194,-288.475905,-264.57531,-164.629614,-122.068753,-122.036458,-152.351311,-271.892477,-318.312179,-268.060462,-220.150359,-208.396073,-260.42069,-286.338318,-318.104463,-322.613068,-289.702686,-253.843178,-193.593211,-137.792709,-106.965324,-77.278046,-89.309759,-146.04739,-147.610465,-47.138457,26.641095,118.144118,51.259623,7.756598,-14.249546,-28.155291,-89.471807,-102.461307,-84.156199,-11.000096,71.537757,245.971725,264.79642,144.976243,75.563783,83.085069,154.550857,248.359143,150.696639,76.983858,-33.54957,-64.697484,-42.136933,16.912173,160.348584,207.943306,200.323248,156.826267,115.761085,21.359478,-10.034256,-33.291736,-21.866077,72.041773,75.668844,-7.626023,-163.355473,-175.487947,-133.3268,-98.212131,41.396533,169.02604,161.328,63.650037,29.516546,-43.604,-122.003381,-245.147473,-200.706899,44.690375,190.264892,198.652302,137.030026,61.943827,-112.344193,-148.510058,-59.038954,70.248305,89.495615,78.273661,51.683554,-59.92706,-111.132469,-148.948833,-133.828678,-40.967799,39.034401,26.407684,-94.279846,-150.584897,-147.756464,-85.625481,86.585937,202.463011,205.699839,149.632203,117.975896,25.743582,-18.381524,-0.651523,64.502559:-13.261885,-61.761464,-63.50739,-94.092079,-114.146349,-72.245781,-27.562522,55.930569,144.181421,160.500831,119.281909,113.60532,215.895802,278.062379,268.887526,203.204818,81.633231,15.283392,-24.639632,-139.694426,-178.358586,-126.755081,-75.001551,-10.290558,45.167126,47.046901,-11.92989,-44.003615,-130.265133,-185.792854,-235.111038,-203.931923,-70.134778,-33.561289,-76.538677,-171.262011,-174.310441,-29.904032,76.530848,202.013416,244.977169,269.390339,252.640438,187.441967,60.365774,59.386739,129.050756,136.426123,79.118709,76.204438,105.785404,109.336116,82.301975,39.950054,13.013414,0.20025,67.879256,55.847077,17.91312,38.580461,59.041047,55.492995,98.366018,125.452854,140.531114,171.568956,177.658613,44.342376,-82.371269,-236.734646,-220.910174,-114.890808,-43.818359,-43.807271,-84.735072,-107.757825,-160.857144,-179.084267,-161.262649,-131.532281,-60.098293,-43.371383,-67.827588,-170.927404,-231.147026,-240.573267,-161.465115,36.017353,128.826136,143.69736,81.713038,13.662184,-59.887277,-47.493591,-6.351546,10.844306,86.781798,158.05437,156.419284,90.489352,36.390515,-32.116818,-32.511203,-27.123474,22.400654,71.306844,124.960854,90.259876,-54.572822,-82.967737,49.832817,164.901021,279.325442,123.172578,45.556438,43.206932,55.555469,64.426912,93.609597,154.746336,101.252635,50.659668,1.996985,-0.753331,-1.274075,27.43482,128.052526,161.701194,220.75213,264.017306,253.320429,156.188176,76.904606,-1.096512,37.050735,116.288824,133.507801,140.892848,91.408833,58.18826,58.261488,74.963078,103.372783,116.433518,144.544638,187.376381,200.052137,103.339672,36.425245,83.395973,165.138857,223.173404,187.76091,162.614367,109.433557,111.435233,163.950322,186.273696,209.42551,250.799844,400.504728,372.690984,293.72351,189.667576,169.895918,165.405971,179.296136,198.309486,218.799907,240.332746,242.954341,207.763008,114.645707,82.211883,36.250261,21.530145,38.542284,53.183513,32.468798,4.224455,26.920407,104.991465,143.64416,218.902557,226.364307,207.33678,197.460333,186.392647,123.854464,127.325921,212.551973,245.154642,235.415245,117.52898,71.435506,91.013121,122.196072,164.293499,175.40554,197.21289,252.255854,270.434703,226.781288,159.200498,0.249992,-36.795047,51.862232,137.394612,192.099354,115.133677,94.575157,54.126705,6.441324,-92.427832,-96.894579,7.817409,69.470853,60.173347,75.189317,84.991017,-16.804913,-112.149966,-217.652677,-182.157135,-45.931704,-67.07477,-105.331678,-156.735174,-188.169878,-185.776837,-122.24206,-14.600772,-54.592405,-86.802181,-118.983239,-131.482591,-176.539563,-176.362148,-46.269773,37.52507,66.008461,5.385364,-7.63535,-57.333397,-109.523273,-208.609709,-227.070814,-160.974487,-36.555332,-21.85483,-136.054688,-235.136462,-352.688124,-332.058949,-211.422971,-149.198845,-57.205032,-60.132589,-103.235019,-193.678038,-197.341791,-145.143104,-120.216204,-40.798414,71.679809,95.069236,18.34487,-72.324618,-215.716876,-196.105409,-62.103586,-38.370685,-63.66824,-113.370542,-156.157201,-283.295206,-338.767293,-289.026115,-211.257395,-122.619559,-40.823871,25.906429,53.429974,-40.236672,-304.458389,-358.338719,-267.042243,-207.064088,-195.28315,-278.715923,-306.214943,-278.653209,-245.675915,-186.512215,-153.009331,-76.773052,4.151901,37.518565,73.036319,57.538115,-63.770161,-107.177687,-63.947872,-25.715981,20.494543,23.965111,-17.141898,-160.353891,-203.766409,-156.182753,-105.03748,-33.088006,48.860701,78.422779,72.057448,57.8032,59.251026,79.187065,138.977822,173.196285,210.754811,155.134968,106.151117,-21.311734,-81.222759,-73.779801,-10.704305,92.286789,147.407858,188.621362,245.550772,216.577433,100.121944,83.957982,156.679702,191.519713,213.697696,165.229196,111.990248,-10.435321,-54.302064,-49.306775,-13.017452,65.322966,108.594309,100.213421,56.349457,21.501088,-85.017226,-125.150984,-131.06588,-85.731795,55.499716,-29.671382,-159.13925,-243.989729,-164.722274,-37.818438,-37.842196,2.753199,128.662945,138.544581,75.120986,50.437566,-53.941191,-143.022139,-195.593143,-113.799884,124.236934,257.024108,279.92975,259.408531,201.408303,28.055364,-13.992112,137.230031,318.694089,280.197897,107.625592,64.121241,12.732251,-21.027446,-53.241288,-19.862587,105.887716,117.68483,72.021808,-30.120639,-76.769363,-143.060492,-142.19941,-76.24909,-9.150639,-5.69182,-10.118267,-1.675954,-37.799813,-69.198953,-17.394972,75.730243:-4.756415,-8.697299,-34.399868,-86.672983,-95.105526,-87.003744,-69.615094,11.388196,113.542471,136.506487,148.753915,169.623954,188.686908,168.77682,155.642419,167.554816,150.583459,64.199635,5.279184,-93.483942,-122.564951,-132.131146,-114.116984,-65.452227,-11.216102,1.810648,-29.428715,-82.691909,-263.698823,-329.938404,-274.745523,-192.187817,-34.745202,74.838127,85.413668,53.85896,46.091158,149.996198,271.604196,469.880774,486.813911,459.859647,360.577675,283.205858,89.198623,10.670539,-36.187462,-11.069816,87.52912,145.165567,128.515964,66.175224,56.161977,58.469157,34.483905,-23.099636,84.76068,162.274263,197.912415,162.542709,64.629499,40.818677,123.267403,201.850056,310.146309,337.266375,303.430116,94.372769,-39.514854,-184.72498,-171.724333,-86.452706,-53.726351,-56.392673,-77.029774,-96.262747,-180.383248,-232.30478,-248.002963,-200.194844,-87.682539,-60.427694,-77.744069,-149.287751,-206.659498,-282.814106,-243.724526,-31.613546,59.805376,2.391138,-106.191239,-87.072669,-61.640432,-111.290152,-159.69694,-77.001555,215.264988,347.522467,324.878075,240.237768,206.906883,183.275328,190.676843,199.576597,234.637235,243.383929,183.11998,137.213948,60.987815,53.623848,161.437823,243.461721,313.075737,215.231356,158.919887,123.829607,117.240742,97.179549,108.972804,161.798949,162.111806,129.071928,49.447152,35.347453,57.863268,78.984482,131.798078,183.281521,349.143827,369.80017,283.519445,87.110593,47.968838,116.327218,163.369087,181.634781,228.880712,262.187329,237.206712,204.917973,175.431942,175.594566,189.140336,177.285531,145.289503,205.741239,228.512553,152.467131,75.915109,-22.578988,-17.464383,56.976455,128.655201,129.377549,88.393457,98.66655,151.735134,163.584255,215.327806,262.103265,319.682951,242.801222,173.111702,128.911678,150.873451,129.054376,77.012783,38.964287,186.566094,265.014409,282.892864,232.208089,97.522407,46.667064,33.828979,62.301064,110.824506,58.272659,25.483343,66.863752,115.056863,166.441911,174.258662,162.344046,162.67256,183.746051,221.475092,230.536115,242.633164,254.281439,262.155556,243.498624,229.189234,252.97991,244.808069,231.189115,235.057582,229.889512,228.59356,251.560187,292.643891,307.168798,304.192079,268.484565,96.450794,13.722761,21.849185,100.636195,242.463691,180.393031,103.558934,69.577781,79.794457,-9.37081,-54.382172,-14.759946,50.293206,65.276789,93.95575,81.320283,-57.320892,-136.110332,-138.296042,-72.638762,11.122833,-59.689357,-112.722817,-167.287863,-176.384426,-185.805537,-174.653719,-110.189943,-45.637468,-52.983769,-119.596321,-134.854105,-118.404272,-87.147364,28.82893,72.008621,64.071739,16.268171,-9.98019,-88.255771,-137.477788,-191.088243,-187.654716,-167.024854,-116.303736,-109.723762,-200.410847,-266.423639,-347.639376,-341.648614,-267.135427,-227.923182,-145.845075,-73.674187,-55.023818,-70.832612,-117.352647,-206.657954,-205.919317,-129.653125,-23.203365,8.687758,-19.657836,-69.148197,-156.704185,-154.908601,-92.296054,-88.744439,-150.966442,-192.489475,-204.929057,-256.969961,-291.819146,-335.339039,-324.602621,-195.538264,51.828505,126.054201,40.486312,-69.811915,-269.265186,-322.536142,-332.866771,-345.724767,-416.291402,-395.574059,-368.528854,-346.076993,-346.121486,-349.208802,-329.685571,-198.646427,10.176419,70.584847,8.233209,-70.41373,-190.652938,-209.397128,-167.528646,-142.804014,-150.242761,-213.149309,-254.346279,-329.25982,-367.643806,-406.44587,-362.979058,-206.269131,-157.441408,-178.610752,-189.169001,-160.080934,-126.512571,-121.64405,-40.736364,22.975007,88.278276,40.471232,8.346276,-68.80727,-134.170365,-226.564596,-206.00221,-88.089466,0.788485,26.914994,72.220647,89.092012,73.093379,52.532909,49.784584,67.364203,118.834425,89.503638,38.398811,-27.698081,-42.424887,-48.09583,-16.797693,103.239392,209.204688,195.255531,14.580902,-65.216423,-83.922409,-69.152289,-89.2901,-91.751734,2.504252,28.039579,-33.357713,-115.417418,-101.807053,-71.686183,-68.613066,-33.783339,72.68682,117.188847,103.102045,56.180504,-125.387166,-236.557447,-298.95536,-234.596397,-38.958381,127.197589,160.881672,114.799912,46.366284,-102.277924,-128.065709,-35.397685,90.845912,112.834665,96.657726,51.895333,-86.502254,-123.639293,-104.280613,-69.803643,24.178716,58.733795,17.329571,-150.621274,-238.349958,-311.735954,-282.613224,-192.74508,-108.413374,-48.192566,44.104209,45.547882,-41.497859,-97.36273,-124.199304,-74.283842:19.770536,-85.477788,-145.242378,-166.156151,-152.538159,-113.532651,-69.583165,91.964437,207.716291,204.061888,190.997533,206.83627,244.506409,279.661861,337.318927,311.592902,180.862204,62.252566,9.946601,-134.686854,-205.357625,-189.671976,-128.273103,-75.999843,-37.818554,-12.689147,-53.945522,-111.385717,-220.210683,-252.829299,-228.853367,-165.582649,-25.621316,3.553884,-12.568746,-53.199952,-54.227608,73.544862,182.586936,333.55759,364.77816,352.151686,246.025509,132.84739,-118.598532,-165.899082,-65.519097,17.771907,108.579826,52.177344,11.701963,-15.992871,-16.686776,-37.933652,-68.041982,-83.953722,78.405549,163.864362,182.543224,127.368527,25.179886,11.436264,67.691266,127.803411,236.981274,261.789225,220.145705,5.61422,-101.651596,-122.255443,-74.060489,-63.410069,-85.315785,-63.583851,-28.805178,-55.474626,-180.122018,-198.952755,-90.91115,-40.750347,-23.317826,-12.036707,-0.819236,-44.826228,-114.039747,-192.470008,-127.178034,143.683575,221.695043,133.228529,-14.65354,-5.967297,5.821118,-37.749911,-86.308987,-21.066707,216.276857,273.936481,232.609233,180.125203,169.787565,177.32986,200.781739,243.403044,260.578582,254.527331,189.352917,114.68969,-44.490598,-40.068749,171.717277,284.244788,359.008977,252.162944,175.788208,49.887321,20.037109,112.38201,211.901644,328.527884,247.654095,156.455544,1.930898,-29.641569,-38.676021,-11.517243,105.874348,174.589725,291.955577,264.492659,187.6046,5.362716,-49.969635,-26.943784,12.716615,77.788272,179.260044,204.404285,111.618342,37.010899,-30.31861,-2.435782,153.675421,230.720664,267.657275,223.326731,187.485557,59.752643,16.742505,80.595973,152.712469,264.056605,272.692997,215.733309,50.114024,4.971368,14.970703,40.571963,132.337236,212.212029,380.035033,350.560343,251.971717,58.092484,3.498831,-3.115027,35.209862,118.436447,191.082538,228.161949,221.621247,160.257913,23.655361,9.950033,106.727055,160.223983,146.386264,19.395809,-22.134227,-9.544602,38.160096,164.845176,202.538417,224.980734,310.90716,343.419119,276.520286,204.752515,129.122155,171.19521,336.393107,390.010275,393.494482,292.976006,239.650525,208.319446,224.193912,274.891023,290.009302,277.665932,311.816548,343.537302,319.926438,252.600811,80.43375,34.53976,106.216715,192.176026,305.860592,232.605499,161.262669,76.147287,65.218707,50.806333,40.148995,51.443746,102.342539,117.923115,99.366829,47.349468,-86.306098,-96.29046,-0.534949,44.015507,58.228538,-31.099738,-64.445674,-56.498621,-52.5828,-49.557505,-32.135094,48.110204,179.120731,194.451493,100.684895,37.734666,-72.703012,-83.165573,59.497542,166.188542,262.693757,171.41928,121.324766,48.1625,0.714678,-46.85407,-26.936918,26.426379,74.225021,81.568318,-18.948681,-119.959304,-270.591471,-250.423029,-58.548388,31.242218,89.579127,34.037183,-0.751983,-72.513457,-112.472302,-104.69449,-34.094408,116.368026,155.204424,139.272058,35.595101,-53.132625,-161.534826,-118.242999,-2.547142,-19.201868,-98.56696,-167.126731,-231.378347,-362.270733,-395.905004,-324.867921,-221.685709,-17.704257,83.779519,103.017765,49.950186,-26.93179,-177.406752,-208.101411,-216.615403,-224.06536,-228.721527,-230.039713,-245.144214,-293.729659,-313.48381,-275.434804,-203.690848,-19.423754,139.024126,178.576199,136.131063,78.295303,-34.159523,-77.705053,-121.518576,-97.513525,26.205682,41.430631,-22.315811,-186.288504,-243.844427,-207.510616,-112.316008,84.552105,135.478383,89.872065,23.868104,56.276458,111.876678,110.016686,168.8782,230.511245,300.092809,207.79734,115.884719,-73.525808,-145.353699,-148.539411,-81.115171,71.567372,170.064562,192.573229,148.513432,79.86886,-56.001525,-70.809972,32.00229,109.639759,164.637976,-3.036522,-104.916542,-202.485594,-209.644145,-208.051727,-192.955746,-53.791133,110.657994,96.527267,-112.936113,-227.796706,-306.384356,-266.967501,-178.182197,-158.037736,-119.360886,-176.586645,-252.595891,-336.006205,-313.68783,-210.017864,-143.709272,19.592738,110.571633,96.959615,53.214618,35.313881,-83.448399,-152.214748,-146.307719,-85.229593,41.321323,103.003732,84.982211,3.100898,-43.792249,-138.160867,-139.455349,41.650032,222.541797,216.02613,108.170252,39.199428,-106.623301,-141.897589,-120.783757,-76.134877,69.77679,76.140223,-10.85562,-232.236551,-330.015111,-392.99365,-344.418622,-235.916957,-177.028153,-136.727138,-55.948343,-54.333808,-147.597026,-182.726918,-136.040265,-79.595867:-82.555125,-67.046568,-63.642955,-71.176263,-81.154434,-84.02807,-65.560471,-11.048659,1.491079,-2.008635,93.185399,199.415036,304.244257,261.934966,187.706561,207.981347,246.687309,155.760841,90.012188,-52.486386,-133.284085,-204.86857,-160.631172,-29.514068,24.980164,42.04003,49.248752,1.371526,-204.019441,-292.621618,-285.092877,-208.310886,-42.398557,96.547232,159.755799,208.227114,188.916056,206.612839,286.07278,538.415056,678.0095,612.290084,357.666936,271.905862,161.768566,111.557984,94.314227,133.432911,222.237595,214.532585,162.332094,24.792249,-36.407256,-100.322327,-93.719242,-6.087985,161.511049,220.799926,200.601116,154.592981,110.518115,143.718209,300.319722,366.197208,385.93487,339.890836,305.689925,166.607315,72.474354,-23.28592,-11.135893,12.551391,6.63148,-16.183643,-102.811879,-131.524763,-154.107743,-155.089183,-138.186353,-130.489846,-83.841345,7.919211,15.908474,-104.960419,-208.727863,-358.630246,-356.59016,-210.879559,-96.947421,-114.137446,-152.289191,-120.541119,-92.5484,-132.773732,-124.920402,-24.270623,212.93406,301.290055,303.839408,328.090678,335.262703,286.542381,269.545575,298.624637,333.511596,305.709381,145.851958,76.008349,51.834448,90.628424,232.576633,285.564714,271.067925,156.889573,103.519791,102.69113,141.621785,224.915837,252.09262,195.816965,53.15222,-5.637375,-94.200411,-104.685268,-13.06115,67.181258,162.196913,140.508555,69.788394,103.893304,126.281637,102.775302,72.261479,84.834351,119.56552,145.075901,175.735712,197.770351,200.297526,204.312473,269.793887,310.053036,342.54311,337.139092,302.868416,221.811368,187.989469,178.892991,148.390675,-26.68256,-85.340249,-3.404531,138.409949,123.920042,-51.565956,-115.340943,-135.520346,-131.792582,-55.171885,35.335386,198.819057,144.535692,71.949005,88.674869,181.680742,271.525746,219.094398,122.503478,250.980387,318.768449,275.913453,200.579349,81.631856,49.876275,-11.343681,-55.67936,-80.617601,59.005,115.26873,114.820638,105.731063,116.694779,121.794247,101.810214,46.917821,34.932816,108.581283,181.039066,241.326173,214.357961,159.668716,147.788507,170.731548,299.424243,365.959316,394.470519,367.543929,326.076057,306.658242,237.921918,282.195812,341.710661,334.814405,254.087538,49.234715,-37.608432,-90.147493,-35.597688,129.48534,176.628059,140.34467,50.38274,29.82437,-5.910974,-42.448478,-117.807474,-129.062627,-108.239355,-37.047289,-8.21807,-38.725787,-84.218285,-56.944951,33.8871,163.801317,63.533167,-9.495618,-61.290123,-60.015752,-67.346394,-42.959059,86.623988,122.934483,70.987699,-63.850694,-104.952994,-132.519278,-119.079392,-71.865442,-78.659597,-81.226874,7.528244,10.748189,-69.5325,-103.642904,-137.828031,-144.400027,-157.991792,-175.498713,-161.398712,-175.530897,-263.77451,-509.492518,-547.992542,-392.648602,-295.688259,-203.966932,-164.914503,-128.145059,-70.898197,-91.274975,-101.38238,-45.684107,35.169255,13.110689,-1.956418,-15.639836,-16.614693,-74.929646,-125.900926,-185.486216,-194.984866,-156.132929,-107.127669,-151.459534,-307.148315,-353.431334,-353.533352,-328.990671,-248.659314,-83.932705,-8.85879,27.894166,-9.916626,-181.269092,-274.579944,-375.147801,-399.659386,-418.81971,-361.128412,-355.633572,-422.754536,-439.817236,-382.511952,-329.579778,-210.0956,-135.489158,-143.43232,-183.534102,-179.377296,-191.605294,-233.10678,-289.160708,-287.394409,-318.650744,-386.64733,-407.647995,-486.234707,-545.697543,-559.81519,-497.315507,-357.454875,-276.169385,-255.845835,-266.082889,-280.820004,-295.241949,-290.689773,-193.597169,-88.647588,85.228081,48.685074,-4.605087,-63.893122,-85.777731,-169.378564,-214.463037,-196.527041,29.353099,131.568381,118.442748,39.952853,-58.352611,-46.169286,40.757816,84.194787,151.027666,128.007024,86.237876,45.409813,58.563302,109.900621,137.118281,181.142596,262.270927,288.885782,170.308823,84.485532,85.289888,134.779446,112.068168,44.430154,4.288579,80.890921,83.484822,45.269831,40.240287,44.232201,38.675731,36.133242,55.425604,65.645403,84.192706,70.021517,-108.395614,-245.007409,-374.518404,-329.022285,-142.806352,-24.523582,-36.89592,-92.24778,-78.586054,-90.736077,-160.798389,-243.187446,-96.607128,-14.944699,62.729608,64.186721,-10.699496,-73.800028,-155.397945,-150.317226,-62.859119,14.464303,-12.008312,-185.130637,-267.972739,-293.573212,-252.184776,-177.271917,-75.829409,-2.950288,62.969274,29.347541,-84.718874,-110.778387,-56.255123,-2.778978:41.032743,-12.427528,-49.996895,-77.492209,-74.275301,-75.499255,-72.029339,-3.558269,112.54659,126.663815,78.218255,78.094666,164.325807,226.169087,328.669969,347.409427,303.544924,155.018596,48.67265,-172.058749,-246.279033,-251.069817,-210.939637,-137.252587,1.450116,60.799357,22.456397,-51.030492,-223.174658,-291.80641,-277.897227,-199.906641,-51.070834,16.28979,44.489997,64.707919,44.995559,84.318999,186.899147,442.766417,522.549256,463.763879,252.677336,142.109658,-40.717161,-77.8631,-17.795988,36.943133,97.912958,82.377367,63.220974,10.351576,-21.427192,-57.010924,-41.534955,102.250041,307.812876,332.02232,165.653371,65.794558,31.122795,93.421533,267.703601,339.362811,427.912364,440.113228,392.155383,178.379012,64.607395,-20.585497,5.150697,34.310631,-21.256643,-19.777495,37.644294,31.534546,-113.463908,-201.659244,-234.256761,-168.34656,32.156089,92.764258,21.549236,-177.297236,-261.072322,-336.691283,-288.722312,-45.623059,124.370768,95.912008,-54.619408,-85.373512,-70.059546,-63.097927,-30.101071,24.684004,213.301345,330.573062,324.77034,257.84829,231.73989,232.745446,234.840758,226.74407,303.054532,318.082534,194.018537,96.978246,-29.604854,-5.423762,223.558979,336.61565,387.329498,288.865218,229.756438,129.264307,104.864152,142.255296,182.144899,209.716764,139.101079,80.690192,-23.562704,-52.91181,-66.956927,-33.766602,138.518127,238.246862,322.196224,191.268642,104.305987,17.4109,2.358826,1.253738,43.406811,194.012016,260.05628,222.801364,88.084753,46.092461,31.508777,60.494789,185.774461,230.033609,220.328869,190.820095,188.25934,141.991206,98.043944,71.79372,102.901257,190.801103,244.917805,209.631595,9.256424,-85.828252,-149.763939,-119.323553,21.898496,108.752448,261.888132,230.613336,140.579977,38.112225,50.028109,84.693928,98.25465,144.091234,222.144787,244.128141,189.436381,132.030623,26.316135,-6.386653,-5.022019,22.247371,73.239616,63.626482,32.39433,19.895791,62.328958,172.695667,212.404932,244.211981,258.716184,272.076662,287.341543,282.385307,241.872361,220.409143,240.913304,286.770008,386.507755,370.990921,309.532957,224.808989,252.878493,391.179953,434.038905,419.751151,462.519169,512.579236,473.885285,351.902193,70.839786,14.921058,150.225926,274.006061,387.974991,261.939939,182.29892,115.686855,109.226905,87.613388,86.19287,129.582615,178.666886,164.417567,74.340934,21.270362,-96.882449,-120.144594,16.675078,123.302263,187.082212,31.543808,-39.097161,-63.453474,-55.306484,-51.034299,-22.777706,90.785942,184.605991,187.507161,91.283006,31.181793,-26.772401,-4.785423,134.943018,205.41801,257.888158,232.728665,193.655527,30.020667,-60.654799,-94.463193,-37.356163,64.742593,132.455229,163.23415,62.655338,-93.279911,-369.201999,-373.21966,-173.306427,-65.971411,65.48906,70.505113,42.7064,-42.495816,-113.416405,-201.943825,-155.875128,37.193095,143.029868,146.033893,56.799034,-23.711676,-128.849773,-105.93405,15.06488,37.214148,6.137535,-33.242195,-94.741311,-278.190196,-346.244131,-342.146412,-265.963912,-52.43994,123.294419,138.124601,3.506814,-85.62464,-215.727754,-247.04957,-264.340871,-270.473075,-256.493862,-225.571398,-235.342249,-322.321243,-373.007846,-333.638074,-232.958154,-42.407324,59.834023,102.019075,97.896476,32.669521,-110.759477,-137.141727,-101.40707,-60.125169,-4.48293,-59.72612,-110.333779,-255.882736,-351.327223,-406.540343,-318.912256,-78.214875,50.138205,40.36779,-66.935073,-99.354938,-105.458926,-110.979595,-69.125835,18.223377,194.474656,112.169318,24.147278,-103.112115,-159.907493,-220.764459,-199.466218,-75.168707,73.43364,94.984977,-24.394511,-117.97248,-205.902331,-187.101254,-102.807649,-51.862094,19.816502,-52.86635,-121.886634,-233.427784,-253.760213,-166.164809,-79.053907,60.834745,128.089571,97.646732,-120.958921,-220.549174,-231.901119,-179.632823,-102.199287,-81.296347,-31.077671,-30.01754,-46.214847,-44.216117,-41.11418,-80.755756,-95.990535,-19.07809,105.620425,115.489914,37.984757,-23.946515,-187.318366,-251.479857,-234.845299,-176.758982,-49.914494,21.787716,8.875246,-94.925685,-172.40992,-280.84345,-273.611892,-172.092086,-71.786462,-47.191731,-12.277967,-27.002738,-203.270828,-283.758954,-221.387862,-114.575491,53.547096,37.320945,-29.185155,-239.050565,-366.479681,-519.963885,-494.336581,-315.265518,-171.396066,-137.735722,-111.411598,-128.570203,-208.252058,-216.991042,-127.106116,-67.430758:197.090221,184.124033,151.309787,134.510791,125.045504,64.201095,48.513728,89.931525,145.734462,157.256865,223.464381,293.777413,409.093981,413.779691,332.269077,273.268133,185.947757,129.739033,85.387534,-20.250505,-81.912433,-160.130393,-125.91252,20.833232,86.872472,88.302116,65.044682,39.558558,-45.532454,-87.244954,-93.435216,-58.6736,62.43855,216.702812,251.135642,182.426491,117.199583,51.22894,81.558461,260.211891,417.71003,409.162622,263.047666,193.123018,115.668903,101.065989,96.519706,75.730853,11.430686,47.098884,68.872826,-25.202186,-121.488761,-217.955335,-198.792487,-121.114357,1.870965,60.996427,103.986882,111.939797,150.651181,179.633756,259.945456,307.0483,387.459709,444.241222,449.91004,360.971591,281.988076,193.291301,207.742379,232.613183,166.258136,130.331622,131.513867,171.450657,214.710492,177.661787,37.056665,-23.374987,-43.523634,-18.483026,-58.903076,-179.637992,-217.655612,-264.65926,-259.143708,-141.050611,-7.472451,26.344104,97.761501,158.324646,211.651911,179.726556,152.612678,211.226679,443.664802,618.673111,632.919739,591.339952,537.050384,377.285758,341.798936,385.787822,409.859983,392.978068,283.321663,205.993767,79.674592,43.994745,33.382802,36.2078,63.669355,133.311287,145.041223,85.091034,19.187458,-112.916405,-155.211241,-265.435137,-460.546541,-531.941926,-507.744164,-421.163781,-256.996829,-226.012607,-263.732972,-306.42375,-315.632547,-281.939201,-314.559767,-384.694573,-386.834736,-332.69984,-275.459944,-173.183747,-123.648637,-99.884242,-66.2842,-40.171398,63.952845,118.735325,173.029568,166.353889,154.715527,174.234016,157.292065,75.646684,29.994534,-26.832589,-30.838059,-46.055327,-29.77844,18.178429,82.254156,49.278966,-121.878488,-203.957182,-195.740789,-108.546894,33.372575,3.384988,-29.360357,-8.071858,36.251016,81.575718,59.580045,-15.370183,23.458118,79.92032,69.53593,-15.292726,-173.132437,-203.959877,-208.711885,-198.008372,-156.31466,-182.669065,-235.55226,-304.530861,-292.230353,-196.196066,-135.746017,-68.073559,-61.909738,-58.719531,1.430627,58.344198,74.347117,0.945907,-122.334233,-110.876815,-22.351113,107.188483,202.579959,344.185799,343.01474,208.786594,132.322797,91.50018,146.483938,176.280536,212.298596,190.759247,42.578804,-32.322978,-30.888133,37.824606,195.689647,242.257422,205.163681,146.675595,155.681122,152.38641,117.822527,4.536464,-66.482708,-52.882958,30.994217,71.40344,90.180192,84.443639,129.075686,169.464677,204.573285,147.82126,85.79761,-23.139397,-33.908489,27.51611,78.691184,152.686984,168.882785,156.585467,54.188644,-8.180653,-46.089681,-21.011637,26.017352,22.68972,-10.190275,-17.823522,-20.525734,-66.23215,-89.499609,-87.540231,-88.70039,-149.828158,-163.174578,-132.497936,-120.629452,-172.591573,-321.64357,-365.087476,-370.32548,-348.377074,-243.537671,-93.677133,-31.862586,50.343989,59.564851,46.33927,53.874071,90.946229,164.155227,198.008748,186.795586,155.09678,96.003679,74.998623,21.703147,-10.129094,-6.070597,61.654917,52.610736,-44.795012,-93.028189,-126.509697,-102.115464,-30.404557,39.873637,79.412585,96.051681,71.685084,7.576887,-43.292803,-157.840476,-187.702576,-195.164408,-219.698323,-251.309438,-307.246021,-321.146008,-295.240557,-242.6157,-124.365839,-83.948009,-94.479365,-153.370789,-190.50863,-280.703265,-314.67463,-284.778061,-245.56167,-214.418198,-242.523604,-283.758733,-371.678604,-394.121697,-394.699122,-364.817359,-258.716737,-140.532097,-106.492144,-138.560028,-176.137117,-193.279164,-157.708034,11.142037,121.258597,223.209687,146.430789,136.217643,195.973488,202.310912,127.691896,72.779016,-3.227313,21.436679,56.761709,88.960338,70.6215,-20.067725,-51.833074,58.456729,172.938881,281.718916,135.133408,42.583766,40.183663,105.045107,178.313352,194.363665,196.572634,154.53272,162.060824,199.043099,189.774782,103.382665,32.649275,-163.164183,-256.447079,-283.639164,-114.507649,-25.19541,50.901426,26.605545,-50.277589,-63.921642,-88.901722,-163.621233,-175.357205,-95.613894,-48.181735,-89.250677,-164.880331,-229.404935,-205.486023,-186.67635,-216.646272,-212.717785,-147.602473,-114.123418,-110.715655,-123.534569,-133.679857,-73.696466,-10.698932,92.447988,103.18288,42.595484,-2.670369,-52.864067,-56.250178,-37.767084,-74.316028,-139.007148,-301.841327,-366.512965,-369.276878,-300.874982,-159.635071,-117.961136,-116.782241,-103.129537,-73.164055,26.713357,66.089892,90.319823,89.018708:-66.129154,-19.980592,-31.247709,-55.139993,-64.819761,-137.846374,-165.055427,-106.40938,24.870308,75.445321,169.498805,222.269509,256.380397,222.535873,150.244845,139.21447,138.359209,141.32111,123.034883,-3.096041,-95.665761,-163.019179,-88.722725,112.070762,171.385458,162.263231,131.256967,113.552254,36.705192,-6.74991,-7.364146,33.193257,118.493347,178.468195,212.385681,230.520306,182.192306,154.119844,239.412568,456.17583,588.814116,601.309477,508.074703,458.193071,403.975559,373.67031,284.97141,227.494419,128.71772,87.945995,83.213432,45.555378,-10.653508,-92.896413,-73.380516,29.163537,144.761346,180.920853,173.941419,158.537731,146.271065,156.411918,240.609108,294.815183,350.651184,386.217634,417.911665,412.014609,322.395032,100.415272,63.27143,98.992798,98.960403,81.666858,69.527004,88.007443,120.202691,118.722137,84.636218,38.735521,-48.938994,5.10844,50.620329,17.791752,-77.318176,-234.92296,-218.687943,-84.793424,-56.724644,-86.515275,-82.259641,-23.086288,60.859885,52.341025,73.256579,153.375184,374.034588,457.585632,438.149473,381.999771,362.724241,356.5692,387.928198,461.052073,458.842143,427.796059,335.435191,305.670363,282.899253,268.244805,226.273738,200.039668,184.340055,188.754762,150.129591,43.457741,36.873097,150.267892,199.681337,94.047715,-100.485888,-128.712537,-117.184195,-107.526961,-56.817059,-21.910186,-2.653957,-41.369343,-149.360431,-166.142316,-159.395633,-189.359042,-207.266589,-147.470282,-94.08338,-67.824185,-20.715571,45.765268,126.99914,127.264569,164.68404,205.601976,230.49167,203.759139,153.463802,172.459273,176.598358,138.059542,118.489529,122.243159,122.225029,48.317476,-41.635036,-42.356758,40.680396,79.703041,26.594911,-45.804035,-88.18297,-43.633032,47.744119,50.486069,59.060214,193.416148,272.091575,284.79886,221.825498,125.512395,271.441628,372.00448,370.552218,280.221011,113.320286,78.725399,66.673414,54.053055,47.704956,71.763272,52.396877,-25.249154,-60.713379,-79.531726,-45.453028,21.450375,21.027575,45.176195,124.186158,138.177561,98.810753,77.802101,118.889146,141.81102,97.63758,87.371159,102.09114,114.203938,128.150177,143.737753,119.78772,97.351395,202.025401,229.579672,140.650002,82.389229,-13.741241,-99.149966,-273.793447,-264.84998,-31.226855,77.926708,21.389992,-68.349272,-73.28253,-114.540852,-140.802781,-149.123692,-177.569934,-225.053152,-276.657727,-236.985649,-149.823989,-152.517561,-159.485718,-121.087336,-17.756322,-62.900315,-154.905984,-297.938954,-297.711277,-231.505176,-204.687056,-160.687341,-81.134688,-60.584882,-124.250584,-162.161365,-172.584693,-166.924653,-175.629938,-203.490686,-288.370105,-288.19515,-255.529189,-206.523355,-205.575609,-211.087591,-201.794781,-214.298421,-236.07057,-216.764535,-188.972058,-217.683603,-330.816894,-366.810673,-341.615983,-305.625858,-259.08573,-243.453582,-207.003538,-80.939279,-56.69074,-95.054112,-91.34599,-20.562649,30.257272,26.90098,-14.84158,-25.40883,-65.58977,-109.206137,-154.601744,-158.618168,-204.192677,-224.265742,-208.782241,-213.285721,-254.501651,-324.294638,-310.81629,-200.708165,-48.370639,-18.80364,-80.170648,-103.546926,-141.718895,-195.864373,-278.554678,-275.720065,-253.345141,-257.226733,-257.668834,-256.673581,-264.630396,-262.132605,-221.538141,-102.732938,-66.671297,-96.102024,-148.14581,-133.119439,-150.05021,-223.857435,-346.250397,-335.976239,-221.246043,-148.455636,-163.60069,-272.241147,-331.571287,-347.997999,-295.155092,-166.671952,-81.337637,-51.570596,-44.135403,-66.850421,-142.923045,-166.592814,-67.620803,29.306986,141.223767,107.420479,82.587007,69.26441,40.410863,-68.169474,-89.622542,-23.622233,78.398488,97.68221,53.648655,21.000584,-13.994173,-13.493933,48.330223,96.532619,127.773148,51.598149,33.384443,106.990877,144.449717,151.288034,180.974544,295.199811,286.263669,251.07857,238.073974,255.185639,212.688787,125.548156,-86.158312,-142.745788,-92.554793,-23.652917,-42.703564,-119.943349,-154.332866,-173.642561,-145.810586,-73.832155,-38.000579,-26.205421,-16.506743,-38.311703,-185.50322,-279.853394,-365.897709,-351.021245,-275.055342,-171.764133,-125.697998,-87.903032,-107.268083,-172.364368,-164.695697,-101.965433,-140.645148,-159.0591,-74.70555,-11.794925,12.503162,-21.206599,-98.556568,-119.20491,-109.428104,-85.858339,-92.137697,-134.376084,-158.199583,-144.271208,-104.81734,-54.980641,25.588334,103.547158,179.122421,146.050281,50.424983,41.111461,130.211637,181.058669:81.413539,38.097175,66.301439,211.150725,235.956741,146.737168,74.196939,-52.365596,-35.855545,48.392641,233.399353,261.924141,220.658732,227.589516,320.941554,340.939859,262.454536,135.746051,54.230823,-134.20755,-201.326167,-197.904552,-132.875164,-22.202097,-26.401701,-41.865748,-71.582574,-103.662818,-208.247819,-237.193716,-177.476147,-110.593357,34.688516,136.232097,136.447454,36.486665,-13.023798,15.624439,105.795534,310.995791,340.998662,284.03348,132.592411,79.667808,-14.844396,-69.475382,-81.30997,-45.000917,-14.447606,-22.74037,-27.167435,-28.583021,-35.601435,-64.883062,-53.925242,67.65195,214.631929,224.960608,111.004514,52.634744,44.095936,85.364919,184.342744,220.372929,308.879643,405.852831,404.723344,274.450775,186.320774,125.507938,157.888579,166.037913,97.06081,111.558512,176.105708,171.388614,70.385116,16.74064,-19.924024,-34.191472,-33.822683,73.228001,89.471287,-45.028296,-155.916107,-283.228671,-265.14741,-169.500507,-84.047428,-53.07625,-0.103566,38.135577,60.352433,37.193454,60.871865,118.069793,230.647981,314.894059,344.07061,340.710903,313.338231,292.482756,298.150198,257.470172,217.140669,213.942297,179.363186,147.927196,62.502671,27.780413,57.092967,100.934221,156.430556,121.050277,83.813335,51.78925,42.592026,-40.558283,-101.689992,-165.416266,-155.668499,-168.246109,-221.904913,-214.892816,-113.512503,-43.907525,80.38634,101.271941,54.75203,35.934521,31.702136,-65.757272,-140.502706,-187.141368,-129.579635,8.522612,32.087713,21.451553,2.169101,12.635046,112.717721,185.440065,247.830446,208.756463,123.391138,137.087915,133.679728,72.919357,38.198127,21.513996,50.311908,93.799524,73.578011,50.640927,-68.555718,-139.572214,-196.320011,-176.126304,-91.95503,-55.979198,-13.792197,-26.780024,-44.071864,-37.458807,-29.562816,-29.700856,-39.452449,-78.353055,3.021841,50.518085,20.043777,-11.668768,-53.064388,-83.971069,-129.819212,-141.039022,-155.328683,-151.996073,-148.094212,-73.269391,-20.587778,-27.297674,-58.429378,-33.145773,46.730155,54.45712,43.230189,66.336134,106.650367,105.024572,142.501758,159.491467,120.781921,205.17278,315.076733,481.942286,491.877374,396.670746,369.790347,383.956311,308.694139,284.364269,321.018547,317.997817,177.311577,92.468254,61.10837,114.505906,244.49257,236.837346,177.804952,97.926426,86.042091,57.446151,48.025851,34.338219,-0.816223,13.124361,106.619363,123.760705,20.763571,-40.901054,-0.259945,81.268529,175.1603,85.423113,5.360202,-66.576941,-45.137978,32.121273,76.75248,139.423827,129.853851,120.582402,120.149256,125.754993,109.92611,104.054625,121.800877,121.643591,112.782119,101.341804,83.993075,57.99747,45.851118,16.55044,8.258675,-43.371773,-88.083544,-63.694362,-73.308996,-161.075316,-326.882831,-324.238621,-227.969476,-186.914597,-89.084867,-46.801427,-65.855518,-35.742944,7.438537,39.41467,40.213721,57.772593,81.48955,82.601202,12.560961,-30.441436,-29.661838,-7.506174,-1.045391,-5.710964,42.007918,74.193583,4.262339,-232.034393,-303.458992,-259.593724,-182.227455,-37.210801,48.623741,45.689897,-32.214033,-59.918492,-88.376509,-120.45496,-158.084528,-142.958033,-145.169659,-229.799834,-270.998884,-318.521042,-328.930918,-289.881973,-237.301758,-119.258462,-29.091772,-5.304435,-35.421099,-89.655041,-182.843298,-193.966226,-185.319373,-180.884522,-160.955686,-162.357913,-216.776112,-422.92068,-496.961475,-472.182728,-402.218068,-242.326481,-133.313746,-110.107442,-140.782656,-211.624531,-384.044948,-391.413853,-174.820984,-38.167127,92.687387,25.867007,-20.506429,-6.155114,28.865607,-33.554698,-134.361518,-229.642333,-44.858599,40.392196,-3.808117,-91.780055,-189.109819,-155.769696,-21.292036,-1.822495,-67.688919,-124.100055,-126.115531,-72.220029,-48.973428,-47.767733,-24.236742,104.67936,208.684393,216.085826,129.501932,68.571031,-21.280569,-74.952325,-173.706889,-165.600367,-53.618386,2.180693,1.25201,8.706029,18.509752,42.875269,52.929617,41.375281,36.577074,62.988477,94.58574,58.866286,-73.263489,-141.259058,-224.494014,-212.130634,-144.407855,-164.318329,-209.961085,-246.669052,-214.178581,-186.958491,-224.025061,-258.551345,-133.647159,-68.50924,-31.531696,-51.413973,-116.670902,-138.182498,-133.808637,-115.681948,-51.802898,-27.880457,-76.183971,-273.727542,-375.640424,-441.546032,-385.391326,-201.829445,-129.64106,-144.489676,-174.360647,-179.473825,-169.525243,-131.419187,-6.914358,24.5192:forward
-77.161255,-185.868345,-235.626448,-294.70967,-299.35314,-227.405408,-133.878243,91.469426,156.240899,121.847428,7.918426,-63.160454,-180.725714,-185.570287,-81.329872,-13.516609,86.0837,167.492486,186.210122,153.158973,142.50399,227.450071,301.572562,375.884196,322.397038,300.523829,292.336456,290.069021,295.888723,287.491028,244.395923,248.731122,280.118754,190.545172,112.734926,-11.648103,-53.579697,-122.270849,-118.166111,-2.573523,44.105916,2.470209,-130.199373,-184.005455,-185.610745,-137.055488,-34.01529,-14.820297,-62.242954,-128.754692,-161.681121,-266.650617,-303.879608,-269.852778,-220.388078,-130.977569,-91.060719,-98.430006,-186.988429,-242.593859,-265.921489,-231.33769,-100.258464,-7.587957,156.910098,187.763523,148.832423,72.248614,85.349972,150.667808,159.368929,184.006612,212.970962,173.269796,18.07472,-15.925599,104.222736,186.635968,209.350144,175.628788,120.562992,59.114401,-1.366334,-159.233457,-201.161347,-163.279293,-122.129993,-53.413615,-11.053555,-16.787725,-69.122682,-67.353092,46.236904,96.886867,84.275663,76.629322,137.67263,144.658342,101.709272,8.77962,-24.62975,-91.515318,-106.683062,-69.907272,-111.99121,-184.470916,-307.584406,-327.033817,-317.364209,-324.171347,-387.956471,-418.108371,-404.590821,-324.177826,-322.860547,-439.48448,-478.534983,-368.131368,-259.264245,-117.826133,-145.67665,-177.315316,-156.514543,-93.272831,52.869585,68.539222,-36.143938,-93.615105,-153.329359,-180.403256,-177.657273,-148.046029,-148.842588,-203.420273,-213.905774,-124.570651,-15.288584,-5.198323,-72.954643,-132.983368,-223.393332,-240.712088,-252.727734,-248.736032,-249.456361,-256.301319,-255.459503,-295.150706,-314.370271,-261.69538,-209.494013,-143.000555,-120.985678,-108.448247,-73.745633,-58.882161,-24.077832,2.57123,66.97635,97.582581,151.398553,190.058065,199.108793,189.660219,166.530984,82.00063,53.15396,100.370793,144.908491,108.119817,-28.506873,-78.542041,-84.085611,-58.323933,10.691475,47.933273,100.151848,126.967488,134.019213,165.598938,193.861505,220.057892,218.767458,262.269503,313.690635,284.948409,127.902968,52.161526,-11.830696,-15.176376,-28.992313,-55.062474,-128.111116,-119.316366,-88.349891,-82.305008,-114.011783,-169.593271,-165.141668,-145.208647,-216.939168,-259.691246,-342.744496,-388.455946,-391.141986,-341.17356,-261.7421,-257.626007,-331.707783,-465.371217,-493.38646,-433.574115,-362.758906,-184.189309,-115.805785,-99.495999,-136.228434,-115.641683,-30.335129,9.37194,77.362,101.556656,191.083365,269.865917,355.071831,250.406846,164.731763,35.269075,29.716531,95.06762,113.177676,69.111441,-24.189735,-79.502763,-194.414313,-216.774492,-140.594178,-87.894761,-25.4865,13.346236,78.088963,2.953277,-82.194907,-213.473699,-198.687212,-71.596341,-25.660887,29.062976,26.792323,-27.907574,-158.949777,-172.879025,-124.99546,-128.51504,-160.110797,-132.708792,7.163229,124.322564,126.882173,112.961117,150.444174,280.653634,342.057264,420.187938,369.035942,303.384098,176.581063,126.491358,62.970193,53.46115,100.980338,146.374842,172.59576,145.007271,148.546228,189.183199,215.380149,241.295866,247.154866,295.344949,309.221059,270.980918,185.755913,187.813172,283.477014,312.942643,223.78472,156.616551,171.609516,254.115608,224.051146,136.445571,151.57719,226.64577,226.266329,126.447014,-88.580259,-207.434124,-312.075299,-287.420456,-184.064781,-124.544981,31.250708,107.787436,148.159247,101.625776,67.084402,-34.165138,-54.105111,-34.421064,-43.137898,-69.494209,-33.037543,-26.099116,-100.493007,-133.951886,-64.015468,-7.32055,22.361046,19.085882,-17.577156,-114.67113,-128.375495,-47.805981,10.337886,64.332672,46.192722,-12.611046,-10.440973,6.428653,-4.902671,-54.015947,-129.575719,-98.131121,81.798516,166.209925,166.188081,45.725172,3.463563,-76.777027,-107.048543,-82.72037,-43.953918,-6.511403,-8.04984,10.075518,47.075744,33.32464,19.220861,54.953022,120.483504,105.510186,26.124911,-14.245863,-34.507211,-67.091546,-60.291973,-43.619026,-45.01959,-50.820518,-124.798568,-189.158826,-302.627738,-321.969203,-253.688364,-196.585383,-95.597725,-54.807317,-32.031433,-100.807011,-145.360675,-168.618296,-135.249106,-34.343963,25.21625,111.173436,22.087238,-59.28586,-170.826108,-181.651426,-134.602271,-106.472886,-63.832213,-29.661968,83.870101,151.633841,122.185871,0.86489,-40.11659,-48.130329,-20.376154,71.815802,112.060204,100.023065,79.269186,85.178956,87.077783,82.723459,172.54726,264.200453:-31.906419,-163.515073,-253.307163,-338.034604,-317.633916,-203.545939,-131.85332,-10.179188,41.525187,34.518265,-29.886973,-57.913087,-62.653608,-60.725575,-59.886604,-32.164625,88.093592,135.892887,94.160861,0.049688,10.751069,147.712367,226.703012,336.170118,370.700241,359.34329,280.34457,240.038384,221.789824,232.048526,277.286146,307.142546,289.681259,117.059491,19.396245,-70.974153,-65.997825,-20.633586,24.236544,116.106622,70.309033,3.774155,-133.343505,-178.379734,-189.308915,-161.51438,-83.112734,-54.04983,-65.103085,-191.498185,-264.622223,-297.194313,-256.980641,-178.54785,-139.332226,-51.262411,-113.357646,-204.79056,-376.844939,-406.382022,-306.189657,-220.503722,-113.783634,-105.172505,-63.997241,59.193995,78.412,16.391264,4.031153,66.470899,92.677566,96.597308,116.799856,109.987732,14.494506,-32.186422,-27.343469,4.972375,63.978806,91.878417,81.850843,-72.329217,-150.915118,-221.467958,-223.430877,-215.79857,-207.331813,-174.466754,-169.95134,-182.465953,-201.81246,-189.049297,-73.195072,12.074623,108.278068,105.786958,114.271058,119.791214,63.089542,-117.209756,-197.932546,-243.624704,-185.864667,-55.840512,-132.529239,-238.107197,-421.042198,-444.595979,-365.280106,-309.620353,-275.119297,-313.544636,-436.62157,-503.654231,-522.772987,-497.162388,-418.24679,-228.64451,-179.425012,-160.630724,-156.470861,-162.601918,-188.467044,-171.321254,-48.758943,9.611996,35.777893,-0.353969,-147.141432,-240.650793,-234.776176,-176.779522,-145.472946,-127.464249,-135.793232,-113.32056,-71.547052,-87.682928,-186.976289,-242.269244,-321.336264,-319.172038,-191.443243,-127.419721,-186.704091,-323.05868,-331.170089,-265.825974,-250.180185,-284.03032,-284.966159,-205.269755,-99.975872,-55.37221,-14.466921,-21.161148,-9.186923,31.486928,111.756858,113.031565,56.435985,75.590485,119.287958,176.618035,180.287458,170.825445,160.726953,126.083644,70.417031,24.967097,-79.279837,-123.180112,-164.006601,-152.946055,-78.703071,-31.70282,46.914267,20.326972,-30.449629,-21.712143,45.771303,118.864816,113.295165,121.181172,120.223432,91.753905,-8.182357,-46.872704,-37.041874,-21.980261,-54.852294,-82.783662,-118.388807,-178.592904,-231.954862,-270.707948,-229.344827,-102.033687,-45.379853,-29.957384,-221.744158,-329.970556,-413.206813,-401.531086,-351.117639,-328.463284,-289.231583,-267.684162,-273.910471,-379.08019,-431.435765,-415.641547,-320.182027,-62.36116,21.742657,33.877088,-49.763929,-78.985345,-88.855402,-71.130602,4.384625,51.036056,118.41416,118.362155,92.415407,126.112593,117.664604,51.72557,60.857849,132.9329,128.580844,40.729342,-49.873552,-91.82384,-155.300735,-159.350496,-109.443045,-75.865828,4.444287,59.883097,135.683946,49.422078,-38.874153,-134.880328,-80.863777,121.088422,157.629193,95.602867,77.058055,72.250342,-44.37131,-110.829472,-72.251108,13.435221,155.940858,189.290102,175.551972,103.842722,82.923948,137.064516,186.429182,226.038939,250.64526,345.230863,297.670612,203.57653,51.608767,51.661302,134.343133,156.175473,159.999677,174.207837,179.931134,87.159513,44.694172,67.701255,137.110947,273.43042,288.435008,287.217627,301.156428,257.113281,101.041505,62.111336,119.622167,173.421186,227.22698,208.972401,118.441109,86.882135,67.396281,-15.046747,-22.810727,47.64697,91.509667,134.851181,28.98511,-63.475398,-177.128087,-170.695423,-84.924903,-40.312154,45.851837,95.638191,177.992648,203.275136,172.112921,35.96752,-10.366931,49.02437,138.771296,263.763843,201.116835,151.572256,58.141018,9.311996,-40.096445,-37.943663,-20.65523,-11.429737,-18.697651,-57.918023,-63.70585,-28.892588,11.285733,106.723131,141.864185,182.737083,195.187074,173.685033,66.469863,16.921497,-2.941989,16.795272,102.827251,157.963413,197.963409,123.385504,69.873897,-23.125456,-42.632143,-0.429349,44.12377,122.016164,161.121144,155.622163,98.370731,75.069103,114.983087,170.468805,222.558752,183.465959,69.901869,8.920834,-22.99105,-69.819648,-53.489141,-2.309784,-13.152914,-80.444239,-135.827609,-165.74473,-244.774794,-272.370974,-250.961306,-217.372119,-156.823474,-129.665146,-88.102337,-97.161031,-148.186399,-266.058463,-264.402297,-170.247894,-123.842597,-54.692161,-57.245193,-115.338988,-238.617771,-239.171262,-167.661732,-130.421171,-34.497669,7.242249,41.501517,49.376648,10.858323,-100.498608,-93.211033,38.160157,99.307202,154.829355,137.254408,110.705691,60.583539,49.749618,92.331715,140.839767,230.765738,247.161183:-172.420614,-255.919531,-298.07186,-362.398688,-346.688517,-218.457788,-144.758815,-32.981482,9.403589,-9.011081,-107.048908,-129.69979,-55.699197,-21.670422,-47.81842,-57.330091,-19.306977,-67.015651,-133.706702,-184.905041,-127.157358,71.701116,156.272421,197.817025,114.803991,101.042048,131.032067,126.951019,95.154233,109.460222,168.994625,152.925273,47.643376,4.614756,-14.259734,-64.565091,-73.3488,-27.455657,31.897219,155.693627,130.272253,48.238295,-118.810485,-142.735913,-97.547566,-68.249923,-16.940368,-11.108724,-89.116892,-198.404202,-237.28844,-250.713249,-199.763395,-59.139508,-20.278426,-9.920161,-79.068272,-153.362524,-322.185453,-347.471714,-237.627169,-156.986186,-22.578524,8.453999,-3.025545,-19.571158,-56.818955,-179.114753,-205.124161,-131.175004,-59.429662,37.179853,10.869718,-18.969759,-91.270399,-115.709393,-67.008952,-19.491007,37.948691,47.950644,3.430471,-154.785036,-226.213535,-250.059629,-231.733621,-239.002223,-236.823404,-174.005645,-164.544322,-177.353453,-198.770044,-207.30882,-150.242996,-84.098546,-5.278397,-14.306715,-35.27597,-48.89608,-91.46435,-225.047664,-272.111977,-243.039012,-195.948251,-176.71817,-315.349594,-408.899037,-520.56673,-512.574859,-396.945513,-324.870746,-250.132669,-258.244761,-297.672193,-328.291519,-358.237536,-387.20378,-342.749344,-180.612143,-120.418063,-87.699467,-126.259283,-157.568718,-224.22832,-218.325061,-63.149412,28.550391,119.350633,135.591837,87.519733,-78.077063,-128.269203,-101.358022,-77.045299,-59.57485,-46.845103,-35.018384,-56.514455,-66.594479,-147.477815,-224.733335,-308.768528,-275.898397,-176.494061,-174.509773,-234.439168,-233.170111,-223.201959,-212.735806,-198.261975,-163.790671,-155.086635,-146.766288,-113.700522,-99.639675,-129.554377,-145.733798,-93.727893,-45.726733,27.806759,52.600755,44.538749,-27.24196,-31.783819,54.173148,88.620261,81.933299,83.777404,115.269814,84.928826,40.770897,-71.748378,-118.879855,-143.336988,-105.423195,58.37213,135.025048,165.900577,55.053452,-16.154774,-74.59854,-62.573698,-48.700945,-31.619736,100.246729,194.490483,142.593893,-75.062458,-152.928765,-143.158895,-69.913746,78.322023,83.055646,-87.424522,-286.571159,-327.75518,-263.133965,-186.559432,-85.346206,-78.246069,-96.64664,-186.555016,-257.174287,-348.959196,-347.770231,-291.403629,-261.940459,-190.912357,-154.411974,-172.592226,-286.718285,-326.339676,-265.56048,-161.074977,60.077603,131.751325,172.661884,135.11456,116.478966,74.430919,69.179892,126.801061,160.610879,183.770687,182.009605,164.006329,128.309286,115.501815,116.171263,124.90287,152.338311,172.625755,172.471909,99.756444,62.028935,29.542401,60.606266,202.468123,258.317048,272.201406,268.550207,293.336768,233.522288,172.024172,124.248822,145.393609,185.693671,205.340565,259.858267,270.288055,239.288917,98.042691,44.3338,104.177688,176.536406,260.443718,252.348336,149.859752,60.215576,39.151091,63.337955,107.953261,168.983389,174.558906,200.137257,182.747078,105.920008,-79.220862,-87.320068,66.152146,118.764708,95.144416,74.7008,82.879871,87.819465,70.04714,81.739499,132.055158,267.883668,312.786831,295.034983,172.792837,87.973497,-23.898519,4.473931,160.209326,207.655187,210.751195,197.73687,181.156989,169.418937,131.837736,10.434417,-12.367699,80.08896,145.959539,145.701824,-38.454561,-121.170886,-168.427611,-136.610666,6.527031,97.782181,242.903268,253.843893,160.131093,147.678569,192.174598,221.45712,191.52719,189.089838,250.223595,344.391051,251.264474,180.233824,54.041137,23.651839,76.954776,119.406222,143.485071,133.048489,106.076616,76.71723,34.730903,-44.383254,-25.480218,91.812924,139.777709,208.564599,283.100351,280.294761,155.183266,98.627078,133.984736,184.035082,238.701661,248.947899,216.241466,81.363485,-7.189489,-101.623777,-77.748391,45.3791,103.866894,146.444511,146.647382,164.359088,194.127673,188.507258,175.623687,194.228768,249.061742,244.002278,158.481708,45.967167,-8.872634,-67.833547,-65.37566,-36.415886,-16.97219,-16.516345,-114.363014,-165.937385,-197.621378,-183.914687,-164.510439,-171.085965,-146.161653,-95.115603,-43.980862,-149.974259,-208.718489,-242.244812,-220.867699,-139.646662,-87.698339,-27.568055,-99.050966,-163.417361,-234.031276,-196.44875,-55.523728,-0.927396,89.634677,114.059014,84.453776,33.606507,2.075401,-59.365379,-47.190277,85.463371,168.376611,253.52609,188.664302,146.111846,98.138686,86.381412,89.983129,95.063903,113.632035,146.222703:-280.206773,-318.683871,-331.237489,-347.234458,-320.260712,-187.351279,-99.535081,61.022692,82.611478,41.034819,-74.03085,-135.867945,-237.284766,-252.960929,-196.475175,-124.792513,54.078123,81.672854,12.576249,-120.812771,-100.880509,79.165758,142.355673,121.231811,89.688328,103.04154,96.728413,66.315587,38.722003,67.745209,155.385534,168.621642,119.115674,48.315672,-0.460647,-110.451423,-140.411448,-151.503744,-122.822995,60.908039,194.50127,144.471621,-107.630701,-207.227377,-206.223922,-136.19376,-21.566259,-14.471596,-69.80507,-139.757387,-179.936067,-243.488812,-243.003145,-173.783067,-118.660316,-18.060027,-65.954427,-163.508599,-356.375615,-375.466127,-253.679692,-182.645213,-85.236573,-31.934409,57.947767,69.371046,35.055083,-67.609681,-77.148702,-2.261948,37.866053,101.620509,139.317864,125.120398,31.923592,-6.96808,7.165243,43.193351,115.363993,130.118985,77.951076,-13.380883,-70.383653,-181.951141,-201.689451,-166.565722,-124.086422,-48.210639,-70.509429,-102.577661,-128.780037,-104.98131,-15.415496,19.37526,45.96036,57.655949,89.135237,14.894391,-72.373556,-201.295319,-204.694604,-166.353978,-147.280968,-108.91227,-185.111097,-277.843466,-423.392174,-432.223373,-371.29119,-355.655857,-396.261456,-420.14952,-446.07279,-455.117301,-450.366402,-419.995654,-369.197353,-218.282431,-164.542138,-143.244476,-162.138603,-156.936843,-160.748142,-162.692034,-76.25302,-6.440985,64.993812,55.970392,-9.797876,-52.007979,-50.507599,-26.441989,-12.593661,-9.550219,-12.345114,-13.152651,-38.804379,-53.140897,-99.430988,-142.325988,-203.126215,-197.348394,-160.354469,-150.167028,-172.145401,-275.048951,-333.251207,-359.912303,-332.238468,-273.041328,-235.181771,-106.643695,-30.557079,-50.387848,-121.583123,-115.111361,6.38708,58.990684,46.363791,30.509859,72.357472,89.854639,56.961221,-43.434373,-76.639354,-64.575778,-24.530511,52.853813,32.797648,-10.287197,-127.697652,-187.568982,-232.826895,-186.897651,-1.309306,61.176069,38.254869,-36.054546,-61.015126,-55.804204,-26.263877,42.123394,88.144262,209.852665,252.794533,224.096223,59.99391,-49.812801,-154.238659,-131.908232,-51.434315,-28.896447,-55.534161,-154.163639,-199.610391,-235.561238,-219.173783,-134.892268,-94.512301,-113.922719,-231.325164,-268.449891,-287.336288,-282.73787,-247.266005,-227.298423,-190.792019,-169.239415,-191.408113,-359.449604,-440.248022,-448.944825,-372.935485,-161.712782,-70.051023,35.924223,82.382495,106.324326,100.192115,77.06673,111.927419,156.225371,170.552033,157.187298,190.569999,238.261035,228.457605,179.05961,178.106685,246.791639,271.211286,218.639546,141.837249,110.05637,33.173729,29.869195,139.353876,203.391957,278.274393,310.067422,341.564114,235.323757,149.095037,-5.789857,-34.412697,44.825385,115.446746,209.651099,190.798912,133.820389,-41.188316,-108.108208,-111.676485,-64.84164,57.600198,113.860455,169.824346,134.020953,90.836779,44.722596,81.409533,210.024691,254.416535,280.294333,204.602357,129.218787,-20.966529,-58.393376,-32.199623,1.399758,88.081199,150.522632,193.520993,61.319298,13.194103,62.273155,129.604603,228.414917,259.342198,349.935909,359.502965,306.595795,204.631902,203.526706,324.479726,398.939722,414.433482,354.133904,239.371364,230.634881,214.674712,142.989931,143.62386,193.495802,176.381586,22.425605,-87.120994,-90.916083,-122.782391,-153.113454,-89.177832,0.43598,140.59416,173.928094,210.937192,206.320285,166.832162,90.493082,102.054242,171.347845,194.140338,207.168667,203.960837,202.024048,128.021393,72.544099,48.196298,68.25472,120.278736,155.265969,171.913154,58.354585,-15.926174,-92.390481,-66.51119,64.118369,122.544537,167.625179,147.913853,143.32921,149.953483,147.1332,130.876587,139.091242,228.195148,264.900091,205.944918,127.479656,108.357764,50.706486,42.702819,99.544072,129.880836,166.472367,202.50286,216.780998,210.723998,191.023739,207.261491,261.417483,349.155753,335.787718,247.036097,182.955164,138.295983,45.75335,45.960895,127.541434,154.057054,122.962533,42.333797,-8.311807,-98.452796,-92.264075,16.92411,44.839416,1.416409,-8.377888,46.348837,71.402718,35.807708,-60.836062,-70.904321,14.168019,80.816613,168.331542,100.122187,9.084834,-144.835044,-138.266222,19.904244,91.404255,119.334437,102.151089,102.056309,152.866671,165.703017,144.285516,131.328137,146.711123,174.819952,241.18552,275.547757,271.511494,200.308458,153.257506,142.85452,185.785119,281.548685,301.86162:-266.348702,-424.900746,-455.573776,-426.123334,-365.354217,-208.574157,-143.781235,-59.945012,-58.882652,-106.23555,-230.793504,-258.17991,-225.470764,-193.140303,-123.876925,-85.985488,-43.558579,-116.711926,-199.232952,-321.479374,-299.821774,-92.700643,33.935298,169.466095,116.088186,61.522845,-47.051215,-79.504617,-63.833755,-39.449382,3.262054,17.346773,-9.511076,-126.412667,-192.317242,-197.474596,-131.660525,27.445586,108.359658,203.514851,92.670265,-2.434895,-176.109992,-231.299492,-210.896481,-148.119512,-12.234448,33.570732,30.728681,-78.966261,-123.436293,-126.350887,-109.083412,-92.204163,-80.215325,-38.339317,-92.177443,-179.812516,-355.081448,-362.444203,-205.916305,-121.646648,-41.489918,-18.682808,29.077595,10.335718,-38.998133,-132.861177,-135.240389,-64.296993,-11.828338,102.423317,149.451261,104.177735,-89.699811,-144.408613,-61.412677,1.824713,30.957074,16.679513,15.989211,-11.049817,-82.798705,-208.624451,-191.810199,-63.298154,-15.071912,-32.593759,-155.179609,-217.814191,-298.246254,-293.311733,-162.46772,-65.874278,41.079909,32.117657,-8.087107,-54.770161,-116.264902,-255.224117,-281.888005,-222.792107,-170.756974,-110.481979,-195.865404,-300.944059,-495.506433,-494.687828,-309.726494,-235.797049,-224.430366,-235.393462,-238.93744,-269.071366,-286.983265,-249.991279,-189.816379,-85.821098,-62.106148,-18.73185,2.287558,-34.451443,-151.353939,-173.641108,-94.002267,-29.223075,65.092057,94.637273,118.348291,86.744216,63.152081,52.634676,80.112423,182.783144,229.090252,205.225195,85.319293,50.277708,3.462954,-41.125572,-143.134897,-153.54851,-74.24271,-39.489332,-79.465919,-170.059604,-201.814837,-269.296032,-296.853496,-255.91928,-172.415006,-7.725852,-28.076404,-78.133585,-165.322702,-156.539482,3.637678,76.406964,92.621028,74.59482,50.876948,-29.531501,-91.522203,-127.696726,-76.237671,40.26748,59.272047,44.349741,-8.504233,-55.979778,-182.843649,-231.965843,-215.824475,-143.463768,71.800518,144.127297,83.105965,-65.051477,-107.054803,-106.078489,-70.113575,9.279385,58.765866,175.804785,184.761646,144.667655,19.545491,-47.207185,-107.290583,-86.320353,29.842191,74.172341,13.919247,-149.507686,-202.273882,-212.434893,-181.78493,-57.601745,14.209431,35.877251,-109.462912,-169.720864,-191.171125,-165.165655,-100.071472,-69.030475,-1.098804,6.22972,-91.666737,-238.048602,-289.205088,-270.220093,-189.418219,23.233524,115.640568,214.967159,220.613451,208.840069,151.807854,126.597202,145.50774,174.702669,230.993062,238.090454,168.549502,80.58577,58.586844,95.879579,156.878031,316.161439,399.987568,452.447184,285.605129,192.557909,118.975403,157.81802,317.52344,366.185526,374.217229,394.024556,451.029297,309.470328,189.15075,74.502254,115.774773,327.194339,434.746374,487.101412,346.072325,256.25211,97.508228,69.549432,148.106072,203.689478,275.177482,301.368526,308.743343,191.387743,111.603256,41.80875,76.891356,227.934022,288.225878,250.630414,94.894558,28.255002,-79.711288,-92.494985,10.918944,79.991392,172.531739,197.681363,167.3508,56.171906,29.785527,106.717877,171.894653,249.914624,283.38615,367.791132,323.207145,253.319853,155.147445,167.170967,338.675463,446.838719,527.603088,481.49184,317.643928,207.669974,157.924401,88.856444,120.507988,247.476867,258.64963,123.060884,-62.425323,-109.695675,-71.944425,-19.840343,45.634051,63.890264,155.538187,205.744793,204.653043,177.321052,179.575137,169.408626,175.415538,278.315058,359.924649,416.146515,277.33524,212.862132,131.939793,91.328626,70.071863,114.775565,260.167193,314.228747,299.622348,157.460987,62.676309,-63.071266,-55.335598,37.131396,92.794096,191.17111,167.996942,124.217307,72.785558,68.033324,82.347657,105.064066,190.355714,226.198438,169.721642,-28.287749,-111.640534,-141.379452,-93.816866,38.721727,91.770303,125.59459,104.510917,101.199266,70.989538,49.951742,91.144211,153.080876,257.277094,255.760579,157.809857,25.999912,-65.554261,-191.933711,-159.565959,21.679428,94.55116,113.547902,-38.088394,-132.722244,-261.759798,-266.996119,-146.664288,-82.247389,-62.807434,-89.981181,-134.809211,-169.316231,-205.104381,-267.500301,-249.696681,-108.002924,-37.290669,2.07598,-79.377608,-150.578372,-312.946395,-343.26465,-210.617125,-96.0614,96.338953,151.977553,140.761218,-22.10456,-117.262886,-182.043881,-132.778137,-22.708925,2.093657,59.071026,105.723453,96.048145,21.47448,-6.318994,14.229579,53.772397,175.587932,234.500393:-360.424303,-385.988657,-365.10083,-270.374154,-222.288044,-166.074797,-141.050869,-44.822931,46.558752,44.715082,-52.265223,-107.979008,-164.136255,-172.898669,-160.29215,-113.318011,68.671555,215.346759,217.352318,111.282334,60.226279,28.650974,42.541768,63.049798,-4.988352,-43.681588,-68.100678,-55.643772,16.403854,52.039537,53.070146,26.30269,-28.899989,-46.049032,-63.839207,-170.336943,-223.498674,-206.325254,-130.341485,42.108761,39.984134,-11.76875,-72.85744,-82.185087,-66.497675,-21.62378,94.101343,113.718407,58.228455,21.045681,23.222622,-36.645962,-85.569949,-126.918574,-129.124207,-123.714198,-137.916318,-164.23266,-224.477533,-228.63238,-146.542558,-101.889123,-57.362991,-16.419547,121.674142,158.201257,105.684226,-10.943732,-19.738034,55.46389,118.556859,233.753641,202.361845,126.148289,-19.174687,-37.068244,45.830867,104.187558,191.79729,221.523663,228.01627,185.106227,134.593714,-13.387212,-64.138724,-69.349637,-48.499493,-31.523346,-43.806271,-29.505894,61.990548,101.828864,121.75896,113.916588,98.764679,109.159515,149.718871,121.65709,60.767744,-56.525426,-52.084688,28.499062,44.47399,2.526484,-117.10244,-181.877693,-226.564959,-211.634014,-217.08415,-255.763754,-343.185631,-368.295531,-365.085328,-307.255045,-282.028484,-267.419496,-247.463565,-131.49913,-76.212784,-81.034977,-146.969706,-147.543046,-114.273837,-89.997287,7.988852,55.900495,46.143849,1.25407,-42.544462,32.283986,72.511189,79.046613,45.491492,-17.975156,5.963244,144.938757,177.015796,130.278976,-7.718685,-71.513675,-110.61346,-76.100582,14.553161,30.475004,-25.447221,-158.365888,-240.228356,-354.959696,-338.07745,-192.187331,-123.155183,-26.741484,21.422334,6.534374,-34.650204,-12.550486,95.279444,130.211077,160.785563,194.779909,259.187007,211.415133,174.760485,98.097058,47.832404,-26.107466,-27.032105,22.84622,9.627459,-25.4608,-77.138172,-93.049776,-117.924457,-110.775297,15.920279,108.603936,156.297767,72.18933,63.143971,126.051378,164.759339,184.452374,185.34069,281.068034,344.305183,283.238776,55.284415,-42.883396,-118.342733,-123.596236,-128.065755,-129.291003,-149.329436,-139.989687,-136.217845,-193.314879,-220.34741,-172.6206,-122.221714,-66.11258,-94.376364,-126.800951,-182.150221,-191.646538,-134.262323,-94.317625,-92.453575,-103.412737,-116.080153,-234.057592,-318.360632,-384.259907,-334.463283,-189.703998,-140.390093,-49.504688,32.850825,49.771948,46.273559,58.487075,165.053568,219.326993,257.290996,268.112551,323.9437,391.796858,384.535151,291.91124,267.279416,275.92419,269.534749,216.737529,137.370832,96.017148,15.531429,-13.402397,14.58104,57.698527,136.739027,173.981756,167.404332,27.164741,-30.305493,-78.562332,-78.827907,-47.214995,-17.148675,97.477147,90.317357,-32.580359,-293.560017,-312.406813,-172.023904,-122.744878,-120.556402,-101.891725,3.212255,106.975845,132.924683,148.009811,173.759534,242.749419,256.141483,246.604794,203.723286,182.405585,133.53085,87.08496,-4.142622,-8.225586,103.115898,186.230632,246.230536,112.677791,51.193026,37.083725,52.528633,87.632422,135.249077,273.462972,294.872378,256.615912,174.159112,169.109551,322.774268,430.628354,435.901742,355.0164,252.055328,191.439364,163.953419,167.258838,187.814865,218.450305,211.887983,96.941071,-136.822519,-243.703043,-317.614016,-288.040968,-178.589453,-99.096451,127.448349,225.530704,258.986144,155.222117,109.020577,88.40417,104.568252,109.160979,107.628291,160.124777,120.427466,14.66945,-192.181066,-208.461626,-96.446386,-37.957655,2.304498,7.766189,40.248028,10.319435,-61.801428,-199.397705,-188.405538,-61.423508,-7.736886,65.577461,64.078137,34.758578,-25.437539,-55.58024,-62.017402,-19.932017,84.500849,122.023748,147.839956,84.921364,19.104605,-84.827905,-78.646627,19.959731,63.060013,63.211429,-13.328996,-42.334358,-58.586291,-54.15048,-3.181109,37.105379,99.344051,114.452691,94.267436,29.996296,3.637261,-5.503977,19.752788,65.553521,65.816977,66.738221,20.785856,-37.318816,-128.044823,-124.775567,-40.143594,1.286973,45.331879,67.993666,111.788737,53.263035,-13.577219,-126.027187,-137.15976,-48.057956,20.621737,96.152567,33.739946,-40.718896,-185.984521,-195.632817,-73.279802,-10.277937,42.764524,63.173748,119.691953,144.743266,120.19846,24.896892,4.272261,75.395666,140.804348,227.971238,226.086524,216.441728,165.552835,122.427234,103.120902,142.407236,232.623493,245.210791:-407.707939,-374.811103,-356.923363,-351.352483,-322.503335,-159.321842,-49.116404,106.426135,11.456158,-96.717268,-261.214348,-282.916528,-215.925027,-162.981816,-80.4393,-47.936921,13.115185,14.433424,-26.756618,-109.889908,-124.657828,-137.30138,-133.340362,-59.711054,13.233897,-6.818503,-148.366266,-207.653875,-191.606324,-127.790072,47.981294,118.744198,100.325839,-50.733103,-112.07472,-164.549748,-156.603062,-87.993729,-24.790295,85.862647,55.292019,-3.029109,-161.448626,-230.909522,-241.225504,-166.505162,49.016475,108.35451,58.477095,-1.768968,-22.564589,-120.590091,-147.97597,-92.290132,-52.92873,-1.452606,-33.085538,-120.922491,-345.26309,-388.52858,-287.342033,-194.469814,16.00719,118.175312,193.852896,60.758276,-27.655949,-101.672545,-62.26666,65.196313,110.187947,191.675482,217.216603,161.594769,-71.373818,-168.796616,-129.248546,-24.219488,138.942195,159.550025,124.472292,91.118342,59.852891,-81.084742,-148.177545,-120.439246,-23.718383,123.898624,-12.257611,-122.646224,-190.21139,-129.832939,32.687484,64.232937,53.852039,74.693793,110.295796,-60.765917,-174.629775,-251.081811,-203.573774,-62.897075,-6.177604,36.174657,-104.225289,-218.539503,-386.640784,-410.786599,-340.625953,-276.682212,-189.26298,-175.034121,-202.050041,-321.820604,-395.591576,-411.15732,-318.506617,-97.38015,-60.542798,-139.492965,-202.093255,-198.421674,-192.815395,-179.467108,-60.839733,20.943568,136.952212,163.019828,163.835504,160.928202,167.637863,169.060811,169.39888,173.085631,191.887651,281.990597,267.694495,198.975909,43.758298,-4.132167,6.611165,47.386059,101.820338,101.712144,24.19691,-158.272985,-244.220163,-294.148812,-250.724873,-109.199922,-33.961977,102.03153,116.13752,61.498391,-90.613374,-130.90555,-39.196676,51.893861,145.948566,140.124436,106.167335,49.255547,-7.787325,-100.501263,-93.373461,0.405749,53.507066,98.059623,6.436079,-76.354894,-273.101316,-351.463005,-324.211124,-201.192514,103.601983,173.759097,62.144796,-92.453342,-124.79594,-122.445868,-82.866841,75.233034,169.780366,294.078964,283.992527,239.372321,53.981723,-65.887455,-197.046274,-175.083355,-21.884351,34.165302,-22.17957,-166.6477,-213.744704,-241.774713,-223.131613,-142.648974,-98.142375,-46.558604,-86.630964,-136.50561,-210.023764,-177.501365,-10.344576,37.440953,6.953634,-18.369352,-82.332558,-246.842543,-336.474836,-392.321253,-322.194218,-98.435358,-20.617467,49.878913,89.345799,102.01262,91.345935,79.14011,151.300243,240.852108,380.985026,391.669267,308.691624,176.941674,126.711999,121.845777,174.398522,318.488311,376.314317,399.408007,305.478932,250.908386,169.700188,167.454917,278.830899,349.633196,424.956549,435.037027,393.864933,244.743634,155.658068,50.475279,54.087036,160.458658,254.526295,409.718402,321.981281,201.21214,-41.690523,-102.861344,-18.659956,85.586887,252.639312,288.879228,289.044419,282.898263,278.624173,244.942314,251.413658,356.929346,412.57652,428.269708,306.925752,201.440795,-10.892177,-66.460691,-8.174287,88.483438,265.167496,286.972899,209.515205,121.742129,98.985969,85.042929,88.444646,148.812483,233.231624,436.613803,423.569993,350.309834,273.803305,285.776391,385.408932,465.487191,562.334688,530.614497,371.958602,255.861951,208.777821,138.632373,157.427344,282.174687,318.33733,216.229434,38.782311,-4.571109,-95.034948,-145.195296,-84.808189,24.506035,250.19482,319.063857,294.34996,163.27555,119.402995,91.599381,119.878684,251.103625,315.831287,339.337051,198.475858,101.956946,-33.384464,-46.303762,-18.420762,-4.792573,74.983941,146.092702,223.362843,142.6198,64.096972,-98.904517,-149.405709,-146.706126,-98.52739,39.69188,127.212099,120.371266,-12.992015,-80.680067,-25.354945,71.373036,199.945524,193.301646,83.728176,-41.581335,-94.211818,-117.207152,-53.191087,132.182182,185.212206,185.825295,85.169594,25.594084,-46.891412,-55.006359,2.785852,64.683953,193.775566,223.739419,158.201355,-4.13944,-83.362908,-146.277698,-98.797747,64.796285,113.383235,99.852055,-30.022749,-124.614962,-282.306486,-293.148532,-165.210145,-89.134314,-19.717407,-18.388069,-50.690866,-125.736841,-191.923322,-294.658403,-282.027467,-154.169081,-75.499887,11.055273,-123.526697,-254.712793,-421.243942,-387.567056,-177.602758,-96.241576,-54.941243,-57.832196,-67.550938,-115.969595,-150.119271,-166.42504,-133.340983,-40.507266,3.749609,80.0916,74.413241,38.211545,-47.149303,-62.527298,-14.621375,23.181403,110.774184,154.070984:-227.270043,-240.998598,-234.468701,-181.869602,-132.263773,-11.977858,31.367593,70.865869,64.906146,57.593164,83.566634,112.108425,116.964852,53.916617,-138.584578,-160.12938,50.102258,242.051792,208.802259,-26.23919,-127.433696,-158.91095,-104.116411,14.910193,-27.268648,-91.283154,-141.938212,-123.076015,-81.098736,-65.019686,-46.221978,-61.624744,-119.464684,-75.200313,-15.102956,31.315502,-1.618454,-51.396432,-29.038642,63.471809,103.505084,113.156209,147.914683,153.446587,143.716134,152.752803,234.352943,301.490132,400.481718,374.915285,330.265069,208.304206,139.824432,31.994513,10.760874,11.809501,-40.185747,-79.125299,-117.128296,-106.241073,-13.97643,33.559937,73.005798,92.307249,168.982729,194.994809,140.587703,-6.571872,-19.509659,54.31864,74.700518,62.66511,63.286814,68.619527,72.786973,77.390981,115.531427,149.514593,228.456682,267.959529,327.818255,273.30984,172.63372,-49.568102,-78.017279,21.453673,68.241654,93.19805,107.629937,121.317757,90.140109,44.220351,33.674405,85.505987,183.936331,201.298159,201.54557,197.575703,182.046479,126.199802,119.235225,193.647664,251.962115,288.480117,186.42061,136.568442,98.976807,84.651045,26.742989,-10.183775,-80.808535,-96.64426,-76.149272,-57.488639,-71.97452,-144.767408,-166.595887,-124.03701,-95.324863,-78.444156,-67.892348,-64.109491,-76.788399,-77.439275,5.196777,65.77741,117.492674,131.51806,194.310425,228.724348,228.695064,230.364154,227.642875,199.694312,210.44331,302.187623,294.912703,248.607902,183.91889,163.359984,126.441383,122.52098,136.046673,129.183797,52.389666,-39.727696,-84.347469,-185.689289,-214.251409,-162.472247,-94.514071,7.528979,-25.805127,-47.423627,-30.457506,-18.956541,-1.968692,22.401727,79.52404,100.778048,176.887969,244.434333,217.797184,100.64168,62.297945,55.274939,86.259338,191.203832,191.963097,130.460029,14.949117,10.533764,98.633935,153.022171,226.150616,237.951599,194.713027,130.578059,111.217354,87.046606,101.47012,182.162429,228.076846,323.748079,319.447856,250.795222,43.871343,-62.488974,-174.142238,-169.627661,-105.094903,-62.894571,17.633247,44.585191,2.943814,-98.017416,-94.139417,-21.454434,19.130202,98.387489,127.948342,129.934661,134.487611,142.732562,194.577682,215.896035,187.192701,168.667494,167.32057,78.655808,-9.476521,-145.537801,-144.437492,-55.968989,-32.572821,-39.091639,7.389436,57.089091,129.962809,135.706277,193.327609,270.699203,389.808659,404.434582,441.110468,522.522945,535.05641,459.53528,410.758231,338.128615,292.340594,196.679059,166.73558,171.664232,156.24808,115.863824,20.405752,-1.979116,-15.134173,-15.58042,-31.870576,-109.259981,-147.061556,-196.618403,-213.276917,-237.567809,-245.379752,-224.463634,-222.748013,-271.195865,-400.578665,-424.829641,-355.280186,-303.606715,-226.834362,-181.942913,-63.010876,50.752456,87.755265,103.577612,108.12176,162.391695,201.759956,253.390179,186.747195,137.281192,98.5299,93.103584,93.5189,107.319399,151.424715,176.136159,185.284676,108.804916,62.663927,34.316435,45.78244,51.562984,55.47242,111.429397,113.55633,46.024833,-100.849797,-92.845462,72.178163,126.847534,90.60835,65.213507,53.286776,-1.426976,-24.904019,-7.62116,26.663577,97.427774,108.399293,32.169267,-171.384019,-261.31973,-305.577554,-291.398824,-265.232532,-226.679486,-40.145571,72.738322,167.089283,83.681218,47.91487,31.213993,17.415142,-70.463054,-120.028136,-131.829042,-100.029981,-125.520218,-260.165253,-317.853422,-314.808665,-273.208611,-190.402132,-165.570676,-190.849878,-255.639026,-268.845074,-281.744951,-274.380487,-207.718578,-182.017223,-213.773015,-242.007778,-215.82249,-139.507504,-125.233164,-175.062346,-214.47677,-192.188509,-118.307539,-14.922871,-103.832328,-167.763535,-211.658323,-197.545834,-127.572228,-76.16832,-41.54584,-175.269531,-249.653164,-325.232674,-334.396371,-274.724546,-199.213975,-12.962101,60.918579,71.302421,-20.706065,-66.830474,-149.400894,-132.112785,36.59813,114.323113,150.639106,49.501899,-13.909725,-90.661577,-108.169632,-93.059536,-55.177708,2.227252,-17.190879,-153.0391,-222.89074,-194.106191,-148.700855,-138.944676,-77.64582,-52.699093,-110.730096,-302.601384,-394.511014,-478.818605,-457.876651,-309.512691,-225.914343,-134.214474,-110.013182,-49.837284,-18.261177,-19.492721,-44.017314,-45.464878,21.684018,59.003193,81.856067,114.233295,136.543489,84.795228,9.921022,-48.038929,1.277716,103.184171,120.812991:-128.130147,-157.422697,-155.3235,-114.229783,-90.891678,-84.187759,-91.31881,-40.427932,75.218163,102.944596,29.294043,-32.434887,-69.168875,-71.763819,-117.181628,-97.65129,80.806532,174.702923,138.678915,13.247101,-17.207768,19.886029,60.282692,154.313644,204.885304,193.105697,151.235111,141.862557,169.526705,193.070346,196.881716,178.272221,138.749476,121.69721,117.95174,66.215979,4.747179,-98.379113,-91.158618,-8.038489,21.871751,12.850803,-62.586249,-108.948753,-80.788354,-12.615921,82.380694,109.338142,164.082575,129.085931,74.182108,-53.056022,-97.939131,-130.739564,-136.775619,-135.050028,-129.904464,-131.222998,-144.396711,-164.680538,-203.026382,-182.010886,-37.635536,47.4505,156.518065,178.001321,156.627514,93.23603,86.134868,114.508591,128.099247,145.61285,152.627406,147.532151,94.799067,64.033643,101.930372,170.210088,262.846907,261.513459,234.836325,224.218762,182.964895,1.437752,-69.693363,-49.793561,6.559566,81.627233,106.00502,128.905233,147.880055,130.286193,107.338314,102.034271,75.956917,84.32147,153.095725,135.921748,86.130028,39.345582,61.499532,92.697925,87.95547,93.850757,42.399807,-5.983767,-46.504437,-56.472174,-120.633574,-155.50247,-210.627136,-246.815582,-298.575479,-281.144133,-275.32797,-315.340687,-336.551211,-281.54648,-218.508159,-138.611091,-62.953626,1.716559,29.607242,-12.623723,-10.120858,25.890388,-12.601623,-74.755276,-127.454445,-83.206718,-65.726851,-36.325207,-27.243122,-55.940764,-60.607789,37.729407,171.6407,186.313003,77.547155,1.320595,-74.69694,-76.309575,-39.934333,-21.7627,-63.795203,-165.502298,-204.004744,-242.971788,-244.694705,-248.796054,-246.120554,-183.80469,-84.825606,-30.164921,44.963607,31.672059,-48.497108,-63.224369,-4.439857,63.134385,211.154378,220.513554,164.616474,31.834389,2.398493,26.463395,41.831478,55.420224,68.976037,57.04323,-25.422106,-71.5256,-93.956013,-63.402791,27.451471,59.774532,84.562853,115.476367,156.999527,280.321402,330.478862,324.868718,296.005433,322.774265,354.190726,294.876256,90.176188,17.173252,-11.559982,7.203869,55.482873,60.464338,19.231019,23.378559,32.788545,31.029184,44.301543,69.369165,70.501013,82.507394,48.094881,4.645652,-94.744287,-125.222531,-85.095707,-28.737391,58.353114,62.965609,-26.143746,-173.927931,-228.880051,-232.599934,-172.414681,-29.64356,5.928793,18.747541,39.827882,58.310888,57.117009,44.118558,90.703166,146.375566,245.5264,300.85837,433.141553,427.471212,338.395971,160.238682,141.855438,155.815515,134.141037,76.892781,11.912415,-31.04639,-103.943886,-144.396268,-217.749019,-229.90759,-216.322958,-187.808992,-119.392802,-139.189809,-174.66904,-236.441502,-260.11505,-273.283307,-237.072431,-141.560735,-217.199416,-296.589716,-377.701257,-357.441748,-262.262024,-250.697242,-282.312012,-253.379588,-86.359426,85.838178,130.728907,156.280987,175.199737,231.589278,249.320303,254.548288,232.558736,212.892393,151.564411,104.795715,27.946931,32.994585,104.384406,135.595633,191.624791,210.904087,182.111441,129.508498,139.47889,181.392976,182.554856,176.357848,211.052662,213.372751,94.3453,26.179932,82.62237,163.533464,170.008139,108.138788,66.142538,135.991382,147.760087,129.630287,147.615322,207.703848,198.245697,100.568401,-98.701038,-234.71868,-390.909108,-360.143693,-233.766434,-197.204083,-84.778858,3.128507,104.368059,49.727676,-12.187525,-91.209685,-86.957666,-86.17217,-109.044028,-110.778418,-94.891224,-143.259027,-281.895369,-303.384476,-241.770104,-203.158277,-152.104318,-140.4922,-171.952432,-200.974342,-184.695057,-129.889482,-103.663115,-95.084418,-125.598859,-197.439365,-206.638418,-180.541338,-116.13435,-112.619681,-168.195353,-184.85716,-101.388558,-33.740002,-3.025572,-49.583174,-57.366618,-91.226249,-108.732838,-83.370625,-64.6404,-65.460282,-109.629865,-137.538632,-198.601221,-223.860942,-185.501512,-124.687643,-29.324272,-5.829115,63.486864,111.190905,80.799997,-39.204321,-63.410915,20.333188,84.100595,147.549737,78.492932,24.236639,-46.935939,-65.263571,-18.510412,46.328139,118.850388,95.814066,24.794128,38.618542,37.334012,-40.939123,-62.015091,25.459411,89.641511,61.35424,-150.088673,-204.357669,-153.971962,-124.253004,-101.961515,-54.2377,94.626903,128.912029,86.844895,63.942479,83.409297,72.081787,25.403271,-6.12964,57.554908,228.647771,228.296093,185.777655,118.026853,85.106457,33.017385,39.087775,138.418286,197.918055:-243.716769,-367.490411,-346.319772,-202.675108,-154.841042,-68.774409,2.540237,87.78077,0.21625,-41.112462,-31.333243,-20.413723,-63.963795,-93.518733,-64.838819,-7.814514,121.900369,139.864306,69.584285,-111.745694,-170.733594,-203.406829,-160.264863,-16.331441,-89.813361,-193.346177,-261.806474,-210.660932,-96.095162,-71.60549,-102.272324,-138.125399,-156.961553,-103.335384,-79.25554,-83.065743,-98.856811,-82.136212,-50.027113,5.799115,34.372424,53.473124,80.474576,74.793203,73.713355,99.2816,174.404937,204.804042,242.898768,273.413456,245.626972,75.901804,9.91213,-11.25504,-7.563085,-14.235552,-89.636412,-133.075127,-139.930609,-119.044336,-84.558434,-60.664705,28.228979,74.718713,112.062867,98.34572,93.659508,71.542826,59.350451,70.819208,94.054852,166.916908,166.934372,109.824773,-35.053198,-66.654526,26.579001,109.331358,204.357669,219.108374,162.357446,49.78241,35.549629,30.865243,26.763266,42.698358,34.395399,-15.661062,-1.689776,24.916907,11.154062,-19.713017,20.691159,82.952497,149.618685,138.888704,60.781347,10.788649,8.024685,-7.098403,12.446623,114.000197,138.762673,96.568812,-1.893779,-53.831656,-140.787914,-166.445363,-139.124111,-102.508561,-78.637474,-83.646129,-54.548083,-45.756219,-82.699328,-169.936037,-179.67857,-154.26276,-150.620881,-127.049488,-21.3875,26.380867,8.463005,-23.332428,12.645129,74.276673,198.210423,255.487552,345.66741,317.194536,264.908588,188.301492,183.533554,192.687341,193.578633,205.917861,195.346769,171.830102,94.4747,53.234321,77.153029,142.815396,225.507268,195.924839,21.894128,-137.061315,-179.564703,-222.248205,-215.910886,-111.345636,-27.981382,99.1258,89.499162,69.739806,84.029231,87.475266,47.292519,31.972995,75.082808,120.693054,159.192042,142.150043,118.689228,7.897258,-26.494215,11.719034,46.936393,132.035676,129.916182,51.925255,-89.131607,-77.86569,54.398233,108.287831,150.388142,148.305728,91.328884,46.068653,44.773123,80.365987,123.492508,192.222848,202.175865,226.341861,242.963822,216.424748,62.384044,-35.837987,-152.411085,-159.961914,-141.959858,-146.613663,-185.232262,-185.528033,-179.671218,-204.603172,-209.048037,-184.799116,-172.822845,-113.640432,-22.287849,4.951585,6.107287,5.052089,80.10943,116.367134,97.128523,77.105382,28.742712,-105.925878,-177.891112,-233.227197,-198.426677,-97.928463,-78.916491,-49.009322,6.509707,26.862693,64.626519,77.131944,132.046391,176.069615,228.181043,260.200644,339.412986,305.219894,262.775166,224.699064,250.729235,348.035067,369.010596,323.969775,270.386476,249.150199,168.746086,122.466022,93.430631,113.202403,176.368176,201.720768,181.418014,72.188512,13.215496,-106.409041,-149.296437,-88.723835,1.172305,93.635921,-33.385645,-96.294158,-104.27283,-88.544488,-75.800156,-63.927449,0.561636,35.561809,38.30471,41.248516,93.241843,222.057609,257.597018,278.024742,278.725884,266.585045,207.656251,152.824673,43.335476,6.684466,-55.695415,-73.303075,-20.353254,34.500263,97.310108,69.349128,37.669516,-9.152292,-7.483068,14.507826,19.167155,31.984141,38.948402,24.947452,-4.013709,19.064651,164.247961,240.215655,242.009131,167.892438,36.089062,18.20961,5.958271,-34.213297,-12.7817,97.453167,120.684133,5.720806,-180.401662,-221.919374,-231.218678,-220.097688,-136.062902,-73.719654,17.666342,52.009697,130.536837,131.210548,98.464141,74.33074,96.862403,136.274718,144.722333,147.50324,49.078835,-44.882023,-185.518047,-183.944693,-91.071277,-66.64688,-77.952794,-54.905419,40.349229,10.100596,-53.236054,-150.318608,-151.349242,-95.104863,-74.51471,-21.362672,73.064679,90.976977,27.576941,-22.448686,-46.561081,-21.760465,29.858691,52.852526,57.725083,-68.178005,-135.676432,-123.643334,-51.171508,86.167603,105.582924,59.70183,-7.377718,-37.820597,-75.880519,-78.356251,-61.22998,-38.991317,18.631347,46.989432,78.413216,-46.354379,-148.197007,-219.471997,-147.688837,90.783639,182.950182,230.025772,82.520709,-28.395556,-184.471133,-194.971558,-93.526219,-16.676251,69.219863,43.070285,-74.076434,-113.403912,-132.805464,-198.811775,-190.297732,-76.516418,-16.208484,22.195212,-134.209205,-252.053547,-412.451795,-407.093275,-204.248403,-103.246545,-91.630576,-122.48202,-58.84285,97.173224,129.08137,82.52103,52.106288,69.640834,110.227436,150.191227,117.00282,124.449902,163.683912,144.630955,45.569001,10.848215,37.950284,88.795234:forward
104.920284,42.88732,26.184372,7.851748,30.368213,146.629727,178.079783,161.858868,157.997315,141.00359,105.261841,116.536148,174.363049,213.363021,303.001639,338.638712,338.533086,282.33282,268.825788,211.236204,156.359107,77.920616,60.076259,34.811097,3.14776,-18.78684,-56.124147,-80.932504,-120.392123,-92.430216,20.883645,47.227859,-12.717551,-114.922411,-119.216762,-91.771288,-111.206063,-176.271519,-191.984499,-226.948862,-268.334553,-251.275989,-221.866357,-279.1436,-448.625406,-461.573698,-333.29735,-268.164099,-242.967368,-293.409786,-328.223847,-433.937847,-472.978612,-435.857862,-373.568741,-247.476788,-253.922286,-342.217641,-573.89489,-635.394125,-562.012446,-456.958627,-248.8101,-186.267996,-198.893616,-324.131958,-334.239329,-210.050867,-155.479563,-160.030587,-168.584821,-82.081776,41.357056,60.039682,32.181758,14.051558,36.844627,90.29683,188.793621,207.42564,234.152788,278.733202,302.270726,317.084054,304.808951,285.087852,286.844967,300.527587,324.02197,326.599112,272.395719,214.225066,127.453406,141.590599,201.85875,179.621776,44.40784,-93.250962,-153.7157,-231.064792,-223.139231,-108.676221,-65.958289,-139.565866,-247.176536,-256.519342,-264.084563,-287.838084,-362.525589,-406.590058,-453.292777,-412.892408,-269.914052,-308.068112,-358.693556,-327.997356,-260.157879,-177.666318,-194.434546,-235.547921,-166.039254,-129.760042,-126.21218,-122.554969,-22.083563,36.365923,22.981449,-29.06341,-65.444432,-16.063882,-10.254237,-98.388962,-152.416724,-136.747061,-94.791103,-48.889191,-56.206608,-88.138292,-146.644634,-153.453519,-142.950477,-128.514864,-136.147088,-181.638457,-261.717115,-156.591354,-66.929232,-23.773469,-69.152703,-115.666855,-98.763803,-44.322185,-14.034004,-14.5287,-25.965892,-44.324933,-117.482562,-160.622138,-224.823033,-232.118799,-213.542012,-225.982486,-246.728308,-323.914479,-362.861367,-350.597444,-289.634677,-71.647542,115.617342,135.981274,85.263581,46.755836,4.720806,21.533616,104.380517,136.629164,106.373766,48.512957,60.428412,81.032598,75.108858,100.315464,107.609709,9.976516,-117.64614,-131.10304,-46.533581,-1.409477,21.284063,34.696578,57.74424,48.092423,32.093284,73.376755,101.079256,85.191446,48.031205,8.514227,19.013945,68.119586,59.118458,24.535408,-60.122813,-114.036483,-234.45033,-258.636951,-180.850505,-116.658485,-95.687402,-225.586137,-283.956507,-361.117896,-382.164001,-353.079067,-317.609164,-281.748283,-299.855987,-294.279949,-294.362224,-349.050572,-462.920271,-443.066171,-321.076329,-290.263393,-298.494648,-338.151594,-381.407277,-516.27521,-564.241829,-470.594942,-327.793139,-22.932089,48.95984,-39.049902,-298.413397,-368.347101,-313.20301,-260.004808,-271.279795,-306.540571,-292.674366,-187.306659,-136.761442,-121.924114,-157.84626,-155.689116,-104.413454,-53.280586,-116.493196,-146.169788,-191.813153,-248.952179,-363.163178,-346.988265,-212.977257,-173.965492,-219.109077,-246.442143,-203.822588,-143.424158,-164.561521,-160.623144,-96.543329,20.418289,-60.114844,-141.431598,-242.060093,-266.655547,-288.723833,-280.230366,-293.214205,-301.70955,-178.276307,-3.327532,2.445992,-189.515645,-317.517733,-398.432973,-333.562081,-142.427462,-71.263554,-92.437893,-152.800853,-163.325845,-143.07075,-154.828764,-260.041076,-280.917559,-230.545844,-254.211654,-267.834174,-270.185067,-275.953061,-195.271748,-114.809638,-16.092134,8.547162,31.688997,59.427215,25.522262,-31.440184,5.424989,70.48336,30.825521,-27.162099,123.557108,192.796899,135.054598,41.492871,-35.845442,10.904485,155.311522,204.54527,171.943905,29.808955,-40.989593,-29.057803,48.366924,148.106604,144.687115,127.33784,112.951459,112.861445,116.91682,92.032871,50.572217,89.237451,268.356102,327.276427,258.886343,77.962355,32.212623,45.39624,61.563121,73.95137,125.391524,366.873083,510.744522,481.944587,288.835692,185.333736,89.802104,101.271621,184.716495,170.238287,113.630664,48.847984,43.843641,-1.931832,-24.509147,22.634638,79.535041,103.255653,-29.687367,-68.734173,-30.395982,12.589557,79.396322,96.05018,127.196968,116.261185,73.890632,-20.525855,-49.562407,-41.525152,13.88023,138.209391,136.521951,14.964837,-69.371372,-79.647712,-97.956587,-111.161581,-121.208846,-115.988004,-76.567788,-11.382944,0.877057,-40.525366,-85.563893,-124.710469,-80.845059,70.194222,151.920801,313.004081,365.148949,353.856235,284.475347,225.827727,171.802379,188.112645,169.612057,42.742108,-22.493864,-132.898962,-178.67544,-198.841041,-173.888692,-150.861677,-153.360372:84.993269,-40.516454,-95.636693,-133.551255,-78.778342,140.035294,205.109648,139.195469,26.051232,8.403662,78.640656,118.373325,109.406081,118.71654,233.254466,271.351871,246.522417,255.013867,261.612449,147.83174,60.057347,-25.33863,-21.728989,28.905786,70.363461,72.286971,75.467486,59.063541,-21.567882,-29.574675,61.954153,107.687112,100.122607,29.942185,3.677336,-69.496478,-110.169541,-147.508907,-148.753025,-149.848202,-204.531513,-216.458098,-187.929893,-201.589605,-324.445502,-364.042425,-261.998318,-188.311485,-223.053624,-375.02863,-410.337429,-460.549707,-492.674284,-430.141407,-333.053813,-225.943111,-267.239723,-321.229702,-533.270034,-625.464264,-592.312346,-490.354304,-272.263787,-193.029307,-141.269605,-166.490007,-151.37538,-76.114572,-48.627649,-7.936994,33.165001,135.437713,125.883432,83.29982,28.831824,36.851051,135.618223,207.581833,275.739463,264.73789,232.837187,231.447013,265.516163,357.444843,357.538475,250.656302,201.854828,233.902491,341.385736,332.852755,159.093121,65.965846,42.776784,102.881792,184.527858,166.283262,45.864311,-78.895614,-111.913735,-131.121918,-111.90827,-16.497149,16.176889,-8.389489,-89.46222,-158.144399,-317.029501,-351.719917,-325.990252,-333.786194,-405.574545,-390.632458,-250.713084,-236.482772,-281.902721,-323.458077,-294.782596,-177.634317,-127.258404,-76.575751,-27.20515,-12.637321,-44.51395,-39.535849,106.730481,169.791324,101.814919,30.552079,11.895249,69.097854,53.962916,-50.718055,-87.684351,-72.988894,-48.658377,-7.090865,27.948567,13.969536,-76.20892,-106.537754,-76.384126,-30.582852,31.479587,15.068759,-82.427956,-124.04399,-82.369381,31.304948,39.773587,-46.156567,-81.62789,-27.23266,30.594008,-25.7717,-192.101516,-204.900199,-126.907671,-128.488073,-170.786173,-132.260692,-54.517699,-157.330892,-217.319912,-288.367358,-299.948183,-227.373708,-142.949574,66.522086,167.010762,141.262239,10.93889,-56.914592,-147.645035,-151.293508,-30.737572,69.283894,160.836795,50.843476,0.2298,-34.900729,-28.440157,31.553519,48.953384,7.913381,23.280383,62.238059,70.158911,18.538923,-46.625043,-4.108958,77.374824,63.923595,28.385078,19.438261,-3.020351,-47.024821,-39.625101,-23.113036,-26.878551,0.661439,-12.792236,-69.163171,-228.288273,-281.815277,-260.923318,-223.522042,-202.109559,-206.51034,-225.009635,-277.662292,-305.983188,-371.562496,-390.873064,-338.96878,-290.081158,-265.718805,-310.511848,-301.38749,-292.562487,-350.091905,-487.060488,-517.966782,-531.585311,-516.831633,-439.270803,-367.623419,-397.534806,-543.201306,-569.086921,-423.402397,-281.139533,-44.750942,-42.522365,-107.477998,-270.867873,-333.146694,-388.764156,-412.544731,-445.80726,-407.441742,-267.787186,-200.481746,-194.364401,-245.735466,-287.864558,-275.349412,-194.210076,-24.207124,-57.436689,-123.947592,-253.559878,-320.090358,-409.261883,-378.65919,-200.481195,-142.310038,-157.003875,-150.419118,-129.059645,-171.383407,-221.067877,-195.073773,-114.346718,-22.320865,-143.429517,-231.329653,-304.643903,-299.107032,-335.721045,-352.771321,-280.61346,-224.533754,-138.034634,-84.773788,-95.289686,-240.043697,-337.201564,-401.741227,-358.39184,-246.289443,-254.739629,-297.826665,-345.104082,-329.679585,-235.523985,-197.892029,-175.686532,-150.920626,-122.914653,-207.197531,-241.937721,-287.20405,-304.463406,-245.361957,-182.107508,-76.620609,45.219556,109.656854,99.850826,19.699613,-49.351536,3.880628,99.352914,94.712516,74.546307,131.526921,147.351373,78.593633,34.477356,57.830274,128.501929,283.047975,272.962968,199.757302,-16.964181,-117.854299,-144.674817,-69.748459,92.466344,134.636803,159.294144,114.807671,69.051887,8.234558,8.573985,81.177912,164.6033,339.996707,258.629963,135.854381,25.847973,72.283778,184.283414,198.158683,228.344298,289.466137,425.609108,424.626347,374.636725,226.753629,171.775214,152.127153,177.904848,243.642834,156.240605,89.856776,51.302908,32.557229,-40.03923,-30.656093,84.913358,118.992908,49.456166,-21.956966,-0.458329,53.227247,56.303974,102.305381,161.099084,256.679085,228.869013,185.71307,78.46727,21.622747,16.745511,102.800191,282.90193,276.453753,89.76934,-1.532861,33.705634,122.626888,116.755794,34.925182,27.868795,108.307524,114.52726,73.581977,4.949886,-10.008439,15.715706,62.958071,141.827551,176.095075,301.471516,351.079764,306.12415,157.99166,126.431622,246.136096,314.887703,218.434576,-44.2152,-129.721994,-175.428113,-169.553389,-135.855976,-122.985079,-162.315684,-166.589954:-87.196233,-77.081543,-76.209077,-101.596546,-74.677202,52.670124,83.360808,52.081026,64.142932,105.599197,165.98009,131.323077,14.900633,35.640047,219.752681,284.404665,288.563792,231.706212,175.722274,29.080392,12.221673,125.543733,179.278407,201.168884,144.303145,99.473426,61.696845,71.859049,86.26224,103.719169,172.04166,177.854628,66.715747,-49.517017,-43.032889,33.693722,44.949862,-61.843309,-138.091464,-148.585275,-97.562856,-117.386512,-139.037601,-108.169039,-101.188999,-149.370903,-159.907482,-100.781853,-65.593162,-197.225972,-257.689716,-305.95857,-290.299282,-245.540039,-246.212172,-232.977947,-158.996405,-156.884529,-306.058604,-399.298421,-425.104968,-358.991992,-158.090923,-65.180229,-40.546101,-142.316619,-158.555139,-149.210848,-144.22337,-61.404369,35.111241,181.736107,155.297737,133.11894,79.379228,27.941581,-11.064001,43.202628,190.043858,208.04834,131.255975,104.93774,138.485286,205.649184,206.65957,124.293647,63.855876,21.452453,98.247602,122.404883,51.746161,-16.916584,-68.348606,-43.055198,3.815756,11.939869,11.153589,-27.759994,-78.956335,-174.991529,-146.448633,44.399007,121.834871,127.143614,-12.759621,-100.279324,-221.460705,-237.247946,-219.339843,-214.862082,-246.494779,-271.217482,-291.181248,-269.652975,-274.95698,-313.271752,-307.3868,-212.552272,-152.575647,-110.340059,-92.535198,-63.903888,-80.32347,-85.214179,67.721191,134.344008,66.794756,26.603305,36.696964,-16.508191,-48.791726,-71.832532,-88.791632,-131.081309,-122.204684,-30.513954,-21.72969,-50.357597,-58.714127,-48.139178,-50.520582,-56.756052,-35.608577,-21.45123,-65.513916,-82.241656,-28.36598,41.359471,23.378376,17.278921,53.658484,131.64112,81.334817,-12.878434,-185.969456,-215.74327,-205.359488,-188.20325,-125.124153,-63.795703,2.102043,-129.975243,-189.293106,-184.504499,-147.525531,-73.761953,-34.439669,99.9604,224.343641,219.399405,54.251751,-47.112554,-100.14026,-45.88539,102.504452,155.110041,167.071587,52.503111,-18.26554,-60.509567,-16.869493,106.290472,123.985601,57.841838,41.510227,52.963422,1.202949,-41.716606,-34.392457,0.921825,-3.194547,-37.593879,-63.28902,-44.673642,-49.275616,-86.927549,-89.568344,-40.819964,-7.148144,100.912362,170.12026,131.219498,-36.973988,-108.025193,-141.758215,-114.276641,-82.349439,-113.6631,-205.894867,-201.808511,-219.426208,-392.531882,-443.552171,-312.973044,-232.870589,-246.141898,-275.131219,-239.861757,-240.572705,-316.153073,-416.164694,-381.966488,-306.308086,-325.896334,-401.422455,-388.700024,-371.312517,-397.886547,-425.72751,-399.645074,-326.550579,-133.323898,0.284579,-1.110152,-176.941369,-280.797872,-329.168398,-277.58461,-124.667354,-55.737702,-5.831212,-64.490556,-106.332874,-198.671755,-240.529564,-228.123281,-153.927554,-4.364594,-63.278872,-141.76618,-246.005339,-274.756986,-306.926906,-291.039508,-192.004753,-133.666774,-95.051477,-174.802206,-204.089399,-183.270524,-162.737887,-126.433124,-98.711966,-71.610914,-140.396886,-179.313712,-213.763933,-233.631765,-313.738087,-335.747646,-262.738801,-189.347356,-72.95134,-79.287937,-135.192374,-285.965405,-325.132702,-293.277624,-256.195331,-220.414427,-273.886669,-289.166247,-262.330268,-242.962414,-198.196027,-194.105329,-251.784304,-278.302693,-272.594019,-188.533148,-156.481288,-230.763322,-289.58206,-225.259232,-120.374708,32.108879,89.010862,113.32357,99.727245,42.931698,-72.87832,-86.637011,38.246054,162.855796,293.171364,161.327026,83.425481,-16.591533,-25.523506,61.116329,130.157531,270.772795,368.277404,334.671394,49.235641,-94.205437,-103.811996,-26.854729,30.180585,30.496656,78.840044,25.825466,-46.035563,-132.2237,-112.821324,58.963746,173.870433,290.1926,212.251639,152.789103,57.851879,33.815641,70.392742,114.04228,186.411142,224.916868,278.957084,281.538357,289.758437,239.879254,187.112019,124.300914,120.213858,176.524924,217.75609,204.081976,115.947538,49.251556,-61.135374,-62.019399,50.096106,89.284999,14.48514,-82.165801,-92.066257,-71.179658,-32.518419,71.4965,113.577067,187.545161,159.333781,93.027197,-5.189574,8.810576,129.39384,191.062643,282.716009,292.637905,134.921318,-39.269758,-24.303734,68.177684,51.7554,-57.470061,-50.273849,115.477186,186.104123,142.098473,39.327051,31.692592,80.857004,98.043339,86.729427,106.360204,235.401962,302.193865,274.480473,120.794384,37.566169,-3.73695,48.171316,132.372047,-33.806117,-160.799246,-265.971958,-233.984051,-142.270854,-136.048082,-173.071406,-157.727695:-34.476782,-86.299263,-101.811665,-103.445154,-87.556168,-10.597729,21.213932,36.346836,31.076841,22.244127,29.505785,36.932474,50.779286,83.575023,172.304841,199.598492,241.969118,248.035101,203.037835,80.485622,55.186838,104.182928,136.486153,125.723245,37.985753,6.100433,24.694634,39.252798,15.710076,15.695847,58.214529,60.41639,-8.654026,-91.319008,-100.335486,-88.89683,-105.821933,-189.575637,-231.895007,-290.219228,-300.102457,-258.00496,-165.362768,-181.66893,-277.022547,-280.315985,-164.06328,-93.268875,-71.990625,-256.489717,-344.13712,-362.545152,-318.839378,-212.108957,-168.705997,-141.630586,-140.252728,-157.643348,-328.448402,-451.535351,-543.521448,-478.034015,-255.149976,-162.236137,-129.097579,-232.320679,-238.397806,-137.636169,-82.41252,16.133155,73.704505,158.384431,167.610187,154.606933,91.468881,34.914864,-31.370757,16.477886,202.477058,258.317544,236.941466,194.764367,212.262646,227.888798,195.314561,126.321549,128.613024,236.519419,338.462328,318.109346,150.315176,57.928785,9.767815,43.515584,71.703616,54.455046,0.921034,-70.596804,-95.395269,-90.234109,-72.254491,-39.500773,-24.377943,-20.738881,-80.01692,-130.042624,-221.281368,-245.409232,-254.550109,-242.687047,-218.198588,-229.627787,-295.241105,-321.458846,-294.553025,-206.306345,-183.053797,-201.200184,-221.084576,-208.209331,-108.198288,-48.659699,25.497548,42.398929,68.518331,64.336432,17.241432,4.842741,14.589248,14.552719,3.762616,-83.568003,-144.638286,-156.480715,-88.32362,60.073905,38.455853,-15.173537,-80.891466,-97.219269,-128.777528,-122.136199,-74.575436,-76.126111,-170.980681,-242.304272,-199.116019,-57.458318,-49.499161,-150.190053,-173.376051,-89.738906,-33.723162,-65.687072,-174.920264,-210.682202,-210.187466,-193.775631,-169.662507,-161.985483,-170.993735,-169.482195,-132.739699,-116.122813,-172.62577,-274.026805,-256.905593,-67.881923,126.219042,161.454817,131.503529,92.664453,68.852551,114.427816,277.683411,350.947258,372.631587,225.94172,156.952403,104.689891,114.389635,187.425908,210.554316,181.21897,142.247225,121.038064,92.069816,93.426731,94.859337,77.191983,12.559781,0.66105,48.027704,69.317004,44.800943,-9.935713,-13.806377,21.824624,59.955226,179.059838,172.715334,112.940124,43.407384,24.641396,-42.139437,-71.625396,-79.12424,-58.660318,-28.556005,-51.995766,-78.433097,-184.034975,-244.038214,-275.885966,-251.484742,-199.683498,-185.865898,-199.022219,-240.378952,-265.545933,-317.254998,-325.632243,-319.0944,-334.82686,-394.469542,-373.502328,-340.822296,-344.008677,-376.954002,-355.193361,-270.316849,-27.728263,118.029054,88.76941,-84.814847,-159.365907,-216.916626,-194.559166,-96.955981,-70.546372,-120.968741,-181.809257,-179.770437,-210.881318,-235.946766,-145.275838,-54.800132,9.662086,-108.119587,-168.174597,-220.705326,-253.763573,-342.845254,-338.411569,-218.359907,-164.341803,-180.217129,-263.274675,-264.970951,-243.113488,-248.19444,-194.413588,-120.512009,-31.182317,-138.870531,-209.858421,-277.011346,-299.765746,-335.079424,-303.162049,-162.601778,-110.077813,-65.240368,-59.210224,-90.376796,-279.037821,-384.306071,-403.113255,-322.464629,-172.439549,-149.822321,-151.832195,-171.37908,-212.253443,-276.027899,-277.890621,-248.929998,-211.049991,-147.825285,-134.393319,-109.379333,-107.501347,-158.354088,-207.600674,-154.751693,42.158113,172.810789,180.772239,132.35025,81.121905,-20.279762,-22.164631,96.505999,168.806752,205.478803,115.20292,57.248219,-19.60601,-28.56793,-3.779918,21.97269,82.578473,108.650318,87.823848,-40.292778,-112.439244,-110.108001,-42.275297,62.568187,81.470873,100.985374,44.812378,-7.479619,-31.755715,1.47999,88.835819,136.784172,232.266228,242.383815,197.483808,62.64007,17.127229,43.022071,80.824654,113.445253,143.728676,268.404264,267.341507,212.501,122.365291,105.279662,111.503982,126.546513,139.941136,76.043975,43.452246,9.014213,-13.719254,-72.580385,-81.810172,-5.262237,49.265287,63.632296,-26.789459,-73.368228,-121.082501,-103.932082,-14.430573,17.445202,31.356879,-4.325202,-33.733148,-75.330072,-83.195282,-69.151634,-34.058183,84.205686,118.919341,20.681071,-141.242734,-151.391762,-97.992939,-108.121813,-202.171749,-211.236924,-94.087857,-55.639122,-98.270117,-142.968946,-133.793602,-117.784717,-100.840722,-5.221132,71.488859,222.849611,267.228251,242.620922,116.758102,36.106934,-36.705984,-19.023046,24.092096,-14.947222,-75.306422,-216.003987,-258.27857,-225.578367,-176.334109,-142.005602,-143.520838:53.811381,-57.898179,-122.839377,-196.047437,-195.821811,-122.225528,-65.658448,8.107636,6.654303,-16.051274,-101.871595,-152.61128,-151.188899,-71.820159,104.737654,161.659055,249.699103,239.217383,171.900059,33.29652,33.182934,163.860768,222.88056,223.570298,112.690763,70.996327,66.245724,55.351783,-14.773768,-16.439287,65.388677,87.395169,11.454569,-86.732834,-96.579376,-98.894645,-115.117442,-153.582517,-153.675818,-121.591189,-138.365343,-133.49254,-81.976207,-93.033177,-162.913598,-159.353914,-38.217566,42.622932,99.685772,-62.985108,-171.378199,-271.363027,-252.884327,-168.951093,-125.80688,-68.920026,-99.708897,-138.032889,-253.532949,-318.628803,-350.778919,-296.512496,-91.807044,4.173707,-3.514895,-187.949868,-233.658712,-227.801768,-197.925584,-33.106079,76.477384,169.700417,117.598373,110.338639,78.04849,0.09783,-151.458955,-122.716336,138.842486,256.747632,266.90728,124.085128,82.682406,90.156712,108.50196,109.394704,109.799785,171.537716,191.416644,158.582816,62.633557,16.75206,0.212148,21.945257,36.283295,41.34283,55.064535,6.404947,-36.648135,-119.066183,-110.716228,14.471081,70.813942,83.610107,17.359338,-14.66021,-72.599711,-112.069277,-200.420085,-220.755262,-204.129041,-199.55899,-218.133611,-229.548321,-251.304209,-301.16408,-288.526698,-189.039198,-145.89622,-142.538856,-239.501798,-273.072386,-218.757982,-150.596951,-24.934402,-4.678263,-13.761944,18.551605,97.540975,-15.68434,-95.424923,-150.500995,-146.755138,-126.797445,-77.713071,117.007871,158.637583,84.169024,-81.035477,-132.872716,-152.282829,-121.118458,-43.333719,-16.190653,3.15967,-40.363152,-71.986395,-91.236189,-66.964008,-19.597632,-7.433756,53.767468,35.342283,-53.636889,-245.417522,-275.743739,-221.299636,-186.307046,-144.865504,-123.811991,-87.318074,-126.806016,-151.708301,-137.028537,-120.735475,-128.212856,-107.968376,78.18111,220.019131,192.877625,66.211572,39.366873,84.059954,118.178819,206.353517,270.340489,334.86591,232.399284,155.698021,68.62458,80.897441,176.269382,224.287298,268.441986,230.053712,172.31572,-3.146593,-62.745056,-30.229115,23.465225,84.957093,75.570889,15.830028,-12.41707,-19.884475,-21.656327,8.953733,91.214286,117.3132,176.466258,197.154061,154.388843,5.631603,-38.176069,19.865533,86.291748,176.888533,165.975876,31.772059,-33.513287,-40.585451,-162.897114,-221.814286,-166.669309,-112.569075,-117.977882,-143.037605,-141.913513,-217.849232,-282.258057,-330.271635,-304.739089,-266.480216,-277.877445,-318.638468,-373.035214,-406.225499,-433.852422,-407.241571,-274.993015,-175.621185,2.893957,-8.78852,-64.46641,-161.629758,-201.132643,-236.805693,-212.112145,-105.786186,-46.100345,23.127644,-28.560339,-91.016958,-225.587026,-261.449446,-215.7007,-136.237433,6.604514,-49.875968,-109.597716,-194.183809,-253.314937,-372.534081,-370.453027,-224.810581,-128.602612,-50.785869,-160.960842,-213.774662,-205.830482,-172.202795,-113.000078,-68.133957,33.619806,26.242794,-4.708674,-108.352001,-208.294434,-369.928586,-330.304221,-74.657066,20.391019,44.620277,-26.824999,-101.070544,-295.596182,-339.131731,-274.247763,-219.605007,-130.867725,-103.150087,-123.128698,-199.084665,-238.016384,-256.657091,-223.630906,-99.281027,-40.023311,-6.395233,-7.709914,-11.792981,-74.671028,-100.701285,-57.749429,-4.266868,133.83533,273.4107,303.356396,219.779714,123.785942,-25.536952,-37.090585,73.506028,174.088803,310.383259,232.66646,141.099293,-16.308381,-27.850888,72.137163,136.895125,209.309483,166.02194,116.482424,-61.292614,-159.934693,-144.460751,-41.32475,115.568302,144.612298,138.482408,50.2592,-4.231244,-45.419179,-10.468888,145.400796,228.515096,288.609568,225.992833,181.252431,46.354904,-27.018719,-68.900203,-41.812734,47.546882,126.388173,272.002652,237.101251,192.020307,112.719028,88.379946,95.776299,115.213042,162.917029,175.09304,174.935319,151.045513,94.340482,-59.92306,-87.974091,20.325284,95.738853,135.82315,79.476617,40.449335,-34.648845,-35.160374,61.070975,123.389372,208.542837,179.204236,122.959502,12.572354,-19.681476,5.648825,60.727814,177.115825,205.893135,149.201949,19.573704,-17.698087,-16.474008,-9.994579,-26.632537,-16.814419,44.952822,2.501584,-60.121562,-149.692116,-144.212843,-53.066783,2.875485,85.486036,123.012918,214.615321,311.517486,332.0791,238.088943,154.866061,52.218754,58.13805,130.4995,67.500205,-18.416074,-136.10845,-157.642394,-146.548697,-120.462283,-96.518717,-94.743842:31.176126,-41.462528,-99.902859,-168.558799,-143.109704,-20.673749,3.129145,-39.863908,-32.107174,-31.437959,-122.190486,-165.482478,-64.222554,70.608327,245.636638,228.633959,139.892337,141.7696,153.52956,173.661326,202.595853,269.241447,245.903349,87.575595,14.879325,8.789139,-36.477083,-66.830115,-55.717099,-6.18596,48.772549,21.882872,-79.595624,-193.675559,-233.577933,-260.581784,-263.338341,-277.330928,-283.200712,-281.304148,-307.575252,-301.480896,-220.132517,-218.074426,-340.216985,-357.889225,-165.218541,-33.105751,80.877533,-64.335305,-169.825476,-261.795865,-247.264486,-166.808322,-114.548496,-54.883255,-105.820254,-157.39906,-290.25702,-338.325821,-320.230022,-281.962557,-228.143257,-218.150618,-245.762371,-319.05943,-334.178045,-295.273249,-266.917927,-200.221695,-153.507453,-52.814842,66.238776,119.721336,151.82962,124.938528,56.910713,67.625395,236.167887,347.611562,392.443383,226.164114,203.184294,291.810202,304.987502,264.618613,273.079092,339.382771,364.829457,342.717377,232.310416,156.772946,90.729542,132.471388,236.292391,237.573274,131.936403,-2.628012,-50.025442,-111.873842,-138.43195,-179.3165,-172.432222,-93.604352,-11.750214,-3.165936,-87.536449,-168.803113,-297.979254,-322.65769,-331.47984,-292.274459,-119.356034,-122.352837,-181.776452,-161.725501,-87.601322,-24.15435,-86.649343,-247.096117,-145.001629,-38.110357,15.861596,-46.602562,-137.933462,-138.323568,-171.961584,-194.604842,-168.017827,-134.121512,-148.167381,-246.620671,-298.793133,-261.48625,-160.479121,47.005319,61.116492,6.898261,-120.687022,-183.151857,-210.983093,-155.822357,-102.574236,-161.310965,-257.182796,-127.697082,-54.628162,-65.754296,-129.733599,-243.254853,-263.913911,-198.809975,-107.145069,-121.249701,-223.762814,-259.012891,-255.328594,-258.949518,-363.364347,-405.579203,-344.654565,-275.369335,-276.422169,-277.54412,-270.129295,-267.827275,-251.071887,-46.452934,179.172595,201.503974,218.664556,259.095535,349.273934,381.406123,430.50551,453.016988,436.691319,299.96521,241.121473,208.700128,215.539612,252.928136,275.311757,272.152639,174.111736,119.078754,118.097991,156.713154,168.287442,136.509838,120.760256,158.271343,189.394106,135.093561,148.373237,190.123523,156.169374,64.965766,74.973943,178.289015,153.573232,70.207971,-108.970347,-176.786433,-240.270159,-220.462708,-97.943348,-28.673742,30.617533,-26.887674,-69.550225,-187.330067,-244.198627,-259.482711,-243.217892,-254.83604,-211.840815,-161.205672,-170.375306,-237.149465,-292.084533,-258.38371,-233.24945,-250.250423,-254.740454,-297.952448,-344.901559,-434.256859,-442.659144,-300.162039,-185.669945,-22.230712,34.442474,26.543631,-47.02349,-89.244118,-160.413124,-184.82604,-191.074186,-176.306714,-155.234868,-142.246322,-116.738056,-74.851761,-73.527921,-27.210767,21.755546,80.46531,70.126945,45.957398,-74.727544,-178.12575,-323.200759,-300.913391,-175.978638,-148.767905,-176.758263,-227.382688,-226.361472,-152.577111,-117.47007,-82.587635,-62.975175,-28.212345,-60.418664,-117.655895,-249.507366,-281.749401,-261.907586,-231.073928,-199.64998,-196.363688,-132.171716,-68.286706,-105.35037,-300.176696,-370.726412,-339.736072,-284.728125,-157.188097,-39.678456,-47.443473,-170.787554,-218.025169,-220.283974,-204.528451,-179.987415,-150.55097,-37.997089,11.43623,-25.000443,-174.257797,-234.154734,-184.261114,-82.962921,94.833369,130.45822,120.404748,50.70509,-12.122628,-85.258276,-64.226516,1.910317,20.463164,97.190616,173.808411,162.625137,50.935597,-35.985369,-158.289057,-141.980975,-26.524892,43.032099,51.57197,-2.582932,-61.411976,-150.595534,-142.11939,5.851597,100.579997,139.571858,-20.744993,-76.499556,-49.220121,-21.572174,2.560679,41.427126,155.822941,133.085539,72.62305,-1.034933,-1.199762,52.660659,103.189074,184.513056,218.461236,318.492301,350.968091,306.777945,145.565639,83.080772,68.023857,98.18259,163.191916,195.697564,214.552131,227.508882,187.085582,77.59125,71.961263,162.946692,216.875934,226.208628,92.088032,41.845781,25.123001,25.759444,34.576059,82.420632,220.725123,150.477332,52.892165,-9.894422,31.148062,87.01343,83.047914,46.964362,34.938736,29.360746,-22.018957,-61.903256,-140.84517,-161.475962,-158.396066,-162.812796,-178.367759,-170.270199,-193.611532,-265.13096,-270.505975,-167.289868,-78.802228,66.065082,126.338805,250.959578,278.234779,248.554656,142.328351,85.745317,44.728814,64.379376,123.198624,96.397534,38.599738,-52.242467,-67.41253,-83.201657,-102.498743,-151.505516,-140.163048:45.62426,-119.617893,-169.242598,-173.156703,-166.459624,-131.495266,-85.516759,-19.490276,-99.428207,-154.080966,-200.345481,-208.561578,-143.872898,-45.736878,99.623711,94.90442,56.871325,77.102044,77.009869,51.467339,55.181468,112.303498,146.888459,178.116833,155.688339,127.459329,25.900905,-34.260746,-84.51256,-47.389355,67.228742,77.757654,-45.998141,-171.51355,-172.843115,-153.727863,-179.604147,-268.448592,-280.417774,-204.441257,-198.056313,-229.0448,-255.538222,-261.51717,-275.08579,-261.925393,-151.63563,-65.189266,56.73159,19.638299,-36.026879,-153.338015,-196.68898,-200.169335,-149.052288,10.203523,50.857467,-15.656873,-234.969168,-322.588581,-339.957111,-283.801458,-162.572482,-124.21118,-155.146125,-301.842297,-329.671861,-224.116364,-152.058669,-42.50029,25.889494,150.716021,148.720043,121.091214,36.598003,-31.357655,-109.976825,-53.973757,212.092328,327.680425,343.069132,230.768346,207.660264,180.076381,148.375474,99.603456,124.872175,297.648816,411.192622,366.25505,129.607325,24.324574,-18.662019,22.295439,145.92817,203.843358,200.541741,13.158195,-77.364602,-114.130399,-80.429624,-48.218353,-50.296326,-13.323299,0.722,-16.908369,-53.856512,-88.477353,-206.274001,-254.797764,-257.660862,-209.703008,-127.008291,-169.34328,-197.346196,-207.806403,-189.736465,-157.997549,-170.135336,-190.251305,-164.408675,-160.678864,-158.300352,-147.716335,-115.855233,-109.849894,-109.489676,-85.579811,-6.721795,-29.874975,-79.107154,-176.918639,-210.515928,-189.093203,-110.091151,98.040221,132.164189,71.985035,-89.101381,-154.360341,-174.306236,-128.238416,-42.112793,-29.67859,-45.186679,-87.607898,-112.898013,-161.080376,-171.95472,-182.063921,-193.194652,-157.627309,-77.800533,-110.799788,-283.89424,-326.833365,-289.746854,-265.134748,-214.122386,-172.15318,-138.252861,-198.191562,-202.150199,-158.792836,-152.154714,-147.840027,-113.269857,64.837492,204.161682,195.699402,133.617866,133.943574,221.157734,279.993674,360.600797,391.002713,430.850542,343.974931,256.960757,132.525319,141.157089,276.511835,345.038749,400.102531,335.058668,248.288521,36.904602,-24.144432,39.415073,119.230121,200.261265,201.485346,182.52657,131.791797,109.77178,72.465865,60.662209,93.891791,136.409891,250.563456,317.976118,291.858408,107.903946,-16.455474,-164.079119,-139.252869,25.788378,78.001844,51.508973,18.480665,3.941611,-104.915072,-167.082547,-209.901009,-192.701566,-107.45323,-86.857645,-130.894089,-214.410618,-230.36435,-246.164082,-250.920371,-238.143666,-212.518372,-171.437855,-264.402654,-345.501111,-427.838438,-414.904096,-324.392331,-235.473388,14.884677,108.991614,54.028362,-84.875627,-116.186503,-109.535107,-92.091245,-57.58854,-41.048681,-24.561249,-68.672055,-130.272223,-280.691642,-301.53822,-178.872998,-88.594233,18.702835,-10.580946,-36.234028,-104.35101,-186.077442,-342.571917,-339.809253,-188.96873,-104.048579,-70.711157,-229.760594,-300.388194,-309.89616,-269.115212,-146.818499,-57.363818,132.326306,146.208589,62.383471,-144.020788,-210.520617,-221.336537,-175.536913,-78.077055,-47.976857,-28.669158,-87.90806,-142.43364,-275.198199,-331.163207,-356.950922,-300.588887,-85.539224,-6.612246,-46.443838,-146.7177,-195.587851,-247.495934,-208.016843,-36.441001,17.989016,12.427761,29.982413,39.581269,-60.789028,-132.63607,-119.286365,-25.17308,208.169304,312.584434,278.930851,104.841859,7.943499,-96.878499,-77.486627,60.820411,140.819066,240.630745,216.757962,162.638115,31.10691,-6.108275,16.266729,54.063608,107.79404,75.973789,25.602152,-117.785583,-164.057833,-100.203116,-27.221486,90.120412,142.729871,151.440289,-19.344757,-73.83456,-49.867596,-24.372192,30.269304,96.484564,231.614315,182.989368,120.721903,40.321091,7.479637,-25.277912,14.314919,177.883314,270.800015,367.190885,215.655187,110.196403,26.14247,60.194911,165.125776,189.299365,217.224102,263.854654,270.196322,163.586884,46.381512,-121.370686,-85.599618,148.192945,238.024022,242.530175,102.505238,23.90292,-80.137833,-75.328178,31.177792,95.498927,167.591285,94.272307,41.180288,-31.903937,-69.04729,-82.728409,-32.844193,105.802329,161.490612,205.255523,80.068552,-25.230554,-170.517438,-187.474201,-162.122412,-129.751109,-47.330133,-69.60859,-123.035204,-196.261426,-197.235386,-152.192455,-114.211637,-0.427334,86.176584,249.665119,273.446641,240.001413,142.088184,104.684459,88.835899,97.78469,113.925615,82.945682,38.155664,-89.194066,-143.180454,-161.674561,-144.738007,-114.463777,-84.348171:-32.436421,-213.89405,-283.362362,-292.84799,-251.037979,-111.701741,-58.174352,-64.145979,-120.205279,-152.31127,-217.502602,-229.243148,-161.277849,-69.414165,142.010848,208.722471,256.741551,289.899598,315.44741,317.504127,278.523257,183.40557,146.354756,113.325729,180.748282,211.823836,134.669919,41.101819,-80.927906,-68.540977,-21.042845,-52.845404,-242.444548,-453.977243,-488.571997,-386.014558,-317.506838,-279.09103,-286.063606,-280.082102,-302.585302,-317.708431,-292.587994,-261.00549,-205.111402,-175.090724,-71.967109,17.79835,244.987718,318.427026,265.333462,127.417572,109.711454,210.050234,273.688979,294.447285,201.944763,147.672415,15.096419,-65.083969,-182.803362,-209.218038,-209.796212,-177.543678,-140.495057,-220.794232,-263.715454,-340.077337,-370.055636,-314.164747,-230.413027,-68.22528,43.585075,78.095969,96.531701,81.908945,42.8782,57.460109,196.13541,260.101154,210.826727,81.405222,71.71381,124.692796,157.781892,214.55595,231.094795,257.930261,280.871793,265.401801,137.577536,26.107009,-112.914809,-59.752727,138.716481,167.661063,90.296927,20.513327,22.559782,65.622209,45.230467,-79.980854,-99.623396,14.011365,127.960394,144.11735,112.153404,54.435838,-85.984143,-119.878569,-100.929664,-55.737295,72.11831,107.53692,121.787755,237.172607,286.932635,278.980849,219.6041,46.13803,9.187716,50.09139,68.827972,23.288105,-51.141619,-63.072019,-137.311643,-187.144468,-193.860898,-181.883861,-223.694724,-337.886234,-343.810235,-164.203638,-27.717538,146.253032,76.798975,-10.1676,-122.404386,-137.926167,-119.190431,-82.041673,-42.929215,-85.329966,-190.148437,-146.522835,-108.589977,-142.648518,-187.468658,-185.408406,-150.172201,-90.992253,-6.721574,21.585681,-90.638272,-207.681105,-346.139179,-340.96197,-344.547171,-390.51982,-464.831469,-394.203661,-327.593253,-243.026913,-226.376505,-169.649536,-116.287884,6.937251,67.119045,86.44791,217.933923,299.104432,348.964926,341.96118,358.203203,369.939206,351.086376,264.662619,211.722418,132.066633,109.770764,86.604671,84.675322,118.486451,106.657512,62.313321,13.118986,31.266578,57.009942,28.999241,-26.535038,3.215327,137.023231,200.911583,195.302553,136.157539,118.916218,189.341842,247.717861,321.25015,288.427006,222.903278,50.57338,-13.264644,-73.345292,-92.14042,-77.905094,-11.98237,142.496669,122.234681,69.408171,5.691119,15.202798,54.578436,46.673397,-1.641705,-21.948989,-36.315195,-89.893969,-96.701372,-37.159609,4.775772,24.542185,8.938098,11.860612,-53.861029,-127.031479,-203.193258,-172.375048,-29.234223,11.588048,6.443667,26.652395,20.682665,-32.565373,-38.446504,7.451146,27.661494,15.99156,2.175239,-15.61053,-54.465784,-57.168909,27.09526,89.921315,155.856518,150.230853,132.077935,125.996726,107.097047,12.361242,-61.425469,-181.009148,-195.906984,-158.283206,-131.939068,-124.511968,-130.941874,-105.076634,-46.966664,-26.833068,22.115933,30.434384,0.11093,-38.481,-63.384601,-95.369971,-112.690495,-166.161303,-171.913145,-150.433156,-134.601071,-48.123374,-10.884652,-60.57185,-244.145807,-321.360092,-330.139769,-285.051187,-157.58987,-5.178378,19.327038,-64.254406,-116.305836,-188.521645,-223.801692,-268.21376,-267.751621,-262.539235,-249.034017,-214.542893,-173.273579,-200.666363,-220.537974,-155.808682,7.006538,-56.387261,-156.152576,-303.056306,-315.839862,-214.344508,-138.07015,-109.483814,-154.061167,-112.138468,86.850744,109.287701,-48.44834,-148.662333,-239.17807,-239.049373,-208.402667,-90.411493,-14.542936,-12.241756,-99.290169,-219.357409,-179.445746,-32.337945,-0.434463,-9.440138,-29.896529,-43.389605,-74.394684,-94.180818,-148.60417,-161.567559,-93.068872,14.860511,23.541645,-7.976161,-21.498476,-46.499986,-41.293544,64.814427,138.088122,210.868632,191.879369,148.76295,33.359366,-0.94073,-26.779295,-17.013854,107.827193,222.210482,216.567552,151.245015,108.877733,-15.745407,-63.553188,-32.282782,21.972295,51.450891,-40.538093,-70.195341,-95.549925,-121.707159,-150.132736,-111.076167,40.181465,73.525347,8.411929,-135.756172,-160.277587,-111.055838,-62.135646,-34.290118,-56.138886,-67.026482,-98.43743,-138.167859,-208.758168,-235.699883,-291.542227,-323.254833,-311.113403,-212.250493,-216.249256,-299.397415,-299.115368,-206.993623,-164.169733,-91.24761,-38.634231,87.36452,133.308628,109.784715,42.528892,24.511621,31.117755,32.803415,6.434854,-5.985874,-10.472319,-56.709775,-79.971878,-45.219814,-4.259506,3.009399,-35.991759:4.152284,-38.273718,-41.307045,-53.944219,-48.536215,-10.614264,-16.010984,-20.613669,74.663192,96.803754,37.586199,4.29703,50.433434,133.281166,288.539512,314.020283,274.086998,267.833361,304.894445,304.455786,226.866236,63.429474,31.244026,52.15764,88.464576,64.296059,-83.076444,-166.172495,-227.92276,-189.977936,-47.499445,-5.732884,-95.804367,-263.706176,-267.356612,-143.245548,-102.485794,-153.648634,-213.885999,-300.142167,-299.412054,-269.689072,-181.493416,-159.329673,-224.113823,-269.456004,-217.630921,-121.494666,41.120606,22.00131,-43.92629,-186.870672,-215.87913,-178.171857,-151.025321,-103.333043,-80.978571,-133.94667,-332.618306,-394.883157,-388.269626,-365.177313,-290.360708,-214.205961,-115.145511,-240.478047,-311.949009,-404.424225,-434.403534,-364.701192,-281.70984,-159.25856,-78.529975,-43.050292,12.368784,28.070086,58.928719,100.068133,188.595801,190.72985,105.372502,71.728422,118.551983,247.237283,282.818728,298.978591,301.105861,307.477059,292.65389,270.900375,182.901542,109.828669,44.152734,109.79062,299.711032,330.209191,206.998132,-30.974632,-103.761353,-97.75373,-70.554706,-40.133408,-42.306269,-88.977148,-99.25335,-86.609347,-98.647144,-131.093476,-216.335864,-259.821292,-285.182825,-229.521308,-100.04556,-185.401686,-235.94664,-155.916813,-74.110195,-22.514059,-68.699431,-143.351984,-19.522273,29.388566,-76.970374,-166.783158,-190.0722,-135.203552,-130.514713,-193.478842,-228.449905,-140.254512,-140.119208,-280.140725,-343.884899,-255.888252,-132.07275,62.569873,23.953986,-70.277738,-246.902496,-290.746584,-264.114365,-200.371243,-118.975955,-151.711053,-283.260575,-248.757073,-154.538835,-51.784942,-98.811766,-248.842159,-267.013422,-114.94,92.475548,116.2271,-0.327815,-84.151225,-191.708605,-213.507282,-257.65498,-290.171633,-332.434434,-306.82561,-301.125979,-336.98002,-339.255308,-285.118356,-242.95052,-74.929923,101.242012,131.846061,163.841561,188.923445,207.137097,197.635315,182.562473,181.806951,147.234761,88.991842,81.641935,73.479928,53.380598,-5.127239,-31.183893,-48.341177,-56.368271,-53.565968,33.524605,72.220618,50.171619,51.191139,122.137319,146.768138,182.093225,266.085337,308.890304,310.646573,272.775108,205.544113,203.934549,270.711402,277.137237,217.043652,52.029815,-17.790716,-110.852075,-130.577082,-76.389858,-5.688148,92.540159,66.054182,40.945847,-3.818265,-24.856671,-67.758699,-85.328573,-86.65255,-84.655621,-100.682544,-128.540836,-133.901702,-124.590798,-91.52948,38.327709,97.852513,69.883449,-153.990231,-245.479827,-252.100841,-204.434814,-112.190403,-48.713374,112.79472,105.133197,36.504168,-70.085451,-93.24952,-90.126579,-62.276862,-62.244672,-123.095831,-217.995705,-77.907594,40.819186,153.3106,140.100968,130.880481,137.641798,126.849656,100.82038,64.905996,-39.641346,-109.733408,-262.426223,-291.364588,-202.792062,-137.485847,-112.759208,-125.182526,-87.354237,-37.954784,-62.642813,-87.889194,-46.111014,74.063468,65.063748,-2.821353,-131.709874,-165.911506,-195.096983,-194.124076,-217.387509,-242.476098,-205.118409,-74.974437,-68.427875,-249.513726,-337.871431,-291.285068,-213.465374,-140.627672,-133.298018,-133.953554,-164.763606,-195.701065,-240.15066,-238.379946,-216.884558,-204.693187,-222.071343,-276.75566,-258.412443,-217.019035,-241.200954,-253.36046,-211.077437,-140.166509,-102.315644,-70.801414,-39.863805,-53.266914,-46.181036,2.849595,92.481299,89.748858,53.815738,84.840959,111.753701,55.034198,-40.08074,-160.966446,-130.339697,3.153217,55.29358,43.561776,-17.954199,-76.366443,-181.900161,-178.905576,-79.625854,-25.51941,11.000094,-29.568295,-42.775158,-45.414413,-47.611835,-71.809461,-70.251048,31.12627,111.681025,107.443929,107.65572,105.563025,61.528067,50.571768,82.573335,118.839624,212.541763,249.834434,218.604901,67.373411,6.819648,-25.953858,-32.05401,6.491842,106.08534,116.980749,56.236378,15.779796,-35.588793,-37.394965,-12.834159,-3.156976,-48.359016,-122.861622,-108.352904,-76.12674,-98.374881,-89.288321,-38.426655,20.844083,-36.381292,-86.620907,-141.772058,-137.106145,-140.436765,-132.970058,-66.471646,-56.204081,-134.69685,-207.814423,-218.282798,-252.771268,-277.407657,-257.430326,-209.752028,-160.487016,-246.567121,-283.12928,-269.205801,-259.961198,-275.849588,-265.5598,-189.812009,-133.536835,17.219178,153.865486,181.697504,132.735513,85.806656,29.368941,13.741759,-16.960274,-15.85724,-30.522707,-160.007232,-231.587602,-227.683011,-167.731261,-114.451238,-138.724011:-124.814337,-218.88598,-236.92626,-237.643638,-236.666752,-201.272729,-175.923962,-168.873544,-182.296955,-173.196555,-125.49976,-115.802107,-118.033182,-82.190484,40.700836,76.355671,96.214895,114.448121,125.877509,143.636425,149.027032,168.850046,161.617866,95.032296,118.499665,169.091351,181.828363,119.465159,5.954205,10.679116,53.980261,28.326421,-141.505629,-344.426923,-386.203182,-345.360978,-324.392228,-343.99392,-354.517356,-297.86982,-227.620926,-217.93269,-209.9619,-218.660193,-245.392627,-216.631387,-43.76505,60.809645,191.233338,115.951822,39.648507,-54.427113,-50.791329,51.063275,112.680259,180.24289,191.262386,169.046026,23.013261,-83.765997,-222.464119,-232.577823,-201.086231,-186.180499,-196.455383,-238.222824,-220.449789,-133.587351,-137.278972,-186.678744,-153.884352,-23.950151,37.101305,46.121824,8.179667,-35.449483,-47.929919,23.814482,255.59602,347.248589,326.307434,108.59243,49.824744,80.807304,115.824574,189.81537,237.324658,332.984466,322.627564,258.090318,155.603216,146.98782,124.457059,93.266848,25.176246,4.68294,0.409177,22.44596,36.689346,-2.806093,-62.471223,-136.693038,-130.945102,-67.005947,34.327474,61.299709,30.283769,-8.601563,-128.531047,-195.338416,-227.349292,-191.299641,-133.706439,-140.401186,-111.81979,46.838186,100.503803,59.245282,7.335901,-48.709665,15.137215,66.037831,97.313205,57.207285,-90.379718,-164.346106,-241.367238,-225.583186,-133.115586,-98.992975,-121.194332,-202.790803,-227.138973,-144.587703,-52.349018,85.211409,38.803561,-41.527615,-184.344243,-221.202886,-189.922336,-110.221004,44.301347,49.393367,-72.138934,-157.352345,-153.958973,-143.521518,-162.656823,-217.924294,-228.315758,-182.054038,-119.437139,-134.657333,-275.192643,-348.86313,-388.590134,-373.390112,-331.474565,-297.086586,-218.726134,-158.682284,-132.699742,-118.233528,-140.353154,-167.799327,-127.765958,51.166494,157.657034,147.134265,145.151272,193.856273,307.73237,325.166838,293.95204,294.053464,373.482559,378.807809,317.137939,205.172603,194.375482,235.478867,256.633444,254.969284,204.958959,172.431647,110.633399,86.165041,51.234653,32.220842,23.907709,57.077173,141.208968,146.654479,129.901885,105.71091,98.95238,109.49723,132.329373,194.18619,254.435033,247.93092,101.610912,-13.595826,-153.811137,-140.104052,-43.088583,10.012181,112.081628,134.904732,120.442817,53.96768,14.729157,-14.685632,-22.854734,-53.140736,-20.515974,-16.278117,-107.243651,-147.021329,-118.09918,-97.671618,-121.05661,-123.606951,-98.326204,-197.636077,-248.826829,-239.828104,-228.484121,-191.831241,-119.858074,66.053148,89.040904,38.253167,-45.234148,-57.739331,-35.483335,5.96113,86.556442,82.7587,-23.8129,-110.307486,-102.91106,-74.573137,-67.122633,-30.707678,-8.270996,78.499294,190.353796,189.649498,27.078997,-93.775629,-232.995871,-231.433514,-187.402321,-160.995883,-138.974883,-207.305872,-227.109697,-201.9948,-190.919309,-146.863709,-83.66888,52.023858,21.212546,-49.677595,-145.622738,-165.553977,-194.109539,-171.85234,-57.318797,-8.532792,30.393399,-84.161981,-184.868007,-328.426653,-344.157601,-277.353388,-229.286424,-164.421584,-108.823969,-79.097679,-88.519148,-162.205284,-311.947339,-281.355243,-76.163972,-19.723972,-29.154858,-34.33321,-41.304854,-123.222,-170.875626,-148.102057,-78.276703,52.702757,43.041055,-13.464336,-118.781438,-130.331023,-74.755883,-43.606903,-5.513878,17.326063,63.174237,71.949528,55.168594,-35.654867,-103.670617,-208.704392,-203.666467,-93.010139,-36.644374,-30.259767,-31.138506,-81.928271,-198.237145,-178.722595,-33.141677,31.890446,83.469059,13.405334,-32.465157,-76.547255,-76.065584,-24.472488,11.323078,28.182113,-24.687784,-63.677354,-117.757713,-135.444872,-153.020665,-118.406806,62.131168,168.260904,248.025755,108.996965,45.227174,46.635172,77.533738,96.728134,95.549946,137.672042,184.059849,184.52316,117.280185,42.331943,-69.417453,-44.748221,68.476393,79.968676,69.660802,75.373357,43.73004,-76.762845,-117.49762,-102.040026,-66.195371,-9.498917,-87.847677,-141.575113,-81.343842,-25.307788,-82.804794,-131.742458,-81.946663,-32.112634,-27.038463,-112.252286,-155.015748,-217.01355,-233.951751,-212.992631,-188.901408,-205.15396,-321.728993,-387.872102,-408.464136,-339.309803,-138.144688,-72.176382,-43.914461,-19.272793,101.657777,155.805449,145.372735,50.8153,-16.422142,-40.480008,7.43859,96.961099,100.444698,73.288708,-15.229643,-52.781259,-36.894815,-10.152094,-47.498185,-79.913874:forward
122.309178,295.312933,360.806205,401.575288,381.694162,267.000623,193.760989,130.774317,195.580418,266.261789,416.423613,430.566009,368.106969,334.25317,219.876775,154.579894,93.923732,142.945094,176.042367,86.296985,-34.945487,-255.162666,-314.058669,-274.655925,-47.817674,53.585141,71.657944,6.076915,-109.87668,-129.118099,-159.749653,-206.54542,-304.16106,-253.665971,-186.950472,-96.167836,-98.663278,-253.227748,-359.890551,-393.219811,-306.665287,-286.01096,-256.051712,-251.354027,-260.856051,-270.062337,-297.482384,-280.961518,-176.880078,-109.67417,-95.03388,-104.352917,-131.671923,-210.709806,-259.529195,-320.000804,-263.081138,-184.582713,20.25759,85.058685,90.478289,50.139788,-65.822484,-66.070846,152.979719,304.79517,260.004672,120.624651,115.892707,163.792715,140.645143,42.560274,17.230088,2.783145,-128.373012,-225.932503,-384.112403,-449.961723,-598.543809,-633.742253,-486.50955,-253.600789,-242.669543,-377.064864,-408.79658,-370.763692,-362.863856,-363.420874,-261.415334,-182.607245,-113.432606,-138.415929,-192.063371,-203.899783,-234.788871,-232.054564,-130.002628,0.468599,26.922457,45.744658,56.399399,-31.995872,-119.898998,-162.123983,-47.242242,28.47174,159.682199,140.868259,-92.202818,-207.115462,-251.176699,-202.907005,-116.002614,-42.310321,31.611734,132.22215,103.381584,-0.561453,15.094143,193.683056,244.872994,201.447746,176.747579,178.074798,77.257998,-4.693725,-93.933377,-73.04899,19.63109,139.9875,226.426626,319.077085,280.002101,105.993827,43.011442,44.352579,109.807626,133.161102,110.795044,54.642505,-61.969893,-96.183403,-143.144692,-149.553441,-77.463565,68.875982,125.211318,172.097065,178.696236,135.828583,77.224007,-41.095557,-53.685132,1.220833,182.938427,269.459978,316.923974,254.767807,72.173949,21.189329,13.880876,60.220458,104.813084,201.887944,216.504297,120.503487,47.862081,-0.54984,15.218253,9.971442,14.816314,36.478127,96.114242,101.687746,-8.407114,-86.866036,-95.296598,50.02978,69.619057,-76.818132,-165.388704,-201.19124,-164.142565,-114.065358,-128.046811,-79.580465,93.285616,131.763931,86.193409,39.492743,14.427414,72.305016,261.129049,348.722186,308.623338,114.318004,37.956214,-8.956751,9.842044,155.107929,265.902685,252.245239,164.201525,119.208989,85.824014,112.584459,152.481524,134.552673,99.760949,121.389733,127.273586,36.329046,-44.023983,-113.620748,-89.603421,-46.332381,-76.39952,-67.377826,12.221149,22.164464,-54.247216,-96.101714,-100.907971,-60.622004,21.464982,-8.75625,-38.632615,-54.13042,-51.108859,-90.381265,-127.367677,-112.455167,20.0103,72.187914,97.834449,92.569931,83.99661,57.95011,7.350581,45.09403,248.217038,379.324611,336.869354,117.57093,23.029583,-124.779118,-205.270767,-336.09698,-341.93064,-279.858147,-117.855329,-87.549855,-159.758134,-218.762954,-298.569861,-291.017639,-175.39079,-72.781487,-61.816486,-34.348543,9.42501,0.097125,-88.584603,-168.629002,26.760567,115.280847,106.86721,32.203495,-91.626815,-95.196414,-57.823901,-71.848481,-124.421446,-66.873657,-6.472778,66.699977,29.576533,-226.513031,-364.720586,-407.090969,-263.282596,-213.782462,-154.32401,-146.945811,-220.550769,-273.913916,-306.553962,-272.928524,-156.801641,-48.468916,-10.879564,-19.907133,-76.784648,-269.658658,-349.279,-289.244455,-102.214639,-82.399899,-148.355513,-162.166485,-47.197637,64.570964,188.070653,156.654322,89.371851,178.901656,233.759604,313.578769,360.836786,361.131378,279.629603,153.259886,209.557387,234.103598,157.430054,72.886626,-40.728905,-35.287037,22.671743,51.806599,129.077188,184.151684,173.795075,84.659248,37.115094,12.481808,18.148882,26.923998,102.305052,154.244636,170.656339,122.5266,42.543809,53.9601,101.690091,98.641879,37.148417,-8.373857,-0.856183,-1.185354,-24.920591,-92.21872,-119.152197,-34.975667,163.657608,191.985945,86.58884,0.531725,-124.071752,-138.792406,-126.584702,-123.700382,-115.173061,-22.356848,68.558931,203.702305,188.821823,55.975621,25.005466,92.650176,112.350518,106.815174,164.203635,190.407462,152.975583,100.695749,68.98895,128.978301,249.934592,231.318496,222.413653,248.606586,261.774419,224.952019,169.654583,140.848717,261.606601,277.630763,159.98655,99.713247,88.303703,109.983365,153.595872,174.857662,221.610566,255.04882,235.547717,120.270377,69.159916,68.083509,110.087857,215.448854,261.718057,278.659836,391.178887,456.845509,487.474767,452.98448,363.050883,326.00488:10.059178,41.139085,58.321951,131.617202,156.297125,99.15525,42.495975,5.2173,123.116859,208.002862,255.814909,180.535796,10.460488,-5.303552,18.854642,4.247829,-16.56567,79.97703,122.241351,42.82124,-73.591469,-295.845613,-328.775903,-250.322732,-164.133284,-97.494815,89.862113,125.138445,-5.076865,-109.292848,-233.49454,-241.75697,-206.407547,-91.518075,-18.908296,8.86275,-56.824997,-223.136324,-262.945092,-218.06411,-183.767966,-199.913441,-217.199858,-220.305638,-289.751297,-354.341204,-405.560834,-348.423282,-139.399715,-40.921657,-63.379591,-136.055121,-141.470455,-156.652739,-224.927556,-392.291286,-358.782361,-268.158469,-84.889329,-39.81401,15.072437,40.614474,4.863696,-21.694226,78.543039,188.789012,155.355558,72.115936,91.985603,118.408843,63.489464,-93.386584,-126.922977,-104.110926,-152.806536,-225.379777,-323.456585,-349.941984,-404.808404,-407.97664,-318.379429,-243.059045,-272.643856,-361.779286,-365.570411,-336.463563,-332.701341,-343.191818,-260.729233,-192.103614,-201.53281,-262.087563,-235.728624,-163.031222,-131.305423,-163.092813,-127.088032,3.869002,13.317164,-1.566077,28.977277,-7.146124,-101.27385,-172.3008,-26.587759,36.077559,65.107865,38.698346,-70.412273,-138.922014,-192.568247,-140.011396,-26.893029,-86.255258,-106.211626,-45.735502,-33.549825,-105.904571,-115.691758,-4.871093,42.663952,-0.678855,-71.319644,-57.220371,-20.365696,-56.53943,-139.217928,-103.077958,6.557544,32.391366,63.589868,125.661146,131.792335,98.508341,65.537792,37.27565,127.230276,184.335982,169.689855,78.980872,-148.077211,-224.200072,-256.506013,-221.903283,-79.335819,58.406247,87.510498,81.616974,60.339242,-29.24737,-82.440495,-85.804587,38.811715,89.506983,123.487517,138.257517,184.579842,172.839682,56.466894,1.79372,2.503884,173.573712,258.369296,223.170436,103.720473,-100.63242,-101.352022,35.371027,135.256388,139.512846,89.734611,63.296345,38.102278,34.23929,6.662936,-33.364257,-74.816514,16.573462,47.433032,-15.22294,-77.033742,-145.264701,-140.348434,-78.186653,-28.133788,-13.225211,9.108573,12.995996,-19.177449,-63.6271,-85.804232,-20.157152,160.615391,257.286725,253.326282,171.816921,120.582278,-6.37783,-46.922152,19.592282,109.177925,127.430771,156.176246,140.807907,64.489109,48.534919,39.912824,12.374307,-66.863889,-70.668395,-48.544347,-84.660381,-159.583913,-277.680088,-254.860847,-142.458666,-138.454552,-122.844154,-66.815978,-98.646979,-226.714156,-232.822976,-78.489401,11.338634,60.126304,49.13246,58.775635,29.982194,-11.380932,-93.754542,-111.062381,-39.627428,92.350476,123.179253,105.762649,91.10243,73.711081,38.313747,-55.582439,-33.265975,202.433847,379.846722,325.100525,1.54906,-146.106421,-267.227777,-267.25498,-263.402109,-303.065659,-303.689743,-249.531096,-226.686888,-227.126082,-246.361286,-291.470254,-276.928411,-139.826456,-48.92922,-61.937952,-87.488211,-72.019947,-68.638074,-92.813904,-88.857834,-31.08218,-9.05645,24.815566,21.127283,-20.19579,-31.023898,-1.817852,6.92671,-35.097187,-45.263066,-18.992717,69.092706,99.556922,-23.57201,-155.828694,-246.633121,-80.342975,-7.436275,52.190932,34.034374,-103.64106,-165.584689,-143.245829,-88.864784,1.980967,95.594575,116.24257,22.204562,-60.841738,-210.720239,-251.612883,-216.157848,-118.050975,-59.562003,85.754635,138.621867,173.270229,187.951887,211.90198,193.269515,164.603959,267.706567,320.917163,296.03513,254.746746,225.72566,230.545698,290.36526,345.104111,334.725294,279.946451,227.731561,93.163809,54.478525,90.3989,159.917514,366.724663,489.316326,446.675751,212.838466,98.925047,35.14108,63.406493,76.671955,96.058106,153.678764,213.166408,173.008365,123.529717,169.787283,270.739166,265.087916,213.462514,249.780974,257.839186,144.871089,52.059795,-89.047776,-86.435567,117.234957,294.515965,294.270205,226.668271,197.43334,124.266403,84.070772,78.862795,103.072004,94.33083,162.007317,255.420804,333.947941,284.097569,210.984909,245.587016,273.38977,142.77676,115.475639,210.620539,270.873617,243.508415,157.451423,69.232111,119.882162,266.722138,355.047459,395.953976,485.291914,489.600499,321.315235,209.826928,198.029752,348.964865,359.470137,248.334972,195.878977,157.579351,149.612328,157.416316,177.275532,239.817267,338.690666,341.028574,183.425178,109.777352,115.833804,146.702447,191.311651,270.832867,317.571026,386.993776,408.272452,387.137948,325.903598,220.309983,222.951519:-81.372434,-8.45416,18.240265,37.069804,21.679726,-38.097203,-60.120915,-59.629093,-5.375808,43.955704,122.992719,108.888583,-13.475518,-79.241748,-150.397226,-150.220214,-88.251548,-0.747535,-1.947701,-104.418427,-165.29951,-272.643547,-306.139428,-280.273736,-166.139511,-81.399293,86.986031,97.498058,-104.366025,-237.749017,-260.833664,-158.271362,-37.469134,-34.061131,-22.039553,-77.149397,-148.103987,-236.910889,-229.330175,-155.306224,-74.438078,-43.701918,-85.947142,-160.55481,-270.487154,-280.385312,-267.112047,-246.765974,-136.823592,2.671957,20.701749,-55.701325,-94.652949,-159.810056,-220.619884,-277.527732,-63.121672,57.034434,91.129911,46.036835,61.246631,116.900483,142.47316,112.260128,122.715098,165.099662,114.970952,-35.751752,-55.444335,-44.434756,-59.550444,-79.752372,-31.365567,-7.423074,-53.03752,-115.507054,-216.648125,-246.900573,-291.283088,-289.681251,-217.210258,-223.24714,-291.275447,-376.561339,-351.877743,-266.381998,-241.790216,-242.958336,-166.0598,-95.45966,-108.38087,-186.275639,-266.192217,-239.168814,-132.993328,-103.436964,-92.083817,-57.25208,-48.224369,-15.122017,4.900411,-54.880366,-86.86876,-29.541953,43.016832,73.215179,102.000295,65.464817,-79.589543,-128.592707,-79.86455,-9.615832,42.317201,-34.672101,-31.974059,47.299538,49.367533,-51.232429,-66.350165,28.755108,23.087509,-4.286203,-8.621501,-15.132943,-44.902369,-60.867807,-45.240679,16.980711,145.781128,159.505558,150.837465,117.846775,101.1333,89.711418,78.887384,33.098892,89.866292,193.124985,302.879917,216.321049,-76.940436,-172.987813,-183.774196,-127.616504,-42.566406,-113.87767,-133.368981,11.651058,78.590296,-21.384447,-100.537899,-45.292068,91.637662,96.756896,93.681508,116.366816,106.442052,42.759224,-72.628462,-51.305454,103.386981,218.178648,246.293134,185.042221,68.761597,-140.558867,-121.236955,91.035629,219.924343,226.279682,170.071223,127.206383,63.401342,51.16478,52.996942,57.333678,132.100203,280.538781,302.825728,234.027626,184.889892,57.403736,-23.605738,-115.543961,-34.660581,-6.64965,-56.026487,-76.171195,-127.093918,-188.505903,-191.0408,-88.146965,137.35598,227.579846,208.544466,56.180884,-30.031967,-124.979817,-106.585849,26.000918,85.519106,73.123486,10.57221,-23.267898,-51.57415,-53.005329,-67.065612,-59.939066,-1.488289,25.579309,4.585834,-133.57835,-234.503533,-328.854384,-261.128488,-93.602691,-215.466324,-264.790907,-97.317199,-12.760967,-123.1942,-202.4628,-87.648865,43.900462,139.999859,22.958473,-32.6718,-92.299477,-111.314652,-156.982348,-184.440545,-161.943353,12.691448,82.332942,75.430232,48.60438,83.023296,107.050478,41.643939,-13.11628,36.360587,224.647624,200.932379,-100.761436,-237.379297,-328.28118,-310.61123,-273.598985,-303.023903,-271.173697,-175.049097,-221.197455,-408.466246,-438.162664,-363.373693,-299.605384,-145.39101,-41.05711,-41.51016,-63.717478,-58.023937,-80.314413,-115.37579,-124.729811,-41.359778,0.134255,14.488675,-24.21432,-96.692943,-101.148844,-76.261124,-50.478847,36.166865,103.754246,91.809457,29.245853,21.374544,-18.055136,-74.603354,-120.550537,9.178224,95.47185,186.296144,151.018763,-28.351561,-79.69724,-1.069231,54.37373,51.383104,28.022988,28.987075,24.954154,7.20921,-90.003829,-119.690071,-77.059267,-10.828422,47.857066,199.263162,245.004297,268.91399,261.138917,198.42515,163.254854,178.084057,247.628637,253.887609,207.020274,195.990336,251.079819,270.7393,263.455829,281.472038,275.191646,209.511068,161.747476,44.136818,16.813205,186.537524,310.29132,357.183072,402.054807,468.137212,370.669888,213.679772,36.964894,48.66885,97.586656,149.326295,188.637601,225.764771,189.396427,90.541368,106.728277,232.675788,258.200712,223.326038,240.373711,248.364461,179.438474,121.232937,-38.005059,-115.923447,-84.759919,146.335164,224.742862,209.508435,133.102499,-63.736069,-116.551337,-29.723966,54.487908,96.532259,100.099434,139.239213,150.94768,108.779284,67.378436,100.991752,156.623778,111.931253,100.781587,160.988914,206.511531,134.962258,1.603478,-138.832606,-42.351472,268.704651,344.136274,337.172595,388.634029,395.186415,244.179221,156.478591,186.760975,347.551287,384.151053,362.694995,330.372812,225.606887,174.060361,211.157501,281.469829,353.80932,319.446572,272.924034,194.825004,206.130501,206.74449,135.361466,58.282478,283.554259,379.069198,379.816227,357.108414,315.625302,255.606804,141.078907,148.52497:-14.372105,168.89738,215.084798,173.916958,116.780187,48.9973,52.58788,77.772314,109.140188,156.292899,270.932849,274.592201,164.187506,97.082314,3.914947,-10.619037,-11.99363,-4.263167,-5.286889,-103.570863,-190.800381,-334.502384,-362.926446,-283.318252,-124.11992,-85.008352,-63.342935,-45.568224,-21.020751,-50.53753,-155.882045,-184.423589,-203.91483,-202.965968,-182.503095,-206.929779,-274.733123,-391.099232,-394.16828,-293.349914,-192.123028,-193.527193,-255.08002,-272.031606,-275.631664,-285.862324,-313.847379,-298.503326,-191.622913,-113.838215,-98.995859,-92.989249,-109.050135,-205.493094,-262.615994,-288.477422,-152.482926,-28.023208,186.044136,212.826758,172.930219,134.865991,-5.292914,-47.964818,86.602769,249.02733,239.763208,160.938785,142.161421,65.420459,-10.763574,-74.657558,47.377274,90.89533,42.235588,-26.846149,-202.904836,-292.290354,-402.763382,-407.896328,-337.202411,-233.572453,-206.123012,-231.636421,-263.811326,-308.91358,-318.725139,-311.317085,-221.247732,-161.880604,-119.300969,-140.474228,-188.170494,-213.47991,-287.1661,-295.726216,-174.43765,-5.878456,33.033105,74.0078,95.665031,55.922751,5.202404,4.001614,121.065834,161.646531,137.677169,86.287064,-26.136229,-78.500025,-124.854224,-89.593391,12.462701,13.000916,18.579823,86.30185,101.367854,82.667509,100.141681,186.98229,171.615031,124.912696,52.693624,43.384708,57.451472,49.447801,26.993969,60.832492,179.515804,255.198301,270.183647,254.346464,229.323,129.720361,73.364775,56.449489,199.195249,291.171492,314.663151,218.140221,24.665106,-15.172426,-83.37323,-122.898854,-117.714225,-45.479084,5.876842,139.488982,159.720775,28.432912,-47.116764,-33.164508,71.815665,115.577355,230.809299,284.534582,297.502183,245.857645,98.606562,70.400276,158.491576,257.999367,265.391801,210.438893,160.128969,90.323969,93.07426,122.899169,148.06817,169.129292,195.065398,173.765104,104.988111,102.041351,153.983221,180.686318,239.17107,284.153156,272.711135,190.892457,133.886554,-27.15495,-103.789724,-106.253166,1.974717,32.895152,56.721412,56.840428,-17.992761,-82.040785,-82.544959,2.948622,185.752246,256.436685,245.464698,148.717779,82.017267,-32.427294,-29.643358,122.37467,219.144177,197.458257,124.677244,118.315273,147.539523,139.032497,60.193687,34.467569,43.608631,57.838239,46.24466,-10.870332,-39.14218,-94.144191,-118.083886,-143.150418,-176.438617,-172.600863,-70.275907,-31.266765,-116.186812,-191.310735,-210.314353,-147.308818,-14.903131,46.706621,57.791555,-1.199315,-73.195358,-225.090435,-255.39957,-162.850903,-23.307515,11.14799,35.725129,44.987116,60.246265,52.182418,20.291192,33.726124,178.499856,312.68433,279.886206,83.323763,-5.318083,-158.43987,-237.862857,-347.104481,-348.09788,-303.561082,-185.096047,-185.841236,-340.642728,-405.311367,-381.889491,-328.035872,-208.405641,-105.85624,-81.885076,-38.709898,20.755972,101.671357,47.183083,-80.45487,40.049464,123.533538,152.208918,100.629484,-11.254491,-32.77685,-26.862687,-24.659045,-34.968217,-2.444487,35.513512,54.043836,2.947877,-184.302381,-262.522802,-262.959461,-133.263155,-81.031369,-53.580904,-82.673955,-190.636077,-238.891186,-239.156978,-183.283475,-56.295883,29.676711,45.436742,-4.997026,-42.987053,-104.856335,-125.063229,-74.953016,39.48707,73.675397,105.78959,101.860406,76.096369,105.58496,261.3551,315.890776,278.305547,230.985065,262.63943,352.461706,382.800064,397.87396,369.497946,311.353295,299.140117,265.715661,163.625222,134.885381,104.021735,75.439646,63.814668,119.585869,284.973397,389.322349,383.727524,204.701297,63.781909,-114.72669,-108.298927,-9.198464,20.486223,1.93379,5.544312,24.40452,-0.786479,-30.751796,-32.329664,-5.182316,39.2737,48.473551,39.099448,-18.723539,-57.543526,-125.989626,-136.638653,-41.004148,96.940419,104.551416,-2.594231,-75.82781,-168.571983,-189.306932,-214.372749,-207.068927,-152.334945,-16.441115,75.207191,115.338291,48.790295,-54.696523,-48.485057,-22.612929,-14.531264,23.948476,152.04149,185.365393,81.705246,-13.416289,-44.299182,35.552355,171.802109,186.129439,183.157616,188.90951,198.130118,177.606937,137.511604,107.868218,204.012318,226.969014,139.190235,87.8891,78.066389,93.653796,127.013721,152.884381,229.174138,308.075075,301.219328,181.148444,141.049702,174.652873,181.151284,145.309255,235.436565,307.807843,377.183135,370.499177,345.416728,338.292734,319.917209,313.859083:-80.719594,23.321426,60.291257,50.357167,5.343648,-80.20299,-97.578059,-81.904905,30.605176,104.511337,151.726286,126.07783,59.369146,23.598059,-47.082243,-70.80315,-132.094056,-194.580748,-204.189541,-248.77893,-306.927154,-433.939768,-428.186672,-226.689326,-43.197036,-10.137919,15.605279,6.284175,-128.573714,-230.880616,-286.292715,-214.491,-116.399656,-137.6318,-142.15011,-248.275615,-344.542056,-426.386516,-387.705951,-243.06139,-98.693082,-50.487754,-74.938504,-136.793538,-235.206533,-254.244192,-283.662533,-291.684923,-204.764163,-18.233688,18.938962,-55.57389,-104.029289,-197.617056,-241.876822,-203.779984,-19.631412,60.524065,125.589726,131.502092,122.142048,84.019804,-17.281285,-26.07721,58.136387,93.090987,46.610763,-63.409333,-79.090203,-95.875848,-112.676338,-76.046584,27.731766,62.381118,55.319464,10.734557,-156.734591,-262.015474,-392.195477,-390.065777,-315.526924,-221.314078,-199.765772,-236.941215,-268.22142,-328.339487,-349.751557,-323.689927,-192.833006,-116.403069,-64.159469,-108.940935,-240.771438,-278.448673,-273.907126,-252.374707,-167.350239,-8.586,38.518364,19.885946,-22.955008,-89.708455,-62.921701,69.164781,107.02256,100.542076,84.738009,36.979672,-136.759606,-191.330491,-179.400268,-165.038425,-140.610367,-32.340193,8.773247,-18.637307,-53.935928,-89.805549,-75.432595,20.138878,126.792042,160.919587,135.89938,77.470072,-48.356959,-98.829398,-108.974703,-41.263171,149.678659,259.279377,266.883795,205.658067,158.425448,78.380321,61.239065,103.499175,208.422471,260.891812,259.535337,173.029215,-75.285699,-173.002654,-234.172611,-204.882166,-97.958159,-3.794518,30.81678,95.114576,85.563882,-84.06,-160.584769,-100.30719,55.013638,102.109969,161.047121,165.864653,101.223931,45.007512,20.125046,90.879886,273.675612,319.871659,303.126514,211.979262,126.671037,-18.065332,-11.486066,111.315142,187.049376,200.96165,182.626754,135.473185,18.390228,2.596611,88.525939,139.977323,216.410187,295.688953,302.687972,254.416703,213.605269,59.437113,-37.309637,-98.321876,75.596182,153.556632,147.033495,103.867439,-17.63095,-107.906504,-194.110726,-133.008274,71.285961,136.820056,116.096749,42.252083,-20.260579,-175.011756,-193.615588,-42.779499,99.999359,118.102772,109.066833,86.518216,7.231986,-36.578561,-89.476427,-68.887787,53.313231,155.471421,155.584825,11.758048,-98.257587,-209.404865,-167.544499,-26.621466,-54.742276,-81.884358,-27.773333,-0.031468,-51.95436,-83.033766,-31.248547,29.72843,104.686793,127.968696,130.299138,61.519024,2.438411,-95.34337,-114.645787,-48.858443,99.627611,170.424876,226.730763,194.714037,93.396881,61.118358,55.362047,88.412275,239.630292,350.66891,300.544033,64.770327,-34.301883,-189.15304,-241.373299,-229.114673,-223.639131,-240.689395,-250.313147,-263.76713,-364.557584,-444.374407,-483.311571,-382.997647,-114.771322,-2.465567,5.243577,2.102595,1.303731,-44.301107,-74.6361,-10.466086,177.791625,252.701883,279.710007,219.256606,44.090686,-8.712104,-13.636937,11.863926,105.181126,203.317225,183.033781,6.526085,-75.227458,-145.399121,-138.997885,-56.988275,74.748195,162.972682,277.598564,225.119241,-46.266098,-154.637354,-129.711712,-28.704583,95.952818,107.660262,144.129911,226.801402,203.174591,33.242823,-12.201782,75.126798,219.935337,288.717659,357.949255,331.213359,234.001832,198.419472,198.561585,247.676387,387.697554,440.594192,419.770429,346.962658,318.722903,262.828824,232.792525,251.55723,334.783634,346.996337,301.97596,270.203877,186.563451,123.922763,88.645189,151.397143,296.707626,406.532271,436.868804,273.750966,105.172421,-56.509815,4.079267,151.351089,126.488175,97.88116,88.2688,86.014246,43.131527,25.935441,46.53179,76.265573,136.995669,196.83169,218.185881,209.708076,165.619341,-22.249351,-109.726452,-99.656183,40.08364,82.123735,84.45721,37.627368,-123.435131,-181.362014,-155.418951,-97.116117,1.472493,97.943401,126.85943,60.011407,-3.75214,-49.409531,-15.890644,88.675206,126.986875,129.034133,160.921061,166.618296,66.082535,-10.685663,18.699461,145.755098,328.936706,267.625004,238.593045,236.319733,217.066268,119.437057,81.44605,61.131862,105.890153,178.821336,315.382879,299.146313,150.866509,106.23143,168.067665,250.697499,436.21052,502.35574,431.913467,223.264399,190.296166,240.710247,232.100103,166.898478,266.300817,327.35513,318.150162,292.941014,274.315627,230.712881,89.291597,75.188079:152.174417,346.667741,412.884547,382.855356,302.795922,173.5408,144.011956,99.092618,140.275078,210.413143,350.438228,364.834299,284.639632,233.831314,129.725688,74.484505,-22.129974,-40.913306,-31.038247,-136.529331,-241.898761,-375.604409,-390.396176,-332.181036,-137.356413,-35.089276,38.678879,-0.483963,-97.998629,-125.149586,-180.925701,-204.49765,-214.119751,-186.509128,-179.792144,-249.191528,-304.637591,-370.877869,-380.320706,-359.312108,-319.675555,-280.51943,-162.450142,-128.443346,-147.085761,-185.351512,-263.19342,-264.590652,-202.287491,-134.275874,-115.278146,-159.322914,-203.75403,-258.478241,-274.381988,-305.424854,-267.94521,-212.490167,-72.631195,-2.417644,123.658533,134.673177,10.704078,-28.964158,115.985044,333.51604,375.455621,340.970398,283.076644,142.897669,114.449207,191.405101,239.551503,201.426862,14.156757,-132.290292,-441.586651,-552.951293,-598.257814,-534.810245,-374.725931,-290.473782,-291.192911,-365.165638,-383.624972,-359.448802,-359.986678,-346.617874,-203.707651,-136.770765,-158.458403,-213.280615,-232.446884,-197.527783,-147.752366,-140.256659,-99.936326,4.225481,57.368483,139.964248,171.570262,158.418832,107.484709,52.993205,115.486453,138.153977,85.938617,7.61593,-175.672918,-238.73905,-279.314869,-268.872633,-218.52084,-114.806662,-39.238907,29.137638,-17.346382,-113.058781,-67.115319,158.048436,229.871503,201.911225,171.867661,161.329328,76.179427,25.848007,-1.469252,19.183757,73.369444,141.713353,187.135359,261.95191,274.770252,224.833248,176.012433,108.648485,131.519617,173.318485,221.42038,188.359966,24.909075,-68.13103,-197.264478,-222.545163,-165.957193,-6.930171,56.360614,101.117169,88.755517,0.67979,-53.729622,-94.477442,-3.190157,76.299241,233.257117,287.787704,310.095118,256.302841,93.782623,77.151133,182.568334,214.219674,192.992428,191.317124,220.063965,253.864725,225.072886,63.598538,-80.919284,-76.540553,39.168519,85.809225,93.38309,72.88037,42.956389,51.37868,126.313785,119.253781,43.969538,-78.564426,-81.743989,-106.12989,-147.004841,-147.631464,-2.079737,85.013173,138.74853,73.539336,-99.415924,-138.081404,-86.731862,-7.578576,170.101939,235.361021,226.550851,116.312714,24.303429,-61.152412,-5.21914,170.714266,163.622436,134.405199,142.205673,128.942529,36.04658,9.686637,59.66648,123.075516,220.805389,170.083041,135.12564,127.35997,135.34215,143.781087,136.762327,66.618462,-4.132516,3.08028,90.193995,130.127966,83.661569,-4.580365,-132.680036,-111.137594,16.40462,38.810121,6.966324,-52.093881,-73.750323,-192.968029,-289.109399,-347.006418,-173.070999,-94.777724,-27.104208,-8.704497,21.355707,26.952356,67.44395,119.977166,252.28069,359.134898,355.012445,189.906969,67.381422,-177.593676,-263.441155,-271.735931,-151.949818,-101.302528,-80.798963,-121.346612,-214.184172,-228.755524,-224.061521,-209.569189,-129.622539,-11.467498,30.581102,37.874964,31.342405,3.887402,-61.925906,-201.386826,-106.816627,1.967602,134.578998,99.905725,-63.589944,-86.349687,4.03869,38.090668,26.643152,57.161617,104.106283,86.648582,-16.569944,-253.13492,-322.705256,-365.3889,-342.528462,-301.760589,-188.119054,-166.654121,-237.701035,-278.466426,-268.760186,-233.063115,-129.802803,30.664783,88.284734,62.838613,2.928437,-100.432363,-121.197513,-67.043105,89.889497,144.507028,94.36734,12.029085,-75.895438,-27.74039,175.0805,251.076226,253.768731,193.366135,200.937289,281.899512,334.461854,380.777592,357.107128,311.460758,306.298005,277.399386,169.355897,115.304808,15.257367,-24.101504,-6.105314,56.599017,207.780788,326.839959,332.725351,159.362159,41.385704,-57.012744,-42.723571,26.55462,126.397413,159.011796,132.496179,88.618026,14.877124,5.596496,34.237837,45.996193,-4.794585,-148.045966,-207.006259,-201.363135,-132.287236,-16.518245,-34.397414,-75.444708,34.101899,58.131122,-34.999288,-102.568771,-206.766978,-250.173153,-293.574963,-253.933766,-75.225051,70.124473,116.068822,148.607644,115.524899,4.689086,-14.537831,10.466656,-3.521329,24.007133,196.106394,251.469584,145.630078,38.516679,-32.923579,24.76065,161.002053,207.531256,196.568545,127.98446,112.58506,157.521116,170.447518,132.484546,121.609743,125.275202,65.171198,7.780895,-39.167311,-17.795351,50.663694,112.498817,255.091339,231.632281,172.25864,93.020685,102.172248,159.98049,176.109568,230.118641,315.934095,343.857565,370.672892,362.46178,314.675406,291.660227,240.822582,208.101588:25.039899,176.275037,215.057319,168.994111,112.786273,33.733604,23.296124,35.300241,77.025008,122.744045,205.642528,201.468262,114.55339,51.795598,-78.02875,-110.870869,-94.313908,-32.807912,-25.249087,-164.986309,-286.644848,-455.814781,-451.620592,-271.517005,-52.296419,14.040677,33.85058,-11.829024,-175.077987,-250.323755,-282.767023,-235.61432,-122.233629,-81.766653,-102.65167,-238.367811,-321.045066,-445.153704,-475.096476,-397.587449,-190.817283,-120.072404,-143.470486,-211.636928,-310.061399,-313.933866,-289.801145,-269.778745,-184.997705,-108.169068,-116.804732,-216.585289,-254.666734,-263.452871,-254.388252,-203.5729,-115.604227,-60.950916,51.028487,79.217296,51.160693,-1.366474,-116.31547,-104.860127,106.31951,266.589972,254.032306,146.606645,93.012244,-5.501003,-39.422479,1.704626,125.97761,145.293754,59.722157,-37.414591,-292.4363,-387.918412,-410.204602,-357.402534,-226.461644,-139.777384,-148.925724,-283.704718,-355.452349,-419.689208,-411.649647,-296.38149,-98.164428,-35.739851,-88.601392,-173.301072,-286.850784,-298.204269,-269.281665,-215.961982,-19.781327,156.056764,171.710734,78.295572,29.089945,-14.939035,-14.235696,56.375126,163.149039,181.124435,91.141164,-2.743309,-220.778324,-318.137631,-360.31289,-269.550004,-41.224958,-0.98444,-15.866847,-32.791243,-56.042844,-128.180004,-117.684848,47.311062,188.564589,209.080685,198.93196,158.750825,1.437521,-64.190964,-43.523002,19.802028,145.146537,309.961247,370.897521,328.415398,267.289998,175.86554,153.759576,170.551394,245.892391,288.414573,256.212087,163.513822,-29.05375,-99.350758,-198.257959,-204.365781,-122.111803,-27.21962,-2.32628,1.302642,-30.154188,-168.568448,-207.576279,-89.357484,43.882936,73.326921,176.276094,225.347836,206.172246,155.452657,111.074137,144.445584,246.587503,280.393756,264.459163,221.058167,202.170963,110.566685,61.018837,78.873019,184.141191,220.133324,243.58223,232.917247,150.65683,102.163603,117.105755,188.181722,337.048259,357.392915,310.490116,174.195721,116.917911,4.741346,-48.250411,-42.983886,99.893744,157.952926,143.410701,68.34971,-129.696831,-183.314881,-86.398938,32.419459,217.058469,236.46124,203.926686,56.010937,-38.745567,-126.515467,-90.20382,46.721138,90.839154,86.222144,90.528789,82.575542,15.687299,-29.869091,-51.919951,6.0414,195.229521,291.060576,263.402321,107.242073,26.158864,-89.643175,-110.137509,-52.570132,1.863334,14.455289,65.760393,73.62304,-43.392494,-138.626137,-196.005239,-121.39722,84.43295,211.683502,228.848305,97.807157,-29.148709,-228.992893,-257.053722,-184.342714,-29.658796,33.543952,66.078058,46.153472,24.180291,33.643501,79.70665,134.067088,330.014384,447.512157,389.153463,140.407272,22.356507,-164.287484,-210.570651,-163.190603,-98.319097,-98.170805,-142.913105,-191.368867,-319.232386,-383.030323,-458.876256,-431.264671,-218.948776,3.759223,51.207944,41.232244,25.293339,8.514244,-0.504287,8.959743,114.251113,187.309815,225.304833,148.531791,-39.267972,-72.5698,-76.986896,-77.177185,-26.286176,111.400372,166.172234,111.815003,4.155223,-231.141216,-296.635905,-263.978447,-46.312186,75.546657,126.650287,37.312181,-186.496642,-259.454512,-268.853793,-204.732065,-19.901966,116.791962,139.584766,108.6383,70.555692,-43.632658,-78.547778,24.557818,232.514011,299.636747,302.42693,237.278903,65.926091,34.156835,156.280186,250.060483,350.582281,391.289716,399.263061,347.364511,311.107622,269.926248,255.702893,276.97686,346.824816,338.529366,217.146814,147.000747,41.986015,4.421039,24.733036,107.223679,302.809623,408.514783,409.318715,253.66162,131.043367,-60.784368,-95.360802,-17.183336,138.180454,177.775315,124.926495,48.152686,-92.322421,-115.887034,-89.648473,-51.229025,71.046375,138.07717,136.300344,91.841734,44.139717,-98.9776,-172.4647,-200.581403,-41.118382,35.43363,52.051026,-12.328939,-211.635319,-304.052319,-364.329015,-305.696034,-99.625092,105.732119,178.73867,159.28964,82.909066,-27.407505,-31.501774,-7.33051,60.787921,127.363735,225.974333,204.613805,19.91761,-80.263006,-94.650601,2.296843,157.957739,152.237767,165.053402,171.075351,120.594563,-4.231808,-27.939187,46.803202,184.303811,218.398807,236.112749,236.997482,140.587673,45.040374,-17.043443,79.470651,380.939227,505.166713,465.485953,317.546954,281.028399,273.206123,242.677769,199.055986,360.587065,442.241889,397.9119,300.260408,148.796719,123.859209,140.41371,162.240687:174.63202,336.237835,366.421785,326.662244,293.179222,235.195869,221.416374,242.842113,274.876655,301.164991,372.364025,376.008277,342.640923,327.5715,212.928675,116.914285,-38.252361,-111.331313,-131.748492,-209.092223,-257.979313,-265.378685,-221.474758,-123.321239,-44.480105,-0.467335,95.92532,128.255949,125.663204,87.109059,-35.583658,-73.939014,-78.755478,-140.970679,-191.712785,-227.22394,-206.126186,-180.377637,-197.645155,-221.796943,-199.18478,-158.913103,25.678783,122.324109,139.844625,56.142306,-86.067777,-71.845231,41.491411,40.720479,-17.326841,-174.47478,-231.950154,-241.907625,-218.744946,-164.489675,-111.856289,-91.170557,-15.500746,27.561812,68.886627,56.104812,6.516022,38.47335,248.280333,418.572024,437.893663,391.841805,357.987252,280.160919,231.236637,175.035789,188.702666,184.808908,74.086649,-37.330455,-271.5257,-371.466236,-532.031333,-545.867963,-423.755366,-384.022622,-412.029226,-400.252268,-359.785552,-346.517087,-375.222813,-359.107537,-248.085626,-205.867003,-208.944843,-247.559514,-283.672651,-252.476685,-135.829028,-71.643876,65.888982,235.104607,285.532638,247.451599,221.814732,217.093418,187.959531,81.053643,9.586933,-5.409304,-15.760189,-38.054534,-145.415332,-213.917231,-304.85757,-299.392542,-227.676458,-155.200021,-109.563186,-76.752479,-107.59459,-119.296976,-58.060429,121.687479,203.169366,193.247321,176.604342,191.128186,182.926278,116.531521,-57.477616,-81.542823,7.04225,148.940656,230.697154,352.904356,360.903935,255.322728,175.000494,98.639539,117.765469,104.695675,10.59327,-39.447829,-91.472744,-121.801848,-250.180992,-300.166579,-263.211161,-161.197511,-110.630202,-6.914809,27.694455,38.364009,33.534593,53.321084,98.982883,145.948028,278.040667,321.684369,318.214239,285.752842,223.0128,218.659522,241.033228,247.497898,259.501864,300.395258,302.511944,223.640847,148.556746,-14.573796,-100.487147,-76.666306,43.790333,68.639898,26.611909,0.91252,-16.810872,1.28994,76.154698,74.442381,38.474422,-1.208734,0.802664,-46.49648,-94.235143,-115.691379,-33.017659,17.51474,56.401233,17.169663,-100.619428,-137.553161,-160.269429,-135.707766,-6.460292,86.207839,83.176843,15.02475,-35.503304,-121.798382,-120.566377,3.076755,68.90513,21.548729,-108.488667,-134.286905,-102.819182,-72.330359,17.470059,87.309603,208.436481,286.176388,330.069636,365.514228,358.101083,365.525872,368.448996,295.315637,145.90514,105.312249,128.525802,136.377443,79.354682,40.482507,21.746009,46.730682,115.505509,183.710148,177.478865,42.265101,-42.152033,-174.610051,-215.829098,-225.72667,-209.420152,-213.771579,-164.634647,-106.080269,-28.894003,-23.593593,-15.34149,12.917138,122.509212,174.294341,128.528237,-51.658501,-113.110569,-118.259836,-110.85574,-77.046346,66.145906,125.121692,117.713389,76.664879,33.778282,27.333452,-29.783084,-51.173056,62.778726,222.293003,218.45774,157.217331,162.198059,135.138013,65.507781,-9.319398,96.625826,147.310211,184.876365,182.721757,170.423193,161.150317,117.756743,101.855497,97.23143,96.047748,123.604042,187.293484,135.637828,-169.710002,-297.434512,-298.724906,-224.347387,-226.008658,-221.515256,-211.538963,-206.127328,-227.188479,-301.377327,-300.316487,-161.195484,51.465403,121.507108,115.567271,46.098157,-117.186415,-140.543896,-27.88627,89.935431,94.477053,-33.480183,-149.867051,-260.923866,-182.870637,64.987118,136.896736,152.9338,129.758531,147.021594,201.69386,202.01345,128.701129,91.981709,116.370106,216.469326,243.106456,149.560403,36.695794,-108.006921,-87.822208,22.882778,68.456014,138.454222,181.968792,202.242398,181.534465,118.470999,-2.633322,-20.902136,5.377835,84.642109,137.819294,152.727278,81.849388,-83.688511,-126.447986,-148.536972,-138.68056,-150.424902,-306.720537,-390.3429,-411.322635,-343.78345,-193.384375,-165.392234,-178.926121,-217.03929,-246.138848,-294.982817,-310.490878,-375.331454,-419.687418,-429.198431,-375.492669,-239.366122,-181.903628,-180.473146,-240.470752,-289.607162,-281.390633,-200.990213,-53.370971,-56.475709,-55.753817,19.797742,32.006056,-83.089181,-162.083369,-234.058918,-208.939664,-90.701646,3.832893,16.286051,-27.900164,-41.69698,-6.305135,19.962136,70.041954,80.568033,51.849326,-57.286658,-107.181322,-103.703046,-57.598863,13.858821,34.591614,95.513478,80.853093,17.721847,-64.038358,-37.906229,47.775523,72.825451,133.086757,224.07068,255.098775,266.239752,236.485238,118.376957,67.901743,44.720186,59.062363:199.059445,402.291038,447.54467,480.584564,475.182786,350.741336,261.395481,210.760432,338.286991,416.663286,483.079946,460.823809,433.352312,418.539843,257.709755,147.4163,19.62815,26.883384,48.485818,4.64123,-64.644586,-158.568656,-153.568708,-76.558643,46.406301,106.111008,144.774908,110.425564,-3.940573,-58.316077,-155.132288,-189.103691,-241.351855,-264.567737,-240.357128,-185.159404,-176.548751,-231.532476,-309.810459,-457.432751,-423.194273,-340.285126,-148.22456,-93.009234,-107.533764,-138.142186,-141.753433,-104.926432,-9.170381,55.692551,60.282415,-12.525703,-74.452692,-176.432052,-189.461419,-138.470636,-104.430252,-105.368803,-63.077298,-19.940982,37.273466,14.569806,-101.145101,-100.503399,117.141446,320.449139,312.096839,229.699081,259.288269,334.088301,274.005652,26.132261,-119.763976,-124.629552,-123.055236,-173.999131,-362.90964,-472.556787,-649.812889,-651.737295,-444.137821,-241.49189,-241.59386,-396.169854,-456.423913,-450.859863,-432.328578,-360.52837,-191.875477,-149.704671,-200.394694,-219.101707,-175.482779,-166.214568,-196.075256,-177.551124,-47.567544,31.987657,46.295586,101.80497,131.39459,80.190749,3.815465,-69.423902,-0.429707,18.93676,-15.990276,-51.094546,-128.910739,-172.381504,-234.401768,-228.217255,-142.767487,34.314481,141.843288,212.897184,161.826767,74.197524,92.831645,215.266428,272.369185,261.545082,260.183551,277.438524,272.853148,231.086762,118.467368,95.877708,134.552907,229.42853,302.967467,392.981623,375.692425,290.213702,253.113175,194.553397,113.507223,64.028594,17.011848,13.241364,-37.980631,-87.953865,-183.781055,-200.598659,-153.842985,-83.086064,-48.867279,23.884393,70.021562,154.151902,150.792329,34.925889,8.53724,91.423139,275.431937,321.41151,365.978764,362.025112,261.680816,198.371814,130.201714,138.064886,172.161927,262.637171,272.834261,180.290556,122.469288,71.092575,15.654471,-17.308005,-3.326808,34.825336,104.95731,113.302503,28.727522,-32.604317,-48.25238,58.26362,80.031397,6.76796,-35.12341,-67.903215,-73.070458,-34.085619,54.005786,90.804092,168.401479,194.732502,149.11216,100.732988,100.369358,149.869316,197.668601,150.359034,122.235089,50.73064,25.980543,30.903358,48.920982,93.842884,49.387563,4.009654,-29.120079,-24.487949,-5.051277,20.968387,97.188578,134.239222,239.549432,319.991035,288.044775,141.786444,122.591989,232.247507,259.054411,153.618662,60.724527,78.08265,157.768357,161.920102,69.778681,1.229942,-76.809642,-52.717546,55.620352,62.809787,16.014753,-107.424597,-133.145225,-92.35716,-87.203757,-91.865564,-20.115458,11.20158,49.533348,62.419435,28.095044,-27.978739,-65.401259,22.234786,266.534232,296.030701,222.49776,14.453561,-60.530373,-138.83337,-180.231238,-213.225399,-68.467029,19.476698,76.876702,59.172384,51.085101,55.158518,-9.648408,-51.166768,-18.326965,102.711726,121.196041,79.854496,79.547938,115.658276,92.01113,18.221577,96.382627,157.841692,180.909548,124.67293,-9.298421,-37.307882,-44.488484,-45.691792,-33.056857,22.737794,55.958941,72.829798,29.004975,-198.620004,-337.946719,-495.28682,-463.561691,-402.910278,-268.64326,-222.293094,-198.877659,-236.548108,-372.587242,-405.89996,-325.514742,-137.663857,-54.505123,-31.329763,-97.681781,-298.761992,-369.676236,-295.594739,-99.375359,-73.740697,-168.770667,-238.659116,-280.546952,-208.165425,29.882798,111.413925,145.782987,143.036463,159.960532,229.524655,280.677138,288.964591,207.680817,62.42916,96.816283,126.904299,101.392204,46.755561,-32.995774,-39.690665,-57.561535,-63.583553,-26.911381,27.415273,33.410479,-0.367761,1.167022,87.480489,116.135049,70.252487,119.568839,218.369929,288.064049,187.187557,-54.516007,-97.164467,-89.056293,-97.785933,-190.290332,-311.385088,-326.828518,-270.427699,-237.432095,-211.909012,-211.440344,-187.620719,-154.109307,-149.558281,-165.772,-186.352023,-259.533928,-315.929509,-426.958918,-428.620859,-308.851141,-183.868981,-151.054618,-161.244331,-197.949985,-247.163914,-220.269188,-114.88735,-57.251618,-10.763016,119.226132,135.909462,-4.256223,-110.798574,-211.177675,-187.142293,-61.608767,53.127794,63.819272,9.005124,-15.875683,-16.401148,-0.388004,84.024384,179.845036,183.985433,99.294353,48.721946,24.69313,38.890931,63.24667,81.53348,109.93384,39.431384,-15.872861,-75.892509,-78.202868,-33.460857,13.481557,116.875986,217.882403,266.810687,314.727812,312.873356,318.952494,318.743312,211.270231,113.288859:131.074587,192.635309,171.130802,91.183496,77.650368,121.86737,142.434657,148.055383,122.571178,118.288158,166.097941,181.647377,165.442593,157.86536,111.721306,58.454354,-16.170778,3.27482,-32.044798,-252.800964,-349.198581,-354.696885,-284.691146,-118.664009,-6.320677,49.041523,136.84627,107.819649,-60.635081,-120.903275,-169.403611,-171.820398,-134.139738,-111.207048,-130.154198,-247.980551,-309.316439,-301.030544,-236.916789,-110.721114,-71.62441,-50.639029,31.10458,32.156009,-52.618084,-67.320385,-39.883278,-26.67731,11.627753,-3.672371,-51.711693,-161.440409,-205.736235,-290.907242,-320.38718,-270.410499,-137.40417,-98.288111,-24.228914,28.121089,79.00871,62.258181,7.346086,-6.383451,65.430441,260.04486,331.775001,303.811774,240.595316,176.427065,168.963717,158.498559,161.408889,155.012247,97.719454,32.069237,-164.570351,-275.043303,-443.985023,-465.324013,-391.143511,-305.913695,-276.663535,-277.790226,-321.55572,-375.37933,-336.086779,-188.577587,-73.538523,-27.808479,-20.687231,-80.022268,-185.616708,-174.960086,-47.910134,16.808523,50.321078,63.284073,110.223031,190.402894,186.217769,134.591507,109.251501,82.148585,101.40078,109.358535,73.458939,30.624156,-115.325019,-208.376793,-299.983443,-281.657455,-216.230069,-120.761251,-74.306047,-97.184164,-157.383201,-216.748763,-164.089886,71.264996,229.753654,234.585158,208.430014,180.742649,79.846299,52.982732,86.880337,125.197271,194.283348,249.368871,286.778414,323.642987,298.859203,198.882617,163.560509,174.528362,211.948986,215.945844,145.756184,59.321397,-83.04639,-95.708042,-88.249667,-84.35254,-24.017526,14.05241,-9.891762,-12.179776,38.277082,105.177858,97.614926,80.448217,104.229791,135.349569,225.474994,269.287163,319.766909,300.707906,200.331848,192.461348,302.985059,401.761598,429.413262,436.87103,404.325184,254.853447,158.563775,43.347997,54.008156,80.949999,160.857694,178.623593,122.906612,104.48624,166.530335,210.253535,259.810735,234.527219,183.034112,70.715042,35.697326,-25.478003,-50.574819,-38.894009,35.021265,80.910736,120.303309,81.948625,-44.673935,-84.467793,-71.620945,-15.007655,147.342419,215.203967,173.828162,0.159959,-62.556813,-50.961027,-7.29293,109.73687,223.820182,231.996483,134.155236,64.438785,-39.11802,-49.707227,24.479363,92.473034,238.365959,305.154825,300.042943,255.200772,237.506648,207.664844,183.181354,133.931406,78.739687,61.509023,121.031331,163.220823,132.588898,54.584801,-70.83005,-47.81432,88.663431,135.547499,113.555251,19.117845,-31.790811,-131.586924,-183.53949,-228.731812,-154.847962,-102.888652,-13.017941,8.134944,-20.917665,-39.427225,27.220046,109.332721,216.121219,189.16109,173.589636,122.339461,65.884155,-67.953035,-111.987185,-103.584595,-12.59589,33.580996,71.137488,29.583845,-159.183467,-244.027342,-270.251609,-195.445171,52.994,125.493512,77.349518,32.102534,56.802378,57.33381,-1.976883,-80.498435,58.38322,138.404593,144.835188,83.663398,-21.641891,-39.715414,-25.096614,5.664884,54.42937,51.820181,61.352152,67.028885,17.188502,-179.337665,-277.452364,-362.015074,-262.461568,-205.567109,-192.140155,-221.959609,-316.517903,-376.197288,-402.182783,-316.529775,-60.834671,35.808997,23.950726,33.396485,55.656107,7.88214,-38.882683,-3.915354,100.06059,99.124007,-5.911242,-84.09654,-166.244371,-126.099443,19.385226,68.374294,107.683251,90.899674,103.902075,206.143392,243.582555,203.867704,163.676119,164.711812,192.000551,170.207676,97.718239,57.336344,-34.26727,-56.356848,1.939883,52.605132,126.219805,272.52633,351.248161,278.820246,127.324491,-129.924214,-147.19096,11.669554,140.74226,128.004752,32.960589,-19.081694,-140.076862,-188.395199,-171.618721,-114.952147,-61.100588,-167.694388,-207.644568,-186.230468,-168.992203,-184.644211,-204.610794,-208.502043,-145.481597,-138.44809,-257.191641,-349.055446,-446.679002,-432.728381,-326.469924,-264.022128,-209.546413,-167.944829,-115.015407,-66.769129,-92.978575,-134.985284,-129.11961,-107.46546,-84.873008,-48.487445,42.862141,52.134236,-10.285887,-53.629197,-107.946938,-96.852164,-22.212721,15.55787,8.839342,-16.120696,-16.019205,-34.146315,-63.457837,-60.564128,36.147291,66.359589,33.28246,-23.071355,-105.700382,-84.903154,49.634334,128.112753,237.434889,214.421081,192.579683,204.399431,214.453675,194.55763,180.598197,209.197953,279.102565,319.96316,354.960769,287.116274,61.353911,17.213032,123.759613,198.27109:forward
82.793858,112.406372,127.171368,132.302457,107.077519,31.938227,20.437012,71.703186,142.734361,167.671296,113.462646,28.152347,-99.163826,-106.169905,-76.222797,-50.350483,14.898999,82.687731,122.538667,169.252619,148.996902,53.790833,21.460953,3.284008,6.722105,31.404336,61.61259,28.975477,-43.155327,-45.503965,-0.059774,47.840809,164.893366,164.967796,123.691797,64.510915,37.342311,-40.868316,-47.761122,14.574191,8.312966,-17.954483,-70.278778,-108.727992,-167.310689,-153.3386,-28.993261,34.114513,54.257904,29.883134,36.08222,47.574844,21.342471,-88.499612,-93.721099,96.35865,280.06357,307.272145,309.586213,309.493314,287.646029,255.044736,190.047208,153.577251,26.480916,-42.053284,-37.830135,-4.760062,21.62168,42.286724,32.139282,73.645689,191.179273,207.619322,106.165842,47.597492,35.126905,57.085194,106.698711,139.642545,221.614184,267.062057,223.229765,70.190875,29.363441,16.69082,20.672359,51.135499,136.614822,193.979496,274.2767,270.963019,144.07946,66.732094,58.695598,97.429145,87.771297,72.698769,67.867735,2.338743,-16.459635,19.440269,58.123759,134.177228,137.153754,125.955049,140.930393,136.701545,10.511789,-79.817314,-109.946898,-30.621412,124.375331,143.709971,122.046844,75.489633,61.900298,66.775034,102.674666,216.833246,292.245048,296.227175,215.733826,161.485323,103.672742,91.784416,109.22962,153.611077,252.426329,290.597434,310.956559,368.171541,381.677353,339.449409,290.635738,204.97115,190.121485,187.82958,142.32395,114.930418,85.864326,62.011186,-3.802863,-2.414424,101.224379,190.621829,176.770466,101.266633,92.38526,148.584968,187.091405,179.382145,82.541944,47.668693,-31.5002,-85.20802,-150.366303,-149.272251,-94.317026,-59.663243,-18.801446,86.0116,155.847693,183.570214,146.052649,78.133674,79.681171,179.110098,332.613643,384.059635,358.06969,295.020315,174.605641,131.015369,87.815205,91.212546,76.644602,15.98596,-10.203445,-51.077445,-76.532823,-161.723816,-204.20234,-228.710465,-159.901518,-108.691647,-87.388435,-115.936353,-106.741846,-58.698238,29.107826,58.2276,91.863593,69.973924,34.371989,-48.56407,-80.335626,-106.883308,-78.780209,36.063397,101.752111,100.87088,27.883651,-20.939448,-81.669119,-97.153994,-99.769239,-76.232412,35.842871,157.476022,158.047004,67.868513,38.035415,70.472309,126.280709,213.398397,184.028648,173.724661,162.129771,116.64985,-29.668038,-77.201927,-66.799449,-38.241936,58.681847,205.57157,225.037751,150.142328,107.481034,-1.26367,-64.267578,-88.410551,-52.376229,-52.107966,-43.370321,-35.941945,-70.023686,-102.410958,-103.62249,-69.090733,-13.832161,45.395992,81.919181,49.990472,-24.008541,-165.319251,-186.179268,-141.669041,-125.448575,-136.10169,-135.437074,-108.563352,-45.258957,-39.637397,-55.215286,-47.812798,-37.385687,-114.052433,-165.720584,-217.558891,-218.471556,-239.021385,-269.887947,-289.215606,-211.087563,-177.138871,-178.845541,-201.49906,-243.495874,-242.870293,-136.963734,-53.785126,-21.400046,-129.52893,-135.866298,-59.720368,-37.765834,-79.315073,-109.614966,-145.566208,-202.918111,-230.1261,-231.855076,-212.436624,-184.39515,-182.073493,-131.245094,-74.141977,3.741675,-12.71899,-34.520763,-62.180583,-49.70527,20.268947,49.644713,58.843622,1.875015,-27.728607,-28.327667,9.374774,145.366545,198.054439,237.259352,266.428917,375.38247,442.227238,403.840702,248.996423,192.801611,119.295348,107.587054,170.51191,166.195042,98.342125,-22.829049,-14.200649,93.453674,108.246613,1.697324,-52.768896,-21.920306,63.009445,37.64423,-70.819659,-83.977566,-71.898962,-103.931522,-237.69495,-310.89825,-285.423477,-208.247669,-200.596287,-225.506712,-241.79803,-247.693146,-229.703167,-160.876497,-61.857843,-34.484345,-46.701185,-45.16489,30.421719,79.159586,125.271077,177.4658,226.331887,210.83019,137.045447,28.743627,7.872208,-42.739854,-63.639787,-29.12469,41.139561,20.394534,-124.491583,-187.986484,-214.787125,-185.418561,-103.61776,-71.960357,-76.503879,-139.176089,-203.68809,-345.846581,-390.709014,-349.351238,-278.431539,-169.47347,-107.739075,-100.74487,-215.222003,-321.126082,-501.468667,-525.345889,-419.379666,-245.863291,-187.707461,-193.096641,-227.28644,-256.520239,-239.899774,-128.345831,-64.192906,-9.412784,21.523609,43.33738,50.148248,44.384802,56.814306,74.794505,106.393182,141.132753,172.227758,193.885367,168.945004,104.88529,87.851806,94.235413,98.405797:17.843957,-59.11055,-94.098206,-99.613642,-87.910773,-74.020121,-53.315825,54.967917,147.309874,132.106131,-4.514561,-75.317935,-109.96186,-79.539727,-6.11375,23.082107,79.060455,143.920874,163.781931,143.802641,104.137216,15.499692,-0.54212,26.958206,59.275991,65.796491,36.563771,11.567618,-9.590704,-20.82166,-39.385624,-15.362488,84.874718,139.040315,122.198191,44.79498,4.982817,-42.801669,-40.657068,17.302368,130.84172,170.485815,114.442638,31.068901,-116.61753,-139.173772,-65.439265,-13.29392,41.42654,75.449523,76.966926,32.258154,6.133662,-28.187206,-21.685952,81.715839,233.730051,283.813903,273.637506,220.541151,109.513262,88.628483,88.287319,64.322592,-7.512079,-23.603743,-36.033884,-62.700466,-46.778082,-12.031393,-2.848196,69.815496,157.915026,167.992935,109.541931,52.358938,-35.203645,-28.142867,66.883882,114.205891,193.739004,264.905293,263.939664,136.583783,43.047175,-34.417971,-15.094621,12.01448,69.580563,134.146756,188.35233,144.904458,0.719167,-54.98772,-72.178447,-52.727961,-23.609989,38.022471,57.544719,36.824764,21.087842,-26.885128,-33.067339,71.481669,160.171607,171.575524,231.080301,247.954623,129.774038,52.401244,95.627703,194.992355,327.591271,336.686673,327.179081,290.697314,253.88558,176.425325,174.049957,231.345668,262.323708,272.625266,273.305185,250.611821,175.371647,136.065485,90.920827,99.321541,189.012823,336.473668,399.418176,435.851483,403.874436,300.045133,254.425633,219.905294,295.038817,330.823546,240.663544,126.092322,-37.989993,-53.110379,-45.759777,-45.950602,17.395542,94.101918,55.903945,-75.500468,-79.854316,59.27462,160.609799,265.878214,161.244327,95.510912,22.049696,-9.806189,-87.943022,-99.41672,-32.695945,6.960479,82.275107,186.631445,204.659052,142.677832,85.498405,46.280166,105.668013,277.409383,400.248398,441.047071,425.584678,367.725912,215.828328,145.742377,69.953768,70.948247,89.717435,57.389236,12.88041,-77.580226,-96.94556,-141.265043,-171.666103,-203.168766,-150.774089,-97.567911,-66.538503,-83.395236,-79.327209,-56.632827,-1.319253,31.407431,124.732374,161.187791,99.937063,-56.943821,-79.91765,-60.522916,-42.076226,29.07185,108.147612,117.212747,30.97241,-44.812574,-150.967515,-166.523255,-122.574093,-56.377186,89.177395,98.380552,49.66574,-37.635544,-58.070862,-81.361401,-77.346043,-26.580174,1.689302,-10.645598,-73.430974,-123.024231,-230.588179,-248.104388,-161.59644,-104.275213,-14.307055,123.419981,153.80489,43.572389,-32.797647,-134.799627,-167.400866,-127.333027,-13.014356,-27.070129,-168.122947,-216.70559,-223.033122,-193.38277,-88.278723,-33.587834,50.029685,92.431754,65.515438,-74.037873,-141.083692,-191.497318,-180.751955,-159.884367,-167.142662,-182.395134,-194.965048,-175.310871,-168.468642,-200.656015,-256.161973,-252.555139,-213.579702,-243.219703,-276.402655,-306.385765,-299.708717,-270.103372,-254.278065,-227.919113,-185.542862,-151.810878,-104.57584,-104.222354,-151.565436,-189.52465,-181.68192,-113.82327,11.331564,-18.560414,-76.373953,-196.240393,-224.934744,-195.544901,-168.442114,-183.11339,-248.851622,-265.089179,-277.153547,-276.138726,-265.302728,-260.755834,-195.797659,-135.979137,-20.14368,88.100299,115.276598,76.064769,38.060617,31.637925,69.991919,131.434386,97.083677,70.21808,13.738238,-5.367379,60.710907,142.952201,302.265196,347.834414,382.435422,402.248366,387.408752,276.57382,206.164582,123.805705,123.15968,156.517529,156.241658,136.755841,102.432932,95.476829,71.308203,54.946994,22.409917,-9.774488,-64.965622,-12.052916,24.4059,0.231809,-57.172501,-130.928338,-124.411809,-107.854796,-149.229405,-180.584754,-229.531122,-233.135165,-210.57713,-187.284128,-123.57403,-97.434493,-26.692281,79.958953,99.238775,20.508631,-27.864103,27.177437,117.568691,178.07757,123.879435,146.495514,143.708193,68.401555,-117.330424,-174.827392,-128.817053,-46.048379,70.44712,18.885676,-56.616442,-171.484026,-183.227825,-173.708079,-149.071967,-25.075535,40.064198,0.591322,-144.06739,-193.577718,-220.190707,-239.988771,-302.847391,-291.02794,-159.385642,-57.356067,-76.255183,-236.774071,-331.621732,-456.183951,-450.745066,-283.183158,-60.541085,2.437985,-81.671656,-183.213225,-233.134829,-182.641771,-122.482534,-128.448066,-106.894866,-6.658692,22.436697,-5.505778,-23.244095,3.147542,33.589376,100.036632,192.135525,229.779185,225.479765,195.176085,125.438031,88.022303,59.691936,78.56761:-47.734434,-16.657986,-78.30488,-176.772034,-156.296384,-91.605834,-83.823452,-23.439128,89.148701,78.72322,-74.79249,-139.094461,-159.158125,-133.321177,-63.90956,-36.795097,20.882645,114.085691,142.997246,93.349689,16.846955,-148.978856,-174.826524,-48.968613,83.428661,66.853948,-51.641461,-97.313765,-162.600368,-190.089036,-174.207129,-120.988822,19.905913,86.213253,55.191508,-111.523646,-193.492962,-181.544325,-95.702227,34.468004,70.692704,70.563438,-28.809623,-117.819326,-240.637397,-236.08717,-139.600439,-95.042586,-35.381735,-8.980639,-32.051994,-93.919124,-98.652608,-94.639677,-95.020474,-51.108392,36.438286,71.366601,79.057922,48.520669,-48.929162,-81.245466,-48.908161,-12.941444,3.034288,-44.96918,-83.3108,-139.645768,-138.744859,-113.467557,-94.542625,-21.161988,72.465319,82.891601,2.084885,-41.301927,-69.504501,-67.711216,-33.749954,-0.458681,71.810296,95.534988,88.384589,33.04117,-32.705322,-181.77822,-194.394934,-37.70497,153.391629,181.667087,91.735126,29.70442,-32.308375,-43.778853,-34.38328,-22.920752,-5.785911,32.861869,27.242945,-49.633429,-89.638028,-101.092036,-53.706969,92.747845,179.163704,184.990138,145.333656,121.852441,88.867219,75.908954,102.543306,149.382423,261.842814,310.826048,282.202495,191.582748,167.756128,177.490649,207.896844,261.825319,247.945236,237.767232,200.710125,156.819623,60.537824,55.211683,149.334901,186.21942,184.572819,249.104307,303.383172,304.163898,233.992861,90.591851,70.493246,99.902127,92.361436,63.664038,14.11738,-5.171003,-89.360182,-137.630371,-117.816342,-43.343809,86.854178,126.598816,125.524658,35.44797,-16.022805,-4.296531,25.008809,17.320095,21.980912,34.968863,-27.619639,-83.538232,-136.658157,-130.821604,-43.913961,26.527577,130.552564,129.854476,90.033434,-12.3102,-34.880201,7.982082,47.847848,156.829395,333.485849,387.324691,302.606646,196.292011,7.888808,-47.813006,-78.384978,-70.268081,-48.285808,-30.131272,-31.547716,-40.139272,-59.749102,-174.363125,-233.259047,-229.5296,-102.450504,-74.361807,-143.609947,-167.945476,-129.06697,-111.498601,-68.722142,-9.941631,145.32111,168.658132,99.588653,-58.865285,-83.312483,-38.889224,-11.570068,16.117594,50.954541,75.608721,87.528248,72.845864,20.971739,1.339601,26.016204,53.488751,95.495721,96.097343,55.346471,-58.197376,-98.054237,-112.998185,-81.876525,3.716394,2.089993,-50.789238,-163.917276,-189.689039,-257.422725,-300.561738,-288.22427,-232.68944,-55.741783,87.378825,72.325614,-30.447824,-56.94243,-70.547643,-64.20599,-26.715298,8.239654,26.010896,20.174603,-10.96531,-85.37852,-119.240894,-132.079522,-104.877572,-42.481326,-18.292032,-30.180838,-122.096096,-194.387025,-299.509432,-310.979036,-300.697809,-240.131304,-190.449128,-171.694096,-216.294403,-314.351475,-334.101341,-288.746612,-239.933806,-168.368791,-209.136306,-272.415819,-376.352066,-380.931931,-304.188336,-241.520246,-146.695373,-114.442551,-96.718271,-76.080984,-92.359125,-141.382518,-130.650141,-29.563799,10.835307,6.638931,-33.241879,-55.201535,-110.491117,-129.349151,-113.727081,-93.214789,-114.856718,-170.335013,-169.61596,-188.569423,-233.763003,-271.827338,-208.255817,-5.253472,42.125038,9.369052,35.051606,68.339498,81.11604,68.332986,65.093074,81.960768,112.499892,93.461677,60.344126,1.671324,6.102124,32.755711,44.582401,129.213067,196.347689,317.893296,344.794988,322.817446,290.646347,267.262482,136.397921,70.411584,93.547442,201.947137,199.789353,118.373844,94.340299,98.636032,112.950536,160.658383,174.625461,156.456273,149.907586,149.664247,83.275894,15.664041,-87.117483,-95.226515,-72.156134,-64.015517,-79.533199,-165.915042,-224.643877,-302.061564,-289.127777,-150.036023,-62.1211,44.743878,16.447313,-17.919759,0.638848,47.839074,109.63807,124.611873,168.063612,228.840087,229.781707,86.370365,-19.049709,-148.114011,-158.07261,-80.992663,-10.442721,109.377766,87.199383,12.134766,-126.311594,-154.777397,-156.860734,-117.960066,21.486245,85.705294,64.525802,-41.989176,-93.400092,-156.956353,-178.059792,-192.872912,-172.872494,-53.420886,47.458628,24.723207,-101.708593,-149.461129,-177.287358,-170.342913,-131.873096,-23.035337,41.888157,18.246489,-86.16782,-262.630525,-269.249919,-161.785159,-83.408971,48.903795,64.626875,25.688179,-61.787419,-71.975447,-21.966189,13.701967,117.236761,250.108426,267.756873,162.613996,86.074821,-32.355557,-65.372951,-66.685407,-38.827873:-24.378847,-57.477702,-97.103596,-141.145279,-126.527601,-72.913901,-51.340424,-18.51241,-11.462271,-27.334831,-136.629152,-204.946357,-239.170342,-205.499995,-143.552786,-139.486527,-142.106216,-103.447536,-73.382072,-16.908456,-16.49026,-92.3932,-126.897003,-99.262326,-66.12194,-102.581793,-242.607818,-280.093214,-206.398229,-167.781779,-218.075614,-238.098984,-126.830784,7.093261,-8.564191,-178.25477,-257.551189,-283.043639,-229.352474,-83.273992,-40.608393,-59.848987,-144.265072,-217.252907,-353.521324,-368.218151,-294.606464,-251.929859,-180.32275,-71.205841,-47.43885,-96.54062,-125.574748,-158.678428,-151.535399,-44.185952,70.887668,108.289336,169.045015,184.35363,164.312404,141.341511,71.651066,23.968842,-23.527884,-37.076312,-69.5652,-141.176654,-158.964394,-169.857626,-145.988213,-22.152073,48.156976,23.490438,-105.866244,-175.445066,-235.939182,-221.924237,-171.07057,-152.906503,-99.282928,-16.331549,-1.815979,-42.927252,-73.997427,-124.868172,-130.622509,-67.129187,60.143224,120.631802,171.586778,142.017849,5.450774,-59.526009,-95.09722,-66.493884,-4.815331,9.84779,17.640908,10.14734,-16.791259,-34.884427,11.138779,117.877979,97.158282,76.623235,51.549901,25.951481,-64.174417,-114.587881,-123.209504,-61.826301,91.367464,141.456957,129.176089,102.982826,94.035576,96.763175,140.532381,279.477194,354.258188,343.59907,197.217648,111.026039,74.790283,107.860262,152.86183,154.325849,172.020781,261.002499,299.795802,290.5956,252.190716,152.378483,106.372895,79.668687,80.844332,48.751608,-28.841152,-43.991412,-31.742372,-16.355512,0.836144,3.640077,58.998224,165.081644,168.51358,56.754016,17.886304,50.175458,75.803708,52.411715,17.403261,17.865907,-45.657227,-102.822706,-149.610725,-136.14927,-81.494061,-45.226687,43.779527,95.096848,88.978042,84.347676,94.228039,81.843212,82.704415,198.861161,341.475766,350.8768,227.395101,136.246571,27.075541,5.39423,-25.518545,-23.952948,2.172078,5.434268,-12.915117,-61.32893,-65.285339,-84.85814,-133.873324,-211.149285,-132.760771,-94.685488,-139.601832,-173.900793,-127.324974,-72.26032,3.496345,34.343597,107.70881,131.39336,102.693454,33.279077,30.296677,69.667838,95.543044,169.391313,232.924174,212.336439,74.199577,27.64604,34.913326,55.967206,104.415494,127.285138,171.142832,210.636078,196.36582,98.878429,65.879768,105.155731,149.690921,182.513065,145.425316,116.383513,34.143711,-4.23257,-53.293177,-78.90848,-114.722822,-101.177009,1.618799,155.97329,193.940641,150.938942,104.703373,34.346943,31.589564,85.160789,95.193808,70.577385,-7.524941,-40.098156,-36.27789,-22.132856,-33.330354,-47.339963,-31.69293,39.558122,36.755253,-74.943017,-129.039131,-193.150506,-210.013881,-161.421663,-69.341953,-71.56399,-171.021779,-225.510118,-274.325914,-258.085173,-190.138669,-178.00635,-199.942592,-217.185921,-231.365525,-265.6191,-258.554945,-194.300929,-168.489316,-176.175042,-202.095573,-185.449506,-111.388144,-98.158372,-154.350671,-176.901029,-105.463202,-47.724365,-44.525322,-78.645256,-42.904054,31.399458,9.637184,-127.353608,-190.222376,-220.651207,-216.876622,-240.074105,-268.253243,-253.140947,-214.696572,-192.496799,-68.736978,6.61659,36.717354,9.443212,32.008814,92.84779,111.383524,133.799585,135.806244,92.786475,29.846164,12.986417,-0.252201,10.527244,78.081084,124.157506,204.754987,227.861003,271.968713,338.064223,349.089996,311.941827,257.74361,69.038754,-4.096184,2.624917,71.23738,81.344859,47.441191,31.519172,76.344385,116.661409,112.3876,56.274402,-8.718333,89.71282,122.09003,69.832998,18.153277,-77.502116,-118.532269,-199.960359,-240.991936,-236.696773,-269.227213,-310.395821,-364.4566,-372.76726,-328.295926,-267.316512,-141.625007,-98.979019,-96.582656,-26.222264,39.478856,110.005756,115.001159,159.374571,225.514559,233.729834,148.251181,65.466627,-74.699121,-110.853257,-112.584714,-84.875286,-35.425881,-72.770815,-125.606246,-211.002532,-226.375136,-230.822363,-203.772493,-78.598265,-12.32425,-40.008668,-165.779483,-226.033702,-276.507995,-263.327621,-205.54344,-169.544151,-45.193736,82.836816,66.437092,-112.664391,-197.275377,-269.789257,-260.892858,-153.294103,-19.162009,9.748648,-35.069433,-88.033633,-160.070754,-149.318523,-36.135811,24.912619,80.386954,88.451686,79.322531,35.353696,23.752936,53.371406,81.991095,114.520459,134.941746,158.50864,159.330286,120.516847,41.841204,8.052806,-62.181951,-65.12043:56.086051,102.664308,49.350153,-75.226338,-101.359159,-88.680957,-58.450604,31.198673,82.31731,45.518754,-143.447428,-215.306893,-203.018329,-156.174353,-97.082962,-93.897287,-56.063016,16.902335,24.080679,-10.593811,-55.092963,-148.167639,-139.931744,-22.853668,78.638539,86.700559,-24.411508,-105.456005,-208.796835,-234.666793,-232.214516,-181.794643,-25.231508,33.656812,5.539141,-103.357177,-161.662702,-187.483691,-121.472725,28.446665,8.402401,-27.996007,-107.328973,-178.150829,-349.614286,-390.293112,-315.249951,-243.948054,-136.952446,-69.763804,-69.991018,-151.359986,-200.259975,-220.895394,-170.00549,5.22485,158.408766,204.209281,199.756239,157.18883,95.995369,89.478122,48.802162,17.737583,54.372463,162.027931,131.413771,-106.571753,-218.42767,-223.154012,-130.547179,12.152238,-8.031836,-35.470116,-127.413902,-193.518402,-292.533994,-309.546085,-257.344765,-195.080307,-90.060062,-55.591677,-56.928087,-111.696941,-158.674315,-213.086378,-191.060778,-50.013082,92.574691,124.733213,115.373364,71.627328,-103.125939,-186.947923,-218.205597,-186.046567,-91.289409,11.677986,4.098524,-123.047247,-174.706278,-175.403293,-122.743358,24.129677,112.673303,129.66864,95.647486,38.988241,-97.959322,-147.399696,-126.157244,-40.079171,159.159248,177.52553,128.141428,72.925627,81.024942,109.246199,139.147886,252.535392,325.20426,305.677769,168.982266,103.029417,35.15952,19.462358,39.76583,72.773978,134.399427,200.644945,225.29202,212.369236,164.562985,1.328542,-69.706713,-81.886819,46.568216,104.412253,108.325626,58.971605,-78.961918,-122.127562,-50.014873,37.353547,164.809538,186.957012,162.391321,49.620824,-4.266596,-43.387178,-36.543998,10.981063,107.751755,122.5201,-19.504283,-121.253781,-202.577062,-173.112475,-37.418948,32.937501,121.27868,142.463006,129.883637,83.39875,53.427806,13.686075,31.105431,143.269832,257.405619,247.069524,94.786053,4.435776,-164.679147,-226.945861,-189.152538,-111.557197,-1.22786,49.415214,51.07669,-7.046697,-62.259211,-211.334649,-266.229588,-235.006398,-109.27613,-87.96463,-136.822387,-159.961279,-163.38972,-145.12443,-27.194525,58.092593,180.868988,156.324072,72.006266,-91.063373,-92.770519,37.162289,107.271463,181.248177,190.494654,161.998066,68.94037,53.221502,69.387922,63.399777,72.089924,113.668437,214.703299,233.504137,186.337822,18.037477,-46.932956,-33.186627,31.331725,115.578657,86.099502,69.895288,37.572585,11.134781,-82.221929,-139.646582,-157.872019,-108.261742,20.648729,126.0254,129.281031,67.761278,56.254986,100.132421,136.307198,150.300614,82.270798,59.366984,38.40874,30.979199,27.261568,31.257475,76.813164,102.846428,82.013447,17.919176,-3.114709,-60.729877,-126.3072,-272.059486,-282.312981,-162.557641,-66.156829,-73.595272,-143.620192,-162.343966,-144.465195,-140.356297,-192.492656,-219.210522,-168.843455,-66.576253,-81.58615,-210.121867,-264.544013,-296.611835,-267.351769,-163.917419,-71.732437,-28.978144,-13.476372,-60.001656,-186.017849,-210.994894,-129.856652,-57.277822,42.40026,24.030104,-15.538906,-53.338284,-58.360086,-110.473381,-137.67984,-164.416795,-173.855697,-170.355427,-181.477443,-204.808498,-247.448985,-233.198966,-108.08409,-37.596791,19.800542,-0.037261,-11.803398,-19.016812,-6.784375,35.35633,52.426993,70.767312,48.069404,19.105928,1.96034,31.594861,69.52665,57.011629,45.670578,62.645461,150.262475,261.830284,270.052144,192.706806,128.089008,14.998582,20.75262,110.142621,161.588181,174.819229,165.610943,150.081418,162.173532,189.384132,221.113308,219.96518,247.838162,296.360611,278.788409,146.501453,56.774275,-66.0428,-72.543191,-74.49022,-97.998354,-81.409022,-73.440042,-110.174531,-226.462198,-283.886219,-313.158079,-268.059131,-98.676534,10.448261,4.274751,14.237471,50.673053,89.60206,106.73192,208.864674,320.880443,329.171671,212.867548,117.977435,-56.874293,-104.95853,-51.138411,19.242895,85.126871,2.993436,-65.483405,-155.188815,-150.849593,-84.353814,-46.593083,30.522898,81.960761,54.942343,-82.339813,-134.255582,-185.79537,-208.274642,-208.454459,-166.053485,-19.65618,75.125996,42.993303,-120.429383,-187.651216,-203.691899,-147.757527,-10.133207,45.848997,59.755268,35.937903,-21.323808,-154.728479,-164.659337,-20.642304,66.030897,112.263261,35.871948,-0.72727,-62.375444,-94.08681,-117.219711,-92.992369,9.340831,96.729,108.013822,62.063807,25.542917,-54.426045,-106.99758,-175.501743,-152.894731:29.05493,29.984168,-8.118517,-119.196187,-159.047713,-146.357276,-91.164047,48.862458,88.746914,35.63888,-120.899474,-162.745161,-164.507019,-155.321341,-145.487054,-149.852132,-205.200511,-251.950262,-231.411358,-145.392318,-112.406434,-63.151276,-43.729832,-54.550291,-123.272298,-149.373777,-178.682607,-196.674886,-235.640472,-260.793377,-273.801043,-212.081055,-36.540012,-24.58816,-67.515012,-131.248073,-151.936998,-208.308596,-199.419944,-61.630051,-22.538464,-75.533527,-225.430568,-304.545849,-389.374133,-350.796168,-197.057179,-171.920849,-231.351109,-205.590467,-172.827333,-178.480006,-202.735769,-219.335457,-179.223152,-5.84508,123.441964,158.652459,232.550876,256.438695,224.162871,193.37056,192.878008,199.489399,140.099864,28.671646,-29.463966,-95.733147,-93.113791,-56.138429,-17.585921,77.351802,90.951237,63.128423,-40.846709,-87.269978,-96.875019,-88.529601,-97.451732,-83.870046,9.125329,71.937412,48.078403,-40.178697,-50.233771,-2.809367,34.498959,106.1311,187.703244,248.725642,298.626838,245.779747,108.249699,83.096819,112.836961,145.81199,193.420291,145.888255,81.620226,-33.335247,-45.69997,25.586909,90.799093,184.141977,169.175621,144.745813,44.413413,-38.036113,-179.250588,-215.547554,-196.062209,-140.863162,-49.68335,-68.792676,-96.16362,-89.794,-50.031296,49.811763,107.282651,203.719595,209.54042,181.147112,88.262592,35.285553,-42.815261,-53.585351,9.258329,64.290535,131.319117,157.355871,170.496974,192.345595,188.495471,103.866439,49.00703,30.804448,73.933011,73.80176,32.329442,11.224317,19.353958,35.107032,63.598582,92.024687,157.378596,198.445626,202.178513,195.815177,208.008863,229.343554,212.480941,101.294314,-62.573418,-118.715202,-186.155851,-218.802774,-241.718412,-204.877003,-75.571403,-51.048508,-88.560378,-10.761123,41.244253,27.389705,-5.378235,11.980811,61.171627,163.143784,229.900075,241.5191,164.045404,80.096261,-44.383107,-57.143852,-44.744343,-38.375255,-33.465981,-79.114098,-138.113505,-229.747406,-231.392521,-240.296843,-273.958106,-327.113026,-260.155046,-198.071521,-140.482303,-149.020844,-130.071002,-97.634674,-19.818337,45.664048,144.37763,0.062082,-89.760453,-58.135557,40.757155,194.95784,217.830268,194.607106,152.234217,131.52361,57.016596,22.088057,22.957719,48.635815,122.405346,170.335821,243.017361,222.629074,186.682243,159.02411,181.499698,242.022454,277.248075,328.404777,256.859025,207.80269,152.955572,125.18032,65.177691,43.10101,-4.595681,-18.151864,55.854727,239.258314,288.540479,231.144771,169.280346,64.428831,26.157158,-8.308046,50.273723,77.159446,-6.862021,-70.111492,-75.414783,-56.758313,-78.096225,-85.785279,-36.84476,46.346166,53.003977,-45.115991,-117.254262,-224.451146,-240.016018,-185.622247,-82.782252,-61.890568,-129.156499,-145.129203,5.837676,92.559698,85.944254,35.673614,-6.910728,-12.861433,-29.976188,-79.043936,-100.986713,-138.36118,-156.09062,-160.770531,-101.505808,-75.666982,-114.001561,-162.001113,-202.162915,-177.352968,-60.69375,12.079544,102.274868,62.821128,21.349066,-27.57233,-31.984197,-28.692492,-25.426197,-58.454673,-136.301677,-146.795807,-127.407937,-133.606673,-146.326292,-107.80451,17.239793,34.161531,-22.541554,-4.995364,25.499126,46.66811,55.812597,92.187005,87.816092,37.922262,14.293861,-4.594363,-33.802905,-8.615399,55.588318,53.345494,64.323821,120.784197,263.252358,314.516288,289.657118,154.933333,72.241277,-46.931879,-49.705483,36.127366,70.277464,48.104393,17.8815,47.571363,136.569589,128.628571,27.352803,8.63588,74.960853,86.388879,36.103444,-32.113794,-10.764814,15.041452,-41.852518,-221.985084,-264.451033,-233.295153,-163.494148,-152.260456,-233.236631,-295.259259,-290.354845,-235.419268,-199.457912,-221.466353,-176.794968,10.830439,89.248164,159.539914,189.854684,245.23891,232.471992,241.654867,253.527659,216.940483,125.030868,90.436919,15.552362,-21.618413,-70.285931,-34.322264,-2.655149,20.926644,6.119679,-82.799836,-120.770659,-84.882191,-68.912831,-114.464804,-188.032319,-190.074235,-185.793575,-191.572081,-160.780984,-110.765082,1.391209,60.086246,42.727924,-100.873118,-195.145471,-356.816463,-393.240718,-313.673526,-136.442754,-61.852503,-3.362128,-17.541679,-51.319468,-53.574558,-30.639943,-5.844079,62.660589,106.298582,90.227899,7.45198,-10.803144,7.845001,9.927388,-26.308434,-28.597799,7.779333,75.585431,71.397543,28.455704,28.58285,64.661503,51.531057:80.789418,3.625019,-62.917202,-139.037649,-113.161139,-1.494987,62.368954,193.805586,187.369488,104.591219,-88.728814,-139.018571,-133.873465,-113.845088,-47.52533,11.6795,80.889629,11.282415,-21.711857,-15.842654,-17.27872,-49.467765,-29.488439,104.054264,164.698032,123.649956,-21.933618,-93.325346,-200.709488,-210.842822,-110.758701,-45.496229,21.089898,65.093944,63.75283,-81.260113,-170.213916,-149.725766,-39.861877,163.600681,125.671009,47.644323,-106.672774,-174.855614,-286.234184,-309.507257,-230.901964,-150.356733,-14.976507,17.121492,-8.987106,-67.77922,-83.033445,-83.13703,-26.763372,220.282649,371.903619,358.051592,249.52613,211.382887,202.699855,203.063353,208.999919,218.37915,199.258381,128.443052,75.053729,-49.112867,-96.551483,-85.276192,-12.12225,150.993969,143.997916,70.233045,-115.438653,-167.458317,-163.189017,-154.291792,-119.835567,-54.716723,79.126784,-0.722149,-92.732879,-171.29745,-135.231365,-25.866006,16.871351,93.210177,178.316878,221.080278,211.62809,135.832068,-17.666176,-43.768869,-17.850494,9.872048,45.579386,22.088488,-10.116374,-81.265024,-104.291696,-84.858696,-15.965711,177.322811,190.778875,113.348513,-89.748768,-172.810167,-249.521549,-253.272338,-211.823898,-162.59669,-41.76719,-38.451817,-98.701183,-172.957694,-124.953107,74.096327,161.777948,231.095237,194.65871,163.661581,26.814868,-59.447613,-96.545029,-48.047192,30.038844,38.075472,78.952646,170.600198,165.454306,42.717784,-7.74839,-36.653502,-46.45717,-57.044618,-7.546555,14.072933,6.925105,-10.448553,-9.206723,20.125769,95.967379,125.806291,168.336627,186.525288,166.827937,45.743361,-15.958306,-11.805683,50.334396,159.074008,126.521975,68.807852,-81.301173,-158.3435,-242.647604,-234.849271,-108.031578,2.020133,180.635272,162.386299,99.841779,-17.06362,-44.782268,-29.875271,21.4069,202.837691,296.124265,246.052441,36.408033,-38.857546,-53.845081,-41.656901,-46.001156,-52.120476,-36.137996,0.539532,-9.573273,-85.113957,-131.55376,-202.426652,-209.536305,-150.41221,-58.30087,-47.493903,-136.696629,-208.943998,-280.315333,-232.205495,3.842878,114.646052,196.67971,104.605543,27.925454,-37.680526,-2.48418,117.187144,158.223693,181.964383,199.803746,200.038677,134.123009,99.974256,114.425145,139.651764,179.296285,206.999835,270.04383,318.607679,310.904755,190.24595,107.51114,35.70417,87.026916,248.308806,230.985043,162.502731,18.679638,-24.588383,-23.935278,-11.560117,-27.542791,-31.111937,56.276012,224.546517,256.790548,138.900242,49.921282,0.781569,49.419111,165.178044,162.807676,117.971637,23.422031,-7.216786,-51.244511,-63.744614,-23.097439,7.998124,-12.865664,-24.657706,15.115406,31.230998,-49.25214,-236.198333,-239.053146,-75.943604,30.157747,5.263498,-121.848722,-154.055803,-97.820664,-62.461937,-70.449866,-85.384883,-59.183023,-31.003528,-58.671624,-155.199316,-195.290282,-258.393705,-266.334133,-187.097159,-30.392438,23.439261,-34.886571,-119.364882,-232.354694,-215.251292,-39.846199,57.207353,111.200877,-31.748664,-101.78294,-96.483584,-61.830011,-109.123266,-172.779137,-243.666888,-265.797367,-275.380396,-276.238455,-275.982054,-281.468667,-255.438107,-140.178024,-91.026944,-39.871784,-30.705473,-35.487572,8.960285,52.979944,67.245714,39.951691,8.275889,-1.398314,-15.291454,-75.105353,-114.832737,-140.209219,-98.323431,61.704468,128.227609,189.601676,247.28348,258.06588,141.976361,33.879225,-115.906258,-97.362387,63.280804,109.307212,83.010822,50.059061,57.501429,102.459416,127.792514,175.344379,200.816857,262.022594,299.416612,260.868576,105.022236,56.672547,47.071848,42.105233,-8.866769,-17.431764,-8.280178,-66.579111,-128.376679,-202.977439,-203.867543,-160.664184,-126.293314,-76.417275,-75.505693,-61.614984,90.244188,199.443502,299.786726,279.412881,251.176416,328.353113,348.310339,238.223784,152.108392,56.395498,33.666417,17.149931,28.588167,12.655499,-79.005668,-110.126145,-96.72369,-80.261617,-110.538747,-114.869915,7.219731,51.164774,-14.225549,-165.196661,-202.360217,-246.57485,-264.918675,-190.823013,-101.775329,30.284515,47.194424,22.925153,-91.873512,-175.462867,-302.516353,-291.384044,-131.374262,10.344846,35.807016,-20.163115,-79.297732,-153.13448,-150.112998,-63.795326,-13.301702,10.5966,0.684992,-5.099708,-51.545611,-75.723322,-55.561192,-14.576831,29.720473,-6.645561,-22.767286,-34.437716,-43.077491,-85.865971,-109.99903,-111.862783,-84.120032:-3.119692,-70.461301,-117.623686,-268.014472,-325.477994,-304.449784,-223.579446,-28.254575,42.270701,30.331584,-44.955369,-87.496818,-90.203929,-52.214183,0.523704,-16.598645,-121.587849,-196.64135,-195.370444,-137.362053,-112.048838,-101.151035,-88.89733,-60.919861,-121.958003,-162.047689,-205.161467,-211.102899,-190.503937,-163.070191,-104.224669,-86.798687,-62.495444,-26.680269,-20.41439,-48.475599,-60.380883,-42.641758,-5.89459,89.210778,93.357917,54.565103,-48.744592,-78.814639,-73.81627,-61.009832,-39.286747,-50.783978,-121.698118,-122.018625,-109.978388,-109.351546,-100.978674,-69.240813,-49.119604,34.325252,114.490733,125.68133,125.820967,119.59813,96.34831,86.876549,72.33812,66.195434,32.196524,-7.50749,-8.62446,10.790867,23.881474,34.331783,41.512298,120.158735,218.683333,220.45018,137.650188,105.52796,88.915052,88.00523,164.678183,227.645058,216.33478,84.448769,66.871958,164.252268,230.147033,267.646498,256.870432,298.142161,410.608036,447.237722,404.303592,351.334143,328.504715,350.462373,368.472679,379.609953,417.669483,366.264694,305.418315,212.586286,221.363698,326.237475,382.502165,441.143423,390.573113,327.857896,171.21995,106.621484,62.430414,65.03544,21.337905,-36.443751,-135.032359,-108.040487,-90.041404,-121.836653,-134.720364,-64.262924,15.010816,155.363503,128.665812,66.244787,-99.460061,-177.037147,-209.527049,-160.767798,-31.186312,25.442178,101.201613,144.290532,156.185311,105.119727,54.953287,16.384555,45.519928,124.061461,119.703492,101.001748,117.698017,158.664012,252.508085,283.409761,315.062557,334.910879,394.902972,377.438613,325.155699,272.977645,299.557696,331.708087,296.268096,133.250388,-30.900234,-51.140055,-16.839684,-24.741501,-84.360411,-85.789632,-24.026146,-12.434766,-58.393275,-20.053702,32.417711,78.300725,66.739499,7.416993,-18.346596,-15.509026,-16.754488,-36.926358,-65.095313,-64.744918,-94.079314,-125.842126,-125.163053,-90.113717,-90.911602,-183.333111,-212.618314,-278.331349,-312.263755,-332.20143,-334.624319,-300.497349,-197.931121,-175.308268,-204.025868,-220.888957,-194.466336,-135.523245,8.986349,46.079549,53.171252,66.264911,61.850721,-4.564793,-24.004304,46.531475,102.433209,133.281474,54.807833,17.244285,5.047251,36.957283,121.763416,124.454707,43.537314,10.653863,37.289775,142.196741,189.736436,234.085392,221.742677,123.645639,89.923601,157.450944,228.529223,218.611728,137.603385,96.696306,79.348174,78.319515,18.191244,-20.962235,-12.979186,120.299004,183.575873,211.68938,180.196566,74.408165,37.752977,52.595675,31.976483,-0.210793,16.587161,53.199056,45.983071,-26.171431,-208.584999,-234.327868,-114.027815,-11.24695,-7.92943,-2.683964,-0.850814,-62.611015,-100.985485,-105.413492,-40.186738,-25.078427,-56.858676,-51.561594,64.758751,139.914419,220.202994,201.664544,119.269583,94.536187,63.921524,-67.163265,-125.334705,-173.334893,-171.09323,-152.125395,-114.657738,-80.658694,-59.34021,-99.28128,-191.111401,-189.69718,-80.114427,-7.466088,61.077707,14.236725,1.905873,10.100379,12.821175,2.653676,-24.442079,-128.076534,-232.319506,-220.206464,-47.484016,12.059587,-48.677278,-103.823531,-126.748341,-103.452222,-84.553458,-83.110853,-46.443603,49.444086,88.984057,118.909645,89.292357,-26.622661,-117.309181,-139.177758,-172.54185,-173.414955,-98.826579,-62.618217,-59.757017,-46.934254,82.688677,233.286666,253.570536,196.702577,163.118896,126.927191,127.376871,119.621019,19.458004,-27.952605,-61.766995,-52.325435,10.682864,46.154236,84.790439,90.093537,117.457351,156.998859,137.252869,109.23213,158.330563,257.565925,232.182931,81.341172,-10.161389,-3.787683,-1.757269,-49.5002,-204.243955,-281.657206,-329.366608,-284.003389,-194.38077,-135.103557,-78.788877,38.017412,80.818704,145.808277,181.439031,280.378601,338.98592,339.618842,296.445244,251.774561,144.283513,96.789583,45.043811,48.204199,79.345287,80.947271,84.700528,147.38036,170.443788,65.540123,-41.225185,-185.947365,-220.446539,-225.817959,-229.665115,-231.841929,-212.634316,-187.253292,-142.62235,-120.056267,-30.06619,78.170003,100.121591,46.924562,-7.589697,-122.622252,-167.447124,-181.074094,-111.990921,-60.029422,41.781812,87.852744,150.951396,133.848378,41.733645,23.772026,55.447632,40.130664,-13.798039,-99.873173,-83.70561,-20.654089,-28.668558,-112.572752,-119.601747,-63.966631,58.339885,86.011467,69.756172,46.712857,42.473663,49.162786:52.966965,-63.804258,-111.305507,-150.93229,-154.944433,-158.689378,-128.755351,54.887433,206.874226,214.742368,128.555901,60.054618,-5.269806,3.895125,-41.197051,-108.246477,-190.140324,-104.572914,-48.415801,-12.345397,-16.874586,-49.179406,-74.3598,-105.829531,-131.06692,-147.672821,-198.974514,-217.675126,-176.008517,-140.937938,-101.493139,-74.905394,10.663773,50.155535,36.817637,18.27755,32.037552,8.388143,-23.467187,13.138672,94.441142,80.80748,-26.983706,-72.542808,-99.50214,-95.353379,-52.285292,-39.426372,-113.415983,-141.059915,-106.343777,-81.247625,-117.716105,-212.361758,-215.275303,-124.481049,-70.063131,-52.628442,32.410817,84.995848,137.573374,132.327109,99.728418,72.145597,-47.658933,-164.177972,-168.780174,-53.320771,37.506147,133.951335,110.586709,44.923177,120.017364,160.706836,128.013432,98.441362,98.195564,94.636716,73.867197,86.893008,161.950195,238.677367,251.134286,254.876549,265.452307,205.145724,126.742656,84.212051,268.780773,350.007371,328.680409,254.44892,163.939964,162.368426,172.944041,171.988087,142.893589,124.628492,131.371443,140.301794,154.485511,214.832789,238.967592,270.763767,267.496363,229.825002,109.398796,71.52181,52.696272,21.255888,-75.344848,-79.32415,26.038405,107.182904,96.972375,41.305909,33.34077,59.880935,88.015728,158.589636,104.517579,18.054802,-80.061225,-63.324434,-38.416934,-43.940303,6.788191,54.975075,154.084281,255.138953,266.136662,206.696722,183.954628,182.573045,177.565128,130.635681,105.202211,115.431334,99.725051,64.012089,3.680867,-9.343216,10.585293,55.347747,187.047593,223.823518,173.037125,59.416782,67.695747,192.582305,239.057047,212.246802,118.375717,78.4624,-9.550827,-53.870429,-92.595202,-82.775321,-52.176844,-64.238988,-74.853145,78.479746,147.508898,157.924721,132.250024,40.542111,-20.590399,-69.011809,29.370779,97.742811,148.849195,130.938923,75.427494,31.772304,-26.477893,3.834028,45.034629,-125.591609,-214.825298,-219.30791,-177.778217,-223.941877,-306.979444,-413.255731,-328.654407,-253.663298,-184.756375,-175.548295,-103.943796,-74.152413,-74.321654,-73.94262,-55.358281,-20.491191,-28.869546,-116.221017,-134.482801,-54.667217,0.406871,46.800305,25.289258,5.394311,-31.56948,-33.249355,-39.827867,-69.617958,-116.159993,-99.197556,37.110971,182.491862,197.417227,186.84362,210.482058,289.310405,307.790463,275.793516,217.889746,213.966787,189.377522,146.279129,85.821854,79.955528,25.880554,-17.045457,27.614876,243.650265,297.745856,212.799761,135.066997,-5.322481,-49.855257,-27.483587,-7.082361,-27.810596,-21.080022,0.085346,-47.44854,-107.513371,-171.532205,-168.213234,-152.281561,-41.531513,51.247862,110.510829,47.909198,-119.697257,-156.916411,-115.385801,-63.421231,-67.955174,-100.228893,-76.761489,86.306532,158.870588,149.029021,100.917726,64.057515,30.2976,-27.270435,-132.853448,-159.139105,-207.108746,-218.761006,-147.650927,-43.435692,-42.301396,-136.188559,-175.174005,-173.674364,-157.172113,-97.419661,-52.992667,-13.202396,-34.753903,-38.127594,-2.528098,32.326197,51.296618,14.207686,-109.348268,-194.366097,-187.535304,-88.172694,-23.678174,62.005117,54.401738,-17.842299,-37.156933,-29.67361,11.905815,34.884186,70.009349,111.305682,220.36692,239.116163,167.989038,46.954705,12.440975,9.162049,37.76155,136.152241,177.868392,233.838216,266.531651,315.757104,309.707349,293.986949,234.611319,189.70314,112.120136,111.513867,153.813525,101.812013,29.508031,-92.263297,-85.677178,31.305106,44.376892,-89.222345,-139.791433,-45.71139,109.176464,97.386968,0.603522,6.884183,43.051879,-0.785095,-134.494256,-174.490772,-173.056681,-151.012874,-150.786135,-228.664562,-267.503799,-262.329579,-254.261596,-266.34689,-187.457968,-127.34733,-76.565967,-59.073527,39.99225,91.900616,101.510573,60.53421,84.966256,159.018753,160.658449,112.077059,71.036959,-11.681091,-6.68512,83.39385,110.9835,93.680627,39.676776,-7.244087,-137.5815,-183.431431,-190.385383,-197.723968,-211.331103,-174.147845,-144.028014,-230.132299,-330.558052,-381.033622,-306.219718,-136.991552,-22.762252,7.748813,-82.021639,-203.734399,-449.988548,-499.542328,-411.117681,-277.943008,-246.357794,-194.632628,-150.632333,-97.703277,-126.920594,-181.270563,-152.996095,-55.877612,34.993004,66.55896,33.071958,-2.606581,-16.438312,-13.009873,-29.009863,57.501452,136.648915,201.925452,191.122691,172.889275,174.091682,215.677389,237.752166:40.913575,49.647266,25.13227,-106.166155,-157.063607,-155.466825,-122.388049,-32.934616,-16.973049,-41.28137,-103.783135,-128.834406,-83.060908,-6.765568,86.397467,52.391211,-59.870346,-58.125851,-51.18623,-123.205324,-175.423657,-209.841516,-180.217785,-37.569549,62.078249,33.492971,-116.93996,-192.84177,-259.174075,-245.272627,-182.784622,-144.181816,-43.776843,-7.251661,-60.006504,-187.30577,-177.822531,-26.240624,52.665749,138.130916,103.428971,46.152549,-122.094429,-194.243657,-202.165239,-158.104393,-84.517734,-59.675121,-21.168914,-25.362829,-34.35168,-22.358059,-42.586752,-174.976028,-177.213053,60.015866,220.716996,223.785042,266.262303,305.650869,315.692891,293.093725,239.786294,204.915043,154.117023,170.384643,146.453213,-2.136309,-53.634867,-47.893775,-14.196999,91.345015,163.664962,147.745935,17.879671,-47.069485,-27.245241,47.294282,148.469817,146.201959,121.058234,131.653207,115.880239,43.738208,35.393546,107.690311,170.140391,285.736586,302.903602,286.928488,244.601205,226.499309,212.665651,202.46579,195.014836,214.436074,238.422305,171.993319,123.855166,34.88441,8.009296,54.479933,123.586207,219.973873,141.775145,71.283027,-61.157854,-127.856036,-196.538847,-166.984637,-53.401828,-16.125227,-28.442166,-143.300112,-211.704599,-221.739303,-135.78269,40.574072,70.96916,63.022318,69.72438,70.696521,-40.281648,-129.103118,-183.605641,-133.735606,-19.985591,-3.069071,-5.975433,36.479559,51.560842,30.690515,14.147145,9.553776,22.794127,100.287677,204.554143,210.793798,110.96389,60.96021,112.210319,198.135989,317.515523,322.752141,285.552534,303.557736,320.5509,297.725087,275.408508,249.912097,237.80267,177.574838,57.493866,-0.411017,-112.198206,-172.418546,-201.682204,-154.139501,-66.606688,-67.822436,-101.939131,-12.414501,56.850101,43.715822,-22.69383,-76.274076,-37.778465,99.780853,152.710179,122.300447,-11.590007,-83.85611,-148.935577,-144.272969,-85.470647,-46.467234,-23.467551,-56.849164,-81.975054,-123.278949,-140.122536,-200.918629,-222.213642,-185.661333,-147.746934,-161.558057,-241.02642,-277.513394,-216.873644,-103.047301,164.035156,236.562438,170.344664,8.564937,-24.668348,30.555582,91.191624,204.014361,233.996017,207.713446,111.892014,78.960279,61.336061,73.489941,138.978235,160.581573,157.788182,169.294627,231.845321,255.560586,231.254774,161.265753,147.831453,155.378695,165.494671,162.506054,63.760711,9.126253,-22.216233,-2.111308,64.408061,75.351519,8.417058,-27.107854,32.725567,172.681933,187.846974,119.751129,85.963392,76.23924,95.039059,135.392602,144.64915,146.857983,104.957361,75.437059,69.17566,63.160575,13.81639,-13.068733,-59.512524,-57.676204,-46.776877,-85.35138,-144.939689,-253.900349,-250.975259,-101.222373,51.632151,67.268341,31.621929,25.468149,44.861132,48.264224,68.682788,92.417613,56.598498,-52.450063,-53.627798,-33.089915,-58.986825,-104.784044,-111.629725,-122.60062,-41.756551,7.62261,-40.726635,-107.897288,-149.03796,-112.055102,27.750277,103.517327,146.470801,8.660882,-67.187366,-121.55804,-104.418239,-78.320418,-101.12956,-179.158585,-236.867355,-240.828049,-179.071037,-145.557241,-118.542796,-110.481197,-80.353422,-69.449903,-65.352892,-56.090058,-64.41036,-89.167266,-70.669071,18.001569,43.541292,-11.46645,-130.66248,-170.454477,-162.001325,-128.416939,-77.868773,-64.717209,-9.594069,36.659991,100.631027,74.499928,32.404166,-72.140782,-109.735152,-114.751807,-78.042688,-21.737487,-74.464986,-84.825365,-63.966486,-46.699757,30.685554,71.383409,116.808711,125.602443,150.638774,195.039472,164.017627,7.983747,-7.648772,118.054257,149.053042,31.364412,-107.593553,-112.864267,-90.311796,-113.483299,-215.948095,-267.482654,-299.52174,-288.767451,-320.658079,-258.057774,-125.836961,106.53017,132.836989,142.628641,174.728819,234.51687,273.30233,302.18541,316.431584,284.033371,192.58072,135.452839,8.132585,-24.536852,-21.198901,-41.85247,-47.88766,21.640916,60.848033,8.133156,-57.984828,-99.103491,-63.931761,-62.4863,-107.308071,-139.334498,-167.369696,-161.325957,-113.679151,-73.907875,14.954426,101.452787,115.58765,31.490627,-23.41896,-104.59311,-160.428146,-228.592572,-145.415352,-89.178562,-10.531563,13.27256,-23.382636,-75.903311,-68.958186,-2.236419,52.311687,2.605959,-14.665911,-93.809816,-129.003284,-42.819285,47.391585,93.969578,-10.842783,-29.074794,8.602273,15.291258,-32.67348,-50.79741,-6.023862,27.637646:forward
-104.667012,-146.181707,-173.199471,-181.066525,-164.39874,-135.589369,-111.454736,-9.854505,85.449525,108.386972,73.112904,20.466258,-23.160303,22.22665,146.276135,162.224394,104.892276,96.535371,118.632071,145.150666,160.936935,213.516416,228.969708,235.976906,218.939119,160.766792,-67.849689,-158.527118,-129.371879,-45.715345,105.220716,141.893232,108.089928,12.456867,-14.323598,24.794794,67.915476,71.363386,42.370664,50.488969,81.223071,84.539692,66.485163,23.810919,-62.477534,-67.501095,11.960552,72.161729,137.05258,102.229189,70.480253,24.073422,19.761973,44.274569,58.608866,113.409343,194.16323,198.990895,166.137097,155.072299,121.690384,89.76877,48.028154,59.912077,66.095382,-66.150957,-169.136723,-339.738399,-362.928101,-313.970437,-270.041073,-116.465536,27.371323,25.960446,-135.197801,-238.942324,-319.23893,-286.44029,-185.869017,-148.62351,-120.562479,-147.619318,-145.487502,-101.279651,-93.659285,-101.10635,-78.387716,5.719024,-24.905469,-73.76257,-107.71743,-90.707226,-33.23383,-5.458281,-0.791088,-31.180448,-117.865314,-112.936531,-84.155645,-91.461469,-117.248978,-117.974707,-93.815842,-77.901884,-115.024019,-121.329099,-114.843919,-116.490518,-103.850986,-100.339797,-119.443695,-123.945146,-143.092005,-161.101825,-174.079052,-255.051123,-278.976355,-195.241132,-106.665281,15.077081,-65.273253,-120.732589,-192.229801,-233.8903,-280.377924,-255.68143,-156.506706,-119.47217,-109.033524,-144.67207,-166.11166,-205.577098,-216.316313,-226.007297,-219.719432,-169.548449,-164.616605,-172.326656,-148.956034,-132.269873,-101.894669,-82.764994,-36.845076,-9.746319,31.047262,34.141417,40.154196,96.597666,151.643768,244.112664,252.233586,234.334529,204.571178,166.146875,35.517783,-19.944394,-6.319329,44.557903,96.805614,84.01337,48.349914,40.116924,32.67512,40.807738,71.373994,151.857557,201.408095,307.669083,241.75642,120.779308,-124.882233,-189.179251,-187.331337,-148.293171,-65.919166,-33.345483,25.926827,49.323389,23.877621,-61.783921,-87.40192,-70.274494,-31.439768,7.516945,-112.553428,-176.16159,-225.487182,-232.120926,-204.116969,-159.604228,-23.279398,42.513761,66.812193,25.638101,26.830716,32.226227,26.059512,11.774949,17.765062,26.309787,-52.816243,-92.066878,-114.691128,-121.951897,-125.679159,-104.922234,-16.215136,39.50787,83.868632,51.136074,49.863152,50.960628,38.981699,40.103948,66.42763,96.966202,3.584726,-62.815097,-125.090874,-118.226614,-94.261467,-83.042067,-20.579358,21.18014,46.258132,-4.936173,-47.517874,-99.186575,-68.365416,62.858418,109.746107,134.08203,109.796408,97.215054,76.057611,53.382406,14.363773,11.938378,28.346091,56.817002,139.809107,175.307282,160.055612,134.832506,158.265905,195.471563,199.254289,217.42382,116.148838,40.545256,-46.456823,-83.147778,-162.877835,-168.060549,-116.475489,-98.164448,-56.24519,-17.182142,-47.942671,-132.59775,-132.09411,-63.13712,-19.205199,32.194677,-17.598104,-78.089607,-213.329435,-227.050276,-70.001558,41.784716,157.864337,154.006647,102.305935,18.942074,-32.981423,-33.051041,32.223273,139.386193,153.835529,174.413236,162.917562,125.879461,30.089535,-5.715126,-57.212912,-79.016217,-98.771673,-104.548912,-126.479314,-135.855913,-149.620994,-181.35734,-168.499448,-131.816386,-128.637934,-68.41193,38.167437,46.024292,-32.371684,-70.418069,-41.991236,17.812206,142.138351,181.122867,199.590091,177.786696,144.611677,62.042499,69.393102,180.71426,232.951866,265.606842,193.757528,138.934762,37.797017,-1.001042,13.36892,78.304698,240.783675,300.255542,341.379691,291.761,236.447287,126.546282,96.975176,45.634907,11.999167,-53.139819,-182.301669,-266.440356,-424.628059,-485.533474,-492.654629,-442.81914,-338.760932,-310.151247,-299.159317,-280.455688,-243.607978,-153.566393,-125.646238,-90.293301,-46.984579,95.879691,97.923049,10.742005,-159.822739,-162.602993,-13.898884,57.584376,69.93296,45.728178,55.870693,92.906578,82.354537,62.44011,109.855793,265.87071,317.545521,378.396932,388.772347,370.080101,309.019489,266.830068,205.340778,218.833508,326.059951,369.504936,326.716559,179.358443,105.951786,11.901749,27.869135,150.677908,190.463581,131.988156,12.319325,-10.54967,-3.974209,3.784844,28.7875,49.211427,132.920724,176.668426,127.331219,-48.463244,-116.920005,-166.870376,-161.685709,-148.66581,-133.906512,-73.95764,-83.611621,-124.154357,-190.624488,-196.521514,-197.155626,-215.417718,-214.850805,-161.770111:-86.660286,-168.766382,-183.346753,-206.791465,-213.117124,-147.918034,-70.350357,69.961031,76.25109,37.255299,-87.19694,-138.869973,-91.417837,7.765537,203.1058,243.657383,221.772359,180.890412,164.877237,134.767026,131.807869,166.814209,214.09461,305.442304,197.942632,99.646145,-33.761138,-65.162312,-42.206007,20.1504,183.426597,225.825317,116.331596,-134.33803,-197.822323,-137.242918,-99.818064,-156.330439,-189.091421,-112.883124,10.764866,11.510511,-76.524867,-110.632961,-109.949902,-72.753315,51.201331,98.625617,120.382598,76.80745,42.972479,5.558398,29.106532,152.22178,207.672887,229.889831,182.432719,173.629921,179.189716,160.034527,107.670031,102.933312,99.639966,71.081425,-26.251496,-159.551247,-257.870956,-411.154039,-406.54364,-277.167728,-196.685862,-65.48976,-1.379763,8.735108,-14.265869,-42.200309,-130.541347,-186.493704,-227.132065,-194.397975,-192.488087,-311.369354,-320.763426,-202.536782,-140.484256,-122.666711,-129.147764,-88.796316,-99.515325,-136.717437,-163.124078,-127.528221,-1.272024,48.638313,62.133771,30.658004,-87.304267,-192.930503,-210.60394,-172.388507,-127.692216,-51.195463,-33.728404,-34.068701,-74.197536,-106.35108,-159.223162,-158.065059,-101.105276,-66.263513,-11.509241,-10.848117,-85.021564,-148.47878,-168.718487,-182.501685,-142.976214,-2.313527,49.411307,78.16238,33.424664,-12.59833,-143.339846,-199.449745,-173.544843,-80.211304,114.559551,152.685143,101.14865,-68.416876,-152.897817,-202.723252,-169.247631,-56.580516,-3.531188,29.960076,-36.321618,-75.592688,-122.116314,-111.552723,-31.796685,0.069426,22.46042,22.399112,0.680213,-8.108492,3.47569,37.678928,74.979786,203.312045,243.846723,203.178199,155.069368,155.51255,146.728855,146.36647,213.163704,268.002623,287.855755,228.706426,95.376459,26.25814,-8.375218,-3.276889,48.773116,144.55163,168.256874,153.612685,66.907681,6.03453,-125.414113,-162.5,-130.628031,-83.108941,-3.180709,23.054112,32.27434,-63.451582,-124.498246,-182.847141,-171.405785,-80.394491,-5.83287,67.693824,-96.227499,-198.726699,-290.263464,-291.979756,-284.396143,-251.672907,-63.244331,37.244498,84.541456,-31.365825,-97.509424,-146.109345,-108.935639,18.299625,55.433893,-3.173135,-117.447227,-151.251614,-210.398772,-219.646193,-123.353048,-30.436246,161.91275,221.681637,177.87796,-0.992727,-81.884079,-162.258122,-141.066699,-8.575081,46.770452,45.556991,-32.605535,-88.083818,-205.820345,-221.62958,-159.894658,-124.615817,-51.30165,-1.303612,35.560125,-81.897884,-162.019195,-225.594271,-181.4142,-44.978313,-25.865937,-119.341511,-200.807872,-201.957712,-177.929085,-158.911493,-100.64312,-64.340187,2.13985,10.038442,-8.638988,17.623703,20.609291,-12.431284,-1.928485,103.6247,162.074577,201.765378,103.743644,32.981559,-56.228896,-52.905103,10.017579,23.797931,-14.587263,-36.26996,-29.898683,5.76266,2.020809,-55.431514,-80.180252,-40.919182,18.707176,84.459893,-11.373205,-77.317042,-111.334009,-59.32182,80.095116,128.66101,184.039479,174.695538,48.176965,-117.547321,-156.815321,-107.764721,-39.91944,80.54965,118.605861,175.04812,142.357875,63.764625,-138.464806,-194.596546,-202.690059,-204.273578,-192.480003,-158.508638,-127.440122,-225.349782,-274.700027,-290.426923,-276.529262,-220.622029,-170.881736,-108.372552,-154.22743,-170.03983,-172.820667,-175.020382,-127.30192,-53.503741,135.155903,180.426709,97.030909,-47.809877,-77.824712,-1.279072,81.698578,188.722447,199.792248,192.293125,117.889939,49.797573,-77.125674,-90.525736,-14.479693,19.274916,50.119637,93.459216,219.953409,172.115711,81.348061,1.3009,22.541956,5.851739,-16.673988,43.472918,-37.539698,-201.929773,-472.830831,-482.438604,-383.835897,-353.805515,-296.825601,-252.517561,-207.87348,-161.901614,-119.450087,-88.679574,-105.474016,-74.744792,6.065341,189.303076,201.48573,115.883644,-103.961841,-142.178619,-44.115655,25.606855,84.637214,69.590128,29.022734,29.832486,40.877744,71.996353,74.741224,69.808542,98.49315,179.439356,158.541623,121.273227,26.303808,-21.602802,-58.407459,-41.309973,39.003998,77.813715,64.319567,-57.691603,-111.948932,-119.338019,-68.799992,33.389185,63.526142,95.215273,41.011884,12.450607,14.055655,18.546872,-14.133726,-15.845532,140.393347,234.663828,147.767814,-154.036829,-227.785533,-159.141648,-90.284014,-41.252692,-50.822004,-64.367721,-79.38627,-91.579026,-185.071311,-275.163427,-380.850033,-337.801277,-148.637562,-87.083863:25.288118,-123.362052,-168.465198,-155.527893,-125.14377,-64.066446,-19.209459,58.11325,-24.24577,-92.356979,-109.339498,-67.009426,-0.164982,29.694392,127.014302,164.670366,154.801639,48.165176,-5.368881,16.26929,89.784059,250.986565,303.936923,293.689801,115.886727,6.407919,-106.384216,-83.609846,25.410368,79.320987,193.873939,228.011576,162.038938,-32.192843,-109.590178,-134.476612,-109.64966,-59.085058,-32.22952,-13.49697,-77.87048,-123.183311,-189.520786,-168.248539,-34.072106,12.756293,21.190766,20.5285,69.871165,84.652701,52.369427,7.027269,23.524142,133.516174,200.553668,282.550511,259.525543,205.822259,102.143972,92.609631,118.517703,141.907743,228.205423,233.914118,52.015105,-226.290892,-338.943504,-433.378715,-402.255384,-265.869168,-186.949351,-49.148185,-10.749181,-29.189377,-68.159167,-76.700816,-119.54998,-152.031659,-156.663325,-134.981814,-177.638771,-282.374054,-287.393959,-195.861177,-136.325573,-59.188333,-46.363965,-62.090014,-113.016358,-146.749422,-191.06432,-153.122129,53.93307,145.829349,176.942657,136.831361,32.666878,-35.0972,-41.409498,-28.26716,-27.514594,6.116351,57.754512,133.53298,80.077165,25.156713,-72.748863,-77.532634,18.140052,65.914344,52.208336,-1.436057,-91.121384,-83.466397,-75.504754,-111.421852,-124.392587,-32.152783,47.039853,98.770768,28.997847,3.720608,-44.470844,-78.945797,-99.703505,-57.191208,76.424567,101.117047,21.325199,-78.33988,-112.294896,-139.987087,-115.117144,-34.992637,-9.771387,25.040484,9.08783,-28.100032,-70.617713,-57.397225,-34.792153,-40.976245,-31.02905,-17.231978,-11.140995,-6.041273,-18.067624,-35.29634,-1.818817,124.136017,180.732125,231.599642,175.639011,138.874908,91.393806,73.244656,86.647498,133.419985,210.376074,188.77956,42.307524,-69.223514,-75.504326,-32.09503,-12.783595,25.989234,75.467544,168.841262,87.712844,7.524362,-97.797483,-101.298915,-16.986971,32.725416,74.446763,70.908412,8.6323,-123.432797,-183.763086,-206.07191,-164.97035,-49.965282,-0.729224,27.517894,-69.473192,-126.252606,-202.21929,-221.933142,-188.181748,-126.287285,26.898437,54.483051,-64.915536,-211.2558,-244.822192,-242.540279,-203.154469,-81.77753,-36.817893,-62.431905,-148.730055,-168.296656,-191.183735,-184.842202,-88.600196,-27.014851,49.785331,79.664882,140.56344,89.711662,17.219896,-108.343245,-114.75825,9.544894,81.040413,67.038284,-33.973553,-58.812598,-133.477601,-171.365469,-133.652743,-70.67809,46.768877,81.462345,48.551689,-119.064147,-191.413061,-207.16272,-168.772942,-88.113449,-60.595649,-80.00536,-165.40218,-178.754375,-183.507688,-201.214321,-173.943951,-91.762926,97.150775,133.615176,81.028948,27.353436,34.807339,87.124775,115.521397,154.465838,179.462017,233.2978,127.506553,34.056984,-31.011657,13.19864,126.436583,151.588346,141.761046,123.323038,74.615149,-10.252924,-63.068899,-116.519763,-87.131218,77.136958,165.483843,235.956299,174.467008,128.980705,51.499252,51.371893,157.003557,228.251459,356.932194,391.992885,312.017209,101.750322,10.875914,-32.785527,28.208291,233.185194,314.249193,298.288763,101.501039,19.482494,-53.82992,-63.903778,-78.657798,-92.812438,-107.172073,-102.483587,-94.147672,-160.898556,-226.14087,-278.066189,-232.329099,-123.574469,-108.454323,-139.373278,-171.844684,-179.995128,-176.064299,-139.631299,-11.862662,39.82467,90.881854,86.900671,34.783264,19.610591,23.926178,61.895715,103.662004,204.986431,257.069838,285.627274,132.524984,27.501676,-129.33837,-133.383095,25.995236,115.62933,192.382401,187.437154,142.350294,59.051533,-0.002242,-30.076637,14.555912,75.923439,75.529427,59.222702,-34.271832,-122.366201,-303.053734,-342.286904,-279.155005,-225.424709,-144.351959,-97.91648,-30.748295,-40.523981,-40.114096,-1.017435,17.56174,53.302116,95.63967,169.811665,81.390153,4.903536,-86.723652,-87.713006,-38.094459,-5.331473,43.699499,46.515998,41.587278,64.075066,74.464658,113.808122,132.866424,103.016683,74.278738,57.528305,22.465778,-11.1263,-70.729897,-96.441838,-112.18917,-96.086101,-79.096516,-97.966803,-151.860439,-207.388539,-249.768797,-273.33645,-210.002974,-23.791769,16.704223,-67.055541,-171.784015,-180.319934,-159.001957,-140.451823,-77.757162,-31.568166,80.061358,116.486096,73.913716,-88.33395,-153.774752,-133.78498,-59.544883,55.422485,49.861808,-22.318489,-51.168232,-63.487648,-164.311453,-245.963413,-364.691987,-365.069657,-264.857153,-208.312517:-107.112059,-180.03616,-208.911112,-215.492776,-200.455751,-129.776739,-70.727828,36.710709,32.687413,-3.026386,-117.752135,-183.633622,-205.608448,-129.059659,98.675853,163.090016,103.357275,16.366057,23.685183,65.027167,94.331641,204.448314,261.692694,283.217589,115.315533,7.96758,-90.100977,-57.985348,79.938384,126.570106,154.045546,161.1303,153.093513,73.115064,23.574569,-35.53726,-46.639818,-58.065398,-47.08162,28.770841,66.475289,36.486844,-83.108913,-117.276425,-71.619556,-52.961082,-103.476259,-113.195297,-42.936302,-30.292555,-59.272704,-79.889272,-63.554989,-1.484339,51.990288,176.541678,199.844995,162.671769,55.41372,12.326674,2.992338,28.523051,82.530278,102.89094,98.542338,-80.633501,-226.72164,-367.776213,-321.904348,-234.463602,-246.359514,-252.99386,-142.054601,-87.192142,-79.899736,-118.851556,-214.329289,-257.690513,-287.328843,-260.282626,-211.266929,-219.535543,-210.095577,-173.975145,-162.927507,-139.803114,-116.510865,-51.849532,-8.573897,-12.37083,-43.505796,-33.726528,32.867709,44.508797,18.244345,21.597296,43.584518,3.353721,-9.158454,7.557416,8.439576,13.090498,49.209813,126.430974,76.168232,21.248889,-31.470934,-6.230866,87.151581,110.921398,103.648641,95.654757,77.312726,30.395148,-29.245918,-168.554033,-181.357144,-78.849291,-9.220988,80.21714,36.956213,-9.64862,-83.378173,-101.780956,-90.876877,-82.582386,-70.17705,-58.119818,-94.623359,-225.650717,-281.243028,-288.961745,-252.31445,-189.323015,-153.283131,-31.092635,2.138954,-41.991175,-139.725504,-153.0237,-96.111592,-55.857669,-28.21989,-38.316071,-60.745905,-53.839649,-31.645375,50.146778,104.923576,196.033798,213.833434,229.084937,254.228889,233.186191,80.406037,2.408622,-26.058693,6.997786,69.165319,70.591632,24.524146,-13.768792,-32.255178,-53.714049,-37.220623,49.548781,122.394626,296.139746,275.983111,160.084027,-83.767767,-129.486216,-77.001694,-30.359099,82.534353,138.081695,115.197425,-30.98124,-88.455502,-168.758296,-179.918123,-94.345521,-9.815201,113.108922,25.643512,-64.232333,-165.119604,-154.508747,-84.287799,-61.523789,-40.96715,-32.323583,-32.069893,-35.724952,-48.497453,-109.060428,-126.770001,-133.631338,-133.354083,-117.83422,-128.081494,-153.941696,-216.478895,-221.572831,-152.022757,-98.469371,16.281377,63.230648,99.181844,78.543601,40.990365,-33.144743,-24.736504,29.335087,45.243929,76.115328,59.692746,27.462689,-56.753758,-104.19305,-167.960831,-157.808471,-33.700129,29.700167,11.485099,-114.870668,-158.8618,-157.148629,-117.087796,-45.006119,-36.660779,-43.303742,-53.040269,-75.382076,-153.048926,-174.509065,-112.952984,-41.615972,91.599912,128.326611,112.456379,82.730481,128.773849,272.838172,306.916869,285.900973,265.413626,218.305418,157.084768,125.487431,19.938566,-30.339388,-23.788857,16.739539,80.173378,89.881785,79.451118,42.07746,0.149685,-71.949333,-64.781332,22.557479,93.84354,228.248227,185.070074,124.46935,77.299581,94.213569,168.56553,234.411626,381.673059,402.752609,319.345824,220.46424,176.047632,155.310481,208.757628,338.156009,372.189197,360.921371,232.159767,157.663484,53.497152,25.764076,0.105915,-11.388694,1.133887,39.862636,87.670739,4.758143,-48.696781,-45.370978,13.220243,100.641959,100.646537,64.258704,19.186503,-12.788447,-65.904863,-57.625859,52.078962,130.186795,242.273512,246.772895,159.256767,108.766357,122.884542,174.427877,214.056894,289.983264,299.899027,292.414584,256.319477,212.408441,96.126433,59.820535,124.758169,194.555712,260.151732,262.167325,303.56234,369.420868,354.733393,244.518131,181.308208,67.37664,43.62438,50.552212,-51.940193,-148.884805,-328.327907,-387.907146,-382.863992,-320.053156,-169.697622,-118.73964,-108.997217,-146.073849,-150.176333,-133.167942,-113.553595,-32.312108,32.978657,138.069399,98.673587,48.425596,-35.652238,-58.111091,-55.060558,-41.83938,7.527121,45.811542,108.519543,126.718939,115.477373,79.442821,90.946867,190.510317,238.573465,224.132261,97.590917,66.629196,72.058364,55.066633,-4.598195,18.723013,167.865383,207.581828,132.134139,-8.948346,-54.907079,-35.614575,22.061762,102.169088,95.811895,10.912721,-108.430534,-132.015297,-89.321144,-38.931069,100.660803,155.019538,185.957488,181.203143,146.436499,69.866744,9.911827,-116.718214,-145.598792,-88.031379,-16.604122,83.622485,25.192579,-24.12349,-129.136156,-193.656757,-270.526364,-262.239208,-208.365659,-174.803213:-24.015313,-161.528394,-197.946767,-161.876935,-114.600045,-4.222388,56.315116,112.210967,37.402971,-11.969869,-111.533764,-145.414292,-105.929237,-36.065047,134.564095,185.564576,128.959147,-26.895102,-85.069067,-90.334777,-22.436451,159.769987,215.972618,189.820312,42.065887,-25.3307,-87.129745,-67.250094,41.117777,93.413598,156.136033,166.975352,142.643472,72.217463,23.346807,-39.338134,-34.687736,-19.202907,-7.816756,46.46206,31.925962,-14.873832,-109.400496,-103.064277,-4.433484,16.577103,-14.384083,-30.107703,-43.038713,-47.140558,-63.39599,-71.297461,-26.578805,121.690558,193.780252,260.546737,179.270849,127.603661,111.73961,129.243098,140.419583,157.545956,249.391693,273.544045,175.120153,-82.501831,-220.587052,-355.809845,-335.149133,-230.792087,-180.586071,-125.158447,-151.031638,-161.487387,-134.112183,-106.83626,-90.398101,-112.456292,-128.105791,-110.608809,-117.523977,-169.152596,-171.198108,-124.821633,-104.128283,-50.596862,16.78872,117.011505,18.544274,-54.97121,-127.991298,-87.869218,102.471008,172.387021,197.469087,183.48319,131.105989,47.005144,18.650487,38.037036,68.562732,133.389425,178.310946,240.844065,160.410446,87.23381,6.4508,26.024877,111.09096,139.635016,185.815301,201.856261,167.883064,68.604145,2.386777,-95.940107,-91.806009,-11.809847,35.695348,110.835282,113.694094,74.346265,-48.066972,-86.336409,-77.828678,-50.528631,12.389999,24.406797,-32.135601,-154.520712,-209.57733,-167.439328,-82.392158,8.121193,10.983667,19.313211,-20.436122,-66.155521,-166.483511,-195.91198,-158.408945,-97.897286,14.788358,31.347911,-27.910376,-104.325966,-118.95335,-93.121181,-57.437046,50.385579,118.617013,194.7898,141.783827,112.68918,51.254966,7.046915,-45.143911,-32.048541,58.525057,88.241216,34.135393,-34.662559,-43.596853,-32.349389,-13.84698,55.030878,128.065084,274.048973,166.037303,41.125752,-130.156082,-122.968847,24.167509,96.384477,189.656416,219.665595,200.695562,59.415231,-39.250715,-171.461011,-157.382982,3.530739,103.596715,212.095886,111.13319,3.764905,-148.734708,-135.234599,-25.789685,-7.10378,-25.699195,-36.630423,-72.10809,-112.962099,-149.015667,-165.630757,-106.74449,22.460031,29.040839,-66.249122,-181.53757,-221.809422,-235.884368,-191.006955,-54.718545,-1.071626,89.055938,133.365287,156.236984,70.12564,12.081546,-69.120132,-74.140303,-21.840075,17.486939,81.062315,114.00234,104.857878,-6.396238,-77.08244,-123.987722,-78.734141,102.075555,171.699229,124.152304,-67.430164,-120.801594,-96.07195,-42.487268,86.102898,114.498391,28.032991,-111.117387,-139.037378,-142.944726,-129.785457,-38.356337,35.312489,175.300491,203.448123,141.530402,81.381041,103.098589,214.431029,266.052444,310.640286,321.855031,310.711943,189.191075,129.15337,47.570968,22.826128,63.843579,119.748251,181.25724,162.880415,89.46698,34.311732,12.405676,-2.41033,3.55825,55.904984,124.414068,253.89379,214.608193,174.063042,135.868864,138.889605,214.218987,283.880862,420.545501,449.920041,383.853254,196.834501,105.137538,52.917534,104.434016,277.806592,361.378518,408.854359,244.188532,142.379245,-14.633393,-59.281319,-62.546682,-35.333139,51.062533,81.217667,33.647503,-61.240089,-76.820285,-17.384488,31.670354,96.458196,111.057001,80.426911,-43.467631,-120.269884,-207.284584,-177.890864,-7.085407,75.892517,163.777717,162.790568,43.077099,-92.147107,-95.861793,6.224106,61.52893,135.434777,174.206704,217.60425,104.261435,20.358218,-110.564156,-127.445553,-24.343339,57.8048,209.058016,250.650234,208.631467,75.950727,20.627812,8.065266,40.678654,100.017824,120.755188,132.777442,5.187746,-108.420009,-315.049793,-360.884714,-317.591556,-260.166049,-120.40998,-59.774098,-27.052265,-77.469355,-97.773696,-80.89269,-60.197901,-17.706252,20.379328,73.420795,-25.797845,-97.339514,-141.017504,-115.688543,-83.541655,-80.905503,-40.032324,-18.3584,-10.755612,2.648795,-8.349556,-78.263401,-91.153937,11.404997,94.259186,115.63413,-94.925298,-162.82422,-150.943771,-154.520684,-204.566879,-175.140782,-2.751106,27.70362,-159.592966,-383.766604,-434.778255,-427.626607,-366.300195,-160.792136,-72.929487,-100.222899,-306.007195,-375.624762,-370.370191,-305.902647,-132.354267,-40.451534,120.581888,135.886465,-30.696307,-248.123452,-296.253947,-271.724427,-224.638597,-122.153735,-80.587921,-46.470358,-59.493986,-84.01007,-251.09093,-353.716784,-408.585247,-368.999506,-285.346556,-256.018073:-57.97297,-96.188293,-135.40513,-175.372206,-146.821813,-34.671619,11.860925,49.616813,28.165069,12.681648,-57.004832,-108.804982,-140.198121,-114.182186,-22.153532,35.558831,72.850804,22.711712,28.678221,91.285661,120.137835,167.13993,193.192147,243.969356,243.015022,207.997436,99.671767,59.659756,58.726478,85.362229,138.00653,154.781435,140.214109,72.594292,33.419657,-2.017912,20.667196,96.658621,120.15681,117.072693,129.622048,162.167432,148.990486,91.416316,10.962967,-4.089471,-15.846045,7.39687,84.814734,92.586075,58.458759,-21.570342,-8.656298,138.431527,207.175398,224.095701,153.453701,120.617906,78.971764,87.131592,151.209669,165.779111,150.32238,151.396479,123.743534,-22.379099,-131.514578,-357.064265,-412.973553,-330.965062,-219.813623,-41.483892,-86.072153,-133.902952,-172.467743,-187.541279,-232.741616,-241.485831,-171.067615,-102.689323,-58.703667,-156.361727,-171.512101,-107.197371,-66.155419,-0.177131,37.976499,116.690727,86.496989,34.889136,-52.533424,-75.563184,-113.925546,-148.540184,-172.733513,-121.762588,20.272248,58.257332,26.638059,-47.321017,-41.192204,22.404406,35.208027,25.202664,13.791235,-1.07957,-33.059147,-44.440479,-44.73969,-26.362631,11.52047,19.257188,-11.170525,-109.391982,-177.511726,-311.607251,-326.752515,-198.047328,-98.350166,11.355072,-82.904804,-159.455166,-251.511474,-244.176636,-156.940448,-137.337788,-179.115122,-191.855886,-186.734643,-194.952414,-196.397503,-202.216418,-212.16108,-207.40159,-179.356932,-123.380836,-123.568907,-120.604825,-97.605843,-106.313788,-132.060176,-107.729173,15.630152,64.329656,36.982666,-24.813624,-16.455484,65.420231,128.313147,218.156734,233.018026,285.975113,298.96813,242.857961,69.915517,2.78816,-4.968513,31.430588,53.85791,35.637169,8.751855,-7.228069,-21.509734,-4.288248,43.261892,130.198214,158.688312,237.936821,213.325843,130.94009,-59.388317,-117.373191,-125.277319,-88.92726,58.418336,136.322292,152.732546,80.790544,83.40923,116.706631,108.449278,82.303337,95.151903,132.995904,88.829839,38.258507,-74.077209,-115.645368,-118.320778,-84.184711,20.5019,62.435225,40.154975,-30.574868,-52.28527,-50.299039,-31.289698,-35.828757,-33.919986,73.209972,40.981664,-61.792728,-175.929862,-152.419426,-86.585376,-57.971182,91.627911,181.251007,225.454324,169.172391,144.047721,114.681095,127.397542,157.873219,142.871254,82.87016,45.858834,33.411837,-27.974918,-80.476008,-144.719408,-118.141574,20.288015,73.361833,90.956629,86.72472,76.177641,41.866081,64.700531,232.084813,325.262926,363.657188,207.801626,140.65734,90.993483,78.411086,77.77004,103.951142,200.21453,239.089869,213.69,212.268216,269.076417,390.378099,432.449037,468.901916,443.717382,303.658145,137.12124,79.308279,-0.502969,-40.19251,-85.12986,-84.157265,-43.648499,4.366592,120.411186,118.199942,61.957379,-14.859583,-5.592797,14.813498,31.804746,153.343295,218.924184,180.935873,77.539665,68.508261,153.372171,220.533955,337.550296,366.61704,322.009897,160.809029,91.262572,133.937047,244.963461,444.421329,475.709636,403.335164,257.652869,209.043365,157.615385,137.700584,98.72903,61.507007,-54.772275,-94.15165,-65.736734,9.656921,11.678422,-42.061979,-47.48234,43.445376,105.246848,168.994365,121.742963,43.806249,-126.980787,-136.723047,10.203026,76.50383,124.116824,161.900846,235.987131,143.333433,75.811953,60.217487,118.448435,223.955275,227.81943,190.388401,104.869186,34.819053,-61.851678,-49.210964,83.663427,150.604871,228.755567,261.278508,282.059807,218.917642,193.408896,182.922695,184.174889,152.643534,105.656366,-52.812647,-242.294582,-327.535521,-466.310676,-502.797515,-488.975521,-468.207659,-399.852622,-345.732511,-281.19209,-288.6722,-298.482928,-279.231685,-241.187109,-142.756065,-81.091859,28.217749,18.430388,-16.152075,-101.605243,-145.969878,-185.030198,-171.738172,-123.66364,-100.438119,-65.144589,-75.372657,-76.505844,11.797829,94.244603,221.004673,238.395183,230.542383,219.447709,203.670254,104.505426,45.143412,81.628267,168.572964,269.597649,264.195856,229.898621,176.719402,124.408448,8.610096,-5.353871,45.756116,56.996202,-4.171806,-84.439724,-87.721059,-32.292062,-11.44173,-31.222379,-53.434862,-9.062705,55.867813,86.137528,0.684627,-24.434178,-73.48987,-111.556465,-141.245892,-106.545179,-22.09838,-52.337763,-93.029418,-188.451283,-231.408051,-266.691698,-274.472648,-297.705532,-300.439723:-90.444181,-156.420685,-207.342444,-266.175042,-232.117504,-70.202242,3.932814,38.364616,-56.73358,-99.698725,-149.035151,-159.369608,-106.935629,-55.258894,18.352723,27.287325,-12.064396,-99.229166,-120.158137,-42.284424,29.42873,132.78381,169.601562,206.859991,109.029981,28.22984,-89.14403,-98.407172,-24.515171,37.886014,154.795672,185.154107,167.096652,67.993635,-4.271935,-95.144694,-75.490989,16.328542,61.905122,151.909843,136.24369,74.236541,-46.968546,-56.185113,24.89365,69.764708,86.326194,53.713525,-31.987479,-74.39233,-77.415567,-24.696907,39.818733,192.306832,246.12371,274.070623,238.758329,208.872917,110.597213,82.720702,158.997703,211.540206,259.676052,257.253017,119.137704,-141.714261,-239.983016,-301.225992,-274.677326,-193.253859,-157.072252,-77.968143,-99.346924,-160.800933,-231.535651,-211.655704,-157.638744,-163.282222,-169.303537,-121.090543,-41.651563,-167.713374,-228.092457,-204.691953,-148.03613,-19.77003,45.94319,96.082196,-6.245944,-59.901286,-120.124619,-118.895297,-23.29094,38.493438,88.115505,77.285932,45.231573,43.791934,31.48097,-13.343435,-16.287493,53.187384,124.364715,239.857394,189.492214,118.198366,-3.265219,9.221955,176.658835,246.688663,269.784838,241.876905,105.059375,-68.236545,-124.280333,-158.044132,-140.138513,-54.326482,11.870469,140.136418,115.297745,40.385645,-112.542256,-138.64793,-97.091426,-85.042448,-91.477897,-78.378009,-102.700685,-267.983965,-331.525717,-320.425967,-276.840866,-153.68773,-71.799258,33.044225,-30.659075,-89.223912,-167.621759,-174.606633,-144.991593,-125.748931,-68.686912,-33.731966,-17.205914,-56.45799,-55.636564,17.006142,64.214376,108.294102,111.115664,141.510573,202.909803,192.489034,36.756012,-46.273535,-79.857644,-40.377363,67.309068,86.776079,4.262297,-77.060606,-84.130376,-70.733101,-53.016772,53.345425,157.7713,317.703439,179.865063,52.332873,-127.308693,-150.874708,-82.474873,-4.237161,214.865733,301.518219,245.174356,23.248552,-41.664744,-82.828821,-84.856103,-23.691832,67.629626,255.407774,164.041131,48.042748,-89.277285,-88.526471,-15.998117,31.948587,134.745004,158.644372,55.499158,-88.380318,-116.05744,-135.362622,-124.7742,-63.763684,-40.474361,-43.692568,-112.382387,-152.750498,-172.511215,-142.797429,-61.957017,-26.173902,69.975401,129.977668,184.813018,105.499656,46.70896,17.995,73.565287,219.466075,254.975807,231.388421,140.654663,91.100896,2.547509,-30.136186,-63.969355,-57.883667,31.176924,76.620635,67.674132,38.923602,33.05778,24.655716,62.867777,250.245125,340.995501,337.629313,105.116806,-7.236568,-112.426709,-96.915337,41.75461,130.529656,271.828651,288.787632,163.864867,51.763245,81.346074,250.577458,331.532437,412.518073,424.117679,388.136637,231.189513,142.103836,5.364591,-42.018853,-59.892228,-17.093167,118.004362,153.469141,92.751799,-20.345345,-50.209218,-30.557608,10.733982,80.546063,110.113215,183.379686,153.222051,86.956858,-29.493223,-25.640657,134.344235,245.057702,374.902515,363.835804,239.159714,108.134088,59.447081,47.052677,100.500129,263.357474,341.664696,392.124086,225.269941,110.066234,-55.209212,-79.454731,-60.290956,-57.441886,-28.285753,4.120785,-15.565476,-125.023945,-156.373673,-146.140762,-103.125724,34.391572,82.818969,67.872321,-17.048451,-87.199896,-252.323248,-269.787196,-127.337483,-30.484053,98.216757,111.740129,21.152016,-99.679757,-124.41128,-90.354855,-47.574295,39.501144,91.928887,180.60818,117.309457,35.127965,-140.312782,-182.06318,-59.002128,62.899235,227.185647,249.49035,191.43197,76.094582,41.312734,58.438031,87.991633,81.793889,49.414267,-6.20454,-76.076195,-147.381032,-375.531496,-470.900131,-430.148808,-323.261764,-142.218341,-109.961208,-150.01596,-207.004733,-222.943908,-215.047724,-179.642594,-46.155831,41.960621,151.43717,50.482914,-41.920344,-190.240497,-220.586161,-190.651024,-164.40323,-108.716018,-63.638697,-9.101675,-82.566363,-138.887742,-162.817059,-105.760766,82.638026,160.201548,150.637449,-28.679009,-92.285402,-126.77803,-121.470567,-62.48834,-12.260944,65.436267,74.616362,-3.034607,-225.192779,-336.99627,-413.946886,-363.301931,-146.643201,-45.42056,-37.659218,-234.784556,-305.372992,-334.027135,-318.156364,-205.404521,-99.677155,81.2917,79.882594,-100.790867,-249.576741,-273.659481,-286.648787,-278.813627,-198.063541,-127.422315,-47.261884,-124.186226,-190.340636,-363.702259,-436.535683,-428.333002,-381.02704,-324.029645,-312.850569:-96.384217,-123.805335,-145.594841,-114.140959,-70.293836,-49.827898,-70.679426,-47.094752,30.479908,37.241251,30.998687,31.364195,-13.380832,-45.927759,-23.599311,32.674473,110.048301,90.071369,89.338414,140.094472,166.354584,190.258907,204.938802,273.736923,275.726875,208.466873,45.782116,19.133802,67.264574,87.067776,115.765727,138.342044,88.08096,-49.845717,-80.656665,-59.973296,-16.279258,88.289266,108.625118,110.584743,201.800951,256.728016,219.774416,135.284364,0.469744,-19.801215,4.797844,37.54822,98.093536,111.932814,110.521036,118.154977,128.031667,130.223283,108.757809,74.069246,96.683863,106.66837,135.306025,155.235629,137.730265,96.984531,57.839579,82.768434,123.113836,13.35427,-82.443357,-241.951721,-265.445441,-216.170287,-185.461591,-157.014696,-121.488075,-96.279772,-107.355856,-126.368181,-75.168364,-31.492458,9.49995,47.495539,182.910289,209.51667,178.155372,122.971667,120.930417,151.788251,159.169353,129.849695,62.613031,39.163336,3.271102,-25.717906,-92.775576,-126.255771,-146.631493,-111.696951,-10.877853,39.550908,29.396108,-70.624751,-118.930492,-136.95716,-122.359411,-73.660322,-24.603251,-16.966698,-83.828262,-155.497682,-233.26442,-200.808427,-83.464509,-62.862107,-134.209475,-192.234905,-198.613169,-201.106378,-188.705109,-170.895786,-175.043209,-164.607797,-173.564922,-195.336836,-239.629885,-272.014703,-328.067203,-314.897829,-222.84638,-190.591954,-167.599359,-108.144241,-76.866657,-54.974176,-52.68485,-71.745064,-100.568701,-139.302184,-111.128385,-78.393985,-30.291019,-48.24796,-94.058892,-70.575345,56.985018,119.194426,144.911426,114.231061,114.145008,128.910821,151.468586,197.020493,192.709747,183.910334,178.173553,138.342538,-4.367928,-79.03684,-128.183129,-108.831522,-116.377374,-150.002758,-176.776293,-90.518605,-63.923742,-115.508195,-130.845547,-59.256217,-2.887815,102.812047,72.94982,-14.513202,-195.679693,-252.221787,-259.19092,-198.080191,6.659671,97.425548,201.873563,277.255107,287.493546,185.618675,104.318931,-11.642403,-9.13823,132.296349,125.044169,10.477781,-192.56942,-224.071978,-194.105329,-156.204889,-62.41625,-16.69586,38.140183,53.567914,35.00635,-48.31687,-49.667173,75.429512,147.525828,197.605905,128.595229,94.711671,77.737577,77.724464,68.818212,78.793813,185.255109,274.848404,412.112065,425.219881,418.133023,371.93239,327.515713,270.352794,281.478936,325.071661,189.334443,53.344967,-145.172778,-183.73136,-190.466973,-155.155955,-13.622813,66.324403,170.919724,228.999884,255.330595,245.471207,226.657229,296.356345,377.851376,462.767537,387.114711,332.070886,240.892709,211.856094,199.799135,220.96229,316.055097,366.226789,403.714775,426.093171,459.417962,552.301039,594.247024,564.00014,487.192901,339.997992,243.501274,184.780874,-0.292655,-108.867621,-255.739138,-279.32506,-211.96051,-127.396199,-16.750764,-99.997269,-138.346202,-72.94864,-14.420818,3.781389,-4.523391,73.670563,127.556114,89.197452,-11.256722,-14.92743,65.407032,103.799185,199.724601,285.951851,374.220658,221.656295,154.945807,190.806412,259.470761,387.468184,430.530478,428.52711,317.387452,267.208848,167.788139,87.05237,-73.217648,-106.171204,-109.256355,-120.823291,-178.811373,-181.245543,-164.116042,-146.358226,-117.948762,6.544952,76.904803,185.24042,184.874174,128.732973,-22.787161,-63.507067,-26.577156,12.679521,33.60272,3.891372,-126.698649,-256.72815,-304.027668,-361.65807,-346.024458,-271.279956,-250.90243,-240.464679,-282.955088,-301.894484,-256.271166,-195.1478,-34.41528,29.808043,50.902169,29.535152,19.869068,79.911764,108.078897,108.811648,89.833982,49.802396,35.151915,-10.794979,-142.116946,-235.18,-406.350327,-452.407848,-445.166313,-436.758923,-465.830719,-449.442195,-316.377444,-248.008005,-292.945096,-428.056463,-436.062936,-318.943939,-251.076156,-198.898794,-233.964745,-247.698102,-277.419717,-311.355062,-349.310925,-331.555236,-292.360951,-292.181386,-300.442506,-235.115321,-171.942482,6.036318,97.649195,184.582096,195.539857,226.58253,209.395373,172.015223,89.857506,72.429717,130.724276,182.935168,238.092662,249.058518,267.613811,220.522651,169.382011,71.017674,49.372171,77.473299,101.025043,40.786113,-134.379464,-190.849713,-209.001075,-201.18762,-205.600247,-214.445532,-227.36151,-235.870282,-231.705661,-191.662018,-210.459689,-323.667479,-357.745607,-365.363463,-358.195898,-271.479903,-162.025995,-165.920583,-292.309325,-354.402074,-355.468368,-331.744673,-365.086818,-399.134566:-34.958879,-120.605642,-171.538192,-130.704887,-57.357591,67.842284,102.969304,162.089286,197.595811,179.802685,79.075207,24.741517,-21.271282,-0.948753,97.167972,133.331584,105.019538,59.093504,61.928965,68.674541,70.789438,118.275791,171.25038,278.178389,236.737944,148.83417,-33.188504,-85.818875,-154.472054,-172.011451,-84.000953,-6.818936,38.039607,-14.0953,-29.115574,-42.238731,-35.058404,6.579191,20.793352,43.496024,94.059545,111.48913,86.628217,46.499381,-35.067752,-48.5383,5.641002,62.095569,166.119923,193.885865,165.399393,43.856061,-9.966632,-45.663906,-36.072908,1.616746,9.746193,11.649517,58.619664,80.367863,68.381521,29.587637,-70.095065,-86.225985,-49.852488,-27.926336,-60.93517,-208.176082,-258.714413,-246.700805,-205.965253,-106.962984,-96.683924,-124.520738,-166.968406,-187.450047,-226.539998,-219.667522,-133.661619,-68.300041,36.4917,21.201686,-20.315694,-83.323701,-83.50595,-36.421454,-7.980365,24.149748,-5.215787,-2.478537,63.908781,69.997965,-13.282554,-71.46556,-143.750725,-135.180099,-58.131097,-50.150435,-108.915806,-247.017891,-260.114428,-192.483975,-160.75575,-118.118228,-69.267282,-55.931149,-143.779584,-225.573521,-265.4994,-224.757564,-166.44881,-163.156941,-189.064236,-210.525687,-232.289788,-294.591737,-292.47062,-195.640474,-126.258619,-40.378373,-100.348923,-138.187543,-197.148228,-240.651799,-267.414643,-235.958057,-176.886678,-158.003061,-121.661839,-95.070789,-80.246568,-52.641261,-61.734165,-137.56157,-175.325146,-200.894005,-193.265586,-170.273123,-112.249227,-109.87484,-126.863004,-120.363984,-61.783385,-2.449472,104.538034,70.624597,29.183699,-8.352889,15.275791,117.242161,159.795807,194.243333,151.026369,110.089941,21.170327,-25.668471,-87.691884,-96.227067,-100.413313,-106.383327,-114.234671,-39.860974,9.553473,39.05827,27.325773,20.236289,50.315353,148.717869,127.519271,74.125618,-34.570977,-96.10989,-206.001267,-213.459728,-72.065808,36.963607,146.334044,153.857509,160.84413,106.379526,41.423372,-34.730268,-16.215679,36.863624,-56.94277,-137.860557,-205.03169,-171.910507,-71.469351,-53.719899,-40.016202,9.348308,129.176875,80.111332,20.97982,-22.036193,-16.335628,-16.235515,8.942689,108.802971,53.47622,-23.978415,-112.129403,-113.224071,-66.024925,-14.678086,123.632618,185.41476,234.543247,224.820235,221.706613,200.330467,183.664924,149.175398,137.827811,151.671571,110.795508,47.826823,-85.868607,-135.299623,-172.356399,-156.988731,-44.673739,43.037407,145.952771,129.659052,129.725156,192.357962,251.137207,360.846712,389.298004,380.111177,281.390633,225.283266,144.489339,123.089587,118.155416,125.167548,169.476229,213.587744,261.078311,211.419738,184.194967,187.482537,219.125578,260.530567,269.097809,281.216796,148.592525,43.127321,-126.837151,-189.533782,-249.245519,-237.696686,-156.371466,-101.333534,-27.458661,-36.400647,-47.261992,-15.25309,17.831283,52.571404,61.198138,59.29118,-13.772343,-60.238844,-113.271399,-107.544582,-50.556942,4.393718,186.079277,281.917296,366.963982,227.616835,128.964492,102.883082,181.813701,306.125299,311.368039,316.64889,339.111029,330.276079,230.735031,150.02924,32.778685,10.76888,-2.145245,-9.826117,-21.724446,-2.118256,-14.089239,-83.994465,-79.454361,4.887828,28.359221,90.330239,229.622635,269.237976,236.357149,194.207678,151.371964,154.717767,155.012116,138.324062,104.295441,84.84532,48.613864,-30.193213,-6.212124,120.717144,139.421373,54.021626,-49.168136,-61.933498,3.399348,44.118564,97.157209,138.199177,262.149358,308.907422,340.074396,352.553491,349.628303,308.588961,284.492583,227.917671,182.143248,78.807787,-18.230537,-92.429976,-291.583268,-376.154764,-441.16176,-429.511018,-360.9522,-315.61682,-249.202569,-216.776436,-198.819251,-185.425824,-194.046336,-177.494674,-121.680804,29.135509,44.768414,-0.738014,-98.333965,-127.211099,-87.855008,-33.855077,10.018458,-11.010767,-69.168492,-40.343219,2.004287,47.178781,50.906729,83.829622,139.308209,307.849838,402.437747,406.394437,374.344708,346.9897,293.984067,286.037523,338.994788,386.601606,406.825404,285.942608,212.154618,117.045615,110.791396,154.359942,182.515302,189.80951,125.879805,91.712643,31.124926,14.258506,13.076008,4.523511,-9.658772,11.62741,52.31238,-5.174324,-56.264397,-105.531231,-88.071571,-64.750716,-76.976596,-63.855104,18.362839,32.597062,-77.843808,-149.85967,-182.60556,-168.74484,-161.356072,-158.328058:-102.922108,-164.567095,-230.359647,-270.408234,-204.615027,-22.802274,20.794944,0.130688,-73.420827,-110.016265,-171.540208,-192.55667,-192.077721,-175.531708,-108.385554,-66.250419,-39.486645,-66.467772,-64.211026,0.935762,44.976673,75.873925,85.491004,175.094298,209.669481,169.35638,48.586086,6.058307,52.449913,129.230463,211.144327,176.963237,49.349744,2.362233,-0.141137,4.452252,22.407452,62.871468,83.967264,173.01073,242.483648,238.065957,174.821619,142.965001,82.843214,19.878815,-85.824613,-60.297219,68.57067,59.345986,1.561421,-46.22561,15.105543,190.672609,218.977945,142.150716,62.984163,70.736693,128.813252,144.51136,155.260764,170.930153,221.393222,219.105895,104.882242,-43.407101,-107.205344,-220.103408,-240.031381,-176.000593,-122.261597,-31.621213,-26.342229,-70.922868,-183.566764,-229.996079,-256.956556,-223.445312,-91.897311,-19.374741,60.447335,35.864503,3.547659,-70.44058,-71.844585,45.770475,120.397408,155.979644,38.358136,2.062874,23.561436,29.166424,-42.13803,-100.216455,-126.402206,-69.406086,64.336684,116.7947,91.576432,-6.195434,-19.383349,38.7636,77.275174,107.478079,77.644956,74.676087,83.543583,69.24525,77.729153,125.598177,197.416654,179.830029,73.721819,11.860978,-14.263428,-119.341889,-166.203181,-192.566162,-165.0,-30.517009,15.742572,-49.905939,-238.319594,-281.477779,-199.566036,-155.154436,-207.029416,-241.14232,-219.174742,-200.349144,-217.246095,-224.931167,-190.208923,-109.378568,-74.734639,5.829818,-27.56011,-90.142915,-156.194739,-147.156423,-98.293567,-66.842531,12.396886,64.018978,122.852353,35.763323,-11.626559,35.67347,120.528542,240.984364,244.708097,238.725455,231.080964,188.886555,37.968366,-47.818428,-160.088968,-175.045606,-137.909712,-96.484279,-53.864674,-89.588069,-108.109425,-118.647957,-99.345947,-17.197552,26.960284,119.965395,139.123284,78.956794,-130.970018,-227.478747,-274.842737,-209.38723,2.187991,76.130286,96.152417,77.283529,77.412195,44.086484,14.733696,2.125138,46.066574,196.564486,193.346893,112.79952,-37.541321,-77.09711,-97.923305,-74.323605,-4.169373,4.017878,-31.414278,-34.219256,-33.879908,-80.345576,-92.3409,-50.555814,-25.275358,39.059019,107.509834,102.053855,21.589423,-24.285759,-73.200969,-73.673609,-16.888213,33.451558,107.143552,145.241464,172.831293,224.017094,242.88773,251.838486,228.025177,146.635805,26.632408,-41.243635,-146.824605,-192.835325,-273.517174,-276.515153,-121.682011,1.722553,95.197474,10.179403,15.591443,139.064624,208.215226,290.076472,294.239444,233.542655,89.159355,9.675482,-68.439233,-48.507321,105.046554,215.20865,365.306069,350.694282,170.954127,68.219621,116.460292,327.608728,411.825042,410.831186,344.297821,223.843432,200.151551,184.899813,15.332515,-105.789401,-232.404504,-217.769031,-96.033678,-35.801325,-10.602003,-80.182697,-113.163067,-119.449149,-80.037009,35.404537,75.210242,104.925269,127.922044,125.545716,63.700117,42.179727,138.48126,242.197782,380.06763,379.196929,324.357631,224.106286,144.27981,57.618812,100.662077,264.09243,317.838544,348.944068,312.086985,266.323372,181.8091,155.574532,70.809994,11.172329,-50.057277,-33.640021,17.009151,14.131332,10.159066,45.846792,93.56077,165.724952,166.176739,169.547483,109.240933,11.865203,-171.439573,-185.872675,-69.746884,-13.117516,-9.438345,-24.083859,-29.467906,-59.474643,-79.890563,-109.863001,-100.564862,-39.217188,-16.63531,-2.804416,-36.045293,-62.347645,-56.495226,-13.368001,75.834792,91.308316,125.179915,169.284787,221.499878,186.254692,169.530614,140.317229,114.404061,42.52651,6.990271,-39.588866,-103.30278,-169.087064,-358.848351,-433.352011,-412.713507,-341.722687,-226.878073,-200.828275,-191.19916,-217.025021,-250.162304,-329.480203,-327.862698,-189.204905,-104.25012,-13.65895,35.961919,50.069737,-23.708179,-112.675847,-230.646729,-205.54496,-70.097297,-25.072369,10.49907,59.622586,61.252037,39.649863,72.533313,208.258354,247.583634,210.45022,167.361213,170.356257,115.893091,64.295185,50.844061,105.596709,259.420834,310.088764,291.245271,182.305579,123.606325,-8.566931,-54.278368,10.370824,108.2039,234.557969,123.307802,26.892472,-156.833983,-208.516812,-146.477533,-69.269818,35.045114,41.452433,-46.850329,-174.51425,-213.207182,-237.089623,-218.400231,-156.867223,-150.102428,-165.293435,-121.718981,-105.346418,-215.605633,-305.175267,-343.866987,-304.899898,-280.135411,-296.342201:forward
204.965066,255.624544,179.15361,56.813873,81.646708,102.240223,31.744217,-140.207986,-189.264964,-166.632119,-166.775694,-238.060678,-392.365249,-406.065995,-362.734786,-335.778631,-214.873112,-21.968426,52.30082,62.855238,6.727426,-98.085338,-117.727685,-124.030261,-83.661305,-57.737688,-81.199294,-126.209261,-183.41795,-180.05646,-194.149437,-215.541954,-167.304538,-56.307857,-34.94051,-54.603397,-96.054901,-195.776019,-208.191385,-136.876866,4.36747,75.437421,143.314025,130.89647,63.205432,43.370064,99.926344,164.418769,291.83035,369.300356,385.863638,365.962295,313.171867,199.432827,200.808349,259.07538,256.649914,242.707215,200.118999,176.78268,117.17161,89.029684,117.445993,170.533263,262.842907,255.760179,220.226199,119.216411,45.79698,-112.362405,-156.004619,-117.876605,35.989376,102.165088,149.161088,144.38608,88.837525,48.376703,34.72132,68.197172,146.942734,181.325504,185.456553,157.149642,105.138929,20.965016,54.078458,209.779926,254.913804,241.507893,245.99497,258.597647,218.288792,172.777048,165.963665,219.389576,317.756255,229.838078,137.537341,7.871099,-29.091612,-107.615345,-136.519681,-98.91805,45.253361,91.955961,78.079526,45.709061,-44.987184,-83.156702,-20.448428,66.812096,195.813159,231.579679,231.061734,182.401151,118.743543,3.069639,16.518018,122.006046,125.199082,86.830579,37.295572,33.080452,-36.551506,-93.974186,-118.47742,-70.271111,70.093889,37.766829,-62.675554,-185.974551,-164.090471,-114.845294,-120.809337,-98.979362,-53.305979,-78.416826,-111.307282,-66.842185,-31.048989,-83.669893,-108.305991,-23.312492,167.253275,155.121544,84.332164,-29.221164,-32.625797,93.595682,207.173426,400.83446,442.463027,411.560483,303.063332,259.299253,228.950077,223.596491,208.669791,219.415382,323.792328,382.634499,308.95635,65.862718,-8.40832,26.147081,97.629178,196.022453,213.028334,195.764037,74.047417,-6.355213,-108.643066,-103.438283,3.452139,51.326874,78.361718,66.237626,54.408308,19.935455,-21.9217,-87.96845,-68.745149,2.969949,47.717877,73.914501,133.655124,165.124078,194.238638,194.054495,194.227891,177.02132,131.401901,90.334005,64.112532,41.56685,38.369619,21.182479,22.811082,93.691991,198.881949,214.712029,206.966716,225.080803,246.402166,212.400203,152.06993,186.069328,356.38779,432.762656,400.53924,364.553654,363.877494,257.833835,198.083953,214.323883,327.020497,374.094597,382.903169,321.758744,144.717544,113.294564,214.666482,279.243584,309.363094,225.242242,161.823529,48.32592,-4.830229,-76.409171,-52.715588,66.813468,98.160313,77.775731,26.808747,-23.305293,-210.546211,-293.754485,-333.631778,-313.214686,-267.159644,-284.279039,-320.29898,-388.93043,-402.978723,-328.191208,-252.535515,-160.555221,-123.344562,-102.959265,-131.758614,-183.957381,-300.25576,-332.930815,-271.806597,-195.720608,-46.324325,59.380937,67.577548,-38.973645,-121.817005,-149.443098,-66.622401,103.68755,156.152811,152.175188,41.453652,-74.331729,-322.510029,-378.339581,-305.139336,-236.047318,-128.725865,-122.305924,-207.719525,-481.578309,-583.079401,-583.623368,-470.303449,-143.536553,50.92417,59.483327,-22.763143,-56.942872,-57.777201,-44.97808,-56.657252,-81.162309,-79.815972,-51.753284,-90.787065,-244.80492,-304.468593,-307.649961,-272.399829,-183.064848,-69.046936,-51.436429,-126.288679,-167.950676,-182.398477,-151.210142,-8.462807,62.80348,81.367576,0.31904,-43.834003,-138.902403,-188.919317,-224.307992,-180.470493,-57.727252,-19.236052,-23.201398,-52.599843,-66.75271,-54.796135,-27.894969,13.837993,6.502544,16.569549,83.10689,49.644649,-124.209106,-176.845198,-167.104298,-153.065522,-204.344633,-316.536765,-352.594985,-360.181846,-357.638726,-430.614929,-487.530052,-510.951794,-481.327054,-442.601503,-478.289219,-526.199734,-608.746968,-593.542017,-480.343745,-441.553045,-419.979634,-292.892054,-171.805855,-0.075029,-18.208797,-228.945781,-329.719145,-316.44478,-216.147273,-31.384967,-34.151553,-79.405844,-158.310023,-190.831138,-153.577748,-57.924081,104.159771,104.026644,80.809764,-1.386765,-42.362778,-22.40923,50.274523,261.988774,347.600381,385.664811,296.339177,217.756869,39.384298,-10.707164,31.48621,75.964228,82.405679,134.174666,222.636709,349.617677,325.03719,133.012559,28.652093,-35.036915,10.209619,117.504266,91.653551,47.632741,26.93594,24.733937,-50.637862,-80.454931,-19.858574,119.468359,149.789235,47.849664,-43.737921,-156.394553,-179.493431,-228.140595,-255.115367:234.998739,218.813872,167.536473,41.744083,-12.215189,-126.40098,-183.558262,-221.768975,-196.005271,-196.532369,-246.762269,-306.616826,-469.139952,-513.58167,-440.61575,-347.687029,-144.561159,-38.189237,-47.664315,-165.838672,-224.022266,-206.692387,-142.601519,-73.38101,-93.278148,-70.662964,-5.240053,-16.047483,-92.389135,-108.10927,-108.962254,-106.203328,-20.386442,141.723588,181.009476,109.601206,37.848325,-43.269977,-44.909073,-21.826364,57.632202,96.891073,94.004206,68.242547,56.202261,80.176478,137.834154,152.494081,163.208722,215.097088,261.891677,290.492925,237.262467,67.779389,26.196042,100.335914,227.364259,242.036662,160.022306,93.298702,-21.262128,-52.373608,-30.84132,28.826381,158.396475,167.143506,127.752992,-17.0787,-113.296332,-271.33579,-298.344899,-196.186973,21.658552,69.028325,-6.664294,-59.516984,-113.787556,-117.320633,-96.716801,-88.060401,-37.251848,36.045534,32.720922,-37.350212,-56.070535,29.513036,121.89783,252.853146,210.246111,150.475465,99.575291,138.4103,206.27869,184.394079,104.385238,101.957302,176.174642,166.285638,108.731904,-14.440804,-66.061918,-126.552742,-109.855012,3.641445,68.549329,55.649951,-22.564485,-75.702292,-181.018705,-196.21605,-82.131077,7.912854,118.040871,152.533915,144.411474,32.6561,-57.232261,-125.934433,-55.42534,108.971442,79.340095,29.887896,-21.727326,-42.056265,-101.251443,-98.505931,-16.336649,21.250337,43.883901,-62.316844,-151.916606,-249.650672,-254.612815,-232.608173,-190.096371,-64.954501,-44.345478,-73.880402,-68.603344,-14.303358,72.652745,74.085783,91.275468,153.841637,324.235892,288.875298,206.55757,111.158463,114.632328,176.54492,217.460774,303.916471,394.350308,409.978315,373.616987,341.409544,242.213325,184.334157,124.525383,138.969041,251.939338,339.101435,308.746424,119.204857,29.315636,-9.335037,16.080564,43.510979,46.989863,49.192405,-0.607724,-56.163865,-121.867773,-79.407041,105.567123,174.562467,213.807404,190.875516,166.227665,89.589684,48.147064,45.778674,92.523058,167.162654,152.273952,111.58799,16.950075,7.365051,63.773905,110.760289,214.739084,238.460348,192.450374,94.715987,67.81669,83.763893,80.85037,12.247529,-6.461449,2.854169,12.51475,31.936142,88.718927,94.954632,59.3902,66.10087,183.406573,257.252691,359.069332,378.355294,367.81004,342.76093,315.042048,192.770711,118.569308,53.473496,163.58059,222.710583,175.646816,92.354057,-23.404299,-26.996745,55.203268,108.913338,155.438028,82.69777,34.658311,-16.596062,-42.606307,-73.09204,-47.65724,21.668163,-6.78167,-57.084363,-127.822772,-154.216843,-310.787775,-418.683565,-489.752397,-438.079415,-314.004396,-309.344002,-356.612746,-451.879807,-449.588574,-331.199522,-259.028368,-162.477143,-85.553895,-72.329217,-173.534136,-257.22718,-328.196968,-278.813644,-91.548027,-16.675051,64.668075,135.445278,151.202997,63.078508,-4.814554,1.049046,56.70412,95.314881,112.703384,143.595938,121.95896,48.344384,-126.865775,-163.266161,-95.801012,-42.488163,48.049416,45.269638,-47.762195,-326.039903,-415.251704,-375.639593,-272.739523,-63.859781,42.887154,73.52324,73.771351,31.298307,-85.539064,-110.137652,-52.624048,-10.106862,16.788493,-63.067708,-123.585984,-226.132014,-262.188822,-257.614018,-206.667355,-68.395017,25.425093,7.696675,-174.089847,-262.912902,-244.606685,-151.45628,7.283782,45.129199,90.610968,22.344392,-43.427968,-79.363323,-68.349274,-86.462763,-101.114528,-109.244062,-73.209286,-45.463453,-25.254843,-52.510268,-152.906192,-164.498193,-60.757602,0.003301,57.93199,34.619874,3.925379,-41.83702,-68.471684,-146.901279,-157.923444,-78.810043,-38.472045,-63.352806,-121.22962,-163.970388,-313.698256,-371.947822,-391.341091,-371.18636,-280.578817,-289.091016,-368.42172,-504.200812,-523.60374,-494.253888,-435.623296,-233.017424,-79.736577,-41.094006,14.618312,0.56372,-160.567447,-210.05599,-49.416584,81.817599,180.539112,59.266138,-13.995973,-77.741302,-84.524147,-71.092707,-35.245379,91.862599,188.835108,179.217089,80.352273,45.152614,56.926463,100.123426,201.251556,226.89839,286.695084,346.129114,292.205553,67.074541,-14.495766,-48.119695,-26.469888,57.930136,168.850201,214.279757,260.335213,251.788744,149.824998,95.318628,111.879836,159.483157,219.779646,244.994036,257.43761,246.389411,201.032598,97.997713,81.958666,141.69559,226.537592,204.499103,56.749693,-3.756003,-88.22385,-141.115657,-222.03404,-225.097868:160.5628,107.650893,62.073455,-80.778111,-160.333773,-230.313808,-226.943836,-218.869945,-252.541558,-276.808086,-264.58671,-260.131552,-351.029283,-387.271161,-336.198252,-292.887583,-227.3085,-159.254865,-153.696586,-269.218448,-340.604542,-307.073699,-221.580613,-107.386353,-88.836308,-82.437362,-83.280292,-99.811313,-109.87151,-73.916689,35.268101,75.544093,138.350926,159.800293,149.041536,88.660818,34.768821,-53.79255,-55.351713,12.630622,108.086571,132.374161,108.295625,83.333266,24.373863,7.767464,72.785331,125.301702,158.839505,136.942747,143.119802,121.154078,54.940423,-54.20435,-24.61152,162.405407,286.788062,279.642125,177.022348,101.125366,-51.680535,-101.628803,-141.449268,-132.895852,-42.053573,30.884886,14.565413,-116.440267,-221.8447,-405.966552,-418.257437,-281.213448,-128.009469,-76.879058,-34.324323,-54.708465,-143.208957,-163.957082,-98.123672,-44.021555,0.12556,-43.300145,-62.896087,-86.7844,-106.148691,-87.817677,-21.346392,122.042012,138.252,124.077551,138.656988,156.914398,139.302627,105.267743,71.811232,97.011866,170.758645,106.176691,37.341275,-55.869188,-82.296558,-87.977517,-44.843211,63.193337,55.229696,29.556295,9.539518,-24.201217,-167.995681,-187.778151,-55.939475,17.482985,94.289006,121.953416,104.806836,-24.625532,-101.459293,-128.104481,-80.4405,-2.301353,14.30171,17.219096,7.181315,-26.011018,-138.831601,-176.12468,-125.721549,-53.644096,21.205975,-88.923264,-159.727452,-256.214402,-296.640111,-301.364929,-224.03371,-45.182652,-34.868144,-66.678323,-69.587175,-42.64492,-31.008698,-27.159302,71.302618,146.122424,221.2215,137.699414,99.021601,115.359936,135.81354,197.780035,264.663456,387.904965,344.828039,263.899722,120.269517,88.061349,51.987434,40.550498,44.355646,57.278981,146.042224,229.684952,209.678985,84.149285,36.099142,38.456959,54.824578,54.734604,13.69778,-34.086484,-155.891099,-203.367595,-209.567973,-147.557059,29.203306,81.551421,87.321235,69.913565,71.827054,24.747492,-13.668939,9.641247,64.792728,114.524249,64.934904,44.406848,26.147552,21.669622,30.174523,61.809109,140.538096,144.077427,107.722858,155.57024,189.543084,146.176141,70.443279,-43.852798,-28.5597,90.771455,107.992384,68.277914,2.326585,-14.229359,-16.346924,12.375939,99.782846,146.997262,252.281419,258.851003,226.186573,189.862979,169.037805,100.150601,99.107755,203.683203,274.515002,245.729367,84.541787,-2.458505,-51.110192,-10.886327,90.439082,133.56872,196.517249,163.040942,113.202476,-8.02952,-59.227437,-43.462845,14.757434,105.851738,122.287092,80.285004,-113.98407,-221.661273,-353.154534,-360.400631,-309.896818,-282.220954,-235.092365,-241.889373,-277.943532,-324.47588,-290.435237,-119.401713,-42.490297,36.003396,121.187523,141.531069,80.872799,22.649746,-73.189124,-68.916988,44.114533,98.07969,135.175468,133.118723,124.951724,47.823278,-22.000393,-82.257821,-26.716834,99.47779,34.875488,-14.118207,1.024768,10.54492,-124.323011,-206.799011,-195.986421,-110.570419,54.008086,12.032861,-90.497418,-347.3709,-420.190485,-302.486522,-160.256765,70.551701,114.111444,85.861835,8.891613,-39.459834,-147.925994,-163.40212,-65.501422,-8.348624,-0.873193,-82.74206,-126.36497,-197.497787,-215.837486,-179.61151,-134.624252,-69.163635,-38.310521,-37.947728,-75.317862,-83.904299,-49.782783,-9.214939,106.276207,152.170677,174.339759,94.733415,27.756426,-56.121935,-53.15571,-44.077375,-70.723009,-115.052262,-36.975507,6.730822,-29.503215,-109.535691,-257.115472,-252.693272,-83.321495,8.018089,104.001027,130.382322,139.02786,123.2177,84.52768,15.04709,1.544312,3.89501,66.484371,91.481282,36.935611,-40.639845,-183.783417,-204.839196,-198.367728,-192.988536,-127.317337,-98.467463,-161.015189,-342.940392,-396.927327,-422.008451,-401.778337,-264.815434,-66.215608,-3.108249,-2.926729,-43.97063,-123.666467,-131.201306,-34.437544,67.301616,267.577865,239.032408,160.013665,64.082079,46.253775,41.363749,71.190144,163.438487,192.377827,177.924577,152.984244,154.671509,161.084406,162.909443,178.96358,197.502042,274.378829,363.15237,357.104602,196.731693,98.460461,38.423899,71.867339,119.624189,106.370151,110.980281,153.465861,171.562591,124.782828,54.795019,-29.712309,13.329091,183.783597,251.670643,240.641068,175.978619,124.591218,57.297989,72.804862,182.265734,272.064528,242.600632,46.229057,-55.191111,-159.529458,-161.570497,-100.958733,-55.113156:173.603532,159.027847,134.775909,75.802384,19.257074,-134.572626,-194.310655,-232.668659,-217.379967,-204.809852,-199.611917,-214.056512,-264.025189,-289.350827,-298.026756,-253.850963,-67.130121,46.117521,19.007357,-166.479014,-271.118383,-317.692678,-251.808807,-155.391496,-203.70795,-210.891909,-194.7434,-216.236756,-276.442342,-273.163175,-197.27871,-148.22393,-42.13545,36.367834,44.226468,-31.936073,-119.24507,-235.906582,-208.093202,-108.168399,-18.079547,64.771781,179.618521,163.646166,96.556731,101.809839,166.179082,190.261201,222.904058,215.833927,180.669343,111.463605,98.809871,87.988053,86.6712,112.652184,183.104904,221.545442,223.855416,171.469362,10.441445,-37.083979,-0.26737,41.69931,79.492532,29.193304,-5.998534,-56.413339,-101.977455,-238.842994,-277.700895,-205.54872,0.880589,70.434711,58.876699,22.444448,-44.495695,-61.653452,-15.681365,16.985848,46.141677,92.86701,117.16167,81.682139,9.473716,-96.842396,-49.126116,163.197443,236.68079,229.821583,235.797649,241.520533,212.113653,182.359607,169.869178,204.230671,252.729966,157.801488,110.436993,56.25499,0.258115,-117.678308,-114.888043,7.578921,125.369675,128.332394,51.239378,13.218412,-64.678407,-95.345149,-55.731735,5.942677,124.291481,141.9444,111.679475,58.245329,33.655945,-20.573745,-23.493864,16.728419,29.869864,9.434967,-38.269593,-61.875582,-181.779531,-248.215995,-214.517383,-137.912886,-56.447854,-128.656705,-189.816585,-286.52916,-329.026058,-355.384419,-293.261853,-98.832757,-35.967443,-72.882576,-125.808284,-98.376266,-34.614823,-26.100599,28.005083,78.141757,125.730441,73.4489,46.128721,61.127769,95.769975,209.274447,282.728747,364.381904,320.508599,282.305203,212.213291,182.740538,142.0027,139.399964,159.059614,169.814821,222.446638,283.597184,275.555651,184.130237,133.476112,81.851966,71.055656,66.586971,108.204917,107.39434,-0.373148,-85.584951,-230.959881,-244.037805,-104.301421,-22.125775,23.370313,17.599662,17.216842,7.476703,-20.562965,-81.391621,-57.525283,15.328528,-35.516187,-50.487454,-1.09981,17.21013,-32.664494,-54.501948,10.529874,51.426941,80.16789,155.44402,197.586669,147.663646,44.015397,-131.233272,-123.207433,27.716531,161.358053,198.141976,258.089006,278.212903,198.292985,116.129624,91.680183,170.730726,351.975185,420.074097,416.079179,388.619304,347.911178,216.977465,192.371264,266.767064,358.576668,374.493117,307.167464,240.577106,148.632065,158.282869,266.679815,333.102896,440.97686,408.334507,327.118807,187.419738,146.1426,66.314865,49.747834,122.779853,261.849534,295.595302,225.926881,145.935924,-21.307682,-86.510623,-136.162312,-123.112821,-74.704779,-45.107524,-47.539041,-71.042095,-64.904391,13.541054,46.072436,28.429935,61.968548,118.780127,145.011396,77.334545,-96.306076,-108.696762,50.294989,125.240607,143.124335,125.330948,105.724635,-1.167576,-64.945735,-97.70649,-58.994936,17.539969,61.277782,80.459802,22.169877,-83.343728,-334.118613,-384.521454,-263.179366,-171.471892,-95.334193,-112.255326,-152.778996,-336.222644,-446.229816,-506.350706,-409.8387,-103.096857,91.896342,105.321086,8.007818,-52.746233,-88.087321,-50.03839,47.09561,51.734174,5.669142,-1.632584,-9.343417,-68.332546,-113.33715,-163.836631,-148.451783,-75.663159,-23.466952,-23.362174,-68.766473,-82.410316,-30.259804,24.634151,116.084436,133.694432,136.186993,98.019031,49.1347,-52.997683,-78.302965,-62.771817,-40.21683,-17.958443,-12.680042,-10.567911,10.478639,19.685539,-27.747106,-65.489477,-40.622171,20.352435,119.017478,77.738823,9.430256,-107.694206,-125.450124,-108.7344,-102.306928,-118.224574,-171.87853,-214.32613,-230.45033,-199.386931,-213.050966,-257.747177,-292.180853,-277.905084,-259.214126,-335.942877,-410.648879,-504.601559,-504.180823,-469.731764,-449.506013,-396.916205,-274.519519,-189.388555,-90.541083,-122.986176,-319.389907,-401.444277,-337.102178,-195.347803,94.142485,155.302805,103.009003,-47.98359,-106.717972,-104.354717,-44.118865,80.043227,109.952212,85.133291,32.785109,41.583618,108.230003,151.867741,296.902886,372.371235,391.041464,274.622503,214.047014,107.432148,44.472014,-45.804526,-39.010972,31.965078,120.901833,163.744328,171.617168,116.335769,-48.570805,-100.71651,-58.06479,16.152162,163.543698,190.220631,149.738458,50.61812,19.42721,-6.863121,-6.193168,43.144831,114.484298,101.218212,-20.223782,-79.709029,-152.121581,-175.440498,-211.898214,-221.496646:141.810053,34.39882,8.012591,-21.104847,-73.626176,-204.378662,-231.296314,-182.945675,-107.668105,-107.021592,-159.210613,-201.376392,-286.089618,-288.499877,-204.614057,-150.704146,-61.068686,-22.880236,-33.050117,-120.144056,-178.106907,-178.756211,-117.190287,-36.215841,-65.677774,-94.520607,-158.165645,-193.336648,-254.063455,-236.079079,-82.900669,-8.009286,92.243701,104.729819,53.74959,-107.55093,-181.785943,-225.105167,-202.885838,-130.47479,70.651414,174.91524,188.027165,112.451659,-46.699083,-83.520078,-27.108447,38.248436,159.283167,166.438862,138.159892,101.80371,73.844567,-3.614362,-3.553074,105.813185,225.228343,251.116617,170.927107,65.754793,-113.049985,-138.499664,-130.476076,-121.591108,-46.922721,11.081755,-20.382346,-198.821264,-297.468341,-330.844164,-255.161785,-66.615246,43.269258,51.17659,-9.86244,-59.950606,-161.465448,-176.969974,-106.182026,-53.27059,14.823087,37.825662,49.340535,13.276181,-46.18765,-101.569875,-52.181801,109.106198,189.582459,193.919368,185.675436,171.504342,118.640935,104.195325,112.895996,123.754487,161.471773,140.725539,81.692593,-77.194385,-129.543976,-100.619626,-50.198469,52.27965,152.535867,152.772764,39.61827,-31.679075,-164.503284,-196.398899,-133.115787,-67.83332,64.080879,116.341854,74.100218,-81.185113,-121.608149,-25.818995,55.459666,84.307758,4.203974,-20.315565,-46.485036,-71.805402,-187.904599,-250.197596,-275.873622,-238.092863,-139.295167,-133.565093,-182.127551,-326.996055,-388.007828,-366.610801,-270.87724,-64.686165,-40.059352,-88.068616,-153.302792,-142.685169,-128.001066,-140.86682,-109.279004,-42.473475,106.37905,120.86413,79.853795,-11.461653,-26.451221,110.992429,230.607186,367.576373,361.883987,317.43963,176.54583,102.857236,-44.239058,-88.436526,-42.393086,27.024419,165.668989,250.488208,250.146901,117.144424,38.752318,-9.153856,-9.236716,7.509352,62.719577,50.595635,-77.744977,-158.343724,-292.256768,-312.889723,-202.458101,-118.987948,-56.554451,-34.221966,7.731373,23.515208,-27.119425,-93.399484,-69.872709,20.880634,27.072599,-33.427806,-153.652386,-148.105952,-95.295071,-106.083051,-130.046639,-95.624731,44.996946,138.173415,123.860257,-18.773963,-90.141543,-84.507951,-24.329477,57.273076,33.950243,26.028292,75.817202,86.281519,-24.144202,-86.883005,-47.103033,48.744478,249.451944,271.647544,218.537844,128.893616,104.692727,83.486783,115.53125,277.097966,364.721937,341.614206,282.772245,265.98958,182.347918,136.318246,196.189364,306.817851,480.165732,357.247239,263.841465,195.851399,171.510974,136.357255,167.348756,269.247236,324.005801,319.111415,246.902344,191.282876,64.497336,23.089402,70.133219,134.472512,201.977141,111.819823,48.627433,-20.158992,-33.197108,-29.210871,-18.905422,33.933168,176.811044,238.174648,224.072535,149.038223,11.054988,23.428841,150.483343,176.811572,161.08658,164.429088,136.730518,-35.03147,-139.278067,-192.486101,-120.476603,38.242545,65.429737,43.91895,-48.611228,-120.365683,-301.982549,-366.91812,-324.276681,-235.577079,-61.792953,-84.526616,-179.255258,-390.536435,-463.740951,-443.790746,-340.923783,-80.278917,92.918494,117.401766,38.520085,-38.185641,-145.443163,-139.162354,-36.917042,3.560313,18.573645,-4.078971,-33.88043,-121.666841,-171.848877,-222.170529,-208.060444,-125.013127,16.260123,54.953976,-15.8726,-90.990655,-193.860199,-176.017983,-40.590218,11.977403,55.602846,56.291335,19.470567,-145.805439,-235.00582,-257.020094,-181.013331,-0.790444,106.25143,101.460718,-10.172775,-79.88063,-187.460695,-194.52854,-88.754384,-17.328302,67.680198,62.068865,34.851634,-64.213571,-109.94992,-83.912742,-39.655909,-4.718168,8.039543,5.323852,-43.33126,-78.117559,-129.267899,-108.559727,6.543208,40.596472,15.881547,-100.703656,-180.550091,-314.805344,-358.629917,-366.51784,-324.739454,-207.053975,-38.527924,45.2196,71.315849,-9.342295,-226.487573,-267.559761,-131.777926,2.273112,251.094568,289.775971,217.144345,11.28935,-46.73595,25.367143,97.366513,165.877533,184.642146,171.597013,68.925031,14.687181,1.808564,39.406553,136.340778,186.384734,300.6158,320.414594,243.966904,-21.169772,-131.985211,-134.363829,-58.034879,21.816122,11.438507,16.653433,-33.936561,-105.340879,-206.854104,-200.869447,-134.164882,-94.121783,-5.764995,8.858738,-1.361824,14.204701,10.917897,-40.439261,-45.016231,54.335878,173.989543,156.986243,-36.02967,-144.65922,-258.029882,-238.726134,-109.221428,-65.234394:95.401554,249.624061,254.38618,209.444625,192.610724,121.179227,58.916277,-34.369245,-53.438896,-52.323684,-69.931729,-97.145513,-147.188195,-157.327089,-152.837379,-120.544688,13.499203,99.938408,94.103133,8.955561,-45.847004,-114.880556,-120.034122,-66.594886,13.828305,12.575616,-95.620685,-167.008953,-292.034075,-344.714223,-383.631543,-347.065681,-167.438397,-9.261844,-13.008434,-144.429313,-219.926423,-297.615103,-287.670271,-203.121284,-36.043852,62.744333,142.662495,118.107995,86.126225,100.551037,162.325233,198.829653,276.094307,333.117669,324.346216,251.565362,216.181138,205.596501,244.650038,344.544102,350.968079,308.07527,199.036346,176.392739,155.825697,121.561932,49.562957,43.202319,97.343748,101.207166,61.123985,-6.925175,-26.268528,-45.353082,-20.890928,75.011487,134.440113,137.23685,87.100807,58.072755,28.691302,30.535177,52.3184,52.473561,63.631533,137.376226,175.10912,159.120969,86.170374,-11.570003,39.365972,210.665907,271.742564,280.309366,306.548189,301.166335,185.258286,111.643615,104.887505,169.502501,268.261221,232.954897,197.014529,116.466756,44.278894,-143.43311,-193.452654,-113.221213,28.873995,32.180234,-63.159073,-102.437682,-156.045883,-182.128563,-132.982398,-37.835913,165.0375,203.712882,173.815374,139.268604,132.342185,114.305201,107.031445,76.409409,48.827973,40.114677,13.740558,3.573947,6.325335,7.516475,-9.16532,-9.941734,25.809837,27.633348,-4.519801,-42.939547,-46.323012,-97.34835,-115.661677,-70.145789,-42.648858,-80.786298,-169.230219,-160.811141,-138.36447,-177.354703,-221.779836,-179.823432,-51.19542,-9.726812,-35.487611,-116.132973,-129.989444,-34.173971,55.572022,189.637266,231.919275,234.285674,217.531739,190.053165,76.026375,31.27911,43.590303,72.517392,112.226579,111.311042,74.637235,-53.838063,-84.176932,17.571635,104.098415,188.231449,154.978463,123.063103,5.269946,-86.806185,-295.498428,-360.028976,-320.898763,-268.902142,-230.334103,-225.675636,-209.784556,-152.700218,-146.802191,-221.238061,-246.015999,-166.574785,-34.245139,9.154922,79.972207,113.798725,109.955405,73.703981,34.204603,46.704016,109.772355,153.897808,144.057696,99.07334,64.695399,-41.52471,-62.639665,29.850326,174.577959,212.867499,158.810023,105.626844,51.475986,41.200398,55.613255,90.571581,193.494877,292.300106,311.345858,250.2712,188.88671,101.051892,96.887489,129.421374,225.812048,320.851016,500.227309,506.683611,344.176779,264.213711,253.948042,297.474342,394.553814,430.545672,394.401169,223.389366,116.80801,7.480832,48.405211,214.607953,270.502951,240.211323,154.01729,123.978511,16.495883,-71.600189,-158.288753,-128.102274,-78.488588,-157.224319,-200.683799,-210.410098,-188.281566,-121.195903,-78.535309,-26.645624,-19.534083,-6.724632,-19.178016,-73.130688,-219.886948,-252.892768,-150.672752,-59.874815,27.213216,-39.302406,-110.70178,-230.195248,-246.884918,-219.448551,-176.749727,-57.469677,44.326539,65.259372,-14.927667,-118.941417,-410.082958,-528.807792,-508.836981,-389.429563,-218.812356,-303.196415,-410.286613,-620.680478,-663.261883,-583.416117,-464.414629,-160.825377,-1.430921,-1.120404,-96.764827,-155.595771,-212.623802,-205.590798,-121.404228,-61.717809,-4.155939,-89.247713,-158.391482,-222.5401,-211.813836,-212.320648,-230.573818,-214.489847,-174.54895,-173.711101,-152.046075,-139.442309,-184.777885,-217.444368,-164.854869,-87.30498,17.617589,-75.10756,-185.599304,-363.674317,-369.137132,-250.388479,-173.98724,-56.219514,-31.230692,-32.383429,-1.728173,15.593646,-19.463468,-42.297924,46.172245,128.379919,143.823732,-0.857571,-38.302561,-46.966709,-54.273864,-101.780896,-136.771716,-214.224541,-305.325564,-332.147514,-275.448349,-218.538447,-221.641682,-279.15247,-312.755273,-272.489054,-222.620148,-373.800931,-495.29125,-614.765748,-582.938191,-450.054677,-400.994837,-359.207348,-248.983518,-152.682527,-57.123635,-107.41327,-280.259476,-304.94789,-148.637396,-36.681056,76.897125,36.721707,-14.257325,-94.254031,-94.197171,-3.358156,55.51666,96.639928,93.205073,103.993672,45.947712,-22.779561,-40.731448,51.724478,299.798988,368.318516,359.48149,250.868387,168.080439,32.554998,13.559426,56.89331,79.627497,28.444421,-48.13721,-29.564587,81.760097,108.953307,-5.664886,-105.024425,-130.82771,-39.349941,116.343633,49.826169,-22.481227,-109.032939,-130.180989,-142.093046,-110.457228,40.479888,174.741054,168.204136,53.207369,-4.880231,-134.229834,-202.068508,-262.319528,-260.334586:122.29531,217.806194,202.127957,88.472099,14.208014,-79.044158,-86.525032,-61.381705,-26.89124,-16.388487,-14.858287,-39.761979,-129.533628,-157.645675,-127.55177,-66.991887,88.110123,126.81185,74.650564,-144.038079,-247.399371,-252.608025,-174.272379,-53.377981,-55.259466,-76.103167,-126.019336,-171.588655,-322.777964,-368.534108,-264.35172,-156.972542,-7.736522,-2.134569,-31.764689,-114.776954,-172.185824,-255.22532,-242.615905,-141.953325,13.954793,88.689234,126.605384,80.130603,-76.692959,-119.908452,21.00593,165.759538,339.331001,272.175017,213.89138,138.714766,112.478672,65.039812,76.267793,214.12581,289.543505,245.73308,103.286888,37.067917,-73.590064,-96.653368,-40.749135,18.993383,107.806517,46.992185,-23.22842,-141.871646,-184.919198,-205.752291,-173.250062,-69.508904,41.404085,72.718301,48.171608,6.251606,-88.907769,-103.823126,-10.221097,56.973067,140.917785,185.111642,198.148709,153.45861,87.271921,-3.73848,20.366684,152.266071,276.288716,298.8045,247.378494,195.264325,80.385877,49.784891,135.29976,224.372371,300.98004,189.794923,120.319985,-48.066512,-149.295009,-226.870404,-167.942902,36.293193,147.798244,129.257135,14.868808,-54.7009,-227.025872,-285.999362,-186.390133,-51.004947,166.515275,136.00908,57.030002,-30.667212,-8.163507,74.888411,92.02661,88.304868,89.255682,75.066611,25.011551,-5.374517,-115.734017,-167.051997,-140.982268,-72.298361,51.133371,10.431885,-59.357919,-195.923425,-236.183758,-202.258131,-139.935169,-32.957765,-25.24655,-70.003453,-168.100624,-188.658921,-214.206398,-229.735173,-226.955343,-188.759299,-45.070114,4.925095,-41.109923,-122.325464,-108.531687,6.082558,76.661939,201.869674,290.290297,289.293663,196.439109,134.140527,-31.040318,-106.032624,-58.707928,46.40063,188.658181,169.08988,142.475266,51.998526,-16.334194,-81.595345,-49.79202,69.084926,141.322996,128.990109,-9.92471,-118.426918,-306.851884,-338.578977,-299.233586,-278.670965,-223.371441,-131.948977,-121.836168,-176.57321,-213.020138,-228.36289,-179.588742,-36.657882,10.965044,-4.136707,-48.633965,-71.754596,-128.885979,-143.054382,-96.389527,-47.538111,43.057547,123.929355,148.15524,47.801239,-65.056379,-182.907669,-135.239959,66.650438,216.167095,222.343982,94.352239,3.25638,-134.76175,-165.152561,-108.813747,-21.065431,176.841323,245.442492,228.94651,155.3605,110.48739,70.673701,103.19803,261.32384,444.191593,481.02104,369.619326,261.228353,136.283105,168.36822,355.204115,446.171818,551.979254,527.769496,455.947556,259.353868,169.777611,87.028693,120.001362,296.108262,398.266966,363.538671,221.970915,177.144682,131.684077,104.037141,64.344638,67.808185,90.084226,62.013752,40.315491,22.384606,18.354588,10.93803,12.886261,53.8274,152.465055,174.928982,104.499791,39.678765,-64.014454,-65.778548,27.976624,70.272565,119.389136,109.88559,34.083639,-203.378242,-274.073532,-214.59248,-141.759388,-54.524033,23.208833,52.110124,-61.222271,-192.068517,-426.469488,-484.5117,-450.744831,-377.262255,-214.624566,-162.975127,-215.89461,-423.599415,-514.605996,-498.549961,-372.802441,-45.984175,132.519228,131.5452,-2.379075,-92.423059,-211.858738,-209.367641,-115.074288,-73.571282,-13.510679,3.270027,-45.9442,-181.238211,-222.668184,-258.697288,-259.945217,-187.137535,-60.932751,-36.27608,-97.422302,-148.308279,-180.48752,-139.143158,-38.059065,-21.244058,-9.803507,-44.755025,-113.55506,-272.082743,-314.828494,-277.381185,-206.365258,-46.872308,55.040239,56.129752,-34.314273,-85.112971,-149.543523,-153.134192,-74.552845,-17.51582,63.451163,89.848929,69.191836,-28.300389,-63.456467,-49.047271,-26.83442,-26.888336,-56.567332,-56.994255,-79.588112,-120.93076,-178.738237,-173.365066,-151.649055,-144.746526,-89.461157,-113.1953,-203.18629,-370.361266,-402.985917,-384.761776,-342.192963,-241.640854,-101.570647,-23.702643,-8.947661,-95.180893,-303.414296,-327.854388,-124.088551,42.963646,276.13672,280.841141,235.447089,106.043532,26.045581,-65.032701,-40.648716,86.411046,190.318345,200.100395,131.364094,80.981688,15.077615,29.322422,163.273293,232.574771,279.980197,182.763644,77.384954,-122.961409,-167.214658,-160.951875,-138.890135,-126.405905,-152.433118,-142.293264,-61.80223,-34.177163,-78.117919,-117.465458,-105.21124,-40.530325,96.07156,74.564096,-4.686553,-164.816879,-200.678042,-165.343855,-103.891451,54.449891,158.619004,135.7412,-48.760666,-147.597396,-229.351289,-216.498278,-209.82308,-241.570357:133.073848,247.887282,268.484394,288.07672,295.835222,251.651886,206.457968,112.023276,57.539627,53.267352,34.700221,3.463859,-82.277678,-102.487971,-23.54645,45.931616,142.568035,173.896848,173.223756,121.39164,68.315474,-11.887297,-23.385463,-51.325599,-50.224349,-18.207129,19.991342,-12.202201,-206.139051,-326.194633,-447.242194,-424.348213,-250.771463,-76.689548,-56.956525,-106.599427,-139.014604,-218.601035,-262.556885,-265.46885,-112.622016,-18.633567,94.694253,87.451225,18.71588,17.616645,106.469883,166.040917,306.605894,448.17762,465.62678,369.949353,304.954703,275.145126,327.463526,466.687055,458.636881,381.938282,206.635607,165.572868,184.782629,214.033571,242.432536,228.78881,205.761272,204.139751,182.795563,153.498787,161.181366,188.7153,212.78133,242.412549,195.52655,171.485128,156.054908,159.008798,139.605606,105.084204,36.413493,31.256165,88.526697,158.561394,188.316932,228.262788,205.429784,107.561976,119.906098,309.536938,442.697356,443.964628,388.745526,342.069933,226.50896,204.018806,286.36039,341.786736,360.720155,269.277909,203.367485,48.696116,-30.680328,-150.789896,-176.897914,-147.454365,-88.327901,-97.485638,-178.685304,-202.533111,-218.70924,-234.674186,-196.863339,-129.193571,-13.111801,53.259307,99.527829,176.81856,186.942167,198.139507,225.279689,271.934908,210.002818,154.004009,75.684133,85.617977,155.657634,164.755961,111.258981,89.11377,114.144757,165.159219,203.275073,289.997326,295.294115,225.883296,189.190558,152.079458,127.855717,97.387979,-36.778207,-103.960535,-171.403031,-198.556666,-254.244188,-266.810834,-265.194018,-299.094607,-326.751414,-282.521856,-218.798947,-192.236589,-246.124044,-344.306982,-317.450741,-269.932109,-189.165353,-183.659865,-263.350418,-318.242448,-327.174855,-271.064732,-158.985727,-151.110879,-171.23993,-196.093306,-178.734958,-73.360957,-8.84403,63.600691,64.82525,39.312619,-88.973179,-161.417765,-272.05818,-316.533901,-377.467792,-402.797732,-435.568772,-360.70288,-312.905493,-262.706661,-259.772653,-275.25895,-267.911463,-226.490269,-139.214901,-54.665913,66.592218,48.434198,-88.125911,-143.071498,-144.064168,-111.232748,4.18703,140.616282,164.095696,72.698986,-21.175848,-141.15336,-117.448211,41.431696,189.363068,215.31941,92.916382,-14.977488,-123.188913,-113.695285,-40.79507,-2.551669,60.777125,141.350397,165.688426,131.628573,73.595269,-69.54074,-114.320112,-86.759627,111.458599,237.498992,367.062543,349.387396,256.26314,212.837167,190.381167,222.858024,317.839779,342.418119,305.568793,193.628229,144.081682,66.482363,53.922559,106.431002,195.457856,199.701265,79.900882,19.533162,-61.481177,-125.174396,-231.237806,-248.558949,-315.710869,-418.152182,-415.108451,-315.774108,-284.804854,-283.773744,-268.003022,-226.613356,-213.95467,-183.576695,-114.962548,-120.802054,-178.595657,-172.165921,-85.786181,-70.026598,-125.827254,-127.50843,-118.678105,-167.852255,-202.026386,-226.584126,-199.24921,-46.500235,80.901824,83.990972,-22.955704,-116.350227,-354.08903,-465.253567,-525.072344,-456.6975,-248.161403,-190.510388,-274.906054,-489.823878,-520.476358,-408.932818,-307.124355,-121.403679,-49.149835,-54.265488,-99.416868,-111.454884,-83.057851,-56.158801,-26.248475,-35.716582,-98.526442,-122.553399,-110.947374,-115.472026,-141.320216,-209.300259,-221.223609,-128.804858,-16.968473,-18.948885,-98.810649,-140.914854,-180.569392,-169.419999,-74.465723,-12.468538,21.056666,-109.975416,-201.499881,-330.044844,-337.036747,-211.639032,-109.490479,-0.839257,-56.075601,-88.77205,-109.675076,-92.717823,-11.037363,33.716769,101.994835,124.003599,131.716992,81.496611,45.558742,1.207991,-5.836035,-31.520997,-57.801475,-149.273536,-275.253616,-315.335035,-341.690558,-344.575953,-328.956722,-322.548115,-367.947598,-390.864169,-341.774736,-335.952926,-389.692889,-448.674779,-427.452679,-385.593074,-391.176476,-391.960165,-290.084299,-229.345962,-180.379083,-194.55749,-283.685771,-324.136467,-285.007573,-219.037155,-94.469588,-18.816759,4.698261,42.526018,64.521327,115.228085,129.508611,98.53911,53.470804,65.517613,123.921823,128.901451,102.92368,118.144293,239.20964,294.308417,291.813803,197.343415,129.627677,34.140891,44.293413,99.715187,88.881496,-20.430949,-64.328691,-26.642966,66.795645,82.678363,25.219535,-11.132693,31.847593,97.440835,173.276364,142.920195,106.461644,36.428171,21.832591,18.961841,22.786256,76.293739,205.045134,250.060517,218.446833,170.786772,52.61757,-22.193146,-110.901079,-98.920327:188.632495,280.392688,231.675535,132.93316,142.533007,183.593433,166.768258,66.278661,-16.424946,-21.177469,-13.094723,-42.780177,-152.981893,-171.21996,-101.30779,-68.841892,-44.797318,55.099312,120.606792,145.773462,102.449215,17.386319,-4.15362,-39.181894,-3.251634,58.146973,122.682664,60.355381,-212.123324,-329.033986,-392.959832,-371.235547,-271.98375,-151.184637,-120.806826,-122.735402,-165.496675,-311.49535,-349.140525,-253.965617,-63.682412,-3.270951,4.741502,-11.302278,8.476472,41.613516,118.179076,166.111284,292.777193,377.17134,372.67904,281.584099,219.596446,190.76788,252.440411,378.037898,353.64541,302.724328,179.252646,135.452161,105.115926,108.335733,163.561157,204.350204,274.474745,302.144145,273.612549,166.593943,121.181803,52.867546,25.439901,27.409336,102.611138,131.166333,115.307957,100.828591,136.08108,151.734021,108.4823,77.883928,100.736904,221.671635,279.717098,293.198116,232.705254,99.450506,99.861637,231.418483,322.499665,321.26426,277.909571,249.322293,143.038479,73.862743,51.180509,115.86983,250.111249,182.794149,94.313853,-32.673229,-78.415264,-186.654448,-215.570827,-138.313672,-32.835925,-53.499491,-139.881193,-127.333625,-86.756299,-122.293925,-172.695022,-122.733899,69.265604,179.474147,177.180581,164.66192,163.633749,145.577985,141.847427,139.071489,101.688455,73.121639,8.620642,-8.404219,18.693161,31.303685,-18.519916,-45.460895,1.929573,72.415889,84.362376,102.606089,112.394672,110.491554,95.78964,50.947885,47.144531,62.401185,46.627081,0.010928,-137.662638,-188.952368,-173.326447,-118.088908,-6.783832,-39.000953,-104.567055,-133.454173,-78.51961,5.215372,12.230466,42.482202,100.51919,115.586547,106.906034,98.493892,83.290408,66.603678,50.00478,65.939575,138.006065,168.808323,124.126904,-1.545446,-18.40814,62.097528,126.114545,210.891424,217.4258,205.434889,123.299397,39.884726,-154.366475,-206.300292,-177.727813,-152.738846,-169.233761,-161.137029,-122.074218,-79.225214,-106.88886,-185.881113,-196.027969,-135.476441,-23.839742,18.613873,56.345165,71.589863,102.726396,98.545721,35.301482,-2.061102,7.231122,102.863722,141.076735,178.797451,161.20136,73.326759,55.166701,105.435628,204.205734,231.796791,182.601332,156.322179,182.954183,184.436895,122.212795,109.581653,196.776839,333.249075,366.710279,321.696831,240.752082,25.587522,-49.098159,-22.523578,202.392267,316.848554,430.756875,429.066684,306.761304,215.754236,148.713801,185.476499,290.44991,309.883197,264.392992,130.152044,64.837668,-22.81308,-23.843586,23.893336,87.243049,100.708021,29.248743,-35.678139,-167.319917,-218.644311,-230.78111,-196.421526,-183.327264,-316.393466,-389.071486,-478.889941,-504.196655,-460.988526,-366.035898,-179.245971,-124.81582,-105.016627,-78.402696,-94.193629,-176.222798,-214.66562,-225.234799,-196.877477,-97.427909,-6.732868,-0.143935,-45.796102,-68.925228,-80.961288,-58.521556,49.401305,146.418497,142.754868,38.925919,-40.896051,-242.1403,-322.072303,-319.223888,-254.550507,-102.699731,-63.526188,-131.786209,-351.096852,-441.467214,-478.882754,-393.750726,-105.119084,66.018279,81.929992,48.224391,37.007097,72.177006,72.384443,-50.645691,-124.071148,-133.50641,-94.388884,-140.63055,-265.744164,-293.816841,-253.668369,-187.938148,-47.757868,10.929979,0.746775,-96.036363,-149.745358,-171.646119,-129.029402,26.911799,76.54975,4.670242,-133.482797,-173.552372,-231.660475,-267.440144,-265.262757,-199.693754,-78.193612,-86.882649,-112.038717,-147.261346,-131.632226,-55.416415,-33.541878,-72.67088,-123.44784,-141.459114,-34.259474,-54.984391,-235.35776,-270.264688,-177.206083,-157.172665,-327.932578,-512.582884,-527.120567,-500.797556,-506.452252,-592.91879,-638.116095,-607.231606,-550.276091,-477.176815,-456.28911,-461.105816,-493.861246,-496.174715,-442.461255,-414.515966,-382.749155,-266.766058,-189.587103,-149.238253,-194.276166,-293.869946,-307.619036,-261.130277,-223.583571,-153.54808,-115.914102,-116.516306,-107.337578,-92.572575,-42.961866,7.122552,117.138042,182.792406,193.98612,144.656574,110.882557,117.683912,158.117975,269.812399,317.614841,365.751232,328.380357,261.159371,114.492386,74.481596,40.115601,23.117474,14.690731,124.633153,193.927341,230.400452,197.378831,83.020436,24.558721,-5.867069,26.952619,110.814729,127.126499,94.160967,7.510834,-34.821472,-117.802377,-111.561338,55.518259,217.82763,244.06075,215.771505,158.159222,-66.130535,-184.800903,-261.339943,-233.179822:178.929054,288.471091,285.238491,269.850362,275.363842,213.117776,134.107675,-13.627526,-5.464183,56.359656,102.614583,48.332773,-64.283119,-75.429287,-26.419229,24.146889,138.743704,136.822443,80.512276,-26.543256,-48.36199,-70.029779,-94.514086,-126.446926,-69.332901,-39.114016,-61.631779,-135.822144,-364.745503,-435.580168,-364.560337,-285.548121,-192.239191,-183.353936,-200.01396,-197.628859,-178.77739,-203.439372,-223.205732,-139.0674,12.739953,43.78685,40.604889,46.32925,64.10205,48.475906,32.550157,81.201201,239.8031,349.91736,373.751839,339.65858,290.960158,225.250704,234.411018,284.654955,298.916588,272.432392,182.689776,150.534487,68.812147,18.507056,-7.704256,13.988069,68.858452,74.602115,44.075054,-16.797017,-36.398473,-19.894048,37.840851,140.021652,98.108901,59.603432,29.031478,46.942995,86.766052,71.188883,16.875372,15.79653,56.143261,117.40698,152.318505,190.639524,175.359034,133.693938,138.471936,199.558115,270.792977,276.914129,245.069809,228.67466,155.787355,110.768178,165.302536,256.933429,322.144812,167.348874,107.961755,79.773817,50.888385,-68.333511,-112.617465,-117.38053,-26.927714,12.674567,-51.445268,-130.565777,-241.369198,-244.734204,-150.042383,-87.27645,58.322994,214.200234,243.527559,229.936648,224.474169,257.335558,283.518288,271.107507,200.089991,161.089763,43.379671,-8.448955,-47.596294,-62.146362,-38.255719,42.665629,215.697934,197.558175,167.58651,159.633562,145.087106,88.560568,79.130259,51.524394,0.290897,-15.45295,-99.71977,-154.178336,-198.070648,-192.962892,-187.355451,-187.520836,-169.794378,-191.308466,-211.811264,-209.343753,-190.507161,-122.888794,-61.646905,29.549994,-31.089545,-56.791111,-5.48125,15.65624,-59.596885,-112.659768,-131.530674,-108.07713,-39.700341,-4.074664,-30.893325,-111.972155,-113.302058,-26.231331,19.032883,48.610643,62.10123,43.357232,-76.764091,-122.113483,-160.834355,-183.043655,-214.842084,-236.602767,-325.82626,-311.766966,-248.217259,-208.359044,-253.327483,-247.372845,-165.580554,-41.044025,-6.748084,23.48854,75.459577,71.812608,-3.861866,-44.29916,-57.504237,-38.347622,36.858897,149.84313,175.894106,96.200471,5.67224,-160.398229,-183.742051,-87.431318,55.596055,80.328897,7.817328,-33.902298,-87.304565,-129.448137,-153.56126,-91.57362,73.969128,109.631842,84.785889,77.726556,114.806015,181.10941,183.569535,162.384227,217.210896,279.326661,350.056217,320.958295,216.345973,218.956281,337.799634,375.809507,384.62368,387.513907,366.801393,319.884356,285.124787,157.783031,133.67985,190.11738,208.813618,203.80734,189.679026,169.001588,84.233339,48.043145,31.939467,26.578441,-19.954995,-85.986412,-126.91836,-165.334564,-136.883083,-58.453596,-38.465844,-29.199453,-31.099994,-34.02678,-31.968636,-26.132375,-51.686589,-67.255826,-18.726803,15.046278,-1.826738,-66.057203,-111.734927,-211.979408,-229.342954,-228.031371,-231.288471,-175.196816,7.760578,66.593387,-49.45668,-194.297365,-462.131616,-520.139706,-444.203534,-373.943956,-302.848839,-279.078767,-309.333757,-456.032917,-516.023752,-490.899585,-386.572972,-93.653571,74.759538,89.762256,42.149134,-4.345928,-83.127035,-86.667367,-33.952466,-22.144449,-79.32582,-126.245314,-127.190402,-155.008941,-194.062927,-238.269536,-215.281453,-101.801011,26.329441,41.051074,-68.849362,-131.698716,-150.885877,-124.859182,-34.751553,2.296842,-32.051338,-111.123288,-131.519254,-180.014183,-221.714961,-267.912484,-225.910774,-42.17439,59.86283,55.609218,-3.288569,-21.973402,5.835223,43.466381,136.961779,165.111257,137.04585,107.059856,95.904101,29.925394,0.081831,-34.422768,-57.458342,-106.872648,-84.239765,-49.5501,-99.003725,-184.571186,-291.038517,-293.478302,-264.105764,-243.640651,-225.079045,-259.073816,-280.986845,-331.236242,-355.553969,-358.390926,-330.615926,-234.860915,-112.794534,-76.812764,-110.183205,-160.110216,-258.221166,-281.756824,-213.256793,-130.660997,40.723494,127.141595,127.299178,84.984911,58.557129,12.288691,8.921342,45.899833,140.303326,197.355957,159.528149,65.200946,-54.510528,-41.900091,88.706465,161.17171,200.850568,142.022214,70.764847,-133.236032,-199.985034,-194.719365,-159.258772,-136.941791,-179.294421,-175.724286,-102.72345,-76.202972,-100.093339,-108.79853,-28.919306,22.214314,75.236095,92.081156,52.53818,-63.357135,-80.42126,-41.465224,-11.941897,58.302773,124.268195,108.637468,-12.935761,-54.794461,-89.000408,-97.893625,-84.714976,-92.929004:forward
19.471205,159.800308,142.156881,36.963477,19.786255,47.753743,47.936642,15.243149,7.603699,16.220332,52.556341,60.341539,19.280321,-19.193244,-83.125714,-74.464042,45.063235,147.828519,138.133106,-3.142419,-83.702583,-124.916966,-80.370566,9.041356,18.207032,40.090932,149.110323,183.698599,110.751024,28.993914,-116.27251,-170.071638,-216.345316,-133.858068,-54.218432,68.132423,64.806007,-20.602674,-48.742109,-9.507908,66.571858,66.614002,42.684269,51.828598,53.783154,18.769419,-85.578296,-110.753435,-31.730986,86.13261,103.437736,101.422907,100.765828,81.499399,49.787081,-29.242457,-61.770388,-66.349465,-35.974076,-13.479158,-38.061601,-73.817118,-108.596988,-87.951981,27.57365,143.454633,176.386408,171.695303,136.638348,76.592091,66.565651,61.187137,55.217301,53.284496,75.604193,82.162887,47.950055,14.711813,-103.449876,-163.14545,-137.159864,-18.54682,-0.510799,9.520505,25.710323,0.539189,-69.905138,-214.694473,-155.189826,-61.820938,119.876603,163.607286,137.764372,101.709496,60.147242,65.967131,101.522612,72.325788,41.139808,87.273871,178.458399,298.109849,248.59539,52.445412,-9.769173,4.558293,72.178671,114.479739,179.712864,197.310079,147.078495,70.631528,-72.907021,-73.496838,-45.986966,-77.487949,-132.729026,-167.260363,-129.336383,-32.723944,21.008361,14.344151,-21.440887,-20.744461,-12.786067,-37.778103,-159.901846,-224.849482,-265.862147,-213.045224,-172.674324,-81.139658,-50.900052,-61.343783,-95.377959,-110.12574,-2.642906,9.215475,-118.059475,-189.798605,-242.011174,-239.250974,-254.210015,-264.944481,-243.09184,-226.589531,-201.84677,-84.368483,-38.184864,-35.121946,-50.352885,-25.005369,52.696635,70.390313,65.499788,62.351575,33.852384,-5.582903,-135.315826,-190.475836,-178.978935,-66.751401,-15.295478,50.883161,66.115911,23.482942,-40.815014,-126.020331,-54.377006,1.272598,98.492143,115.908655,95.171407,108.890114,185.178585,182.976516,50.920202,-66.131869,-79.170443,-100.000712,-121.757252,-119.687651,-99.634265,-106.160637,-169.144642,-183.04749,-120.72665,-59.942642,39.50426,48.858879,-32.064402,-75.033525,-15.08642,97.779393,97.70927,40.49033,19.183224,-36.788945,-101.925473,-166.789535,26.961146,131.179443,224.554414,244.159384,273.32071,254.045171,92.770252,7.87623,-6.129139,88.43156,130.219366,179.128731,182.484041,163.282754,145.148781,125.83196,178.486012,210.484886,202.929939,165.49182,88.573173,68.717797,56.507616,44.45236,9.251621,61.649544,95.630045,40.725073,-10.439907,-34.982386,-49.127578,-106.128642,-16.18301,48.257521,38.105447,-14.117888,-69.723009,-70.12671,-110.705008,-154.223665,-197.274341,-105.161134,-27.220323,67.707634,54.493556,-53.957283,-100.469639,-83.090904,1.146857,-4.39259,-65.14279,-42.992186,118.65449,192.566398,209.012028,157.486895,64.654231,89.669261,100.16702,-2.203517,-76.583021,-124.521279,-119.36497,-160.110032,-197.897118,-168.391804,5.665353,105.209637,143.385216,67.059403,-69.300155,-38.045405,162.573971,263.99164,261.08175,218.355113,189.84362,153.513966,142.240484,108.974335,115.621214,126.251783,104.316141,84.855922,90.253959,97.664871,64.443431,52.718596,113.108563,152.652928,119.067199,9.654389,-18.181952,-19.750135,-36.273618,-45.178213,122.497443,229.973774,337.750151,290.554885,40.358395,-60.92243,-64.269797,4.055577,145.42501,183.094299,172.109882,166.231371,185.833525,237.941363,234.367759,164.695189,170.950235,192.641428,148.233207,103.528446,68.513456,67.575305,60.392882,69.891241,137.068711,201.532924,217.703028,171.87944,110.472082,56.398971,91.26047,194.403191,264.714322,286.331288,312.914898,323.611699,320.173149,278.826245,129.397482,83.995772,134.97077,215.446777,233.057078,244.40943,226.437727,174.007735,161.675175,129.838271,109.575872,135.653323,197.43884,194.801861,161.530228,148.722067,86.446114,49.467414,33.363429,41.470318,54.537841,108.506934,124.35381,83.224937,32.032337,-13.790308,70.718994,94.875748,97.793107,98.679964,3.757171,-96.145858,-195.446281,-141.647183,49.722454,130.512136,142.064402,121.347322,49.123962,-139.472797,-190.216767,-168.020932,-87.7636,-78.352177,-138.639344,-184.37183,-231.505368,-222.721881,-212.253147,-219.419612,-178.704387,-82.1422,-26.944259,93.328738,137.613199,153.557738,110.283508,-17.474921,-46.133859,-38.412028,-8.463762,-0.26524,-67.254976,-117.639575,-174.850217,-170.993813:-78.055557,23.065039,81.287887,99.630565,77.12281,30.077949,-11.303624,-104.802527,-96.543517,-54.542916,29.481866,31.300408,-46.560716,-85.780803,-116.198416,-105.42482,-12.380368,117.033607,118.350715,-12.792782,-77.272763,-149.039269,-164.282855,-118.039675,26.146781,92.981413,185.641612,214.441154,156.665608,49.562444,-181.224564,-230.718134,-189.691351,-86.641289,-38.068311,14.619355,-9.476245,-143.630347,-202.94712,-219.006902,-144.573028,-93.55041,-10.497643,-3.357915,-41.177658,-90.009437,-224.094535,-225.721739,4.592361,212.339279,204.763546,121.856371,121.254836,127.170497,92.893696,44.318358,75.244733,86.435204,65.658612,17.165424,-91.85119,-110.350927,-120.238108,-110.269327,11.541385,169.941311,219.837111,220.184538,176.97249,100.67098,91.107357,119.519298,146.63494,140.446182,101.079137,80.124107,20.311598,-21.097087,-78.619086,-90.178174,-89.522642,-16.834928,12.126455,-52.728582,-95.99652,-74.707364,-56.503009,-61.41112,-3.365718,44.523637,128.780277,145.125955,75.089498,4.949804,-79.466518,-56.725482,63.200174,80.681955,59.712432,104.17884,149.608557,166.585665,131.748842,20.488654,-59.457208,-72.2961,-41.657944,-17.695342,-39.402472,-80.440608,-120.959841,-108.029729,-91.597003,-117.869152,-129.19931,-147.298534,-151.425277,-173.661779,-204.510206,-198.513167,-28.320352,44.43114,80.885646,75.967107,54.790696,22.708295,-46.515611,-45.745407,-8.791643,-10.614087,3.187728,72.336139,85.292887,6.972492,-50.398975,-40.198658,95.718721,119.699405,79.885588,56.550079,-32.410509,-110.253993,-210.60126,-202.0681,-134.89742,-99.775501,-87.236446,-69.417679,-94.429724,-183.709434,-199.876236,-137.511466,-24.519101,27.244988,72.716973,38.873769,-84.540812,-124.174018,-157.007269,-169.485537,-153.461513,-49.641155,5.123294,20.932492,-20.75395,-131.00897,-168.53349,-129.906901,-18.75965,12.158726,43.575926,58.253032,85.281961,85.511188,9.565896,-38.596759,-46.832782,-41.438965,-84.391116,-207.06504,-234.073482,-170.707259,-116.492386,-41.03946,-9.193539,1.907196,45.823401,76.033659,96.922163,60.299687,-57.113869,-72.961564,3.745829,59.794787,66.942034,53.51385,14.238914,-123.874041,-188.323464,-190.630313,-48.36339,22.741974,131.91501,160.040953,118.715859,58.08992,-73.549202,-112.891806,-57.868486,124.877076,194.991657,205.637957,170.573781,120.158469,112.62087,134.337966,144.578033,125.03876,72.779145,57.283536,50.092079,26.15022,-91.406258,-132.238446,-66.37993,77.371016,100.050351,21.523502,-27.978954,-91.956202,-126.268763,-154.400708,-39.292135,27.68972,33.462696,-16.787899,-78.174358,-74.734597,-93.091451,-130.132652,-176.334284,-92.454633,-22.603749,53.251551,25.754081,-122.767561,-184.447503,-125.969039,100.021392,156.259978,121.02425,105.090342,131.342672,136.090956,109.385134,109.887507,144.111736,144.495695,146.898133,134.093607,79.106575,-66.574544,-92.385187,-84.67865,-86.596346,-55.768316,70.163505,130.069989,161.794327,128.784573,65.248577,85.25081,240.353047,414.671312,456.703845,407.490103,348.785574,273.188608,249.309854,198.558366,183.035787,197.821309,254.052468,271.886488,267.12848,245.884901,185.469711,170.62563,173.353738,176.428627,170.625804,131.538359,115.078372,81.296377,46.129242,38.041733,216.492528,321.266096,371.634426,291.575425,60.779711,-3.212902,36.098641,92.807502,161.552952,207.307541,243.111174,278.602125,244.290214,96.338286,46.797588,87.413662,174.28861,191.667261,210.211342,201.456772,110.979719,69.281024,79.454712,117.265776,215.634503,302.155077,314.462452,242.699007,173.608822,52.653013,21.008941,43.915164,205.52215,283.79486,312.1669,304.159658,304.749547,262.912609,123.97388,115.331816,217.28618,250.741912,241.126429,189.251947,130.078873,19.963533,15.41473,77.646824,110.967614,121.650355,209.383213,263.250358,275.166682,239.166211,169.086016,149.613608,122.039103,146.822476,197.582199,213.674708,142.089456,23.147184,30.572423,147.348771,256.216095,248.718085,154.040029,95.033834,-48.219017,-112.365355,-149.336768,-106.155879,82.240645,198.031088,180.602003,77.74446,4.231891,-192.575468,-283.750454,-322.179544,-208.895395,-173.733716,-176.769633,-188.900465,-221.338495,-243.413101,-254.799348,-233.831205,-149.391615,-15.237642,41.118324,57.983146,41.21664,52.969936,69.622375,59.910139,26.268446,5.315954,-20.811646,-17.898123,-58.261178,-113.93921,-166.072727,-132.130178:-79.891221,-28.729206,3.859122,40.370548,24.276994,-87.099923,-157.318839,-194.254609,-62.248587,14.024312,96.016582,80.945888,-74.02875,-171.139241,-220.336066,-154.271531,4.886603,79.663903,105.89446,94.746459,27.659636,-141.404539,-175.221666,-99.381645,24.497507,62.204179,110.464128,132.742532,108.080461,26.070012,-176.726808,-215.545522,-151.47258,-55.019675,-32.132583,-39.869544,-60.285772,-147.414634,-198.557408,-208.472173,-89.079926,-12.777375,67.247824,43.283925,-86.821632,-163.106634,-260.960854,-242.196413,-81.195286,80.431988,116.171762,90.600819,81.83425,127.886716,133.697428,112.771786,148.401514,170.460923,181.87307,158.42382,55.574826,-9.971892,-88.65288,-55.59695,133.156837,307.822687,333.226613,206.918108,98.933207,-13.538519,3.372181,84.532619,164.983176,200.348002,173.898855,113.019407,31.797545,26.316163,11.209842,-5.170485,-3.675019,54.146498,76.240664,80.304096,70.830028,14.439279,-32.863642,-88.204437,-28.442195,38.623833,141.102307,127.311512,35.925384,18.629296,47.73389,72.465396,112.692304,110.989687,108.095518,128.866648,146.975623,128.523987,64.458618,-75.440071,-15.905393,46.680319,54.994776,17.594395,-21.658471,-30.839734,-92.067263,-127.166041,-150.42315,-110.234111,-73.606127,-40.952274,-54.726076,-82.261012,-92.74546,-89.209773,46.904345,136.951211,209.703325,171.522549,19.814242,-53.148445,-125.530774,-98.038505,24.836623,52.091289,40.879224,46.943646,54.908472,28.723024,-2.469622,-8.406791,79.506224,117.542289,141.570317,123.035412,22.936488,-49.497193,-172.023714,-176.099243,-75.953511,25.794486,61.330836,61.281242,0.0199,-185.47342,-230.961768,-108.326833,101.10613,146.781348,114.708832,52.749951,-101.045837,-163.729458,-236.924259,-230.868591,-103.539628,86.327603,141.895609,81.371393,0.437535,-111.060728,-131.490024,-115.140156,-7.121767,61.269156,144.932754,143.769498,82.52345,36.551509,-35.095507,-24.701227,27.066576,-7.902992,-29.207276,-47.692084,-47.903644,-51.654592,-67.378178,-60.53967,56.499157,118.502583,173.777711,154.48761,65.000873,21.163497,-59.091336,-84.304258,-49.757875,58.421937,99.458456,89.433687,28.9629,-175.584283,-260.192939,-218.535623,-17.595687,56.687769,133.497992,134.672903,51.883518,-13.159364,-85.929648,-57.522375,80.730412,156.333917,170.275279,207.27657,210.709648,163.694099,153.121118,218.816572,267.101879,258.703591,214.066739,167.303734,20.913628,-47.986391,-101.850054,-73.136086,54.234646,148.219279,146.753508,41.042021,-32.359727,-137.966695,-162.83712,-163.566856,-72.94069,-16.4285,0.179169,-45.635914,-170.514585,-216.646017,-245.609845,-242.189133,-207.30689,-119.348807,-87.254114,-100.332659,-117.454017,-143.567636,-162.918142,-136.349948,-16.415949,16.049264,28.625794,40.780699,78.103557,96.924557,139.497662,168.475178,199.20407,188.684861,196.429048,137.096472,53.079109,-47.628891,-22.403685,48.833916,29.242417,28.867289,110.199269,159.179531,162.774709,113.499108,14.509558,20.947868,195.812087,426.109874,484.443436,450.349438,392.158537,283.013301,244.094357,214.44836,244.945808,283.334137,341.599511,311.678714,165.882857,100.106326,36.370217,40.584526,93.113395,168.237259,205.462789,205.846081,163.516888,64.566429,22.277245,-24.06029,49.172937,125.964356,249.862927,247.178339,88.472294,-15.557384,-79.008908,-30.721683,64.861887,120.790867,161.886967,207.61343,198.508381,182.720612,193.602375,244.501587,293.561765,305.760265,276.635904,226.225827,129.077934,124.647634,173.608149,184.910498,187.686218,218.462925,230.849189,193.447672,145.888026,87.357337,98.219519,143.883128,162.133294,187.844813,267.287581,275.32772,194.499448,139.186683,63.910517,55.091541,76.28872,85.541785,82.148383,37.144031,-3.986165,-71.932739,-81.914344,-31.50189,66.235199,94.295097,106.496975,121.731827,173.446822,166.16573,74.86887,51.653946,103.759085,161.7149,182.07929,160.195414,96.928774,-45.95461,-76.751713,-8.932861,107.059303,130.89309,97.160873,37.484922,-94.20108,-122.002441,-112.50409,-103.120413,-48.03264,86.157011,114.595387,17.262307,-61.690691,-198.8195,-253.476751,-259.793031,-146.88509,-106.128373,-114.84225,-158.0031,-216.622242,-208.966172,-184.459919,-182.23742,-198.201493,-171.66467,-114.057301,-16.215147,-16.977876,-73.520357,-93.079365,-75.792931,-45.703645,-32.685225,9.466255,8.972452,-89.112469,-153.304419,-215.79415,-214.278:21.105492,70.718134,69.711393,-3.918366,-60.681697,-138.231164,-138.422134,-100.507257,-110.887514,-101.811148,30.460303,77.831578,-58.472047,-172.810072,-243.792763,-202.337603,-76.163558,64.564349,118.473797,99.902408,39.350102,-57.170799,-71.994666,-21.503134,101.905643,165.110792,250.019649,252.63993,174.267774,104.00764,-60.737491,-114.87905,-81.812951,47.042711,102.715768,186.202964,192.265673,101.916912,41.785183,-7.523757,-15.870484,-19.916426,20.883661,38.833069,-19.802843,-84.772412,-193.740423,-187.376232,-16.211684,146.144745,155.075779,85.009484,58.646545,62.525135,53.441235,-7.28395,18.957568,58.937213,109.080863,111.71169,51.619947,-5.109831,-64.860019,-27.639988,130.129188,225.818654,237.909585,236.591104,237.152169,246.39004,239.475306,249.708803,328.496981,337.004442,260.951152,222.426813,195.843656,180.445454,75.981047,5.219808,-37.777523,36.156782,61.159255,52.378907,26.275129,-24.408647,-35.991756,-48.597592,-45.015886,-2.913316,155.05617,201.517967,146.833138,100.495208,86.354875,109.407819,155.650592,138.427881,110.003537,86.644441,115.005176,206.624789,210.491639,125.748789,99.535941,111.341051,120.546712,125.985279,137.045597,119.449139,12.343331,-58.95935,-149.892203,-118.086358,-79.032331,-35.693091,-35.024172,-41.799669,-47.474525,-32.834451,35.84571,66.702429,125.261947,129.344421,9.559123,-75.027679,-187.319466,-204.992074,-152.492618,-75.589023,-56.223513,-45.913275,-46.077156,-59.979619,-78.53062,-66.372694,18.609902,26.820427,-26.73018,-43.381016,-53.940461,-91.286528,-257.079641,-314.451641,-219.642725,-47.304431,-19.481408,-32.673258,-32.844933,-27.32816,-48.227767,-68.168434,52.221049,106.67832,109.717271,85.090154,16.411099,-34.425068,-137.32451,-147.131252,-54.188339,23.86734,43.251405,70.763472,48.392392,-73.60942,-124.14288,-121.637641,-54.377995,-12.705821,93.724459,140.669463,182.325142,174.646222,115.362922,84.736917,80.392847,104.084379,85.355901,-16.452423,-48.805102,-6.355196,17.405336,3.429899,19.390438,53.048265,97.808093,84.022735,21.78631,-0.762899,-35.055179,-49.155366,-30.596483,46.815961,88.317346,108.659655,57.713117,-132.024015,-212.753147,-228.917332,-102.849663,-28.12425,145.503597,227.685656,279.741152,237.576341,74.152203,4.074836,26.303056,249.338081,353.449373,352.54936,270.065032,199.568926,239.053826,312.584393,325.79918,327.606111,254.05833,168.065402,65.078106,82.152884,71.119284,17.965893,-5.834774,88.700206,98.091232,11.50388,-33.805085,-88.616398,-121.213994,-164.164999,-111.079431,-72.853756,-85.125067,-145.572105,-239.385866,-234.603483,-210.730405,-229.427146,-259.146763,-143.821467,-45.211054,52.213341,-5.223989,-188.221504,-221.138709,-177.974643,-106.751232,-67.215073,22.668749,63.485276,140.246766,194.203628,278.983238,268.01882,170.19013,123.282287,137.330542,142.874943,97.685303,-25.708481,-59.620917,-96.099927,-72.025295,-8.923331,128.709481,155.756729,112.932458,70.217484,22.725515,61.13793,244.398549,307.892115,281.745779,257.546299,258.29785,230.407486,207.42851,182.706946,194.961937,195.089941,192.613656,204.936314,187.918584,131.89215,13.433253,5.96582,67.820821,141.566443,174.396935,152.758811,110.385542,81.171827,77.904664,58.092125,151.335889,228.504789,284.992292,232.80225,49.285608,-14.445931,-29.083201,-5.762231,62.89397,162.171204,211.127892,248.069977,238.31998,206.926066,189.264925,176.528109,223.302873,244.705205,204.174236,141.665402,35.306821,32.527408,72.321971,77.167934,88.381032,171.655603,212.209281,185.809526,125.54847,26.709776,21.189014,103.078049,204.611612,225.734096,234.901839,243.832999,228.332711,178.908475,37.933333,-2.296994,35.992891,105.465722,110.539319,46.335734,-9.82677,-76.450892,-79.247605,-112.172749,-137.921426,-84.135971,104.616254,163.333297,165.667745,144.130656,92.829114,45.946222,-67.849327,-92.743635,-67.79439,-51.531013,-82.157169,-152.153301,-167.217564,-130.065704,-49.974402,-26.042056,-5.561659,-26.234062,-164.990082,-242.842948,-300.145096,-279.165693,-169.135698,-46.033652,-10.549656,-44.2176,-128.347411,-307.951933,-330.903056,-250.194831,-162.934116,-153.229416,-213.287222,-275.645044,-392.324356,-401.678085,-349.084532,-327.691723,-304.308129,-260.988855,-212.070738,-115.415479,-97.419414,-124.325505,-153.915428,-175.95186,-160.145157,-157.484498,-116.198041,-97.436994,-140.888909,-172.289901,-225.063338,-252.193696:-55.789408,19.55615,13.095477,-94.125633,-150.169336,-193.626798,-225.884262,-308.614096,-201.086284,-76.750728,143.666777,161.691743,-57.646799,-214.789669,-352.946699,-311.572572,-153.212797,-30.400306,21.755075,63.099785,27.117409,-92.234727,-122.440945,-112.937641,-45.631215,22.643505,130.694688,126.450711,36.492549,-12.718004,-80.397035,-100.913702,-89.179338,-2.891812,44.111202,120.824145,133.195781,15.561228,-85.658161,-147.48394,-60.362417,-35.327691,-37.301767,-60.31989,-132.595465,-176.11629,-266.832688,-259.478941,-78.349966,59.483884,68.42552,81.25808,108.550345,128.896682,85.233114,-18.85269,53.756273,127.097653,190.620297,172.399272,78.016824,16.92502,-54.952307,-35.835154,76.390744,214.376753,263.359827,238.994423,198.263857,179.236645,173.496531,155.008591,236.836922,277.848968,262.691703,219.759241,148.234644,124.478253,30.650304,-28.252879,-51.841003,25.212342,47.755161,49.00653,42.667367,10.576196,-13.891166,-32.546092,60.637294,129.842744,188.937958,161.563574,108.846888,109.222971,95.924401,97.353873,169.677163,223.005724,218.123008,170.557778,142.381826,100.491176,85.336747,68.384368,26.314957,6.256653,72.875463,147.688707,175.130117,91.261998,-82.675698,-114.888992,-138.212973,-104.298822,-37.989113,71.3684,67.370241,-4.651505,-41.413216,-57.037559,38.091191,99.375335,135.058567,82.75769,-82.457623,-143.161085,-218.575725,-228.486675,-133.779206,8.186118,50.351932,55.898249,25.450674,-48.016335,-82.316037,-101.208248,15.979992,82.953688,126.152005,109.380049,28.487586,-53.996311,-252.988389,-295.354493,-179.215,22.398902,58.323734,-17.696792,-73.510183,-122.14284,-114.187061,-37.95196,58.41143,76.07733,43.317534,12.003579,-63.21215,-119.287943,-203.44721,-186.557833,-49.121585,122.027243,174.801182,133.273567,64.366534,-77.337995,-142.297235,-174.616934,-18.668615,84.298383,210.767737,207.704879,138.981684,109.700342,56.243669,48.358805,128.66708,229.586899,236.75695,165.569588,127.543762,100.142241,90.42162,93.950307,195.414926,250.711912,268.883535,215.982222,83.436121,50.71287,10.349905,-13.067365,7.650562,101.907283,131.368388,107.380611,44.24947,-182.044053,-279.906651,-253.126769,-58.721037,16.480748,121.840791,158.651342,147.200632,92.777059,-23.185378,-30.602407,86.243204,246.038858,300.688816,301.997626,257.468898,178.717561,172.898277,238.597102,315.200746,326.045978,297.292545,255.421403,146.634172,97.426255,-5.247996,-37.427386,5.497228,100.500808,126.177821,91.921227,34.557965,-99.330783,-135.626345,-100.26898,-52.185268,-63.458631,-113.037787,-130.536434,-158.598146,-172.034352,-190.619381,-200.068178,-175.15433,-44.788651,8.125439,-20.184702,-88.670898,-226.131941,-249.11223,-174.385078,-61.626367,-13.079392,76.557079,96.722202,109.595998,131.490898,173.422373,180.600988,200.474166,265.777355,289.166471,167.117957,46.816511,-91.843454,-100.786772,-80.838634,-16.471107,38.225747,169.216268,201.363387,142.671475,93.665237,79.510195,129.105375,242.73087,286.876593,322.846338,404.916085,404.666996,295.586044,217.084841,135.991305,240.418165,320.268636,323.381283,236.020495,102.410093,97.511041,81.580286,56.431271,49.92004,107.809816,140.816102,143.868435,106.522531,8.110962,-27.693211,-17.71964,126.502036,222.7558,321.873179,275.631253,75.69228,2.804252,-27.980036,-11.119752,26.807101,93.33977,144.357089,208.839541,213.992998,191.761751,178.660378,200.156499,249.338277,260.460842,252.426493,237.8855,194.13224,159.381524,96.335235,100.602718,195.795981,315.719174,338.592255,284.20988,232.986962,133.108937,89.119487,67.712862,194.519568,255.657841,258.520392,229.829503,161.872179,105.318718,-37.582449,-76.742988,-24.548295,89.094637,124.703314,99.293245,28.30185,-144.100587,-188.752657,-145.679736,-52.144044,-9.871187,112.344139,172.124897,200.624376,160.919076,21.166877,-38.642151,-60.60587,52.320145,113.041842,104.861382,30.397918,-139.500648,-185.859386,-149.770262,-2.110576,49.124717,32.642473,-30.202721,-202.605736,-271.732737,-281.300503,-211.620202,-66.48063,-72.050519,-89.31609,-103.470078,-123.485418,-228.03858,-300.95445,-375.643426,-272.792042,-200.103048,-150.484539,-186.086512,-284.494303,-313.341629,-336.420452,-333.035901,-296.649337,-249.320227,-214.912686,-161.192302,-154.163602,-188.121686,-211.745598,-161.450115,-112.849894,-121.201659,-92.999013,-84.703659,-140.007444,-173.667899,-231.28001,-231.663386:131.372067,120.584471,84.851954,-10.807231,-64.095686,-101.387906,-77.467134,-32.306327,-41.635545,-40.015597,39.404871,76.103606,-3.414835,-90.38351,-174.866664,-147.827649,-28.349545,73.635342,95.420103,33.003957,-26.006114,-21.403342,55.18762,189.300981,183.81141,159.177141,124.177592,105.700982,76.311351,73.567827,41.856838,12.722962,22.543888,145.74043,226.525099,340.833427,344.550671,268.258909,214.208913,178.545227,260.726857,265.677209,164.609842,116.17831,67.458781,59.972133,53.93202,42.877857,70.943344,136.575637,133.211641,106.176679,98.083027,25.385921,-26.091194,-55.906628,-21.792666,-5.569952,15.15257,12.927701,-0.992979,5.706717,3.25935,-16.205688,10.984836,137.590971,184.177033,179.678677,156.421902,161.998694,177.411461,207.647037,296.257344,330.299727,323.715998,295.626277,211.079879,163.033333,60.575221,13.197098,-25.811579,-0.88709,16.097575,36.813754,39.100337,25.192724,-3.060031,-41.106823,63.025307,135.522794,223.18493,234.973233,199.1134,168.262885,139.416093,155.378977,225.996227,236.890144,213.681631,191.131928,207.531619,231.4947,219.225918,205.476361,242.001427,254.043841,261.375684,272.9804,282.720691,257.752277,124.718505,41.022275,-18.772593,31.375808,23.086306,-66.883531,-100.029916,-61.977294,-37.033613,-80.045617,-48.535565,18.048961,104.890293,87.903207,-46.149919,-122.954718,-229.629542,-264.127806,-277.737668,-194.888276,-139.744969,-54.257513,-33.729995,-41.463378,-75.58664,-97.525804,40.941552,80.774648,-31.966101,-123.549527,-211.521479,-221.969907,-244.226392,-230.506048,-118.565133,-38.855521,-25.935153,2.748215,5.521711,-46.431446,-76.919691,-69.64006,50.572355,111.456934,149.887728,126.171887,43.660477,20.508227,27.079911,28.70069,2.690711,12.773586,38.068728,29.462095,-13.334188,-75.86852,-96.14457,-158.672079,-123.763113,-54.065083,98.614331,139.399453,138.079244,136.760167,151.008414,140.342922,95.011701,44.832548,19.021046,15.083451,45.508052,103.742529,88.420902,-52.960072,-134.023753,-98.769443,-17.267168,-1.160574,66.247526,116.660327,106.103745,39.442591,-16.677666,82.782035,119.78001,94.929619,52.757522,-48.421939,-112.913283,-195.334953,-55.35953,61.934786,210.157577,228.113683,226.045439,218.237249,136.182329,87.636638,133.395744,270.611027,298.217157,302.005383,301.057508,277.165425,258.904183,279.988596,345.229138,338.628448,234.943296,163.339043,55.58005,50.765974,95.241114,97.173116,40.402477,-2.270849,-5.197992,-17.36194,-34.599885,-100.948069,-135.808146,-172.458796,-175.079182,-158.0667,-108.600737,-93.599685,-139.940436,-190.003214,-244.765322,-234.19957,-187.289085,-101.556478,-36.766244,-3.220129,-72.529508,-264.438004,-310.228535,-244.617358,-111.230597,-91.423488,-143.9171,-155.942265,-41.676985,71.256895,213.83372,191.004902,91.576563,66.201249,53.526462,-18.512319,-52.342453,-88.667075,-119.85888,-194.507274,-157.219948,-110.466748,-33.130731,-19.82641,-85.196507,-132.198728,-132.793288,-78.566482,54.34253,101.403485,88.993858,38.567718,20.68403,70.178958,118.629769,124.877023,66.444576,61.627526,83.022989,84.05364,54.289523,47.264781,77.4242,97.521068,129.33098,135.213282,114.57246,9.110647,-44.804091,-68.658795,-56.40797,-12.693859,114.865167,176.453213,166.750763,91.154882,-73.043294,-105.621652,-101.0048,-92.255276,-2.01861,137.085586,160.875735,128.92985,113.446143,134.986475,137.208884,88.048417,111.284812,152.927662,189.911009,152.604907,13.993692,-34.116449,-74.829713,-70.645532,15.16675,88.958887,81.300325,10.491284,-8.43575,60.358037,113.833474,147.796094,163.205491,183.306662,194.560248,185.890436,161.713702,142.360856,50.715934,-8.665241,-47.056336,48.762653,119.480395,189.049272,153.678701,13.299209,-30.953548,2.650538,96.647372,108.357382,77.667449,75.574113,89.435596,74.13168,12.612628,-2.872961,-31.683671,-93.950299,-103.595198,-131.964912,-165.249022,-168.222868,-130.252698,-72.64864,-80.351883,-103.208438,-135.960341,-136.218197,-175.087821,-219.376554,-292.949908,-294.520662,-190.978404,-59.748639,-22.171225,-32.530082,-85.122999,-193.419508,-210.117296,-154.445467,-75.69498,-61.109714,-126.988014,-211.537505,-341.983871,-342.89372,-323.925904,-330.193418,-292.641702,-210.279743,-200.964472,-224.856572,-212.317015,-138.217557,-138.445174,-226.858361,-236.459542,-222.666701,-160.290363,-106.555322,-99.830148,-165.546271,-281.991145,-289.489489:-56.790989,13.579516,-13.385652,-116.508627,-170.30523,-235.86031,-238.691068,-187.113435,-102.093104,-68.222602,-32.803707,-46.422418,-177.619326,-271.90437,-382.830953,-364.691436,-224.096285,-45.943363,31.195948,63.586545,9.293598,-105.206319,-110.757793,-20.119526,114.5384,187.084314,278.790749,256.159303,102.768283,20.922105,-70.146454,-65.404773,11.586791,118.653018,182.121639,270.63025,256.505285,121.891048,58.224417,54.693021,107.787982,95.701697,39.01645,4.872709,-111.778903,-171.151926,-205.010875,-164.082155,-17.724926,28.465187,0.739969,-29.514398,-0.20599,2.940114,-66.043147,-109.607142,91.664024,172.670953,208.303643,178.301079,30.63105,-47.967272,-89.621584,-47.651969,109.875942,246.314993,282.112676,292.894558,269.172337,174.987232,133.976835,180.360927,366.112961,429.810373,383.828172,299.642693,156.263201,123.399486,73.9499,38.106716,-2.304961,30.415799,55.890657,80.185733,66.556938,5.45773,-27.655589,-51.762659,25.378145,94.182272,199.220109,190.477125,82.999977,39.57749,1.489792,4.781233,85.311475,162.653873,157.295664,107.029792,93.082497,94.291841,93.429496,99.39679,153.374703,186.834783,262.201069,284.119203,239.414345,187.810652,33.932968,-58.279101,-128.32087,-25.511901,35.998027,85.853588,56.715783,-38.194489,-57.724896,-13.66507,73.04988,93.811684,56.278334,8.245694,-132.697039,-209.52827,-312.71514,-315.509207,-184.911146,10.326788,70.814955,71.53299,22.708914,-88.751546,-124.176619,-96.684116,75.208448,137.80034,91.94881,17.89429,-108.599765,-157.648736,-254.154243,-259.96974,-107.46221,69.878229,87.27096,22.896794,-8.161935,-44.659498,-67.747944,-85.612766,-2.088039,55.48599,103.502967,87.587454,23.369958,-29.863779,-152.417844,-175.118754,-97.361539,52.486291,105.390889,100.214219,55.646727,-62.599804,-125.05869,-169.112641,-72.536485,-4.972686,144.483233,204.133607,227.925081,207.109948,156.742807,124.801533,61.6878,98.118336,156.54018,196.315523,146.376932,48.15305,41.908891,60.756099,88.443106,119.562522,173.83971,174.062033,133.315015,108.229338,53.345217,24.647259,14.553806,78.51636,99.876845,58.500768,-1.152097,-155.652834,-219.871871,-228.433358,-67.02755,44.326791,230.849097,265.281371,222.635258,186.055468,143.004868,142.857593,199.904151,311.886934,363.959346,358.303129,290.60953,165.656485,155.905463,229.24876,283.383667,286.047516,293.297254,278.652126,157.188294,67.152106,-53.090722,-32.810356,114.345157,147.019945,111.74291,45.331782,20.34235,-77.110341,-151.161597,-194.887366,-59.318393,-7.96992,-35.27527,-87.431714,-162.753512,-170.266405,-161.574834,-157.970652,-159.200369,-111.040092,-50.315475,40.727336,17.919295,-185.812294,-299.511294,-316.5463,-126.002977,-60.603831,-25.997342,-13.55919,68.045551,120.582309,169.308948,175.202259,215.497911,257.33467,251.471547,137.975652,41.666411,-133.625126,-182.318933,-161.316321,-22.632116,37.025457,74.910531,61.870501,16.055008,0.535295,8.837105,43.540958,142.2342,192.524254,208.118231,221.235503,201.709083,143.634123,129.750204,127.758135,131.636012,136.527778,166.852141,170.68837,90.287066,35.229909,-2.057363,15.912817,42.655173,63.154897,100.563533,121.420194,71.21073,-40.674547,-63.902572,-22.466236,135.48554,205.405357,194.438965,112.069092,-90.683212,-151.980984,-178.74571,-162.542371,-42.634384,134.405079,174.830842,94.701344,40.648949,45.747649,62.472266,72.97764,149.099514,185.690305,191.772952,175.753557,132.725569,107.01216,64.419526,59.173094,117.630461,253.524478,299.089511,251.26976,183.037499,61.163958,16.740938,36.537095,243.395097,327.919454,332.557651,283.587495,156.688643,87.299717,-21.823665,-33.982765,43.586891,147.755636,174.446425,165.32303,132.993961,21.571187,-45.784521,-97.25074,21.62508,98.013657,191.911415,205.49963,199.465352,183.167908,81.134866,7.432642,-57.900259,-41.616288,-50.180018,-95.415543,-109.849643,-116.773556,-120.848227,-81.023189,39.328187,78.98933,63.655221,11.179553,-163.301829,-249.339649,-322.388087,-302.704889,-173.856984,-39.807613,-8.199577,-14.741361,-55.106582,-202.341645,-264.609603,-233.171973,-90.229584,-57.977965,-117.799081,-186.731329,-302.31141,-341.411308,-435.615502,-458.055392,-379.99743,-270.35482,-233.099889,-204.148382,-215.312692,-261.833556,-277.066733,-257.695508,-249.365344,-244.181584,-137.075215,-79.33941,-113.447898,-173.020175,-256.936803,-272.487829:62.76014,62.793224,32.961816,0.174891,14.055809,35.351016,6.666267,-83.697964,-42.029282,13.868781,74.120863,54.492833,-81.477382,-151.632422,-192.707897,-165.921278,-61.680405,-16.82463,-31.436053,-50.605284,-34.126522,31.463644,44.242126,3.727846,-32.579777,-28.536581,0.198746,-6.211766,-98.457181,-152.329626,-198.176382,-178.564044,-44.594267,122.312308,172.681613,170.779311,161.774027,217.621995,241.721169,230.44643,240.211436,244.517438,200.641282,178.297074,199.30874,237.951626,281.137258,264.063375,208.777598,170.209299,146.250223,105.331635,100.486348,58.208222,-5.599883,-106.781351,-19.427235,27.081683,33.694275,31.878127,55.214009,80.907722,114.7181,86.634813,-4.836801,42.877136,111.720832,192.751449,197.567616,172.013247,144.332674,119.966912,160.76221,194.322462,246.026309,235.614876,181.597237,173.804142,162.991989,141.420619,85.308971,46.050598,39.148698,44.831277,56.701898,52.447218,26.862514,25.886384,178.594342,267.080794,320.454561,278.349704,179.362481,163.018444,166.822696,151.506437,88.138615,71.915066,87.432239,133.698627,155.415,193.947398,206.244667,186.832034,141.155382,140.92532,222.658487,284.201887,319.408113,273.845816,132.836517,82.369019,73.799025,33.351648,-28.882302,-101.807214,-85.813023,-22.537034,-10.520448,8.678312,70.440133,69.75769,-3.296084,-12.694141,73.533898,103.719473,19.090754,-61.994681,-158.298079,-123.18013,-65.793768,41.745352,61.728995,77.633539,75.462426,50.417403,117.78024,158.046136,102.1949,18.890123,-126.040368,-155.049236,-141.598442,-104.903202,38.110167,112.253174,73.04705,-33.194453,-49.813267,-36.520272,-13.966692,85.729415,196.460074,227.216687,237.699022,215.897124,151.085396,128.608338,53.105359,-2.202829,-8.943191,89.123086,96.972265,-10.815098,-95.1402,-187.328213,-190.084251,-186.799876,-138.834561,-97.527643,5.278853,56.765954,121.782676,138.160626,118.844573,77.360806,-1.253602,-25.581052,-25.150029,-26.5687,-15.30085,57.439562,62.356451,-64.252361,-138.983454,-116.830248,-50.176916,-25.359764,50.407759,98.811996,82.493832,12.600608,-59.046461,29.555244,93.412506,177.930189,154.687877,-11.406588,-89.25094,-117.413914,-35.314706,6.121878,124.843603,207.198829,312.33444,298.83487,184.205704,140.423217,163.229855,213.150094,217.508226,244.523349,248.322926,164.185924,119.256436,149.732756,204.711861,175.166696,70.523108,55.852328,108.498161,134.892464,137.05313,106.990742,23.908725,13.097089,19.964315,-5.558098,-29.981997,-93.996078,-120.121004,-83.448742,-3.748885,3.898789,-10.903655,-14.829457,-22.023881,-17.069348,-21.031295,-40.229011,-19.463344,98.127954,129.542216,79.720582,27.501357,-69.593008,-107.008128,-152.293683,-203.690974,-238.520655,-221.053879,-147.574044,9.523281,51.606234,74.13192,59.440473,15.88051,30.168003,33.603891,-44.025458,-95.876922,-148.549873,-175.230851,-240.201439,-219.669448,-195.202241,-171.644818,-159.253408,-147.062852,-171.999208,-255.425614,-255.92299,-137.417574,-96.474247,-150.081227,-299.149794,-338.391133,-273.792916,-201.033506,-115.887438,-159.239627,-191.906584,-181.169135,-153.377128,-116.465853,-72.70638,75.666467,111.538211,63.015596,29.576127,43.437415,45.140929,16.805055,-33.630139,-31.346734,17.291466,75.858629,93.253229,73.298949,38.554063,-42.773435,-76.2413,-135.856436,-146.654418,-38.468233,122.138834,144.156026,96.086725,72.263881,71.678227,80.712356,70.074835,41.926496,38.358796,48.728793,39.317893,-37.676932,-79.321762,-136.398868,-149.58703,-96.117467,12.569817,25.84612,-58.455827,-92.015169,-3.707362,72.766122,116.492389,86.932077,93.751497,122.498276,125.534405,97.822619,76.265445,47.830778,52.998893,113.696487,182.216699,191.777511,155.011521,133.863882,126.422421,112.486541,61.99947,118.741724,157.580203,158.324389,160.971466,237.421152,268.19409,186.899755,97.399611,2.598862,60.876806,81.438354,14.407708,-27.78137,-16.057066,15.886322,40.965639,26.025306,10.842463,11.926862,39.186862,66.388369,37.382659,-64.425381,-81.400065,5.908776,101.516336,135.734108,184.292728,163.396245,39.260382,-5.2491,17.626114,77.834273,77.043681,23.158808,-10.360316,-57.17502,-65.109507,-64.589704,-65.124657,-79.092279,-128.832529,-149.307089,-151.018412,-143.438653,-135.837776,-146.990889,-201.166351,-264.147741,-289.274895,-212.970917,-114.098749,-48.835243,-112.09768,-234.210218,-241.90115:78.99003,103.97708,116.29006,143.112436,157.645436,192.606193,192.93276,140.311175,115.315659,127.807345,153.674848,147.70375,123.051815,112.0585,58.628141,26.835799,7.612133,54.02793,72.589366,0.3941,-63.304428,-97.147106,-80.57469,-87.953947,-118.426066,-112.348945,-49.592778,-27.393482,-74.261737,-123.141869,-209.901986,-240.528122,-240.354968,-120.040774,-25.877794,137.936863,175.321499,139.031291,89.29579,63.556939,156.320948,186.020769,182.703975,173.36595,153.805089,148.422266,154.549877,175.132966,253.046133,270.779638,249.975569,207.615116,194.7348,133.733685,58.932329,-77.907102,-56.667373,-33.568291,-39.304089,-49.985783,-15.377942,33.147138,86.351743,72.195827,91.398757,209.255299,257.602004,284.192018,263.54363,198.22961,169.984324,137.92581,136.058882,131.231213,78.115255,31.576705,-17.171149,-5.203341,-17.449765,-52.012317,-78.726043,-55.698114,-61.568114,-76.876897,-51.132981,36.940773,44.512278,-2.905164,26.484237,76.455473,226.965159,289.660345,263.828392,182.341442,37.016635,36.818432,164.584281,219.570994,195.263665,207.300475,260.450999,320.2789,283.094889,145.813059,103.625669,135.71141,235.789588,258.592242,228.693754,210.446025,173.089547,139.889623,102.454643,83.927692,37.663512,-68.541177,-59.729584,67.916678,116.932687,128.490351,102.357811,90.302286,83.1383,93.289518,124.392992,121.266273,14.715063,-69.680031,-168.242596,-134.318501,-105.594899,-102.695525,-117.986916,-94.616823,-67.280876,-19.01021,27.137563,4.544581,-120.368041,-163.08038,-179.127316,-188.90967,-235.356181,-228.221465,-91.824334,5.832034,-0.258241,-42.274748,-67.508555,-96.985203,-72.083512,30.818785,92.034802,97.670066,67.053886,30.366838,-20.430704,8.265626,91.977469,67.375664,-97.543713,-147.373281,-87.879961,25.158243,23.708624,-29.576642,-67.763541,-186.178812,-190.132515,-121.456501,61.221684,134.016731,228.432989,257.798884,232.842003,182.135479,75.797205,-31.003459,-70.672089,-91.357797,-82.972848,-47.359005,-55.838172,-230.921195,-387.030899,-350.429028,-144.561102,-58.38101,58.316749,108.430112,102.447889,41.364179,-16.757414,34.760618,53.635214,78.170227,75.941197,-1.295373,-69.120535,-137.322506,19.088127,127.085564,252.060315,281.081263,331.966513,323.128783,137.319408,13.970629,-81.766692,8.11951,78.994977,180.144383,163.3938,24.359076,-30.541177,-24.237813,65.381168,83.818906,58.360321,51.493107,61.911883,56.137813,-22.160443,-73.594935,-68.782307,23.527663,28.661025,-28.847157,-44.81043,-43.338491,-62.302074,-118.924657,-63.286579,-14.824242,37.974383,36.516568,-1.216211,-2.740166,44.392366,36.341265,-94.758595,-110.08705,-22.165035,98.697472,62.941183,-85.108176,-130.759989,-128.351642,-116.67016,-145.518411,-186.268955,-150.431412,-2.983098,61.753966,101.397883,77.51556,-15.131949,-128.359543,-173.185273,-182.308464,-152.62036,-143.605275,-197.333367,-332.200358,-307.036329,-243.808962,-122.861466,-90.697152,-125.059204,-177.832629,-257.242101,-247.842771,-149.958104,-117.883794,-136.96606,-157.684623,-155.342122,-142.322461,-136.806283,-133.340537,-100.707211,-74.986848,-34.161113,-25.006512,-27.752854,-19.757889,29.590524,48.861906,58.801337,69.150433,82.153927,60.116429,23.835884,-14.633915,-12.929026,15.331955,117.552376,172.464391,230.524057,216.658021,85.969718,17.362498,-23.880345,-6.915985,67.544765,155.993162,187.507185,205.635886,188.52012,167.039188,195.269753,264.641285,212.858377,159.193422,108.127121,127.300394,203.258318,217.511333,128.922872,56.179194,22.927976,138.090423,177.248858,114.513814,63.420467,109.010441,159.91755,158.402391,132.192201,128.496843,109.81045,106.645553,120.00982,117.118658,61.810743,30.937785,54.013682,116.23231,111.338892,95.559812,105.794794,136.445543,143.903998,116.046646,65.407961,66.607413,114.937936,135.361585,142.826718,118.824753,-31.937755,-122.917723,-172.927944,-67.678341,3.201171,104.097822,100.797688,-5.766327,-65.231671,-97.205238,-42.570405,-19.552086,13.179828,20.884689,-8.667588,-33.716396,-51.058618,-27.011468,79.771394,177.405411,213.122529,213.214109,161.411442,53.600724,31.63681,32.544665,60.390314,77.470809,73.251146,28.031009,-79.123398,-92.063741,-56.68123,-41.461142,-66.585934,-122.025519,-84.745709,65.513999,88.260263,0.928097,-67.394104,-153.00417,-135.665355,-124.393064,-100.311567,-77.358962,-76.974535,-102.22581,-123.97816,-128.622465:88.448103,87.132085,6.192097,-122.928305,-119.110277,-78.17072,-106.198616,-181.07347,-68.046894,9.31185,44.644735,11.073486,-114.801052,-183.06392,-263.187004,-257.267225,-149.377211,-51.418647,-39.089706,-57.633672,-71.084412,-30.677213,18.456115,66.548885,24.853536,-4.394013,-12.645423,10.098662,34.749553,26.452435,4.200492,9.296676,103.128846,265.041419,326.913309,375.915535,363.962816,277.552763,224.398774,180.333729,246.686279,260.561037,139.698165,41.732678,-41.443547,-20.588777,-5.121107,-3.884156,18.179271,-80.247541,-112.026264,-52.181242,-43.697599,-129.564248,-149.288314,-72.018037,33.60848,63.208062,95.992789,116.799351,95.351095,38.878877,-46.051852,-35.885055,78.266558,212.604365,247.358734,243.17512,215.234691,142.916357,132.699177,230.677337,373.414158,413.825341,408.716758,352.869825,169.671491,95.634605,60.516393,64.878353,35.06109,-1.867918,0.797148,33.941624,25.654438,-38.678709,-36.713593,58.371304,109.539954,97.499798,104.407581,149.027142,195.866773,165.228633,73.165803,35.237615,47.825504,173.77827,199.725665,150.065039,133.157642,201.045427,254.44323,298.034967,246.966095,195.355712,158.483238,192.233832,214.659313,182.592977,96.971438,53.46506,35.200207,49.812709,13.7756,-56.363104,-45.672374,58.17049,98.029762,55.770957,6.846043,23.292351,46.75486,23.91673,-74.648539,-140.094372,-275.646513,-299.705375,-167.728349,25.152701,57.257487,18.127655,-6.619182,-1.130971,18.707106,66.458223,152.514703,184.7964,131.615167,60.321263,-44.186845,-63.699763,-110.854303,-132.724549,-55.184733,88.177304,96.061138,47.200655,42.460554,53.091129,46.365149,44.447502,96.803559,123.115522,103.890619,51.033714,-23.253853,-0.664736,54.840273,35.279922,25.289569,132.890483,132.051683,-23.55609,-101.795678,-155.975629,-151.314645,-128.800595,-98.03534,-66.475174,46.643408,103.536367,156.37866,147.017673,69.521786,26.894407,-7.456159,26.828304,58.614894,62.160044,44.527995,87.002986,100.321357,-22.196251,-169.308051,-172.076761,-25.510619,54.14675,74.542151,35.695146,-66.238282,-101.70115,-62.77841,107.816867,186.655754,182.885483,112.18734,-26.762938,-81.250788,-177.794683,-137.759362,-55.89831,121.440146,199.120546,310.191239,334.205884,320.172484,289.061631,249.463329,293.995962,322.037119,297.682877,242.580715,163.444269,167.058853,211.226037,227.173665,211.342453,160.933183,153.651994,190.284406,204.910383,142.345356,74.867522,-14.397276,-6.181852,21.472286,90.876527,98.478125,23.09361,-35.689056,-112.404445,-88.989721,-65.097119,-32.434279,-26.847247,-20.715228,-1.218268,24.10994,14.37444,1.921762,24.444369,40.609076,11.295769,-40.418163,-152.85917,-181.315388,-127.06791,-76.218593,-111.551374,-158.929085,-117.994016,23.726767,84.201419,135.539017,140.868728,179.166843,124.86448,65.139086,33.694861,32.292209,-56.112304,-104.77894,-111.389515,-90.704996,-108.447885,-125.989359,-99.481372,-49.811208,-55.515913,-98.285866,-102.171859,-50.47364,-23.083149,-33.816499,-45.986602,-23.808027,33.113709,27.573991,3.868089,83.373228,114.836733,88.469376,35.465466,-104.488856,-131.780731,-69.573553,-33.534976,6.399513,29.220785,42.014941,40.017939,20.181446,14.058367,13.847227,-43.278945,-36.532474,20.451732,75.07041,14.867595,-192.286762,-255.516214,-225.471864,-171.545407,-71.230855,2.876862,15.333859,-56.102988,-110.548442,-109.543885,-61.293438,9.975445,57.810601,74.01545,53.478675,26.237342,-19.078837,-20.976695,-32.069812,-64.558232,-78.017405,42.208042,85.878767,42.473193,-7.787757,-56.203029,-52.506849,-4.000168,132.420775,200.43333,202.677273,148.376827,44.222485,23.568824,5.967112,-5.196217,58.288542,159.394509,156.246071,93.037677,63.034132,17.377067,6.962896,3.661057,49.254859,98.972099,171.406254,193.120492,234.769391,227.17486,149.780056,123.023968,68.595518,-124.994841,-199.324017,-196.271694,-184.676369,-150.163432,-85.362833,35.05409,50.607548,48.49053,25.050456,1.95491,-42.598276,-77.206192,-190.160345,-224.072351,-141.796462,42.47157,94.773048,44.738852,-3.865764,-47.098143,-71.820315,-98.426461,0.360113,27.277598,-42.1977,-88.863376,-152.083983,-178.551183,-229.10485,-247.360213,-277.67962,-338.363474,-332.10115,-212.162552,-153.569201,-121.59214,-155.312465,-286.512888,-328.788866,-291.404898,-167.031377,-115.8454,-92.303323,-109.115159,-124.489953,-104.252614:forward
-19.461909,16.429605,8.351795,-33.687846,-22.959571,33.625952,24.829065,-6.358563,59.110302,80.561651,57.838741,45.611574,82.522805,110.914835,114.425302,107.197026,138.239012,176.001178,147.274785,1.052029,-39.548548,25.993424,74.659758,128.872289,194.520375,239.568892,291.15832,263.519895,126.650668,79.20023,109.158162,158.252964,209.055897,153.657593,114.21256,42.28299,19.143713,33.222861,52.757203,41.28029,-54.994748,-116.979264,-231.126951,-254.83709,-153.112502,-56.12845,85.683516,120.863798,146.88939,49.652426,-39.542069,-194.631771,-213.597172,-166.149721,-181.526335,-276.739281,-234.532122,-195.3168,-186.237284,-181.680844,-114.616837,-85.343484,-81.390769,-76.879666,-68.716015,-149.501268,-197.867909,-223.555198,-195.745068,-120.485393,-100.049103,-86.177615,-96.219561,-101.792291,-96.031479,-93.045883,-49.528648,-0.455561,120.551141,177.517799,212.17168,122.814104,72.488787,20.060806,28.58662,92.587492,128.29654,210.496597,269.446752,243.491543,98.109422,25.060862,-15.878503,24.64654,143.86771,188.23471,191.357915,98.706215,48.959251,-26.697889,-31.182811,40.25001,70.932075,10.845859,-131.494598,-166.101764,-167.294782,-187.428119,-231.700241,-189.969016,-10.134804,64.435702,64.298821,-82.61704,-114.714809,-67.777517,-37.217349,-10.233295,-7.757741,3.338685,7.191804,-2.663999,-23.003619,-38.319936,-64.964685,-56.707654,-16.551945,1.856205,30.523694,15.997424,-0.098284,-12.310466,3.143913,89.465594,133.641087,152.372787,142.352368,157.45457,167.562724,128.710306,8.738873,-26.97587,-74.806905,-105.791151,-143.414893,-110.168217,-74.759035,-55.719003,-87.683551,-176.093434,-190.731991,-106.832362,-18.502161,-21.850362,-114.379626,-189.138133,-249.285123,-196.102075,-46.657624,-0.547283,5.556054,-51.781805,-71.421341,-107.501971,-129.687329,-128.490617,-88.570162,27.357356,72.850316,55.001957,-28.487609,-67.171176,-29.074073,31.765814,71.159857,39.154303,-65.908734,-137.052608,-152.919808,-204.549702,-211.033641,-108.888903,-46.086821,-59.757672,-196.438836,-227.373056,-175.384404,-119.505328,-3.479131,38.064071,46.942844,22.765797,-19.467117,8.907435,44.367399,88.007055,105.724997,158.592841,161.984933,122.699977,111.611396,123.151089,129.367505,113.523161,90.746698,75.887567,-3.718372,-39.907843,-14.688387,53.455362,49.798259,10.664507,0.68279,-11.803583,-16.028495,1.462961,-0.422813,-25.575831,-83.012604,-103.14073,-117.293183,-113.562977,-94.10088,-79.696361,-60.839292,-30.869231,-11.99166,-51.507033,-110.207154,-210.476569,-220.82182,-141.888449,-77.47996,-89.775415,-119.226775,-126.92484,-129.571504,-106.875077,-28.758833,4.558149,33.143763,83.938127,118.571426,51.981179,-36.171896,-92.88211,-49.307238,19.077509,5.864094,-0.853019,-13.602668,-46.231193,-176.448559,-237.952845,-279.308589,-270.095637,-263.666018,-300.996749,-320.786132,-327.580796,-316.996919,-292.167907,-278.406555,-227.901042,-211.331632,-231.91857,-263.806868,-278.226016,-327.510896,-332.262466,-273.467094,-250.908779,-285.136664,-272.795901,-225.518419,-160.500281,-139.21281,-67.562832,-43.912726,-57.718832,-103.48562,-145.610473,-264.030032,-300.379396,-249.926681,-192.840194,-135.015524,-129.96865,-97.629788,-34.678038,-2.757998,22.767934,7.727358,-37.939268,-46.502428,-59.312594,-106.700771,-122.404309,-169.337003,-206.593442,-173.883721,-89.57695,17.972853,-7.66781,-122.978543,-188.448829,-192.648857,-168.225345,-158.087651,-168.604339,-166.177767,-99.906689,-40.868291,-41.727367,-105.759176,-142.8901,-148.734007,-131.360982,-128.377166,-135.143364,-119.8008,-102.28648,-128.343089,-239.957456,-258.632128,-136.392808,-37.770542,102.562563,82.286612,23.615603,-66.185596,-59.170986,22.637215,55.349046,91.622659,110.768103,98.740219,11.075465,-23.753398,-14.569074,33.574916,119.242831,127.153112,105.444994,84.898534,94.520809,103.00763,64.272669,-59.878028,-103.689529,-112.900236,-91.849737,-82.681038,-113.459835,-110.374105,-59.007048,-21.590962,39.9494,54.892381,61.767545,53.308849,80.315377,177.03097,178.130427,71.387534,26.058469,30.782241,68.854343,133.623333,102.882673,69.211536,38.159466,55.267359,118.62536,147.428376,236.521134,305.532114,302.293978,253.60674,210.054229,137.055655,138.269475,114.62669,59.782225,8.082349,69.43893,69.75674,-32.625562,-73.243729,-43.150576,-17.090096,-31.316921,-55.059968,-31.852948,57.318303,67.007593,22.7658,34.598025,155.208208,218.232307:-5.226469,-85.217564,-99.817916,-82.807942,-65.645936,-54.613068,-51.629274,50.192728,157.86133,126.384562,-31.847764,-68.728085,70.902671,186.851032,246.339539,198.755014,149.179506,107.011074,26.792834,-111.936688,-86.919012,72.230188,111.674881,94.499582,103.03093,128.257568,123.063743,71.797552,20.362359,73.123191,241.530321,286.255272,222.609339,122.919898,103.74365,41.714987,19.451751,82.568113,115.781786,56.915549,-76.407558,-112.76913,-144.772599,-170.153764,-140.717593,-55.260056,137.582054,199.590715,218.112705,93.517913,-5.505711,-171.142873,-187.852013,-93.586854,-30.786267,33.514111,1.980896,-19.876568,-23.673506,-27.752614,-89.238579,-124.566368,-157.07908,-153.389414,-157.180378,-227.245756,-267.325557,-300.973386,-264.159622,-91.150025,-28.773591,-73.523381,-167.666428,-168.80133,-168.428055,-192.437482,-168.838971,-100.597317,75.101597,151.59693,180.575538,46.725263,-21.081932,-52.684148,-5.157696,130.513749,184.130097,284.134389,324.476887,284.831642,173.149058,148.399843,158.604885,172.050898,226.899419,270.183527,286.766908,215.973208,188.470098,119.297003,79.447102,41.154048,32.836721,-18.889889,-128.720899,-171.239675,-166.777652,-123.830283,-13.778136,29.99109,72.625204,75.799308,47.83252,5.941236,-14.938442,-78.282971,-75.805257,48.327802,105.729853,110.137211,49.719251,17.444367,-32.903233,-15.677585,125.404353,181.350137,142.701622,82.083169,8.717584,9.694915,18.464627,39.269279,58.18535,123.687897,162.477035,200.311506,141.271966,98.082416,49.509181,33.028649,-9.15728,-13.711556,18.244459,30.270987,-8.868579,-36.478698,-39.176536,-109.226646,-132.438717,-57.520224,-0.655667,21.455002,-77.909995,-98.392614,-79.706978,-87.103257,-91.397638,-70.994759,-0.437351,57.302598,145.774588,68.063921,0.005585,-67.018848,-57.147405,-0.486541,41.407622,177.373025,274.676778,275.460154,197.671849,135.720754,88.941035,121.2768,141.657745,80.701193,-100.45272,-132.260844,-110.391051,-158.433825,-184.400398,-86.313585,-4.12608,48.871961,-62.06975,-123.998396,-150.663501,-123.197334,-48.979047,-24.624492,-37.879767,-46.437576,-26.377225,-18.074281,-19.417746,-6.045146,22.190184,104.087194,142.727104,191.289842,138.483804,103.883032,75.17143,52.411316,8.819033,20.637016,53.482332,37.263778,-11.22349,-47.791714,-95.504078,-191.561176,-180.744695,-62.842099,-25.063278,-34.172872,-84.825134,-122.171063,-226.621471,-276.350123,-293.335812,-264.744738,-202.566153,-180.257199,-169.240191,-188.569835,-211.895234,-295.107783,-316.740809,-239.358341,-162.213565,-59.900706,-113.366198,-161.025503,-195.036725,-188.298466,-150.733482,-109.677711,37.339931,110.590867,116.349914,54.940482,49.690757,-13.036163,-68.515193,-119.052139,-128.407317,-175.766023,-163.335113,-131.69465,-150.526889,-206.765758,-290.559175,-298.996884,-275.524163,-256.04824,-237.787998,-288.964881,-344.082626,-401.614289,-367.006507,-267.881356,-247.440272,-244.744801,-242.01645,-228.050714,-230.214226,-273.292612,-362.533776,-361.802626,-268.137496,-211.856427,-178.672624,-216.913805,-218.005807,-160.876641,-110.830157,-34.919851,-31.610264,-75.366034,-129.500448,-137.247586,-133.675514,-143.475127,-123.412167,-74.000586,-1.421279,-8.95346,-44.578961,-39.133031,-35.467311,-38.395317,-29.023257,9.092656,35.93912,106.186153,60.482781,-32.598412,-217.094459,-239.511684,-113.661715,-31.985062,27.276834,23.589671,10.051932,-43.987199,-88.036824,-154.752026,-160.280196,-180.85838,-218.389162,-228.243537,-50.409182,25.551294,-22.191823,-96.417992,-142.543901,-119.273553,-98.136564,-103.417548,-135.086904,-247.991105,-303.271947,-319.775531,-285.035916,-171.945995,-91.073978,69.849198,0.496606,-112.234651,-217.700002,-172.163566,-41.789171,-3.320955,53.548701,71.433874,13.782589,-94.778877,-129.679157,-166.245646,-143.677203,-20.145626,25.832283,34.38436,-1.562976,-17.375734,-68.198006,-103.485468,-91.320126,-42.860167,-13.36864,-45.283067,-97.118528,-110.974439,-115.452313,-68.459805,-12.714284,27.945704,-3.374942,-36.336228,-14.556648,-16.227149,-24.464921,-12.770743,5.233754,-17.61986,-101.22964,-120.422295,-82.176411,-39.620589,-52.642975,-79.754423,-47.583631,52.409149,95.962449,208.966553,235.52256,192.790403,106.164286,70.435749,41.886852,82.555884,191.433344,195.397593,119.149584,40.878051,13.565291,-31.583885,-45.989931,-20.786363,17.726269,97.464547,96.684049,67.91939,13.165538,-7.191605,-7.602805,21.783238,109.939608,141.585876:27.006763,-17.684342,-60.265833,-138.109081,-121.621742,14.295605,85.784562,163.836811,108.61406,53.032216,-33.499986,-62.919795,-46.699099,9.063822,108.200641,124.216752,118.651825,72.499873,18.529371,-109.948005,-133.732354,-69.676055,-15.480201,77.629185,73.07874,40.553447,-38.673913,-88.176273,-108.772771,-52.969476,80.745167,112.590437,84.758823,44.273432,53.996348,90.79839,112.643431,189.67696,233.813616,219.448483,12.812428,-87.950576,-198.852799,-214.399438,-110.938417,-7.96903,164.394567,216.254975,207.062785,37.645811,-50.976997,-148.499664,-146.191913,-101.729749,-82.931847,-53.550096,-67.012915,-83.687735,-113.493438,-120.131386,-95.472839,-87.952995,-125.627458,-141.046891,-162.112274,-237.636742,-284.916795,-355.654632,-331.195045,-122.780922,-14.768809,46.783359,-48.181202,-119.38943,-259.918983,-292.340797,-206.968137,-107.629402,86.978601,136.850662,87.919993,-19.249733,-43.430143,-42.145175,1.691419,146.168724,196.543864,239.355965,205.126459,165.627832,93.243373,60.975124,40.685101,64.782309,147.493664,195.935198,273.10856,236.41555,157.105838,-19.736499,-59.918909,-56.53992,-33.457185,39.460731,45.381145,15.385013,-71.371443,-114.640594,-119.647058,-69.51251,30.168808,35.679178,-18.10577,-66.047505,-85.227743,-92.556669,-72.087613,-35.040285,-39.197605,-69.656347,-62.315022,-50.207749,-48.90805,-50.363469,-20.167832,5.836488,91.490073,140.15489,135.26785,34.787167,0.052841,-37.189667,-36.485968,34.762665,90.427877,156.251908,137.866397,109.036102,-1.140473,-63.590168,-67.762346,-11.538754,38.650592,5.748496,-79.652392,-140.223531,-163.266747,-153.738498,-104.995047,-6.736096,5.988645,17.530061,47.821332,49.496328,-35.847673,-100.817649,-101.603786,-34.318593,87.757869,119.092656,146.171823,128.47816,94.860259,2.825436,-10.564206,72.040393,140.935047,261.618331,272.777267,234.295007,122.154142,87.966309,148.603723,196.65574,161.696757,95.65175,-25.89868,-80.760916,-111.364312,-164.112306,-127.50132,-8.387518,-0.511434,-57.630773,-129.263843,-161.258578,-170.212158,-145.404074,-102.403923,-93.022283,-58.715767,-50.622425,-117.214265,-145.759084,-107.281652,-27.104882,-3.932564,42.832398,78.605492,170.488326,179.401083,138.308968,70.405329,60.372947,44.335286,38.45901,41.9591,33.547637,1.894419,-10.309198,-45.574117,-162.59957,-181.001721,-89.796316,-30.14535,-6.75135,-108.312602,-154.355824,-171.685051,-172.95063,-235.980736,-272.946806,-252.897065,-205.126539,-160.703213,-159.18056,-146.71989,-178.212525,-215.811816,-182.863775,-102.174792,29.207259,-17.913175,-82.827246,-193.803136,-217.789282,-144.952972,-52.823908,132.940614,184.482466,170.704286,110.990248,85.075287,-10.965452,-54.597461,-69.419266,-84.928862,-195.0802,-255.790626,-235.695053,-202.142906,-224.877258,-301.528268,-323.374071,-325.458067,-316.564679,-270.569743,-216.017386,-220.506078,-271.830947,-281.720223,-248.464437,-213.868372,-126.763274,-97.270724,-137.692867,-250.538102,-274.340131,-254.529941,-230.686607,-180.963125,-160.416652,-109.041737,-90.190521,-143.627273,-273.088028,-262.410553,-103.712194,-17.109298,76.035941,-2.149916,-75.702064,-172.614658,-187.259382,-145.325229,-99.316959,-22.828218,-8.964931,-19.053368,2.018014,17.175045,-0.308667,-18.596356,-25.703831,-1.569574,76.553746,58.091327,17.059562,-30.108457,-31.910835,-6.81683,6.063841,0.510517,-14.278712,-47.176353,-46.863047,-45.017456,-105.153955,-157.574727,-187.365127,-136.72957,23.510091,96.007882,56.770087,-148.786724,-241.810943,-226.211447,-148.14951,-71.517565,-86.220402,-134.516116,-214.646587,-257.195671,-256.253623,-224.065336,-216.374623,-225.184538,-188.245168,-211.710836,-262.755124,-313.845628,-279.446009,-160.750139,-117.367632,-36.417341,-1.751335,-56.459227,-172.817025,-188.732007,-150.730514,-105.314531,-6.538559,25.576377,30.783976,-30.833198,-47.948159,-26.419931,-18.364454,-24.963819,-8.514178,60.609198,65.536588,-50.237041,-157.064053,-150.436418,-100.266687,-78.661682,-7.669568,44.092383,126.076828,92.497683,39.185113,-75.069939,-113.859739,-109.534866,-86.566564,-92.809681,-118.225309,-154.298133,-128.065965,-109.984262,-111.877927,-105.649128,-12.910548,69.859053,241.467938,300.471132,272.407945,144.845519,97.575661,145.998213,203.441818,227.011478,192.63489,125.697249,115.846439,114.700128,74.18902,51.860338,61.462913,94.618875,173.741667,198.161999,184.314264,114.141902,82.727205,114.28289,171.783217,277.211256,278.434116:-97.587172,-62.355553,-56.87347,-96.938094,-102.563384,-3.822229,63.299441,125.957566,85.426397,73.298594,140.865305,171.816101,141.85574,118.948416,138.334479,164.641693,147.55652,32.962724,-19.704367,-96.49837,-120.474893,-90.153119,-31.564391,91.267629,135.873354,144.679935,95.833369,11.119055,-119.515049,-96.274786,20.909686,53.486365,63.226287,60.624846,48.67033,-13.362368,-14.373877,85.388402,132.400586,125.872192,-21.409688,-106.295498,-202.242716,-198.961955,-65.60337,38.299168,211.204622,253.118853,208.72323,53.362038,-34.595178,-218.027498,-281.282954,-296.70898,-279.82434,-261.204875,-223.057513,-193.450578,-153.813331,-167.192656,-243.098214,-271.303922,-251.752789,-209.384755,-182.931819,-280.029979,-316.935564,-307.32864,-251.455916,-71.075932,-4.855906,25.59867,11.622645,-4.109618,-76.771535,-110.823065,-59.966752,17.869543,149.606961,179.536799,157.514909,56.708105,-4.191607,-75.778669,-51.816209,68.316738,122.12843,201.963255,165.331121,87.474392,-35.6879,-55.895221,-48.917246,-13.548532,89.702048,118.844416,118.351688,80.245417,32.1962,-72.636256,-80.260505,-21.098036,-2.12537,-6.119641,-25.316821,-43.85436,-94.484811,-125.111648,-150.612045,-131.68142,-91.447003,-79.166588,-57.10217,-117.537653,-167.318873,-209.298066,-200.417072,-168.258818,-154.104454,-110.690426,-60.270439,-67.9441,-132.526639,-147.053288,-113.01817,-92.916174,-59.361459,-37.243134,-27.062119,-26.873487,-2.761947,24.945071,19.012121,45.53161,82.41014,117.194483,84.888425,66.161466,20.814255,-8.384656,-71.500456,-108.881864,-156.155652,-145.405192,-134.427668,-146.780178,-129.465508,-153.163553,-199.074877,-190.579249,-120.143706,14.842212,33.479142,10.088708,-51.274785,-77.483887,-94.356994,-67.270137,40.260085,84.270866,102.108048,62.209115,39.987134,4.566643,-12.290051,-57.641014,-61.075952,40.038126,132.471364,112.946006,-15.133812,-76.41703,-65.123689,-8.421807,17.151556,-30.564816,-144.844274,-152.276679,-123.828171,-148.470392,-186.258544,-160.129818,-112.462022,-114.124166,-258.762713,-302.941279,-218.128826,-130.200194,-15.042055,-1.245205,-0.167133,7.864257,17.946343,11.177792,13.300863,34.88616,61.141496,148.262798,196.073328,270.496242,276.628472,249.995068,199.580403,186.244205,138.727918,99.546941,27.004163,10.850708,32.429802,67.401566,62.659454,41.329287,60.042797,119.043733,121.788748,108.391837,132.42234,123.299278,26.889272,-19.741393,-25.581293,-20.195448,-81.134542,-109.943113,-82.401324,-5.250862,4.629933,-68.832362,-101.402674,-52.726649,-4.454198,47.084036,21.50303,-20.333595,-105.343151,-113.410877,-41.44212,4.345902,65.917458,98.458996,147.508983,163.906064,191.643944,202.707537,151.041239,29.678422,3.310594,1.859734,-26.862012,-47.732347,-53.213858,-64.05975,-138.444535,-183.53931,-274.097736,-303.844715,-274.252416,-190.136233,-175.572317,-173.221999,-140.967772,-44.900684,-33.495286,-90.988691,-162.011877,-189.47906,-253.788684,-298.453226,-326.766509,-273.183266,-126.575416,-91.218218,-101.101949,-115.396742,-114.994458,-117.519064,-90.260864,11.446199,41.40224,59.474699,61.731432,29.747798,-113.664505,-174.719262,-147.958621,-86.040465,-20.547843,-26.406168,5.984388,129.410411,149.222354,46.472144,-1.474169,39.698982,79.953967,62.022999,-12.772464,-18.986311,-20.144595,-39.547198,2.041692,87.612071,229.650314,237.50052,136.991806,-11.607411,-50.181083,-37.453696,-23.999718,-51.634737,-77.834565,-84.411576,-60.795331,-77.217885,-167.739989,-207.71472,-176.883519,-115.261823,-56.706861,-92.196359,-209.364972,-280.562876,-300.499115,-320.329142,-317.40938,-294.892459,-266.008349,-176.640569,-168.931592,-193.070751,-203.275648,-186.789662,-121.781053,-84.25489,-46.897344,-50.060518,-114.971186,-184.262229,-182.083299,-158.184304,-133.236915,-26.890054,21.403322,54.670154,35.098339,16.395306,-17.851897,-26.743417,-17.078446,2.969787,24.625569,0.964023,-122.875573,-200.324319,-165.163749,-44.500202,-14.252898,10.935211,38.367948,83.900633,62.522774,54.318984,37.609975,14.016942,-34.38214,-51.692697,-84.147763,-95.651302,-86.550284,-49.307561,-48.125804,-51.496339,-7.706371,150.835622,220.048223,305.82526,274.972484,217.085696,110.519218,83.240345,92.555937,125.145123,150.837826,118.982945,61.197521,50.410526,26.138318,-46.068485,-59.750985,-28.31869,-2.071647,38.203723,55.700786,75.080883,157.070096,183.945497,183.584232,180.555458,181.641979,177.268773:-8.081923,-61.52806,-111.455766,-176.925714,-152.628256,-5.944433,69.886822,163.627404,132.207259,95.476636,76.022647,83.485615,107.344587,130.486378,222.325352,274.802967,246.274115,54.006595,-34.255005,-138.510851,-134.821273,-19.454087,47.250195,90.752266,65.04321,63.493198,-10.21252,-109.436969,-255.344664,-235.204123,-96.997611,-42.267475,-20.056181,-42.029484,-40.365434,-23.321579,10.159776,156.926634,237.338925,284.425474,108.321432,10.753219,-51.013216,-29.854777,73.261074,154.126145,325.196414,378.301017,342.505247,105.676251,-47.499647,-255.118488,-264.067143,-172.186426,-137.232161,-150.475081,-184.877426,-166.569369,-137.226346,-176.931985,-279.449349,-281.49817,-202.68335,-168.701414,-205.195963,-328.380504,-365.439665,-347.309909,-290.563717,-108.278103,-14.28328,98.192257,55.371765,-4.858411,-90.529467,-97.015652,-32.027822,30.347442,175.333467,225.646185,140.8842,-92.148,-162.692732,-160.507038,-110.47194,17.669705,72.615475,125.400681,74.732805,7.637325,-119.05301,-134.762277,-82.217589,-31.709177,107.696333,170.77411,162.85627,16.135448,-48.428228,-114.755618,-108.127589,-31.502306,13.810055,74.240041,45.933948,6.455099,-80.033527,-114.243484,-86.233195,-31.782903,44.968185,42.549216,-43.058345,-173.122484,-241.828913,-317.674146,-284.105196,-152.693036,-125.439096,-147.064823,-140.380654,-142.194931,-194.643941,-210.271386,-136.923273,-74.381043,-13.010661,-24.509144,-76.882578,-101.551483,-125.278882,-177.327403,-155.892888,-20.402689,45.637031,101.017606,23.959085,-58.869016,-226.447733,-244.907094,-98.527574,-12.589993,22.830489,-15.351234,-126.447378,-196.323176,-215.550283,-249.553953,-238.133665,-119.330589,-29.886007,106.735103,111.282686,93.833648,21.097471,-46.515814,-129.677798,-94.734733,102.415457,200.122702,242.838771,129.674601,60.974363,-30.917052,-13.692722,133.718737,198.500767,223.493281,175.419563,132.811338,-25.191461,-96.078681,-65.280842,-11.480729,-32.609696,-85.533432,-136.063934,-98.692549,-79.927902,-130.30725,-180.708636,-200.151567,-160.85963,-104.270273,-196.756605,-258.750779,-275.585353,-239.98556,-186.730646,-160.507648,-49.091016,3.256797,5.761032,-57.449948,-69.467674,-22.985666,17.686123,85.936137,124.001644,219.072426,247.388067,225.376163,120.96351,39.298462,-67.718517,-39.227741,97.010241,127.136607,84.03334,13.017735,-27.746301,-96.037993,-86.448948,18.920537,83.595838,154.263986,105.958404,56.245292,-64.010225,-104.113837,-85.037176,-61.495799,-47.479586,-44.593299,-20.125236,19.395564,-9.864343,-144.23068,-178.214238,-110.962593,-34.729606,46.49734,-57.191596,-114.26932,-159.058801,-164.714741,-141.617778,-101.027126,25.15337,85.316016,111.105427,59.876875,49.194481,19.565902,-13.66994,-70.783867,-87.04205,-92.075023,-64.402325,-82.387513,-213.274269,-277.57652,-306.217938,-289.348304,-283.357376,-294.737646,-263.185162,-139.666118,-110.904075,-161.728975,-174.196582,-103.362126,-35.799928,76.850223,-13.187384,-119.67387,-315.122017,-365.774982,-332.535744,-273.662787,-153.156864,-110.742114,-98.655623,-154.559314,-190.681452,-221.42458,-188.898574,-92.191769,-57.84386,35.564495,82.93549,45.248369,-68.651251,-129.008751,-232.911453,-228.757978,-63.319775,34.817818,95.003886,36.287953,-1.226076,-55.139003,-50.259026,9.39121,54.392961,118.890308,37.323879,-26.424335,-108.656635,-103.870812,70.527111,194.758292,305.240146,276.373331,122.467438,-17.26432,-32.893407,-10.438478,4.3493,27.569118,26.744962,18.788722,31.205804,30.461773,-47.798271,-127.300915,-231.570907,-196.710302,-51.044585,-27.984852,-110.935232,-219.16224,-262.010816,-289.890617,-272.217509,-259.301352,-247.517221,-132.755198,-110.484998,-181.21788,-336.31196,-347.047414,-200.393299,-110.660379,-27.210993,-27.2116,-74.341618,-140.074795,-164.6009,-144.303104,-86.164939,34.312302,66.594651,98.08068,107.134197,127.747042,179.630365,165.151013,91.842074,91.079064,166.088289,183.132098,96.407454,-8.430313,-22.940286,6.326142,49.457047,157.546019,195.329368,217.100536,201.585568,189.910378,102.428676,36.871942,-8.643259,2.011381,12.665115,16.234679,7.365094,-26.067496,-39.075752,-14.780268,34.047742,130.223573,160.127144,224.09292,244.368002,223.463994,145.441285,99.538668,75.148056,105.261389,150.722641,150.812052,116.531119,44.276469,16.698463,-12.994198,-17.664967,39.830642,92.910846,139.108569,137.467769,164.777383,219.806097,225.906003,241.8601,259.559624,273.556478,258.786616:-55.126988,-44.768026,-7.449152,-2.047028,-54.055206,-174.567833,-183.32112,-54.006902,2.362147,-37.380322,-70.371876,-40.770084,8.021442,2.91083,-14.844262,-6.249917,0.520386,0.598114,24.156006,34.132372,-4.865601,-75.561041,-59.181043,101.534367,271.346892,292.93299,223.254009,164.717929,96.77683,88.36493,42.71942,4.413367,-63.004364,-54.356564,-28.06409,-48.639567,-77.440049,-43.250508,-8.744022,-26.692129,-100.059506,-141.956685,-240.760158,-249.360739,-82.290487,54.197762,218.180306,210.76303,90.599083,-105.88156,-205.854925,-359.908953,-408.204085,-447.714113,-446.078947,-410.378905,-325.812818,-272.597859,-191.54022,-182.893795,-189.748468,-187.166263,-185.759158,-174.674702,-109.664207,-113.208884,-180.127911,-324.778618,-321.295707,-136.969523,-13.969787,164.328393,150.193818,85.274861,-7.11513,-21.15414,4.168284,42.797297,131.693167,178.410818,227.81497,111.061232,14.868189,-74.957785,-34.320366,106.375076,155.869628,207.675161,159.947886,91.85723,-55.663217,-105.93047,-105.343375,-67.700705,-13.561253,3.6216,27.573237,-16.267962,-49.899519,-106.342305,-112.953156,-32.440722,25.83141,55.222411,3.798104,-20.553823,-80.865589,-122.530945,-148.279222,-110.21431,-46.556263,-41.963369,-21.006395,-38.907706,-74.196755,-142.946289,-175.088767,-236.63675,-232.822413,-87.194106,30.157543,-19.200958,-236.003717,-316.875094,-327.761588,-273.292264,-149.384516,-120.841428,-151.959106,-139.165771,-65.635072,68.258939,66.011284,44.142038,66.653959,75.161769,30.600535,30.030319,42.052411,31.255332,24.23933,25.682525,-39.704522,-97.316513,-199.274074,-161.980251,-93.732135,-43.597872,-80.629044,-170.859063,-193.780984,-149.515027,-27.435944,-4.850442,-84.85845,-153.651049,-212.902955,-177.571914,-60.839279,-17.789361,7.377662,-34.531153,-64.78822,-132.878479,-148.93897,-104.723123,-67.096253,-17.652983,-51.06083,-110.524941,-228.28299,-224.394903,-105.275057,-56.906362,-39.881378,-59.293938,-150.219266,-244.258399,-247.840331,-177.198598,-139.339393,-97.7136,-90.341409,-98.0338,-161.210461,-186.397206,-150.153504,-114.596987,-41.145691,28.587227,192.034889,214.520629,79.489884,-19.480925,9.255842,72.689835,93.242835,144.934117,159.535894,172.748494,218.658627,253.96454,259.897563,213.274001,121.835591,103.833972,83.975979,77.452462,100.533459,135.254856,123.272699,73.331607,76.248472,125.634084,132.810362,118.521274,136.134208,125.218516,21.11523,-14.478598,40.5297,82.642862,84.451093,62.41984,56.594649,112.616151,124.441656,28.4465,-52.16894,-140.175289,-123.075202,-23.230893,-10.997652,-48.797247,-82.928648,-63.717667,-31.692021,-43.828023,-82.383104,-52.07421,119.811591,165.72172,115.847194,44.687951,51.677347,111.029412,151.426229,219.072497,175.261926,99.147385,-42.667158,-68.121896,-84.289119,-119.237752,-232.4743,-263.288142,-261.188775,-258.963689,-258.347967,-269.604497,-276.210495,-239.731314,-190.636797,-67.879916,-67.454264,-138.239754,-312.165551,-390.645585,-474.780577,-443.575738,-257.199219,-168.903353,-130.346351,-197.577996,-211.280226,-197.206888,-167.684169,-30.173885,17.076432,-39.629875,-106.115809,-122.154595,-228.887789,-286.755204,-226.957318,-125.567373,25.063034,42.997885,38.722017,69.47747,68.712751,23.833815,30.185687,113.097767,121.658185,2.79939,-99.723993,-100.603846,-128.022857,-165.238162,-127.755506,-42.772702,94.795387,104.777018,20.607946,-94.485992,-112.832374,-72.747486,-46.312972,-64.406306,-103.131267,-86.025715,6.491683,-24.840705,-182.433006,-218.843609,-136.460985,-74.207377,-53.145732,-76.06236,-98.882085,-117.435971,-134.56678,-176.173855,-191.106096,-147.077513,-82.805051,51.436853,58.961675,21.972516,-39.650692,-54.243216,-27.526791,7.986084,41.327743,40.201363,32.4589,5.974408,-4.23698,1.103724,26.214448,113.466788,141.063214,119.95938,111.249919,144.247186,200.886576,168.7495,27.396215,-14.15151,-24.082701,-12.970362,19.033679,54.306784,96.605265,143.930256,106.06768,19.437952,17.493477,73.011942,150.006446,172.278834,141.584764,85.294836,-15.129389,-7.411031,79.746577,101.382755,78.549159,57.303946,73.050995,132.712138,162.930402,231.734351,263.653452,323.581552,329.984904,294.855527,221.613933,185.545612,128.240646,119.963134,64.923341,9.83819,-20.287432,62.028051,53.529147,-99.959932,-150.322143,-83.55613,-37.618123,-65.877677,-93.174953,-46.218493,107.980722,165.10792,200.92249,193.805124,158.488835,143.787713:-26.825964,-68.911402,-78.02819,-143.336086,-184.658997,-171.45256,-96.92835,94.252294,130.491204,114.637568,145.957568,164.926752,162.256035,169.877343,187.212414,159.028986,31.87608,-32.646293,-25.111102,-63.743424,-108.301507,-90.364235,-5.788891,176.935095,172.716335,134.153688,63.479044,1.998994,-134.120079,-152.803057,-59.621166,9.040232,63.137541,32.519207,8.538756,-55.879163,-44.844038,136.659905,222.880772,202.977602,41.963357,-26.764716,-62.128301,-18.693018,156.185467,235.070703,266.089334,238.190051,158.511216,-2.24443,-103.965767,-217.291998,-210.815552,-207.645305,-243.836536,-274.526855,-236.802109,-240.0149,-248.993849,-234.204774,-178.425262,-153.488154,-151.255863,-163.931835,-181.394412,-230.359619,-274.312398,-320.433394,-278.008098,-85.039598,12.98983,130.501702,135.55776,105.462403,19.497944,-14.559236,4.639431,55.187479,178.219166,227.212376,178.478824,-17.684788,-74.074654,-39.579745,21.626816,116.258895,119.542447,72.117751,2.081275,-31.578022,-54.140291,-51.200318,-44.256238,-21.443695,83.603829,135.867913,134.492785,4.996578,-63.302206,-121.031958,-96.622705,21.607103,90.443343,152.18859,38.212376,-27.712862,-57.037441,-41.772436,-21.030974,-20.254734,-29.438998,-30.211133,-32.553443,-97.31131,-161.245741,-276.781116,-291.826297,-236.213292,-184.082024,-79.866061,-82.533127,-143.483694,-296.977462,-348.076769,-314.552595,-226.230594,-35.785509,15.051348,-4.530921,-98.659879,-114.944235,-82.442885,-67.782541,-36.558431,0.827996,77.152632,35.623796,-35.00804,-164.06608,-165.46462,-47.938381,2.587621,19.661068,2.823913,-76.206808,-124.547086,-122.483508,-139.903795,-155.663904,-148.538111,-122.287252,-8.825279,66.787191,28.071251,-116.81411,-166.55471,-141.463206,-77.496185,35.242895,71.702042,119.134279,15.161451,-93.843456,-231.817909,-217.220426,-96.400344,-31.660227,54.258142,-33.174024,-137.66908,-306.323936,-315.902907,-186.440586,-110.044131,-80.068468,-109.888609,-149.147284,-168.866252,-191.994652,-238.98523,-220.815387,-109.905536,-72.817491,-89.541556,-177.722593,-228.070069,-277.538963,-249.608481,-112.220003,-39.847137,68.90359,105.538711,119.607284,48.857331,-7.026723,-85.67379,-63.687179,85.967375,155.313784,216.958421,220.065886,194.030541,76.977141,20.906854,11.792054,51.510061,106.534235,102.513139,68.306373,16.947524,-3.424051,-15.699869,-13.522174,-12.479819,7.738888,111.138473,126.936317,103.082867,82.998988,88.602234,99.672301,86.537201,21.724749,-14.548253,-43.864341,-19.691879,-37.645287,-130.055553,-146.882543,-91.381763,-55.183105,-6.003148,-55.484063,-119.584979,-196.572054,-184.052001,-137.221866,-135.369382,-120.217489,-76.611655,12.472522,-0.793653,-22.63083,-50.383874,-63.54203,-73.129809,-56.69841,-11.874452,-75.707306,-145.042666,-248.201813,-267.417613,-242.621848,-218.794425,-215.838223,-230.279816,-248.124739,-223.883138,-214.671027,-242.076887,-241.808145,-170.798309,-133.998675,-100.909671,-176.708716,-255.422455,-392.406581,-432.072813,-429.733535,-380.73034,-226.672086,-155.662171,-123.152249,-226.413446,-273.181545,-285.955713,-241.907384,-83.817631,-7.400159,63.358474,-37.606473,-123.609814,-256.922079,-283.166035,-222.465316,-162.012675,-73.190839,-33.859707,29.793447,20.093841,4.072381,-21.248193,-24.617854,-2.260119,15.023969,21.033613,-22.433021,-51.265436,-101.947376,-99.558564,14.484213,102.034315,216.551066,220.666363,103.745625,-91.913439,-132.406199,-54.817883,-3.358018,35.055565,52.233477,71.486073,-13.390728,-70.746936,-160.848217,-189.548479,-196.94527,-164.180045,-42.584066,5.148945,-28.985998,-166.32703,-227.175046,-305.927515,-304.773445,-208.23844,-138.747558,-11.377741,4.823632,-52.200701,-174.156015,-184.540803,-89.506519,-21.863473,71.691812,95.707795,82.549013,-3.269073,-33.723134,-22.710429,31.514689,203.83477,264.146552,263.395793,199.517326,194.879774,227.431322,233.55105,258.017053,297.306386,324.791987,270.941233,134.126821,155.460304,186.668109,161.326003,145.2232,211.956386,258.816963,263.455411,218.700272,212.083068,159.250978,103.019672,39.227452,49.210048,101.823357,125.976451,129.825225,79.506363,52.217662,33.357571,67.903251,196.14181,247.233329,317.819919,354.99699,330.252361,212.747025,156.064961,129.005511,155.174338,173.829593,135.34631,-5.08137,-68.434897,-47.550178,-16.00069,-13.996077,39.897679,78.578615,79.651503,29.033571,31.24306,81.467384,125.653382,256.861148,306.568882,304.396821,262.531414:47.478486,-87.789192,-123.278531,-111.539299,-117.561423,-158.031778,-128.29268,26.584465,44.227835,-37.837085,-218.607236,-244.154583,-188.713315,-176.701529,-248.225544,-278.183689,-240.350182,-125.411481,-70.554595,-59.730833,-93.884878,-104.485536,-55.99203,130.582764,284.01131,305.28224,307.970202,301.478387,249.65716,210.536647,144.696653,142.08471,164.751904,141.778091,114.574951,16.28931,-29.260884,-31.262059,-20.27664,-58.332487,-103.291846,-108.214476,-109.278126,-122.735998,-151.530111,-128.446987,-6.022621,31.906274,-27.644524,-146.238568,-198.863614,-290.039486,-315.954659,-375.593585,-435.339245,-493.204914,-327.960458,-227.585884,-143.713407,-153.828003,-175.137297,-146.032882,-59.97408,-42.303497,1.550728,4.577998,-65.575877,-206.469684,-187.48183,13.517271,120.968803,274.016534,314.148005,283.351605,209.743842,172.595901,112.876137,140.888659,298.208557,358.872805,312.756288,87.948919,6.539609,13.389233,64.185546,159.002386,195.151029,226.384973,129.315763,40.93558,-75.646309,-87.389426,-69.567197,-39.004432,66.958631,121.414841,118.77051,-34.899626,-77.915141,-28.202338,27.424222,79.646889,37.586592,-111.011307,-154.650992,-135.734509,-110.40643,-123.100992,-113.771745,-62.877858,-0.147384,-23.861562,-44.134465,41.16668,79.051867,68.616742,11.486196,-91.328218,-92.532956,-75.281592,-128.477663,-160.557763,-230.717006,-271.311157,-328.087291,-329.150083,-265.054385,-230.320632,-236.647478,-239.125666,-191.169957,-71.405582,-38.238361,-5.341862,3.201709,-14.183917,1.866887,42.563022,77.835179,49.741271,10.173883,22.912592,17.182238,-32.052179,-153.563236,-156.818636,-114.072467,-60.960066,-70.238924,-105.815156,-112.3777,-85.181089,-62.363169,-70.431655,-98.028908,-122.628738,-181.429869,-179.470674,-122.216839,-114.080083,-160.905697,-215.508601,-242.265259,-295.381214,-295.582046,-233.307109,-209.595817,-218.576013,-200.647015,-185.695292,-234.163229,-283.687562,-299.574361,-256.479449,-186.673469,-189.13811,-218.881157,-164.667998,-107.793108,-68.782207,-97.301377,-116.672362,-74.609335,38.716972,33.734233,-6.190586,-27.337161,5.441738,83.456345,111.808626,192.830877,244.675037,231.273735,59.641808,-4.870472,22.397517,107.050325,235.043584,226.888329,156.57637,155.265711,185.667524,223.32256,220.562614,234.237281,240.875715,194.468649,163.443685,155.586851,202.10559,221.577737,234.667178,233.319994,211.238023,180.346012,100.398321,85.165857,81.568808,41.240719,31.743009,41.956819,41.301497,-7.843501,-54.793237,-112.226044,-44.275398,-4.001348,-34.09218,-87.72071,-141.7756,-144.891995,-164.67337,-162.218035,-153.222901,-142.194861,-150.46423,-177.838899,-170.809429,-136.251457,-127.297336,-93.33839,-35.620463,-27.822711,-69.723149,-67.420974,60.912799,139.922876,225.276127,226.809008,204.93503,150.382557,118.868923,23.699444,-39.725924,-166.522786,-196.366228,-181.98066,-183.511578,-187.084687,-169.563565,-153.974061,-134.872134,-144.187398,-180.272422,-188.502651,-180.793005,-205.096344,-258.841676,-354.894063,-348.144788,-272.023797,-253.204977,-271.355534,-215.094809,-161.864755,-147.693827,-165.117667,-136.642122,-128.723142,-190.339611,-187.122858,-174.132135,-228.931109,-258.627074,-198.254061,-128.664734,-85.501953,-117.403611,-90.387019,71.983846,111.620924,54.645332,1.801201,-32.169907,-14.268757,-31.261512,-132.794326,-168.269515,-158.961198,-129.008993,-82.195372,-58.729413,-17.39472,-14.254566,-23.253918,-43.182743,-46.920877,-48.989978,-52.743993,-62.798439,-75.679532,-61.113913,7.907391,24.190504,-11.842136,-57.303741,-64.94426,-6.01523,67.60877,47.470813,37.125961,160.062692,201.524352,160.131627,118.027871,100.219037,126.558449,247.822689,366.66759,340.12129,166.025179,118.412452,175.474543,225.583801,280.69334,287.374287,254.039032,190.557617,173.664601,197.708205,237.934139,320.149932,325.411717,277.639801,276.83208,297.77323,309.214835,275.957491,195.731703,178.777368,133.244222,103.819952,126.322089,212.103162,237.746511,231.35955,204.094451,167.011166,160.270052,126.928597,96.662369,80.00573,54.562271,56.80848,69.026933,80.308782,107.936837,110.091125,110.651327,160.670248,190.761096,202.544644,187.948158,173.165374,178.751205,213.183128,226.432976,220.297385,232.957922,226.084406,155.932765,119.170631,48.394577,9.221639,-41.571845,-8.63333,12.557397,-41.25179,-88.783378,-98.455997,-68.871307,-5.229155,57.660063,95.579616,181.921239,201.55001,181.56456,178.989616,198.976349,190.087448:-66.836174,-56.404775,-84.628432,-132.228726,-133.247472,-115.148361,-95.85524,-25.166152,-13.766513,-52.396265,-166.445513,-207.842901,-170.580554,-115.18517,-76.638584,-77.611351,-19.710708,33.876807,35.881827,2.622873,-7.067791,45.06357,79.941321,107.364539,131.836802,166.19194,263.60661,285.329232,222.932039,173.269261,129.918401,134.625463,108.077239,61.847519,68.789163,50.38195,13.575106,-1.904496,20.175108,19.211848,-54.491059,-99.755484,-186.522026,-210.391864,-169.934713,-118.481703,-36.592552,-11.51256,17.665339,-41.788092,-115.238797,-267.528797,-288.487639,-268.502036,-312.404893,-433.419916,-350.824164,-272.724095,-191.982503,-182.617887,-153.981965,-129.430949,-105.041439,-109.510906,-88.422049,-57.652184,-80.696324,-140.66262,-146.731389,-127.876208,-110.338044,-20.647312,64.865937,58.573331,2.182289,-17.804697,8.370846,64.635221,212.673886,266.000289,272.088124,152.718157,77.760869,-18.159482,-3.695901,157.96225,227.092868,222.569109,143.876961,88.290702,-33.542107,-61.494628,-6.511089,39.697285,54.817357,33.622318,-27.846231,-112.434633,-122.94831,-71.411834,-38.913409,-5.336039,-19.142569,-110.821039,-219.386761,-253.560385,-260.830996,-249.497791,-200.095045,-154.740141,-43.359038,12.432046,59.086891,-16.093245,-41.32643,-20.462359,-13.41447,-41.15612,-55.067972,-48.950614,-67.988507,-99.411027,-109.183059,-92.779491,-115.711501,-129.276659,-80.681935,-48.693767,-43.440688,-79.108296,-63.568926,18.585996,39.534849,64.370886,79.779755,63.090517,79.056014,134.197711,208.382064,179.334532,82.387678,50.600716,-60.701026,-143.469213,-246.062878,-194.594392,-135.983552,-100.467097,-154.173337,-283.638179,-286.217508,-175.297343,-156.662748,-201.03744,-270.066427,-289.874233,-311.816167,-297.762322,-181.025965,-89.554051,23.326548,-18.581115,-62.893125,-188.201586,-246.720625,-230.623406,-167.484915,-80.006656,-105.720253,-142.36083,-214.288677,-232.750735,-203.199738,-156.01803,-79.716101,-81.313054,-147.166203,-211.249782,-223.961722,-218.789148,-188.610715,-65.437115,-14.712752,-12.878338,-78.768636,-94.842625,-40.441031,10.6572,97.481409,132.069201,193.35457,222.003758,240.487068,205.601876,186.47088,152.775273,164.389023,244.807483,273.85367,253.068118,157.740721,119.64474,115.427293,138.852062,160.027103,126.554928,19.568642,7.787354,100.472718,172.508827,175.104754,173.601508,182.187966,176.946841,143.946638,99.896485,108.731251,78.687473,-24.173777,-58.003871,-60.277304,-27.120876,47.57096,46.363708,4.512137,64.349371,107.100304,44.240291,-55.299466,-195.926788,-208.670542,-170.50736,-80.662657,-50.619469,-49.191938,-57.929979,-71.754688,-81.08254,-104.607595,-113.100789,-98.977329,-33.822348,-10.244603,-55.705376,-93.14882,-71.171519,-15.107057,116.126105,176.900298,167.663733,96.175145,39.417933,-35.174274,-42.592741,-94.742206,-151.147728,-281.115223,-311.940371,-265.873934,-186.204611,-176.999217,-162.651118,-157.776071,-124.281573,-75.167578,-86.724127,-154.745103,-204.675109,-305.513729,-313.345685,-223.26162,-166.353882,-166.172457,-243.084505,-225.744119,-117.172955,-67.512827,-31.786459,-55.09798,-94.942867,-95.571784,-139.310855,-290.143825,-323.819705,-206.485367,-101.146136,-5.689294,-23.446087,-28.28459,43.188412,75.880357,96.395317,68.816975,-56.990782,-110.64026,-135.440968,-156.250375,-178.643501,-174.842739,-158.180109,-125.455483,-82.050567,32.300358,64.02193,26.759354,-93.25385,-134.420631,-135.487276,-121.436162,-157.35426,-191.94146,-159.705674,-31.852088,25.449581,79.998072,57.591549,-16.528324,-34.894007,-60.97639,-77.241937,-55.752605,46.382521,73.472134,56.984562,55.247563,104.965578,141.498979,217.279712,247.502244,237.563707,192.742493,170.089201,171.072984,207.418961,320.549542,355.120656,279.844008,125.24247,101.193392,151.847649,188.291404,207.229698,201.85202,245.836986,271.963311,259.908268,227.974784,188.720882,76.998853,40.73287,20.972993,19.438025,18.159915,46.515978,77.786493,112.276385,95.745348,48.985339,40.272203,50.058409,90.321924,120.557113,191.55725,206.558738,169.713732,139.472847,108.196162,116.257842,156.015262,203.102426,205.726774,134.876823,101.728102,109.932908,146.096821,256.385571,275.107947,243.759361,225.971501,224.375596,168.486933,146.236183,135.310533,112.29751,71.980357,125.369766,114.099072,-32.103909,-84.717754,-67.976067,-47.361439,-26.796131,40.884259,70.284145,85.12723,86.425143,113.710646,146.043471,190.928039,177.784484:53.437976,-36.476129,-51.818804,-96.620025,-150.661226,-185.302156,-129.283008,23.90071,41.682409,-7.629466,-82.072827,-70.669584,19.585635,55.679732,-8.825885,-94.658679,-196.765782,-111.663349,-21.199336,61.574081,18.854172,-36.327317,4.069515,139.498049,211.759113,214.614834,191.987783,163.471174,98.078298,85.825282,106.133459,128.032714,147.715507,41.38052,-27.049621,-42.256549,8.409521,90.157734,72.973385,-16.825958,-52.94078,-73.850496,-114.858334,-105.837189,-19.199624,32.321282,62.662251,37.806346,-16.228023,-96.142554,-165.538007,-324.339718,-370.315472,-333.317161,-310.364878,-327.446254,-248.287696,-186.561741,-152.994391,-181.801223,-262.188208,-273.914826,-190.114943,-130.619032,-88.698416,-158.176151,-196.292145,-191.206046,-147.89567,-15.302886,56.605679,185.103911,245.349279,218.272272,141.495774,124.67892,74.569366,49.720163,106.486333,168.635791,188.436617,33.05568,-43.319313,-84.457533,-65.360352,-17.399726,9.653568,38.299939,-48.443797,-119.160173,-182.551713,-156.462278,-76.756468,-48.59822,35.734181,94.762111,107.149372,-23.834501,-51.131874,7.596937,53.949503,101.943641,91.425663,58.482487,49.142772,45.077375,56.156756,52.288339,-42.448504,-85.081407,-23.107302,38.374145,81.910546,37.9942,-4.478971,-151.188445,-228.894291,-277.897078,-251.326383,-168.527881,-124.144257,-125.68445,-188.881737,-255.43087,-351.485014,-331.994855,-196.63863,-149.788902,-184.71186,-208.694712,-154.870598,-22.212394,9.586634,21.301331,3.833559,-79.469041,-100.527097,-79.744595,-108.159465,-149.290049,-122.71294,-71.183551,-72.142936,-116.876997,-154.860708,-117.85912,-107.814268,-108.089327,-102.670644,-78.214812,-53.604662,54.849695,95.848896,51.050569,-59.153645,-110.769994,-163.865715,-131.66621,-22.021297,17.582125,28.428456,-76.288592,-148.919543,-283.412118,-302.324161,-170.858108,-101.082321,-130.859764,-184.629159,-176.105332,-191.964607,-220.906291,-199.660828,-156.230086,-135.109035,-146.172684,-147.593273,-151.290276,-146.330441,-114.755285,-89.963404,-24.254307,-1.691359,0.633814,-37.965127,-69.558202,-96.997663,-62.433025,45.87296,88.494848,130.592192,118.73289,43.863878,11.221575,17.561315,15.472781,15.15221,75.113683,129.277107,201.6284,190.4971,168.153589,143.005396,158.987289,223.39005,233.201972,174.419644,150.708814,179.598297,216.692923,227.451637,254.153575,254.253564,166.556746,99.803956,73.485026,154.816437,146.27207,41.361874,30.839867,144.886803,185.469561,97.986878,15.399701,-87.172263,-118.200723,-112.051925,-85.817603,-97.346382,-109.458365,-59.592184,67.023873,-22.627475,-114.338577,-188.920768,-162.791857,-84.090303,-93.451707,-172.260458,-143.441802,5.209021,7.132901,-8.745586,40.777176,93.899432,188.414805,203.895397,173.508073,117.450279,103.398237,84.599922,44.058022,-69.981279,-114.026426,-200.732458,-237.967156,-263.000555,-197.738401,-127.330953,-90.854621,-157.869743,-259.670538,-243.339795,-169.056214,-155.891982,-162.506538,-230.960623,-298.120551,-374.235511,-362.518042,-278.914711,-213.945547,-123.636432,-191.163784,-235.227214,-254.955885,-233.216694,-116.164344,-56.203778,-55.546952,-136.685508,-169.835593,-248.35949,-268.37389,-154.231698,-59.759095,7.382221,-18.922811,-101.623697,-67.978973,17.56855,107.238885,76.467335,27.701402,31.087065,2.995567,-48.19708,-50.587618,-41.263473,-41.26844,5.729492,58.14965,149.988138,153.57623,9.368698,-137.983647,-119.965405,-30.27344,-21.684427,-45.651983,-58.440742,-56.164958,2.939363,32.688146,33.376079,-2.411569,-43.588211,-31.427102,-43.981621,-65.226804,-69.06819,-77.775322,-86.506623,-85.919187,-89.625835,-118.820179,-120.760252,-17.256136,110.447538,97.391368,-23.086224,-61.82458,-40.565921,-2.411855,93.636127,159.011593,207.401425,96.077673,71.948764,113.677667,140.953557,187.806797,214.633688,273.868597,262.405717,242.085339,248.348052,239.651267,147.474635,109.733728,104.825227,111.086641,138.903654,206.558924,233.634012,234.621292,218.393972,193.575561,177.22018,139.072754,139.218877,133.585574,92.596958,64.642901,-3.48504,-7.169431,99.337043,135.227914,65.8556,93.484411,172.1328,232.325714,208.08391,200.670306,222.318029,294.782013,340.041675,311.366519,204.39509,162.151189,150.157218,161.455955,86.387611,7.72118,-65.25791,-19.669177,-0.949873,14.064999,30.86106,63.930465,40.353982,-66.735732,-65.502744,-5.655356,129.634355,172.827763,242.422474,269.37185,240.332269,184.303124:forward
427.184626,379.153673,330.194749,296.695819,318.026052,354.611524,357.369568,327.199608,235.479934,184.996572,74.525519,25.122192,40.861356,111.229445,224.976121,220.891277,216.440567,312.158046,320.79176,218.356877,170.221346,199.822812,258.304898,291.761676,146.239586,53.688883,-54.830655,-46.228724,49.193676,99.947344,147.242272,112.320622,-55.826073,-145.955017,-135.733667,-41.501801,38.867237,200.228464,242.138382,235.065246,205.690243,180.272563,90.891918,67.475954,66.108366,55.569682,37.800511,31.259448,-60.955622,-202.251467,-214.981077,-113.717098,-84.889023,-210.145331,-304.802592,-353.390464,-249.173508,-222.790831,-262.849811,-256.567589,-119.133703,-42.245539,32.035716,24.464271,-37.553497,-141.43475,-200.864059,-211.440398,-176.430042,-160.71724,-170.662834,-182.737418,-159.367384,-124.237771,-100.029245,-125.298601,-156.033415,-138.482224,-82.356768,-79.183359,-102.59827,-82.253058,-73.019383,-44.538861,-19.886017,22.434102,44.493187,69.53467,55.63834,56.970301,84.875894,89.848603,61.771875,51.585125,40.882954,20.880321,-28.319354,-82.786874,-126.313551,-168.080848,-140.775357,-29.222407,24.372152,41.170497,-54.775555,-115.44608,-246.942914,-278.286442,-177.742356,-95.87529,-48.088439,-58.256002,-17.346568,-35.97863,-110.030402,-231.206696,-237.099825,-174.925785,-131.090206,-82.092167,-80.19571,-84.033719,-124.058565,-149.00211,-146.586699,-105.846492,26.371431,86.692815,152.121221,106.937994,32.09811,-143.105432,-207.568267,-233.758199,-180.93274,-45.315873,-34.894107,-66.009764,-82.900281,-42.310839,109.99218,209.786939,377.474583,383.529288,265.618892,196.309841,183.061402,95.342323,36.460253,44.79698,113.507831,186.205648,110.900864,54.994177,-52.197454,-89.801304,-123.72075,-117.942337,-45.337658,-4.275434,-24.440289,-158.64168,-227.211502,-269.409388,-232.990665,-110.960195,-48.578123,49.393166,81.820436,50.158532,-54.309766,-71.735427,-42.19688,-16.999569,80.370526,133.583479,186.166241,176.783813,128.857161,-21.266874,-76.678341,-71.407279,-22.680591,32.565245,35.415645,77.161698,212.83112,269.908388,298.268407,269.740963,278.289084,336.008212,427.342897,413.562125,371.754639,294.189654,277.755682,275.149222,287.923367,297.297681,193.344732,105.819118,-20.99051,-19.00949,71.550629,101.547618,65.100857,6.121408,-137.207801,-256.164569,-305.45287,-338.164043,-308.63655,-248.321921,-245.158753,-241.485174,-229.796077,-252.941135,-319.422873,-305.107729,-170.390839,-97.592197,-3.486603,13.316492,-11.676286,-104.061966,-168.452814,-221.908382,-205.392281,-186.868312,-174.717996,-130.05192,-152.639201,-199.605409,-325.020227,-358.644965,-278.869422,-184.411981,4.806988,74.022076,132.116209,76.380293,38.982178,32.815334,36.810917,-34.297974,-69.077861,-5.025509,182.823278,225.479023,89.052485,-0.863136,-37.943728,-22.463378,25.199185,80.263361,174.066267,104.522373,31.439354,-91.1095,-134.027512,-157.996083,-121.286228,-48.642904,-85.542008,-109.759775,-149.732328,-172.717611,-157.03324,-95.028627,42.194754,54.874276,-1.107585,-38.076798,-65.302842,-107.421001,-112.238033,-155.407864,-173.917277,-131.357773,-60.185618,-39.861404,-65.708731,-104.570875,-148.70955,-135.719072,-82.171795,-68.395713,-69.876621,-71.801004,-88.969374,-132.446462,-121.415839,-24.35429,45.005726,205.953212,296.77129,276.606971,213.010037,229.139745,290.846695,293.023713,291.345921,305.497814,366.692615,370.701216,279.741582,15.133022,-54.41499,15.806453,81.808047,76.270901,-9.098237,-24.994785,-79.843747,-132.633709,-195.242689,-184.198895,-154.144782,-187.850142,-304.709554,-302.045917,-283.617683,-297.375788,-295.410114,-219.712434,-183.439302,-215.931175,-323.160434,-348.113247,-391.387827,-444.000286,-510.448676,-483.126736,-355.780656,-281.168103,-140.260218,-110.985187,-135.231943,-163.32398,-172.916574,-197.367344,-176.976151,-58.293661,32.172029,15.024428,-124.385191,-171.31975,-122.56348,-62.871021,-5.102238,-19.305508,-32.610985,-4.906516,-23.311217,-67.230899,-59.069765,-66.399951,-106.780207,-172.397009,-125.135739,-91.397635,-61.962962,-41.369572,-1.789732,-15.283378,-56.813093,-61.392765,-66.157747,-106.379986,-144.239735,-185.009972,-175.484253,-145.340763,-131.887689,-134.376173,-210.114807,-236.166232,-260.920195,-282.065711,-315.570304,-314.365758,-251.670855,-196.430182,-94.175599,-58.09796,-78.337936,-95.682336,-70.323729,-9.081667,23.773896,90.018453,120.055583,105.555312,-23.328313,-109.068644,-201.39003,-203.864645,-174.797799,-161.984558:282.894435,229.152206,214.566066,276.728764,323.693908,311.595309,278.072088,257.543507,236.318668,199.216633,99.437062,72.899497,130.107865,180.276916,217.212037,209.966617,233.816575,286.651718,275.584309,216.474985,201.802613,220.634504,244.808458,241.816393,143.024045,87.046282,11.183197,-2.440945,5.817949,18.679495,16.699649,-13.487105,-94.207468,-188.276936,-236.462064,-215.436506,-124.765389,89.440616,152.734719,168.25995,103.930671,52.101305,-59.969089,-74.487672,-3.256124,29.680987,1.499115,-45.223419,-145.390874,-225.397629,-228.72432,-127.236628,-63.314106,-45.136588,-92.537572,-176.266694,-184.027477,-190.000296,-165.277989,-95.252554,71.518527,109.058941,99.446322,85.694981,48.636802,-55.069001,-101.572613,-82.764748,-52.636736,-77.329097,-111.556503,-113.730908,-43.409992,-40.043097,-121.248495,-152.627329,-102.412946,-39.853427,30.498702,26.788416,18.478013,-37.379215,-78.276818,-37.237781,37.62556,124.189588,106.328653,53.914819,59.34094,32.782619,-50.302854,-34.347256,80.438421,112.177406,68.65139,10.241381,-80.416916,-109.583465,-130.61325,-126.646715,-78.473427,12.217028,5.766686,-70.100256,-84.895129,-88.241102,-143.409443,-176.308461,-182.533463,-138.645344,22.947634,95.111057,77.219151,-155.122682,-256.839202,-285.153968,-262.941995,-263.787535,-250.648052,-146.107406,-85.37321,-121.950101,-257.904537,-291.282633,-245.477856,-182.579756,-22.21235,48.18567,126.057827,78.637661,12.657905,-87.915524,-93.271923,-68.576905,-56.871145,-34.697894,-15.382252,-11.167007,-13.668923,11.941782,140.905296,207.964579,245.793783,203.856066,93.786903,57.340258,43.418659,-5.811273,-10.92453,61.285823,105.785663,97.3091,-20.09155,-74.498526,-138.934871,-145.910506,-117.374895,-91.260573,-31.764417,-15.029068,-59.82104,-178.751146,-217.150389,-204.495314,-165.58693,-51.6336,0.912798,61.68986,53.62054,8.907913,-100.101,-118.550522,-71.000474,-12.806025,124.065254,153.683263,117.408516,20.168092,-39.373833,-92.612104,-71.510752,20.214249,54.240534,16.894322,10.943604,77.847095,170.290896,153.398242,114.789123,146.755169,246.416128,237.732654,149.31295,192.176737,240.463375,282.604198,259.793084,173.061774,165.627997,200.324645,83.519621,-9.156625,-95.637544,-86.396835,-44.240463,-18.519305,27.428382,5.802171,-174.784254,-377.230605,-416.419083,-383.139975,-351.126273,-346.055359,-376.093073,-408.654783,-386.203837,-390.264382,-380.193181,-334.997434,-215.012256,-167.166975,-81.740834,-43.278004,-68.126061,-231.463416,-284.655328,-261.145535,-222.142685,-150.403693,-111.747276,-83.119893,-182.920335,-225.448048,-205.243726,-181.782729,-167.428971,-132.141684,17.090922,83.246312,181.253292,151.991291,61.180636,-104.817743,-126.541095,-56.167838,9.057838,127.747318,210.668684,204.645994,38.23239,-36.915531,4.813624,88.489888,243.501771,273.447049,204.588906,2.511057,-91.113793,-124.137203,-92.951158,-54.250119,-52.707815,-79.636651,-68.852288,-50.723985,-58.256059,-76.936556,-63.198599,-9.443781,124.14988,146.753112,85.204104,-3.633306,-21.471457,-5.890796,-20.723357,-102.11135,-118.832985,-84.324839,-8.500587,37.285539,73.593369,52.382238,22.405095,40.314717,80.271961,84.110573,94.07713,31.35387,-21.850395,-37.299162,-6.59113,72.244956,133.304906,266.919897,272.656327,214.262225,110.359004,131.753921,282.21663,335.601833,329.635198,313.576297,361.541358,351.859747,270.714698,103.496185,72.206934,113.634673,138.444569,80.15073,-27.989025,-61.885803,-139.577987,-179.351225,-169.059821,-128.162915,-100.000248,-132.917895,-205.148138,-217.237512,-207.93514,-148.365178,-98.0684,-31.502344,-38.226338,-101.850522,-163.891167,-183.77129,-243.449529,-293.602735,-368.892003,-352.295574,-221.763905,-159.575081,-98.410111,-88.218197,-96.971215,-95.349868,-76.866862,-16.013952,11.406197,7.85653,-63.027076,-105.369714,-167.633461,-166.921301,-65.314003,5.473288,53.515497,35.45508,26.244162,22.214169,-5.761608,-56.937789,-63.733381,-74.244312,-93.980208,-155.752277,-164.593046,-149.892317,-121.758907,-86.411325,35.233374,72.506657,33.709318,-19.749542,-124.679134,-196.907965,-240.619839,-303.305577,-289.507587,-173.206879,-99.187291,-58.565958,-153.932078,-196.518594,-286.49417,-329.186714,-323.882536,-278.792807,-180.282389,-147.529987,-136.441771,-155.273951,-163.393441,-141.984304,-90.692673,42.740367,82.20472,60.281224,-24.074826,-71.349712,-192.18736,-247.785925,-290.007988,-267.167199,-199.257292,-212.725033:137.645854,214.838335,267.353923,279.845053,243.205406,149.652251,124.781646,124.873379,119.44335,97.499902,67.814909,57.235321,5.104057,-5.646079,69.210267,132.253075,226.983558,236.183337,213.553225,190.735633,226.060054,362.689098,399.135457,308.810263,121.314744,55.027901,39.341779,51.62049,-17.549361,-78.862484,-158.763038,-170.785491,-188.037535,-237.932878,-240.759743,-183.10097,-146.422125,-39.304918,27.986231,93.027312,57.995637,32.322189,49.652036,89.682001,100.479329,61.422473,6.029763,5.041479,-41.300609,-174.15261,-186.462035,-34.139488,46.8051,66.805696,27.221655,-36.117768,-85.206818,-122.396393,-67.031513,56.18918,260.159813,261.264577,149.674123,115.447529,89.386596,-19.924147,-57.0329,2.417273,54.305137,70.830847,26.347648,-56.942896,-41.336072,-45.042217,-56.902654,-13.322677,156.775588,220.867594,195.632576,137.759961,71.740393,71.787039,77.803184,128.542002,166.253361,200.355241,190.579479,138.886204,83.664624,60.650845,64.13187,94.456764,121.184588,118.534279,122.398469,108.367078,32.847634,-52.813334,-80.181002,-36.321556,40.810323,162.852982,149.692275,15.409926,-101.306981,-120.091284,-105.117595,-93.500774,-53.707826,-18.225071,32.886966,40.039198,35.784597,-87.703103,-185.269032,-260.602077,-248.095514,-211.137269,-169.232631,-85.844931,-141.746266,-203.293094,-235.360692,-185.667807,-74.420521,-39.118109,51.049221,93.941795,86.118591,-34.522381,-109.015807,-203.91379,-210.090692,-163.416589,-115.065219,-0.270371,36.840666,16.747514,-35.223551,-12.969574,165.204601,257.028975,258.564291,164.545605,-7.240877,-3.792805,33.924523,97.330529,110.95741,149.796005,175.479541,138.583833,-24.356111,-100.88281,-138.800895,-119.160769,-102.598547,-94.004923,-52.330278,-38.817036,-52.996907,-143.261995,-181.540582,-149.334698,-88.231168,42.35609,75.943471,63.615017,34.368697,21.595462,-53.240107,-103.128301,-116.388381,-51.804489,105.056293,120.600911,22.149551,-89.478662,-112.059736,-110.926614,-111.781123,-96.00819,-70.12453,-36.358776,-49.824956,-60.287875,-80.6886,-82.030571,-44.557756,-7.894986,77.552845,85.868919,17.607046,39.011452,81.511416,82.883535,49.77999,30.661915,35.685312,-4.835748,-76.277398,-105.10655,-118.437857,-90.557465,-42.878576,-67.70205,-155.760523,-161.967482,-157.35387,-299.681729,-365.78134,-359.585086,-341.601324,-399.199745,-445.758922,-465.811027,-438.01255,-445.638662,-444.553391,-390.536277,-242.701577,-206.507483,-152.843081,-102.515037,-99.226083,-270.71836,-323.766204,-310.812302,-288.727062,-248.136823,-222.010015,-172.48505,-185.699495,-203.135677,-164.974455,-122.403023,-91.059026,-83.367573,-18.550896,29.42577,111.207383,48.129053,-24.943739,-75.557143,-40.559122,59.367852,94.370812,119.95553,133.533313,133.717052,106.771274,101.40173,127.047843,136.622764,138.550165,135.433198,84.7122,-40.696908,-91.749192,-103.193642,-82.372136,-61.607443,-70.47339,-83.268842,-75.451604,-97.773546,-139.198963,-109.824437,25.428572,92.735298,178.176321,180.012554,111.741153,-3.245734,-49.45662,-24.387323,24.9005,48.11254,8.991201,-21.253874,104.598924,144.408541,122.645122,122.361623,167.16467,182.243972,222.219151,234.494853,167.952416,52.942457,18.387583,45.347421,85.904481,112.445163,109.287506,184.587641,248.715044,198.947448,100.774284,137.896415,303.877426,346.578703,289.221915,245.741273,248.292785,179.016812,64.183485,-121.803747,-106.0752,79.106945,136.82019,63.708698,-31.081083,-51.110158,-109.103849,-120.129555,-61.609019,-33.533155,-33.985708,-45.593797,-80.646702,-137.408967,-141.92824,-70.590347,-25.574091,-1.941344,-35.550948,-116.086098,-112.48024,-117.14431,-162.491125,-168.28109,-149.255107,-138.694493,-98.865862,-77.525552,-29.85992,11.686005,-13.296237,-87.165132,-65.151264,103.64161,169.346318,106.50722,-67.26712,-115.152046,-84.936737,-35.211569,25.417864,29.176172,-8.851726,-43.244783,-59.178271,-47.14034,-58.510586,-68.007837,-83.185277,-136.69204,-130.595931,-87.161241,-139.17279,-199.454057,-271.659764,-229.859924,-48.324549,7.503016,-23.353644,-92.629488,-244.112622,-282.569955,-273.191157,-254.543043,-254.206656,-262.472389,-243.488706,-145.321857,-36.463105,-31.746877,-172.566091,-247.632298,-277.131174,-255.708158,-191.682783,-152.802012,-89.989617,-69.364108,-69.899279,-56.207849,-42.161621,18.326125,65.732254,62.789384,-99.150545,-165.78802,-197.670193,-195.835701,-238.362318,-249.599406,-210.557242,-213.471544:340.604849,332.977831,319.21022,312.683764,313.566411,297.191864,304.433142,331.192978,269.611301,216.324414,137.012383,124.425002,148.040637,181.975665,256.446807,265.394715,256.309988,304.55735,319.516223,265.422415,216.42619,205.227278,258.76639,323.616347,192.492977,91.767944,-18.146415,0.577349,82.971912,85.234893,-24.081897,-95.374218,-184.80135,-203.172018,-178.796665,-66.57943,1.018924,115.178111,155.405435,211.173589,196.92568,135.509137,-5.359024,-12.121132,96.882988,134.93678,83.915413,27.77771,-61.902841,-130.914477,-136.677875,-30.209962,29.064328,30.801706,-8.068888,-59.069676,-6.507251,17.304942,-5.121385,-8.453365,66.798388,131.024761,244.541669,261.725407,184.593364,-24.563305,-121.798199,-132.07215,-68.510403,0.84993,-19.674736,-99.500444,-68.497925,-18.242038,12.854829,0.531177,13.024271,42.095076,107.851448,117.703647,76.315239,52.211969,56.937831,106.925546,142.300586,186.461222,200.130663,198.313735,162.949691,154.547505,174.070515,207.506678,290.593138,308.926328,247.327894,191.364869,120.537411,45.55303,-7.245178,-38.707472,-2.137456,73.545797,61.253869,-46.258455,-116.689369,-135.711965,-183.974977,-176.605664,-29.966251,65.432927,166.152211,157.703725,68.506765,-84.697627,-165.965363,-228.37883,-209.54142,-140.763241,-105.423055,-64.393979,-97.075417,-138.832517,-222.475294,-231.951186,-166.180166,-119.235117,-36.351615,-7.603793,23.042467,15.75003,-44.453787,-239.686857,-318.930664,-346.231694,-278.381446,-72.217147,-3.634169,-44.03633,-117.463815,-86.127072,100.563241,196.267134,275.381265,254.700661,155.886411,80.579517,79.490876,103.817535,96.93835,97.8988,124.600017,133.778625,39.301357,-11.372253,-91.771723,-129.558631,-196.432045,-201.883768,-124.745347,-85.813968,-113.230094,-212.835202,-241.584103,-218.391785,-188.768688,-139.952707,-106.916454,-29.340451,-36.17291,-86.40434,-192.328895,-202.672875,-187.122089,-181.836877,-110.397859,-57.058126,-1.261635,-41.703396,-89.676012,-159.38995,-176.954896,-189.14161,-160.864694,-77.230407,-42.661102,-14.379475,77.239793,105.475497,78.127997,60.076503,107.496496,141.522346,161.722442,187.724566,208.533387,217.913945,182.061258,79.292742,74.570696,124.255415,44.851857,-23.347198,-66.824217,-40.53232,9.830499,7.844242,-11.135706,-15.822657,-87.786321,-215.313068,-247.120639,-260.017126,-273.944688,-304.845127,-301.909107,-270.318549,-253.425233,-271.073451,-314.357817,-291.546288,-166.538612,-97.217837,49.850354,100.567128,52.759051,-118.382977,-191.389114,-233.72444,-207.81477,-137.308731,-87.617767,24.308162,-25.840345,-108.996265,-223.002757,-217.166874,-120.347807,-53.24555,78.859953,118.435182,117.184128,39.623998,-1.665874,-19.88566,-9.995854,1.429851,20.438795,78.927604,124.922595,134.457494,88.529758,62.426367,49.656849,52.979745,109.06604,150.139443,142.002436,22.509588,-31.571364,-75.605465,-75.444804,-49.479613,-20.754306,-1.788121,-49.365996,-71.687083,-135.871993,-162.780676,-87.199926,3.993195,95.936252,65.389055,0.462724,30.433512,42.13786,16.483763,-20.972578,-108.629626,-111.627962,13.473419,129.087244,119.924662,21.070083,-0.511662,52.427473,76.366004,75.194775,83.09615,121.416538,58.334038,-4.659897,-46.585377,-5.434501,121.389796,172.804285,233.874725,236.334084,196.589111,110.364323,114.435594,176.570781,198.05015,248.728343,280.301592,285.699966,215.197971,141.581498,-35.802877,-60.471222,59.930484,119.230154,91.142641,47.203827,37.355061,-91.605699,-170.345295,-174.350543,-114.032335,-44.204947,-77.069571,-178.315029,-184.621072,-172.362785,-163.724053,-158.908373,-130.619768,-117.787155,-128.673117,-190.321068,-245.113274,-370.294818,-400.524743,-380.235866,-343.070912,-211.61208,-130.327696,13.061431,71.130752,40.30975,-69.796211,-94.739791,-44.65255,8.22614,69.128993,70.341205,82.752209,86.890163,56.597259,-28.798975,-47.922076,-18.024321,-7.841509,-63.369341,-101.096843,-83.89227,-50.085134,-56.993301,-111.219392,-128.2985,-84.171613,-38.684343,-60.756003,-142.064958,-148.087644,-87.064546,-61.598608,-44.613278,-57.378432,-140.177478,-234.496803,-270.12786,-297.741258,-277.998698,-174.165553,-113.078128,-64.978099,-138.639432,-196.012981,-318.776995,-369.1972,-424.381468,-418.859457,-305.204613,-221.805725,-152.442812,-238.204283,-263.674037,-135.439414,-21.348483,83.232016,74.837896,54.132002,32.25244,-2.563705,-126.716964,-189.236535,-256.323509,-244.256191,-178.244995,-166.107555:162.112131,129.472442,127.274527,147.102867,162.025757,196.511822,205.711236,140.579652,49.140722,23.241861,-21.202059,-34.251234,12.725932,85.386669,223.447612,224.756419,115.565607,71.317754,95.618635,150.485129,174.469933,262.496687,310.085243,268.045013,36.713459,-73.32098,-130.628833,-87.23017,-37.482454,-52.590701,-89.20047,-109.608578,-209.180762,-313.162059,-299.172916,-143.71842,-62.974091,12.925891,23.572544,60.93147,129.393657,139.748397,113.29314,121.168566,211.609447,251.50578,199.486371,122.844642,-1.828401,-110.233285,-126.693444,15.066574,105.815929,151.438211,121.976307,77.209864,53.021685,23.892254,10.441101,69.739804,266.323104,333.301218,337.08869,302.302603,188.5003,11.77961,-39.890545,-4.571255,38.449272,94.294506,93.053435,14.475601,-69.231628,-77.32488,-0.312012,61.32518,143.055362,166.510173,210.414156,205.394182,112.822365,26.199029,16.155141,97.063917,176.901804,287.71039,275.424021,199.426127,228.013126,243.307675,187.750396,154.228979,161.862588,196.063287,239.090777,222.303205,139.649176,34.813438,-16.392783,-31.232315,11.117564,105.15113,120.596743,58.09386,-56.265692,-98.512153,-159.909549,-175.091286,-95.202019,9.801335,207.840979,217.05531,48.86826,-142.819747,-199.370379,-215.248559,-179.745057,-66.803281,-11.383745,23.455274,-53.468459,-103.4659,-152.382746,-128.370513,-51.129733,-27.951097,-12.009557,-35.946423,-121.920222,-180.771252,-226.122672,-330.359367,-348.68587,-290.474102,-238.502328,-148.950788,-101.866271,-103.353577,-136.262211,-113.921557,92.316839,224.758593,325.128345,264.291536,73.324866,-37.950562,-47.217623,2.325904,46.902938,200.36081,288.333689,319.10509,109.618494,-27.48657,-179.292336,-175.334837,-173.713184,-196.881022,-168.41283,-124.515275,-84.602095,-148.51514,-202.496467,-212.278331,-136.37104,55.164883,98.995067,54.704589,-29.719193,-88.876277,-258.954047,-306.364078,-239.03371,-143.837904,50.78242,77.407608,-25.312731,-126.502043,-151.684534,-201.943227,-221.415512,-194.967867,-162.660907,-150.221574,-160.707647,-149.710765,-99.990178,-68.705735,-11.242822,18.548174,54.236144,46.892434,6.201479,-16.660934,-19.653986,-28.880028,-22.738249,51.917132,79.606386,-9.030891,-141.392694,-161.992777,-139.031999,-127.574873,-157.37856,-167.013106,-102.577831,-82.417171,-182.998418,-310.70031,-303.185653,-216.260812,-227.161441,-316.015013,-310.835118,-236.757393,-254.165331,-297.585143,-346.200589,-312.396563,-162.379148,-96.133403,-27.3372,-16.358576,-45.586232,-170.627454,-247.91744,-277.058307,-218.219223,-101.875102,-67.98062,-8.281685,-44.882667,-109.767649,-191.530156,-180.117835,-96.167825,-39.29698,22.317598,5.779637,-32.8751,-55.139995,-70.90241,-23.346177,38.463355,131.827061,158.635371,187.418893,156.726852,125.240003,73.876391,71.251134,97.929184,113.674903,145.195869,151.590578,126.203174,36.238568,-22.952505,-66.172669,-28.468411,91.000046,126.858592,88.602019,-1.635962,-35.610432,-83.045794,-69.52153,77.084291,184.509166,316.954484,286.224479,104.90948,-32.349607,-51.928349,15.822776,52.866936,80.077257,102.212385,139.518095,103.544285,71.060569,36.128804,58.144994,146.370393,174.578003,181.85339,178.874353,137.179457,-17.73529,-95.257061,-95.952205,-24.214277,126.652502,167.409858,175.074679,115.489812,50.311168,-29.244575,21.735328,181.456008,205.797905,178.396721,180.453522,209.001141,116.309356,31.54301,-59.360613,-50.740991,34.492511,89.574986,127.145647,53.666768,6.648316,-65.582631,-82.043721,-60.729306,-22.207606,43.521414,27.278019,-91.67791,-152.842904,-127.69635,-23.67628,6.782517,-16.840069,-44.723372,-63.708802,-26.772918,-33.019085,-107.686932,-130.981277,-121.628184,-84.93388,45.853969,92.994109,111.366016,80.791206,44.7291,-9.027624,-7.877767,51.210088,97.04362,138.847301,104.835261,85.837054,75.435088,84.28367,69.069459,38.117591,-7.128598,-21.037029,-68.861543,-126.809501,-141.658659,-104.527526,-68.963121,-19.741603,-24.548999,-98.040692,-170.29689,-200.835356,-263.955009,-260.274812,-121.939156,-47.638279,-41.797589,-105.550809,-270.723438,-341.005862,-316.241546,-238.145837,-235.026359,-221.538807,-154.831916,-19.832326,-92.790188,-191.158273,-340.032016,-339.122149,-250.877033,-215.002703,-175.848348,-159.73583,-142.37366,-202.719903,-230.755104,-159.475862,-75.267486,52.847298,68.136366,3.960954,-105.949267,-157.762864,-257.787602,-296.792706,-339.819957,-329.737121,-222.915336,-157.690335:460.31718,305.803847,265.678449,348.402698,404.351935,406.814332,389.961464,345.47767,236.322544,195.10067,140.134806,116.710415,121.029443,147.966642,207.516313,222.465671,271.823985,368.206099,355.683068,225.530909,195.991468,275.841996,340.235385,370.361673,245.038528,164.639239,72.655475,86.335654,143.022264,146.851155,135.393469,114.928151,-17.651124,-162.221963,-175.567517,-59.484236,42.347977,194.827892,196.996088,97.161468,83.07418,102.890691,55.242886,20.392371,72.46984,142.837747,201.354216,158.219619,35.781428,0.358825,-2.180076,-49.735049,-94.79776,-186.126614,-205.999964,-150.210531,-27.675508,2.559866,-72.633902,-133.344351,-123.889148,-43.688954,111.749164,123.641662,-2.344042,-210.303426,-279.749083,-268.139049,-228.771149,-209.652644,-222.634373,-237.29859,-183.902096,-143.006878,-112.432864,-116.936013,-97.881663,-74.226504,-66.420586,-87.680734,-80.971298,-22.894177,-31.083915,-64.228806,-40.633868,55.072859,71.413018,16.535497,30.753984,64.916366,86.183987,86.626306,90.638271,81.020071,76.006424,99.030758,111.605907,-6.295518,-81.202496,-131.461094,-87.579822,34.340624,58.329966,17.763934,15.705236,11.184576,-128.524577,-188.620871,-96.48095,2.65606,81.633923,55.557888,-3.922668,-19.290486,-41.289614,-118.867387,-135.061944,-109.984683,-102.324477,-106.769088,-85.809332,-104.993959,-208.073282,-229.32822,-181.996753,-143.938063,-64.946372,-37.597074,-43.898846,-151.276302,-224.515541,-325.402588,-353.766555,-354.419829,-294.98814,-102.283545,9.555324,3.846108,-85.235453,-103.530957,32.009482,151.720783,289.939266,269.975787,180.554616,124.678979,89.173701,45.663558,58.052174,158.520347,228.574235,296.043731,236.94887,176.178586,-2.922257,-89.038098,-139.011245,-92.294531,35.100944,38.666835,-96.209225,-193.389926,-197.83639,-145.664508,-124.268103,-163.339196,-184.062687,-99.198608,50.403781,54.844292,-26.885664,-37.580973,-34.617534,-39.245938,52.578297,133.522073,179.106499,13.811589,-88.089499,-160.970413,-140.557829,-121.4046,-124.153866,-107.190798,-42.436268,7.710518,102.880871,137.124978,148.328699,123.299807,104.621707,130.514897,207.241311,260.488009,250.86023,188.203523,169.570049,170.043157,173.831811,152.344971,117.545909,97.909293,60.20005,75.121405,141.386294,149.131929,100.763997,49.677336,-76.424204,-108.227659,-81.194177,-72.445684,-115.772612,-168.822618,-131.919702,-41.876966,-80.567426,-115.067376,-133.306622,-122.721355,-98.051481,-57.621114,108.457768,167.887985,127.66269,-18.996866,-108.308375,-217.54681,-202.155748,-113.787885,-69.95312,-25.800125,-76.732489,-112.74024,-188.944641,-237.086919,-260.779806,-187.216746,42.024253,98.3695,61.157959,68.694287,113.423101,152.18905,106.989732,-31.818216,-52.087232,16.930705,81.896049,100.063259,88.046226,59.400827,-3.929769,-1.392074,130.964928,203.753723,216.690957,108.366269,43.61144,-64.362757,-96.977994,-104.293751,-65.820206,70.783736,92.29812,5.300786,-213.005538,-236.647131,-85.325048,3.299064,58.697745,29.933164,-28.54229,-14.67514,-19.223816,-33.536744,-20.454,-35.522594,-77.428582,-106.400875,23.953677,72.151311,-35.215227,-132.044154,-193.739629,-167.42204,-147.821357,-168.577323,-165.429968,-97.673653,-104.90238,-186.415589,-196.058902,-86.408894,7.503973,159.955988,155.866745,113.325217,60.03932,65.516099,103.371787,129.640119,210.71272,238.973139,234.544871,219.623441,169.944947,-50.848462,-154.815485,-176.023792,-104.555923,-7.185909,-58.647476,-82.882722,-88.545845,-90.047402,-96.039228,-94.316447,-88.523813,-100.113386,-142.653047,-148.913307,-154.716816,-195.62964,-213.058076,-227.43396,-235.242221,-261.31609,-288.202433,-314.834799,-423.620748,-477.782958,-508.742151,-469.361478,-266.037943,-152.159879,-26.004806,15.489035,28.020883,26.68894,15.719171,12.077041,20.49874,43.966165,127.759092,172.604748,162.095219,130.988502,102.457358,86.017187,29.991667,22.796723,73.509333,49.240517,-7.483797,-58.034994,-52.324093,-104.217473,-152.41388,-202.984625,-203.235677,-201.89948,-169.195438,-114.898271,8.479816,21.687712,-32.248051,-53.219647,-102.648044,-178.91854,-189.706842,-147.223708,-107.866544,-22.555456,-3.178941,-50.634104,-144.499808,-193.843548,-284.615398,-296.538665,-257.045683,-246.161459,-243.408827,-216.172277,-108.170802,-60.938416,-68.689089,-56.707733,-35.678437,9.234381,38.419983,32.164119,-23.717359,-4.860781,55.570401,26.33001,-138.37109,-195.298292,-156.066081,-79.447987:297.793927,175.721991,135.421345,189.004446,223.524375,228.728735,250.437527,313.047134,218.297712,113.666198,-52.280668,-70.9334,-13.015411,47.774092,167.363008,182.725909,135.622922,88.694583,81.796732,85.623262,91.063062,170.138588,235.573464,228.966119,50.053013,-11.342837,-44.065434,-37.074108,-17.733711,-6.763753,0.712303,-37.536134,-193.403429,-325.854209,-345.688474,-220.227973,-102.163577,84.843971,124.582329,121.333201,66.94728,27.478835,-37.142419,-29.732432,68.364514,112.110827,84.356366,39.923084,-11.274191,-77.782495,-114.302157,-106.168373,-71.288426,-43.44211,-55.416893,-7.973816,87.308509,48.896494,-132.841268,-143.631756,67.998051,196.863598,300.226677,257.596177,53.932949,-171.210282,-245.391423,-266.71795,-225.375752,-112.449854,-73.501542,-52.171618,-57.778299,-82.617196,-148.760815,-144.431974,-66.849363,-26.869029,32.206128,48.316415,23.647828,-84.243018,-123.656623,-105.18129,-63.35404,69.737657,127.491193,84.599436,-18.226362,-19.149,10.664681,29.111776,79.911194,88.979992,53.808383,45.09516,81.984157,-3.356548,-98.259127,-134.956614,-54.722752,87.507912,80.13728,-48.593311,-124.540043,-145.827861,-237.981885,-264.039802,-125.769061,14.500595,190.700043,156.836206,-45.845377,-163.980649,-197.238826,-251.417137,-241.161219,-128.483602,-72.744088,-54.038229,-83.650639,-109.420035,-177.082724,-187.88701,-169.205675,-156.69545,-109.269785,-79.063557,-75.339412,-205.374574,-316.743431,-520.90475,-538.239079,-352.129013,-236.232601,-161.527193,-129.992471,-84.881367,-89.813355,-112.37306,33.359697,170.275581,294.552576,247.917303,116.111299,65.725078,48.779266,67.488887,109.017999,204.686036,250.98766,288.123862,179.537962,84.196754,-122.455539,-190.630401,-165.777164,-83.795118,75.229082,78.342764,-101.578578,-293.266821,-311.83625,-218.149532,-160.505431,-95.262546,-80.614386,-59.268565,-46.358004,-68.178493,-155.938671,-177.442476,-145.599714,-99.778801,38.609425,88.807529,61.768679,-73.972047,-157.402891,-260.657084,-252.967015,-167.117452,-119.157125,-54.459417,-23.16947,-9.515261,22.772738,46.114818,120.188228,175.14731,260.056617,237.854283,99.165671,64.244482,101.285303,164.120942,157.746327,161.704503,195.196754,189.551042,31.983245,-53.675516,-136.404237,-107.894955,74.596838,170.450863,185.661821,100.496298,-68.212812,-93.797729,-88.493076,-114.623587,-135.997949,-116.667258,-84.680815,-56.121634,-101.818118,-164.332564,-243.614989,-204.43543,-47.044466,29.806925,169.52092,214.616933,198.761348,18.003998,-101.305595,-201.925254,-165.749673,-72.387076,-31.988647,89.341951,107.680316,29.424122,-110.346264,-117.48779,-85.505193,-53.786511,46.870036,71.130969,32.089826,1.40944,9.131705,34.663013,49.874742,131.777559,194.527109,262.729662,228.377217,196.8277,143.959313,124.11774,90.576783,103.752509,247.66539,319.073341,269.366832,80.5727,27.591574,29.379966,56.134894,146.123775,192.227188,174.999492,66.828241,11.479413,-90.791366,-88.085369,80.210905,173.351022,185.697435,118.17451,12.855037,-26.390509,-22.974671,62.572949,80.604098,1.761257,-10.660855,103.885688,173.435885,117.354866,-69.925482,-87.593392,31.967595,67.088492,29.34624,-2.456184,-41.766482,-88.45224,-129.641831,-149.981411,-108.498657,0.436554,48.370415,120.780688,120.335629,71.633227,-70.639191,-89.134752,30.47746,104.462751,182.774338,190.674996,159.347488,39.267867,-52.018065,-163.073592,-142.552253,-0.496947,56.735985,21.042396,-49.748753,-52.620122,-118.541294,-184.128648,-231.67639,-184.405818,-73.149206,-80.371552,-157.856801,-139.866612,-123.570074,-145.460636,-170.123783,-168.052148,-138.868299,-118.739223,-176.749593,-212.323448,-304.986645,-354.172932,-373.84306,-309.227534,-54.02267,54.739662,130.817253,116.37726,90.615654,69.653349,103.56621,224.879381,273.02617,282.573679,261.511379,263.297016,223.02634,187.010467,141.188591,126.653508,130.654468,146.281576,126.161254,37.599087,-4.256344,-27.057236,-18.196482,-34.407806,-60.709648,-107.029414,-129.521593,-151.157026,-197.294913,-179.626348,-78.780451,-51.712529,-71.247405,-89.893368,-133.820841,-194.946065,-221.158895,-211.175038,-175.5819,-112.35489,-100.048524,-121.300309,-213.178783,-284.078107,-414.406171,-441.756805,-434.330735,-411.583393,-297.409274,-234.195363,-189.9257,-199.842185,-187.53726,-96.798565,-55.154469,-55.401133,-70.130928,-75.106624,-109.323549,-155.674163,-274.823006,-319.730585,-306.07948,-242.352353,-97.631018,-60.157497:394.40613,242.649734,203.507758,251.642157,278.32863,263.713841,247.82789,215.80013,205.665345,197.731783,109.811521,61.060333,14.204268,-2.397952,-39.297825,-44.881736,36.909337,171.793478,193.828812,159.74467,140.799989,205.737584,290.780513,333.774804,128.676438,49.113463,50.455706,107.625311,236.453673,263.76631,192.547012,102.342988,-117.357068,-232.579207,-225.009452,-101.457209,-23.604665,10.828206,-16.18451,4.005525,109.783747,133.349262,79.413868,45.260579,55.115959,78.411913,97.679871,106.896739,130.762126,74.692263,26.458802,-17.430582,-29.835253,-93.139031,-101.750961,6.177899,118.670665,110.104472,-16.226076,-67.052017,-44.833479,-11.642488,28.839091,44.714718,11.963367,-192.539194,-320.674079,-409.178172,-365.036759,-295.636355,-282.200928,-248.811964,-278.248155,-311.114551,-330.541685,-311.899553,-273.253155,-263.546624,-242.015281,-203.71702,-65.660081,-36.337271,-80.831788,-104.186542,-66.415081,4.412616,22.308318,10.061261,-34.94732,-48.924176,-46.675392,-32.054944,-50.952673,-79.171498,-39.534009,16.035755,33.118368,-118.196275,-195.831156,-178.284446,-89.551359,52.349282,61.710183,29.361812,62.156674,86.536209,32.7938,-32.126313,-72.007186,-16.840611,116.946664,127.708258,78.94238,71.009313,57.470026,48.287025,85.627582,130.010811,102.766445,46.573595,129.863362,172.739915,58.426933,-59.452244,-183.097785,-168.5897,-77.515913,-53.137322,-104.495611,-233.715327,-293.306686,-340.469209,-324.959757,-241.110086,-193.101498,-128.913918,-73.56483,-61.282572,-75.788471,-62.546027,35.784445,87.624426,156.044862,182.808494,205.506055,160.979132,135.994693,143.085105,160.073825,163.123863,170.506561,254.776394,371.148704,390.360471,293.650031,212.802811,86.962545,63.07654,73.708356,59.331282,-21.939214,-14.479921,6.77824,20.003632,24.370932,33.089915,31.694917,27.776449,63.70971,81.260305,79.13479,83.845433,105.270584,96.926363,92.458861,119.696065,183.145735,161.595073,103.142325,-48.95939,-107.697865,-149.94582,-131.274427,-70.770281,-5.792336,41.403621,125.953234,144.490875,111.083626,76.357579,76.36473,110.212536,165.27026,187.235071,186.41932,167.918844,163.061569,195.543811,233.90927,237.552461,122.801905,104.117845,121.923438,111.064606,88.587794,97.379587,107.562252,89.964002,28.823643,-45.110518,-87.396034,-103.124903,-74.573456,-62.955242,-73.911876,-41.794757,-52.497559,-110.271097,-189.739108,-183.742767,-157.631702,-149.389911,-104.65193,-60.233801,49.229635,57.434249,-18.918134,-159.284874,-149.256257,-38.044388,19.025719,104.399165,71.085898,-14.9787,-241.56422,-298.019749,-214.457668,-147.738698,-87.568838,-62.910116,29.948964,112.748793,111.456734,62.970967,44.561723,-6.330604,-34.239559,-34.333405,43.205576,68.165409,9.699189,-45.838993,-115.590947,-103.557668,44.478879,126.252595,155.591914,79.376026,32.085495,-51.460592,-67.309785,-49.083532,-16.146712,59.25069,53.439854,16.183124,-118.702479,-175.691881,-104.597051,-7.075099,94.427072,78.474566,-10.299884,-69.87642,-77.517702,-49.035452,-29.000677,-74.054592,-111.570382,-90.124744,-34.65039,-53.801567,-204.280386,-289.946874,-402.196777,-430.539988,-400.914434,-332.303876,-175.692637,-143.419147,-160.191182,-190.387367,-198.205297,-165.101538,-126.269007,-33.868579,20.508775,-12.285685,-146.357723,-179.340001,-157.272128,-134.559977,-79.600139,-56.327009,-33.860894,-70.519611,-143.931554,-338.465597,-385.265861,-280.783366,-168.268088,-1.130282,37.239529,31.176827,-34.676547,-65.881177,-36.522427,-9.675429,-41.819321,-97.758318,-173.758446,-103.803517,-86.23785,-175.32378,-226.276307,-248.235811,-234.159106,-242.236338,-285.206999,-282.691062,-317.681507,-366.764157,-360.168361,-268.449719,-49.610331,11.513968,78.366564,119.738906,110.834755,128.009348,169.160324,201.797332,188.449564,196.649493,288.864803,326.102001,311.012213,290.573251,266.683466,245.757802,214.937871,200.833599,119.763223,99.39729,114.287461,82.178688,42.499142,-12.157056,-10.284045,21.97059,29.945069,33.950305,69.638334,97.310885,107.440044,83.618859,115.593994,183.247424,213.789262,4.059161,-84.844917,-38.760707,41.727128,112.252932,111.298268,119.380088,81.66811,22.312373,-106.048128,-132.893672,-116.586404,-103.290772,-56.181956,-8.218787,89.875791,111.318419,83.196554,18.476186,7.734989,-9.965118,-15.920827,13.336444,40.487649,56.367804,56.27808,10.33746,-117.171469,-141.35712,-37.602436,58.146194:279.487718,134.80785,132.699188,218.807657,248.20594,235.310186,229.463695,194.216527,98.120942,85.260496,70.229619,45.734054,37.884585,65.597653,174.515559,243.979537,347.325711,352.850554,318.139975,217.377436,182.097151,213.251332,276.037932,325.687395,175.62651,102.333384,73.056142,99.594643,166.026397,185.657872,157.233664,86.183131,-113.290034,-160.313496,-123.659558,-22.552313,41.164224,185.993756,240.614703,253.259101,189.823607,156.01887,79.381486,42.07564,34.100285,68.854688,140.212975,156.818072,135.949605,97.827135,92.0208,53.827521,6.283767,-99.304283,-124.675294,-120.513525,-81.233496,-78.153991,-193.906423,-261.230164,-256.020615,-199.299431,-60.016246,-11.828578,-73.951141,-251.009368,-305.076507,-340.115665,-344.423108,-356.310749,-360.713135,-356.070305,-346.91068,-350.039366,-401.687366,-430.294098,-386.094194,-303.372108,-129.009995,-91.421769,-87.812036,-95.356685,-137.046773,-231.769127,-203.914239,-33.655442,15.928399,-47.999691,-165.348226,-181.369314,-146.84663,-121.362437,-95.338888,-88.494843,-42.888854,-15.428746,-7.32112,-88.359772,-146.653668,-176.418634,-125.618583,-12.917533,-1.635207,-18.942577,33.567291,37.657787,-140.350816,-250.738925,-268.48166,-202.529719,-111.4983,-94.483102,-62.14795,-44.666577,-57.856382,-80.5327,-69.122848,-7.185524,28.606,50.168639,49.850189,45.671909,-21.673754,-54.960958,-86.040112,-106.008271,-109.688909,-74.411256,6.827518,-5.818102,-40.087467,-98.856292,-138.731947,-195.102102,-150.812646,14.553358,52.273004,19.523082,-58.958082,-72.418178,4.272843,78.388304,197.966962,224.606859,228.12541,197.254194,176.202616,133.75068,100.376955,20.73725,21.563067,149.516033,292.807982,288.642929,101.21876,12.091278,34.621326,102.92707,182.000318,175.144055,105.088956,65.628048,65.938629,63.161716,51.473148,27.645443,29.644224,71.287603,183.660579,233.132098,182.344443,106.390583,19.80437,32.096429,125.814559,181.87735,254.42394,213.601414,149.842437,-10.074928,-75.088158,-71.151946,-5.841829,45.309988,-13.78889,27.859769,224.166505,286.351269,271.965937,252.268454,292.51689,322.799624,341.066156,367.661579,376.868208,349.23859,324.867547,298.932122,300.023337,292.532399,241.261873,202.436868,130.338386,127.455835,194.11387,219.720251,197.179746,136.101677,-92.154209,-228.649294,-214.211517,-150.460306,-141.691258,-149.459619,-136.303968,-68.297158,-65.666701,-94.359056,-131.843056,-121.728253,-45.342542,3.437092,92.863456,108.495111,58.233403,15.270117,-9.233731,-73.498553,-83.207764,-69.735418,-60.264277,-22.023626,-3.07143,-58.36022,-259.917272,-323.192351,-303.135422,-262.643198,-176.49005,-122.571285,-11.75703,41.599781,41.184687,39.410272,35.48566,-41.410668,-82.91637,-52.140911,48.700132,55.657822,-63.634879,-138.399056,-165.217291,-112.934709,26.364006,74.945437,114.769925,123.748242,101.106527,4.039347,-28.968738,-6.305024,24.757771,46.839813,15.057872,-15.971034,-115.573853,-163.620336,-161.107409,-91.402225,36.599445,24.162809,-54.616011,-39.163597,-34.55473,-84.498663,-131.962508,-251.207884,-281.412018,-246.942175,-158.496428,-123.716639,-176.089347,-246.237663,-315.693046,-315.592356,-317.456698,-309.504368,-257.287291,-278.733938,-333.087032,-349.392857,-294.900787,-177.22747,-104.634287,77.962631,121.83147,76.012097,-27.546639,-55.982901,-104.725521,-106.421903,30.892661,112.384908,123.708347,34.396594,-10.919225,-94.762828,-117.495878,-109.076699,-89.524035,-57.435406,1.310162,44.177629,23.519666,-42.6701,-147.897176,-169.680984,-193.651671,-210.067231,-234.117777,-203.151961,-197.664647,-264.644427,-297.442109,-277.716105,-253.910791,-246.611274,-246.318242,-223.984249,-240.106975,-322.622627,-478.248291,-452.190062,-233.748485,-137.373309,-37.04076,15.957093,17.608915,7.50693,0.197294,-39.404737,-40.033259,12.533265,86.132898,109.782076,62.409106,28.988634,18.655827,16.173867,9.795496,9.064018,40.686111,145.730748,129.226882,-47.780236,-94.006463,-77.462924,-85.716797,-125.992191,-56.017117,-14.658741,-12.257464,-2.703528,46.582868,42.636518,28.816578,46.4321,48.689811,-63.015432,-113.922452,-83.666852,-22.464376,43.047598,21.446533,-65.832672,-134.578347,-153.557574,-179.343037,-197.281859,-266.226284,-317.77128,-351.393546,-285.857282,-65.124851,-4.435143,-73.516584,-201.99071,-200.074757,-135.568308,-99.420778,-24.187021,35.98471,47.352508,21.596898,-3.008818,-55.310297,-84.683593,-121.217063,-113.139993:230.871093,181.592717,147.631685,174.310214,202.174385,167.483246,152.841352,199.041584,146.0255,60.987852,-68.317126,-75.887405,-58.203742,-50.117905,4.440845,29.101726,29.627065,64.498636,92.457141,90.953669,78.97686,159.881168,233.604628,242.285847,122.935261,71.619371,-12.331388,-7.731317,77.35963,111.968389,165.663821,160.817602,18.133648,-168.923512,-234.636932,-225.425877,-151.520972,-20.972998,-16.710151,-78.788462,-75.878353,-39.722615,44.233578,74.643789,140.707989,180.05714,215.994877,213.216492,205.631924,134.792088,63.855264,-34.808077,-38.85227,-25.883082,-19.003533,31.450633,124.10062,145.627533,47.498719,-39.899753,-60.921679,33.185912,177.776749,138.924364,-65.960335,-182.01782,-200.995117,-249.505444,-285.18949,-303.956653,-249.689405,-69.312499,-5.965628,-60.864697,-218.714444,-218.261921,-60.564852,-18.02515,-95.650472,-143.452929,-101.597556,15.789255,15.521056,-25.976546,-3.34555,72.830859,78.561126,28.167755,10.040979,39.050838,86.437771,91.649668,85.788916,61.618329,-20.310924,-51.146207,-32.429765,37.968384,31.442973,-23.182164,-11.105438,56.345912,70.86745,70.079797,71.223295,82.426414,64.240201,22.137345,27.258922,113.964258,273.508113,262.026143,137.760017,95.859024,72.33979,-35.098264,-67.313259,-14.260306,46.869071,109.57003,70.994134,57.797359,25.405782,-18.50688,-75.926511,-60.860803,-21.665419,-25.303557,-70.861867,-170.385284,-242.591965,-350.905937,-343.298751,-213.381792,-158.503139,-175.555373,-197.846411,-159.365739,-44.103521,7.710265,121.122294,185.01512,296.504489,322.43476,254.796746,148.640237,145.141951,189.529016,191.53447,161.869525,171.451259,232.808908,253.965082,231.672949,101.860545,34.467548,-0.275955,26.78799,90.539156,69.889103,-90.745208,-147.116842,-125.825991,-83.065471,-61.098272,-31.053481,-18.177992,29.576426,27.280028,-14.35708,-102.473896,-127.86071,-153.57023,-130.159885,47.34733,147.971457,178.987079,17.588828,-68.09161,-182.970884,-211.123232,-228.545373,-208.19037,-65.511874,58.122321,34.729422,-60.987557,-46.752781,50.643224,72.726607,83.86828,91.433652,94.37992,128.714996,159.053668,198.863661,200.200803,164.551547,142.773778,112.763329,104.450094,88.626515,29.674364,23.962489,59.672215,77.09292,69.146495,24.930572,-83.606242,-102.714912,-114.218396,-149.511022,-150.440594,-131.605496,-114.919637,-80.058633,-54.812498,-60.570218,-142.607078,-174.115288,-125.238067,-84.447922,-43.019841,-6.943602,123.572703,93.667948,-8.872823,-131.725142,-106.324785,-29.497654,0.661561,81.355559,101.198631,45.892572,-124.568414,-165.600647,-110.337464,-69.022044,-37.683426,-27.821786,-10.800465,-49.368854,-63.146691,21.219559,76.121321,40.943152,4.846651,83.231686,139.696247,83.10448,-33.245944,-39.385993,-6.824214,17.874738,94.797995,135.673079,205.466545,191.785247,110.619465,-77.798171,-94.348599,10.04785,62.454578,119.195034,76.072373,-6.97401,-151.771095,-131.886406,34.822568,90.479099,91.237006,63.8326,-19.294201,-82.448798,-81.765781,17.747739,70.21483,-1.036877,-69.304015,-34.48092,55.654271,42.844492,-36.696261,-80.700198,-176.326479,-212.128694,-204.901013,-161.537498,-58.75347,-64.247493,-124.264094,-241.528361,-233.118436,-81.068432,1.707897,45.078019,-64.79714,-119.141604,-150.519276,-140.715632,-147.604563,-144.986274,-45.148123,12.198822,50.331327,-0.840133,-63.549987,-165.921246,-164.023495,-98.073507,-73.552865,-77.676319,-65.273762,-46.159608,-68.908612,-89.603493,-54.859318,-24.411567,-37.474559,-83.192795,-182.657697,-199.356494,-181.259891,-203.992346,-242.436972,-236.573105,-196.224642,-206.707022,-289.245316,-280.201141,-250.823367,-284.723133,-360.522698,-333.452717,-152.877038,-64.189509,37.58225,103.218476,124.638619,156.293114,175.724223,191.944811,187.372485,192.249551,278.955617,347.05844,359.58505,282.188415,155.567821,156.404257,221.557893,241.582292,208.238952,151.722239,141.712495,114.433975,66.382301,-73.402777,-115.735818,-111.580828,-69.506018,-46.348959,-15.069067,-2.283478,43.02767,69.451328,116.852491,126.552447,114.625155,44.794728,-18.166579,-76.393145,-21.72299,151.818488,183.740751,103.739781,4.333425,-35.74081,-172.671583,-248.172727,-269.506611,-209.151032,-84.237223,-66.819453,-47.981659,85.941772,141.750049,118.325004,71.286516,-4.104587,-19.688687,1.174614,26.980839,29.537254,-9.882,-70.287162,-214.569952,-226.473386,-71.562331,47.801817:forward
-154.093411,-30.113935,7.41978,13.54321,-19.36543,-105.234579,-124.820303,-100.135927,-80.220111,-87.631581,-79.601583,-82.616465,-179.754905,-243.401629,-296.036584,-300.650214,-320.637376,-203.892688,-90.175854,18.00868,-16.021807,-101.172708,-95.151871,-17.861176,-13.655615,-36.687553,-8.104156,35.814741,72.674176,76.187138,117.95096,143.755638,158.591487,117.79198,107.166738,129.695436,131.322362,114.578147,126.020626,195.258411,242.303933,251.133272,277.287352,287.387224,271.037993,246.776186,156.976004,106.092471,63.547504,7.299092,-33.083227,-62.623029,-53.79317,-54.010856,-84.353805,-141.303707,-71.8214,-10.220734,46.8239,26.164339,-41.688142,-59.715854,-107.187694,-132.020527,-88.532013,15.76892,53.9823,115.271015,137.305208,112.352902,62.411885,32.919676,184.562634,231.864877,135.877709,44.063627,-67.777686,-76.466951,-82.228857,-95.020954,-100.108286,-105.511562,-122.448124,-131.411628,-101.811837,4.336609,45.783105,82.511038,82.394406,67.1397,28.973312,-10.649386,-144.537675,-199.91692,-218.052288,-177.875085,-34.882834,79.596595,76.673728,-63.78499,-137.3005,-193.744386,-218.12556,-236.589325,-111.105473,-44.845625,26.877146,35.517111,6.772358,-8.316103,22.590495,67.763441,135.351427,87.010721,51.427076,49.498499,80.600887,119.220152,93.256643,44.798624,141.114643,201.226428,282.749049,303.892617,246.953397,152.163274,-79.195723,-136.859905,-80.810643,-28.335366,-25.6636,21.195518,42.752894,7.090458,-31.70107,-72.9672,-73.119937,-75.701209,-108.075264,-144.65277,-232.659385,-272.151394,-369.384309,-424.572914,-498.321246,-502.363829,-468.285845,-388.281738,-378.57534,-389.416232,-378.140505,-299.479042,-234.600466,-222.767273,-146.973618,-83.485175,-39.428659,-67.774735,-149.203573,-179.671334,-158.700016,-106.762465,-119.63989,-192.250727,-228.60199,-294.942038,-317.398766,-298.458789,-237.061267,-228.007642,-201.701607,-170.214882,-151.23113,-160.273571,-116.79071,-56.850171,50.456273,45.107539,26.479997,26.697756,21.964279,-20.237245,-13.9702,87.679728,109.301854,56.824844,-59.217683,-85.984089,-70.886692,-48.150945,-57.892425,-90.062145,-108.344754,-33.594946,18.110941,108.427945,113.872366,45.94413,37.582492,120.861522,124.756836,83.081548,58.908686,80.250499,95.754971,74.939935,-13.660012,-60.662339,-107.109559,-98.49424,-81.541105,-67.793675,-85.380599,-146.004505,-171.31229,-166.803681,-177.665256,-204.789555,-184.804665,-148.569975,-159.101116,-214.433075,-352.131259,-387.196097,-296.295301,-107.836426,-48.782019,-25.098791,-52.259924,-154.763712,-196.699891,-204.46539,-193.473398,-200.469162,-179.271161,-157.271749,-163.981414,-183.851322,-210.024925,-206.43506,-155.430437,-130.307949,-145.176287,-181.121439,-188.623017,-202.815365,-224.504755,-313.960617,-357.081975,-299.422845,-93.186066,-35.657775,-86.931914,-146.968568,-266.562529,-301.748447,-226.683704,-48.278588,20.624666,60.598741,25.358152,-84.058234,-132.29527,-205.4927,-197.803042,-154.971126,-121.868338,-178.012332,-307.820773,-321.41855,-278.849548,-240.326529,-149.141317,-87.698116,-63.198703,-62.373965,-100.511815,-160.360065,-171.152431,-240.248878,-296.893321,-273.884452,-185.271796,-165.556059,-217.433924,-254.82285,-299.032332,-305.315681,-215.154285,0.555982,85.341475,70.440184,-6.739187,-132.38039,-160.810501,-178.77232,-103.178263,-12.807276,186.79315,227.385743,143.43124,62.406485,-69.230242,-92.198267,-11.768565,108.303651,111.488767,58.758771,41.294402,-9.267286,-48.293599,-41.027836,56.97168,60.896067,-22.766521,-65.179565,-72.996595,-47.631863,-28.458967,-31.592498,-38.875672,-46.490192,4.639675,168.416941,193.230935,117.263032,90.415258,156.847261,240.613959,240.702482,248.405687,293.654906,382.191272,368.110195,236.365851,173.415648,104.652973,137.900627,200.059375,237.339555,175.467335,55.962191,46.147083,120.762205,257.513875,288.548528,235.63177,194.296205,201.656064,235.067979,185.787393,101.655311,-15.474745,10.084533,60.189927,152.553531,155.605419,44.178671,-31.058316,-82.156563,6.485395,65.182654,152.075338,152.022445,50.501147,-4.342872,-19.456703,11.325115,40.854725,-0.746668,-5.85635,45.852853,82.874867,104.952217,64.451668,-33.724181,36.524545,106.889363,200.184523,224.155663,227.037519,209.051295,167.768542,144.770151,92.042455,114.024322,174.533233,252.269814,214.878709,89.656299,75.122998,134.438776,143.644203,135.400045,176.591703,180.874847,19.678839,-89.287985,-178.141129,-157.692568:-149.865474,16.72002,121.909725,195.54674,153.300362,21.386478,-48.552665,-141.590234,-111.112522,-96.62718,-164.277404,-217.37658,-261.181466,-267.515664,-319.774714,-341.038728,-247.881523,-22.933445,51.649199,34.437613,-13.315149,-62.307757,-65.741562,-33.977975,65.018391,113.75144,185.302059,201.72566,164.690182,131.742033,147.982422,193.948725,219.412559,150.119532,135.874861,140.94179,150.836086,204.325073,217.66824,188.606576,232.159075,297.084924,380.477554,362.595441,289.326329,260.244798,169.024539,113.982209,76.47453,65.981394,38.425518,-2.536813,-4.902208,-21.13931,-50.237564,-99.468328,-42.73889,22.304228,92.141478,50.006876,-83.480896,-110.848404,-111.34469,-108.495604,-81.162348,-6.318595,58.573374,190.056101,207.476359,132.420124,88.308882,88.454037,149.743713,168.804403,171.295002,147.031858,43.12318,-12.177995,-38.5277,-7.624503,31.995048,53.29159,101.763472,163.828535,138.504693,72.112607,76.777339,157.223898,262.038194,309.544952,306.971035,224.758819,-4.534685,-94.223613,-168.368951,-123.431833,114.152913,294.726593,289.370268,114.718118,17.520006,-86.849192,-115.316637,-116.949361,-14.414086,40.653785,85.089194,69.872855,38.927782,52.154006,80.456406,82.74279,139.817191,210.138927,211.104848,174.529949,147.725027,87.875232,81.328279,119.384926,123.731209,141.042644,251.960038,267.376371,148.792299,74.322112,-43.25501,-84.479123,-96.060619,-0.813277,45.052208,34.500013,-7.506733,-82.965536,-113.591642,-144.560248,-77.073375,-42.816355,-39.01715,-45.073192,-42.015646,-60.948263,-168.652439,-221.910778,-285.130083,-273.706979,-221.558366,-158.932382,-197.086191,-298.446291,-304.110882,-204.537556,-65.45852,-32.759573,-11.4507,19.514564,130.97947,156.298366,71.715189,28.955524,68.974257,98.79927,73.182241,39.6565,45.330856,13.996184,-45.4985,-165.244618,-165.216243,-133.144548,-89.451187,-98.627961,-144.360542,-143.759501,-92.391476,-68.214474,-40.416632,-36.845677,-43.109421,-94.304445,-143.333291,-201.437093,-158.257268,12.825889,50.445732,20.378067,-58.651912,-95.041343,-102.714075,-68.426873,-31.952304,-52.296731,-48.908092,45.816301,51.547477,-55.708389,-112.96018,-133.803546,-105.519548,-60.048886,-51.658392,-25.631019,12.203124,-17.772402,-134.337595,-190.532146,-290.343284,-333.165049,-337.334075,-196.887132,-128.812302,-117.196833,-159.69948,-263.491488,-296.793742,-257.68096,-200.683011,-193.664036,-157.03096,-149.289842,-200.375817,-241.378244,-338.989875,-375.229213,-324.34594,-165.706766,-111.825026,-136.420625,-201.797163,-284.076058,-268.148173,-214.577529,-238.779895,-239.955457,-143.539992,-100.500115,-133.866582,-173.714741,-209.45548,-213.583645,-235.729096,-245.454799,-237.392232,-210.493404,-201.387909,-253.31061,-306.550927,-337.411902,-253.039119,-215.799343,-156.460354,-111.477808,-51.007403,-88.035135,-287.215675,-359.534801,-292.580841,-119.31737,-91.753082,-190.237133,-263.292723,-343.25375,-356.14026,-332.40683,-199.106943,-131.891111,-125.28488,-191.155932,-322.139718,-347.836897,-342.011591,-312.02351,-200.307837,-110.030632,-78.983354,-25.511738,-37.355548,-148.614522,-194.242641,-228.300121,-250.665099,-251.324074,-230.046914,-207.75539,-156.515721,-161.084619,-231.373301,-248.462647,-160.022238,62.144344,163.324034,156.946137,37.076154,-190.936106,-208.360718,-114.415732,-10.999333,56.726554,203.651506,223.590559,127.197004,60.248969,-19.212696,-26.713956,1.888877,91.351053,136.987356,107.765074,34.843377,-70.924631,-73.082875,-37.009563,-15.633269,-11.306615,-14.770581,-31.695241,-74.06536,-76.801149,-68.641358,-85.851239,-144.725069,-94.891811,-13.262748,101.230433,88.107926,6.308107,-13.735453,75.172219,241.277545,273.177157,243.085207,224.012814,212.62258,188.640618,77.171849,30.299724,-0.825619,55.478056,111.706272,152.340174,120.552435,41.684566,19.528604,41.234372,160.63274,245.976881,349.085593,327.274386,224.520503,172.484418,43.611452,-9.747176,-22.535706,46.179419,110.754806,240.199163,241.117451,73.485104,-35.725863,-118.218122,-5.576367,72.380556,164.84736,141.788946,-5.65475,-69.499225,-99.837891,-62.680745,62.889033,94.985917,66.522385,12.514758,6.966906,28.821694,37.297227,32.24846,44.153074,78.675197,190.85071,221.35545,177.196828,134.070378,62.507506,53.021874,76.543844,125.088642,188.237966,341.079067,370.520195,247.848314,129.395435,24.986782,161.430648,223.096248,224.971522,180.534302,65.988491,9.59344,-98.354892,-117.327652:-31.868759,108.449134,183.212615,226.324068,193.352733,52.318717,-33.619898,-142.006157,-153.100012,-129.725831,-76.48203,-93.004833,-204.363093,-257.608082,-314.493024,-308.511718,-203.383849,-13.603872,51.31744,52.105639,31.86003,11.012321,-10.110689,-44.029484,29.345371,84.164972,151.547134,157.071597,136.996862,116.615196,98.217971,125.83519,169.89136,99.354761,64.216179,63.535186,86.977993,149.420834,180.857497,210.760108,205.672907,221.596544,260.05174,235.349256,135.450005,97.6146,15.215598,-29.4849,-57.590719,5.719198,33.856338,3.575815,-34.528855,-95.759083,-123.096398,-104.802663,38.153061,94.390982,89.1659,43.334042,-53.275249,-89.296783,-136.306165,-139.546345,-78.814542,70.452768,162.938981,253.27433,221.27929,111.441086,79.077369,100.183112,219.112576,267.393522,280.453655,258.181606,177.469353,116.899978,17.066495,17.562069,97.143552,161.746955,173.586449,168.908169,166.467462,152.288502,127.249807,98.176581,196.348878,278.987207,325.547828,254.208811,43.956791,-49.591734,-138.88795,-103.81059,101.974799,295.750261,302.158895,141.922808,63.339161,-18.305044,-61.231448,-72.726674,103.041251,197.974782,257.915845,222.025376,137.355265,130.735772,160.121387,161.244725,152.683895,207.654535,232.250881,214.961921,170.802082,29.581564,-22.944385,5.875975,85.716034,96.512904,126.084192,143.506967,85.630372,21.461788,-65.120955,-72.666831,-28.758462,40.399055,35.374755,-31.160671,-42.824768,-46.133055,-81.90454,-149.785584,-51.625339,2.89613,-4.75763,-37.352843,-84.735207,-104.972954,-166.224793,-200.938818,-216.115875,-150.591774,-124.28687,-142.16757,-164.265013,-183.567373,-189.304972,-199.366332,-136.01094,-53.266166,96.648539,108.217913,50.673494,23.409807,-6.721177,-4.692976,34.383812,107.078987,140.403711,109.156436,33.380426,-108.318053,-123.078209,-77.62636,-32.255934,-10.369842,47.656365,53.217277,-31.562618,-85.70179,-113.250795,-73.762933,24.806029,15.154238,-14.771175,-94.025391,-133.372982,-121.49696,-67.949148,23.452387,11.955969,6.04353,51.4441,64.317817,-5.726234,-61.330115,-110.340156,-101.126726,-61.739443,4.979808,29.777913,18.27916,-14.039137,-107.652233,-155.930494,-185.228411,-78.336832,-15.365847,36.771308,20.598077,-82.864456,-153.203835,-276.060171,-313.806543,-322.884493,-300.905845,-289.131555,-222.602976,-190.681489,-235.742597,-281.586211,-247.824295,-139.169792,-119.535755,-153.645397,-190.719826,-234.89101,-248.378518,-330.180066,-383.818511,-409.085804,-292.185212,-222.798448,-145.830758,-143.086874,-222.538271,-271.656261,-236.192969,-118.59066,-85.619824,-64.262694,-84.751408,-180.449203,-214.657578,-165.684238,-107.078138,-84.830531,-111.607035,-90.391052,-105.456479,-176.592765,-345.778244,-375.240558,-270.744143,-149.750598,-112.169725,-10.038492,-1.879517,-167.875953,-255.513999,-306.599123,-299.36746,-220.486894,-100.32639,-82.260082,-120.211264,-150.546693,-227.153645,-254.629709,-215.379601,-108.217761,-78.845278,-116.202577,-171.284675,-259.577997,-268.110627,-228.437124,-206.938684,-206.265525,-193.729758,-174.3207,-117.014068,-94.808097,-149.030891,-197.058989,-209.749245,-161.850144,-148.859806,-161.982866,-186.100392,-239.746196,-256.208078,-287.721524,-291.132745,-162.303005,92.608939,170.189067,125.214386,37.0722,-126.924925,-156.564609,-99.099616,13.193033,84.852215,256.056517,291.782286,174.302505,77.271195,-53.427951,-74.47827,-37.268165,67.907214,116.239499,115.85234,66.060643,-59.854952,-102.475445,-68.976588,19.382784,14.306037,-54.882262,-78.376474,-93.889243,-107.165201,-139.879457,-145.982601,-154.443078,-80.93462,5.47709,114.004079,94.357991,20.418877,29.083874,133.800871,220.508304,243.000151,273.736126,278.199536,223.371425,163.644989,40.287133,-2.373068,-40.943004,29.699941,85.75504,111.8251,96.602754,89.022516,81.081833,55.151598,132.815609,203.635635,236.061528,181.838899,76.718137,48.914331,-1.14148,-21.182618,-31.217197,47.301381,131.143785,261.687274,256.940081,145.200297,84.816652,13.993857,11.53365,32.239218,50.377119,26.057671,-47.560272,-68.656969,-53.712739,-22.821708,34.094826,46.404294,46.987718,29.025607,15.918424,16.196164,25.915244,49.26606,115.25579,170.103975,230.010022,211.818137,153.191803,132.888287,117.555145,140.047546,215.632279,292.721733,342.75826,398.667156,378.425111,247.4582,156.475895,48.795769,121.08721,180.23836,204.563709,154.776444,18.120535,-41.36546,-115.929636,-106.932909:24.360544,118.743006,142.740223,109.137579,51.202382,-24.292316,-19.159859,-9.549947,-10.444305,7.434612,40.875397,29.483276,-34.703079,-59.445493,-91.861371,-111.356356,-153.176088,-133.439233,-68.940183,72.371456,85.756497,32.758151,28.034479,115.03886,204.825543,218.696353,232.746094,227.65764,134.825796,82.078013,114.334411,186.114376,233.48736,69.514198,10.828927,78.875539,145.120077,206.290448,218.693387,230.024712,196.012508,200.6686,228.933136,210.835292,146.600746,101.103449,-75.050473,-153.315196,-180.974071,-146.042768,-105.045966,-37.758719,-63.263095,-162.77015,-190.468883,-189.410158,-87.056166,-10.84928,59.385683,27.150345,-58.605763,-63.796535,-59.763945,-67.690699,-28.638041,47.974341,87.996299,188.691441,208.927931,141.925515,109.787188,173.185252,270.964918,266.245657,193.458148,149.497664,21.958519,-48.665975,-73.395777,-13.399905,119.745426,115.626878,72.16426,-28.64559,-63.365494,-87.275549,-90.530136,-51.241382,69.276875,116.071402,101.931468,26.434136,-205.455504,-287.365847,-315.050461,-276.022604,-94.104118,71.767091,74.892401,-80.45135,-185.960419,-306.433816,-302.809419,-176.827378,-13.686592,23.258419,76.249236,125.879092,180.372333,148.896757,34.216723,19.766297,105.540343,113.331223,66.644501,1.954286,4.178757,11.767319,-4.400526,-42.741989,-11.394273,33.839186,132.240606,152.191041,97.91864,34.760414,-87.359891,-87.840634,-3.005727,-42.430616,-72.361053,-49.941159,-31.86485,-33.772843,-56.165503,-100.576736,-53.830623,-30.648455,-49.923316,-69.460262,-104.536715,-133.156642,-223.927066,-269.666669,-336.650865,-346.867413,-317.937636,-256.624772,-251.05658,-267.326102,-277.671033,-279.810779,-186.330588,-114.076545,-4.702804,21.183032,35.527753,27.297046,-13.493217,-38.784955,-73.865241,-68.145494,-59.997461,-53.579133,-57.73497,-92.08078,-130.432235,-194.637896,-120.540659,-61.172162,-4.117704,-10.437629,-57.127962,-68.561652,-17.16766,30.435545,69.828765,8.067068,-32.345523,-114.050867,-147.748038,-141.151306,-97.897265,-8.833097,16.463612,29.717711,91.155467,102.86855,23.408249,-30.254456,-79.14256,-82.856391,-72.900738,-42.609842,-12.772139,34.756747,23.444565,-59.465276,-103.643939,-93.373892,50.596515,104.515779,122.076475,96.302187,3.836368,-42.955222,-147.782647,-207.115108,-271.321188,-273.230315,-272.12882,-261.800814,-243.259815,-222.673388,-251.190296,-331.674144,-337.919199,-315.246476,-220.11813,-168.570611,-142.903942,-179.865152,-323.693142,-377.050253,-316.250753,-167.59034,-137.955057,-162.47196,-191.17214,-239.465511,-240.311249,-179.380252,-132.577477,-139.12176,-150.815377,-140.668623,-106.311964,-95.494589,-118.474603,-145.240612,-151.222761,-98.880459,-106.0742,-248.748706,-334.145161,-384.532569,-361.953954,-320.360525,-290.697255,-248.416762,-98.157219,-48.687279,-110.202415,-201.41024,-372.609424,-378.950521,-219.871068,-78.888788,-48.050876,-10.411082,-7.163661,-54.881262,-94.445315,-150.878529,-137.912245,-120.210171,-148.494343,-202.335004,-259.933394,-234.074172,-174.153979,-170.431228,-188.53404,-207.076726,-206.003304,-184.468877,-195.182727,-248.398178,-249.65846,-197.712612,-163.706808,-167.501747,-192.173179,-204.164691,-210.8308,-213.960393,-275.86057,-315.334463,-260.895195,3.29214,123.552247,99.125344,-13.653473,-166.066515,-174.410687,-116.423964,2.154226,93.590488,275.110731,294.964143,180.55198,107.264662,-2.58908,-47.54406,-84.966865,38.964907,133.274876,183.015519,98.138944,-141.406316,-205.598566,-150.521391,-17.357937,14.070491,-9.654421,-52.79629,-120.753893,-119.34273,-82.890979,-76.891606,-113.113629,-102.73013,-39.969457,98.115066,121.761751,75.71082,54.164261,118.921864,220.593798,242.236413,270.873492,293.093689,296.341708,243.771031,79.905616,41.404183,89.486633,170.895846,204.686827,219.54134,201.708819,161.697476,154.553509,187.644678,231.871569,240.839228,225.164167,190.112695,119.072524,110.206603,90.007147,58.316048,-13.343008,8.2758,79.229352,195.193657,183.58071,99.528113,54.002644,-40.705518,-19.014663,43.131355,135.649984,127.045862,45.632491,12.943255,-2.52951,11.082336,56.591754,108.343059,133.021841,132.106563,112.824446,100.275065,88.959792,41.206086,99.774153,166.007599,273.052242,300.467794,302.278222,266.919278,143.66302,112.30176,211.887044,374.385168,413.572233,410.962719,379.769224,243.846241,165.920124,132.367748,192.604993,189.801883,133.508057,95.587041,-16.46469,-75.805767,-134.702556,-125.904004:79.745819,190.460946,243.686939,201.979002,125.737955,36.00702,32.892218,17.898759,-22.218373,-5.242491,60.572761,46.04055,-69.003358,-127.737681,-195.824618,-185.797846,-130.783707,-103.369068,-72.045378,-17.828086,-20.750204,-37.502891,-34.418376,-22.290625,-24.286156,-4.710486,127.402644,192.961565,186.347688,138.246218,82.182015,82.466349,60.360758,-0.103477,0.639515,52.383676,70.850785,89.658328,95.634393,103.28556,141.749941,181.034466,233.132624,210.474743,86.358165,2.25549,-186.254395,-249.445448,-208.694524,-12.273583,53.527668,-7.712061,-86.678314,-177.953038,-188.930278,-165.550423,-18.059418,93.459816,195.615742,140.346013,-34.718615,-90.908926,-134.963341,-130.695982,-38.63598,155.252266,243.022279,322.691088,315.701872,236.931656,188.176982,161.317796,243.623752,286.480467,275.479042,224.764761,98.693022,20.49909,-113.882703,-111.606838,24.54358,144.085055,162.545672,98.306801,32.083294,-37.047458,-24.916199,43.750563,150.102147,181.981316,127.698647,60.327127,-81.592031,-146.896906,-219.208795,-201.464438,-81.830038,31.146647,59.612401,11.801782,-72.654519,-247.224894,-268.055703,-137.397833,23.153848,65.733122,104.484389,109.103257,87.486832,55.368659,-6.059378,-9.314182,19.601804,73.280391,111.700864,110.609542,38.047166,-137.74227,-166.13783,-102.043543,-4.488397,50.370343,124.629908,103.263438,-20.180218,-68.78761,-68.180601,-25.055803,51.977737,59.838267,75.107504,75.664022,26.38099,-75.663695,-92.929957,-72.024786,-55.713118,-79.365251,-146.181826,-160.807841,-142.493853,-117.286229,-104.042336,-128.006713,-154.592253,-108.336196,-88.742079,-116.289117,-146.633649,-187.745596,-194.805695,-151.618769,-50.816727,9.962113,142.790186,174.590928,108.630348,46.621115,-35.03109,-44.50159,-17.942753,67.121976,104.945657,78.18896,31.647451,-56.600161,-103.505477,-183.545726,-113.313119,-14.373896,155.986677,175.384328,75.184624,-15.059337,-121.484085,-80.344867,78.903888,64.869244,9.714497,-65.425669,-90.726687,-138.955707,-132.789105,-45.936058,16.279408,53.773302,164.735483,180.974699,39.541003,-87.341906,-215.433622,-158.658776,11.483837,72.038053,102.700427,145.915044,107.127121,-74.406216,-158.195548,-183.792736,6.548565,131.723099,285.634386,273.631799,88.498671,-24.242246,-154.680859,-161.094175,-104.717451,-88.337525,-112.861205,-146.643724,-139.822663,-149.214698,-179.603831,-209.996403,-182.967725,-157.727244,-70.931045,-36.246432,-77.816712,-159.08646,-302.767273,-289.623205,-107.618516,19.290917,19.672062,-10.647071,-24.451445,-73.192349,-86.025046,-19.01699,31.21526,16.501967,31.558663,67.903235,76.946916,25.289542,-82.302569,-72.121618,-1.173227,-38.926421,-64.231585,-108.835692,-149.243588,-220.895329,-217.702632,-168.517773,-169.578588,-128.544588,108.735888,201.049971,121.554463,-3.762599,-190.704,-201.375748,-71.349597,103.761791,150.392924,127.016806,86.469174,7.497882,-37.505767,-92.359761,-27.514086,25.860223,86.67732,68.318956,-51.841088,-127.093317,-209.375293,-175.795164,-54.598337,-16.272683,-3.434912,-12.451855,-65.278541,-196.945142,-216.831725,-139.235246,-71.454738,-81.897977,-140.351433,-174.589468,-230.472588,-241.537535,-267.748621,-281.516697,-208.897614,65.663446,218.870095,291.055479,188.175888,-42.576389,-88.119065,-53.683125,95.162889,194.965539,295.009716,258.311038,116.198464,52.648364,-13.085872,4.213173,66.850529,110.754495,133.423341,71.829947,-8.152882,-138.118068,-171.818599,-152.733208,-36.617615,20.254025,57.520835,11.211878,-143.914903,-193.750319,-224.988083,-221.514882,-139.8528,61.46234,146.691069,131.241452,69.415588,-17.104142,-29.103425,38.446236,151.072782,186.04633,208.648026,192.417945,117.019311,67.205525,-72.270457,-140.243191,-156.96057,6.598191,104.422281,161.950909,108.47773,-35.288771,-62.763757,31.660199,146.991004,158.118577,142.197297,133.661261,102.113088,70.693844,15.534716,21.887133,73.213735,111.692016,153.810362,243.338786,243.025952,133.994037,49.249194,-41.09639,75.720374,141.225064,150.685301,106.709051,39.76909,39.227229,39.74466,33.242842,63.755312,138.803389,156.396327,133.97912,117.932365,65.439556,35.433396,78.905326,173.031448,194.046403,264.607419,308.531271,286.160613,210.152881,69.562854,66.416256,203.038438,388.186915,419.718375,291.963867,199.299422,89.308901,55.356781,34.820632,89.369155,116.625054,118.601924,57.892553,-163.944671,-242.000272,-213.843866,-150.02146:-34.217418,2.745616,-13.789419,-70.780341,-99.691083,-116.76568,-102.980688,-45.366623,46.837397,78.651466,76.336774,55.588997,8.485123,-10.566089,-61.133173,-97.491695,-147.162098,-157.05354,-143.743291,-61.455536,-23.050343,-21.612494,-45.491799,-47.252699,-3.087996,3.153665,33.621598,54.071144,36.521283,23.443862,48.894006,57.452826,13.060301,-42.988079,-49.583639,-36.734014,-31.849059,4.116073,48.344823,136.809369,126.687268,68.758033,-40.06629,-39.911138,21.714386,29.280204,-45.135127,-76.066188,-78.163562,-161.966378,-196.464266,-143.454238,-104.590564,-109.776285,-143.168496,-205.745338,-216.130237,-177.168429,-5.111116,54.787117,24.843689,-12.267911,-59.620976,-71.441749,-62.405341,2.949412,54.108381,70.160282,19.536579,-33.461935,7.475972,136.827916,162.89193,133.987818,67.629185,35.293066,-30.355604,-52.360043,-96.675797,-124.624191,-138.249288,-100.221158,-87.83615,-114.325579,-152.964593,-200.622587,-177.668723,-67.040778,14.756346,16.354706,-76.6931,-165.916024,-331.446785,-360.543402,-313.585358,-257.935976,-127.348565,-36.57391,-18.380088,-81.168318,-164.842214,-306.621444,-311.680156,-186.586289,-33.639812,-5.118929,-26.836195,-32.465444,2.585653,9.772294,-54.712491,-83.179424,-20.757014,37.633304,23.588422,2.739431,-7.283088,-82.223158,-116.037547,-55.214602,84.832617,120.934263,132.734122,118.695794,54.09494,33.85997,55.155468,73.959985,73.228492,-10.332735,-50.516797,-70.681503,-56.957176,-16.565178,-10.370289,-27.435616,-49.034033,-80.638092,-169.57531,-199.159734,-239.250231,-264.79239,-320.862508,-340.245396,-384.923179,-456.53774,-449.7268,-349.90281,-325.830277,-370.56202,-386.950712,-348.877437,-307.979079,-280.242718,-173.386876,-137.444293,-137.498711,-125.946054,-91.132405,-114.006243,-186.32246,-177.112938,-164.070776,-202.09979,-239.393688,-266.378201,-249.536126,-171.303705,-79.208427,-43.086343,13.867491,26.133913,11.632133,3.062804,19.640843,49.181392,115.392354,98.845903,62.36917,10.365929,2.024317,-34.101235,-66.406989,-58.653633,32.461671,44.241281,2.530582,-24.112884,-75.800082,-100.358913,-127.432281,-105.669163,0.831287,98.38336,146.452075,199.276238,175.238421,103.551477,111.960461,205.657653,217.176381,192.88482,206.978572,220.107738,139.528922,73.553895,-3.438303,-9.262841,16.380881,-6.826814,-40.551338,-85.854895,-102.849706,-157.34149,-180.723191,-195.879321,-253.780487,-285.920471,-223.353355,-138.923951,-35.11262,-54.577173,-134.516919,-126.463609,9.364421,113.28983,98.555661,-22.898201,-87.361519,-153.989532,-143.47079,-65.820987,-35.155443,-48.592777,-41.257926,-2.431701,69.040149,53.999877,-54.550837,-80.820849,-31.946792,-16.163859,-42.521785,-179.846794,-272.04321,-339.767203,-326.915474,-342.016259,-279.520043,-170.414641,88.736909,153.980567,59.717237,-50.393738,-225.962659,-249.827918,-155.842555,-5.697676,43.29597,55.192703,40.23601,46.34916,55.470521,33.797157,-21.411015,-54.996861,-97.551969,-94.050372,-75.488034,-69.418165,-43.901493,-36.463456,-57.337852,-82.361384,-73.555532,-38.928502,-56.937402,-135.346232,-148.038137,-156.95068,-228.611881,-257.025062,-209.845747,-159.73135,-150.487335,-183.516662,-242.258603,-263.923163,-203.104002,38.602982,121.697694,46.839608,-52.561203,-153.502835,-134.689709,-42.366178,19.125873,75.518697,278.690982,330.060027,229.166919,157.950998,65.484885,18.746021,-18.520747,68.676732,104.209982,97.799831,71.783368,15.161969,-1.868019,38.996591,115.626145,99.369291,-23.350191,-79.415052,-92.48014,-42.612397,56.643393,52.36507,-30.16988,-12.554035,70.296248,200.827818,169.886294,28.825911,9.870721,103.152813,197.639891,212.014647,253.092511,282.62554,278.232543,240.074998,124.353155,70.834667,34.824199,94.700468,154.837013,217.40737,171.290457,35.277038,15.296172,122.654025,250.006229,222.677241,59.790781,10.200701,27.997706,60.12581,73.461156,51.689582,20.095875,58.373654,94.412774,150.194911,166.454234,186.362314,187.397581,184.912337,172.710443,173.600991,210.211254,209.389354,104.986659,49.638162,44.690914,61.504128,53.637206,106.722522,147.8416,99.605892,40.645176,4.150897,4.778662,10.751781,89.524921,140.123622,216.490226,224.27487,177.667853,149.774906,122.793869,122.652861,156.525284,258.932287,296.898651,230.646625,148.583697,25.442357,4.110449,-7.81184,-27.366985,-33.040093,-45.73342,-81.287895,-204.743979,-235.295105,-177.280648,-136.599838:138.651244,222.184701,226.488693,164.133311,107.036184,19.616254,9.286194,22.348391,43.220764,63.939792,113.706731,116.598356,58.961265,21.27703,-38.051508,-66.82921,-104.682568,-44.619841,3.05884,26.835727,5.600696,-13.754015,-15.750569,-15.438061,57.345595,113.23655,193.479581,183.42598,73.181741,26.771601,-15.59903,-34.806375,-31.068732,40.231525,79.320964,130.674378,125.339937,59.833643,31.517835,48.704378,116.683343,135.695399,123.677698,99.838332,9.983076,-69.123233,-223.843849,-241.218424,-166.047843,-130.349743,-121.343397,-74.382344,-74.558642,-146.56141,-172.938025,-134.936263,-49.192905,11.490105,162.795928,193.993196,85.591639,-5.539586,-99.721746,-73.442025,66.252313,163.079635,194.981061,208.358211,168.821194,57.183682,34.866643,126.343092,301.468596,346.264815,278.543948,190.744729,26.837955,-26.050664,-79.218913,-75.87779,-0.789191,92.347726,100.397256,-4.788884,-93.102297,-222.011544,-224.50791,-91.096818,91.322812,133.227436,92.967697,25.980227,-138.853753,-206.617624,-272.077064,-250.234334,-113.324242,5.244484,28.068638,-21.313257,-95.777656,-286.332981,-343.123734,-279.646937,-89.140219,-12.144309,68.321818,79.945414,45.236542,2.936248,-86.305965,-98.107188,-29.182759,23.51479,22.138219,-33.660309,-99.735898,-236.251897,-253.699551,-160.319665,-12.099357,55.880901,161.34371,163.040008,77.175067,45.124498,37.814282,47.768389,78.33083,103.692948,117.732608,85.022044,27.967697,-73.496007,-103.793568,-109.8883,-10.339007,27.814848,-15.385297,-66.362216,-124.460273,-138.014398,-191.144114,-227.566025,-288.124076,-250.240939,-177.363951,-67.170373,-79.914453,-181.546506,-223.389353,-227.419138,-106.652251,-21.191193,111.131082,115.741195,-0.930709,-60.242967,-104.249518,-103.342915,-59.119824,25.552953,49.327825,27.403856,-0.503352,-73.985378,-113.154738,-116.168353,-1.113532,72.838811,171.362098,171.557759,106.080515,62.561948,26.663694,57.854701,130.021995,106.742961,77.063873,-8.61229,-67.68202,-152.846383,-155.435055,-71.001787,50.979015,96.867478,160.714786,163.927174,70.942476,3.618538,-48.426723,-16.239655,95.776227,201.871774,245.899915,242.335664,185.201376,37.711778,-17.085238,8.131565,177.08426,250.409815,318.843572,303.463928,194.207811,134.768522,25.635589,-26.75641,-41.070937,78.159392,103.049608,-50.123186,-161.300162,-237.734862,-217.913357,-175.422149,-151.201279,-129.31565,-27.049361,31.617782,61.22727,14.782831,-121.851529,-142.592745,-2.173372,223.219847,268.131525,153.973748,52.445756,-85.750192,-98.497684,5.416702,151.085328,179.403057,185.587734,188.700381,181.037047,144.55113,47.545359,51.440946,138.830425,83.322757,9.685918,-97.775784,-123.680169,-163.35503,-190.230153,-220.364045,-146.56017,-60.499232,138.546693,179.661941,83.431754,2.071631,-104.530586,-100.097284,27.571082,142.423108,162.398375,152.649509,121.629312,23.046896,-13.841126,-2.823196,38.251487,44.782551,82.108529,99.38351,51.130371,10.380726,-3.310229,12.900351,54.616561,127.039425,148.675468,97.760751,33.532775,-101.674986,-148.055365,-170.210364,-130.485557,-105.010548,-43.182619,-18.901658,-53.88703,-121.818619,-277.939585,-305.022766,-145.947432,154.615675,233.592827,128.293383,3.772984,-136.017467,-131.967116,-82.023897,24.630204,118.56237,296.924985,302.961306,125.919732,34.637005,-8.100774,11.085171,37.389884,100.622192,162.415973,184.101664,105.453403,-89.028534,-144.662361,-140.47411,-9.344697,70.243349,120.008396,57.213925,-126.601232,-171.858041,-129.427399,-82.673366,-42.504851,0.347322,58.57823,103.135884,61.401939,-39.381865,-62.218397,-9.856088,103.17686,151.413665,245.065391,266.669843,133.825513,-7.53883,-203.27682,-190.462774,-83.336658,-23.66979,43.903787,166.424111,137.665533,3.861275,3.273117,165.850333,250.946705,220.010589,126.306638,84.396769,36.93466,28.137725,-22.769129,-67.025274,-114.923784,34.902003,156.598839,231.500478,152.627737,-39.105626,-81.664119,-33.645787,93.490956,132.366257,150.628763,130.263648,-3.159192,-80.192176,-105.954623,-52.296792,56.205552,107.145109,134.549299,144.736218,106.362195,23.146792,18.056173,59.89339,101.939555,125.983289,181.740579,204.329773,221.201075,194.734482,82.215279,56.293683,133.95446,295.136305,352.433846,301.250416,205.652455,13.083601,-44.44995,-66.640287,-61.166694,-74.230192,-86.881533,-97.983935,-164.148176,-195.227669,-227.324607,-224.97188:86.39628,-28.335799,-99.870183,-188.716649,-195.175021,-108.873021,-43.351874,14.119201,-23.288752,-47.821837,-77.401004,-82.246787,-90.336067,-85.236233,-31.059224,-3.495282,-67.891708,-218.154568,-260.548291,-304.658521,-302.192223,-222.366922,-186.937786,-244.205481,-409.843336,-463.072349,-408.89416,-330.226886,-244.6048,-243.259648,-216.603095,-187.643094,-172.27399,-213.980366,-225.929094,-246.862951,-270.469925,-264.848203,-225.292557,-156.925689,-111.586498,-82.743164,-57.461089,-72.929259,-108.546086,-125.143644,-196.747316,-225.886741,-219.394634,-241.439753,-246.157897,-173.115742,-147.286693,-190.30962,-215.869443,-203.505159,-158.253556,-124.116359,29.211665,135.133005,261.933343,242.400337,61.656172,-47.414137,-162.527541,-136.617729,-101.706672,-53.369398,-49.159234,-58.429587,-66.259258,-46.531527,-39.899325,-77.32662,-141.831083,-152.227643,-153.474991,-139.947419,-150.439094,-191.783881,-275.047902,-274.912394,-254.466292,-254.530663,-266.463657,-261.266852,-277.452025,-343.345201,-347.230849,-348.011232,-346.327717,-325.104628,-302.147842,-302.252441,-247.393736,-198.421044,-103.348472,-33.547236,-15.280636,7.409728,17.853608,-4.839963,-39.104118,-38.108062,107.333157,177.543144,246.1369,247.657034,196.357237,165.879097,180.282354,237.638743,317.26118,234.414451,188.896555,131.025682,81.132147,-25.325918,-19.00986,110.708308,187.308809,188.86301,215.263988,239.294966,246.736184,244.335148,246.261385,234.974737,208.807864,201.939244,201.117884,169.505096,144.055352,125.787349,117.234828,54.708103,-22.495012,-65.704514,-144.992145,-165.639023,-173.891442,-178.614712,-227.247856,-268.400241,-343.855433,-395.677663,-402.767396,-393.29721,-392.014128,-373.461614,-358.54088,-372.165006,-370.280309,-342.62268,-262.757526,-217.956673,-151.917822,-143.721484,-175.108416,-182.028975,-106.848739,-49.74189,-72.588431,-130.407196,-140.195377,-140.180875,-115.928416,26.124484,131.765327,122.559139,127.386382,173.630047,246.429903,253.315633,249.082284,246.408178,218.552772,118.664253,73.317369,55.375763,79.586944,150.936217,149.933012,60.248501,76.26866,134.050106,223.148457,233.592599,206.731507,179.955293,98.896595,78.837375,175.875809,298.901145,293.600461,216.707085,207.207824,263.562899,291.216612,290.807177,291.808644,321.676832,359.480294,337.575366,273.805047,241.317865,167.118592,165.248439,250.218973,245.54056,203.31093,145.853642,107.818844,-9.923472,-32.967432,18.315136,14.429467,-5.603368,48.644629,130.545179,311.279938,347.69836,279.519491,256.283914,381.856769,522.713035,509.665113,381.855825,331.951207,297.16397,287.547807,263.502889,241.254423,233.716444,230.781153,234.902035,284.778548,325.129635,366.733942,368.450379,329.272139,194.97467,139.575561,105.624894,101.218516,90.908829,58.94261,-28.606919,59.003826,148.644597,308.699459,345.343986,244.358682,136.564229,-23.641654,-28.591107,88.340018,139.964765,121.803779,159.382907,224.307312,296.708746,274.19937,224.322503,248.695244,243.605446,174.267479,139.242291,125.697826,151.026557,149.684446,75.910894,-84.823818,-45.993291,6.132527,31.158715,13.844227,-10.268919,-28.483667,-115.673213,-203.605512,-219.57794,-170.769524,-124.399113,-60.969463,-57.446853,-112.198968,-132.194174,-40.926916,134.578713,185.567025,172.949864,116.869254,-26.089974,-57.740819,22.584286,153.461484,188.394068,242.803776,261.367338,237.395191,213.185552,156.090545,129.344524,128.643048,143.295714,150.235117,200.128494,206.411074,111.441528,55.263492,52.970048,158.445901,194.41619,174.93781,127.201711,40.472183,44.354823,84.936137,56.995875,-58.809207,-45.716485,10.115389,55.104673,10.505537,-85.158994,-72.196416,51.345906,118.88606,101.10194,58.419695,73.033156,158.879788,191.612166,168.719445,115.018916,-14.628252,-37.014038,0.715127,49.231212,38.699976,12.078369,3.590001,-13.079532,28.198963,45.759916,33.343393,36.823195,89.06651,116.354275,125.84923,101.413875,26.304232,-15.211011,13.931544,143.879678,174.125371,92.849519,32.868227,23.940658,153.475379,225.768877,311.959524,298.158829,172.700703,111.36755,59.774718,53.077713,70.364367,78.304682,46.26524,1.395209,27.052408,86.481885,59.312665,-58.876066,-43.153146,19.24703,170.709055,223.422795,195.226877,131.00175,-14.06121,-78.471157,-109.665857,-46.692232,-40.531734,-129.59392,-205.580618,-286.063649,-264.959432,-228.318322,-319.644324,-369.720436,-397.988751,-406.093711,-508.50133,-571.445435,-564.040729,-498.197921:-77.341791,-74.624071,-106.610113,-177.380905,-194.033731,-192.380392,-182.055012,-118.208793,-59.970004,-79.801521,-158.540044,-189.081717,-228.727294,-232.460482,-207.984235,-191.348203,-200.161421,-187.688734,-149.783017,-153.379914,-210.741965,-275.336449,-256.904184,-230.989526,-289.64933,-317.708307,-256.323997,-182.127391,-94.179012,-95.719178,-145.179266,-177.996823,-239.161764,-289.441688,-278.179965,-191.84135,-163.484407,-153.015843,-148.464388,-111.781671,-49.406375,-22.426896,-18.818479,-25.223009,29.129059,66.095642,60.077184,27.803228,-47.25714,-100.030067,-73.192998,8.829341,-14.348602,-118.877914,-136.154994,-148.318068,-139.228653,-115.899123,-81.108669,-70.65407,-52.018142,-42.024895,-42.254582,-66.375218,-144.968627,-131.798701,-79.076138,-20.623584,-21.130536,-18.948325,-22.741893,-6.721258,5.337287,-37.06371,-128.265089,-149.441663,-194.748775,-219.819793,-241.327793,-234.211722,-231.904036,-265.345739,-272.243537,-261.635136,-244.852779,-167.802473,-112.831958,-38.8266,-78.063694,-109.815902,-137.218674,-157.617734,-226.971028,-227.688627,-121.274211,-67.999654,-35.819461,-32.827769,-30.846511,-63.511611,-96.035071,-153.307159,-194.500385,-240.815913,-82.067984,17.40739,95.061071,74.974633,13.901013,14.717013,90.36044,137.822491,160.912085,59.23044,32.598843,66.402789,76.431602,43.131762,15.548817,43.989167,211.82283,263.333511,266.092936,260.132609,223.673953,163.563149,10.755446,-28.295242,-10.303432,19.42372,25.214204,22.393105,22.150845,34.343146,19.187906,-51.414409,-103.110414,-138.687961,-220.501275,-261.132047,-378.448432,-438.238004,-524.573753,-580.186547,-713.837312,-729.785804,-668.67478,-490.683467,-439.905345,-464.743283,-472.969817,-358.087133,-283.433273,-306.776571,-319.891637,-288.505847,-199.471624,-146.466651,-114.030069,-163.433525,-266.187371,-263.545689,-243.955998,-239.843894,-256.065647,-280.724998,-275.839135,-230.50345,-225.636509,-233.61589,-143.387176,-52.557053,38.804691,14.806851,-29.490354,-2.717909,93.016026,71.310019,37.81656,49.033377,51.957261,-17.29384,-27.875763,72.801059,106.58223,69.249355,20.113471,13.050612,-19.190353,-40.61506,-89.278443,-97.509275,-11.45366,108.201696,130.994582,115.305242,95.490791,59.923713,54.513495,84.050454,105.46519,102.087746,125.278613,158.096499,191.74706,154.239855,30.59084,18.557008,92.4302,85.68921,46.227581,-43.617823,-94.359793,-177.139404,-190.838027,-164.391222,-161.716787,-194.786133,-204.984283,-134.774933,37.306194,41.0102,-145.698206,-225.343732,-128.080993,111.038681,156.653305,81.058368,9.871811,-92.498005,-106.016955,-85.649472,-64.809305,-50.000189,-17.227031,-20.758385,-31.756269,-17.007495,1.939874,-5.648884,-22.199957,-51.063636,-78.17496,-161.465024,-180.148755,-107.838932,-82.796765,-157.22151,-176.538871,-110.489303,98.267724,191.264712,234.128993,163.339957,-78.835912,-160.427826,-98.279632,66.576008,105.267543,100.273491,82.729477,11.014162,-38.392828,-57.387851,-0.168053,16.027782,15.413957,-8.007213,-77.639962,-85.921525,-44.031337,-25.315183,-22.586322,-49.859158,-50.849827,-69.124448,-100.604053,-119.975014,-106.34225,-145.092356,-258.989558,-260.532931,-99.990665,-11.702609,34.868451,3.870866,-80.41756,-94.009815,-3.556751,197.345695,260.255219,149.964887,27.123695,-78.012063,-64.339341,-69.015627,2.035721,101.999243,289.849567,323.382641,275.210882,232.438748,132.777565,74.541321,16.473499,88.491244,128.913143,138.88144,142.606922,209.675164,218.774469,159.558916,135.554947,140.418744,161.595105,143.624018,25.805808,-6.99392,45.626471,66.228397,36.111654,102.804895,187.403432,279.521471,254.301174,183.554068,182.290603,232.557562,250.559651,238.343807,252.666017,300.636598,387.120276,364.13499,222.448942,170.428179,151.384349,198.382223,234.976667,235.025189,192.720481,108.327554,69.96207,34.114681,115.535265,157.576443,184.466502,182.50148,190.430581,215.279857,236.010354,193.709827,52.95859,-6.596416,26.083151,123.684308,131.836644,77.850388,53.571072,57.151416,146.523233,222.010027,359.562587,371.511207,280.564726,215.845109,135.039904,142.386032,172.278697,144.045002,141.855892,160.486854,167.949377,166.389636,140.520722,60.348229,56.770682,91.092972,213.232239,275.23955,261.629369,181.024106,-10.781838,-79.149002,-71.256314,104.408899,152.69539,31.053977,-79.30964,-193.942109,-184.15521,-106.425227,-76.342547,-91.23667,-88.500233,-72.440617,-138.004669,-215.889878,-302.461058,-286.266024:142.609865,192.992655,185.07241,50.663602,-55.566189,-154.54426,-126.953086,-39.925393,32.05415,58.508584,102.198504,109.732884,50.871938,11.782988,-24.588775,-31.205338,-52.836008,-125.807829,-161.664348,-109.931487,-34.060802,37.40247,14.671318,-13.547778,-6.665284,-18.352725,-20.181644,-29.266988,-108.501608,-122.962053,-74.268959,-66.728245,-68.968512,-14.777708,9.869716,7.584356,-24.026722,-60.74328,-58.520307,-96.55647,-73.15674,-19.355032,43.747623,31.047234,-7.422455,-16.628805,-111.230106,-186.123983,-222.610367,-235.390957,-274.609152,-256.930588,-203.840648,-168.655632,-200.416909,-228.698292,-121.546449,-50.091185,83.338544,115.55034,94.832542,90.605933,94.060238,67.919389,-13.963111,-0.379311,52.032032,64.670871,8.349653,-7.745793,67.237595,183.109065,101.481854,50.414316,37.138835,35.110353,-7.444649,-13.955069,1.963082,-0.558238,-17.123371,-57.125882,-103.558524,-217.143073,-241.147153,-210.674529,-202.030478,-210.974277,-145.128055,-112.616057,-153.953439,-210.75632,-303.574168,-316.33407,-257.20154,-194.733395,-68.792147,-35.536756,-46.562207,-86.365891,-120.501969,-199.660958,-221.822018,-161.386797,23.030664,114.403428,210.950145,199.972855,130.585463,115.205638,92.828658,69.351219,46.1844,48.801466,52.112731,25.502036,-32.165087,-157.50364,-153.571234,-7.603298,35.354196,-5.606927,2.171542,66.140703,156.467788,170.428252,187.133865,177.375336,137.509411,127.331378,101.694191,3.234534,-7.409719,75.735566,99.371516,44.23873,18.236909,33.776049,37.537554,26.062899,-2.924956,-38.602651,-126.489962,-145.893665,-172.306994,-259.746565,-287.43869,-243.133262,-202.0089,-195.731472,-227.10443,-245.942054,-158.950944,-109.316525,-61.323699,-75.006182,-135.394901,-142.31956,-124.719813,-133.372436,-133.259294,-65.185368,-59.049562,-149.196709,-177.028447,-72.754558,8.080591,88.618941,118.921104,146.378546,201.998204,218.93847,246.645507,246.301376,201.134944,180.897252,164.163014,74.930117,15.769765,-38.558269,-54.862268,-77.522786,-80.622834,-87.572748,-17.762346,54.469909,159.055552,162.006223,102.840712,68.951105,43.822437,53.609981,136.833222,232.939375,228.011271,155.863264,132.872283,158.756641,201.886593,281.566533,268.250598,247.176718,230.768585,221.709463,155.426508,116.793857,115.661448,149.500513,164.924498,31.104186,-45.78484,-134.383099,-148.38027,-123.916665,-94.909229,-56.733459,-73.356489,-78.769491,-40.378073,8.655888,131.086602,168.076889,168.686676,154.314933,155.227947,223.464463,269.187791,314.561615,298.95435,221.829653,185.491626,140.236084,105.194816,109.429173,172.856714,191.438477,170.50477,168.129594,204.331769,226.859289,264.820212,168.40813,64.310463,-118.374078,-157.818234,-129.69266,-117.137673,-173.07274,-134.282796,-31.162397,182.130385,206.707047,82.098699,9.149651,-68.504109,-87.85352,-40.718913,110.9699,162.098207,166.454878,146.622768,101.523684,56.0504,-27.062849,51.906534,102.526423,93.640807,65.820083,96.541492,135.778608,122.982733,83.816381,61.462347,97.646483,119.3425,90.055615,10.588657,-139.569518,-139.913012,-62.243793,-118.892911,-170.093511,-120.640722,-55.790601,-6.944,-9.481142,-59.691714,-111.108162,-166.553944,-48.788935,42.754668,83.055913,9.610173,-134.654485,-143.242112,-51.726293,77.323311,127.357015,209.669547,213.863459,97.06888,34.997257,-22.303194,-36.864994,6.164992,123.301007,155.451863,114.799807,58.774634,-48.578753,-83.787953,-71.034898,41.095855,78.390994,49.534863,0.307799,-77.859401,-72.563677,-5.735078,3.486291,-41.114538,-54.101418,-44.819308,-79.081258,-121.161817,-187.441383,-185.501833,-89.120521,29.856708,67.311528,87.203379,77.261472,50.255739,24.143717,-44.546105,-53.836489,-44.658176,-49.23304,-19.539377,28.292603,12.365825,-8.819308,9.092473,78.324099,150.652435,149.360537,33.724373,-40.814549,-69.333258,-18.909187,50.129822,33.14342,-2.305306,41.987271,80.052849,145.798914,142.864228,59.291847,30.135787,84.115581,195.143011,200.921696,137.572636,122.603861,121.051816,97.354759,-24.166485,-58.2036,82.930358,233.939962,208.792952,59.593759,20.982054,57.693973,86.788283,111.866578,71.104742,46.729727,89.221258,132.000739,137.644441,108.221719,70.388594,76.562517,129.402584,183.762554,173.475068,70.953296,5.150166,-128.2231,-191.740256,-260.60574,-263.5008,-271.808636,-281.472237,-281.785707,-312.494237,-327.984557,-295.441453,-248.642476:forward
-450.030851,-554.681166,-555.112935,-415.96749,-310.417083,-141.569347,-93.110716,-42.345852,-61.040486,-66.596219,-51.415718,-58.648223,-86.526624,-68.202417,54.652855,95.295881,21.590956,-28.905945,-7.494794,-20.761461,-59.546291,-109.525476,-100.198202,-17.368141,55.056158,45.267889,-59.63564,-97.665705,-32.202668,38.827316,147.624015,189.320485,219.004817,89.130969,-1.588769,-92.389195,-73.542813,8.12271,43.408471,95.566769,84.080582,67.962211,12.026872,-35.545571,-61.161314,-1.365188,175.457088,204.794712,91.615057,23.936825,30.680215,4.884795,-17.384846,0.663742,43.846282,131.262427,117.244405,53.890982,-139.080796,-212.42151,-241.845875,-238.802451,-252.951569,-243.910951,-147.884927,2.089364,31.702578,-22.558814,-46.445814,-53.627176,-62.633417,-74.652089,-51.947522,-39.641071,-19.524775,-20.578392,-60.59209,-97.497928,-145.823588,-118.9665,-15.799417,-34.839882,-99.796493,-193.179061,-172.871018,-53.63135,-7.702094,17.041568,77.503186,130.913257,161.169534,137.836571,106.497612,114.051829,170.011447,191.464926,171.884145,152.802726,141.774017,126.585431,170.062545,292.574339,305.467174,261.649058,224.528559,211.86139,195.873367,196.136541,232.06417,253.690988,241.729785,207.865246,127.337022,50.539369,-3.112416,-102.6544,-95.187629,40.063402,120.762288,216.281561,149.74717,82.23229,-1.77971,4.760925,52.431117,59.869005,117.036913,185.813057,302.701423,312.058391,262.1426,81.268636,5.121197,34.014749,123.297839,235.076697,167.940354,108.176301,-4.141528,-43.924784,-59.26214,-22.566189,131.472705,195.354147,162.102256,62.217066,74.072101,212.30672,283.969882,351.552974,384.416854,500.092986,547.027136,511.112662,376.258127,344.133624,420.903889,490.441791,600.060191,625.287158,584.132225,435.156859,353.11339,216.928397,183.641051,246.039883,319.454109,404.20474,391.692699,399.24378,397.284329,364.923694,307.785625,281.249191,192.480569,152.135329,104.945137,47.37403,-1.372001,-97.57107,-97.423201,53.869009,173.628705,345.468892,313.488459,253.53731,173.190992,190.377992,279.553493,285.49031,241.334213,247.184267,259.180585,177.551873,131.718416,67.262697,50.324409,57.203496,103.743086,239.026626,196.210842,83.344359,-191.621413,-289.566679,-319.413856,-264.626598,-115.361777,-70.805765,-117.247128,-162.176127,-138.523452,-117.856376,-124.003741,-106.086451,-76.96871,-7.039362,-31.316168,-59.530109,-93.282081,-119.841872,-126.80909,-63.169479,87.622034,93.687181,-25.130444,-89.858647,-73.793481,-27.881883,-15.042798,39.012081,109.691985,253.22036,142.390188,34.772726,-63.356077,-68.10456,-73.708505,-48.677578,68.254486,100.558926,31.441011,-75.56111,-88.547754,-46.985686,-32.029042,-53.695221,-61.508739,5.41751,152.831815,194.089767,109.705399,9.200224,-121.003119,-97.197826,18.652162,34.770249,-27.444825,-116.896664,-168.136171,-270.613427,-279.743436,-182.496896,-127.338685,-110.523643,-156.610603,-187.859416,-297.713552,-336.534892,-291.715462,-254.854771,-256.453825,-266.18034,-264.07564,-303.031782,-351.235842,-455.598655,-463.67165,-354.309685,-264.350162,-91.613204,-0.876944,18.760887,5.858024,-20.876494,-46.828982,-37.33149,11.389354,52.340884,147.865676,173.121007,157.959663,159.047151,194.244079,274.241625,298.997668,324.353873,260.980175,201.565967,79.557442,32.854823,36.998255,66.201462,103.436343,121.829474,121.697317,32.020316,-31.321339,-124.02268,-125.14458,-61.949369,-15.959418,88.110417,93.455848,50.349816,14.378391,47.18761,120.560513,116.343204,76.741792,93.437812,127.094666,17.880768,-43.209461,-32.808542,29.970509,149.571739,186.849434,207.685962,147.380913,90.899746,-78.873528,-162.176203,-212.045237,-176.324666,-58.964837,-17.436104,-45.866065,-190.362377,-270.042901,-320.580964,-254.566116,-47.98858,17.096066,31.551443,-49.610077,-90.947439,-103.47645,-77.513391,-9.028033,3.964425,-56.605692,-116.312699,-230.103126,-243.902537,-220.089234,-211.907046,-239.7086,-296.569059,-282.972335,-172.484443,-139.247868,-149.663929,-135.175595,-128.041368,-114.803033,-84.261127,-10.022986,8.472421,28.462718,76.372673,84.315,24.233434,-10.015636,-36.130319,-42.935913,-85.913795,-114.714787,-124.498135,-234.911975,-321.616803,-361.456921,-283.187461,-66.361553,13.029808,52.468855,17.293653,-3.585472,-37.973158,-13.245345,126.050131,194.04003,209.458437,52.965223,-12.660505,-58.857916,-62.870753,-6.079883,41.173664,77.248886,73.08583:-372.823531,-403.978995,-409.71101,-359.058375,-278.639081,-70.600601,14.12296,70.172137,14.531468,-2.27597,-19.326683,-25.599706,12.857062,63.770356,187.654718,203.562929,100.846002,53.033844,82.877142,141.554133,134.607606,47.091679,15.815799,52.687723,114.961337,124.455126,99.202239,68.784567,25.466044,47.170334,147.326991,173.824875,171.000253,123.17159,43.496543,-96.913463,-73.008089,90.621847,154.148448,181.082121,121.438106,76.046658,-36.359742,-73.514618,-28.81144,49.770518,211.275687,224.722772,123.032043,99.978624,121.121337,125.445652,116.674875,129.080553,163.705006,223.466572,130.876448,60.508266,-16.36525,-29.905765,-61.093011,-72.114815,-49.697741,-36.155495,-76.339048,-167.40065,-187.758993,-112.394927,-25.517624,149.623604,188.149289,79.562075,-56.480494,-28.758171,116.676852,146.255209,97.434287,65.731289,41.741789,35.119313,-5.642106,-30.441691,-33.36465,-83.761857,-108.310296,-32.628651,53.25721,179.10373,228.121782,247.072331,224.600898,195.612359,201.594907,231.188734,299.878302,320.218511,279.100404,174.498658,124.545479,98.215483,135.723807,219.295896,234.309826,222.815272,145.722352,100.769355,78.059428,100.096162,184.368934,241.147532,344.046652,333.553997,153.483533,39.272074,32.250983,20.442955,29.739158,100.050202,150.029794,204.280165,99.893085,36.214305,-47.050389,-74.287231,-32.133823,48.437334,208.930388,218.971744,73.615755,-67.533628,-92.257378,-111.628216,-120.987583,-110.966176,-79.245062,9.49876,11.695851,-32.599023,-128.027665,-141.675638,-96.009147,-48.046714,57.578405,79.032792,3.367293,-144.979201,-184.483904,-108.903704,-17.126019,154.205314,212.129189,266.041602,257.354629,213.390197,73.678039,63.529409,244.176145,357.296518,449.602143,421.62159,287.349518,171.250922,141.350818,135.739129,149.854316,181.540921,190.586006,181.535685,191.332583,209.717661,162.409671,100.123844,18.064842,0.034851,-18.013891,-35.050033,-125.094482,-208.973189,-214.202288,-137.800541,-71.221754,94.369646,181.630189,219.565684,31.085259,-53.041126,-62.981793,3.295012,141.58889,153.628956,96.139053,77.080448,63.151629,-37.560794,-97.783444,-88.505335,-39.890063,15.06674,38.086066,85.262502,-6.493897,-101.939598,-278.354846,-310.543847,-256.863484,-209.541028,-121.323499,-108.040295,-172.884128,-191.816355,-168.335016,-138.539555,-135.638386,-133.655174,-121.067393,-60.411253,-79.763462,-137.404009,-190.187319,-158.763732,-85.267064,-57.083882,10.182444,29.085886,22.995575,46.672011,60.843551,89.720229,118.96322,172.856098,191.389212,202.009224,134.826716,78.914677,-50.371724,-104.98701,-145.51896,-121.436442,-13.571096,19.903983,-33.624449,-168.256801,-222.027601,-228.301839,-193.392667,-133.460216,-106.025227,-31.565438,27.525647,47.206976,16.99633,-43.930578,-147.383951,-132.743338,-42.297826,-51.707929,-162.939653,-168.164764,-149.436117,-117.226114,-77.349783,0.162209,5.132443,-13.887654,-22.124148,-40.549765,-113.86496,-127.931055,-58.184561,-24.848644,-62.249396,-94.516815,-102.100514,-139.550665,-206.267968,-368.026109,-406.744821,-324.494423,-212.292158,-9.876652,-21.959975,-76.383091,-148.928837,-143.182128,-63.102393,-21.529184,28.917274,59.55478,145.442006,184.04115,166.9841,136.115139,164.794561,273.414839,311.243938,305.948608,238.414542,208.976195,148.305639,123.284474,137.998234,172.86661,237.314896,242.000646,155.440196,15.927992,-35.206415,-47.35374,4.609386,145.242538,184.136936,186.044548,163.427824,176.68323,243.098443,247.674353,155.561321,103.663186,98.757158,141.183012,201.012025,138.126812,64.104634,-66.067189,-52.352811,104.99761,160.711724,117.646185,-36.870089,-95.92262,-129.981133,-116.037835,-38.781558,12.27235,57.841947,11.554355,-167.781347,-211.352682,-200.19449,-251.089578,-272.014581,-176.861899,-85.538414,7.728329,-83.743669,-115.107738,-76.969207,-39.067588,43.946401,55.013187,-21.327329,-62.568226,-118.309644,-169.797387,-170.680591,-123.98591,-133.276011,-207.769371,-162.493571,78.044664,78.539063,-16.103827,-125.514255,-114.021213,-18.406019,45.956839,101.824182,60.98287,-46.314995,6.288328,52.700753,42.09913,9.82119,3.013882,29.735243,80.753557,11.330665,-67.973735,-199.04799,-223.937717,-191.219599,-135.083244,5.181706,43.530156,42.726109,30.33751,36.402043,132.710778,215.259398,291.832008,256.791819,136.66937,30.624557,-11.474757,-75.837511,-94.271621,-36.416274,40.919422,180.00411,194.637459:-363.205861,-400.382167,-417.563492,-301.292294,-177.737604,24.5908,71.870728,71.897974,48.392466,50.566074,29.625587,20.393299,60.771532,100.331602,205.419428,245.91689,235.921941,208.780935,204.99663,179.995408,176.514898,202.446495,214.411798,185.581627,61.307323,-12.745616,-85.428071,-60.786617,54.321406,121.235541,240.343191,253.937092,141.760792,-6.801333,-48.634459,-64.47212,-43.707372,26.6929,64.312695,94.742699,18.70769,-31.268765,-79.644085,-74.974332,-33.615743,-6.679532,79.430416,126.609219,126.335372,51.316525,32.684033,27.055726,37.818138,108.480335,157.249785,193.548187,96.604826,30.419051,-64.271827,-85.06668,-87.550367,-65.881225,13.627322,23.12128,-61.503015,-102.759604,-73.032097,46.81733,107.715586,148.854968,142.509147,130.383592,146.15966,180.370035,206.963721,164.073163,49.997274,34.031527,72.130651,63.328508,-28.405377,-23.039094,8.892205,42.018247,44.828955,54.809394,77.380867,134.929002,164.968116,167.784738,150.513758,164.414645,257.74557,295.530925,311.768147,283.717246,193.373065,162.121718,148.532659,103.224054,107.409301,221.651788,302.683818,350.490627,151.750713,42.175942,-39.896476,-20.247447,65.385154,105.322063,142.767004,124.673453,28.341292,-12.537813,-13.876972,-86.280305,-156.707208,-235.370896,-195.472545,-26.592313,-3.478508,-63.438907,-167.787736,-183.331871,-169.590768,-114.944082,88.125303,141.11964,16.350694,-178.658818,-201.040712,-126.041402,-98.799552,-100.493102,-95.255414,-60.259586,-51.669904,-66.440027,-125.95276,-158.023274,-195.046654,-169.989265,-15.740166,46.537726,-5.716548,-156.450797,-199.049994,-174.573995,-108.23557,77.131055,160.028021,215.579946,149.558768,113.8439,67.174861,74.422025,160.192623,214.107324,271.855035,264.725943,225.441444,174.419486,151.130434,169.519348,190.088313,155.736335,116.962011,80.626,85.538782,76.912423,-19.959526,-79.790931,-121.222798,-106.937378,-37.591498,-19.186939,-106.15723,-239.058031,-259.650587,-182.094413,-104.081821,64.917624,134.45005,145.596434,20.377601,-13.897946,-9.711553,9.425281,70.440059,98.200502,94.207993,58.556125,-17.823355,-83.754353,-115.072972,-82.738157,-29.508412,6.030304,-18.233864,-61.851479,-89.177666,-138.390258,-278.289229,-288.76953,-147.264869,-82.431001,-61.987711,-74.245635,-125.950339,-228.588861,-281.371292,-317.697227,-284.174661,-167.422979,-121.152886,-94.59561,-161.893122,-214.843191,-263.140294,-222.490327,-62.884226,-9.157246,10.667222,15.360478,45.470469,111.971921,156.541665,223.459654,236.751933,219.252886,208.456098,203.725054,128.931407,66.47754,-63.480272,-129.05962,-211.273722,-184.79244,-37.349648,4.921535,-59.325539,-178.929447,-208.963723,-227.605102,-225.495408,-191.638201,-169.598602,-147.249294,-122.571237,-106.200775,-163.455084,-221.164693,-204.775882,-122.467081,14.290855,18.430814,-72.810166,-189.497427,-217.633366,-154.784291,-99.021165,-62.132574,-54.442747,11.20598,34.78008,12.929831,-21.065356,3.318148,107.228861,135.465911,78.758032,13.430784,-74.517161,-86.610089,-109.151604,-192.92422,-225.088613,-193.432692,-134.802501,-49.905436,-51.616378,-76.550575,-135.224803,-114.594883,39.952925,99.391897,115.04355,112.509344,111.699345,54.677113,27.382359,40.209407,77.218737,175.797285,215.473755,232.49986,210.917826,194.794063,147.881863,141.85493,188.676967,231.099854,290.073627,270.638496,143.175773,-10.101204,-63.588567,-60.525183,-10.169627,99.71454,143.342839,235.025196,231.316426,170.30736,72.916449,92.379068,185.909374,198.481414,212.719766,242.014678,220.389415,47.955188,-36.428818,-101.573103,-74.246056,19.424232,45.577025,35.683232,20.771433,21.578117,-38.961232,-82.021002,-58.880439,-7.635777,53.526257,36.855942,-100.386966,-231.845247,-263.881589,-266.604986,-213.166736,-27.595982,32.890316,-5.051198,-94.729204,-104.415399,-104.662021,-95.788499,-13.601973,26.97032,5.339053,-42.192351,-117.248112,-148.134747,-155.28437,-116.994553,-88.163321,-51.507947,-15.637857,29.596514,-5.875111,7.577225,81.682041,105.955872,146.063509,178.095032,223.420189,207.150005,114.664566,36.621929,34.449285,119.715368,163.60125,163.167698,154.01208,183.738855,169.762309,124.973957,-14.668807,-76.853272,-72.572932,3.404561,185.850694,223.547893,178.898858,148.768537,157.629155,206.322842,257.997136,415.833871,471.665956,370.319311,65.762266,-30.481135,-6.065512,53.195967,85.945353,57.674961,55.259142,80.760363:-323.096337,-351.576992,-380.411541,-380.935999,-305.579478,-71.617629,27.538897,118.410919,106.842924,99.994804,86.40085,69.862179,48.772638,64.511539,148.887805,180.308127,168.866906,168.216353,180.103474,185.015972,181.945505,146.322678,116.082161,56.190328,-50.17551,-90.695999,-71.654452,-34.081498,50.561296,89.960045,136.794152,140.942223,137.846519,123.411984,80.827921,-5.519997,-0.917816,72.058093,112.902894,153.433979,89.479099,37.766597,-38.202602,-41.254906,39.131188,104.739572,202.058255,193.043964,72.374447,5.445004,3.703412,-21.181558,-42.935536,-4.2178,85.481378,275.822512,217.250132,106.911106,-89.489044,-139.269305,-180.442618,-185.538637,-126.4184,-70.978611,-4.986237,-31.310006,-53.200039,-21.980876,31.314293,77.09116,57.779768,32.713055,56.887342,61.11949,17.286109,-6.712655,-22.39819,-34.046139,-35.777955,-6.329359,22.936964,-60.995939,-107.743422,-156.359358,-150.243443,-56.681065,5.520462,53.050884,63.133062,90.084248,104.372078,92.830059,112.138658,138.152624,186.804772,189.838513,162.125967,196.300029,209.518753,174.059798,167.703465,240.228225,290.310181,292.621853,193.112945,162.873867,101.09539,62.059697,58.009772,83.755293,127.579652,134.703392,64.694604,-65.46462,-108.722822,-152.028562,-169.032935,-157.083066,-89.952199,108.64292,148.775119,92.641027,-73.390588,-135.650756,-85.444201,19.912942,202.100279,219.410434,140.622721,99.414587,92.999844,36.419185,8.953945,15.139734,46.050139,128.045727,102.738189,18.348705,-144.274527,-140.540085,-19.878962,32.883356,149.896347,209.449901,195.686699,72.70551,39.232374,90.125926,158.317649,274.437067,318.923942,406.296384,393.349145,352.605111,297.593706,305.964006,397.850321,457.598093,512.189875,498.441087,431.102763,345.577752,312.692275,278.43698,270.435048,287.860367,318.688972,371.259695,360.546875,340.091286,251.394327,204.83438,197.197636,219.759315,234.494716,197.998452,33.588372,-71.437512,-91.905635,-150.012998,-140.692884,54.331613,180.146325,274.587878,181.394193,145.292783,150.254717,170.407839,193.700469,194.79418,199.897167,193.495086,109.103621,-25.121135,-69.459406,-84.332286,-69.739897,-24.115206,30.593116,173.470549,113.605423,2.632183,-211.875473,-276.158044,-280.692561,-240.728877,-149.732185,-112.508325,-104.655407,-141.527096,-143.278671,-132.046593,-115.057299,-35.747029,2.578512,-9.417749,-117.106114,-162.880526,-218.263307,-230.615176,-157.895012,-57.090909,158.095062,190.932452,42.914332,-108.854057,-116.489326,-62.801232,-24.670734,41.924268,74.278794,130.05222,77.919723,27.026575,-36.241771,-68.969848,-161.311136,-169.582912,-59.52559,-3.495374,-27.602091,-119.565474,-137.924651,-153.479197,-167.357768,-192.964207,-186.606804,-146.768805,-111.600489,-89.095709,-105.337176,-153.99038,-207.001195,-182.497685,-101.537139,-87.58263,-149.415785,-249.689204,-303.764376,-363.734804,-316.213474,-138.750301,-104.507913,-188.947051,-217.653744,-165.58285,-59.590899,-42.511259,-58.967232,-74.035949,-69.622766,-58.738254,-103.444168,-204.333774,-259.463808,-368.148541,-369.904615,-222.971151,-124.634317,-24.141822,-78.255545,-100.932793,-84.159089,-63.467795,0.369575,34.138002,71.631429,87.89659,134.186928,155.214487,146.032466,139.761984,160.83324,231.369881,269.13136,309.215395,256.879101,218.471223,173.672684,167.234284,152.733227,134.012246,107.510161,117.425651,108.500321,-24.03576,-103.998438,-183.183507,-170.059562,-115.831602,-92.100371,-4.312167,59.083009,44.382292,-14.064241,-34.133686,-53.287058,-44.852502,53.512539,122.228134,131.305764,-20.008237,-91.157168,-123.678702,-70.099711,71.328322,95.929589,19.875558,-50.623765,-41.558717,-66.170326,-121.418967,-158.805105,-123.456537,-39.718518,-26.021362,-96.65438,-190.446541,-232.217748,-333.014904,-348.129145,-268.294053,-213.19094,-144.158404,-169.588626,-198.653102,-243.658707,-249.075126,-182.793018,-138.89162,-136.946121,-170.465504,-252.852737,-320.751567,-334.348422,-322.754,-307.469616,-247.214521,-185.54108,-69.77497,-96.41685,-113.054001,-72.260532,-47.077552,11.121216,54.404823,110.152636,106.882951,73.407437,66.044486,56.262826,28.0371,40.563966,86.058719,88.581109,51.535373,-15.86485,-50.031781,-108.87772,-137.396875,-171.630601,-152.605623,-24.362525,61.680286,176.858648,131.062877,80.314477,56.36723,84.21176,134.705179,154.43748,164.98061,35.434312,-35.707201,-58.223313,-32.424478,34.371081,67.879192,71.49064,39.664561:-196.757985,-273.26131,-310.44226,-280.764346,-209.156603,-6.640085,101.245376,200.844078,108.423025,52.423654,-11.361299,-16.60636,55.060956,132.334467,279.321442,291.134396,198.563234,130.643616,124.806416,140.321378,145.080432,125.633986,110.57494,50.8094,-85.610727,-147.451842,-182.677785,-155.622639,-48.787692,7.141326,85.531963,115.524752,147.523853,57.790638,-30.380033,-141.194009,-118.396954,5.569193,46.986897,24.039038,-64.693027,-97.891283,-154.664464,-163.974177,-69.274468,6.637411,90.955091,84.040591,6.155936,-64.625105,-82.987616,-67.608838,-28.008807,99.993178,175.334727,224.772866,94.865486,18.846942,-69.439302,-73.743582,-58.774814,-43.830518,35.731633,66.172349,31.195107,-34.890718,-36.016301,44.287385,92.866725,119.479221,124.645719,167.9588,141.66539,101.057428,68.180799,84.947347,109.315747,102.997108,110.329496,125.576603,96.345197,-31.517462,-88.121658,-91.326657,-45.756974,23.733368,31.097481,36.561195,71.236725,94.13282,93.318834,95.07587,214.419045,304.838687,384.546254,341.811069,205.914287,181.785164,184.841035,212.814573,258.14006,357.622937,398.411682,421.843968,267.267178,144.257111,-28.778449,-38.458904,16.034463,45.817744,113.431793,108.927283,-37.594225,-179.028821,-225.482223,-301.213937,-320.059739,-273.933725,-207.109869,-65.737952,-28.935036,-72.448077,-242.316697,-288.223388,-185.53562,-74.194217,112.794348,125.947993,-19.838293,-177.760504,-205.727526,-155.58945,-106.057017,-40.206389,-31.874736,-38.60913,-90.71708,-149.519423,-274.373863,-273.19231,-113.278527,-18.256998,94.549238,87.85496,-40.441362,-96.25112,-73.775073,-20.302252,5.397854,106.968001,186.005659,285.967145,187.486052,107.571527,63.676605,117.833924,260.457674,306.56036,348.378824,341.730119,226.861453,34.996222,-19.416862,13.815364,67.085816,171.674055,214.491154,237.185424,139.288852,56.274114,-108.730286,-141.108474,-91.944297,-56.830649,-35.127754,-60.399627,-150.388235,-188.128069,-191.028009,-175.99437,-139.78347,-15.713593,51.882638,107.201405,25.880116,-14.884926,-15.905926,21.594759,102.987671,129.708262,178.013999,183.260041,112.780076,14.169959,-26.546662,-76.100679,-65.593799,66.688396,158.472233,248.596829,166.416458,59.206746,-188.274909,-231.118728,-94.543904,-8.290793,30.058861,-8.629046,-112.414298,-170.940421,-192.404892,-175.483365,-107.613129,78.605319,139.346135,95.000973,-100.670115,-153.698011,-129.641155,-93.634434,16.304897,91.711299,201.609298,197.689784,94.156974,26.913454,37.989677,102.869532,120.448877,139.226009,182.331236,286.397077,243.291344,167.629554,31.294858,6.88847,7.525369,8.592295,49.302843,74.216035,0.273534,-134.196413,-164.385118,-228.629866,-265.146872,-210.21551,-118.039727,-8.319653,-61.578466,-90.877226,-182.14646,-247.654695,-272.691721,-197.401443,6.656913,48.348673,-36.488349,-191.719276,-244.598612,-223.057118,-157.783547,-56.443058,-36.849321,2.761039,25.740058,35.891828,107.215337,161.65655,228.823706,228.891507,207.107295,187.052324,104.422157,0.554985,-56.937934,-134.511667,-108.973522,48.263299,118.594991,140.010688,34.09798,-22.208713,-75.539503,-35.868065,159.498719,235.603867,272.620599,265.248402,232.900685,173.280614,141.370585,110.606752,129.542658,235.987517,296.352379,324.256269,237.271978,213.613825,212.329376,215.70675,220.299499,221.887267,251.040421,266.985178,219.916709,40.073285,-55.072101,-96.07428,-39.117569,56.670075,60.706405,84.730283,121.92272,88.70096,-14.760243,-16.560908,62.710731,95.01727,153.671855,186.675133,179.856216,45.898299,-43.087305,-103.02703,-36.701295,116.531526,137.494596,112.346749,65.896988,29.548064,-49.870682,-66.273698,-34.988958,-11.351596,54.172816,92.972834,51.160002,-132.026836,-215.195905,-280.706081,-234.99789,-65.471248,3.208607,54.242801,-41.15678,-109.517753,-210.652802,-231.12253,-145.577466,-57.217095,7.658013,-48.124932,-175.184797,-198.965722,-196.028531,-177.035474,-176.388528,-184.882236,-149.814738,-45.099878,-10.469993,17.725622,67.817071,52.488274,23.881358,57.521382,175.332928,205.18018,135.668279,-5.231034,-56.933012,-60.755722,-1.933801,117.604806,135.264132,120.408725,61.423244,7.411091,-118.355546,-160.36933,-137.287543,-74.842229,75.195291,118.165637,58.782151,-64.200913,-73.880346,0.492974,54.704009,175.985425,228.347204,175.26159,-121.003298,-246.808776,-254.684172,-168.375408,-36.472481,-27.410669,-62.649792,-96.645035:-189.364802,-283.459071,-304.50048,-313.929338,-285.43649,-106.727167,3.774802,85.349496,17.711254,4.760961,22.439495,21.541031,20.210256,45.31799,141.368942,181.440761,194.697276,171.164093,156.53241,108.283951,80.021186,55.446032,100.36218,232.773977,80.333464,-64.05405,-178.56102,-139.002881,5.899227,72.678564,141.126104,152.274576,159.429321,128.763695,94.848367,26.560466,21.488775,90.140285,125.622232,88.125506,-29.84414,-61.492553,-79.217495,-69.113531,7.790597,47.985555,64.845448,35.636023,-65.481938,-89.169099,-71.874722,-68.65265,-71.437924,-24.004297,21.537139,73.096337,2.006438,-52.601712,-177.974346,-240.405412,-277.888591,-264.165827,-252.883192,-237.560686,-156.321396,-119.337102,-134.309035,-137.732309,-114.811618,-113.831329,-142.105843,-199.214417,-221.369944,-198.007437,-115.011031,-96.495116,-111.569421,-115.421512,-84.854152,-64.835089,-62.759969,-103.922457,-120.996139,-119.374603,-90.419524,-9.30096,2.22608,-36.194304,-13.67746,19.643836,25.571237,17.570248,84.264676,138.076758,182.522711,183.014191,229.505324,300.682123,289.914859,269.933906,331.638184,454.512393,441.311738,361.529086,271.827984,212.472588,108.003094,75.001514,53.409412,49.211549,53.165626,66.964482,25.659143,-109.33962,-163.473948,-170.902496,-121.09973,-27.864076,-10.632468,20.621473,32.430333,21.034335,-1.275782,-2.462443,-19.443316,-44.1368,14.117117,115.196167,257.064892,217.172778,156.854033,48.780507,38.240355,88.582382,142.996252,273.311187,198.390658,68.933702,-125.106329,-128.449214,-44.721697,-3.974763,108.785794,174.257716,205.323596,168.128874,172.246831,236.809296,284.148512,314.505053,298.689856,327.327216,428.944427,443.716523,381.090848,352.401096,390.437962,456.100223,592.575185,611.688499,493.683688,291.313478,220.522303,167.263691,186.374629,253.16426,273.093164,319.01771,334.689784,318.94949,285.92266,268.491401,256.665792,268.486762,243.793709,181.855506,35.057617,-34.549329,-70.16073,-157.420474,-149.636246,16.674003,122.487836,206.417391,109.743592,60.692013,41.97428,73.916695,160.557649,173.559359,122.674445,92.736528,64.63118,64.983055,40.613616,-100.870229,-163.473691,-112.571905,-3.015686,195.300786,91.960944,-42.233855,-251.82796,-302.662103,-280.898769,-211.82569,-67.334428,-52.280433,-144.924416,-149.398657,-87.443978,-2.996493,23.178553,139.710224,196.484688,195.894122,83.31104,47.272401,54.047975,65.437229,99.811419,122.578899,140.251871,148.394724,160.199346,97.468455,42.093556,-2.665686,35.775979,106.9196,109.215781,112.822029,75.06689,41.159351,6.868047,0.399164,-22.23998,-32.366314,-4.575815,21.778131,-2.515936,-111.536871,-149.290047,-169.94681,-165.767443,-115.751307,-70.179735,4.39468,43.162486,61.14363,45.679492,7.667658,-53.353178,-63.282521,-80.930264,-101.956554,-172.966522,-249.395077,-294.564137,-418.225261,-461.880923,-440.814171,-389.159095,-261.026936,-187.215107,-177.260619,-153.998558,-140.720232,-131.186429,-132.274296,-149.708311,-162.596424,-178.290578,-175.649645,-196.931164,-310.629681,-350.82789,-301.692055,-224.389991,-74.900901,-45.366519,-42.416674,-12.111346,-8.960251,-11.271804,17.869492,139.713538,191.989328,186.173931,154.356724,174.109172,217.254354,226.40318,257.68653,290.457632,333.435917,234.367009,149.032401,45.07597,62.66052,131.225017,101.960769,5.225727,18.522243,93.758408,60.606024,-9.533342,-166.85509,-196.435,-159.031203,-124.80471,-56.020712,-17.097525,-19.399653,-66.199617,-80.910825,4.974987,83.260706,202.605632,221.400896,136.361974,15.525742,-7.867156,3.888098,29.989126,114.767061,162.466987,190.547517,130.4443,109.964518,51.827462,-18.307872,-145.339646,-135.548247,35.580936,125.053679,160.861168,56.234593,-34.873426,-239.931117,-273.573996,-130.619607,-15.929692,103.139207,-45.605136,-144.048013,-184.131335,-145.065297,-84.020953,-78.341157,-103.645313,-131.537194,-193.089169,-219.166383,-224.2497,-236.064455,-244.341934,-274.350095,-264.760759,-139.112865,-56.121526,-71.403103,-97.24888,-66.204328,76.056888,133.959811,147.817957,131.584912,68.00065,52.50838,101.170658,172.012168,169.408538,163.573192,158.146195,111.214651,74.107617,45.734518,-100.597061,-193.457528,-262.050215,-203.55311,-10.177471,49.404674,35.948119,-30.090544,-43.737809,-13.048255,22.449849,86.232159,104.395863,108.442102,34.83139,-23.027105,-100.563653,-88.984068,-10.354739,-6.808865,-47.640664,-38.251749:-204.503243,-228.201201,-244.815186,-298.211783,-286.658466,-123.8022,-10.549905,100.759971,14.457872,-29.56829,-42.712759,-34.987801,-6.711107,29.976216,159.924192,211.697461,195.565841,130.989401,102.46265,51.866932,48.855821,94.730542,120.402589,53.182458,-134.874322,-206.560042,-282.639592,-261.729488,-54.502222,77.420969,220.244917,206.364638,94.240733,-1.033974,-40.132654,-51.27507,-1.482233,126.93576,147.765257,60.85945,-35.318447,-59.169827,-109.006946,-107.598026,-0.18522,61.783165,98.373855,72.878233,-20.629912,-85.469814,-96.048113,-85.771474,-75.699331,4.408416,99.591782,240.552051,152.141675,74.528913,-69.265259,-131.192316,-172.032253,-131.511874,6.42765,42.153432,1.077757,-44.173145,-31.089853,37.173665,61.865153,40.543078,25.821463,77.085439,95.279208,50.354516,-28.696216,-16.143517,102.242549,172.833163,242.17554,221.0575,124.804218,60.629216,24.262972,-73.92053,-89.458963,24.023261,115.851247,190.969461,102.641118,69.590263,47.11901,42.737462,116.347869,190.779862,283.639978,275.317151,239.673886,283.419845,307.48222,367.5579,416.302537,458.828319,423.411359,283.646691,137.317958,77.860953,6.958422,3.016218,55.837483,90.172364,99.768147,61.425958,-33.257898,-111.918394,-190.928374,-327.546316,-310.59733,-187.90387,-145.219858,-106.16229,-120.58744,-143.447613,-186.287615,-197.088995,-157.97857,-95.420709,54.709788,87.296114,24.381852,-87.927151,-130.288601,-156.568883,-139.878438,-57.32231,8.611414,101.337167,-0.226992,-101.950907,-262.956344,-272.488791,-147.182829,-62.096246,83.406937,126.022734,114.946779,49.378123,7.909821,-12.176507,38.31483,140.245897,153.989755,166.454989,187.327227,177.037591,114.551077,103.632464,206.938664,311.188286,460.653952,433.894156,237.917806,77.752236,18.638684,-59.396769,-41.09633,102.064408,170.904001,183.644399,46.869855,-26.164266,-107.835191,-98.060313,36.603453,107.41859,64.561362,-39.90342,-191.143438,-205.54002,-233.819593,-305.711889,-273.841609,-76.300891,27.267407,129.774898,30.915957,-44.880972,-84.997842,-32.42041,137.05905,214.291559,320.307396,325.734347,166.991354,-64.198668,-131.500604,-163.210126,-146.051479,-30.431156,80.635002,264.176175,169.855962,40.32824,-205.062545,-261.297988,-199.53842,-120.681107,-3.773046,7.917901,-42.055226,-72.500985,-65.50569,-41.372103,3.964632,213.736221,322.200662,320.008539,78.956848,4.230599,-3.718686,5.148348,45.379147,100.60913,213.362489,219.708605,94.564062,-39.610665,-64.420877,-65.941392,-40.080151,61.246283,120.09308,192.63631,101.805134,11.142275,-92.800182,-73.225975,9.939469,34.176624,71.863235,73.845512,-21.020097,-151.618067,-184.481085,-213.903289,-229.040415,-231.12301,-198.56273,-111.065337,-99.986857,-119.139466,-170.046845,-178.13929,-122.903577,-84.218889,-39.670481,-39.791942,-82.391133,-190.472052,-282.844505,-400.566912,-362.27968,-177.593476,-89.744323,14.228355,8.667247,-15.461432,-35.106553,0.681681,122.109124,159.840007,180.723194,166.466418,67.748643,-37.780438,-92.827633,-176.608865,-140.995583,40.440081,108.479472,140.290279,61.026199,18.297185,2.2813,11.204476,39.697494,78.161536,207.528797,258.830901,217.883945,89.614807,70.135611,145.454903,205.636607,292.89453,326.72547,363.939897,300.232695,259.508231,201.861965,186.638154,203.466073,224.093178,237.430052,219.30555,113.170943,10.228564,-0.919668,-30.925449,-52.389412,-22.424526,26.146757,87.593244,41.159185,20.510646,27.240233,43.311851,87.608109,117.128808,224.681434,275.24407,239.654617,97.903738,47.427429,52.400727,114.250983,261.628866,306.239081,315.744916,221.611895,149.420017,-4.290171,-50.752985,-24.410532,13.169592,101.865867,163.966632,210.413177,44.510421,-76.948947,-233.630736,-220.293639,-46.234416,47.123425,63.83129,-126.909407,-195.715265,-229.395513,-226.45969,-163.315039,-106.648925,-42.305044,-59.658688,-165.463623,-243.223661,-242.568939,-195.077112,-170.452747,-146.835442,-128.629202,-58.152936,-30.788902,-23.717174,2.102255,0.206452,13.697537,66.324189,190.704601,199.410507,105.995732,58.482622,61.731955,64.128618,87.402337,169.075791,183.171596,115.566675,-19.56481,-75.524544,-131.656484,-136.908634,-92.436589,-50.615565,17.773962,28.979578,-12.620337,-92.7122,-114.370035,-87.147786,-46.840413,71.021346,130.581419,117.831874,-81.329901,-150.748128,-149.284275,-123.705232,-79.927609,-52.180077,-3.729018,-22.93948:124.985332,-10.562043,-81.881035,-174.479743,-158.017099,4.337684,86.430268,122.442907,41.504262,22.582736,36.368648,36.989345,44.323687,76.179453,230.670769,325.31686,368.976949,288.002836,281.326237,293.931844,283.057748,246.888118,241.889657,259.739537,271.646152,263.41252,222.473517,219.507082,295.086238,349.162001,417.625233,417.905916,371.17154,294.017847,231.22172,129.10787,133.87707,164.30297,137.478043,48.938784,41.729325,72.200466,91.231735,68.039447,39.067585,39.887948,50.910395,54.894441,31.884019,-0.29232,-0.430026,9.757862,3.676282,-23.205887,-21.197706,19.080314,1.457852,-31.344319,-122.735705,-173.877189,-237.599188,-258.838904,-305.17005,-296.537535,-195.102033,-102.489646,-78.985345,-59.950409,-47.217829,-42.982977,-88.512409,-223.972462,-240.076169,-208.51114,-156.948888,-141.980273,-136.388837,-156.75573,-165.544443,-118.483828,-26.343441,-71.676985,-96.221527,-58.077767,-26.889033,-21.811192,-42.136453,-90.621838,-75.813503,-22.288616,55.285335,46.641631,32.790516,52.752586,103.459278,110.770494,116.420404,233.027374,291.420207,291.128434,281.779128,360.144292,410.943452,399.988841,254.744776,195.22682,154.417759,136.924139,59.216927,19.397895,-25.548203,-49.855572,-141.223008,-143.568671,-105.299598,-102.321112,-139.304611,-167.552547,-122.30692,22.47499,26.871311,-7.830574,-30.077792,-23.942916,-21.469986,-34.946091,-60.725102,-38.286343,79.936465,159.595053,139.893668,65.253824,80.591374,201.695723,236.668833,161.639165,-8.034481,-75.461432,-136.355678,-128.578932,-56.244769,-0.587693,134.940814,180.689002,146.523276,79.170567,93.80517,161.636971,171.651648,122.968162,102.593675,196.325088,344.821067,338.434294,223.208888,205.884565,305.829579,366.08389,399.248336,366.674201,257.343053,184.445759,159.726706,109.334739,94.808586,62.271423,38.485654,43.73345,51.281352,22.53602,-25.173935,-7.34364,122.596013,185.603063,180.239342,122.728978,-8.563731,-57.582877,-63.871964,-120.545721,-129.375131,-36.897781,16.05698,47.669476,23.322448,15.975454,-9.602501,-44.103158,-83.0804,-72.229914,-50.43548,-42.679999,-48.361722,-88.078958,-111.058418,-194.315123,-239.728096,-224.950524,-141.98495,24.118752,-64.808961,-162.190142,-280.747195,-288.097195,-176.789082,-87.801197,-24.621821,-50.282841,-74.699993,-12.448837,46.160822,166.277232,196.756576,189.492356,180.064638,188.399963,166.622262,137.703472,91.61696,86.365231,139.423542,184.446208,240.647084,243.682188,192.621094,116.686301,83.746698,38.127624,48.975938,122.869973,147.829365,123.302455,61.628327,57.062167,56.631902,25.475632,-75.408702,-108.974207,-64.744582,-7.45825,27.367026,-59.668847,-85.180751,-71.404358,-56.927486,-1.057307,49.244261,143.147795,136.176215,113.555621,104.527879,113.066899,128.054752,134.842795,157.6449,163.538518,138.133402,66.007476,-11.975595,-193.82643,-217.10967,-104.941019,-48.120872,-44.224154,-76.977126,-70.365695,-59.463857,-68.54255,-100.680555,-119.542483,-133.712105,-108.530032,-0.964673,73.062323,71.181068,13.233698,-17.431679,-43.085154,-33.798086,28.794143,27.76924,-5.263994,-52.114794,-64.323244,-32.975989,20.128805,130.309946,160.298589,153.134001,111.118088,115.000065,158.17513,171.745027,165.401582,145.163537,68.572248,-30.34173,-72.11598,-134.188354,-142.660264,-105.164458,-86.156114,-94.814747,-99.52586,-23.803364,92.475021,71.113552,-120.021703,-192.497466,-175.937992,-132.392382,-71.472001,-40.491634,-38.504229,-61.475757,-68.817926,-25.084234,21.778244,125.078447,162.786407,128.349481,-23.148735,-61.926463,13.021684,70.140655,99.29705,98.325059,151.880341,218.265751,217.814848,119.589933,44.501966,-45.248769,-34.606082,108.759721,203.718016,243.910058,87.897565,9.329835,-96.060435,-113.279506,-44.245243,29.749887,135.018767,85.907094,25.369954,-43.593677,-23.386099,29.836858,6.500923,-80.504643,-89.500432,-91.438181,-164.310123,-190.686265,-192.669755,-194.385203,-204.442085,-179.079275,-54.992086,20.193612,15.774501,-23.233439,-17.543608,81.263786,141.541457,204.448233,191.358066,70.496099,0.603361,14.688037,46.96416,69.711182,129.212218,136.908707,105.911191,38.942241,-17.237958,-179.457609,-263.279368,-338.009514,-305.269573,-152.803944,-85.843585,-44.873683,-84.269928,-101.810349,-55.618537,14.290239,148.75509,183.687804,229.946278,218.136819,167.355751,76.908106,65.03517,38.143093,7.253556,-14.263012,2.694561:-240.914821,-314.231536,-342.334749,-317.395856,-249.81514,-56.152404,28.340185,89.774909,0.608899,-31.730902,20.682015,49.233227,9.293685,-6.565484,30.10964,23.092159,-32.76219,23.347895,41.989491,-16.279858,-46.380102,-56.743669,-36.606577,64.47967,140.486245,129.470954,65.145867,73.437418,210.300823,277.379739,343.274287,375.490864,414.755084,287.085243,183.193038,39.150032,37.757585,112.437182,125.115187,92.00633,84.127416,91.311991,58.723932,17.248348,-15.598991,14.889707,90.834347,90.145526,49.509702,107.902901,122.047821,1.915128,-71.782023,-62.793545,6.016073,103.980943,54.252007,6.064211,-50.821144,-59.985526,-76.210502,-99.301333,-185.150161,-203.847822,-109.534459,-13.372507,-17.576935,-24.582742,-1.182884,-49.991329,-129.122223,-161.26337,-6.488227,39.082299,7.218982,-14.142744,22.287111,27.96643,-51.570759,-66.630466,6.918765,30.030605,7.266008,-25.20295,-18.109055,-4.200582,-20.380766,-26.244201,78.059201,127.919719,160.532106,162.229439,171.242579,168.525077,160.79686,164.083885,183.217588,216.771067,215.279928,173.248183,179.315466,262.290686,290.014946,246.683361,146.469893,135.645447,184.674017,203.751978,248.225523,267.710561,216.821557,158.547419,40.673984,-8.464758,-16.168274,-77.643299,-110.008539,-89.103905,-31.676648,97.987669,51.806781,-22.053063,-98.141711,-83.190776,-18.634542,-0.683574,25.575705,48.814466,133.034353,249.927511,232.979618,36.173449,-26.239367,69.00418,172.047272,237.457151,11.352882,-113.021078,-221.001175,-216.386176,-146.792151,-97.833674,20.242684,70.162223,48.134682,15.505847,74.24109,254.312895,310.980342,274.092463,222.775682,234.181463,333.064713,332.291341,212.271339,155.495516,191.107544,265.468977,398.697478,429.389022,397.019634,291.373728,246.739564,196.757233,180.340783,117.192686,74.056289,66.893674,156.499459,180.448804,170.778461,165.68667,187.946001,187.376954,111.376184,73.63409,81.570368,31.541137,-66.037446,-242.447396,-258.013188,-158.509016,-61.937001,125.204228,179.921511,188.446607,180.96303,151.949647,107.857572,107.673549,109.853194,109.027521,128.445536,171.077411,175.980809,115.699416,79.152889,67.742547,104.765475,211.951418,167.216366,62.0509,-162.650294,-206.666324,-124.383422,-56.944201,-13.58241,-36.80512,-74.787337,-21.48076,15.466462,15.898958,-10.118069,-14.160867,12.673342,53.41517,28.720265,9.160185,-3.583224,3.22246,60.702789,108.486391,192.908497,210.661493,133.740542,-2.580414,-39.231787,-35.460225,8.099042,118.842671,151.334444,135.349155,63.206887,62.940227,86.159754,49.151663,-63.821642,-64.483736,41.74658,85.647932,74.499353,16.278503,2.340495,-32.647864,-50.568633,-51.752285,-42.561065,24.355596,181.029875,247.209077,248.435146,188.58484,94.399797,92.464551,97.720764,83.580836,62.937168,61.959014,35.881731,-58.145408,-56.564039,67.030482,111.007038,85.778795,10.984842,-11.747039,-49.597559,-82.264909,-124.629313,-123.142798,-150.709372,-176.973718,-162.655027,-67.413342,-47.38467,-120.043536,-166.951122,-175.125525,-129.277087,14.162316,91.60679,109.124857,116.263581,78.825661,7.624596,26.578742,137.849306,187.687261,233.107739,253.242284,275.206932,310.842039,308.864152,295.720204,306.81877,308.779309,196.188149,128.918407,-10.664237,-84.669947,-154.569191,-144.716854,-59.357713,13.2594,104.890331,61.009349,15.239757,-90.973806,-125.730874,-120.14656,-108.941633,-98.662311,-46.636275,-20.039514,-14.215258,-16.883071,38.46112,67.389349,67.227112,69.094065,79.399733,40.123533,-2.316157,-43.436187,2.305123,121.392232,133.891167,120.627262,151.850284,144.901014,15.282901,-71.838791,-163.529675,-151.935898,-13.62643,85.213398,169.562862,41.481645,-46.329648,-166.741,-181.623482,-122.702132,-53.045495,50.168036,-25.140762,-56.071751,-14.64956,20.352591,38.014839,4.732005,-100.789228,-132.552424,-194.244399,-345.79695,-405.247982,-398.850475,-356.099703,-303.766458,-304.404749,-284.94117,-240.692481,-231.389322,-234.425932,-236.806071,-166.804482,-98.223441,-23.873903,-35.606136,-105.254394,-141.009815,-135.48449,-111.43877,-88.649182,-59.144779,-80.592535,-157.29975,-145.231599,-118.883343,-191.913154,-305.389936,-472.127075,-448.079534,-255.569143,-171.182723,-108.340964,-71.769657,-63.389285,-43.708883,14.268415,150.618517,185.138482,234.234439,235.843359,199.363415,73.053643,15.084012,-7.489984,4.769933,2.806281,3.969098:20.988359,-92.990693,-134.928627,-188.380891,-181.229859,-99.40093,-69.057638,-57.946427,-54.619963,-46.10501,5.431594,31.057786,26.541033,24.036134,123.538194,193.764011,245.856649,260.769399,265.417359,231.52937,217.081994,223.576513,237.146748,242.049574,152.998072,93.735698,24.949255,30.515648,133.228309,207.098919,295.196812,281.609888,215.684733,255.331674,247.047783,92.512544,48.795093,105.290563,118.294142,58.531799,35.659774,27.032878,-57.440984,-72.974665,55.440383,129.002121,138.494486,90.606042,-22.73055,-65.226923,-72.26971,-107.541098,-94.780093,4.921894,32.163462,15.211557,-8.512559,-25.639274,-97.751852,-147.816876,-243.200324,-273.509789,-247.146435,-202.743398,-137.940798,-87.03907,-67.699819,-85.595944,-103.698349,-100.006251,-83.844271,-72.471933,-96.211142,-95.624437,-59.546907,-46.027593,-22.775084,0.405302,31.40264,36.440113,45.427586,-7.500877,-70.002608,-154.303548,-137.429663,-48.537191,-27.361845,-79.142227,-133.54267,-110.593199,-10.411652,24.318013,53.358444,64.901042,83.657705,91.451595,148.795407,233.684944,240.762988,227.319541,241.11214,273.253042,282.29489,266.211489,127.789151,54.14421,5.020564,4.600973,1.192286,-3.15362,-32.889626,-60.343963,-133.11838,-178.43789,-182.888963,-212.603412,-248.075932,-307.894911,-296.454988,-172.182994,-42.229934,-14.088717,-72.494064,-134.618507,-185.256366,-167.51122,-80.778154,-13.070892,55.801316,-33.795782,-83.773204,-85.978842,-38.801076,48.119134,64.28624,49.017504,-46.062109,-108.530182,-222.460707,-260.833396,-216.798416,-113.669978,146.808985,212.271505,168.306641,105.116751,84.447866,38.091233,38.366126,92.074509,109.027259,137.312239,246.314414,286.736403,173.636726,78.948455,138.255895,274.630976,428.01824,383.29445,176.552819,58.30672,41.927446,23.130499,27.305759,84.880288,114.570376,95.484466,1.630004,-12.775042,19.14912,13.271197,-0.666696,29.663516,48.029932,-13.703154,-166.874994,-168.406143,-146.731821,-163.195953,-169.728908,-98.235828,-36.731398,34.069442,-37.204789,-71.540469,-62.218352,-47.875611,2.06902,44.842476,95.511745,95.507819,63.434819,8.763871,-19.426839,-47.984696,-33.776884,20.497839,68.917101,194.606164,86.240091,-44.665293,-173.839973,-142.979252,-52.21977,-51.253965,-71.897681,-35.834217,83.576311,131.17763,134.975774,108.279161,113.674708,262.313965,342.61424,322.946498,247.019035,244.091723,193.700946,143.471258,119.640513,152.273682,200.012632,186.315879,79.5195,9.323617,10.01461,23.39162,39.682563,75.202489,83.943432,113.730952,95.309103,57.664927,11.21916,16.303699,38.232707,31.682418,20.763703,39.82321,57.747737,-0.217351,-15.615953,7.159702,30.71358,41.588799,22.626691,48.858196,148.774566,169.034312,130.774124,103.153671,112.230972,120.986582,92.322635,93.800399,124.358556,22.382723,-93.835715,-299.634529,-313.109958,-196.849938,-132.98595,-76.290879,-67.201073,-43.978185,41.140278,72.881866,89.476267,110.507427,171.719273,158.779806,37.304807,-45.245751,-41.668434,5.940211,21.669783,9.455612,11.34596,94.207852,87.283216,33.433245,21.493267,68.97596,111.734513,86.278413,69.558142,128.243706,280.516915,294.620408,261.49896,184.984116,173.773747,209.096313,224.838703,244.143885,208.519862,157.64452,80.542586,83.604157,129.004836,127.021719,70.981591,43.449952,6.305641,-41.363114,-98.915594,-208.462561,-188.271294,-55.278947,-25.307228,-8.93458,47.663135,47.391402,-28.030379,-49.010586,0.790539,52.899786,176.850379,199.357557,66.250899,-66.360341,-66.086693,-23.47966,2.53182,43.967334,53.613131,101.637658,159.716638,153.009809,52.540623,-4.119219,-44.296067,-33.733543,55.471635,123.361786,192.651821,164.213857,104.821226,-131.692039,-211.110859,-116.207123,-14.286106,46.833319,-108.388903,-186.5628,-244.826567,-231.262933,-187.380255,-179.972571,-151.002732,-123.937979,-128.987612,-171.425817,-174.347758,-192.1932,-215.190895,-224.202122,-180.365097,-57.810956,-67.912947,-102.530429,-102.107464,-52.148273,95.994843,134.154291,98.511699,55.03742,-86.440061,-143.479818,-76.487485,94.613076,130.159091,84.9637,46.384638,11.484257,-86.294599,-161.600738,-239.614794,-228.533907,-162.790551,-146.936359,-158.463801,-165.167778,-215.247334,-228.600389,-160.527818,25.206359,86.666015,98.253947,71.458361,44.874143,-15.466282,-68.772821,-135.156917,-134.03126,-80.381152,-65.616798,-111.302162,-143.75103:forward
-176.893022,-13.273047,42.238155,76.183044,54.197074,-20.381904,-60.313738,-115.668382,-54.150197,-4.820631,39.149811,33.918429,-9.499062,-33.755592,-67.057451,-81.677742,-107.89393,-94.228655,-84.363471,-106.406599,-117.325826,-101.62037,-95.793538,-81.40588,-14.782756,20.989705,106.879568,152.621692,144.034392,86.6241,-18.336991,-29.891285,14.782195,32.934114,28.967688,65.696805,96.092891,97.573796,56.783521,-13.481473,45.009627,95.073232,145.023799,126.60391,17.769108,-50.84536,-160.349209,-159.282171,-28.084446,-16.124852,-104.720039,-267.289757,-269.775388,-179.58859,-171.592257,-255.701661,-221.419515,-133.175552,52.540793,92.772214,22.327299,-38.493457,-106.771731,-116.200265,-61.195242,82.380754,141.14074,163.586132,141.176883,99.556146,83.619641,59.695193,87.695355,117.253114,166.358797,169.356588,136.373348,114.729402,70.308723,63.932581,87.707494,18.906403,-42.024967,-66.596541,-33.019683,-7.363724,-21.482223,-28.726718,-17.865488,-7.781135,55.537897,79.8152,32.114905,-12.311673,-50.338739,-48.049201,-43.017396,-42.402497,-16.953138,95.523933,129.222398,57.365907,-18.00599,-60.069759,71.061984,123.104714,150.862881,127.532624,-11.966417,-93.165564,-200.020397,-219.933051,-171.337404,-134.115055,-160.612562,-203.222329,-196.691747,-155.167737,-141.424215,-166.159613,-134.061532,-85.264979,2.514103,22.815209,-33.448796,-89.730823,-165.33906,-157.264653,-5.725184,207.164792,274.259952,328.045048,325.041158,225.714231,131.29427,-26.972714,-31.169433,6.827177,144.630321,228.585546,273.951277,210.536806,21.745331,-52.668105,-106.708134,-101.329764,-111.495212,-179.800259,-213.136455,-230.101399,-237.104577,-289.183681,-327.859264,-326.038659,-339.056477,-375.398708,-473.123091,-507.865662,-547.988386,-556.559123,-507.813526,-395.550884,-330.563601,-276.206384,-317.862379,-457.933341,-509.212307,-518.460009,-446.85396,-430.429716,-447.589301,-450.148083,-389.679289,-330.160445,-249.669365,-237.007609,-203.581231,-178.389434,-156.70144,-103.702848,-113.534318,-201.556269,-232.153279,-209.298101,-125.252177,-78.413067,-14.424439,-12.958994,-55.238543,-82.840116,-141.110653,-163.418003,-119.952716,65.666083,151.23479,189.293702,170.704336,165.487332,154.502874,87.490847,66.540827,66.876408,52.212977,44.664225,15.778534,-18.755073,-112.500925,-118.400575,19.458717,161.943297,200.78355,274.19012,300.502826,269.243658,217.172328,125.628133,118.819723,136.449821,156.471491,118.169992,-40.197026,-80.387463,-16.765758,42.835711,125.917084,97.834725,81.931147,106.109892,100.621358,-12.98695,-72.936998,-49.433877,62.923194,82.105263,101.632502,136.569457,201.786281,199.526553,130.207768,89.907078,38.686753,5.751123,-7.206316,-43.945421,-74.376849,-152.194857,-187.398805,-191.252297,-142.938475,-156.368011,-248.495687,-281.253174,-269.392595,-243.751834,-211.632486,-180.816605,2.034545,188.15843,250.621675,371.685011,399.908011,365.004998,332.591703,247.403257,133.057321,96.089009,100.144243,106.295336,52.156756,7.534422,-127.262812,-212.902978,-314.557334,-249.603131,-185.730951,-119.784096,-107.541146,-49.270678,-10.468164,85.683508,188.642265,209.997386,236.597996,258.912033,250.28316,212.501785,128.67841,110.167847,130.619666,108.777862,65.849573,-49.289776,-105.068311,-140.722068,-109.343783,-10.382684,-1.043254,-44.485028,-77.170814,-31.949102,96.149423,135.70211,137.648681,143.48866,227.858332,285.069045,272.92078,211.604683,189.239136,129.652455,56.178666,-108.323214,-132.058164,-111.765332,-20.720384,56.457957,139.214006,120.987016,104.22804,148.954204,290.649434,396.420908,448.6648,525.580359,498.228095,271.86927,115.217615,-108.408989,-125.497237,-80.319449,53.830009,86.0512,16.500525,-28.970439,-32.612903,-1.991726,39.643739,10.647344,-26.441317,-113.476713,-134.930074,-115.323351,-112.919458,-151.938246,-144.791814,-136.169618,-171.674873,-189.439571,-154.222945,-114.939428,-75.695726,-83.550383,-86.16591,-99.488288,-132.233733,-146.137518,-93.019107,14.822018,10.285215,-46.447246,-3.940958,30.399445,26.896614,1.059851,-12.414082,11.475077,29.240255,-3.650287,-47.736533,32.151108,89.535253,141.256605,125.298122,60.048777,25.636879,20.856351,168.193161,238.074612,250.444096,216.801353,160.84895,131.360374,30.258184,13.085051,131.025499,242.663189,252.146997,227.237918,195.439001,95.585951,54.674607,73.144223,166.670542,182.376086,115.021209,60.068022,-2.987551,-2.330883,19.651521,21.248908:-216.55296,-75.192733,29.139076,140.523531,106.436598,-39.479804,-90.636382,-81.174457,1.995345,6.184208,-70.623158,-102.275345,-117.389122,-126.447053,-161.810759,-162.548925,-110.195616,-89.443939,-99.519478,-133.892157,-167.692755,-239.619052,-242.836753,-157.173082,-81.733522,-72.652614,-54.106599,-60.624349,-126.489058,-140.757702,-88.161207,-46.221902,-30.7207,-87.02836,-81.587378,-17.866204,-15.530245,-88.599676,-110.329073,-77.227612,-7.978739,27.001833,48.748431,8.071293,-139.342677,-195.198458,-222.629392,-206.488911,-156.414447,-119.044229,-113.618072,-153.864312,-194.008937,-272.585334,-294.705241,-261.647061,-158.789595,-108.982623,-43.718314,-47.930474,-89.460304,-81.862193,-38.435974,-31.394194,5.053966,126.012633,169.8249,102.061998,37.63573,13.526193,39.790246,95.244813,121.239354,126.745217,148.126955,146.656345,78.492278,33.671842,6.05222,38.568607,137.588944,171.871122,168.476423,120.629332,73.794651,21.793527,24.593755,10.776216,-18.857458,-16.987488,15.642535,34.824289,51.700508,39.454751,-27.003267,-52.826442,-31.267316,24.314898,45.262706,71.773596,71.950712,-5.390942,-83.541645,-156.440664,23.633418,139.234768,219.443569,167.005179,23.018089,-37.449207,-188.624124,-237.371646,-181.511029,-117.76405,-119.625171,-141.166386,-156.060438,-204.965677,-242.575934,-268.568026,-146.508676,-75.770849,-23.06003,-41.230249,-106.20777,-128.436282,-114.553665,-76.450818,50.587486,178.620069,209.244396,188.359061,149.964418,45.081261,-14.93831,-93.773977,-52.283155,-7.581756,55.956212,55.40095,-11.846563,-51.562899,-84.506145,-77.698144,-72.451691,-139.256761,-172.329449,-198.995774,-209.958968,-240.021129,-252.170595,-280.625676,-301.963105,-302.962755,-307.886678,-330.893666,-428.167029,-463.614802,-455.152536,-438.281453,-418.775748,-366.412486,-312.940059,-233.326047,-229.149464,-260.489285,-284.555275,-300.885785,-231.667142,-189.347837,-180.497777,-207.276682,-225.947164,-212.979283,-212.51873,-219.520041,-207.988764,-170.266999,-116.665291,-16.03971,-43.57896,-226.299327,-293.336054,-255.810603,-83.420322,-4.666706,18.080412,-50.699493,-149.465173,-130.676131,-110.569853,-139.094018,-173.703759,-58.982612,25.191649,65.106082,19.175092,-56.566221,-52.213716,39.227303,153.779893,176.743496,138.850908,105.181533,52.303477,19.432394,-63.401608,-70.732087,35.750386,159.341082,200.866166,246.967905,251.989949,247.933557,222.926612,115.679904,84.933477,120.851791,204.623328,195.371499,51.499877,-15.887111,-29.50183,1.549891,51.793133,82.175398,108.741402,139.33198,114.549279,12.014832,-24.099721,-19.265418,41.37936,75.43859,114.477316,115.253733,108.88927,110.434643,113.794309,104.8201,82.43069,121.796905,143.259293,91.709331,30.96559,-47.585142,-54.152881,-46.994843,-52.579781,-60.629216,-87.312581,-106.942292,-115.977091,-99.730057,-49.032228,-9.877869,91.588897,202.568368,269.384884,350.427325,325.378552,213.889333,175.252732,140.006926,131.98975,140.662255,142.787024,113.083998,36.504544,2.55686,-120.430839,-196.248586,-265.060918,-174.811417,-108.79769,-74.937056,-91.558783,-60.07064,-3.867144,131.536462,210.591877,219.823134,223.369054,235.715478,283.910238,278.441515,166.910725,128.869038,166.71093,184.545099,154.746879,38.259108,-16.522297,-33.052684,-7.725903,44.990149,114.832841,140.431056,120.281771,93.520707,89.993405,104.258703,134.992727,188.445886,335.765807,311.501293,252.553251,188.854247,180.027701,148.507917,118.348386,87.381838,154.11439,188.3748,196.38074,169.978165,106.2509,102.030084,147.008682,185.825714,310.003784,432.69812,464.495469,483.661039,463.187968,306.304849,201.483047,90.951555,55.833892,38.285391,58.072202,58.874156,1.242666,-7.11093,35.369493,67.043581,94.475287,7.741421,-34.943464,-56.451313,-46.558351,-17.311163,-24.432543,-82.4298,-66.719215,-29.092869,-1.644359,-37.243328,-126.553897,-131.487744,-75.519729,-60.027795,-95.105604,-106.887049,-75.745229,-36.981113,-65.86113,-131.290512,-107.016226,24.808914,110.424268,118.78961,76.041079,36.284797,-9.212061,-11.79665,-45.039318,-61.902368,-7.971105,131.6907,201.850524,258.335401,219.452636,81.708919,44.350605,105.278005,223.00087,255.336265,274.980448,253.089357,131.194147,63.95863,25.311077,78.484716,250.892565,334.035453,326.616445,226.258481,165.273124,116.668521,116.13594,101.707887,103.962168,132.418504,191.305605,187.827307,119.553903,60.744279,-54.108687,-64.354388:-168.010008,-54.040953,-22.158284,31.317275,16.113182,-112.04833,-167.918619,-140.419516,-55.650821,-53.220293,-71.241107,-70.461226,-65.619636,-72.655815,-127.219871,-148.517132,-124.496073,-91.292668,-92.811359,-146.14564,-188.491169,-248.477493,-261.122927,-234.435726,-128.406259,-71.458098,-15.820307,-35.612938,-151.133574,-208.397528,-240.23925,-208.052976,-117.421611,-93.822494,-98.059954,-91.164403,-81.608493,-108.402526,-145.051807,-159.623836,-74.268332,-49.125363,-79.497035,-122.047236,-222.411915,-258.779782,-256.602648,-217.849917,-131.388191,-90.283607,-94.888977,-198.841391,-262.902901,-289.064642,-273.842115,-274.520075,-249.8265,-200.602467,-43.191845,22.60858,10.572114,-48.583786,-96.962981,-57.008343,67.931299,179.994885,201.021753,109.862179,44.877634,24.122344,54.638901,102.375635,111.579042,117.339352,155.356309,162.867043,106.097859,50.082711,-22.875364,3.271068,130.662117,169.347402,142.486298,28.607543,-43.730212,-114.285009,-99.555677,-21.703478,61.569074,87.290921,89.878397,59.597783,-46.625928,-105.784171,-190.997652,-185.194269,-66.862944,3.690874,-14.316313,-51.765632,-43.879908,-42.103573,-63.5024,-42.518737,104.905111,181.501662,262.629808,234.784371,63.951675,-31.118364,-174.859977,-195.274349,-129.601974,-87.184548,-89.621903,-131.282458,-170.762584,-239.531328,-244.192032,-169.813609,-102.684512,-98.689225,-80.473105,-64.035618,-55.375583,-68.51997,-106.163115,-89.322198,44.461177,128.859209,142.279088,125.046458,66.479491,-99.529924,-146.23412,-137.230071,-92.507584,-52.276396,68.139094,94.592957,-14.162536,-102.054992,-170.253986,-163.351152,-176.788731,-176.237548,-153.863453,-181.481562,-247.704172,-347.646849,-340.662265,-300.675976,-371.013443,-410.194612,-399.927288,-385.791991,-423.117647,-463.598949,-536.700313,-535.931125,-430.198249,-296.507204,-249.425925,-232.812168,-264.008009,-327.504989,-324.874909,-234.27107,-134.690697,-108.780116,-106.733068,-132.387096,-163.019379,-148.390774,-142.259613,-165.536506,-180.450502,-92.569017,-48.166679,-53.570294,-108.308566,-275.241256,-340.036487,-287.972542,-91.314363,-30.286156,-28.504091,-71.116204,-137.576183,-135.340699,-81.427963,-42.947269,-0.371782,22.753693,59.209842,99.177966,67.451792,-35.035296,-61.101324,-17.589384,47.189766,60.997806,106.781098,132.161674,125.618296,96.765485,26.639771,7.043618,50.755538,173.889886,223.514213,237.057566,225.228824,219.48188,213.162992,198.947041,198.238607,191.918389,172.366238,158.808144,97.465849,52.136528,-13.204321,-13.488634,37.843635,66.957957,67.965214,70.163478,67.827782,47.157512,24.870161,-9.052281,46.374978,97.458996,161.602629,162.749547,153.191701,136.452096,46.387843,24.891692,102.16011,185.801931,197.668059,120.243591,54.441533,18.526163,44.673715,79.449144,76.447458,81.140812,75.816272,28.376496,-69.031309,-62.074728,13.269665,55.665105,143.851546,229.235923,254.309646,216.053622,170.656493,86.95574,55.104737,63.16363,150.689415,172.53758,128.643464,94.077929,68.145515,58.682415,0.071715,-24.059886,-18.788498,13.182146,26.749386,9.697173,-15.403276,-32.150448,-6.740974,130.088626,271.586673,296.622613,306.881055,305.901709,265.267129,239.714194,226.06507,230.335755,224.067493,194.525667,177.49527,105.022162,55.953903,24.474142,53.087979,148.331686,208.490883,194.737453,126.739049,108.389398,109.022832,115.023383,168.230652,233.331846,360.144899,345.295145,303.153395,203.031963,146.719062,29.135959,-11.265358,19.422969,148.040402,203.25246,256.602609,253.843645,218.300986,203.06786,243.720164,313.798794,456.643718,484.623704,480.096613,453.248961,397.573708,206.944489,126.600676,107.96511,162.389443,177.540879,232.281685,240.147307,151.354853,95.430396,44.646848,51.061368,102.525775,140.037654,139.171643,136.982624,141.144986,100.06772,55.492964,9.580775,41.674079,60.504126,62.573207,48.333909,20.906679,0.864766,-58.212284,-72.063642,-58.048488,-61.335785,-64.989809,-44.284267,-16.937421,34.372307,42.345966,53.563782,137.005816,193.747113,196.612322,147.34423,90.569483,78.450868,19.78904,8.742692,116.528896,318.514255,389.39057,392.309742,348.737159,240.72859,190.827516,186.615146,253.484128,264.501728,273.180376,271.532943,224.495224,186.050768,123.841147,128.768971,222.369238,305.871434,314.658426,271.197213,216.808989,80.78427,44.522035,80.12486,137.890713,163.550484,205.881333,193.522965,139.987669,114.255727,44.475264,36.80065:-220.435649,-131.749292,-90.933895,-48.533551,-64.639553,-114.105065,-128.226143,-114.310082,-7.737369,52.649849,89.207223,52.602997,-32.055854,-39.653366,-55.676432,-97.468035,-163.360929,-126.562406,-97.73254,-72.719439,-80.22556,-96.778263,-89.127276,-54.818796,-47.791852,-33.643701,69.170436,110.943181,48.004723,-25.144429,-77.670912,-33.470993,76.796469,56.891513,25.090128,19.780946,29.687979,7.627688,-17.03836,-9.74829,99.626023,147.613452,157.954749,107.263049,-60.155663,-126.491302,-179.195041,-168.610893,-94.263039,-81.252214,-113.944991,-188.806598,-219.778467,-277.739612,-299.40219,-273.893897,-148.646816,-86.322217,-17.324364,-12.444933,-38.500916,-57.464957,-104.284954,-111.894172,-9.85779,206.048047,268.831778,188.921641,99.543226,37.825682,76.165819,147.614775,137.105028,130.217301,135.395865,121.905603,38.743301,-3.671769,-0.223966,54.196427,129.196002,70.92646,63.983342,82.248489,40.939699,-87.61725,-104.35866,-44.006552,16.743172,54.258182,172.572917,198.0777,111.081131,48.309104,-51.43754,-87.440517,-90.826557,-7.386288,29.488087,48.328976,42.931594,15.93823,1.709797,55.917422,226.838279,293.531278,307.159746,251.584733,91.386799,28.42978,-44.990848,-57.824284,-30.230574,38.570874,46.345022,-40.105884,-87.850499,-108.438075,-112.346448,-130.315522,-97.35659,-76.178836,-70.719824,-77.004256,-55.198242,-39.8432,-77.79287,-108.964677,-69.460436,96.106582,166.465533,181.470126,147.674503,68.67604,5.577469,-131.77839,-140.373673,-109.557283,-9.484538,48.805476,78.220371,36.412027,-70.317479,-92.343448,-83.593649,-112.168806,-140.944804,-189.029787,-200.2598,-205.341769,-226.708989,-344.578201,-445.748624,-448.659994,-409.154668,-418.083698,-502.298084,-532.5974,-554.665716,-566.302664,-553.828305,-458.876251,-407.907621,-388.577767,-409.490273,-395.043823,-369.650833,-377.545626,-392.416852,-371.941706,-321.414214,-311.809304,-299.779962,-295.254078,-333.483164,-350.463663,-281.296907,-175.932703,-161.524182,-215.543961,-261.928561,-319.41672,-320.529426,-283.8566,-206.414493,-152.364338,-57.088955,-51.297316,-129.916433,-177.735761,-225.645281,-214.436773,-94.360536,57.983363,104.128188,137.309643,128.446748,82.054166,51.767128,10.42683,40.375303,80.602792,152.053489,152.132884,92.554724,61.165447,19.894718,9.555781,-2.648869,26.788657,86.251624,224.32148,253.920042,259.332937,253.461776,201.875836,164.771248,181.820923,205.450932,155.152033,-7.314073,-42.215388,-17.827019,3.192093,62.924067,109.622247,110.129494,81.282398,63.566753,20.888097,-2.616266,19.663197,120.982361,143.553804,119.681419,113.22076,159.877307,191.145559,204.09565,184.733985,114.430517,57.191063,56.67826,29.890309,-29.977842,-149.208452,-150.91287,-59.987287,-24.68513,-38.694144,-47.417081,-35.410958,8.498784,37.223883,53.361629,23.969724,-25.101684,68.739618,151.11979,256.306715,245.838648,153.398359,125.151841,162.819026,184.795702,153.767785,135.750152,173.84625,226.240342,190.798049,23.98977,-42.962455,-60.026572,43.425584,115.542735,174.801171,159.083406,163.217102,185.022548,241.573224,355.457817,391.949999,377.9081,361.668275,373.584236,382.747423,318.640428,265.175736,215.924073,157.009752,108.826249,63.096762,71.197573,105.073967,130.165899,208.101234,199.955529,122.689769,12.233171,51.077672,161.710104,154.668068,86.3441,104.386501,248.094535,284.0318,245.534338,146.117067,87.056891,-29.974386,-68.638388,-53.054903,57.038746,87.258547,91.393034,102.548105,157.977157,183.165923,236.654813,291.120071,442.984125,528.648469,538.059613,496.871011,445.074347,316.935289,253.93054,146.007975,86.583045,83.614729,130.547192,137.201012,75.482543,44.692291,-38.188727,-90.348766,-95.577135,-47.346203,-61.771134,-106.51683,-98.255394,-50.04535,-50.43947,-97.278402,-45.880522,18.2101,64.280357,21.828452,-65.906077,-59.786639,0.79136,7.078669,-30.423612,-56.555919,-64.169457,-88.591948,-81.12382,2.953189,35.482723,50.784202,93.41933,120.155152,178.790582,207.163291,214.045278,192.525815,109.634529,63.890473,83.679287,263.158707,336.847725,326.672915,265.891588,168.192987,144.996326,136.555857,195.116328,225.634131,245.757555,239.93536,179.785482,122.046181,9.586725,9.943649,162.745426,315.683463,335.135988,255.301374,175.845366,7.917325,-33.093879,55.968669,134.648713,101.001633,29.032087,28.062322,52.306095,46.654798,-23.013225,-49.512726:-304.536514,-118.773184,-35.173878,28.638155,0.749544,-131.128118,-182.970919,-110.699952,62.484723,100.357301,75.408176,54.289271,61.589888,54.08852,-99.632651,-182.885557,-124.46599,28.651409,11.389127,-121.564482,-146.253759,-110.899454,-102.756341,-94.682423,-13.043188,56.55722,217.420338,250.644138,133.128403,25.946469,-113.764641,-111.097137,-37.987655,-9.107695,-11.516623,-42.466174,-67.584339,-86.621212,-65.657448,29.636905,98.249941,109.961476,134.34076,112.816297,-56.791796,-149.146269,-207.693033,-171.980354,-59.040023,11.19544,17.642036,-77.01981,-164.611855,-268.666947,-264.918334,-219.611124,-186.601342,-172.259648,-108.099978,-74.784139,-105.599726,-150.736697,-146.418739,-87.280034,26.949354,77.529922,98.128489,81.762653,39.872224,4.177398,24.120203,44.73362,26.923827,44.997672,127.299934,138.020536,32.946675,-41.304733,-83.388748,-31.814212,114.112924,147.136767,121.303399,48.01176,2.659388,-82.197742,-95.057097,-41.560932,25.439267,42.306153,78.13736,86.788515,21.110785,-44.206623,-163.733512,-177.711381,-73.614785,57.434951,76.725948,38.740277,3.945775,-70.751402,-81.740238,34.907692,250.791272,335.433909,405.295728,362.761522,141.002463,36.336737,-41.34717,-16.919018,77.920543,94.695349,70.881843,-1.585047,-43.624017,-129.375812,-163.924148,-159.612555,-67.32822,-23.466863,20.705644,5.852946,-95.668402,-160.213768,-207.209517,-151.307396,-5.198869,22.105515,47.54646,128.35909,120.715301,-16.717721,-101.116807,-159.869315,-37.206011,54.221478,194.275808,201.047484,59.310286,-48.93186,-159.061701,-128.641175,-39.557632,-74.41399,-122.957078,-191.769294,-194.240543,-217.392858,-262.462153,-315.082081,-316.071165,-326.288624,-308.155462,-295.107179,-352.570931,-423.737015,-574.222588,-589.270383,-447.290908,-297.885579,-272.240652,-309.933243,-334.507567,-298.325617,-273.054991,-285.368279,-247.821702,-190.966135,-93.328697,-87.473612,-150.826117,-185.74645,-213.91341,-206.205288,-162.671752,-143.144163,-157.374367,-203.808977,-226.069435,-301.803831,-351.644419,-357.904313,-199.227162,-103.469598,-2.935989,-33.599103,-176.938218,-219.632606,-205.527937,-164.432299,9.462211,203.474751,226.573981,108.343436,45.629639,57.410451,96.693547,145.573523,146.77341,138.446693,130.321997,130.07498,127.298698,114.994725,33.124606,-19.619001,-28.659148,123.667886,206.659025,268.888889,249.177605,194.049134,176.755819,137.641455,112.761191,131.490023,164.653745,136.110459,41.713051,1.434078,-75.523706,-83.064804,10.408264,154.076049,208.290909,183.052539,102.28955,-56.914645,-88.03728,-12.265998,132.395249,179.502934,214.80884,193.360483,107.235299,88.916818,117.768838,129.057906,108.81445,149.708149,193.944742,151.788633,64.15141,-67.040318,-88.484313,-76.489568,-33.225549,-27.860562,-15.359001,2.838369,10.490425,-11.978725,-75.798989,-100.47377,-126.338524,-57.908944,27.163186,149.593006,143.26964,86.577929,67.911194,54.97747,105.223723,147.711276,221.725387,236.43871,191.360935,130.398632,9.838983,-3.052239,61.686329,144.017009,160.726926,96.664509,37.546497,-5.721505,24.244668,131.588883,241.530151,284.960726,346.526712,354.08374,312.173609,274.408847,188.097536,154.173327,130.631437,117.60907,97.173024,37.541855,11.828157,-15.385179,-14.846369,35.613108,113.183102,116.589932,67.590818,49.119499,33.809883,22.133317,9.95015,42.390685,176.663876,247.540499,227.738545,95.634699,17.365815,-83.236162,-112.449479,-132.476009,-35.280037,41.472338,158.408638,172.886664,127.264934,103.527539,140.403456,204.781064,332.65374,379.190324,402.808288,447.529929,425.325618,289.498827,219.252027,145.501733,139.930751,157.25922,205.407573,186.332959,61.707059,9.002032,-72.694865,-112.342466,-140.15971,-42.041556,36.083453,89.380488,48.120912,-50.048557,-67.456291,-22.360093,37.45546,57.582079,105.543189,122.445204,119.552288,96.469201,28.757824,12.282569,27.007261,51.096436,54.829177,39.012049,41.191099,64.645006,54.72916,38.036667,143.397237,231.750882,378.582002,379.091488,220.953318,121.409112,21.371069,65.671062,303.569624,456.590888,446.249895,331.855957,268.038027,147.080331,101.533942,105.513889,165.081913,180.110349,196.508032,189.056126,131.656146,99.728595,63.37873,82.884229,210.348019,304.724309,304.794906,220.409658,155.466485,50.013731,22.166962,38.6403,86.274877,79.674831,46.144141,49.036005,72.788539,58.896475,-19.12523,-27.866025:-298.538762,-84.888205,19.334144,73.69459,21.20474,-80.891388,-97.998888,-86.350218,-14.168405,31.085572,92.407698,91.688596,22.715812,-13.099962,-47.243334,-64.718507,-70.022629,-4.161978,13.054411,0.689137,8.827691,60.345744,47.612042,-77.552065,-81.772263,-13.977545,147.052854,199.091532,155.487494,84.087747,-7.326743,-8.271576,49.099229,129.700668,172.076742,255.116901,274.51715,225.560451,173.488058,134.458335,206.409083,244.047204,279.407913,243.444497,79.022772,14.510884,-43.412031,-42.181099,42.863078,85.78326,27.779214,-173.695692,-236.53202,-215.690485,-197.102307,-225.592743,-152.641052,-52.876992,133.316736,155.549861,46.862658,-9.530563,-29.457684,-19.68058,25.339723,137.133921,209.939309,298.707227,290.368016,215.881667,174.465972,147.528213,229.18836,247.057606,141.135304,56.152871,-39.439883,-16.59979,95.202631,119.77567,72.804562,-46.370923,-105.593899,-154.516682,-153.825505,-179.032905,-207.537417,-209.276903,-89.888776,-17.612705,110.141266,159.338531,173.982648,130.112013,28.671051,19.584551,60.506021,61.705119,80.540327,181.948082,197.555285,62.387392,-36.709519,-42.489623,209.706812,302.865188,330.718634,300.22087,196.34243,119.823038,-33.361674,-56.304742,31.549422,106.99455,96.252608,8.505195,-51.3029,-129.509382,-124.334688,-52.626959,43.225192,70.960067,66.399546,40.54664,-50.524323,-90.056303,-127.641716,-122.315499,-46.966914,48.742768,103.203334,208.168836,223.582117,132.676039,40.215804,-75.395969,18.563527,75.92668,117.963411,127.426428,124.352004,88.190317,-34.583871,-90.128848,-117.588628,-88.422328,-94.865513,-150.716165,-187.441454,-238.181165,-245.58369,-262.586102,-274.535874,-248.963592,-192.825028,-232.688933,-441.225818,-531.493645,-597.429001,-586.856664,-489.635858,-366.287064,-328.272882,-318.98657,-345.289636,-440.176941,-495.093471,-535.285058,-467.09875,-444.154886,-465.327805,-486.946435,-443.347958,-368.262065,-281.98148,-299.541426,-290.281187,-239.933496,-259.583533,-322.338496,-336.118013,-333.614318,-321.575792,-273.865367,-187.026209,-126.932847,0.089606,27.188508,-19.232877,-44.475854,-58.847133,-68.321652,-84.140224,-39.712831,14.41363,147.245757,206.421518,231.283194,175.954071,42.692816,32.476638,60.640548,79.321816,41.346683,-75.540047,-106.212023,-121.30098,-126.208236,-85.535003,42.537326,104.443766,156.074653,159.520751,186.60157,195.466284,137.159007,94.426971,121.67803,173.91934,150.848854,61.192039,46.998253,27.218035,-2.980895,17.367678,161.010371,207.411165,173.168139,115.773803,-16.785763,-56.597818,38.845791,215.86613,244.133847,203.9129,170.222799,159.676191,192.337774,234.774129,205.254222,68.076655,24.191631,46.25044,-26.19345,-128.311941,-265.563613,-267.146317,-176.140629,-105.030283,-131.288742,-219.474733,-235.367748,-221.455353,-215.009396,-221.702657,-212.298713,-129.215054,-15.456883,42.616897,89.085428,79.858482,120.01196,166.133925,195.382652,137.243702,111.576226,132.558824,180.11328,224.724266,188.061354,70.267698,30.40225,8.083795,12.284441,21.533068,23.624995,10.214735,51.046098,115.863675,235.906339,322.313809,355.213409,364.791472,341.135415,259.966964,232.086185,233.23562,234.004758,163.739969,51.30324,37.618788,63.202371,40.747901,-73.953787,-101.529683,-23.150318,62.930011,51.156362,7.802749,21.294483,124.205781,185.473981,210.261048,178.25876,172.734026,272.990272,313.432462,253.14198,140.989759,-128.365618,-234.827699,-341.229772,-311.179361,-255.720804,-49.055878,51.900909,73.446904,40.389884,93.590686,176.525397,337.113354,412.893336,431.790033,439.620398,410.519322,259.95684,157.583774,11.009043,6.997541,36.612388,93.580666,94.37071,13.272113,-48.16194,-132.210371,-135.22424,-109.961622,-105.826773,-99.409623,-123.611431,-168.300378,-224.776944,-225.548765,-222.526703,-182.330784,-148.880164,-103.736186,-102.569707,-76.770548,-16.122118,107.304614,105.817908,11.023915,-24.376048,1.850917,73.255573,83.950686,40.765771,2.747944,-29.879035,105.027322,205.916278,304.293907,281.435848,204.207115,185.937974,137.741382,109.99226,160.711729,308.698275,339.287832,241.552944,169.872889,133.202612,156.697909,216.732825,273.757363,286.117995,272.004781,251.10142,202.772741,172.876126,93.683731,79.798634,137.914766,172.55945,159.954409,96.011581,51.482182,-43.805091,-79.60659,-76.412362,-14.04228,9.513041,46.005219,53.566169,-22.035833,-111.358916,-268.423947,-280.002964:-272.982417,-103.070146,-31.110081,-11.060682,-80.406018,-205.436847,-203.863759,-102.009881,58.54626,109.563344,89.714781,58.907423,28.679426,13.956582,-56.897341,-87.237467,-48.118289,57.500978,85.185995,38.639407,-8.434093,-55.685903,-54.656258,-20.227251,81.219594,157.531609,280.542216,275.162818,119.589423,33.133388,-25.594399,-11.022962,32.261688,76.37164,100.530201,117.744769,93.213461,-16.137867,-68.842904,-28.783839,144.765935,186.475584,181.559593,158.637437,76.975906,20.875116,-125.290577,-161.313954,-46.786491,57.872242,38.323605,-90.5099,-167.71777,-259.524947,-268.481112,-237.403806,-115.210213,-34.05763,53.713524,34.137268,-64.673947,-95.180404,-98.182768,-75.927254,18.16379,108.25876,145.507374,161.711923,129.891974,67.375652,58.552698,97.892283,182.682276,200.362057,135.026119,69.898247,-12.450288,-12.2188,-12.148676,-10.477629,53.781678,94.193858,76.002861,-15.208545,-79.904829,-194.92966,-205.185485,-71.387663,123.833585,167.734315,172.580467,164.397568,89.186237,10.644109,-138.070061,-154.739946,-33.683072,131.498093,170.258316,153.711801,111.861804,-3.976279,-51.759682,-15.438145,206.002351,324.221243,457.881582,424.247082,162.098859,37.891725,-6.1788,42.314249,143.291014,204.340555,204.551323,107.751801,36.703246,-76.00894,-100.055503,-23.865982,97.244347,112.209929,110.384371,97.814975,7.58736,-42.072924,-93.018806,-83.552716,18.590058,129.714379,162.32347,173.580294,143.637815,16.770088,-57.699822,-137.008957,-59.832415,24.652855,206.166572,253.432428,162.139916,39.904742,-145.474894,-129.856023,33.967456,113.163795,108.985978,36.195297,-47.145649,-237.810517,-291.623146,-283.394551,-206.548964,-172.803002,-162.600972,-195.213924,-315.739776,-398.223582,-562.399088,-584.085741,-430.875761,-241.584021,-198.932963,-184.488894,-214.741605,-344.508041,-405.967539,-424.285681,-311.807858,-257.674856,-216.544575,-216.890306,-216.161478,-216.814104,-220.578915,-208.501494,-152.654394,-114.213139,-115.757245,-187.859203,-258.526789,-356.321841,-330.255048,-180.107684,-96.80443,-76.719578,2.261074,20.451652,-95.400441,-178.968524,-232.136696,-190.517736,-8.249882,167.809263,202.060814,212.418876,224.754684,226.01851,179.078082,68.73226,77.797059,106.063564,123.912432,103.69651,47.733728,36.09519,7.258113,-25.641418,-51.553948,69.380673,176.33575,303.984094,261.643998,88.612934,41.241312,42.237031,98.332177,145.506505,217.501901,177.141781,-26.027595,-85.005672,-66.485677,-44.295812,13.685135,139.644046,197.117108,193.342332,123.633933,-47.540311,-81.364178,33.770495,228.997781,272.464528,237.133262,199.218405,149.239497,135.899411,119.277592,114.77769,103.42349,130.731032,165.964731,136.961054,39.885397,-157.225696,-177.338801,-86.417983,-34.981142,-49.609265,-69.513785,-62.642353,-73.414628,-115.194784,-254.316295,-297.457078,-239.579832,-65.837087,27.049821,97.511069,63.170452,1.53305,4.226874,37.792233,92.361904,137.004337,249.009705,278.746966,189.124647,82.345014,-75.398011,-69.050672,30.994324,107.778477,138.114098,120.328883,75.250415,22.472813,23.922517,80.930482,214.687011,274.523408,304.423873,269.391172,177.220165,161.475756,164.439591,155.272238,115.899326,55.12,34.123847,-9.782345,-66.894296,-187.883839,-187.138635,-32.418434,104.943104,84.008669,-28.259411,-36.811768,36.772351,48.649965,-39.71616,-78.086354,-14.53917,134.435745,174.808023,75.343769,-60.229551,-327.491351,-385.316845,-298.000167,-147.419052,-96.23579,41.449515,102.678342,91.189929,50.083815,63.526812,132.497567,270.872425,351.604072,395.823662,381.761065,293.253126,103.783685,53.537972,-5.981248,-25.34308,13.651887,150.729237,181.084692,79.747336,-22.034482,-194.801852,-203.765289,-86.562587,-34.545057,-52.055345,-121.121493,-148.547022,-132.446302,-120.839485,-133.391182,-54.864856,7.710346,75.206412,69.324624,-3.244167,-30.576679,17.733279,62.618897,55.908668,-18.93562,-6.578516,63.211157,59.094899,-35.652442,-88.204182,-103.584734,37.564472,127.190199,248.130565,256.617346,191.463256,157.19886,108.585826,97.577792,163.658183,313.93661,361.757941,306.743728,232.099447,117.843105,90.696281,124.610383,260.749619,293.441503,229.251674,167.604959,45.461321,-11.128419,-51.390072,-4.473075,146.529397,192.640065,174.668339,119.417874,78.131657,-49.011916,-96.575273,-51.647301,35.455235,49.740967,89.146132,109.550494,81.795868,13.224959,-155.503174,-167.280989:-142.807284,-27.875868,0.513087,18.994315,21.875776,54.328447,84.870567,141.701676,191.957738,207.117673,215.827144,221.587996,199.153829,149.167465,22.343225,-7.18693,49.273611,89.433322,66.268433,46.136958,75.078954,162.170146,170.963675,88.304213,84.762654,147.534316,281.32332,302.425369,219.13665,140.007032,2.423287,-22.20351,40.484615,181.577427,249.38302,297.943251,270.39927,176.51135,141.454668,156.73682,248.269909,304.237921,432.291301,464.785925,372.33731,282.473158,181.642909,189.592506,243.31472,218.422933,172.704033,75.243831,42.878986,46.519221,68.491252,90.901223,121.860562,137.817239,119.872735,102.064281,81.678875,71.630311,73.370984,92.146363,142.50918,212.259314,255.843351,319.434422,318.366944,245.820676,197.672102,147.095232,176.323242,168.591346,64.932024,22.672229,14.790057,31.87254,78.223513,85.296869,27.630371,-128.720089,-217.570683,-339.814023,-365.097068,-360.033483,-343.550814,-291.113299,-154.681387,-54.446465,139.043079,194.889886,209.606095,210.106965,212.829018,197.310156,175.905859,125.912315,91.125547,110.251639,155.542558,178.317067,124.759814,17.933523,111.539471,191.749658,254.569759,222.605649,99.558217,49.140054,-6.059169,5.020669,145.970453,237.780153,203.704144,45.686591,-35.060603,-149.71043,-179.005938,-154.805994,-49.160922,0.709715,74.044706,88.429962,62.341328,44.523855,47.048397,63.174611,49.319575,-40.3189,-39.385066,114.172456,196.772387,201.841311,130.064532,-0.538852,26.450108,62.720687,102.032665,107.643882,84.951755,47.653343,-67.061019,-103.051091,-66.195986,-66.125256,-114.464094,-195.737591,-189.887183,-99.806385,-72.69411,-120.239215,-140.315584,-104.283853,-48.061128,-78.95793,-221.450272,-272.671442,-295.215662,-273.781064,-154.923144,-53.893801,-33.374307,-34.561106,-83.094736,-246.741909,-303.978726,-324.017532,-363.245373,-424.525551,-523.468363,-506.697481,-346.094733,-255.076661,-178.460079,-198.863816,-241.778475,-254.551578,-276.065029,-304.620488,-293.596947,-217.139436,-179.350053,-168.758883,-164.352646,-147.416422,-102.684024,-91.748673,-107.940974,-102.256131,-86.253059,-118.267727,-169.652444,-76.20805,-15.793608,83.147734,126.242141,132.679993,84.163588,-3.847523,-21.57075,-32.306492,-56.259422,-70.25496,-109.894165,-119.143985,-150.94736,-177.878026,-144.737984,-19.055412,39.948456,95.203764,65.683453,-51.564152,-93.292656,-126.599893,-96.329744,-58.730994,5.032266,-0.537238,-110.555709,-177.175536,-268.546139,-288.360787,-158.84567,103.377341,164.833833,105.598355,34.929131,-49.115279,-35.99011,71.951455,192.826017,232.234066,263.023771,266.873822,257.096023,244.461096,217.271028,191.566173,81.39013,-18.936213,-23.297749,-18.857113,-58.195911,-189.175489,-223.077379,-182.968168,-152.054826,-192.336079,-324.815837,-360.032624,-356.780951,-355.026551,-430.481825,-502.728849,-571.968703,-431.492265,-337.089771,-288.466439,-314.078489,-234.178529,-131.055591,-1.964307,-59.376931,-113.231058,-90.047497,5.37114,117.973524,55.038756,-126.910206,-133.610752,-4.649362,25.191894,-9.176571,-20.724902,-0.152995,-18.876247,-50.058209,-32.863463,56.225737,73.689115,60.870562,59.836009,89.111095,95.61433,44.428887,13.76959,17.585823,39.07744,45.71787,67.031516,60.801877,-8.919198,-59.098919,-127.684278,-98.423207,-64.911107,-12.991756,0.727068,22.934787,40.254089,79.77073,96.439166,79.067482,26.117841,53.775862,128.912705,75.731685,-192.327654,-318.453912,-435.614294,-389.377226,-329.166046,-175.580855,-128.389437,-157.996063,-181.14869,-131.094987,-61.66745,97.861937,185.711951,196.907757,158.573102,109.28323,12.027528,-20.62694,-85.360413,-149.462983,-155.243659,-90.336238,-54.788366,-86.582734,-143.81916,-208.971417,-178.439325,-31.774878,33.509737,-6.609901,-145.756318,-188.785577,-203.421635,-200.073338,-190.24774,-169.52705,-161.098006,-132.46432,-101.951427,-26.060507,0.358876,15.978853,35.290374,130.19944,108.839898,54.783753,45.623786,85.550843,122.324124,100.130919,-4.457824,-45.904133,5.590339,167.930024,204.405949,151.517969,119.365012,84.897095,69.287867,93.688951,148.172275,141.322736,111.943889,131.686597,211.049106,229.335743,193.784672,105.299203,83.171082,123.094217,137.456528,103.921621,86.094305,79.200069,92.221955,125.469363,87.784052,52.840611,-15.136357,-47.58784,-86.849503,-99.70709,-102.489702,-12.58457,29.935578,55.194616,46.997292,-37.480159,-121.457133,-302.195832,-345.467273:-153.342613,-32.941376,-29.124531,-52.374855,-51.466059,-20.836743,-1.569624,21.322477,40.896563,50.389659,54.076232,44.417374,47.356724,71.412705,33.128202,-47.678289,-135.092531,-57.989629,-22.4862,3.797762,8.424202,-4.016203,-32.222876,-90.799686,-7.940033,83.051252,226.625502,233.767621,135.380203,79.528395,31.174956,32.589069,49.172208,88.495705,131.306378,207.974843,200.323935,108.700182,68.633207,47.726151,92.016773,134.09914,208.093824,202.292156,104.983918,61.42593,39.958676,43.934191,43.288009,27.060646,-8.251859,-136.824939,-187.828807,-204.551928,-193.423244,-187.005612,-120.829809,-49.870294,100.420102,147.734699,116.773873,46.045139,-107.531888,-142.509788,-76.692967,53.055552,105.57659,199.013952,226.929175,189.536341,140.912544,100.99606,159.727145,176.802972,139.533423,114.608675,103.871041,99.04697,56.56682,49.170615,57.889501,-94.193319,-201.894761,-302.983868,-301.056309,-293.694206,-302.666378,-283.365547,-142.825507,-49.707178,117.77775,166.160733,162.589476,133.578749,44.445532,1.201184,4.671662,82.090559,122.0534,192.700365,201.346123,147.148342,96.311278,-10.368047,-49.773042,-40.483821,25.179997,66.129755,53.912061,-8.269185,-147.899484,-179.808339,-130.066111,-58.081857,-54.660731,-82.884446,-98.661151,-105.201295,-94.781469,-109.693686,-116.252946,-88.340995,-32.540358,-22.839231,-10.811916,0.060483,-14.015446,-34.615898,-18.975182,98.534909,182.314352,315.843209,314.83676,188.231545,113.908037,59.862973,128.06689,139.517992,123.570981,157.706362,270.119604,269.106163,100.012382,-9.382674,-91.910751,-31.506101,-42.04705,-195.882853,-265.746218,-254.379729,-230.810937,-268.363724,-280.551219,-251.651749,-173.664898,-155.350631,-225.841354,-290.210922,-369.67626,-368.877811,-292.99416,-221.007446,-191.358518,-145.893546,-164.753,-311.694764,-422.754087,-590.299807,-563.359748,-530.188704,-496.474819,-476.691382,-420.354263,-382.779615,-288.327202,-243.667646,-189.228125,-197.6441,-199.467339,-149.61548,-119.609986,-91.368311,-98.514332,-158.883568,-168.435957,-114.953298,23.358213,63.672044,97.157851,101.427463,22.569958,-56.711427,-125.049765,18.008666,119.484558,240.314345,244.311703,209.648076,191.80468,156.198575,102.794774,68.619301,15.369049,12.846562,24.770245,-8.27972,-150.544504,-180.241898,-43.107203,183.922657,264.325434,303.355122,257.966785,128.924063,78.189231,25.78479,65.931093,94.282248,87.843162,40.935365,-78.285861,-90.841679,-56.270633,-62.845415,-35.005017,107.342295,163.187187,169.181434,130.847193,36.131694,-0.290217,31.660513,177.493817,206.544187,162.038394,148.254456,175.437535,195.353053,193.442533,159.773936,55.173046,-18.845342,-40.03769,-99.780675,-148.031496,-255.95396,-286.854973,-215.702923,-115.0638,-148.585795,-326.152025,-394.62047,-416.530514,-405.250003,-417.582433,-410.812804,-271.71645,-87.472585,-39.094403,-50.518151,-83.166356,-61.487666,0.718603,76.8414,36.449561,8.612628,15.705143,69.095029,174.689805,158.997654,-34.739478,-144.602651,-232.886901,-149.479957,-82.520296,-43.698742,-75.577673,-104.995185,-86.578602,14.571396,98.617926,75.782368,47.328845,106.310181,225.582619,201.563661,49.001326,1.820516,6.227649,27.823562,29.436369,32.00167,24.938777,-28.720238,-64.990612,-55.895926,13.101763,-25.299187,-159.380441,-153.123933,12.880143,88.13386,105.9511,85.03789,104.758276,206.477425,250.908913,253.178888,209.724304,57.778606,-43.111283,-228.066944,-269.874105,-250.610863,-200.703497,-171.2332,-123.214499,-107.035306,-53.697733,-2.272569,143.837198,252.453731,278.055231,314.793754,312.367215,194.819449,94.3771,-51.269281,-55.559163,-36.273126,-26.495283,-53.096037,-143.481018,-164.393298,-95.465964,-23.625737,92.362627,75.826632,44.809477,-2.595279,-29.185881,-88.496328,-120.063554,-173.373941,-168.775987,-160.810762,-147.850639,-132.58291,-64.012422,-1.395929,118.123444,134.634648,100.207516,41.105379,12.43364,8.802936,45.270365,134.884679,133.403907,34.147578,22.303865,63.52975,127.899039,136.947534,145.7925,135.094965,11.613761,-48.4237,36.131476,227.842378,251.436143,134.823445,60.441796,28.756524,55.880197,89.825843,82.142501,89.104532,180.748192,244.520649,284.844195,240.883051,94.331365,61.941996,144.811723,215.802894,209.484484,166.127356,139.046682,93.383037,69.126697,-7.099908,-52.915264,-56.126795,-32.096035,-5.87778,-0.187862,-42.908248,-192.310873,-267.351198:-174.904513,-57.986576,-40.510112,-6.493379,8.850712,-4.833167,-31.194919,-61.485762,46.562557,125.084371,221.707537,228.22605,159.706493,105.152058,31.847646,16.483465,6.652902,44.793873,63.361564,22.394833,-14.066912,18.988055,70.893208,115.398752,133.011515,170.554765,280.439879,312.119724,210.626866,103.527914,-57.138529,-67.306749,46.116186,97.701235,54.330328,12.108765,59.187995,168.969802,185.303666,188.738055,241.167436,286.680028,363.440974,348.022087,219.845841,161.152298,80.93158,52.127398,59.206805,76.975364,59.580186,17.262175,4.160089,-18.370775,-32.817043,-56.538311,-32.817125,9.939617,107.338609,111.026376,10.671686,-34.777304,-69.132188,-75.627063,-14.470562,112.752608,146.398995,135.704024,128.550505,176.468651,199.264145,179.02739,139.342017,120.352365,60.157575,35.182077,21.26988,15.634597,-18.526333,-37.119365,-63.37204,-109.243915,-141.093838,-185.660418,-191.235331,-230.425251,-273.886032,-265.252429,-74.073748,3.548525,50.485364,44.674278,30.620101,28.710889,-17.42825,-49.575633,10.67712,121.838031,128.504161,146.398392,177.004466,187.151305,164.604096,174.661066,297.221966,346.158272,341.616041,308.915001,240.464478,193.833035,32.418969,-24.832997,79.553392,239.004413,222.112069,60.662686,-24.365411,-120.828197,-112.364236,1.460963,91.236527,97.325341,93.857311,83.289638,20.981554,-4.353035,-23.500602,-30.366502,-6.624767,57.399904,108.759188,259.928614,293.669501,163.89571,50.528839,-74.416628,-0.463555,70.524628,184.62099,199.270246,102.317481,23.718096,-47.642444,-24.006955,60.841738,38.467862,-28.332273,-158.281908,-178.168746,-124.243475,-81.300213,-40.372273,-81.356495,-119.634076,-151.591925,-146.458766,-227.73716,-300.079594,-336.049504,-310.064784,-251.768963,-168.017297,-125.05548,-84.356613,-102.337865,-211.462446,-293.836774,-425.463096,-322.363903,-218.991331,-126.372664,-147.694315,-214.664062,-227.887337,-220.399153,-214.654583,-173.707505,-140.857986,-179.487209,-313.693478,-340.190225,-275.076982,-226.491576,-134.386715,-61.204875,-63.377304,-75.025179,-46.836155,23.760717,44.966832,2.768577,-61.581706,-144.362502,-117.262907,-82.926096,8.179578,53.441765,109.211799,110.904851,58.645241,-9.330719,-17.590908,-9.103452,-6.469896,-16.82178,-28.426019,-62.857242,-62.142755,23.816777,64.973742,46.176352,37.173197,45.853431,45.418416,42.339933,17.726556,-6.164236,4.120348,54.633772,59.967463,-38.256467,-123.423276,-258.973482,-257.85071,-89.814151,94.339581,125.223674,51.116901,0.564646,10.04022,44.318681,75.018121,113.752824,136.415902,136.620782,114.502419,113.374246,155.318897,189.45425,135.270996,12.645259,50.153413,86.101546,51.644597,-21.887483,-192.833971,-248.234442,-246.208396,-199.628416,-194.822255,-183.037845,-181.710726,-213.21825,-232.5415,-303.283077,-359.129168,-379.029599,-228.696236,-151.410174,-109.461007,-137.862109,-162.155017,-134.825278,-59.200055,12.08761,46.41065,121.89781,160.249087,166.645556,109.451852,-67.665654,-114.714571,-42.117193,52.419382,64.078703,95.832778,117.939274,121.627956,99.142291,91.926864,167.904234,183.565591,151.203388,121.594131,79.429797,87.351946,122.326786,113.432186,25.60339,-16.473506,-0.041918,-30.934206,-84.098664,-142.002986,-131.014719,-99.203519,-116.525186,-133.368896,-132.695311,-108.593902,-11.075747,42.358194,62.552603,43.899785,33.446714,31.457188,36.401226,-24.777871,-134.918362,-374.638248,-418.298838,-382.291818,-342.223968,-290.865492,-65.971002,23.827004,-19.120175,-84.416302,-63.98009,16.013957,190.533663,264.349343,240.131345,122.360532,71.804407,9.996051,-22.688705,-69.901466,-31.704984,-3.463391,20.936982,-4.258324,-90.97057,-120.554254,-199.142622,-217.020578,-79.787929,-23.495597,-90.286638,-218.12169,-251.996646,-285.871298,-274.327003,-180.609831,-92.422806,-75.110543,-30.248284,-2.662491,15.307656,25.478274,67.982259,65.416551,0.869155,-77.718965,-108.573782,-69.134615,-2.762836,53.191239,12.442893,-35.15041,63.555743,83.913422,39.326495,50.881268,134.504614,130.037934,19.638323,-10.378274,78.144797,190.832073,190.321722,108.86995,71.783511,77.961786,112.241094,164.766429,153.181818,127.988956,90.193385,77.039467,39.758813,9.043246,-48.759549,-19.912859,171.202847,250.205487,188.973229,36.570843,20.400643,69.473276,61.644091,-18.248155,37.279539,99.634965,155.274673,139.587869,24.509066,-54.770462,-144.036473,-137.170194:forward
165.102374,170.073396,173.549873,215.193354,237.793718,188.45083,149.227314,186.884883,237.233783,221.199894,184.891187,187.153713,192.7422,160.371371,63.456314,47.346343,74.175404,105.531321,109.958233,83.217454,61.112685,16.637881,9.973482,60.224233,95.838923,98.178967,90.066229,70.284222,48.118811,51.851946,47.255151,45.150524,47.013373,28.470577,3.248317,-66.234046,-77.478479,-43.921865,-42.237339,-96.898272,-106.976517,-78.750716,-27.027808,-23.304121,-47.796775,-66.552264,-64.116428,-43.144542,-40.288527,-5.327271,39.367289,7.158533,-101.617344,-357.21011,-419.089529,-365.154212,-244.59566,-204.465888,-185.620151,-194.660424,-208.705071,-221.120015,-247.488689,-246.171443,-233.18037,-227.931474,-217.895683,-146.936356,-96.282783,-93.960369,-160.749552,-277.941435,-226.734152,-165.055274,-55.352569,-20.747525,10.29895,4.388466,0.109982,20.985957,55.616612,138.948676,212.89771,313.165888,320.955555,270.426678,240.467662,210.016625,151.734982,122.997931,107.47256,93.547237,0.870722,-59.712522,-108.214903,-72.396134,39.993326,118.669348,144.018246,136.355316,101.171023,28.364392,31.313751,100.396562,143.981242,183.085102,321.447061,371.943341,356.456384,314.659786,284.283589,321.388647,431.908458,460.56756,433.510498,345.702148,304.121913,203.951791,167.800062,213.408247,313.040156,342.300526,369.176665,372.237797,290.574491,184.392221,10.921188,19.544863,147.34347,237.790603,250.498885,254.995118,264.40427,252.053342,227.215614,193.464767,213.15905,238.340283,261.846515,251.81937,191.451725,134.952112,30.556497,25.715558,82.300201,103.651446,110.350337,151.431095,151.449138,83.182946,69.306489,98.229203,51.607065,8.422829,-44.384045,-72.660186,-211.275445,-292.543878,-332.976139,-283.574449,-174.247727,-92.250103,-27.906344,99.964143,113.870897,13.482644,-35.022107,-6.780835,74.773151,96.787354,89.483058,89.351251,135.756201,140.735833,104.385122,117.325563,219.400655,292.134722,283.840056,185.662127,131.103775,32.430492,-23.625714,-143.027375,-231.004315,-237.728656,-221.26908,-209.516784,-159.476272,-161.172932,-223.809031,-215.132788,-103.125492,-1.591169,27.969247,25.306443,3.208765,-60.297024,-86.902156,-61.892308,2.80404,16.034293,-19.266623,-61.966373,-97.885888,-73.665078,-13.69347,13.513093,95.356234,183.653322,206.424957,180.817293,118.263929,-91.313615,-171.508614,-150.205703,-36.344291,-24.297221,-133.388744,-215.119776,-306.744808,-318.699119,-303.164996,-267.411559,-188.557338,-152.760139,-132.072894,-58.107611,4.573866,66.815817,13.184752,-70.146977,109.775387,209.908719,166.350352,42.999562,-146.446459,-187.891805,-235.981944,-238.404018,-187.386603,-87.296543,-51.735476,-23.192899,-2.316355,-1.971325,-59.2471,-163.354167,-64.451499,4.337096,-26.211119,-113.839348,-279.68755,-344.690177,-430.403958,-442.455434,-426.322981,-324.253261,-269.180424,-268.004113,-315.701774,-421.263586,-449.587337,-423.392769,-300.453443,-215.610325,-101.530835,-117.368497,-251.045872,-315.412848,-332.469387,-275.753355,-173.741192,-200.033627,-221.364516,-197.848425,-154.804536,-108.095269,-120.55661,-85.881168,57.625015,98.049396,101.480241,95.826086,26.477194,-39.112961,-126.185497,-133.786037,-87.631705,43.773216,94.191223,82.21675,36.349072,-96.696009,-162.615928,-175.27809,-57.548344,0.388913,66.437935,58.809172,-31.001504,-93.861314,-190.025094,-202.36955,-198.035097,-152.611839,-89.632143,25.919725,38.377729,-4.136718,-18.611463,57.689147,218.050028,282.514602,372.754782,390.700918,345.293109,296.23406,211.857406,201.759892,230.073731,251.219121,236.379649,126.340077,62.521858,2.945848,9.662248,42.077811,5.750232,-20.01308,-24.05686,-12.792496,10.758583,18.353563,36.538014,67.689118,179.113258,268.628382,284.339789,268.887115,231.008625,90.232163,45.13413,118.976876,215.398283,223.037833,236.035506,246.713305,244.96952,209.899774,100.380781,93.807964,189.305274,197.035373,148.319074,46.969787,19.268977,-37.935662,-74.453606,-25.383935,159.316128,214.457047,225.700695,221.929812,213.577015,205.816962,268.833563,335.018357,402.608449,378.26394,357.396208,272.416997,198.253357,46.931123,7.438663,5.815176,25.023437,37.90005,74.514621,85.156039,76.601079,51.458221,-7.22205,-7.698643,56.047032,139.480744,132.764185,-5.956748,-71.41189,-142.455653,-167.73238,-145.488434,-33.395708,8.957068,24.00727,6.078882,-77.635139,-151.483651,-277.288187,-264.16195:48.165374,144.071026,189.806001,181.27008,155.079096,115.619565,134.364027,269.07981,311.194856,285.851715,255.473185,243.523152,181.425506,134.229622,56.994532,56.399112,163.119848,229.088671,177.89686,41.060789,19.505195,26.775174,31.693288,61.043627,84.125516,87.203262,124.080714,161.353956,203.634092,187.335095,127.02795,115.2791,150.728251,138.18527,71.845542,-70.724717,-95.205851,-85.391055,-80.201317,-57.773235,13.48695,38.678873,-5.729824,-59.368926,-183.928805,-245.557097,-236.550413,-140.903103,33.454999,27.620407,1.307365,-61.237064,-117.079878,-267.605686,-314.100402,-284.822812,-208.821556,-188.7315,-188.512549,-197.1275,-236.534048,-266.409789,-276.203558,-250.797307,-157.613609,-8.945632,38.789006,18.367913,-28.175443,-139.344129,-189.093424,-221.186815,-115.018584,-39.272163,5.822567,-20.042878,-31.139947,-5.286599,58.897764,81.775013,91.650825,115.152571,147.393038,196.510047,176.768751,20.939407,-56.487732,-53.485969,54.745056,84.297753,87.167257,79.558981,72.47787,76.591407,66.148441,36.541453,29.35958,163.107667,200.933405,106.397128,35.565298,-0.466319,23.908745,83.689346,140.187345,193.714484,308.501946,304.061575,190.196263,154.887776,184.012323,224.075311,352.104377,431.498088,388.818129,227.891562,176.069523,155.033483,166.02395,206.855915,293.637333,349.709255,383.625607,342.951463,209.460425,144.915446,84.222148,88.740836,132.802742,221.615589,240.319869,182.176552,154.462683,173.388423,192.097118,184.529714,181.192704,191.82909,169.120398,130.897135,41.420308,13.464064,37.941426,66.971592,102.478402,197.654461,276.170542,363.931226,340.249673,225.16152,178.077237,135.203793,144.91175,152.332455,77.614482,-10.244143,-195.767078,-266.637718,-299.930052,-237.846919,-64.605116,20.789745,46.578544,115.272874,138.130101,93.041393,60.505403,87.395088,164.693558,184.083221,177.456159,174.009746,209.566768,214.737576,123.870789,73.290488,103.07788,190.583501,183.743905,91.270388,40.568082,-18.142685,-34.815902,-102.365458,-99.131302,-55.672883,-55.484024,-109.320453,-182.105327,-168.467487,-83.176662,-52.03337,-42.971757,-11.481322,19.614682,67.530412,66.341372,-15.717273,-72.073086,-109.142186,-24.58999,38.343656,88.572083,61.842234,-9.951698,-37.108959,-65.312702,-60.555112,15.992197,160.694719,181.877849,74.030354,-0.703159,-124.862053,-170.421753,-164.20182,-93.701978,-86.238495,-92.193194,-101.574296,-185.195126,-243.203265,-270.310211,-241.065562,-206.183651,-144.874547,-84.134814,-1.358268,6.540295,-48.925339,-92.950817,-75.778331,76.232711,134.704611,127.726033,88.689855,33.006267,-0.433678,-97.292599,-119.906663,-78.786232,-48.817189,-52.611295,-27.76405,-2.313828,-9.476902,-41.36753,-50.515252,44.204176,80.846297,11.402062,-82.07325,-225.2482,-268.182906,-364.755148,-403.520374,-422.524358,-383.330702,-361.460584,-367.566256,-390.12733,-427.738218,-440.218444,-421.026309,-290.243567,-206.743128,-128.426837,-149.875287,-278.405538,-357.520997,-393.2684,-324.153282,-175.208023,-195.246488,-246.840289,-283.81915,-254.079739,-203.243627,-189.701859,-97.731131,58.100793,95.639674,52.942954,15.442537,-29.051042,-61.713884,-176.289904,-216.617683,-151.727589,36.133995,80.039548,-4.593204,-85.669693,-226.726676,-270.051554,-236.416303,-77.767313,-2.67402,64.820579,39.564499,-119.46205,-208.657137,-237.602526,-189.944064,-136.906439,-75.289452,-13.045936,53.899768,39.04391,-9.647285,-6.610991,96.081823,239.162309,272.482206,240.975812,198.150872,89.781562,39.799425,38.05997,89.69189,198.655592,201.451317,147.120749,13.040325,-7.777509,100.16261,181.084248,150.531036,-104.10183,-163.892434,-116.108081,-81.708575,-43.255006,-30.119848,0.83815,40.085907,178.36347,294.415154,307.656731,231.70867,165.913365,75.13028,82.723494,142.133053,140.46182,150.431707,202.29733,186.729767,23.691113,-76.481847,-114.841442,-21.718825,165.450706,152.152729,110.668697,10.039763,-43.340541,-128.867259,-143.606271,-36.069052,130.15072,150.146589,120.181233,125.250201,190.830084,221.47597,237.879054,239.41026,301.605558,340.039767,279.614345,116.212228,97.715657,106.902486,68.129297,-14.949809,33.826604,90.371314,163.597928,167.117115,161.132403,142.010831,72.7945,78.652991,181.751013,236.900417,218.60817,84.860059,-11.400369,-213.224794,-283.67385,-257.320569,-116.808179,-74.425745,-58.56161,-67.473883,-135.873724,-197.655624,-277.576966,-260.838837:177.021662,230.759582,228.274482,194.504408,188.159737,204.362868,236.650109,371.54557,426.64437,387.215489,296.942501,268.874739,179.465364,116.82563,73.217213,95.865901,142.547297,195.707995,199.383475,87.182087,24.99755,31.921283,72.99069,115.751002,104.231623,105.080009,144.946206,163.770639,194.113814,222.340364,266.761924,254.605666,180.071538,140.041159,133.944415,112.441429,86.419018,-15.778289,-53.665194,9.333816,160.262571,183.978635,69.861879,-9.501329,-99.042738,-128.702947,-146.175232,-105.062878,15.171889,35.167036,-2.789593,-111.168645,-171.626995,-276.810576,-275.494717,-142.955864,-8.772048,20.2954,-13.075802,-63.777224,-179.043632,-210.984153,-157.52956,-104.205527,-46.335524,-28.548729,-19.947869,-0.627997,-4.222861,-59.091947,-104.257649,-185.593426,-155.000201,-99.092703,-21.726068,-20.434261,-48.92451,-52.837759,15.165264,57.517074,65.449961,50.929744,55.510475,36.532062,3.672474,-64.942036,-78.922251,-41.830528,68.590132,112.43756,96.090659,47.314107,-36.071885,-36.109712,45.14855,91.969535,150.387236,184.113091,166.33436,45.631624,-7.799154,-31.176885,-27.692056,-10.852446,84.550387,145.167858,186.875641,148.368664,58.605966,54.394201,100.357141,127.275501,212.32789,284.931189,257.615982,128.768638,87.397609,84.23819,113.731673,232.105431,310.214189,283.408139,204.541906,212.913335,242.793499,206.278653,95.243555,68.246065,82.701067,129.417032,136.823301,128.562699,127.729427,150.565774,173.208452,188.469194,189.201016,212.331796,240.876356,227.82787,156.155735,115.468486,88.178683,101.92045,156.86248,222.110562,236.496494,201.340493,153.049895,41.36482,22.024455,79.089082,126.34014,129.328014,94.76779,36.913435,-134.575751,-190.229425,-181.28062,-155.253299,-108.990067,18.007436,91.718207,132.286367,99.163578,34.506269,52.735999,138.163978,92.778424,72.442092,151.049003,185.279477,164.58811,154.678103,155.893752,140.155486,129.327685,190.821459,196.966549,104.130072,32.280881,-42.177538,-27.634331,-3.121618,-29.604747,-42.228014,-93.071394,-130.694382,-197.521329,-219.578847,-195.124685,-144.78808,-36.193163,4.694777,-0.063085,-4.134892,-15.85904,-111.454769,-143.603406,-47.379138,43.251426,16.609754,-48.14635,-45.029568,-47.423803,-68.649458,-68.734781,-45.996191,-20.657263,-18.875711,-14.337468,-44.250694,-81.294426,-136.303701,-146.207666,-134.954634,-99.388236,-79.109625,-40.645435,-45.555892,-126.818315,-181.902803,-243.134048,-235.66541,-149.523081,-19.27046,-3.497619,-117.142498,-173.796989,-161.35652,-119.616366,-12.484121,151.413741,212.150114,178.231296,126.205772,54.863419,10.482906,-55.572149,-46.104482,-11.00906,-31.670966,-58.834969,-73.671242,-36.733967,18.277873,9.789644,43.896784,137.915307,152.344421,92.319512,28.862253,-130.045791,-212.055132,-306.190279,-310.54635,-301.098687,-242.300334,-191.992281,-153.672016,-187.374611,-277.644962,-276.86554,-216.161031,-205.028766,-187.173263,-131.63459,-138.374967,-246.534539,-294.658803,-239.66695,-167.932885,-112.489761,-193.043174,-224.331759,-185.923865,-149.251032,-95.900744,-44.048336,103.046523,101.706995,44.054738,-12.195205,10.291173,33.003157,-3.302195,-96.949977,-105.656294,-37.766389,28.366678,26.471571,-40.716941,-96.358267,-215.481318,-232.543085,-136.789085,-46.629167,-44.67212,-51.495123,-32.91883,-63.845404,-132.974954,-191.308112,-161.42188,-105.249573,-18.165056,49.326303,132.705858,120.632487,42.082524,31.253528,156.552525,323.178898,331.459709,243.268789,184.803982,18.041379,-70.756947,-115.06388,-62.803926,59.11913,94.737143,82.913355,14.729798,-19.78894,6.063118,76.805698,164.049669,31.475409,-28.085391,-14.789914,20.152993,54.020478,40.436073,8.630102,31.442666,161.713637,276.560249,283.085717,204.311399,142.798564,32.565054,9.349351,14.731702,50.149669,98.661691,191.31967,184.470055,62.959234,-4.573362,2.578123,86.866391,244.857411,243.735383,200.678871,64.603811,-6.457606,-76.653554,-62.602219,80.001533,247.460901,275.564237,246.976355,223.095927,171.54594,149.518481,181.782639,235.725327,339.706932,339.610951,284.193857,131.374378,56.991198,-35.829975,-21.136243,85.471763,151.274491,173.575934,215.128445,225.782567,189.593475,137.639709,70.199425,94.790881,194.063792,228.780348,202.819324,58.551091,-31.444415,-122.700106,-114.001382,-107.401166,-153.508502,-150.706374,-98.082973,-79.709497,-94.874999,-117.997783,-112.557685,-76.63411:160.598067,163.967937,188.040915,217.984918,209.850425,197.6897,211.82966,280.972813,286.208091,260.468927,242.230757,241.727622,172.441148,107.648597,18.198884,2.514643,9.38345,64.324919,75.669896,49.993292,32.747238,-17.135378,-34.519436,39.414582,164.829944,194.082641,194.924835,175.97277,130.979216,110.071614,71.072443,60.823518,72.965134,101.434358,87.824195,-7.015395,-45.606869,-87.015634,-109.371895,-97.057582,1.736589,46.75133,73.468413,48.874802,-88.281921,-188.290659,-291.593826,-242.002766,-46.414348,43.383314,9.008261,-181.010673,-284.627027,-423.499485,-441.688379,-336.028033,-159.576204,-111.48329,-112.478938,-129.070496,-139.102515,-147.264797,-162.98388,-150.958213,-104.589426,-50.914861,-37.149134,-63.361016,-74.721191,-57.678453,-46.571736,-71.68965,-120.372057,-96.534492,10.230777,41.507033,49.522625,39.394549,-2.529521,-7.462807,64.564574,136.560767,145.856281,117.932387,91.054869,74.821569,95.720278,123.288089,122.698557,143.923721,149.153367,98.844696,-21.600445,-48.242185,-37.538265,-22.401374,6.767392,72.199769,98.135323,55.700801,-7.869764,-109.148064,-103.605297,-38.636267,21.409439,85.774443,234.705309,256.135081,183.799306,132.74531,107.629493,141.260985,227.99919,296.627961,295.856338,218.161388,179.638998,116.138472,92.033947,121.185651,231.484241,290.379761,338.924273,307.366725,180.521088,105.262599,-24.409457,-53.310151,-23.981805,87.738175,128.406071,118.368465,102.154268,108.362717,125.428051,158.498416,216.374165,262.732694,288.798861,256.666871,179.195046,137.596858,31.349088,-6.880714,15.913918,75.171989,85.023836,103.852462,105.467977,30.413624,-33.652768,-122.009059,-64.353684,-3.808008,-4.177113,-82.843764,-253.434186,-310.914936,-355.972345,-328.238824,-187.048057,-42.321833,0.622092,55.431046,71.118254,24.409615,-14.238486,-27.118213,5.7101,44.570184,138.588031,156.024084,142.86596,129.835335,96.563203,90.388527,127.897341,204.164713,204.302535,107.399778,64.489103,-6.369284,-66.863739,-171.624793,-121.284875,-59.704553,-9.10998,-32.464773,-94.619787,-125.361159,-161.472289,-134.71253,-46.53443,-10.706527,-6.506557,-10.821173,-23.378973,-81.430566,-97.889093,-50.149724,-23.827194,-36.408415,-53.738332,-61.881639,-120.819186,-167.18308,-166.052566,-96.447106,29.261723,52.837929,50.958221,-9.863649,-75.613174,-168.929412,-159.978492,-97.274218,-89.049001,-85.539675,-45.925996,-56.413336,-207.824772,-296.497518,-327.737805,-278.075784,-179.25771,-127.527488,-119.391648,-59.637461,11.407331,62.13545,10.938964,-10.61739,167.894258,235.254388,190.002023,109.045279,-41.596244,-98.167883,-164.141487,-177.181112,-178.881721,-72.526218,-19.380966,-52.926356,-87.594824,-73.151863,-53.176382,-15.708356,82.74071,140.549428,138.85154,55.254679,-195.508922,-308.746948,-380.10222,-337.244354,-257.846265,-238.362952,-217.375772,-195.532476,-224.479772,-327.602977,-349.820144,-295.980962,-197.314986,-141.434234,-84.615578,-116.115875,-255.835726,-311.329217,-280.783668,-211.043986,-151.551164,-210.342872,-210.112369,-124.966233,-76.356266,-63.850117,-83.976065,-38.869451,55.163242,63.777532,72.969753,91.164778,54.52628,-6.957093,-95.572915,-91.179919,-2.111009,132.559259,187.506194,174.853849,100.999426,-71.401582,-118.960488,-96.789631,-17.511069,7.012198,7.31724,-14.714036,-83.762724,-126.339776,-189.132852,-194.526215,-173.249137,-59.3222,31.637112,133.541017,131.198863,121.3809,123.504256,144.239734,241.339114,284.541039,291.297073,280.894072,251.823928,213.479384,159.260715,185.890382,275.544947,275.558424,243.864108,145.772176,88.702498,-18.65029,-46.656985,-8.156838,48.497776,41.888383,-33.092142,-61.654565,-18.958024,16.198157,47.54285,99.393516,311.618299,419.621312,391.402408,300.48882,281.445853,231.737811,176.458025,94.273593,121.644753,169.798261,273.861347,282.833571,186.703158,109.435105,26.910443,61.813685,166.27828,174.700207,162.76528,113.645958,75.200567,-9.777566,-33.713619,35.155289,185.498831,233.903892,237.947883,206.037723,130.833212,119.309289,212.413673,276.413645,288.193648,238.702515,234.743357,165.764484,83.733226,-36.091312,-30.308253,39.399869,33.881448,19.730297,54.480309,84.200713,96.573038,71.037158,-15.204875,-43.63988,-14.40503,112.820053,142.557488,4.363666,-101.036001,-176.047878,-155.194868,-119.231115,-89.843499,-56.049993,-7.068549,-18.522509,-80.693865,-98.285671,-76.069163,-65.61522:163.2116,77.337622,44.261421,-17.805438,-53.962001,-47.981083,30.045205,232.298696,273.093528,248.29833,212.87858,201.228186,147.932459,98.633844,5.29725,-17.185272,-22.892014,4.773991,13.074447,-3.665098,-31.791108,-110.510294,-114.178963,4.582999,134.559554,159.784995,159.481923,148.105627,109.90971,92.63995,93.017549,109.435987,160.738622,170.820123,126.656776,-3.75722,-50.424062,-79.685482,-70.937828,-7.749867,131.018434,166.945035,60.790363,-21.595837,-131.743508,-191.182184,-295.316417,-280.696562,-124.101748,-14.616302,-19.110245,-57.88133,-78.73668,-184.433602,-238.661898,-191.209674,-7.746168,48.411252,35.026467,3.199096,-47.324005,-68.918517,-58.520084,-30.80427,25.26802,86.134983,93.044135,72.08438,59.725592,-20.821439,-80.654295,-146.258328,-76.37455,-5.661349,83.61778,76.842189,-5.242899,-45.190003,-33.294361,14.290685,116.152348,142.919582,120.188088,75.860624,68.890639,37.707325,28.005479,96.494013,237.874388,270.614335,161.076954,58.449595,-86.083043,-94.600334,10.660564,76.463442,150.298153,168.86812,138.838198,1.344558,-69.019021,-157.546724,-170.262236,-96.569614,68.831891,138.704444,182.952694,165.53501,99.953576,44.394521,-63.709818,-68.961174,38.452554,205.140151,238.019801,138.339362,49.778574,-98.938748,-121.32239,-26.264474,125.827943,174.689376,189.901496,156.263133,15.331701,-59.549299,-116.605343,-99.331588,-26.62977,59.384087,85.100531,90.331548,71.629927,18.315945,27.265124,120.257948,206.717544,249.19397,272.99611,242.492324,149.051019,89.708709,-11.767415,-15.342066,56.760387,108.170763,112.812316,50.314676,-34.448837,-180.813369,-163.74304,-37.41412,17.245336,29.507997,-11.821261,-93.674527,-314.921252,-384.444569,-316.036023,-216.346729,-83.8234,-40.543701,-4.21419,78.001273,70.416596,-63.307784,-110.569291,-40.904955,99.107647,147.601413,153.508277,114.143399,55.666332,58.083466,86.69628,95.018266,87.87309,104.305373,111.58029,46.502541,-10.048837,-73.614033,-64.759363,-24.770674,-20.455869,-22.670624,-45.195907,-67.606837,-128.407316,-157.969233,-145.287812,-105.05206,-50.545898,-55.678815,-58.589924,-73.27961,-102.351617,-155.82738,-141.504207,-40.636062,57.477731,64.36402,-55.070792,-135.186292,-212.043316,-207.815913,-151.321337,-106.520682,-11.27822,10.336423,-37.453506,-197.74823,-236.982958,-198.105131,-174.071347,-157.970026,-96.773992,-45.28925,0.217481,-31.201726,-196.703758,-305.238805,-387.513352,-339.335345,-225.279021,-161.106048,-145.598148,-120.202553,-84.023345,-27.644884,-32.267139,12.285965,195.470369,271.464957,221.325143,95.8169,-169.106949,-220.672956,-72.568205,42.138253,120.602018,104.708493,76.720391,-27.042394,-70.12233,-115.365943,-107.514527,-5.890146,131.288522,167.230191,113.992676,40.628258,-145.223721,-247.026828,-340.098544,-299.24589,-180.246566,-121.839827,-108.802207,-135.326997,-174.175595,-255.348504,-283.81033,-296.817861,-204.709628,-133.254649,-89.756463,-145.363387,-299.987042,-328.371989,-225.789943,-150.723641,-106.579537,-136.391068,-126.08973,-42.813151,-14.16454,-51.934533,-58.705054,67.465785,179.390752,159.024713,66.017647,49.633338,45.400744,13.6771,-85.97894,-89.187716,58.648705,197.701814,198.227914,116.713634,48.28371,-107.120699,-136.237134,-59.30729,42.572449,67.512244,77.05464,59.655725,-36.899639,-91.779868,-124.998617,-110.794413,-73.925661,51.621313,133.995189,178.316929,135.622349,37.927068,21.66674,87.218915,239.70207,313.007911,342.505466,281.215158,98.485494,26.73357,-7.693375,14.048756,93.116678,159.785819,127.53653,15.343786,5.624553,49.508264,78.083885,118.819409,63.542692,23.429358,-20.46742,-21.344498,4.596754,22.248884,71.416226,114.025838,255.90491,388.423765,396.239822,323.379089,264.983689,93.761223,20.438741,4.82882,101.296567,176.138058,295.748444,290.984852,149.382342,59.892393,17.290399,87.808218,245.957499,276.568212,258.96176,150.830902,66.299027,-39.006089,-10.607167,168.37935,307.473034,322.888891,241.533096,167.210993,54.716999,47.375216,124.995291,154.365934,130.74401,146.836864,154.140234,77.838884,19.273228,-67.376975,-97.020921,-115.650482,-16.310185,50.945375,109.073751,91.225819,-38.000212,-127.649021,-167.231033,-85.075165,104.996506,167.531427,138.538558,-54.84537,-180.097522,-326.11604,-307.121323,-157.134503,-43.81291,-3.094708,25.14717,-10.903938,-119.498793,-143.964124,-110.379321,-92.088876:97.566722,127.30629,139.040278,170.64495,195.216839,199.308673,169.603403,138.55027,147.366566,135.593751,91.369257,81.807071,113.25899,118.914519,68.764555,53.023398,43.466915,8.17831,-0.003573,33.991071,69.948662,108.99321,92.202087,14.977086,-43.14301,-35.12539,27.020638,40.269356,-18.644179,-66.908374,-121.487547,-123.625523,-69.455643,42.425791,61.062652,-32.578286,-78.051452,-76.446567,-66.603709,-84.175036,-122.933268,-126.693102,-91.383305,-69.673955,-54.555635,-72.304503,-126.086069,-115.277738,-9.950691,36.800568,-3.123976,-182.588255,-287.31947,-422.171552,-402.812612,-201.466886,-79.739062,-86.603852,-111.253923,-103.256452,-88.475733,-114.534262,-158.746339,-120.341808,-43.398846,-112.546494,-153.461759,-189.226849,-188.257877,-168.932679,-152.384417,-85.025398,-6.634684,22.912198,69.016463,77.318883,50.439206,27.201248,14.431353,29.46755,41.546194,93.076683,154.088658,214.15596,199.004227,186.811295,201.732791,225.831634,255.873842,268.308134,211.120997,144.293242,24.580734,-24.870916,-112.938498,-119.625547,-63.956741,-44.083764,-57.742327,-100.400601,-120.977653,-164.83725,-177.348658,-99.109945,45.789122,73.303394,68.182512,65.008268,45.935104,42.225529,100.350312,147.418219,200.819878,222.18553,247.148452,270.644579,240.048314,150.762751,138.728057,200.077634,263.83649,274.074295,296.474273,301.483454,179.711316,44.883945,-145.759949,-123.77825,49.206742,210.907267,264.996822,298.882527,291.133605,223.985473,178.863852,163.130365,184.856394,183.961257,216.841793,246.611579,260.73713,237.864647,165.645718,132.161424,67.985651,30.466328,39.840726,77.431158,91.535279,63.907388,18.374917,-60.887674,-61.049319,-43.237893,-91.706848,-182.34905,-373.99259,-420.957433,-379.167587,-316.837731,-222.020355,-162.908736,-110.881619,26.727281,68.452125,0.905431,-68.018837,-84.558789,28.239717,93.710806,221.367303,253.478928,237.471584,212.495579,175.972369,170.494945,176.993403,241.473524,275.075829,214.331809,130.31007,-20.261243,-70.448205,-156.173676,-207.456787,-195.634642,-184.721304,-215.0379,-259.749716,-271.999815,-325.371803,-318.96621,-172.690843,-40.021377,-51.786659,-160.059566,-184.591995,-195.085773,-210.906085,-167.470551,-52.42004,-42.292111,-116.993217,-153.318193,-131.869333,-95.86988,-72.094428,-67.189538,21.949634,146.420328,162.106091,65.423061,-16.05308,-162.429017,-204.542867,-194.048324,-79.60956,-13.482957,-8.311546,-97.3179,-326.292642,-388.774081,-326.206627,-239.091328,-135.202069,-188.254324,-209.486234,-135.551758,-66.704634,-15.624446,-45.414692,-11.495251,185.373086,240.235362,154.9861,45.570658,-159.84839,-232.422838,-291.167537,-260.887854,-165.115081,-159.811667,-184.615712,-198.085405,-165.817483,-133.685568,-167.985132,-197.415247,-33.569328,53.730142,19.463916,-87.93865,-276.686778,-339.370495,-427.444902,-432.499121,-357.422542,-243.216562,-208.020314,-246.79448,-298.422069,-346.90556,-335.977636,-290.00295,-212.243075,-157.741236,-96.253829,-114.101421,-212.27876,-264.462112,-294.963823,-273.073646,-231.969744,-210.624988,-197.637741,-175.447431,-166.406454,-173.71659,-183.520204,-134.732636,-36.813788,-27.20155,-53.490416,-52.88481,-66.354598,-107.573314,-218.761864,-235.486107,-93.54353,114.070863,127.844832,-32.609932,-131.093418,-234.426733,-223.3423,-117.032124,-2.081028,46.34809,99.853252,83.321314,-52.084867,-146.750301,-240.986124,-202.987733,-83.8374,-62.929107,-60.382731,-18.899012,-10.064273,-65.519652,-80.794655,50.129915,262.718973,315.426086,327.452898,317.323099,277.474223,259.175969,287.114585,319.486539,315.74332,293.243526,283.541805,169.823467,99.534881,31.222518,24.575031,26.73661,-4.102407,-19.356662,-35.058686,-52.542696,-77.133517,-47.527206,100.918901,185.310523,299.118646,342.135864,346.167579,291.316939,232.430376,78.182384,11.695363,24.875735,229.595658,316.569031,345.593552,330.530894,326.747539,307.166175,219.05233,187.351047,192.176539,287.401137,312.14131,218.485197,138.007255,18.469317,-9.77588,-1.195492,51.035262,91.33635,202.586309,244.195053,227.437243,176.868885,151.664134,219.008549,381.121787,436.721167,415.696179,254.738454,149.884064,27.616604,15.747646,29.445006,53.003058,62.775392,42.093419,22.120749,37.722933,57.667147,45.412543,31.546088,52.146839,95.021439,96.876735,17.17135,-42.87609,-96.730839,-79.868021,6.913023,73.361896,76.305204,32.277147,-16.507856,-118.152905,-136.28447,-129.871318,-137.633502:1.913718,55.851908,66.902332,37.039831,17.685125,6.698638,21.537028,81.141221,96.525799,91.878241,62.076103,32.999389,2.244259,-1.645147,5.672416,17.40995,10.974226,-2.558465,-15.075871,-121.479746,-187.80016,-206.324716,-143.257238,12.797565,51.54322,46.091485,28.521666,6.476565,-64.162187,-113.570564,-161.266776,-126.61241,-5.593662,30.475796,-11.68778,-150.185645,-197.629877,-213.060653,-200.210548,-175.976701,-150.370027,-115.420637,-70.41187,-101.549769,-231.488569,-284.07605,-260.040937,-200.103736,-99.864381,-17.372569,-8.324414,-139.145697,-255.153023,-420.812878,-412.527244,-238.547938,-64.223881,-13.444802,9.63542,-4.48085,-58.446975,-95.607255,-80.282323,-26.498306,36.223082,48.280223,49.388617,11.346337,-22.29693,-75.187653,-74.07906,-13.946456,79.757208,132.612297,184.177105,168.853068,86.577988,34.668437,-15.721721,17.40516,170.150416,249.000545,215.101941,117.471446,102.807346,119.665111,146.208557,233.632321,295.297499,303.674708,263.664638,211.640329,46.305219,-35.299556,-46.634046,13.17784,70.283846,46.838814,47.242955,10.7926,-54.307869,-208.59625,-220.105693,-49.202338,116.419634,124.202709,60.542429,35.515542,19.758295,-4.502866,-56.394578,-32.913581,87.558648,179.913981,199.073969,141.878935,55.625892,-113.035313,-120.046368,26.585678,173.249339,199.910629,167.36994,117.056712,-44.913979,-134.512991,-192.761029,-143.944201,6.90558,160.409694,198.573304,138.883658,83.797325,39.752186,74.412272,197.987017,292.879727,333.476263,353.00568,324.84794,238.742335,172.408121,56.376181,77.36933,225.830575,223.535089,158.168194,37.633303,-2.334704,-65.560712,-83.849668,-67.619562,-26.056068,-21.601208,-59.574473,-116.955463,-298.619747,-367.453827,-343.109887,-289.353343,-239.653324,-170.348216,-99.325133,34.860683,46.063662,-91.763796,-158.037133,-102.856391,61.879711,121.339017,173.022475,177.1025,160.574198,144.204949,140.108575,159.238908,179.113832,173.031087,181.121582,172.982829,125.340624,-25.546965,-75.620949,-95.169312,-77.542771,-63.794598,-73.443666,-110.316079,-197.65904,-223.672744,-218.919687,-193.15527,-137.856586,-92.545807,-83.457192,-122.677771,-151.88359,-205.430345,-215.72491,-138.592868,-61.318942,-74.734,-170.481276,-222.196165,-281.592405,-282.320563,-194.838752,-118.086479,-15.710589,3.048495,-0.427719,-85.373715,-172.401505,-300.506597,-288.790984,-183.839854,-143.907422,-135.130271,-114.524239,-138.502321,-302.441607,-404.597198,-442.168364,-358.924436,-207.09921,-227.364013,-247.487344,-208.360407,-172.693302,-151.877217,-145.539304,-53.171686,78.26925,120.55038,105.195927,38.077962,-150.710243,-232.295005,-292.277271,-256.828198,-101.806356,16.711209,-5.060437,-151.966544,-195.632958,-198.87734,-190.986242,-126.452781,15.891712,61.981955,11.562036,-71.613086,-267.462172,-345.969415,-396.520775,-365.582046,-264.620909,-188.822748,-161.350802,-178.405316,-237.644352,-363.03095,-382.371957,-322.698411,-203.921204,-138.32753,-80.267541,-129.811593,-302.08584,-359.604742,-343.348686,-283.741232,-169.54081,-137.312205,-152.889254,-161.57492,-130.413649,-93.376716,-105.854437,-90.312388,5.057738,21.326387,-35.726456,-60.653584,-97.019074,-145.660442,-233.702711,-197.742732,28.154172,198.038146,198.041263,62.128273,-21.627349,-111.363645,-95.349555,1.847208,78.546136,112.980392,167.179852,154.809604,-1.831893,-105.479678,-179.814754,-136.032651,16.263855,155.870185,197.649388,189.971798,149.504534,70.174519,63.331984,176.709706,347.004415,384.284952,355.031298,323.805458,222.847986,142.834948,98.619141,171.874242,340.583843,409.628568,396.046279,260.434108,170.849133,56.046235,44.087159,74.836441,102.520278,127.661989,176.986009,159.966545,49.87746,13.119844,90.162761,183.367303,356.086175,456.187968,460.089648,336.979497,238.849302,93.026476,76.457124,150.300817,247.720023,305.823849,432.436138,445.328513,315.955603,221.21531,162.797604,220.858191,366.25583,407.391608,385.899985,290.574135,226.945784,80.585314,42.152024,152.187008,314.393723,340.410884,332.666363,305.673287,176.936636,107.810723,96.712761,147.37148,283.856418,407.692314,377.029004,139.739263,40.802336,-3.418396,12.340928,8.050877,12.649059,69.503718,184.893019,170.96394,34.974971,-17.154407,-27.380714,-0.932175,119.284171,292.270823,294.354985,31.917319,-117.066896,-178.981309,-117.520535,-0.49022,55.495728,71.136775,25.76984,-39.78852,-177.391595,-228.641954,-254.968655,-220.949874:136.84896,53.055991,38.0533,28.966166,6.652943,-71.550476,-117.659562,-196.280923,-221.924436,-218.486828,-219.448303,-227.117628,-238.974951,-253.456654,-284.853019,-267.157208,-150.112634,-50.608371,-44.328749,-83.143804,-82.204432,-53.537681,-67.596537,-130.180198,-151.718941,-144.705684,-121.4382,-103.14784,-82.685382,-107.999663,-164.005614,-161.238109,-165.468917,-154.35311,-121.866603,-93.603646,-94.1312,-67.650869,-50.599722,-60.328254,-118.941046,-131.769628,-104.538994,-91.954031,-111.605935,-124.100394,-78.496205,-36.414481,10.455789,74.040872,102.061271,49.537027,-24.704468,-143.990392,-130.920205,16.15912,91.15982,74.898394,48.90055,63.491957,87.474345,64.237062,-22.757876,-31.125049,21.888928,-45.055894,-125.917479,-225.586106,-220.371775,-178.772215,-178.120641,-145.503063,39.383681,128.628806,143.029536,81.889009,-46.503953,-71.356622,20.95376,95.56071,133.336398,140.923064,195.191121,321.361084,343.229607,280.261406,218.165434,128.737924,176.669267,207.022854,106.965313,0.946394,-132.139444,-156.1915,-188.144221,-201.881368,-227.804042,-212.122414,-192.535701,-207.016373,-242.838201,-304.064627,-302.900142,-235.789827,-201.809696,-186.088362,-61.016801,3.642877,-17.758053,-67.432337,-48.930901,11.039415,88.518544,120.725935,161.638068,274.657731,317.33165,320.769496,301.037166,299.577743,275.069327,257.342481,263.645155,263.212749,180.301189,89.83543,-93.138135,-125.883078,-55.372417,120.045446,207.506534,293.093739,302.897968,279.13416,226.637495,109.575833,154.087741,224.715307,320.157193,337.319297,365.949517,358.092121,255.446041,200.308238,144.097194,107.618634,101.174468,148.827636,187.886512,183.5709,134.648638,86.268075,131.728618,120.488911,-68.366128,-207.851476,-333.394235,-293.222515,-197.604989,-187.878075,-189.246963,-154.570923,-117.488503,-27.913219,27.112363,108.344131,99.151631,82.326997,178.58641,215.687552,220.957759,211.062502,223.819167,235.202131,171.463056,107.702336,57.382562,162.229917,213.04126,208.354833,170.377074,53.657498,-32.78952,-226.791661,-287.117876,-246.685158,-190.517667,-222.702865,-345.424338,-401.406385,-458.618281,-438.720352,-305.837673,-176.888407,-165.402384,-239.665729,-276.767654,-252.202699,-194.909428,-72.387122,-52.317347,-88.00459,-155.74957,-140.557044,-9.494869,42.087861,19.206844,2.723746,113.486083,259.201377,257.959059,144.525251,93.899048,41.251958,24.447278,0.572744,-66.728186,-99.20024,-109.396019,-120.627976,-221.915482,-281.423648,-287.429314,-231.041833,-156.005769,-183.87254,-175.333831,-41.018505,50.493794,104.004991,80.879861,172.776193,344.899176,326.658936,114.262677,19.545365,-50.854021,-78.707534,-178.948748,-209.110169,-198.897474,-178.789904,-185.623016,-202.593732,-187.359782,-151.665201,-152.147573,-111.96074,-4.062827,12.332671,-95.130846,-171.4839,-237.628806,-251.204108,-326.409274,-364.462374,-370.201071,-294.934256,-253.81388,-230.582436,-241.954561,-266.673511,-282.557823,-270.29241,-112.973622,-16.710013,80.075544,53.982167,-92.822147,-150.780629,-125.692609,-64.942326,-0.884546,-23.787729,-19.050003,30.472986,54.353814,53.132001,30.009324,-9.860741,-19.252114,-27.847848,-71.338826,-91.941318,-127.124524,-170.353624,-306.173475,-354.973667,-322.285769,-159.576997,-112.88179,-155.213911,-186.642902,-208.536716,-216.549725,-185.492253,-70.445963,-8.11994,70.274875,56.243084,-55.269811,-101.659598,-112.724674,-102.730537,-120.398816,-112.594678,-74.865127,-23.061428,-34.21369,-87.892343,-103.301797,-65.067791,47.694136,102.393003,154.480692,148.482177,135.89894,151.113253,237.098335,305.214508,394.87683,348.504938,300.805799,176.445186,122.458319,79.307077,65.553295,42.172017,98.127102,136.97821,140.183419,103.118823,39.050075,34.548825,98.887166,155.109288,203.615867,154.84813,138.080864,106.653709,61.636447,-89.184328,-143.696448,-74.603106,135.135745,224.732092,342.203464,375.926277,376.579341,334.601686,225.104895,180.672425,120.374683,158.980129,195.52219,166.090978,103.012688,-42.677775,-106.587999,-138.454859,-61.619823,-29.999285,-1.408211,-8.830156,-22.806224,6.048887,97.581013,139.889305,251.147045,399.186423,431.499098,324.280843,247.42825,198.687267,188.695293,113.959486,64.580749,42.125869,-33.572139,-29.982362,118.787506,184.85639,203.725218,217.818334,280.452577,256.034207,218.58087,109.304446,57.94279,22.96329,29.166682,55.6128,54.912295,48.640183,48.224641,12.585608,-163.716822,-233.287354,-211.972732,-147.22296:82.119486,-30.795822,-56.00103,17.063509,68.517543,11.031932,-77.341104,-178.635025,-190.884871,-190.039918,-175.058142,-162.733885,-131.829751,-132.245065,-172.36247,-175.545372,-100.53816,-0.922956,2.6395,-71.910798,-92.075099,-81.024403,-89.994839,-132.668167,-152.616596,-155.792826,-163.626693,-151.83058,-69.115441,-41.085146,-71.056153,-93.246719,-80.819002,-32.826144,-30.300556,-61.055714,-47.837676,44.303066,63.33655,-25.494714,-149.15759,-161.772999,-109.741084,-88.571066,-78.921581,-66.472855,-6.884754,13.904506,-2.739637,49.709537,95.821075,72.7818,5.594977,-160.397809,-203.598897,-103.891494,8.364434,-28.373354,-124.827091,-89.452364,9.130402,-33.915004,-199.094233,-212.223208,-154.948595,-234.830364,-295.380002,-288.572605,-222.935376,-165.371053,-224.477689,-321.354575,-206.660463,-134.336969,-43.682949,-24.844972,-49.755686,-71.595838,-21.09979,49.215945,146.185756,199.909936,240.661879,311.560513,342.643131,397.888061,399.202816,332.592774,247.284569,231.008004,212.464044,172.461902,26.790444,-61.182352,-174.307495,-158.415362,-36.933682,58.687166,80.82282,72.58027,35.935511,-80.63503,-107.466202,-31.248837,47.808707,68.835735,160.507327,212.555888,235.001104,213.46197,214.106803,252.908106,330.677112,379.585825,393.893494,376.622348,355.100518,277.367716,230.204284,198.044973,201.113219,197.385461,235.569176,275.784237,255.652851,156.264232,-17.859952,1.793123,129.269405,197.352977,228.791973,289.26551,292.120417,229.369852,187.979572,110.16713,91.835878,148.964845,313.658686,349.931723,326.406384,293.672796,194.689384,154.362854,138.569405,141.2362,144.841797,136.875091,111.145929,71.365122,85.303503,128.09791,98.368415,71.173317,20.033017,-17.116293,-128.45247,-188.032883,-236.435624,-215.748333,-162.013071,-84.463518,-14.038436,128.495997,151.075467,55.242961,4.924277,62.390539,132.99477,99.211345,44.612385,65.314365,92.587319,69.564738,32.990141,42.391344,82.250948,217.289758,297.276972,239.631161,96.25961,-179.665744,-238.558036,-266.894933,-353.047909,-373.236997,-323.520184,-313.374019,-337.143668,-358.078248,-392.310268,-358.337178,-171.256905,-7.442775,0.416386,-91.089581,-132.359333,-163.264257,-152.061198,-59.883308,-29.346683,-77.809832,-143.664297,-106.059096,14.748433,23.807033,-20.514366,9.231068,157.549574,220.513333,217.319484,204.557918,175.46892,-34.284825,-177.56056,-279.456295,-137.685895,-87.664565,-159.328107,-241.704995,-340.690346,-351.225217,-297.871343,-227.865173,-151.945297,-221.971869,-227.230815,-96.95906,3.450098,95.962516,60.987113,-2.455436,74.610079,92.598706,-34.83241,-121.671586,-195.538147,-222.499434,-316.584041,-331.657774,-233.311484,-145.478082,-150.433148,-133.662046,-82.413141,-64.321407,-143.036075,-289.799036,-205.631153,-132.339667,-114.412829,-165.35506,-251.072863,-279.51438,-357.131457,-390.074254,-379.164549,-176.37003,-56.438297,-23.629236,-88.664584,-170.127697,-179.728811,-197.980964,-99.714207,1.301394,119.900073,104.55572,31.643874,-0.392371,-44.896188,-28.862111,30.57853,6.441308,-2.899502,45.863293,83.074503,88.642276,55.050758,30.133132,105.403965,149.267193,198.128818,188.926572,79.42735,-4.446014,-150.169176,-192.22677,-155.532553,22.022736,85.580201,102.417969,79.167705,-19.024117,-77.90712,-117.250174,-6.958126,81.621449,181.613287,167.23477,100.591809,72.201999,59.981823,74.258694,25.349999,-48.075875,-17.212686,85.605106,105.187751,113.707812,131.066208,192.288857,222.096272,242.606893,342.857013,385.311142,379.074393,344.049716,307.756327,336.059175,421.699645,400.768728,343.295259,217.595517,181.910404,125.224622,89.720364,60.461444,73.063578,83.085593,95.594738,84.638149,63.343742,58.356271,72.494271,128.997688,309.238821,358.880562,302.84135,121.315272,39.315321,-66.280439,-71.186934,55.567836,267.434848,350.162085,388.702385,356.026562,278.987629,238.347683,173.097803,168.290355,162.833977,116.20093,86.926572,1.764304,-48.823165,-142.294263,-176.267988,-133.203825,28.872644,92.192204,129.32311,111.386084,97.325945,125.961939,252.623633,328.457387,391.615759,371.271698,352.634532,237.798791,170.251408,119.362636,117.738387,91.055198,55.060633,53.99538,87.226262,118.58428,204.206745,237.659464,247.586936,238.412682,224.070535,208.792257,198.786124,126.919347,59.772208,-41.422299,-34.934608,11.833015,-78.765876,-116.566721,-26.338454,38.291474,-7.836092,-112.807579,-258.373435,-221.263451:110.032907,124.510373,112.73885,78.492587,96.895576,150.750271,127.443255,24.906063,8.030609,20.143323,-53.388327,-112.605268,-113.905512,-80.028659,-37.174316,-21.493157,1.742256,55.184372,88.926067,81.085475,61.441598,59.137726,60.851925,50.900533,36.601233,36.021922,39.004276,40.135955,14.54199,-42.686034,-218.382609,-265.931321,-172.56148,-4.951403,21.211801,-54.27845,-99.549746,-99.176171,-70.030795,-63.263797,-108.620894,-103.128292,-88.567765,-100.894964,-87.390529,-65.178514,-52.565442,-38.83439,18.945092,43.944998,18.840495,-99.073397,-135.239219,-150.216103,-153.566318,-65.822909,122.037489,177.351349,161.074709,142.604358,158.628594,133.53933,-13.129515,-55.225128,-50.501569,-53.689936,-53.519349,-46.612139,-57.805073,-106.6047,-94.474757,47.138232,137.121869,120.35101,41.222324,18.281621,20.047093,18.162925,13.524629,41.428501,125.449663,155.018944,143.63584,113.559362,124.527502,170.609699,172.865309,164.570418,163.163931,160.375127,149.386977,114.299437,6.858051,-31.355454,-86.14803,-111.545427,-150.128351,-98.317987,-61.176137,-119.807211,-186.924435,-220.26672,-193.188253,-133.482663,-66.452633,-42.063152,-34.255604,-28.394775,-4.826773,-31.080589,-108.203474,-84.960064,20.044936,34.812632,43.805199,104.516746,135.690758,142.656832,121.943037,130.418423,189.678334,200.35575,178.55812,142.621199,6.757435,-83.129699,-237.75398,-254.69941,-108.909583,99.150035,136.281466,87.794062,68.744777,69.893923,76.588786,136.977417,176.407639,182.246107,210.390511,214.04777,188.941422,160.425021,68.734576,41.002074,65.033012,77.890733,56.157542,24.42658,38.159735,37.130648,-10.991008,-80.300074,-17.655356,-5.721794,-134.332533,-232.374641,-334.175257,-338.202829,-319.629805,-280.653754,-191.216734,-238.621248,-268.03264,-198.927452,-123.383046,-55.296517,-62.505869,-31.419539,33.672463,55.548417,98.460083,122.408578,181.696098,185.217919,81.673152,28.085064,32.480244,117.233164,154.379403,144.50533,92.592961,-0.547478,-14.075409,-73.968335,-223.696979,-243.650752,-163.608715,-160.775045,-292.302236,-363.600438,-396.162187,-352.534602,-219.740994,-155.000748,-185.251934,-301.319497,-316.856113,-247.201361,-204.350527,-114.907623,-96.337722,-149.939205,-252.528995,-229.56679,-88.836338,-69.852668,-158.870252,-172.618557,-66.231511,89.416327,148.507636,126.240167,32.367654,-168.98654,-188.395149,-78.051802,-12.68314,-15.415881,-45.158658,-101.047686,-300.027809,-370.371366,-329.417186,-260.82879,-207.102764,-248.746649,-237.380491,-118.436875,-46.588768,55.302051,96.165972,151.783739,152.411339,176.175141,212.500068,171.122001,21.023935,-56.83134,-143.948288,-118.957056,-60.621581,-139.135599,-172.254652,-154.231403,-132.229521,-135.896423,-147.837242,-111.557419,-61.351438,-55.812367,-36.138613,-12.341348,-10.052432,-62.848422,-191.617266,-224.151167,-222.96987,-174.790811,-164.459346,-211.755662,-247.16039,-313.991813,-353.618297,-354.672471,-173.745215,-55.348237,72.139046,38.830849,-129.68887,-199.210259,-225.525866,-174.048929,-40.065005,14.18942,26.233327,27.962267,26.813299,38.515105,20.83281,-74.596446,-111.588178,-95.235433,-52.417944,-48.153343,-115.017853,-175.655657,-244.902784,-227.759893,-144.971151,-19.879495,42.912017,43.827928,-5.989086,-104.756507,-135.695062,-109.291938,-10.068238,34.557109,99.093019,88.412504,-31.363395,-88.348584,-107.830936,-91.457609,-83.749185,-56.543791,-23.48055,26.088131,34.167292,20.809524,-3.692618,-18.411492,120.400193,205.426202,257.804287,223.522201,128.869434,107.287072,186.882278,263.526906,331.162487,321.595233,308.157545,201.240981,130.625256,44.465823,22.622922,17.154137,61.444136,71.745435,61.895373,55.422099,39.513665,52.22021,166.915208,235.504036,282.994521,223.109889,178.903786,116.257816,119.723741,94.712358,35.929034,10.151531,150.660885,193.179339,193.070584,196.436585,197.941395,152.466323,46.705407,52.662702,147.613191,197.256866,206.050374,207.800456,177.18382,10.318699,-80.379877,-78.710058,92.344943,142.544906,139.166227,114.57646,23.993198,-30.826717,-6.616287,80.560315,198.565533,229.76787,257.848888,232.383347,165.500967,52.498387,27.560216,-29.633489,-83.72773,-69.457944,-6.64631,-16.493293,-96.69483,-103.398861,-39.581135,-15.253035,-9.3664,4.598244,3.980236,-39.402914,-53.066649,-45.303775,-55.916345,-90.096836,-40.039907,-13.22389,-77.759221,-165.245919,-315.943888,-348.017652,-335.999502,-289.102422:forward
-307.386526,-278.028437,-269.849405,-213.560608,-161.723291,-132.970073,-159.912287,-166.219518,-130.454824,-135.082187,-166.453204,-165.7217,-132.361683,-145.993735,-264.073504,-325.890606,-390.858927,-324.633131,-233.34946,-27.735802,32.304866,25.480285,-5.452059,-96.165869,-238.308397,-257.26413,-132.806007,-57.80309,-13.814833,-42.811104,-121.853209,-136.402413,-135.39599,-158.202546,-166.364252,-127.491791,-66.435387,62.488335,75.56817,-40.763743,-211.234309,-236.697029,-170.163997,-118.97893,-29.065246,-14.236149,-75.690911,-133.656554,-273.249822,-360.216627,-324.86005,-133.893179,-47.196338,18.242479,10.319388,-55.646514,-146.583152,-159.5793,-99.224723,-49.386902,88.536333,167.753294,229.694396,183.021949,18.743613,2.849496,61.191253,187.116942,222.602897,195.888013,148.590896,42.730108,-24.837388,-4.890939,88.344059,104.095717,61.593798,6.027468,-191.242415,-299.024962,-398.064079,-268.799007,-156.751127,14.410445,47.214531,37.708981,30.349475,17.4123,-76.750118,-107.762845,-38.448837,28.815149,135.244642,164.41481,228.241888,277.528953,313.849772,250.680484,234.564726,266.828952,294.963289,265.398308,200.331339,115.434883,145.268977,149.193621,75.182615,34.677805,30.755226,41.701136,63.536448,97.308457,142.363689,134.592449,143.498059,171.931438,187.541069,197.741904,190.58005,205.08226,286.499967,363.270417,597.343787,729.580972,915.016417,935.516031,846.186341,750.634912,510.706712,393.08799,399.135699,435.823058,426.931393,349.620118,303.555982,188.171793,52.029286,25.165004,68.353119,106.507909,152.277361,134.514077,10.889773,-55.441423,-90.051325,-2.240079,40.370447,61.835266,64.771377,95.703173,98.456307,43.704136,1.219848,24.545123,133.692833,202.25172,328.730363,347.237325,272.129971,193.48088,-13.614158,-75.361303,-9.729167,130.726655,146.700899,100.325895,78.762554,50.662201,-32.887031,-77.886641,-59.430787,20.775555,181.538835,188.270459,65.947281,6.945329,5.310385,73.361025,107.81921,224.757786,300.988326,387.539231,380.437278,293.281788,154.695244,112.117418,146.304183,201.728797,287.930255,289.106248,223.751955,183.228619,105.117935,74.3387,114.321722,287.833323,355.834614,330.078931,268.025733,115.527417,-36.533687,-43.905653,64.132294,105.297326,68.551797,19.932751,-22.979284,-15.65963,-20.859223,-72.690691,-107.263525,-172.923988,-188.661118,-248.802266,-336.755368,-531.473804,-530.971639,-465.799111,-324.924721,-259.594798,-80.21882,22.152884,116.523359,80.125912,-83.296968,-199.481187,-208.340055,-117.56242,-31.758405,106.504822,128.502178,117.956043,120.947935,129.616482,170.896114,225.376099,309.81954,273.849567,89.337486,3.089334,-111.112235,-148.135031,-137.940585,-91.514953,-71.238939,-92.414618,-126.495937,-152.866769,-133.590571,-124.714389,-95.887851,-75.665799,-72.761191,-117.840273,-258.275507,-296.010629,-269.133543,-185.242443,-154.277457,-150.314853,-166.596177,-195.945341,-185.185093,-97.360863,-53.14387,-64.416635,-85.412106,-65.439516,59.786239,115.771465,82.584275,3.231391,-144.989169,-127.544704,-54.659798,132.680303,199.538161,183.000376,116.612859,-34.526551,-143.062162,-157.419093,-111.850164,-55.9853,58.069028,56.527637,-42.533861,-74.756729,-87.30047,-70.605393,-25.815296,142.401144,221.139892,223.009071,165.028168,90.195187,56.191665,45.215111,127.236931,221.693408,341.995031,304.336817,135.12562,75.255907,4.254801,-13.754154,13.507355,60.618094,45.620089,-23.362957,-49.761814,-115.229794,-212.032486,-217.603056,-142.041472,-97.492162,-28.795171,-32.420841,-115.776754,-134.684095,-93.322658,-85.918101,-95.565801,-59.672686,-18.244001,27.041952,19.528054,-56.043629,-190.223897,-212.864485,-100.572616,-17.249678,79.294746,84.243856,75.215425,68.223897,-35.034234,-135.012111,-106.507324,58.369207,131.008607,168.34182,159.31729,132.529579,32.939785,-20.274642,-36.041704,-12.174887,32.77635,56.264078,98.831121,101.739564,80.73195,118.792984,180.025823,342.08627,401.729702,365.403117,283.922529,152.712774,116.52458,106.439379,85.049924,91.729654,152.401187,168.815481,80.387076,-11.546118,-192.047389,-230.458814,-194.007725,-113.227029,-76.180388,-3.786858,1.919322,-90.793696,-197.628221,-208.091341,-178.102242,-164.386498,-201.638049,-273.039275,-452.675119,-504.800971,-521.305765,-475.689701,-402.402976,-139.309187,2.070557,162.739044,166.142678,76.472826,-13.73775,-21.454183,-40.917952,-66.717373,-45.743742,-19.620654,-45.781357,-68.498866:-436.802944,-359.18735,-303.204945,-199.636007,-170.432839,-201.54996,-232.511816,-258.004901,-282.804556,-296.303529,-286.064253,-243.64689,-130.78938,-117.081356,-219.288464,-299.133259,-387.842418,-312.253373,-232.390334,-67.369622,-17.709926,-46.195101,-111.012143,-236.467281,-258.020784,-231.248899,-110.131225,-38.709425,-10.676386,-65.905701,-158.652234,-158.160697,-139.403949,-165.321136,-178.333476,-145.418692,-94.482113,12.528078,38.953412,-15.098593,-138.117315,-142.50692,-29.134466,28.5858,54.147367,17.024845,-106.727269,-167.693006,-244.271307,-208.644925,-154.152787,-13.570208,48.168155,92.109533,75.707182,-23.312266,-215.847176,-287.877354,-203.144812,-71.698555,77.904391,48.564776,-38.85376,-36.645369,15.642626,53.532301,75.803507,194.821412,264.133537,242.689542,161.584058,43.529033,65.385091,98.25128,110.899208,86.336274,-32.594961,-136.643078,-294.833884,-292.360207,-188.779314,-79.651342,-28.593588,55.181976,82.730197,113.080081,116.692871,79.385369,-22.489909,-47.679756,51.121563,142.069158,238.074815,221.341671,209.151394,265.074033,364.237435,255.953726,163.400256,103.323199,153.728546,236.059418,216.292624,130.890494,86.898805,77.096935,53.44255,36.144861,10.873618,20.554024,96.523775,141.096494,168.22582,91.078287,59.203038,81.96554,109.178873,125.843557,132.161765,177.686761,230.580561,277.886268,459.458504,571.418854,700.015253,678.055651,534.138623,451.058548,262.077728,145.92018,157.167127,258.693836,303.710996,297.983066,251.771274,129.088941,13.661401,-35.075323,-76.824848,-34.775757,114.4267,138.833594,32.566929,-45.720274,-116.803364,-45.348323,23.320472,197.576592,273.696085,272.015846,196.271032,43.339044,23.074664,72.847902,227.684945,301.281253,327.224005,253.090457,57.238726,-12.813937,-116.64373,-107.318872,-42.890534,49.548489,43.75784,-10.768727,-38.729936,-101.967453,-141.166226,-122.594876,-39.418817,2.181213,68.852923,87.541556,68.477243,23.251902,-39.349546,43.576475,104.858952,199.705217,231.562162,253.541094,242.667888,168.700987,53.503564,23.873014,55.332739,96.763801,124.028532,72.316504,-98.256853,-162.202411,-180.190786,-75.735317,7.061659,218.936843,295.784818,256.968427,169.251096,-3.454621,-98.906884,-88.448897,19.763462,62.726986,45.940299,-2.680311,-66.677659,-56.732527,-12.406111,-2.626295,-23.704511,-108.283443,-146.042368,-191.270859,-223.984978,-351.540248,-446.049261,-410.15606,-240.933738,-175.355164,-74.347878,-30.520768,-23.953534,-56.371739,-97.871988,-63.318009,-25.85005,90.615477,152.146366,178.456511,130.573543,-3.912048,-26.492288,16.850211,135.415448,176.138774,123.542762,45.198347,-70.797426,-94.775047,-125.825751,-159.146078,-167.170788,-134.453208,-109.226201,-120.871974,-142.075806,-157.661512,-221.282018,-273.308163,-291.655448,-232.173525,-118.937631,-119.208416,-172.451739,-199.23723,-240.936959,-176.47793,-113.657752,-60.875312,-91.113696,-177.145478,-192.713541,-195.990311,-200.653624,-188.309364,-135.253979,-96.452218,-35.261714,-45.380986,-114.468452,-142.534114,-184.964779,-169.81367,-146.318892,-108.477139,-84.898929,-42.73145,-45.472224,-152.401505,-286.771878,-273.312718,-94.329041,7.315528,96.160796,69.36527,-41.79689,-79.011528,-59.999665,61.835634,133.229241,221.856002,223.896687,149.471277,102.583102,39.482459,46.906151,104.6263,265.683221,308.52983,291.047485,260.486598,174.054549,102.296309,-86.541301,-173.457056,-143.395837,-50.632905,-31.512263,-31.094048,-38.354142,-127.034856,-239.151551,-219.779344,-95.515682,-59.204667,-25.606352,-7.663121,-40.977374,-93.298751,-129.626189,-55.408735,-43.319046,-34.337842,1.010713,30.451896,-6.350905,-108.742401,-123.729672,-80.217203,76.833536,156.182886,185.141758,136.002841,49.073046,30.205233,3.198926,1.289274,9.887811,61.845603,111.780381,159.436757,136.050385,101.761254,119.772607,139.170122,224.024068,266.584182,263.115737,226.584767,180.62477,178.912503,194.674848,308.499617,391.941592,482.769843,487.408887,472.694137,445.879136,319.112567,188.886243,185.525343,280.880819,327.688172,318.108452,248.234887,44.985222,-46.964873,-116.796081,-35.259746,-4.015078,-9.553655,-1.909442,49.937708,45.450112,-47.5014,-82.95884,-57.839583,-34.271774,-42.29492,-71.391875,-109.500097,-226.640993,-283.781196,-355.922045,-321.484559,-258.21214,-50.12342,76.203698,203.93646,157.499217,-26.376185,-91.264416,-79.435869,-29.414409,25.983888,163.133491,178.772168,76.145161,3.813604:-408.737198,-424.322826,-393.816047,-229.646872,-152.237383,-175.038152,-255.161272,-385.749529,-361.686991,-296.526261,-175.532247,-160.743553,-238.706584,-300.989269,-349.026957,-344.585733,-381.838437,-385.770135,-330.920272,-136.054196,-58.149649,-76.586351,-144.152508,-258.611415,-284.617219,-268.524698,-184.875607,-112.161567,5.109067,-0.541599,-105.806625,-152.717067,-176.748374,-145.001707,-125.042651,-94.613575,-86.597139,-79.109937,-79.396677,-140.482671,-204.528249,-168.09106,2.595699,73.267233,71.466598,15.76733,-92.214351,-140.267923,-223.722459,-188.158368,-107.638827,105.686062,174.053348,154.817632,102.63633,-21.424432,-136.252771,-163.672024,-136.025605,-92.810003,-55.892588,-76.777455,-131.131989,-158.735814,-204.091745,-134.62051,-56.039837,114.126839,184.035935,229.36054,194.699636,81.247942,30.957707,31.285414,32.261139,44.43504,43.081614,-14.251169,-168.664281,-216.837856,-212.145218,-48.780036,52.557405,177.329666,184.864795,126.142918,96.00541,22.759608,-101.479328,-111.817917,17.607596,91.807339,146.564275,159.692641,224.924619,241.916278,202.318476,172.890217,159.746837,131.251833,140.409723,216.640823,245.651366,144.070805,-51.938933,-87.412987,-51.111917,-31.161249,-17.371339,-10.909647,-30.277544,-57.032604,-58.199859,-7.618711,-1.479167,-21.999107,-43.219326,-97.546324,-105.219842,-49.7152,52.079808,120.080272,299.906465,384.166182,453.420206,426.411322,252.879093,132.55353,-14.933752,30.65538,78.518154,178.078088,208.691891,160.281238,112.808746,70.90038,14.314234,-41.121698,-122.585174,-108.575447,-21.901596,1.782445,-15.251342,-62.495928,-190.572963,-158.389728,-58.881747,187.345359,257.746974,225.689027,188.793294,136.059648,64.410765,73.601991,217.666557,289.560864,267.876517,191.843985,77.850085,48.38442,-6.690736,-10.777969,15.808253,63.465491,53.965168,13.499024,17.825696,-11.735938,-93.066945,-63.688363,130.809898,214.303164,256.622584,225.325024,91.611935,29.08578,45.402306,190.186572,240.797478,296.64496,319.814312,318.76661,277.315453,138.921653,1.177054,-47.350572,-36.824405,17.631404,30.310084,-49.99546,-214.823678,-239.420258,-213.354901,-174.974297,-129.339812,35.873299,98.329722,76.072917,19.630589,-104.521801,-179.531823,-168.129591,-83.562645,-56.449362,-85.165385,-106.751591,-78.46347,-62.063431,-127.39188,-195.578002,-185.350878,-135.06246,-134.649159,-219.445556,-267.948056,-292.713172,-271.216068,-234.442038,-102.576266,-46.001499,-15.665111,-31.202624,-58.754894,-70.582273,-94.065694,-6.550618,78.247983,213.639101,223.285057,95.981985,2.549981,-110.901815,-81.986511,-19.961816,114.681806,148.085096,115.230783,56.487422,-97.263476,-162.198797,-215.368878,-179.369224,-146.891716,-85.206685,-77.837298,-118.967242,-133.58782,-155.35984,-236.474344,-265.574533,-213.529015,-138.401375,0.266125,21.13248,-28.820265,-71.541827,-113.525693,-20.199609,22.732482,-5.948996,-33.134682,-56.335795,-74.724829,-104.53515,-56.780594,-12.810795,70.925621,107.582393,119.688877,65.456338,-92.281537,-148.270325,-195.433219,-154.474046,-110.35417,-17.29465,10.014268,-13.767277,-54.476556,-151.474592,-182.927867,-137.254928,-0.681453,47.852634,94.592837,95.363421,59.060849,28.348753,11.455792,127.561621,197.776118,286.28418,300.610102,272.15654,249.186349,203.885444,172.017865,201.639732,339.655857,401.566202,462.588505,448.597995,327.038581,241.620024,88.796028,60.12204,103.142847,213.669631,224.701519,143.842735,101.051705,30.936453,-55.033238,-55.65498,72.441692,164.197652,289.211577,303.889775,240.393702,172.303346,40.508447,21.616117,59.057285,167.716708,191.424798,123.038708,61.115421,-40.127437,-29.565003,36.836392,246.774403,340.851934,362.892671,306.637232,221.734983,197.598345,112.520886,63.249253,103.412059,255.507185,292.95473,219.847722,166.841251,122.483823,100.925522,94.045936,146.180209,195.998138,204.625465,166.436015,154.837057,173.517265,157.036587,198.793792,270.565601,377.156129,372.678766,288.094316,253.570872,203.947321,92.911548,59.232501,106.255422,138.271489,104.737048,52.250324,-44.803184,-107.728006,-255.413639,-195.39398,-96.506471,37.567609,60.938586,65.388709,39.363014,-59.415095,-87.296442,-76.141918,-104.717549,-121.777747,-88.873089,-66.896987,-79.785769,-118.414584,-223.222244,-195.944544,-105.858917,114.233127,194.91283,223.34627,172.21024,24.012044,-36.775266,-15.14797,67.952619,115.982703,228.645892,268.090121,219.935536,134.230342:-336.399737,-289.288586,-273.776686,-214.651413,-170.738496,-134.86941,-143.110607,-132.770926,-59.601553,-31.052645,-44.181855,-58.949837,-86.850397,-138.560876,-263.593248,-295.632841,-343.950698,-334.225268,-276.055106,-73.651766,43.423917,173.236397,150.95922,-32.279526,-220.817981,-233.484562,-113.174322,-49.646559,-18.088795,-41.514667,-80.529212,-86.991211,-134.131197,-198.972596,-198.566639,-96.505182,-22.912544,53.175783,58.033666,31.428117,-50.750452,-58.193604,19.387862,62.547819,84.961514,50.594914,-87.292766,-162.010718,-281.426462,-301.467693,-247.608771,-111.818441,-77.169952,-56.778467,-56.65585,-121.36893,-258.437131,-296.998191,-247.485203,-169.833721,-21.367619,-6.604037,-58.790468,-75.328798,-77.742959,-30.676226,12.645589,105.679776,148.277442,159.606224,116.929881,44.936544,66.383832,81.543799,74.523203,68.022062,44.658736,-11.259561,-165.917182,-211.65692,-239.439716,-153.961413,-73.581143,15.071567,2.083217,-36.985321,-11.252395,69.519622,12.142713,-36.67953,-16.274222,70.525106,267.402818,303.772722,264.865726,241.428859,216.487973,198.34012,186.886676,193.591982,229.177589,316.14522,340.342351,282.68517,94.234907,31.214671,16.685334,15.761537,-22.842567,-45.304517,-40.383158,-9.303175,22.319866,-4.4546,-0.885551,43.272479,53.969207,21.058501,-13.316351,-79.361434,-3.805163,117.098095,415.891921,524.265212,574.330898,540.719701,457.011846,402.855768,229.456278,107.657527,138.435017,319.569697,369.111519,302.224085,237.867602,113.254017,-21.758381,-76.319841,-131.16978,-116.313727,1.80147,47.590347,-21.427968,-114.869678,-247.229311,-180.788998,-119.088399,1.466731,71.087458,136.409916,102.500919,-38.211296,-71.591574,0.879111,183.950512,241.140947,290.73402,283.505373,201.794138,140.030337,36.901265,45.837811,92.835345,190.832782,202.149074,134.306165,103.46496,90.542343,14.125884,-16.850344,52.794291,130.443657,223.145328,193.952211,38.473664,-28.387816,-51.038526,64.409269,130.730543,251.886837,307.086892,309.860095,251.366271,161.101469,180.274105,191.199723,162.903053,145.114203,116.949314,82.814774,-4.363872,-43.428773,-123.376493,-88.625214,2.965164,229.949382,298.056733,280.133205,238.204624,158.892349,18.198117,-34.592262,19.236763,87.490043,130.380171,89.227238,-4.64592,-32.071635,-110.327091,-170.05952,-150.894004,-56.43413,-31.18298,-127.582205,-221.95594,-345.045833,-395.365025,-382.367385,-205.685238,-91.102095,60.655745,92.462006,78.5607,37.933536,-73.494333,-71.295741,-4.8249,147.432317,193.468861,166.378032,98.378195,-31.538811,-9.061985,43.705178,123.605359,162.356408,226.668954,192.538163,8.367355,-60.305304,-82.669574,-37.736856,-20.709046,-1.991547,13.958227,1.379513,-44.647566,-133.889481,-123.656531,-93.170365,-68.094691,-65.035858,-19.820879,-8.519295,-46.205056,-65.056857,-83.306545,-46.110323,-14.458929,-7.232185,-27.173053,-32.99937,-0.901346,52.682614,-6.707877,-40.756354,-27.414821,29.494265,169.970196,192.470392,100.050468,17.188252,-104.92753,-57.284934,-12.323724,24.166995,36.440752,61.185375,54.191317,-45.463898,-196.177034,-227.485596,-160.43052,-75.007367,103.397924,140.882904,80.273407,9.636795,-112.76798,-62.751595,31.744989,237.01507,299.369166,303.550099,259.453404,142.082954,98.426405,124.956611,232.341212,314.805639,485.644261,488.26273,294.433704,178.083943,18.769815,-4.956689,44.112853,163.657658,174.974062,95.165797,50.400262,-35.057933,-114.709892,-86.284835,57.449583,102.605072,162.643772,196.109644,184.818216,130.367597,21.288315,39.99396,93.874123,163.708422,171.65953,206.687774,202.037369,50.539476,-91.15834,-55.078065,182.496817,276.12251,269.29894,211.988824,149.142891,142.650656,55.732979,-39.257292,-13.165816,134.675262,193.562507,194.298201,151.17783,58.175888,-13.860371,-35.955591,-22.09129,12.650108,89.21679,119.272975,169.244026,156.507747,18.640114,38.052918,156.956798,379.214907,405.315577,298.816162,226.495397,121.369974,31.333358,15.056236,65.079171,99.51511,93.406295,35.85163,-139.116411,-225.885974,-316.37209,-208.991044,-124.550973,-35.205671,-18.565175,7.407518,-12.385779,-145.548151,-226.283581,-221.528257,-205.428824,-200.669976,-215.590031,-244.308342,-272.464459,-266.80057,-315.031303,-318.198435,-223.92411,85.37664,215.933782,259.441282,187.782082,3.207046,-119.460629,-135.611095,-91.422866,-37.351673,104.728208,147.385072,84.221773,10.682458:-402.36311,-281.385062,-195.418861,-75.23109,-54.719068,-98.141498,-140.009017,-176.832979,-72.087429,3.634793,58.190969,40.931168,-7.246795,-58.747266,-245.750401,-340.35445,-423.614007,-364.745258,-292.328403,-63.864486,36.374233,66.91188,8.017465,-150.907897,-188.241153,-157.799423,-138.110904,-145.39331,-126.119439,-121.02056,-157.225184,-184.904968,-220.813188,-161.011859,-100.29761,14.455232,58.017806,104.187381,81.187371,-79.246587,-161.158156,-105.169713,28.13727,55.770352,80.060186,63.026796,-82.325898,-191.608733,-347.609674,-249.048445,-137.2518,-8.752862,-17.735816,-93.60036,-132.323268,-218.996136,-316.85537,-329.86155,-233.122567,-147.746497,-39.912881,-51.413268,-147.508599,-195.435735,-218.88679,-92.815036,-9.925927,85.626293,98.882534,96.029393,80.717565,34.724222,57.586144,95.998737,143.402121,146.131785,59.590303,-29.553363,-154.065307,-172.365365,-186.015387,-132.342376,-74.946063,25.309164,38.293384,-1.850059,-10.323525,-26.773739,-98.384767,-86.089097,53.048199,130.632424,210.612695,217.82595,220.189463,200.343528,117.237289,128.753623,163.540081,233.091883,276.508458,325.534688,298.508845,124.379006,-61.795466,-78.334995,-18.556608,-6.281744,-37.319442,-68.45492,-136.081091,-154.165271,-152.436241,-73.997997,-2.522316,81.985573,55.831564,-75.155881,-134.625042,-168.485402,-58.575385,40.438912,269.933936,356.941665,368.835368,317.35844,215.973612,143.483461,-54.135443,-42.827317,68.976084,254.198429,254.805258,161.216991,120.400937,20.244611,-127.998616,-176.440524,-177.138278,-124.607563,30.946925,71.168699,6.221115,-89.233147,-283.786099,-255.292947,-173.438845,-1.472117,71.120317,138.510456,119.612897,-10.017162,-128.53575,-104.069365,114.863423,228.197446,264.377407,199.270803,96.90892,75.762694,38.260489,85.09006,139.266638,232.804979,229.08251,80.235525,9.873886,-28.011264,-33.738988,16.569919,233.923934,331.528452,387.453044,334.881676,128.995472,39.652426,9.702165,120.271985,188.88575,311.843088,331.382897,247.891599,178.282942,71.355418,34.655162,38.858944,62.627235,69.796697,21.238787,-31.895892,-128.57962,-181.127017,-250.557055,-163.446215,-102.209329,11.355954,68.085971,117.995829,98.684876,-23.721871,-163.968379,-159.392435,-14.798703,37.842309,-16.296903,-84.028311,-146.033673,-135.731531,-141.641302,-210.764294,-216.936332,-112.77154,-65.098938,-140.474866,-225.350272,-341.692042,-409.412481,-398.622937,-212.673522,-87.149002,62.091254,70.289498,0.435761,-56.495687,-109.642725,41.317417,138.832632,202.413188,172.442149,64.462108,12.907494,-55.702588,-42.253565,16.281286,138.144217,169.277387,197.122958,183.870759,53.326514,-38.625066,-136.297073,-106.05381,-94.799808,-61.067956,-4.871467,86.345381,60.84829,-102.356691,-197.835875,-172.03733,-17.571365,60.987041,82.568659,30.864891,-60.965409,-77.167744,-45.692346,52.858928,90.202692,130.820374,138.319211,93.408455,48.41099,-36.359775,-86.989013,-84.926166,7.058214,90.644937,177.907316,129.534091,-3.492912,-32.259267,-79.258833,-99.651327,-76.725014,0.885508,42.373968,109.885477,112.410838,-41.317014,-257.045918,-276.939546,-181.591366,-98.790839,113.344401,182.610205,156.323241,92.990242,-2.24446,71.775464,164.969193,337.928225,376.381696,326.777812,273.201489,183.818458,146.31407,180.339858,362.789386,463.160553,532.869872,478.448404,297.975546,233.018765,160.15775,106.934483,121.009597,272.125773,335.893784,270.537671,178.07883,32.497769,-4.216361,30.672548,167.823526,233.132239,299.297698,293.230167,202.407124,132.656767,61.533622,138.220405,174.98245,224.165304,257.882586,278.142411,230.395048,22.472852,-88.649785,-17.483553,253.580583,347.427128,344.28141,296.859796,218.414997,171.26916,53.618089,51.099895,114.937362,233.178959,237.430723,143.147697,85.889714,13.264467,-16.518385,3.431782,111.077131,152.951655,151.70165,144.356717,150.145991,112.668025,-8.471533,103.066173,239.899162,420.425584,429.822534,379.772177,332.672451,164.096088,46.7252,57.398696,141.490087,183.931508,179.257188,111.587849,-50.608868,-114.305281,-172.418673,-46.940884,56.384187,194.479781,198.231514,98.190147,24.940489,-130.064616,-170.58422,-112.845706,7.113696,16.650526,-38.506937,-86.073967,-184.656604,-205.853827,-172.036799,-60.455733,26.255879,211.696074,277.680097,266.366821,187.757695,14.907155,-44.169417,-32.075285,30.753819,67.571114,155.300703,197.353675,172.449256,114.602246:-182.214258,-79.79951,-59.136394,-77.700911,-39.675942,112.730585,136.546736,100.272218,145.438378,166.302243,99.420081,46.804076,-32.339352,-90.907762,-222.524163,-260.416288,-314.044951,-275.390442,-201.648005,-21.684665,54.230932,105.358584,86.186149,-3.492823,-153.184354,-194.461744,-134.811261,-67.989071,7.1035,-9.799982,-69.542238,-79.584466,-93.025022,-109.299738,-90.298757,35.003744,112.713855,166.854587,133.447405,34.66997,-44.07796,-47.555641,33.988402,69.676918,4.222392,-77.76644,-204.128804,-243.713275,-349.064784,-407.75379,-359.094073,-210.838283,-178.509432,-145.372303,-103.17037,-37.748301,-54.97512,-44.862652,2.615581,14.182781,87.808111,163.572232,241.527482,183.854765,-63.233238,-153.98946,-81.921087,115.315331,174.042925,164.214579,97.990771,-19.602804,32.271204,83.31436,122.628653,117.777443,91.378839,33.147644,-174.573678,-255.238522,-292.040937,-174.349369,-90.586479,-16.892853,-27.504761,-34.416112,-3.843272,78.369189,74.964322,57.860612,98.296544,169.545904,319.111976,336.123092,254.758653,199.013509,124.53752,146.944937,171.613478,213.250036,256.234191,336.246994,322.849542,170.728595,-27.654811,-64.690595,2.989212,55.211989,94.124749,69.337998,-38.677897,-100.077623,-166.233292,-77.211789,-1.80236,110.7502,137.756844,85.024527,21.100227,-4.311111,144.183183,235.881444,446.560906,559.247145,685.62613,667.454098,518.534033,431.517352,306.863763,252.887449,228.262077,215.851964,242.466111,248.26993,191.502997,25.76676,-79.275365,-88.624328,-38.86068,20.020893,145.502516,139.661426,-28.253053,-113.352636,-182.983498,-169.419478,-163.852223,-126.179182,-67.01153,53.061251,60.776393,-10.551847,-55.364902,-25.050223,109.659651,154.88823,173.954693,178.276684,160.075232,123.941644,47.18057,40.197198,66.173903,134.762523,154.872332,135.719765,111.926201,81.690293,68.17143,61.882702,86.83619,138.756872,239.016941,210.185615,-7.439378,-111.857606,-137.109905,49.044335,127.59126,214.437384,269.18375,369.049821,366.632593,278.406074,202.376,195.37859,218.254501,231.344122,257.065484,253.599922,179.390644,124.32893,6.310113,-40.487175,5.333248,202.587343,305.018145,338.880008,238.233401,-50.546026,-138.818112,-60.744568,153.057489,191.893048,94.10794,9.316546,-80.092856,-85.663803,-155.230702,-277.985092,-296.75313,-179.960951,-78.951128,-40.391776,-156.264925,-458.951782,-538.362848,-502.102557,-408.991649,-341.687632,-109.515877,7.392287,61.713549,-14.618229,-214.805244,-189.119316,-105.648582,-33.748667,-53.436163,-53.00975,-41.35138,-111.107769,-128.640325,-52.410727,127.417608,185.927632,213.820533,156.420554,-37.093021,-89.534471,-53.683364,-8.196926,4.13154,64.275064,78.828461,-11.998664,-76.644085,-105.492826,-64.166995,-40.508283,70.682226,156.829974,233.411612,155.491492,-88.433479,-134.584063,-74.823437,7.89839,34.793875,30.919137,0.776833,-60.013174,-65.707394,-44.731558,-74.397904,-108.274587,-121.727392,-66.285025,106.090078,131.288509,34.302422,-7.861165,-38.364635,-35.059885,14.176677,163.371772,200.613346,171.20962,133.457092,-7.209689,-230.263896,-297.151535,-250.885028,-157.161277,37.874027,77.289522,40.488933,3.960618,-74.089435,-120.978508,-86.92209,98.472592,186.839041,183.75442,105.388411,-27.648606,-23.007671,16.427452,114.87898,182.321253,307.566894,298.683138,136.892689,58.270841,-4.644097,4.315513,29.178237,52.983173,11.187318,-141.286563,-207.679224,-290.309421,-308.518824,-266.001829,-131.460393,-89.486417,-29.867998,5.665705,41.624137,25.773405,-64.998749,-82.734143,-19.434787,152.180338,199.50519,186.681559,161.361851,58.812391,-140.553699,-156.392879,52.085824,131.842019,43.747715,-31.921946,-10.22869,41.766252,15.235232,-53.715003,-14.332616,141.879749,186.786033,149.538494,102.317053,23.351513,-58.43944,-80.463511,-33.849175,2.496359,47.321898,66.27755,71.622192,42.786518,-30.69231,-12.536911,39.945726,196.190374,252.766407,191.615039,111.185759,17.593886,-2.535145,16.952673,95.601538,101.706464,27.747831,-5.61233,-33.233879,-64.128954,-173.58531,-172.17534,-104.524129,46.743665,96.707396,112.852029,72.923882,-72.172502,-183.28505,-172.104674,-48.652445,-4.374312,-61.357637,-144.157559,-245.673958,-226.913407,-200.641587,-241.461919,-182.528536,112.107654,236.533942,266.269919,203.078,69.489484,18.632295,21.31217,4.986101,-17.807327,-29.625887,-12.439584,44.353905,51.448678:-313.161375,-227.888973,-170.403514,-3.35163,68.882753,32.828114,-47.501807,-87.87684,53.559769,105.905999,105.808571,83.50414,57.730351,23.029504,-166.22336,-290.381915,-426.578799,-291.506821,-178.752797,21.688085,110.829525,173.240599,117.163643,-63.686111,-141.391528,-96.896765,54.427822,96.527589,92.386682,67.761081,13.922055,-21.830663,-113.131307,-118.541626,-61.299251,121.984703,190.626605,177.147623,123.11428,16.517071,-47.146375,-23.839445,123.377058,176.582709,97.147521,-5.206155,-181.187918,-251.763793,-376.033768,-352.819641,-280.280499,-140.101522,-116.656429,-204.493608,-273.483744,-346.80776,-346.380432,-305.191823,-131.307219,-36.61192,51.465251,31.568481,-48.791998,-88.150269,-160.61691,-150.610351,-94.594732,74.500873,131.801764,102.846357,54.954863,8.602596,17.741207,35.036806,101.98854,138.968086,113.680128,21.086351,-183.92978,-231.016974,-235.575498,-171.007954,-106.001286,45.925097,80.295718,20.292466,-25.135095,-67.260971,-37.23427,22.389362,177.256484,246.854195,335.426387,325.096581,194.463465,114.542611,36.593124,110.319786,183.569446,347.807325,410.06218,413.679848,348.028947,126.19944,-51.018508,-52.379895,51.028085,82.001932,57.8242,17.783951,-98.343618,-161.132409,-250.495948,-191.978983,-96.951393,106.717173,152.910847,89.251015,10.429486,-134.291331,-85.563252,36.141122,316.831581,413.325363,451.330499,401.348655,259.328368,195.037073,96.994935,88.752308,139.051485,296.953349,352.463824,334.482447,257.429742,15.247343,-179.422968,-196.850537,-88.862037,-7.248627,109.486557,96.653272,-99.835175,-226.499845,-363.777583,-277.791377,-204.827982,-92.983997,-46.747313,25.409682,33.617338,-41.306643,-137.8237,-124.892661,38.154714,127.472975,216.711699,226.122387,181.771852,118.581174,-13.370787,43.92737,148.630577,346.304286,370.238979,217.613687,111.550794,-12.785317,-42.826458,16.721953,272.418898,388.97407,430.649966,325.671,-4.234066,-117.394766,-142.311938,-21.947478,62.426337,250.23115,318.130258,269.371193,168.118309,10.00509,-16.01301,-0.523687,54.03044,90.993887,142.325213,121.779784,-11.539094,-103.850441,-270.883621,-216.444902,-97.149969,132.726357,196.145814,199.878351,142.14264,-58.746435,-213.447537,-181.643966,65.865573,175.414788,164.129023,62.951613,-97.818176,-121.381317,-168.192552,-203.295051,-171.739729,-22.27679,35.601597,-45.553123,-162.60694,-353.75621,-418.307945,-411.254711,-271.540387,-135.125943,105.940189,133.247054,31.16121,-45.894903,-168.892243,-113.921483,-30.232978,89.185619,88.675079,-5.805964,-58.229916,-119.307009,-131.03938,-96.999184,90.579774,210.242532,310.369596,254.72106,64.071151,-11.219857,-96.714248,-81.446138,-36.147896,75.155659,110.554772,98.450742,64.848483,-12.958122,-72.29511,-63.862196,72.192024,175.625797,252.76358,175.129425,-51.389704,-115.24872,-115.048185,-0.473085,63.403183,107.253201,73.302759,-15.918825,-31.310456,-41.884379,-44.316811,-14.763069,81.686318,144.139813,249.724797,238.737662,66.737306,-34.282361,-128.315381,-52.133938,14.064166,136.385918,181.365049,165.274822,81.447733,-193.046393,-377.948005,-365.138692,-218.63829,-125.861192,22.791895,30.237559,-77.525785,-141.267652,-196.434343,-117.491761,-28.378406,213.638876,310.136997,313.31813,248.199259,114.724579,53.057541,81.64288,255.157435,360.207001,413.219908,309.592027,48.909931,5.879348,33.786274,15.152292,30.726664,152.255549,180.113956,63.479215,-38.107887,-217.273373,-252.911068,-193.047395,-25.26801,44.625198,161.175126,189.569658,104.094127,11.982867,-90.175272,29.733965,116.669955,229.72137,270.39041,292.608114,235.759751,21.876063,-104.93911,-69.059373,135.75318,218.711571,213.872812,147.480985,14.388469,-33.924729,-93.145886,-37.517851,37.854401,198.09368,233.85825,133.681894,35.96208,-95.61688,-132.525478,-112.909476,11.302133,87.5772,166.868419,148.07048,19.010177,-55.846677,-104.007463,46.571293,172.486644,419.310108,489.062865,448.43803,359.419034,154.678889,55.173989,65.771594,128.787897,166.793977,205.623311,170.412294,-7.160285,-117.003735,-220.082831,-49.460427,74.489346,222.060568,218.901566,92.894724,3.246834,-176.216495,-236.136135,-187.962802,-31.238588,37.655936,76.595424,15.580943,-200.985945,-287.738245,-306.444952,-126.980993,7.51764,296.274557,399.635679,383.03665,280.650231,44.066367,-92.625212,-86.148825,6.201709,48.210329,137.74009,170.29311,111.775767,30.36094:-36.947644,51.041463,113.919409,96.240683,56.988857,94.388145,173.368726,348.536528,394.1939,353.477281,222.109934,148.554865,4.883059,-55.998145,-134.953609,-147.558311,-195.507384,-275.798956,-259.086,-88.752702,7.569653,129.963708,154.43385,86.255428,-78.10454,-106.756296,-37.02878,8.90799,31.324932,1.997959,-45.217951,-23.412929,51.666769,29.353684,5.284085,61.669034,129.861114,183.844668,154.930327,85.041879,91.911536,126.017566,164.722823,152.47025,105.996654,52.930474,-141.440314,-230.064112,-331.212193,-388.568819,-367.657189,-205.356166,-106.307638,28.898132,54.908749,75.085595,124.83046,144.597887,112.179143,90.630468,162.38132,241.235371,322.549549,289.326374,136.086574,75.767714,127.437296,300.360863,364.1937,372.227798,327.311615,202.476951,76.909094,50.312843,94.741653,138.434633,148.187272,75.203245,-109.168439,-150.778656,-175.373107,-174.039005,-118.982571,59.11273,123.007383,154.328496,140.888873,87.484761,15.370589,-27.420486,-40.163581,30.864269,207.7636,226.486468,149.813145,130.536072,149.537147,176.75566,188.049134,188.791527,196.686346,199.950229,144.308573,-66.751834,-147.49759,-106.897881,-63.354284,-87.480766,-123.42592,-138.664604,-228.623,-278.184055,-286.326801,-176.936211,-122.397688,-9.572879,68.774268,149.536368,120.453815,71.088109,176.396684,251.087728,343.008098,363.877481,413.787498,432.758215,361.633914,266.301048,96.49417,121.88933,169.06037,158.894223,102.090373,-23.415518,-76.579364,-156.461564,-152.176287,-98.349525,9.931958,38.219448,81.591838,70.922394,-59.889263,-133.303264,-206.035064,-196.329748,-156.995117,-53.881312,-15.691963,51.852811,88.404985,111.157017,32.820032,1.617799,0.281295,2.322952,-5.478048,-14.251879,-76.256987,-117.086284,-164.164413,-127.028932,-66.920967,77.533654,124.722513,107.639657,54.830434,-51.187016,-131.119198,-152.848719,-122.506259,-68.598583,90.34202,138.191647,35.120009,-72.268551,-187.080349,-59.545602,59.676755,269.78176,322.040272,295.980594,277.178801,326.011882,301.534206,245.420652,178.998947,200.166077,278.058227,276.319245,182.029095,122.987807,20.205562,-23.339614,1.821369,121.12754,154.846621,58.925909,-43.053319,-215.900864,-244.915658,-193.775183,-64.197557,-34.544152,-52.625167,-91.062817,-202.575137,-264.573313,-373.662274,-377.792522,-338.0367,-215.033314,-141.715071,-68.050191,-114.442395,-311.777597,-422.365346,-424.182062,-379.682962,-329.962611,-166.298221,-71.667729,49.128235,25.255785,-184.103334,-309.033117,-283.006827,-184.603112,-161.145971,-156.997179,-168.104611,-239.782885,-246.733321,-160.058085,76.261949,138.164416,158.043395,155.653327,122.784654,91.274606,37.24666,71.002578,111.805831,163.587187,174.864021,135.034287,75.841176,9.34244,110.654288,188.807632,331.57118,393.681959,451.000214,387.858141,135.230189,55.773524,62.724216,123.414874,122.894121,83.544989,79.977378,101.3395,109.637773,114.710423,80.032932,54.696313,13.340292,7.176156,47.006024,72.245741,117.060359,144.383262,107.872857,16.860248,61.972656,277.74482,357.090259,369.919362,308.937187,109.022291,-27.700672,-21.383107,71.665721,129.462329,267.101034,303.960134,222.407254,145.247206,27.661831,-6.298278,25.963778,177.281371,251.551634,255.540023,178.984284,8.327486,-11.903385,25.860836,69.296838,64.398184,72.902638,85.334116,73.413811,54.16532,35.447631,31.547401,18.54063,-7.544059,-26.539314,-144.705642,-232.774903,-339.4523,-302.808115,-238.843138,-88.042547,-46.408989,-29.236546,-25.389117,-15.409062,-26.234514,-101.435695,-89.166127,-19.49013,92.237133,103.605496,89.392298,92.897939,83.939975,-72.260028,-161.479783,-235.472513,-235.916457,-213.33068,-186.216693,-109.837477,-91.882208,-147.635641,-157.102327,-98.875032,13.568825,34.628247,66.869603,73.397305,-27.860011,-204.070385,-241.872463,-192.439853,-154.259397,-114.503782,-94.634149,-53.550987,-64.524814,-196.386531,-288.75752,-233.901834,-19.735017,46.476316,22.686376,-32.441429,-105.90099,-95.045973,-76.430998,-35.364471,-11.265846,42.061115,46.882649,-40.547943,-102.977248,-143.826526,-98.430513,-70.729084,1.045109,35.004787,8.495324,-56.670585,-177.471682,-191.479526,-157.503073,-86.873465,-79.629366,-76.216034,-76.393354,-129.38924,-174.691662,-267.645827,-262.838972,-167.775812,125.979691,224.818661,237.197643,208.77018,181.551814,135.637981,92.977037,-18.113732,-65.406712,-53.41991,3.278224,95.79678,97.727655:-161.493273,-124.754881,-117.553211,-111.54721,-90.384807,27.047326,111.068493,206.631162,127.031354,81.957836,12.943825,-47.828246,-156.633649,-171.165099,-204.117448,-253.083447,-361.880645,-343.396676,-281.177993,-154.701598,-112.360201,-69.321587,-66.475617,-124.565419,-209.966654,-193.664643,-80.561569,-44.78033,1.512268,30.983116,56.342681,36.066846,-48.345519,-67.876328,-44.140226,26.175598,68.805023,124.514002,116.916666,40.609449,-73.780491,-108.359274,-119.001861,-106.131189,-52.846739,-42.88646,-104.054063,-156.758421,-235.496028,-215.448428,-166.73321,-43.178033,19.785654,135.165357,161.148715,116.909154,74.626713,93.232473,151.769259,184.98693,314.458778,374.401131,358.101661,289.311392,122.425902,60.647517,77.854012,134.625612,161.867951,211.944234,212.322436,110.416732,17.840386,29.63235,84.96058,99.317513,82.794451,31.16247,-112.97506,-158.838139,-209.834572,-225.699945,-191.252887,-99.193025,-75.669874,-34.077406,-6.890478,-12.481,-88.791481,-93.512045,-33.942513,-19.606708,-31.409737,-24.909236,27.285153,52.49649,69.608854,91.570187,100.606814,75.758246,72.145783,107.17726,109.050418,53.316133,-6.290029,-13.127962,-31.154269,-52.110744,-39.848179,-17.561492,-33.449259,-55.991431,-58.791122,15.264774,64.871939,103.05179,95.177374,89.849229,85.056058,53.171078,139.18941,282.901767,618.576504,704.319351,681.709546,641.041666,598.079902,577.62987,455.889465,347.633766,343.17162,308.540248,238.695979,58.34242,-2.475966,-59.582349,-104.120602,-102.634183,-19.21819,44.762362,102.246912,50.069729,-124.97701,-164.320801,-126.47514,-50.253511,-28.540384,-38.769486,-38.330323,7.146586,36.717857,83.062894,34.216541,1.110416,8.458865,36.28938,110.544341,141.771415,101.874349,15.838746,-172.723313,-122.837263,-26.410256,98.613216,116.140707,108.632408,95.572537,41.705768,-107.978313,-179.665828,-163.924127,-74.639477,96.879854,110.878182,14.165483,-20.211882,49.825054,161.031682,184.595193,253.370171,315.724132,375.756477,358.567015,303.058796,210.74262,159.011951,118.942354,152.740891,308.453668,370.712884,358.758433,306.95504,200.061281,148.74567,156.238698,220.066646,234.059158,160.935313,97.608056,-50.760042,-170.911289,-166.996772,-46.405869,12.210464,31.551291,3.14156,-44.297575,-62.870163,-145.568474,-222.032685,-236.735138,-226.344024,-200.837764,-191.032717,-251.195857,-486.656953,-601.457888,-531.199758,-300.234169,-216.416154,-74.470432,-1.274085,61.839743,33.380518,-101.500216,-213.039234,-232.045821,-202.874677,-162.188548,-69.810347,-13.270188,110.386529,91.843592,50.175473,102.128789,192.998353,302.508061,276.16304,145.680465,81.263188,-31.405099,-47.638088,-1.120704,120.242641,155.806481,126.524789,75.164641,-11.987192,-50.561747,-50.087474,51.424958,142.758657,214.037039,141.968594,-67.130028,-119.576523,-127.317666,-140.739912,-160.931643,-167.729155,-129.596544,-38.753014,-14.54992,25.061881,13.263952,-18.803752,-76.422846,-73.662645,26.479934,70.710242,86.93129,100.082379,121.896147,81.383619,95.335866,237.13959,319.979035,391.258478,358.048732,205.754587,49.750802,13.746164,50.536402,100.515395,214.871809,240.299496,195.662374,153.196823,48.739682,-4.533349,21.88775,167.989165,253.399858,308.733456,261.293507,110.176075,34.19394,41.418558,94.925462,133.316738,213.712091,221.445446,163.361031,138.405951,103.634064,67.366333,72.32653,74.957867,52.426687,39.811578,51.757215,-3.125647,-68.564292,-38.566811,27.419972,31.658263,61.830782,72.996488,15.929153,-21.474437,-58.912552,-83.841697,-90.457743,-47.734982,10.04494,101.761777,109.826216,32.137012,-190.168133,-252.278538,-125.697984,-28.91773,31.167151,32.424631,94.397978,121.03141,53.170786,-17.355628,2.908981,94.572235,135.556627,177.996276,176.522344,133.085614,70.234921,40.426656,-33.728548,-68.404719,-46.184137,-1.188652,20.99501,-3.002616,-36.67884,-42.84271,-24.776308,90.258745,159.16725,177.76689,106.598659,-53.211558,-59.252608,-16.023048,59.290045,57.329891,4.448497,6.223092,61.354655,35.755984,-157.626893,-241.029841,-194.801413,-50.396776,1.412549,46.285756,51.908027,-4.772887,-170.22757,-229.422927,-193.780604,-129.49873,-77.430607,-143.489385,-357.800176,-425.014555,-458.100939,-406.752111,-348.673471,-139.827028,6.158147,204.682161,198.76844,103.834713,42.97292,2.44347,-135.23541,-190.095822,-151.299982,-96.919093,-61.064931,-66.379366:-146.141519,-130.778828,-68.87938,40.022995,47.586385,-17.408201,-40.26039,33.395388,174.544359,223.924903,238.97108,199.454826,52.852224,-36.99532,-198.760192,-270.760558,-370.810772,-257.231532,-155.400059,7.048163,81.004789,184.132068,177.248305,86.486599,41.162825,56.920712,111.688862,118.047363,71.560559,41.034371,30.90664,46.41777,79.246352,116.418619,137.757155,203.021402,260.48202,379.648683,383.105547,203.704231,49.000092,91.687081,218.596808,191.782194,29.95205,-43.213329,-202.682464,-287.781566,-369.695503,-330.759419,-300.449859,-244.626915,-208.842267,-151.639697,-139.623298,-148.194109,-147.783796,-115.50823,-38.637398,0.136515,93.971718,110.303408,39.812274,-19.64018,-95.121953,-26.519211,41.92393,155.991042,193.99941,196.829827,153.300484,61.937239,50.96003,86.960297,154.751625,143.790093,49.819157,-4.081778,-87.47619,-128.684398,-220.503879,-188.20076,-119.069245,5.07892,51.179875,140.446185,170.751695,120.396894,-38.44173,-73.29157,45.881444,164.403868,317.314727,319.603042,251.543292,210.089239,151.741863,158.933898,173.127676,223.497939,263.243198,254.685763,169.967032,-63.61918,-164.780117,-134.057218,-44.052937,-22.530523,28.987602,27.873402,-90.309482,-145.314482,-179.423067,-210.277766,-197.272864,-31.067636,67.915123,108.577215,61.299616,22.296857,107.13929,161.617379,292.441517,335.749592,318.518466,298.924451,277.707743,255.051001,186.222557,130.909489,127.27734,175.068817,211.233675,216.883056,182.568298,85.191577,-74.015225,-130.116202,-69.808483,20.78982,179.210526,192.618299,15.637423,-126.663989,-309.501435,-280.107446,-207.420077,-40.289197,16.050275,93.055375,131.438797,150.836981,62.467672,35.588502,98.725308,153.548764,168.147191,108.209174,-21.867566,-43.20479,-20.786342,32.233244,60.46297,155.199114,224.314991,259.593317,197.031131,58.795456,19.785751,21.157979,76.342561,129.78177,177.203737,140.103217,2.555765,-73.573434,-186.870992,-73.167193,70.233518,304.989651,347.519493,294.345416,236.772585,173.525171,166.160071,181.010788,245.193015,271.896443,259.649841,206.912767,72.775044,17.419515,-83.421692,-77.259281,-17.40813,106.966863,138.969197,102.652249,44.254967,-74.204495,-110.178348,-47.086605,137.262163,147.640187,-3.836414,-80.714812,-138.126401,-150.994064,-223.608917,-230.630485,-177.956623,-63.288918,-26.673955,-44.054837,-124.188766,-340.128106,-451.241803,-455.242129,-324.070961,-194.666309,36.640997,76.191582,-3.428401,-89.218208,-228.440852,-164.524136,-85.894876,29.050265,47.968809,10.778743,-45.575285,-182.916961,-225.419941,-185.732125,-49.528353,15.037885,109.115458,106.389787,-5.817095,-55.188985,-60.962009,36.253756,89.128824,130.628558,128.648647,100.556127,80.947907,64.655905,34.647611,18.745508,85.157732,160.701887,230.412361,187.428497,103.769021,119.199648,142.375967,84.612637,83.375945,131.41038,134.335036,58.820557,16.185375,2.835622,0.831284,-5.345712,16.412558,33.575663,97.192716,143.404792,162.266455,137.950537,87.741232,66.369452,90.354687,132.457071,126.021531,102.907282,72.535079,-70.477734,-235.911992,-265.196283,-184.8272,-107.428404,31.180853,64.567345,60.049351,35.631464,-15.818212,26.799428,75.249463,160.720877,207.021961,216.837413,131.581525,-78.032657,-49.260874,53.764752,229.429127,251.331083,214.409175,176.066941,82.714439,54.02004,14.545622,-59.168423,-77.17905,-64.699655,-60.001427,-117.484969,-188.153342,-301.003079,-253.522528,-198.622917,-82.862525,-15.800419,102.026001,97.842967,-88.156732,-193.007835,-223.704374,-72.558898,14.724016,123.859596,117.680564,66.019728,82.807395,98.666524,-99.48454,-171.687913,-124.036606,-91.499102,-114.741011,-130.974055,-123.795138,-115.038272,-158.654248,-193.533274,-151.074254,-10.965279,37.392314,50.010097,21.787016,-97.948167,-221.295214,-204.027999,-27.316888,32.661033,-30.782378,-101.901418,-162.893622,-159.066145,-193.089106,-188.463652,-93.994771,168.284339,227.895986,120.251292,25.106759,-46.562949,-23.490537,-21.464066,-9.342849,11.617166,15.271074,-30.255775,-139.204126,-170.306133,-190.12017,-95.400778,-26.140256,5.461466,-17.701186,-51.672966,-82.536349,-224.207042,-297.920294,-238.523495,-95.037719,-82.189692,-85.043144,-76.568845,-124.250793,-180.985782,-268.537598,-204.721455,-105.899132,148.6582,258.552999,316.830753,255.371273,59.142889,-58.320507,-47.137699,6.325693,-4.049043,-0.119285,50.293492,134.996828,125.233566:forward
-23.631807,38.51088,73.373921,110.338091,82.101908,-49.555807,-91.4294,-87.635726,-37.451141,-16.618981,-36.083593,-77.07774,-149.111513,-123.392957,89.904617,200.632785,253.536192,135.119849,69.632114,-38.605282,-83.816658,-92.669958,-50.801093,32.040735,44.414364,33.76381,34.319612,43.971531,0.617779,-32.282129,-10.878418,23.636744,72.843829,62.620898,21.885368,-83.416421,-145.103192,-291.352075,-330.204699,-284.111793,-220.602356,-202.718419,-153.653702,-163.566532,-308.362235,-379.034929,-410.985639,-384.516756,-277.815878,-225.773504,-238.782634,-234.695866,-230.019596,-275.547289,-279.845421,-168.843155,-87.465746,-95.757327,-95.691858,-95.382067,-200.910429,-252.673349,-162.671202,-61.283556,65.845136,58.026961,23.280317,-63.109673,-111.615593,-205.219377,-232.564558,-235.63972,-164.379314,-113.992885,-58.834865,-62.81063,-143.259297,-206.202863,-240.220106,-187.441745,-53.290298,-38.878928,-54.074048,-11.916638,21.064646,-3.043575,-51.770247,-129.569413,-44.965657,48.279673,159.521377,145.565525,52.710668,29.1607,66.160689,79.295256,78.713099,194.194793,277.491254,313.838437,232.325086,39.937726,37.016317,206.529102,313.996724,285.775799,140.963189,91.454342,62.144398,36.834407,0.913231,33.341173,130.870009,132.811521,101.255221,19.776216,-14.80355,-26.089065,-4.489259,42.482491,72.070678,80.197848,114.405574,148.664271,221.34292,257.451826,368.743422,430.06198,499.393521,493.404329,462.186106,358.531572,291.421282,208.562828,225.072758,270.550259,201.766922,158.126503,165.780636,206.005278,187.041558,120.498509,59.83227,89.647654,146.659864,113.92951,83.156179,58.5172,65.949635,91.177695,98.790702,62.071451,16.809585,-0.533945,-94.19119,-153.240739,-197.898906,-174.57456,-71.429829,-12.525357,85.464864,107.424736,57.976386,-129.025765,-224.011176,-331.110007,-319.556426,-184.641324,-41.544015,-17.432401,-42.978323,-54.522585,-50.033988,-48.619621,-38.406264,-16.021741,98.159167,212.738355,207.753878,142.822512,129.843914,105.668744,64.446443,-60.306282,-59.404306,9.771547,99.140722,88.571804,31.400575,3.530983,-28.09674,-33.640936,-10.097084,24.831155,5.794193,-55.956706,-62.93449,-64.395454,-85.186929,-109.685538,26.683383,107.858303,107.338982,47.074018,-68.563214,-108.686311,-89.458171,-5.371949,220.673306,263.163083,196.259712,51.769091,15.397148,40.217795,84.0109,124.496507,139.821884,167.49805,209.59366,223.066902,252.751756,253.110097,239.77976,260.736102,348.418089,321.748821,239.347252,67.131545,15.80351,-22.543393,-4.685188,85.387711,116.273207,82.965672,-2.198118,-31.372007,-82.964632,-109.026459,-121.40958,-95.208479,1.166145,72.096005,64.871052,-75.189751,-209.9783,-445.952444,-461.148376,-321.8214,-164.832461,-127.212089,-111.53611,-95.40445,-66.069499,-81.240349,-114.748731,-126.120335,-165.482082,-139.889925,-107.123174,-123.790516,-180.42589,-277.759852,-295.071174,-293.360162,-218.94742,-177.739561,-131.472311,-86.326433,11.981391,4.131329,-75.834146,-77.146047,37.781001,78.479383,2.158432,-164.46139,-179.624934,-125.667162,-109.511811,-159.903499,-243.995712,-272.742958,-298.681364,-288.61699,-262.092195,-268.908915,-286.606134,-271.556875,-171.883024,-73.107032,-68.75957,-152.933553,-230.119051,-367.721136,-393.005074,-338.22761,-162.247084,-100.585641,-153.017982,-209.56158,-266.588809,-280.805423,-270.609618,-233.73353,-133.908863,-135.887036,-215.100615,-399.209332,-441.505682,-405.37621,-341.358737,-207.998017,-140.533996,-116.670472,-72.09775,-51.248697,-84.162932,-151.766405,-229.983128,-197.373592,-72.767534,20.188325,22.756575,-73.24352,-133.821062,-153.908299,-112.377548,-82.797303,-138.360873,-127.288567,-19.264907,39.605564,79.905831,50.858842,-78.756214,-156.307692,-211.83321,-58.940222,2.718954,-65.326157,-153.223406,-231.438945,-177.477465,58.774172,267.430742,293.651991,207.685879,142.502872,22.89276,-18.09932,-11.882684,16.53814,63.213474,94.342697,79.140178,-33.469849,-98.488987,-138.121587,-107.201963,-37.298723,7.339749,39.860023,123.112065,160.69765,193.381166,176.625397,111.411568,104.99492,183.946319,265.162708,237.059471,62.993622,1.658081,45.158927,99.398479,108.235813,57.865234,72.55528,169.478489,200.549792,97.249237,-19.700275,-207.173189,-247.887014,-250.749565,-225.564536,-235.55133,-229.531363,-192.482271,-120.659396,-93.446056,5.729998,181.221092,262.868607,329.059411,308.205518,232.224843,219.101572,296.670454,359.903054:86.698097,148.679389,119.682383,26.01307,-12.384377,-43.117642,-50.015549,-78.261329,-57.221971,-32.340901,6.580791,22.484776,71.852797,131.129664,283.981656,315.741209,274.389398,168.670966,99.105245,24.238549,41.923066,102.501436,109.456086,115.982086,192.571066,221.051061,189.822227,151.843216,81.655608,73.316868,124.28238,146.351895,134.372283,32.205212,-34.782522,-96.266378,-112.532582,-205.312048,-240.426657,-194.114659,-126.409948,-127.237072,-165.042886,-195.315351,-262.889356,-274.172008,-239.023537,-227.456264,-247.433876,-238.866748,-214.304534,-154.624486,-130.976572,-136.817486,-156.461425,-106.045261,15.944672,14.960035,-145.836022,-245.154272,-330.409714,-303.267182,-155.097811,-70.64616,32.641711,42.846984,19.6265,-89.929484,-163.411534,-261.732997,-238.744846,-59.329284,38.246098,11.060103,-64.603947,-81.803828,-109.920839,-107.155277,-57.142223,-43.739591,-44.762235,24.722265,70.116481,71.474212,33.905539,-25.705037,-38.26379,-41.578577,54.641005,130.081056,215.086829,202.671374,99.510284,70.047642,129.117407,156.628589,138.426144,120.936446,113.473975,83.907606,75.671423,115.14376,167.537443,295.77015,384.093593,375.009518,258.568871,200.791655,138.977832,131.036952,128.848296,123.957973,136.226004,137.480879,115.398053,43.864121,-2.492214,-64.497184,-59.286341,-1.889146,71.157791,95.440184,138.885187,183.839171,271.504632,271.051628,237.73309,248.580537,269.54247,215.934965,212.029808,249.375829,240.652016,206.654081,215.929973,249.396074,274.10868,264.761478,143.004532,74.017444,69.578188,106.281452,123.009376,127.56333,177.63085,156.896389,109.661555,-20.228179,-65.264928,-4.588947,58.633787,56.728023,-3.968836,-1.068367,-12.412077,-46.037427,-81.872798,-46.008598,72.805197,112.722818,139.707724,81.267941,17.68237,-130.364706,-192.451132,-241.733272,-209.260062,-47.117514,87.680891,92.811475,36.285001,25.207213,24.360153,11.334989,19.989756,77.305366,261.026457,351.71481,329.760831,214.513187,154.624019,70.046692,29.947545,-48.043789,-18.404297,30.98469,85.910701,77.699503,51.456652,57.52285,66.340053,54.855694,72.53067,68.302697,22.99641,-34.375547,-28.656647,8.58821,40.115616,116.12001,216.841543,256.437259,222.757949,165.590079,42.423909,13.557689,138.17548,249.134118,341.415003,235.734973,164.781382,110.156708,126.005782,146.115606,139.809017,155.498442,167.512492,132.984657,68.358189,69.778081,78.114849,74.178814,94.585747,134.030901,223.542491,202.82898,147.0213,-5.981136,-69.726121,-75.910231,-31.996338,46.963062,66.277639,38.784205,-91.171899,-162.404165,-256.480767,-267.08863,-242.303889,-228.716449,-192.324995,-158.391103,-149.589456,-192.671409,-282.904045,-507.052953,-534.044707,-369.365415,-215.031005,-215.688762,-262.811081,-274.178662,-305.572978,-300.088934,-185.028585,-122.514029,-90.106933,-151.944583,-198.811749,-257.421434,-253.082809,-208.943205,-204.833057,-249.663773,-275.102312,-269.594088,-197.213985,-140.454461,-81.780807,-93.254182,-117.450344,-90.561777,-3.42855,-26.567012,-64.029187,-98.084408,-112.008855,-178.113047,-206.746509,-210.684526,-223.146014,-262.58219,-338.969903,-344.123154,-317.41179,-297.829691,-200.731707,-126.921223,-19.179595,2.639919,-0.394527,-49.366954,-116.672056,-278.79284,-324.760244,-306.300392,-184.707249,-152.6851,-207.055329,-245.888968,-272.844521,-276.715569,-310.442245,-315.086634,-240.078222,-223.168695,-280.150784,-438.717191,-502.890889,-498.482183,-408.622485,-173.299526,-65.754978,-71.134394,-132.108088,-160.948967,-203.33188,-222.813642,-242.273095,-241.300669,-198.532534,-105.136741,-82.481495,-83.925174,-90.583606,-104.264439,-87.549113,-14.593963,-2.334166,-22.303779,-50.029752,-33.255383,64.807969,112.004401,92.194786,34.762573,-57.598166,-70.699421,-29.982858,78.28677,58.474505,-117.510499,-160.182794,-53.95529,103.906875,149.011487,176.699401,157.974259,84.516443,81.409814,153.018062,175.718271,211.43781,311.351445,321.048674,170.072004,66.433493,-28.511492,-26.581667,-33.778624,-30.569201,13.589736,132.471692,150.365955,53.929956,-15.911742,-85.517815,-81.3935,-9.788819,39.403331,20.586898,-28.272238,-22.861836,59.550384,101.488705,100.147966,26.88282,5.657877,48.895706,85.023372,36.522919,-62.808854,-305.048484,-386.187731,-333.227177,-117.423913,-79.147776,-158.085806,-192.280611,-128.866852,-41.631991,174.895092,345.095989,375.013771,337.343698,301.880172,265.25275,252.695549,214.066527,217.901952:-11.795552,-0.426317,-22.207342,-133.392608,-192.87418,-157.446248,-83.795252,-10.619894,-20.031051,-18.66111,14.79213,46.661564,117.334285,150.535621,207.294108,225.60874,263.857041,259.544802,204.583421,51.317782,-4.186383,11.056776,78.478263,198.904846,226.109628,226.081546,183.336865,126.324063,36.812392,50.017223,128.700042,143.647231,102.696723,11.777729,-43.51485,-161.801994,-196.140425,-158.412591,-129.241344,-147.730609,-120.094353,-84.679912,-116.525468,-177.152227,-257.287634,-254.105781,-212.923145,-189.069378,-131.94239,-105.693735,-106.880488,-125.924765,-130.819206,-101.753936,-80.150016,-33.533881,47.02169,72.234798,-7.250052,-97.859228,-197.323091,-158.669931,4.905568,62.477879,39.699065,-35.398274,-25.32211,-3.454231,-32.840212,-100.413337,-106.043552,-63.19404,-25.493095,-26.003453,-15.298048,-17.195938,-55.427585,-50.065983,11.503371,28.932517,38.666023,24.562788,0.734436,-50.370211,-57.454637,-40.260759,-42.402358,-44.596472,42.347845,97.899229,157.127884,162.786276,136.538898,109.341425,81.458361,87.298727,107.064599,155.996372,192.210596,192.786042,137.371902,78.620173,140.391402,347.40234,396.982994,351.879163,246.718574,207.891486,132.166262,91.44034,45.472112,50.22513,81.954167,68.054572,14.149801,-140.456812,-195.080222,-241.64804,-238.02667,-127.469172,55.853427,105.221522,106.628466,89.267431,67.205967,72.636083,118.644711,145.997584,162.017485,139.700779,143.364771,127.598057,86.751808,32.997314,33.924514,51.931023,91.114843,87.835316,-3.260077,-52.709814,-59.706347,-24.027503,51.169659,80.483956,123.574722,96.611967,55.889857,-18.239241,-29.937874,7.570862,24.491591,-15.781909,-32.918883,-20.344568,-39.879586,-62.894628,-91.316919,-93.876003,-44.741465,8.566113,118.277677,96.234539,44.749883,-41.197898,-89.840707,-179.688685,-171.110741,-6.507025,139.059444,117.904136,10.114459,0.734828,45.86962,73.779229,162.554813,223.620519,307.187266,273.765225,240.483599,165.744002,119.950153,43.691168,17.557553,-26.490236,-42.454419,-50.517287,-102.909854,-128.115217,-92.321371,-26.117748,63.245941,50.341569,23.96321,44.52232,33.805671,-6.648152,-17.764578,3.347479,34.442311,95.598378,145.043327,159.051564,125.715721,83.42479,0.561281,-15.083331,47.759705,103.555135,169.51673,133.247054,90.498343,5.209627,-15.145154,30.692259,68.099227,77.620152,24.896192,-12.220219,-41.236069,-9.351331,63.343074,64.329544,19.790573,24.583076,153.535171,212.191505,142.855071,-40.886056,-78.465481,-44.846001,-27.877836,-46.695402,-70.831516,-94.980486,-222.752097,-300.061943,-371.780569,-354.205919,-283.682966,-257.756973,-230.801712,-251.150951,-253.75771,-242.02325,-270.355692,-364.082295,-382.227784,-369.42646,-340.634292,-329.381262,-338.124148,-358.207328,-388.923734,-366.59297,-245.416854,-185.552441,-128.467088,-126.739585,-123.434284,-135.461881,-160.181416,-201.499079,-207.917676,-164.432491,-83.516005,-90.885393,-176.186211,-203.432379,-219.489981,-206.785192,-107.874308,-59.785869,-38.401619,-46.494668,-57.859942,-91.613519,-92.49372,-94.270199,-129.128028,-205.508636,-129.965016,-78.917908,-107.477741,-151.22114,-182.890075,-174.25927,-120.63595,-71.907225,32.805875,17.023832,-39.20295,-154.648197,-196.089236,-224.080832,-219.908273,-224.674559,-200.38722,-190.233273,-247.178087,-305.08023,-440.064057,-475.411037,-393.417064,-316.288736,-234.337982,-269.582332,-298.413681,-339.622338,-361.768592,-391.840538,-369.161198,-223.081411,-52.934318,-21.021609,-84.855776,-128.545961,-163.355134,-168.218509,-143.389185,-95.354023,44.947876,86.262891,43.267648,-36.262701,-37.0667,-12.27019,-8.692727,-4.083125,26.329897,32.673161,11.851411,7.307545,37.56008,62.874824,72.021524,55.203308,52.803266,44.517009,22.984141,6.560518,0.259132,-48.942275,-62.315981,-1.114755,126.193936,178.93616,234.394044,234.810694,185.950812,147.713089,87.3,89.079631,162.682833,200.118548,181.655137,119.015195,79.334207,0.177929,-15.93233,29.089438,104.64269,108.464762,56.976887,32.729541,-2.684664,-15.519158,-36.074333,-50.853777,-57.601832,-39.900676,-49.489683,-104.184542,-101.797086,45.669136,136.592499,178.446101,120.159351,111.810764,105.02351,68.856686,-84.261694,-159.371833,-248.154629,-264.694235,-232.195158,-166.299787,-150.529552,-153.928104,-160.02171,-135.839183,-96.949318,47.913808,262.828942,329.725556,309.213696,247.947175,167.341185,193.985714,305.0525,321.879997:111.112798,142.579198,91.444672,-19.065274,-46.390011,-48.110763,-27.412519,19.185712,19.818717,5.247276,-22.20943,-20.314799,12.372251,45.212745,151.04508,201.688037,264.580791,270.584958,235.421786,86.382879,17.451227,34.561617,99.329136,143.253701,74.42327,65.562815,106.718067,117.910649,92.605138,87.589873,126.136893,142.924337,124.17862,43.808431,-15.357442,-160.195449,-230.838145,-303.532164,-312.585111,-340.030997,-297.80723,-236.67642,-200.195754,-267.30533,-453.618039,-494.050819,-408.013148,-319.620512,-184.406449,-223.690824,-281.441986,-302.933125,-264.139481,-191.144357,-163.714112,-91.720224,-10.809771,8.026146,-15.461952,-38.763861,-86.272252,-106.773366,-90.467876,-43.010899,62.626675,100.448223,82.534895,-47.039662,-136.634757,-227.617817,-201.169275,-104.608387,-83.190494,-89.204692,-80.363286,-83.171415,-170.658302,-224.598361,-215.082549,-148.131776,-20.412836,-53.729559,-99.630438,-120.548168,-103.002705,-65.185886,-49.574204,-23.176918,50.995646,117.015139,230.271449,224.601162,65.386706,-10.038719,4.137877,56.427289,165.682571,277.011375,300.920881,225.035278,132.115014,0.383612,30.211743,207.896651,293.127034,265.329977,150.477289,91.151329,-46.924496,-110.525885,-130.833868,-94.500397,-32.738554,-54.515277,-93.715002,-189.193555,-240.869552,-315.814431,-310.621992,-199.756871,-24.87316,36.935898,14.87707,-34.328127,-32.232749,18.613645,95.654742,114.29416,183.756902,247.661062,231.131826,126.534374,75.852355,39.954684,49.067689,72.961936,78.774437,56.53936,-31.721561,-67.460542,-85.798398,-65.703882,8.753136,40.132953,72.724246,74.413917,54.259506,-41.352373,-101.533159,-160.672956,-154.335894,-143.957414,-119.268036,-110.213107,-192.908699,-266.955319,-322.200605,-253.536809,-16.795018,54.431243,50.324027,-18.901138,-56.00605,-121.237846,-175.259104,-337.408283,-370.849409,-232.978712,-51.107832,-28.170801,-44.214496,-33.153315,-20.220154,-28.819238,52.98297,148.282448,293.505815,278.600354,231.892967,123.028162,77.667834,18.993642,-2.590653,-29.470137,8.452673,20.065348,-44.742955,-78.261182,-73.158451,-65.771703,-79.684129,-70.126981,48.473358,131.223116,85.992927,-78.510627,-115.31564,-65.79673,-39.382133,-29.679045,42.747433,84.798007,67.147521,4.667422,-175.24268,-226.869889,-94.661834,36.344456,195.009141,186.061104,137.498933,14.425914,-20.818241,-0.495942,37.04484,92.420771,105.790673,116.597902,147.494759,146.238891,84.274359,65.185139,105.167173,140.092499,224.230861,241.182956,183.565824,7.683697,-58.436788,-80.197366,-51.353359,34.409272,105.987204,85.503293,-76.458675,-159.269922,-236.776994,-235.119943,-187.908046,-148.908575,-60.756146,-29.055839,-36.571388,-99.961481,-177.568873,-339.091949,-360.37212,-274.450639,-153.30119,-144.987569,-215.440443,-242.193712,-243.893831,-225.594247,-156.366104,-125.919762,-121.865574,-136.561866,-129.282323,-117.63611,-131.758646,-182.254482,-190.595096,-133.787023,-53.557895,-40.06099,-9.785359,23.29284,55.856975,50.807336,58.249079,69.665112,75.12077,18.101222,-25.534383,-56.966527,-53.28904,-58.769468,-46.418038,14.518046,4.103941,-55.578475,-155.560779,-138.313295,-86.999171,-109.530433,-150.019234,-114.005498,31.266194,66.643935,23.312801,-110.58271,-187.687794,-293.835144,-300.223479,-257.023072,-176.253413,-151.586775,-185.121145,-215.219364,-268.705373,-303.308977,-316.62203,-273.245738,-189.639278,-203.294387,-237.848973,-314.980867,-337.383687,-328.90813,-287.788297,-134.235779,15.72106,56.700151,66.036215,51.050088,-24.834451,-84.245664,-126.85428,-79.390136,53.688861,100.06585,83.558933,10.089168,-30.200398,-59.061889,-21.683765,85.32541,68.304696,31.552065,-1.359175,8.651845,25.232923,12.093141,-24.754156,-23.999357,50.780651,159.207651,180.048871,100.408706,3.296315,-153.059997,-146.275193,5.024484,136.712503,166.075482,209.190579,203.518567,97.004455,51.865327,44.317203,45.323253,83.331127,187.570344,189.737159,29.394807,-76.945265,-145.845725,-94.421371,0.509006,-28.823585,-32.750529,38.263752,74.236766,42.975903,-0.305203,-1.673784,26.433785,40.700288,34.575821,23.01683,-36.276546,-56.243837,25.125867,113.407371,200.114628,177.361514,213.044741,315.685189,301.484723,101.394175,-40.91176,-240.518274,-257.859185,-178.446995,-100.056246,-103.849218,-140.947008,-139.724756,-96.255413,-50.491254,112.056988,324.476298,389.61383,368.297695,321.327226,272.26875,295.22565,418.944926,456.767079:30.416444,100.934297,54.371436,-91.347316,-133.990249,-87.683016,-24.924321,62.501096,63.20325,21.055252,-66.586602,-60.98822,40.223387,98.747151,185.330366,228.555049,317.467749,286.241175,216.532676,62.231362,24.147368,88.222343,157.034279,246.640324,270.529668,265.241569,177.074539,106.103323,19.958608,40.755593,160.311325,201.622512,168.662898,15.10105,-54.040941,-139.58727,-185.178915,-270.88622,-281.406583,-226.085425,-99.342539,-48.493395,-69.637202,-146.612938,-306.074714,-315.804132,-230.722231,-203.349359,-181.093039,-155.694302,-161.666319,-212.118131,-231.185277,-200.964706,-150.50608,11.99157,159.247405,173.822965,96.641828,49.846358,13.453347,9.797897,2.07195,23.079446,90.755379,26.737484,-34.297023,-101.524685,-113.255029,-115.574801,-97.045525,-7.724224,97.417229,99.072011,-19.892015,-84.092887,-132.817245,-128.879204,-90.389492,-38.224176,142.908831,216.96583,163.42028,29.788846,0.812737,-24.819848,-34.888997,20.207604,159.593758,200.797982,182.094463,127.564818,-24.656486,-56.93337,42.690226,120.023076,216.902756,221.204945,208.701792,179.739415,141.798601,90.209519,133.07627,290.109625,313.480148,262.295952,146.469139,101.381173,29.825918,16.320735,16.398779,5.935841,5.100637,50.661844,21.40657,-195.344445,-294.447723,-286.522646,-220.056448,-90.37987,64.161366,108.733043,43.694691,-19.935596,-42.815315,3.332226,92.708507,118.879971,163.386854,186.102126,175.953493,60.324497,-17.277661,-53.155308,-12.156066,82.211392,131.296487,112.05635,-14.523108,-69.645699,-92.862837,-75.760374,5.502251,65.643048,164.878152,140.948191,82.474048,-53.497418,-108.833637,-133.860008,-111.623158,-74.052548,-42.835456,-60.027173,-161.390867,-192.311322,-189.935765,-165.685991,-48.416077,48.727972,234.226525,195.181016,96.610812,-95.080643,-156.766629,-184.049888,-153.68888,-41.289727,119.340953,162.919837,109.219713,75.048321,71.370646,86.803226,204.044193,297.38074,375.536862,297.757172,265.026514,198.203673,143.189506,60.329042,71.07338,164.825201,208.110918,170.67232,38.95053,-7.88096,-31.297079,-12.834688,45.06506,70.621654,147.831305,191.255565,144.941917,-18.91054,-60.561615,-28.983421,-5.24591,51.942928,122.050191,114.502215,52.8213,7.406056,-164.938588,-222.092038,-82.715037,61.269554,272.408278,228.120933,121.033719,-72.663238,-94.033809,4.341833,67.119224,169.006617,197.101885,141.374184,55.451405,89.505475,143.314926,117.810037,83.409923,114.300246,243.031192,281.761282,242.671676,109.935226,42.1516,-18.950987,-11.69427,36.691676,130.481211,140.632718,13.439925,-74.30999,-189.281725,-198.887556,-112.895018,-37.199831,95.915622,125.912731,104.225525,-10.667085,-106.876183,-259.467569,-262.667328,-158.087239,-63.667315,-77.70834,-239.764007,-315.180483,-285.353817,-193.425356,-9.3757,43.205466,86.865255,28.527175,-32.240942,-99.91507,-101.054998,-66.873584,-27.085488,50.161419,46.534829,25.058037,-20.679705,-47.451699,-70.284047,-30.626023,86.412086,108.45592,129.186434,146.324749,103.395626,-23.600625,-53.734495,-50.471807,-34.612756,45.960428,109.352072,75.17055,-37.10514,-54.584747,-50.955321,-59.994177,-61.64391,-18.836207,153.570199,205.521576,139.039512,-67.713602,-153.845238,-225.730591,-221.095121,-155.446097,-40.466834,-31.310713,-141.058659,-208.922914,-314.150694,-338.858072,-292.182019,-243.855538,-182.972387,-214.135217,-252.479237,-298.441005,-298.742021,-238.625972,-161.965905,21.699539,102.890987,93.83888,67.595987,70.921593,26.579366,-19.927696,-35.243138,6.922417,104.132246,73.133963,9.330352,-102.66975,-124.522515,-71.047485,-16.659724,61.69957,69.924159,38.955199,-65.686667,-102.480294,-99.980164,-74.386225,-27.272581,-20.990123,6.857389,103.607778,133.212167,50.400076,-40.969409,-120.422804,-74.811933,48.880312,78.934408,77.509086,82.287794,74.519363,29.877866,20.726257,37.073013,39.014198,86.882026,154.962105,125.925991,1.358899,-18.412512,20.160803,26.316629,51.334347,128.077802,118.161748,6.430118,-37.200032,-84.310338,-95.609833,-70.506892,-46.701787,-14.893847,-29.865798,-61.470086,-96.76536,-72.194958,42.857018,106.453992,222.164506,354.810934,372.248029,216.440693,114.744967,16.000384,-19.948038,-187.409427,-281.822846,-313.740843,-230.646761,-223.388542,-238.471494,-233.973071,-192.381788,-142.845997,22.68573,179.501957,202.636978,137.192601,93.590105,83.146145,125.560209,238.209277,251.464121:95.803406,84.009047,69.663215,150.327027,205.531443,142.194899,42.8445,-64.014808,25.373451,47.274842,-77.104318,-155.388759,-211.764063,-182.292245,9.931661,127.183567,229.074548,160.804806,112.807396,23.63815,-19.090617,-39.014352,10.017762,115.620398,43.079103,-18.866627,13.685702,93.45281,170.11032,153.059205,106.606729,87.264411,85.1582,55.639434,-26.625401,-196.579228,-234.018801,-279.978227,-298.425201,-305.526443,-285.815542,-254.05371,-191.626374,-188.253647,-247.619383,-302.852039,-349.05731,-291.844253,-110.136285,-95.466704,-157.071948,-264.061596,-279.148858,-233.925393,-179.866097,-90.939098,-54.792095,-24.633592,60.285751,97.728266,69.680564,8.454882,-27.316699,15.784877,84.68106,47.555093,4.662014,-67.783596,-104.554204,-197.64149,-220.720691,-189.104191,-91.160965,-34.212628,42.21214,47.638805,-45.631314,-133.701187,-227.459164,-187.908576,-29.75291,32.712276,15.713458,-46.049846,-81.610112,-130.453353,-119.995338,-73.27448,-46.929632,-8.87192,89.076434,104.607225,-0.875117,-76.39296,-40.019542,67.397848,243.646,293.923652,283.344209,198.248116,133.93086,53.213817,87.273063,245.575103,284.25862,231.304768,75.224974,8.196985,-91.296963,-133.81981,-177.743357,-160.269943,-68.86804,-23.323927,-38.317417,-103.125837,-156.825487,-263.127737,-266.677246,-155.571429,20.468276,92.051062,117.233425,77.456614,46.408224,111.462135,310.374787,352.525578,315.4054,318.287973,330.237489,288.996688,229.195384,108.571516,81.056549,74.202753,80.906485,73.736697,52.166287,70.572147,111.782166,79.759333,-34.033708,-61.344791,-21.825569,91.506343,131.329739,66.560619,-21.418619,-93.605997,-53.141954,-5.062765,-55.559421,-71.067756,-99.439542,-136.62222,-217.940133,-210.046872,-30.561375,89.035969,210.323418,183.244477,140.433285,13.734677,-67.348781,-207.585573,-226.954256,-162.723558,-64.487166,-38.490188,-38.297042,-62.690677,-151.281091,-172.38786,-81.315935,4.957551,139.448461,144.481016,121.178601,117.933949,124.573663,96.544796,74.156944,23.949652,16.119405,55.587679,129.174288,106.905042,-18.562074,-36.896078,56.583012,87.496668,53.063095,26.762398,22.21577,-30.656114,-83.604179,-189.340404,-218.97628,-213.984472,-113.725977,-44.803345,11.560269,-28.803642,-200.085678,-269.144224,-207.507739,-95.466154,69.647844,43.730122,-4.153318,-38.61277,-23.106387,-13.461182,-11.448512,65.219901,231.583945,303.080067,312.936269,267.061862,190.559994,181.968319,269.907868,350.568244,431.316096,301.231975,206.938256,138.398957,147.956109,103.144194,62.752765,85.643788,209.667062,233.631274,150.250825,84.92203,6.051505,-0.729329,38.19191,69.841069,120.831699,90.264139,35.512296,-78.118622,-141.92505,-274.082657,-270.012735,-102.174321,9.098244,1.564459,-34.754731,-14.283361,60.953318,62.420324,-6.098816,-39.71502,-38.316612,36.04937,53.145502,10.100418,-17.11265,-11.995341,11.279121,41.421935,92.225502,142.032946,247.688002,289.099171,284.805036,241.479644,186.777016,201.46216,276.409608,233.801615,160.637438,90.501683,93.205284,86.212811,92.582668,133.962015,98.576357,32.048016,-83.396084,-104.29972,-130.273162,-143.909047,-123.799624,-79.822875,53.889541,135.81706,118.486646,-11.573294,-103.062096,-250.931913,-273.49038,-245.678526,-194.84126,-161.429652,-93.87435,-76.146303,-149.063814,-236.02699,-317.883086,-250.833594,-48.849619,-78.779127,-179.583606,-363.085191,-383.252878,-255.145683,-158.12253,-61.082379,-86.817282,-80.557274,-5.121412,26.140204,-10.252323,-74.128801,-129.691271,-67.606646,125.736954,138.12823,46.602874,-149.605947,-184.54116,-143.949964,-113.051888,-111.403216,-113.948563,-79.339807,42.6903,92.755332,76.055268,26.092119,-35.251899,-30.060315,16.616831,98.970585,136.377591,137.943908,101.184839,1.25935,-9.771795,111.42951,264.615164,300.1921,255.29391,196.051354,79.680751,31.293127,-33.798555,-50.024744,-21.49068,58.589551,58.25372,-31.618047,-73.451784,-97.2499,-83.982892,-30.201283,53.879058,106.127338,147.595454,129.595647,100.64531,99.694577,110.092857,119.443638,185.197586,262.585268,227.524316,55.974757,13.267404,105.80435,179.689311,196.185906,161.62626,206.275543,320.16106,325.042825,182.278853,71.080611,-115.312018,-183.963783,-244.306556,-216.257598,-216.42995,-196.103835,-151.060917,-65.285004,-34.894641,43.880251,140.234498,171.39277,173.802893,179.988251,283.431745,361.383488,461.647941,454.134091:42.349235,71.396701,10.247319,-85.340636,-83.04058,-31.28454,5.622845,54.246514,26.807021,-4.280774,-54.392098,-69.626278,-108.621958,-93.370033,102.088094,231.810278,350.252051,235.75549,155.82126,28.22,-28.510289,-52.148194,12.286034,186.199884,249.549548,234.26039,166.522449,143.715963,151.248736,179.761116,244.415828,250.259386,198.822547,94.628941,15.304912,-208.858485,-311.867552,-359.033389,-312.601621,-213.948678,-197.599159,-204.191083,-194.566749,-206.584468,-324.734586,-379.737629,-306.795226,-187.659681,15.164643,10.562155,-49.541221,-206.567213,-274.250118,-270.831293,-177.659079,50.29391,137.616657,132.41137,119.24622,114.864722,54.722088,8.670161,-22.022287,17.495997,127.642762,76.260005,-11.554731,-151.665964,-179.699383,-216.918992,-210.854598,-80.824975,20.364664,-4.177749,-83.064325,-89.997796,-96.253281,-126.326968,-172.990242,-128.296353,75.876989,145.753113,103.787328,-9.354966,-41.316676,-12.902852,34.417178,144.690389,243.508507,277.253183,279.056271,222.653007,12.926975,-57.146425,27.360406,127.560533,269.035758,300.157689,280.690385,192.307931,122.055359,16.527807,34.804606,173.565642,247.838283,215.074147,69.173872,-0.262103,-95.240464,-124.304146,-126.29086,-100.987233,-35.910099,-14.002265,-44.611647,-183.869678,-263.693083,-325.404481,-290.412418,-119.666613,78.281919,121.551305,50.479901,-21.360677,-68.096256,-15.563113,156.726461,220.721031,257.4004,225.579744,194.240126,94.569449,38.223726,-19.168011,-8.704479,90.592148,215.23072,207.207847,49.238712,-18.008954,-26.635475,5.491941,78.651657,105.91068,132.944455,153.781256,150.252949,41.650308,-56.803271,-139.51955,-85.175106,23.22475,29.475503,9.841164,-76.744004,-126.100295,-194.969737,-196.033627,-101.909449,-18.933184,145.968388,170.958516,119.561365,-14.769241,-89.288074,-205.822765,-192.720764,-38.049261,81.587039,85.970913,19.786693,-12.770461,-29.686717,-15.12932,84.758458,172.456617,312.721211,293.523959,253.636264,185.100405,151.9406,111.105414,124.164354,203.744701,314.300029,332.747551,198.124066,78.188869,-71.399004,-45.435791,136.458253,213.91659,274.25053,263.163314,235.4989,122.941609,45.072366,-79.24203,-88.034367,18.661508,124.684744,121.923879,49.974627,-8.267692,-189.808413,-257.458582,-172.154926,-47.530522,203.343362,270.593741,194.128431,-11.548177,-62.85439,-41.22933,10.551417,137.254627,265.675707,313.930496,303.703782,242.65321,102.522964,78.911132,135.994818,187.5625,332.326299,396.72724,328.622502,92.482819,14.003227,2.067542,38.901543,128.624349,182.112935,164.712396,52.297332,-9.056114,-99.145363,-109.451271,-40.412558,9.74161,52.738457,32.516359,14.755251,-49.056201,-102.688999,-198.412664,-195.209722,-61.031363,71.605888,54.785578,-95.234261,-146.892936,-149.832699,-130.326556,-42.704954,26.95118,126.069346,123.82406,118.428691,110.417016,72.945621,-48.743792,-80.208776,-0.800764,182.140226,207.998785,78.344593,16.572339,48.795472,108.981056,177.783365,179.742781,203.885141,154.946093,63.597091,-128.017223,-183.864682,-139.634194,-38.281771,137.110044,144.897007,110.764479,34.491211,-3.204396,-122.140032,-166.364152,-128.107011,-80.808771,26.786823,125.770295,105.776585,-100.538793,-231.728547,-371.736675,-361.920715,-284.483101,-161.767461,-97.151053,-86.3222,-149.272561,-286.172552,-317.253153,-287.644384,-231.230821,-133.370656,-208.528536,-276.730912,-332.419977,-324.415594,-300.772117,-272.73386,-114.711353,67.879683,85.752272,19.824,1.110678,-34.949603,-75.993782,-72.967353,-3.618832,133.0067,124.255506,67.517109,-60.195223,-95.216662,-102.442222,-91.035607,-80.245199,-53.764863,-26.054824,-1.463079,-9.564998,-53.669019,-79.010913,-54.55872,1.062103,113.698799,181.096797,187.754558,77.943351,-16.87883,-94.3993,-55.211365,63.018551,163.629403,195.989068,186.28979,139.336417,12.236967,-30.079769,-22.491751,23.841011,134.506668,128.835495,88.723893,8.596798,-42.590397,-108.385383,-66.866411,81.644173,111.900212,93.308415,54.577753,46.009284,17.554277,-12.975674,-61.704707,-61.042693,-4.008223,33.588234,-1.728879,-136.458629,-155.479817,-8.120949,94.826805,213.124284,307.143266,359.142032,373.352087,325.76443,182.393843,105.458512,-58.346296,-129.541261,-134.255841,-33.700107,-45.924398,-178.292762,-221.771129,-196.281415,-149.454375,-8.795966,148.236397,191.660122,177.496958,142.478994,113.196045,157.863112,327.424799,368.983056:40.560914,-19.116351,-31.162697,80.133786,146.030779,135.486596,82.185392,-17.494704,-52.854495,-41.901422,-54.771263,-106.51362,-213.541872,-206.747652,-40.180708,60.456399,142.81846,94.542252,74.669799,56.621702,15.149773,-135.481114,-184.460395,-169.853898,-147.373302,-157.708304,-133.604397,-98.697944,-49.8535,-18.301061,59.617413,67.880397,75.79458,96.221488,56.565782,-79.376046,-143.967713,-230.741146,-230.205765,-191.573835,-174.979882,-159.966115,-119.159521,-97.878294,-89.573734,-98.870602,-48.682285,19.030372,143.319329,170.010663,165.924564,153.416824,117.072569,-5.506557,-43.611468,-49.596828,-57.676072,-61.534808,-6.621932,44.256001,70.778639,25.977741,-67.787511,-79.668188,-67.499104,-69.355979,-71.79792,-114.5646,-168.267965,-250.378748,-257.615163,-268.58602,-214.28601,-129.471734,39.061919,78.168604,4.74964,-100.969648,-242.842589,-218.794771,-107.556547,-70.613426,-56.488476,-72.813181,-142.142537,-243.333408,-208.469291,-122.147753,-148.603283,-155.69998,-143.184008,-155.998298,-210.053384,-212.565095,-141.729768,-95.329549,-29.970142,0.39648,31.00037,137.377396,163.41575,105.707778,72.045419,109.024234,204.289846,191.335078,-10.849119,-113.794965,-131.794127,-98.992275,-106.019786,-111.224649,2.143249,141.195767,132.565351,16.481909,-32.374168,-67.908407,-62.695993,-42.035941,22.051664,74.044226,139.694738,137.923702,118.883178,125.812997,164.011653,174.490194,159.676042,144.874653,149.391273,142.01304,101.075245,-31.370763,-68.774306,-54.531771,-34.854564,-41.164508,2.635506,81.137225,201.006921,176.556315,44.683836,-13.003141,-76.318839,-0.269022,69.573401,119.893495,68.487141,-70.471459,-88.672538,-29.643179,44.850201,65.665248,58.201179,38.250516,-13.548001,-21.948075,47.115196,111.718976,263.991644,367.215361,327.358889,123.521136,54.500198,28.063146,14.863607,-58.640862,-44.353015,-0.575868,15.273728,-23.077928,-112.097211,-132.991574,-93.551852,-55.298227,-8.206057,-2.128709,-8.603126,34.751542,81.738246,125.600081,107.426981,65.69715,123.128895,159.80729,144.924659,115.550051,90.818837,105.774614,179.966073,197.386036,164.676137,127.817057,95.457214,13.921584,-8.237303,-69.305849,-136.058181,-242.923503,-193.011878,-132.990657,-27.749502,-7.247485,-66.898403,-110.948003,-108.408989,-84.866284,-40.454158,-13.46044,-49.662499,-150.00634,-157.241062,-129.111415,-126.028999,-70.394687,85.684881,155.203557,168.836837,108.561458,-8.675679,-2.221141,139.335433,205.797596,246.393855,200.437633,131.571332,19.09304,19.505484,59.522147,81.057906,151.645279,222.767284,234.707898,226.120159,207.189558,104.780534,53.92947,83.241686,132.45843,176.455869,152.695487,107.874384,-56.133495,-144.389135,-216.740556,-188.435229,-95.418048,5.736521,73.177731,199.849774,244.452254,271.508047,245.310357,158.071902,122.447843,136.170305,278.093771,324.172449,260.631422,191.896303,134.57951,167.457735,263.932729,303.633187,301.581663,248.964039,223.346974,195.608151,171.84711,152.866184,179.477341,247.395543,227.150905,191.174606,176.746856,188.768077,166.98949,148.766884,160.245403,174.900423,138.677087,-21.452822,-83.05249,-82.847065,-64.576134,-54.681208,-36.068047,69.062218,187.426807,198.010091,103.046106,33.770732,-71.407336,-109.689323,-148.584221,-50.464668,16.444436,57.2622,53.316007,35.361689,-15.445646,-147.613091,-146.505007,18.018754,108.320196,57.302651,-63.494417,-54.778318,79.517254,146.123228,173.793883,113.897433,97.112026,84.418597,83.773759,76.622348,52.732867,40.041464,80.901721,178.227785,191.943205,160.851634,84.653581,58.204242,9.884593,-14.140649,-37.593595,-2.501533,36.786626,100.006608,120.221643,178.95851,188.304102,108.636136,56.757941,48.046618,171.121061,209.933129,152.65152,95.421924,22.129727,22.087563,86.160492,180.147464,222.56763,234.29507,189.431045,67.116408,27.278361,-16.472422,-49.761463,-98.268397,-49.748485,-43.606907,-64.562994,-44.805535,21.027492,36.433771,33.237406,45.421445,72.127435,157.465877,200.412705,183.333296,107.178539,-30.777057,-23.543188,152.107208,271.482532,219.160779,41.745043,22.118383,125.540739,184.85257,244.515175,281.039703,323.389894,401.914322,403.029197,297.205915,223.413911,135.044722,83.763027,-99.981789,-167.655005,-130.926773,-36.295695,-10.943408,-36.923026,-62.207553,-54.54431,16.299857,26.985314,-3.702956,13.139309,124.037153,177.642377,247.352811,263.72193:78.62783,20.020096,21.254602,159.928007,220.360865,149.769228,54.392347,-125.554282,-186.518005,-162.920087,-116.765403,-133.408564,-239.92591,-261.926724,-133.305041,-39.450707,63.476174,47.884121,1.715786,-126.645267,-190.613351,-282.300355,-288.754863,-227.88681,-112.797133,-43.379952,44.496866,41.035581,-41.583801,-81.17531,-118.569782,-132.151018,-94.801559,19.505934,17.798022,-127.706877,-203.580863,-231.522415,-181.116393,-59.758549,-14.632332,-5.951303,-2.751943,-26.472694,-102.294719,-115.229968,-79.047888,-74.424282,-120.266984,-104.851023,-60.628348,-10.186984,-25.933169,-49.787246,-29.560323,18.08406,4.407111,-4.881791,53.361902,100.96495,72.230374,-0.710675,-75.608593,-42.92089,59.496161,22.864219,-37.815868,-124.780802,-149.336529,-166.169579,-171.753977,-227.34081,-180.955123,-99.623604,55.226203,97.768063,28.820287,-77.372871,-214.105831,-188.059467,-73.896426,-48.328453,-52.842429,-51.205408,-57.757665,-95.254197,-106.493055,-97.608498,-81.098292,-62.394053,-24.245501,-36.511011,-102.905418,-105.984182,-27.470899,8.237847,24.29947,66.055442,137.371938,270.576894,242.001122,73.45582,57.761934,187.110686,224.867556,161.352361,-5.276194,-28.071216,23.245334,16.537479,-19.70218,10.801517,101.117548,142.6827,153.13461,100.389346,32.40096,-77.749208,-99.017875,-104.832224,-22.212019,53.694165,197.165379,226.751668,183.837768,158.850343,200.7803,242.042401,265.174215,250.723263,237.396862,164.539887,133.284543,157.658657,187.19051,198.526551,230.204083,272.907101,324.280151,306.647477,174.9384,102.767985,61.238046,61.934491,33.962843,55.800532,85.192369,85.071013,50.806258,7.382589,25.991556,91.167377,94.141933,59.442252,-25.263288,-39.58619,-19.618838,-4.131908,56.831352,112.278374,232.143162,236.857822,166.275692,-49.315529,-156.369319,-265.150378,-248.26889,-173.713284,-130.116298,-135.605555,-189.493404,-188.341128,-170.176052,-217.945269,-327.100384,-298.453383,-86.817267,31.345524,6.246064,-25.429507,7.352524,75.452046,67.24428,-34.853867,-55.727444,-9.482448,46.184037,39.516269,20.877121,14.848607,-12.889525,-48.953618,-115.567451,-92.616128,-79.716999,-86.7659,-102.668056,-187.354678,-255.070395,-374.787178,-309.76274,-207.455664,-94.726797,-120.41944,-218.762545,-249.940719,-213.184942,-151.897629,-65.828915,-117.549688,-157.890252,-193.767464,-207.261868,-224.859599,-207.458537,-157.32532,-88.115492,-32.083752,37.290509,22.407117,-48.327751,-60.712433,12.031547,81.387943,210.578732,212.775223,128.593919,-92.416942,-145.458184,-105.525555,-63.21609,-20.45476,11.00343,31.519146,48.596502,43.881617,-35.239477,-102.832774,-156.944393,-136.885782,-79.790689,-20.700495,-20.025084,-173.614298,-310.400909,-495.993355,-497.341518,-402.040003,-253.863331,-184.381801,-146.99154,-165.150092,-183.156574,-177.415308,-168.964412,-180.635611,-204.733017,-141.835595,-96.687271,-101.919996,-162.893024,-274.115142,-289.718775,-313.774612,-318.286993,-265.925114,-133.644096,-98.567768,-76.940997,-86.468615,-157.229365,-188.681664,-154.629124,-94.439168,-131.223303,-261.226451,-279.053811,-191.640598,-139.895155,-162.617921,-253.80455,-263.761312,-238.839033,-222.849807,-224.629797,-240.551557,-246.498097,-224.221734,-149.218209,-144.561339,-193.365934,-318.909442,-352.566556,-332.986986,-316.958151,-308.855357,-224.881586,-166.959762,-101.212185,-83.960035,-75.760972,-97.968037,-155.370393,-151.153901,-49.698838,-31.555248,-115.866724,-299.972204,-312.454111,-156.271335,-52.436586,53.377554,53.321308,42.120482,14.686769,3.934498,-44.343202,-86.291471,-108.855014,-70.37845,15.527313,64.717831,77.602801,41.326278,-0.711324,-53.471556,-57.628764,-103.623896,-108.016836,-42.210045,62.872324,47.074105,-13.594961,-30.41849,-87.944921,-132.580278,-187.181539,-120.69736,-92.337703,-146.095902,-185.111732,-123.931057,-25.010591,162.095768,246.590051,254.176133,164.030651,73.927572,-85.416803,-117.468028,-140.43874,-183.188762,-253.430369,-169.915035,-129.977651,-154.637944,-183.073998,-157.609646,-119.932608,-90.58637,-82.206371,-54.969407,50.739453,104.374321,126.391813,96.935768,26.401513,11.563478,92.013641,200.13576,177.983425,58.52828,38.636138,100.877699,147.269991,183.823809,198.620857,250.440041,403.790322,442.377764,316.805057,196.935058,29.831506,-28.27569,-140.951433,-142.065115,-108.9249,-74.907839,-76.496864,-47.777563,-18.43277,28.231649,115.685868,169.970711,212.624352,213.085702,273.707001,326.795904,393.930897,401.866752:139.183405,153.230413,116.736245,61.812073,81.15507,145.202874,127.658955,-7.558791,-16.125861,32.23048,40.543808,3.802044,-29.067996,-21.252307,6.12127,29.499532,105.336878,185.844896,205.281703,169.06957,110.515336,-7.384002,-15.301913,43.814448,76.933771,85.550365,120.593461,142.9585,140.254373,116.307475,108.151059,125.471289,190.969515,207.310699,120.759843,-158.714356,-253.200463,-247.093803,-203.431593,-203.385809,-192.326734,-140.100795,-87.838337,-114.077163,-184.113067,-205.268146,-154.740095,-60.315396,119.934436,58.192643,-14.852266,-96.137865,-133.797682,-217.268038,-217.321787,-173.529643,-146.062994,-95.367533,29.44999,66.012061,60.875057,19.907126,-23.856364,2.897834,44.993172,-8.410535,-39.697055,-107.180482,-155.636985,-220.76033,-210.19239,-149.822465,-87.215577,-66.055604,-76.093616,-79.024268,-99.759613,-150.506593,-181.821566,-108.7781,76.189871,131.086187,119.104513,37.969374,-21.526505,-80.874273,-56.862103,57.851531,102.768996,78.196007,61.907044,62.774465,-57.286498,-126.172997,-69.637984,10.754724,100.984392,134.245856,132.757479,94.711099,72.041337,18.870615,11.327352,69.588232,95.476443,54.280618,-69.801097,-94.319683,-111.730685,-164.949812,-306.186348,-324.228411,-166.065736,21.12128,4.716749,-168.972124,-226.378244,-201.73155,-167.210392,-112.569884,-17.123323,15.417982,-7.578538,-16.449521,21.715162,47.246652,92.65496,102.251328,124.170992,150.29049,121.783417,41.498353,18.691791,-28.600836,-61.440151,-112.80336,-64.000311,-2.400067,71.144299,64.014679,-15.34156,-86.017458,-176.58771,-148.607075,7.295938,122.154317,125.55345,43.7914,-41.534668,-186.426661,-181.440865,-113.803588,-75.596471,-54.947546,-37.009122,-47.262696,-112.91746,-142.683087,-89.472001,-25.920973,57.972253,91.877386,95.023642,70.667764,46.234712,-54.109372,-117.078153,-148.231123,-15.404963,32.34912,-23.345563,-77.830543,-126.48878,-125.313125,-108.64585,-92.789729,-43.873561,-3.358828,-6.263805,-9.776434,20.276044,101.601052,120.261127,123.050337,158.681727,172.711965,92.493826,16.797418,-39.434707,7.778808,115.983582,118.689812,86.313777,85.407796,76.743648,32.428521,-19.483691,-177.794801,-224.63164,-151.566389,-24.63366,-7.18653,-24.274008,-30.051455,-70.132833,-117.556102,-166.315035,-137.097984,-42.849174,5.930285,10.602271,-33.203543,-77.306035,-173.531814,-208.887569,-167.917686,57.388394,159.38224,176.527414,119.246127,18.04558,9.92715,51.124066,65.946377,156.368399,302.033317,277.877975,54.964979,-38.159053,-58.524854,-13.362573,70.111719,109.248772,98.857577,7.038907,-50.536378,-167.276297,-195.972538,-73.648401,37.575678,140.974249,49.935795,-6.902716,-86.184219,-146.737206,-272.320223,-250.143785,-31.408834,102.62894,82.400772,-4.010836,-10.946377,50.103251,90.199878,137.025032,127.993959,103.572262,148.947504,165.909214,137.829777,107.348579,112.625172,170.091834,269.594561,232.146455,201.614902,208.260565,238.13431,226.875022,171.452955,85.060046,91.494834,145.874908,65.886472,-17.952806,-80.852271,-63.272595,-7.130656,47.665329,142.392437,113.831066,73.105548,-36.347973,-85.263627,-90.100418,-51.86145,35.024729,67.924022,126.683292,145.05608,90.618379,-93.136528,-176.480459,-278.213759,-289.700704,-233.380428,-121.552747,-90.755837,-85.217092,-72.578314,-68.5029,-107.270843,-165.49852,-140.909883,-34.948696,-58.745931,-135.702633,-222.823317,-182.231209,-51.109367,-16.479032,-3.876653,2.794584,14.787327,60.803053,88.81216,72.013823,9.009594,-87.609987,-42.744416,157.584394,179.551965,100.332484,-54.544517,-74.805316,-49.991704,-40.982344,-41.778773,-16.540554,6.318408,21.306538,32.337995,96.844219,111.820511,52.998864,3.395857,-19.495846,122.756854,177.020534,148.798252,119.931308,127.926743,153.382936,192.256826,215.388417,219.66187,159.301909,97.734694,-21.921023,-60.754718,-103.801303,-118.594393,-108.755298,-15.094368,27.383688,39.147803,24.907851,13.715755,33.7772,110.532343,110.177771,70.520636,60.909334,118.600627,172.280593,116.66195,6.338587,14.947914,125.781473,164.562932,106.567744,-29.418603,-34.019312,104.695004,193.02741,267.819673,296.673116,331.993759,389.160662,396.71787,316.942241,216.788554,34.0393,-10.746918,-22.914076,42.648598,51.895918,13.844509,-3.517953,-37.086125,-34.505566,39.281718,96.736851,76.603054,3.483136,37.642916,282.486158,388.896318,380.100582,307.514296:forward
18.429865,-68.3804,-84.213329,-21.474046,12.007827,-39.22418,-78.996803,-4.734648,128.430328,96.332916,-48.79055,-29.546282,143.098216,190.458669,196.424653,198.122393,186.278922,88.304849,41.845096,25.538,36.570203,56.539977,53.525288,-9.081899,-104.328105,-169.987803,-275.037217,-245.678329,-78.146639,-21.806507,-6.639558,-18.130473,-33.272109,-53.814969,-65.944472,-44.789049,-12.783663,58.946377,68.088616,1.972681,-19.405282,-7.116223,-5.776278,-1.805464,15.875829,18.285476,28.104929,24.588917,-10.726619,-81.679827,-123.92941,-109.521421,-22.531256,222.048793,291.259991,205.561881,52.566128,28.631841,-2.809883,-20.203707,42.731317,131.586389,296.257207,317.392011,265.486165,189.271621,133.425923,24.427061,23.336349,177.966347,277.146486,310.112694,228.705057,230.165149,262.835545,271.772286,284.820031,284.787942,257.500279,245.985319,269.0972,249.959033,195.70581,88.74687,79.653758,124.029589,132.6985,65.005633,-50.508404,-112.46911,-231.362704,-258.244411,-240.98428,-211.111634,-113.005217,-67.216968,-57.572909,-172.115165,-255.532505,-342.48054,-314.148196,-176.681592,-109.920756,-23.682789,88.476392,145.088649,138.203318,119.011586,193.997605,255.655928,300.44383,264.844694,134.120686,26.289347,-6.863511,33.502038,108.226878,272.066346,341.974449,455.552989,478.635119,459.2448,467.968171,486.133254,401.529222,322.020129,280.035601,293.849365,254.112293,153.381312,117.407391,124.555872,149.081776,226.164521,282.424397,326.866327,270.000055,221.898357,40.188309,-39.182108,9.780724,90.711661,95.777492,9.50219,-125.912522,-91.151208,-72.206448,-112.876691,-134.096676,-80.889122,-13.796736,52.951437,-29.800779,-102.35673,-323.989919,-421.52878,-434.398445,-385.262269,-318.858794,-313.610569,-333.548105,-308.748541,-253.490584,-111.143758,-77.405511,-59.737193,-6.494752,163.211392,184.52451,152.855631,157.329977,177.608785,162.87117,167.795873,241.277845,238.832636,119.016841,60.133242,82.481343,210.066089,314.676503,541.662684,618.574577,624.109244,482.52928,388.359769,191.37537,94.978884,-40.739751,-34.862337,64.665354,70.532361,-22.237887,-61.885892,-43.120027,41.493774,61.045432,-12.168453,-49.600411,3.83204,129.195263,131.872957,10.67394,-49.399429,-56.951919,10.393348,163.912826,158.455485,10.805269,-116.085671,-144.702266,-122.107904,-114.929082,-122.193033,-74.034737,86.317675,100.991996,65.959545,11.413759,-12.907203,-57.584049,-51.471909,19.258142,44.718553,38.713839,-14.494713,-47.832703,-60.385414,-34.253645,35.20708,45.648079,-22.049798,-67.626487,-62.300454,-60.137558,-61.984743,-32.147176,-5.627438,-3.247312,-36.215723,-102.743055,-211.077494,-282.112171,-305.875028,-264.515408,-194.153563,-171.66037,-136.679324,-97.346076,-97.43353,-82.182565,-3.204046,158.542528,142.894914,3.404007,-68.086699,-221.15676,-315.843841,-303.585631,-195.638674,-159.269572,-173.244641,-173.447001,-94.046293,-11.024514,7.821801,4.147496,-13.171312,-48.715909,-38.860137,71.042195,137.426382,219.378811,173.547226,79.900021,-101.645278,-108.838032,-5.246786,36.59106,43.165719,10.511114,-1.692063,-27.048521,-22.412664,89.624428,188.410974,323.78644,298.377848,120.79456,-24.965796,-70.812441,-103.347873,-81.806862,-8.895925,1.059683,-36.885937,-22.069752,17.547152,104.784078,146.248926,220.014206,245.321971,259.361724,251.839367,232.76917,148.750289,67.850794,-49.582265,-48.787427,43.873391,108.969877,178.128764,107.25923,14.855607,-180.166002,-190.564464,-31.821439,51.825139,133.851368,149.089777,98.879208,-185.245137,-354.253596,-465.132336,-401.937545,-242.100907,-189.351543,-142.555562,-211.991377,-267.184922,-319.384632,-309.024371,-247.303032,-197.462073,-80.095663,-42.335691,-39.676934,-81.877882,-108.119003,-175.322197,-204.220111,-155.202543,-79.679257,-9.913945,-93.697805,-124.148091,-143.035772,-148.589569,-130.463711,-103.811696,-85.196369,-139.231559,-367.013552,-548.882499,-570.664358,-462.185323,-377.027612,-253.942547,-197.769886,-94.047363,-101.665247,-169.219075,-411.660131,-500.834476,-479.026452,-413.997118,-272.520447,-208.796214,-171.051736,-307.999784,-403.034597,-446.295013,-369.409339,-142.87063,-62.017491,-31.50723,-84.454553,-133.71925,-228.892943,-220.362519,-113.109912,-83.79723,-70.899456,-49.079744,-31.927672,-149.82977,-212.750922,-164.675955,-63.494265,93.784942,108.276415,70.944976,38.931159,8.172653,-70.917086,-62.179313,54.260574,87.036977,50.725837,26.81918:18.864677,73.728542,46.212784,-61.453994,-70.752189,6.552583,53.862116,114.638444,84.208818,15.319641,-76.986136,-27.317338,126.587593,130.14246,15.717154,-23.327711,-1.110976,-69.514624,-137.292486,-124.140298,-34.618038,137.859653,146.570045,-1.651684,-175.132081,-235.116888,-260.568465,-208.1497,-62.148203,-13.923049,10.254304,2.356052,-0.439795,-4.228076,-11.07576,23.223764,58.079171,116.503161,120.916182,57.017377,64.295372,99.463543,90.482396,65.52781,123.887957,203.566961,288.634303,256.476959,131.439659,-14.047714,-74.830219,-75.966417,-8.293541,209.441171,286.022477,193.931449,-29.468445,-81.715474,-42.456068,28.910787,210.795977,283.363961,276.74215,211.944126,123.614423,65.001821,17.475029,-11.950226,53.279976,286.958806,348.964169,219.380347,49.766901,55.227282,169.59041,213.877027,193.574569,155.382724,133.77737,146.161668,139.890351,96.634673,99.671903,130.288194,133.015631,144.50003,137.933248,22.677746,-109.485129,-159.790942,-247.578013,-262.482354,-200.328215,-133.069376,5.39856,33.139982,-69.821171,-262.072158,-316.129273,-276.821564,-203.074679,-61.121488,-4.800848,121.083272,166.572493,128.681182,39.960382,34.957545,58.237481,58.453997,99.013756,120.293565,-4.196824,-180.485596,-175.205486,-48.063789,9.594826,84.412519,133.465211,290.691747,328.765189,261.57261,185.572182,219.408884,252.549106,222.282489,201.762109,231.737757,265.880683,171.125091,113.545703,81.600033,113.026666,229.178168,262.478017,208.767,146.728755,116.389508,-22.995002,-92.535475,-90.51073,-33.584435,-27.878227,-115.563228,-240.59968,-164.866918,-129.089584,-95.719008,-78.694938,-3.978673,57.657144,77.125828,-36.848586,-68.779435,-171.042537,-252.473817,-322.961828,-284.637259,-162.113738,-121.604057,-88.82395,-129.075208,-156.160195,-160.119195,-140.178999,-65.111676,-13.441948,92.615331,75.838897,8.561095,-60.740501,-35.843719,55.063419,104.907722,128.445841,79.666743,10.260345,29.329956,15.612745,34.228229,119.527755,329.909788,362.240896,234.186741,135.477256,114.381624,-12.599343,-83.601301,-95.606977,-47.379943,50.209646,58.58809,-57.808861,-194.163444,-191.349076,-47.502714,25.308581,35.622339,-8.777859,-42.435749,30.931029,33.516762,-67.215524,-97.531607,-6.213547,65.927555,110.411972,92.303549,29.944399,-139.146828,-213.884065,-225.075945,-210.891577,-165.791629,-94.668928,53.276052,65.750639,40.915976,-6.539335,-14.08991,-30.716944,-39.135968,13.912871,44.807521,-13.113782,-145.434839,-164.133922,-120.882514,-106.900158,-78.150585,-58.034851,-61.893071,-87.3944,-101.961307,-74.99459,-35.364685,-58.218282,-115.403052,-164.773644,-159.906698,-221.391845,-377.318149,-398.837732,-286.175964,-231.572982,-180.87637,-141.103918,-37.856271,-2.79069,-33.365577,-99.210734,-70.372054,34.058462,52.995613,38.51056,-9.877815,-178.038895,-222.151055,-184.443386,-111.546798,-89.857415,-59.375555,-64.842971,-82.853746,-27.584436,-18.326647,-102.491556,-140.106551,-97.118036,-32.712195,73.819426,84.997112,86.3083,54.197284,-15.624823,-155.372401,-150.422682,25.279681,122.708668,152.803952,-13.419409,-103.048462,-136.684678,-49.341763,203.467625,275.593032,238.198316,173.007701,46.240888,-62.515287,-90.980638,-49.892315,0.624348,91.002499,109.489095,93.378374,78.074341,69.974312,62.252722,91.784103,184.505149,212.89219,223.603614,223.983572,214.150299,119.533414,59.615562,28.356687,58.194917,121.822943,132.902994,96.355665,52.140057,25.068768,-102.457081,-145.273805,-45.424926,45.338981,134.70371,128.667168,77.967376,-74.137426,-182.831769,-242.890423,-162.586017,40.012434,91.10468,55.770172,-48.883473,-107.021635,-225.556922,-230.759192,-72.084081,26.132131,93.781058,81.670609,61.629164,-36.740637,-135.697451,-300.454248,-303.795713,-158.110011,-72.864352,-37.593343,-193.949797,-264.951769,-252.102317,-175.824163,-27.290296,-9.791832,-94.360598,-149.089619,-240.34678,-416.981724,-496.107465,-431.838348,-310.78905,-128.814676,-111.417193,-131.244921,-166.153811,-230.834294,-392.068846,-406.962197,-285.041443,-216.328664,-148.299147,-122.684376,-101.305094,-212.833689,-247.613972,-140.181762,-48.059202,53.669194,44.532717,5.283813,7.629524,-27.09338,-85.502602,-59.662708,18.498614,27.777425,50.474707,86.054917,45.384979,-186.497726,-243.931357,-88.701354,48.646704,196.343934,182.099731,88.86348,41.820225,18.276118,-30.174749,-22.688417,19.079807,13.943334,-41.558885,-67.383433:37.839401,-9.068534,-63.672838,-129.309858,-89.092228,82.930342,133.984364,99.236044,26.700475,10.639785,39.852809,75.811134,69.0952,16.767767,-38.459439,-0.304864,65.801804,-157.977203,-271.714634,-184.350149,-61.337188,74.724555,76.991734,-24.776639,-173.732703,-220.656126,-244.250608,-222.085787,-85.73608,-9.097407,13.350759,-17.281542,-37.526293,-59.114826,-62.820542,27.111057,79.662705,99.842012,91.545234,86.177279,94.074445,109.943284,170.483521,207.460034,271.902901,306.824681,323.653073,264.821361,91.44738,-34.587172,-51.834348,22.576197,57.534306,93.687264,119.192315,103.393117,-77.014666,-164.912651,-104.592901,25.443237,256.608478,330.624234,340.224247,264.455328,97.549631,-21.771642,-68.282072,-47.706442,49.112181,286.075031,291.596144,28.562329,-115.271765,-87.923914,-2.551645,45.061027,164.7579,182.297013,57.133322,3.37013,86.166827,128.160951,79.092305,47.949509,81.482005,82.602847,31.574617,-59.803695,-85.690541,-105.873195,-177.910831,-210.411092,-230.422034,-203.217061,-88.841734,-63.094336,-177.340247,-308.402297,-320.435577,-251.584471,-186.815948,-55.9503,-10.375878,6.894037,-2.410348,-8.969973,-83.033369,-94.62951,14.847877,54.844714,39.924685,46.195848,27.644261,-153.271656,-207.220115,-119.129439,-23.556267,124.435082,149.476975,170.384484,138.361411,76.739332,71.543356,158.591359,219.578365,150.767001,39.253803,31.27162,59.698163,53.343102,10.470186,-36.911217,23.486473,212.235858,226.102801,93.944866,42.842871,19.886548,-109.881937,-147.06473,-101.702153,-69.498648,-80.723235,-124.32214,-202.473163,-157.456732,-105.409769,-22.775877,3.166185,73.227944,121.213059,122.699525,9.071436,-24.551831,-86.967131,-134.894116,-188.155895,-178.019432,-110.581069,-65.112286,-9.638574,-84.77776,-129.313256,-116.911722,-71.663168,-25.116526,-40.772145,-39.507919,-6.122512,-21.540532,-52.971083,-52.669278,-14.157775,49.047595,152.249506,108.83655,-71.523823,-79.38924,-15.749935,163.742629,248.169617,319.646669,293.446438,214.30825,176.320101,113.819382,-48.998261,-70.229395,13.155408,60.698374,61.698358,15.990248,-91.218097,-135.032541,-120.309186,-43.942529,11.017074,102.573673,69.971592,-116.452834,-96.660518,-49.589456,-95.83074,-122.040959,0.46898,109.83903,257.645381,270.901177,167.27346,-36.625576,-115.990495,-151.872093,-130.097468,-57.807454,-26.926559,-38.956153,-72.472916,-64.997608,14.675907,79.298697,138.892187,117.983565,70.033696,63.590076,10.617901,-147.855034,-182.721226,-113.402016,-62.075973,11.157988,20.039078,12.860869,12.54668,-16.559565,-30.111658,1.942641,24.93568,11.021166,-16.831562,-30.839592,-98.806276,-234.591773,-287.458248,-253.553155,-197.503454,-109.61541,-76.125881,-49.501757,-39.749656,-33.63846,-5.447313,38.903228,121.266678,139.640685,140.055856,81.263772,-125.102915,-183.980575,-152.86556,-109.389716,-99.40317,-69.015687,-78.220065,-149.279721,-174.410255,-171.311815,-141.071606,-95.25714,47.973486,117.088813,167.225715,144.636284,81.373406,-24.043782,-92.665552,-131.98232,-76.759643,57.260872,82.844093,103.606889,74.1606,17.605659,-51.306446,-15.13359,145.892789,216.94177,263.292889,239.749712,148.51224,57.938619,27.284137,35.882551,86.673314,216.605652,240.704931,177.671062,140.334307,141.132555,131.238562,145.152508,218.222743,247.660283,238.25833,206.244808,119.349452,-7.202827,-65.053817,-44.560256,33.691855,151.396809,161.330975,165.010376,190.813521,177.739334,78.042085,45.577735,97.818588,138.511315,143.940761,125.351869,89.783827,-32.462968,-111.417293,-130.86722,-87.134217,-30.681436,-25.756177,-75.891393,-150.709853,-151.015621,-111.813236,-97.439555,-61.083984,-14.17259,134.133207,183.957646,133.23151,-63.654728,-164.271479,-264.467936,-247.407528,-107.373859,-38.683937,-61.142801,-189.602053,-225.770782,-240.482165,-194.630692,-15.100606,37.804928,-49.583086,-145.290703,-303.312123,-390.724348,-416.554053,-413.963062,-366.750342,-226.940382,-194.773606,-227.038232,-254.82216,-268.521173,-275.199798,-249.832382,-136.175199,-53.0149,29.909867,-13.56407,-143.142249,-136.229485,-100.49539,-48.089036,-18.334269,76.691094,80.325673,-58.338101,-124.033829,-125.145835,-126.222287,-100.888327,-24.238908,-11.001654,0.00112,11.730325,-67.798077,-268.446918,-305.30779,-148.03581,-32.799547,61.920774,46.171481,14.126163,28.576738,24.713169,-11.887995,-20.969851,32.016347,72.862726,59.665238,4.212996:-102.580793,-103.795002,-105.704103,-110.476408,-89.132847,-40.985902,-45.865583,-83.371054,-96.620097,-115.430952,-135.081212,-90.179731,39.657009,53.634298,-14.27858,-26.880838,26.876896,-106.439,-212.350308,-193.722209,-108.441646,-16.718913,-31.649171,-171.667282,-327.424682,-364.743463,-365.639248,-321.206278,-152.52958,-72.645252,-10.776767,-15.023799,-44.558437,-127.208837,-149.344973,-63.051316,-6.999686,15.071084,-6.3862,-72.372601,-19.437435,48.841012,97.587678,77.084816,58.300008,75.850002,105.44709,99.718097,42.12013,-101.417566,-155.697249,-128.942603,-73.410404,66.742321,129.096822,128.822287,-4.262612,-66.516152,-95.469251,-41.797759,151.632736,258.072542,393.622983,380.269111,217.773685,42.544655,-9.900764,9.232774,81.144901,251.837815,292.985956,227.491558,133.590659,131.493864,169.28019,187.636246,194.448037,167.504863,75.580435,58.446561,124.526889,133.513998,91.919219,44.12333,54.133434,93.676564,102.341388,63.861851,-6.513034,-66.38569,-223.893723,-263.944221,-241.39681,-217.230304,-197.217577,-201.86712,-200.856937,-217.656354,-253.671787,-270.347081,-232.141614,-122.125641,-79.665456,-54.433932,-2.092453,40.888801,90.548079,97.27057,89.194458,91.591707,157.287178,192.359737,147.76033,-39.818834,-97.503992,-4.852887,105.949139,282.368184,316.3987,333.293664,340.910828,328.503278,334.629669,350.740363,265.344277,190.295789,157.441442,178.825787,193.358761,169.005327,146.415864,129.767827,147.707042,233.216471,287.369461,341.647289,269.9164,183.122646,-19.435677,-55.233521,58.593053,131.839323,152.006523,107.243749,30.184323,-9.711139,-53.620124,-142.475571,-136.978627,7.075426,87.346258,64.418301,-106.804993,-151.768767,-232.810563,-299.888642,-380.156636,-362.894542,-304.834984,-310.520825,-346.128391,-321.43474,-271.192461,-154.160499,-141.638043,-156.31677,-94.633842,159.233017,212.544549,136.605213,7.737037,-2.452477,68.949121,151.064347,277.760466,237.054958,74.355594,87.712267,119.267822,192.937454,262.619896,457.657308,531.321814,507.377957,340.148132,237.951498,66.803123,41.563883,106.873144,149.120308,155.563922,112.257053,-25.140075,-130.200061,-134.280606,-24.151988,44.998698,73.505783,36.786522,-36.80729,-24.549443,-26.842559,-132.380358,-188.682918,-151.73937,-51.931759,141.339115,151.611138,-4.259214,-183.202523,-234.847021,-262.277144,-242.514184,-140.972655,-68.161257,18.794818,-27.51212,-73.455742,-126.554268,-105.801821,-18.386617,24.665727,94.282665,87.984907,-31.125478,-124.828646,-109.313863,-14.444332,19.405826,69.294359,102.766547,152.978244,120.313769,51.43409,-91.108978,-113.305735,-77.92905,-32.215537,70.758252,75.791986,-26.374474,-168.719784,-239.381751,-323.105546,-312.809382,-225.75378,-195.694374,-198.458416,-137.530719,-93.126693,-77.247445,-71.087202,4.021798,45.898806,58.78821,0.847325,-176.651056,-237.504033,-219.4094,-156.326725,-137.690203,-172.922019,-207.132131,-188.975495,-78.106035,-58.179827,-88.305157,-96.369016,-51.987897,8.982917,157.477476,192.873957,176.003143,80.548142,-0.459852,-120.131548,-110.838381,13.210062,83.079739,146.533133,39.377737,-50.797066,-141.340181,-100.783759,69.065426,150.480366,262.52694,270.019688,189.382377,72.801249,15.311205,-28.651773,16.311719,173.916949,219.185594,197.312076,172.542894,161.47901,102.662554,95.773537,147.577595,177.365026,221.646399,216.152549,121.504034,28.680273,8.84211,20.085026,58.734939,177.059249,231.930698,290.823887,246.010213,163.562588,-8.415283,-12.837766,115.47393,171.246705,167.647116,114.368119,-23.192111,-158.963561,-221.114603,-258.842368,-228.560917,-145.250244,-114.294383,-120.098394,-188.812273,-201.881032,-184.495196,-179.740162,-185.171558,-162.854678,-17.592129,62.403774,60.250439,-160.044455,-262.350157,-308.709877,-271.452354,-138.706273,-68.166153,-64.616139,-205.801943,-261.481715,-302.182675,-272.039033,-125.089118,-69.331392,-140.230561,-243.902915,-401.893995,-459.034442,-484.428204,-489.527837,-446.764687,-302.909332,-225.556598,-124.647411,-163.510614,-246.200437,-434.486265,-464.881319,-371.328287,-290.954201,-158.129252,-140.362818,-214.419222,-342.247185,-382.464813,-329.558978,-252.147993,-105.83119,-63.381686,-44.69246,-64.60569,-85.626987,-103.785564,-83.819711,-39.293636,-24.375641,45.20052,82.666803,35.438177,-143.691606,-199.300023,-113.055191,-6.657605,144.994018,157.252957,96.93132,58.965065,56.403127,53.631037,69.090194,143.864748,165.398319,124.598109,94.091965:-82.492612,-128.40639,-107.870297,-87.61114,-86.558902,-34.740712,-8.601617,-27.961096,-117.135365,-162.449406,-123.164932,-43.335757,50.914681,42.296249,16.096635,33.628087,70.545779,-98.532988,-197.029798,-198.923408,-142.489501,-28.566506,14.346663,-32.717183,-213.88211,-279.072685,-312.172478,-288.751967,-154.18898,-65.185973,13.452294,-12.453521,-95.712501,-158.185418,-149.970658,6.913004,84.826748,71.497137,23.186262,-8.154836,12.762311,-1.86502,-26.27593,3.17969,120.99369,183.88493,199.909184,129.573671,-46.372506,-187.896951,-224.287625,-165.182014,-93.689197,37.119368,75.635447,43.622892,-147.138091,-237.991583,-179.037301,-32.755084,236.686815,311.332554,356.65732,320.521767,150.878534,-35.147168,-72.322248,15.41422,102.492491,246.769371,269.25977,200.070367,42.699418,-29.840165,-47.950215,2.017301,101.641655,123.074937,98.373455,78.700245,78.192627,46.276018,16.948734,22.043957,76.656198,206.410401,220.664482,132.643415,-2.48803,-74.193234,-176.214385,-184.264272,-163.951462,-156.828623,-150.513851,-163.751467,-199.899548,-213.90354,-216.885878,-157.802147,-106.308309,-22.827687,4.524687,5.494331,-7.401988,2.155105,32.392565,67.157582,147.217866,151.139161,123.555329,130.286137,95.464965,-97.602241,-154.381649,-53.976108,36.59007,166.270291,213.843849,283.038951,216.325803,113.454988,-46.981764,-42.713862,34.276702,60.924947,92.753403,81.386701,-18.490456,-114.084096,-129.109594,-83.39308,-19.873592,118.751378,141.324415,73.420245,-29.628969,-86.252267,-144.310905,-94.263326,88.572904,154.170944,161.837888,114.551354,16.961432,-42.989725,-56.793922,-61.000124,-52.878064,38.776685,98.978946,118.871581,-1.967736,-77.119209,-171.296281,-179.863995,-145.685313,-117.592793,-87.807843,-100.362031,-167.901358,-234.130411,-228.474352,-134.448277,-86.418112,-22.789309,8.138555,102.296339,171.308204,147.227228,41.199602,9.737907,60.014051,157.355669,319.567505,281.733743,102.513992,106.723187,150.955974,232.817555,270.457419,343.057128,368.601229,345.885323,174.680019,44.503157,-100.032745,-67.596597,82.3169,146.771465,169.17676,117.380027,-29.32035,-130.832944,-129.5486,-6.096144,66.804172,94.609413,48.11532,-48.188992,-61.202127,-67.324096,-105.715255,-106.930875,-24.752058,54.112468,186.730907,175.77313,1.533031,-146.611406,-172.693367,-197.956635,-204.93751,-130.797373,-62.981386,-36.742502,-151.556465,-183.009787,-100.774608,-13.710916,102.135815,113.589829,95.371089,70.180745,3.735075,-20.592892,3.199081,55.56138,59.758979,101.946487,135.32302,116.198975,49.840749,34.154379,70.684138,90.909817,51.511584,49.216576,153.545127,172.302852,1.420641,-200.621674,-232.522618,-216.346899,-186.290784,-59.423302,2.967317,16.266932,-47.310935,-72.738972,-59.102701,-6.95033,132.103355,187.76433,179.789328,95.649915,-81.322156,-106.227225,-82.333327,-23.587327,-7.390878,-23.963938,-60.900735,-137.141709,-138.357084,-146.595608,-165.072257,-130.985877,-29.454529,8.118181,65.714392,80.855136,93.575099,53.529634,2.995879,-70.288946,-57.147535,8.515609,24.138793,47.093638,-11.86083,-95.582047,-167.233839,-107.736688,77.20294,158.539977,284.583396,323.275381,314.097192,211.350521,152.281514,87.846025,121.103749,289.53191,325.597194,218.959537,180.465456,187.258783,152.517903,152.592773,253.740089,327.28258,383.028188,346.856677,227.46249,64.858964,-22.524464,-51.260752,29.760756,217.161883,265.758069,301.47615,298.191978,249.950621,128.043854,122.510108,186.280319,200.611676,172.564182,147.491892,84.464857,-55.783836,-124.864763,-128.432562,-96.536667,-50.681161,-20.509417,8.607491,-77.018578,-135.54536,-203.665182,-196.634025,-113.7163,-49.192141,109.675231,172.418891,138.059926,-101.533235,-203.594093,-230.369815,-188.647875,-88.98559,-57.093535,-97.933546,-188.546771,-222.795596,-238.567909,-191.813361,-43.19343,0.12117,-35.484048,-101.549527,-262.140061,-368.881485,-396.491274,-414.556496,-387.738561,-255.421518,-189.324871,-110.960681,-130.782374,-199.269242,-357.996695,-387.564916,-281.223479,-163.148896,14.65366,9.84514,-109.020231,-214.314947,-255.576167,-259.404604,-201.743873,-52.308612,-36.850488,-147.434709,-223.89236,-257.512124,-317.61766,-279.352973,-85.742728,-1.673589,77.092132,73.883627,-55.259685,-272.375538,-314.06452,-182.571573,-85.174408,27.771744,63.689822,117.733476,59.306341,-2.567603,-88.494258,-84.439241,-11.42614,24.511468,56.419212,47.669618:-75.29022,-114.357852,-152.904161,-192.925672,-190.223171,-179.891107,-162.192061,-66.122828,8.68695,-13.731864,-122.473808,-142.586507,-68.371794,-14.556399,85.147811,139.177618,214.46002,136.876394,65.305198,-5.323329,-18.660225,-64.084034,-91.745962,-147.02598,-171.301282,-189.052493,-246.755939,-251.856376,-180.660079,-126.310277,-58.94324,-61.629254,-87.610885,-91.611731,-100.902706,-106.23427,-88.487423,-61.819032,-70.762047,-77.491889,18.587143,57.413748,31.911684,6.930138,-17.470976,-26.424307,-12.700226,8.999522,28.844787,-43.389559,-84.910664,-62.328397,10.163989,218.980178,293.342438,233.396033,70.949238,23.385303,-46.45945,-53.307403,63.911011,156.155945,270.997801,281.925527,273.013721,225.33323,165.08306,40.088714,31.239456,161.15311,234.926029,248.461429,225.338618,240.247817,229.257019,200.64522,175.237568,195.610641,256.790768,269.406648,261.145763,174.603067,96.06543,-14.932355,0.026812,105.995106,112.301452,-42.477367,-163.999586,-142.989894,-91.00024,-141.227844,-277.980393,-252.831204,-51.383252,6.774885,-68.52176,-201.535709,-238.314624,-260.598826,-242.834276,-136.067733,-69.988005,8.482029,90.408938,147.112615,175.56848,158.694375,210.960487,286.010078,390.514695,376.246283,260.096186,115.818916,52.863189,53.723972,136.145236,352.420401,418.860361,447.752414,454.159823,441.341281,391.038595,378.227083,362.133407,367.274257,383.042314,338.709916,183.540433,131.40067,117.331088,72.991501,82.367763,224.673641,334.972052,446.680572,332.008534,235.95652,98.701485,110.898937,229.247375,255.487074,159.159861,63.036246,-31.23618,56.115827,70.65051,-41.25067,-128.319378,-188.671488,-117.16441,70.796881,15.247787,-94.928175,-302.34668,-350.98026,-356.965589,-349.659175,-338.47946,-341.891497,-376.277595,-385.975497,-370.841541,-298.103601,-242.603429,-120.793949,-51.475369,136.131532,308.129026,328.800647,237.274821,177.652479,172.2567,246.153452,403.214157,393.212647,243.502187,201.832526,232.693846,316.148755,364.102813,547.888467,663.265129,729.700875,536.408248,400.899377,182.747901,125.46479,96.191253,115.461932,148.594485,120.557069,16.015492,-26.984914,-43.281258,-63.957893,-55.124664,-58.332447,-75.666383,-85.194099,-63.414976,-56.74185,-98.615929,-154.161574,-217.010936,-161.451971,12.27912,18.002737,-131.527455,-253.009626,-275.775372,-267.682643,-261.334536,-264.077226,-241.250889,-107.867031,-2.773717,-24.846477,-140.99509,-166.015159,-120.736136,-78.911405,-3.888143,4.8155,-52.110343,-79.752586,-36.363377,111.658556,158.487784,167.910294,144.194188,84.688748,60.60477,28.233333,-39.250357,-22.519271,56.494221,69.147319,53.48739,33.852827,-37.112592,-133.290366,-191.718334,-301.803862,-333.526937,-334.956369,-316.689773,-254.18005,-157.715131,-145.696183,-194.83715,-177.451549,-21.686202,43.022989,21.071682,-73.33468,-318.442409,-408.276031,-374.07019,-272.811639,-264.083289,-315.868468,-315.820179,-206.168182,-91.270993,-77.581753,-88.931627,-82.388909,-62.311451,-59.188071,19.867278,113.428952,239.23458,131.795512,45.568667,-39.662495,-30.460292,7.539243,22.498489,87.395393,79.416678,-3.298237,-151.205283,-131.273481,31.579203,115.148563,270.523239,327.146236,297.061245,121.913407,43.981314,-24.857277,-11.756754,97.953636,155.886157,147.748508,74.097128,65.017727,83.222646,119.034375,196.857334,206.91207,220.5383,249.781981,294.253473,186.016458,80.785222,-49.947256,-20.913236,155.652927,237.890627,256.856486,151.894546,100.291502,15.943138,11.920892,101.412524,156.019164,206.416468,185.589813,17.208575,-253.31751,-366.698767,-440.532097,-413.699416,-349.833991,-330.661543,-292.411742,-239.033634,-215.651738,-209.253359,-226.496323,-259.639912,-233.332979,-46.347483,46.642628,76.253321,12.139689,-29.404848,-147.348379,-177.961868,-105.047061,-42.898349,10.863852,-4.784875,-24.026319,-77.953984,-84.408586,-60.868951,-68.442782,-165.027436,-231.938831,-337.304663,-435.961207,-466.09824,-395.335524,-313.763983,-189.889058,-151.541898,-55.67525,-47.324883,-140.321271,-409.078292,-493.900891,-492.306817,-424.105588,-234.646785,-172.500204,-229.35678,-399.751848,-445.152237,-388.02075,-295.577837,-82.122736,-2.900431,49.665491,-47.679927,-133.860606,-242.512499,-226.31397,-114.583118,-59.875264,1.260637,0.978165,-40.256935,-119.512479,-151.617678,-112.506145,-49.858029,77.431977,112.087989,112.832501,128.687594,131.660651,68.114516,41.551638,85.015495,111.892493,98.588695,84.43326:-136.894326,-126.459624,-130.076813,-158.261924,-161.327613,-114.418898,-70.381645,12.23181,-4.579292,-68.629253,-202.693085,-217.198124,-114.108686,-20.717055,137.140364,165.542111,122.53311,-40.931317,-119.662639,-133.474782,-107.05393,-81.93903,-69.926271,-91.227432,-204.696786,-270.411925,-318.338117,-271.501449,-96.070804,-10.514127,50.734125,12.553634,-130.464771,-227.863821,-221.663863,-101.030937,-23.308096,46.888125,26.41264,-27.303263,0.079704,5.641027,-78.134213,-111.839995,-2.922127,97.886871,150.370984,90.755427,-40.017513,-143.414295,-188.781868,-176.670178,-106.294106,101.365876,200.871372,228.239367,-35.601863,-164.094722,-175.828159,-76.237179,145.544763,234.41975,374.175114,400.928215,283.44418,12.764694,-74.670344,-23.775782,66.799176,214.424377,236.966985,164.049817,85.304841,69.092993,57.065698,78.026694,169.275542,200.691499,188.17285,162.85204,87.901184,-68.138008,-142.989045,-152.255266,-94.078808,26.420095,47.908122,13.524177,-27.714755,-59.993988,-190.75101,-243.598934,-214.486577,-165.47334,-106.905519,-99.278788,-111.752694,-164.652621,-185.357409,-165.290512,-120.185664,15.111279,58.858798,74.209692,136.594499,143.352875,45.033094,31.493804,181.817698,281.8411,366.916795,335.325536,204.993369,49.65062,-15.078812,-7.383568,81.106373,324.073419,396.768087,367.757572,260.912512,209.662242,144.724211,153.080802,215.871326,244.1455,242.479571,192.904388,61.543642,-26.900186,-54.146616,-39.443533,16.614438,195.934306,275.209298,293.030305,150.962694,82.525561,-3.835056,-9.376523,89.084887,162.108566,207.508254,169.601094,100.832933,54.490428,19.884524,-35.125582,-24.724961,127.056014,205.833082,155.764414,-42.210869,-111.829805,-220.679411,-265.184577,-255.29827,-196.330042,-119.458189,-145.156702,-237.981589,-275.768815,-263.892691,-190.979674,-157.46103,-88.718527,-21.002543,151.060268,195.752689,138.537451,-5.616623,-22.725466,126.682693,272.396023,510.554236,517.089245,344.602335,191.703799,153.9242,203.643752,313.399347,571.622021,619.478426,479.040999,229.244055,112.616154,-9.827753,6.227697,85.335069,119.547368,154.961862,125.079397,-36.113922,-175.931816,-191.766285,-109.684822,-36.664465,50.534998,31.121777,-53.1859,-87.291622,-115.038311,-215.674379,-252.080686,-191.153735,-80.38521,135.240012,140.360877,-63.575439,-273.855492,-298.436594,-214.470669,-174.616439,-159.503725,-142.549376,-86.955256,-176.056772,-267.272881,-309.85959,-231.397549,-66.954048,-28.540989,1.65903,-4.80224,-75.989657,-134.382406,-112.211876,40.711977,127.280294,237.582344,252.922255,182.123479,18.605992,-62.963041,-116.981512,-75.440084,16.014235,28.400634,15.811494,6.12426,-32.729242,-148.769973,-219.633707,-304.942157,-308.664468,-216.970582,-142.230027,-90.192721,-186.372168,-231.275341,-238.615495,-195.604708,-22.349618,80.204294,160.369495,89.573915,-146.60981,-233.705238,-213.711798,-111.670289,-65.996535,-63.229566,-79.997401,-57.062111,-63.086628,-111.317538,-174.789573,-153.912334,-54.658985,14.383509,143.903896,161.253692,133.531819,61.513015,-8.69536,-87.215369,-58.685601,32.951471,54.49479,29.803486,-69.589585,-130.543368,-193.522631,-165.158307,-10.745553,80.102428,232.162162,282.128001,263.376774,71.954904,-24.327826,-59.480958,13.828057,253.37956,348.663307,346.746127,202.223687,151.504503,147.268547,174.197575,209.631918,226.901808,285.862254,314.627418,329.088144,156.875059,16.335419,-103.104425,-26.595063,229.143088,313.643158,333.156238,255.988914,205.454541,105.479471,79.090892,116.261321,170.242234,228.109668,186.956645,18.019183,-163.580024,-227.484057,-234.926623,-209.417645,-128.524845,-67.775745,-0.628033,-45.832213,-89.853799,-161.143515,-162.96853,-84.732637,-4.651671,186.414639,241.31186,186.934446,-41.143949,-151.489648,-198.474776,-134.896033,49.189833,105.581336,34.465588,-116.803257,-152.291749,-159.129632,-141.475778,-77.363765,-38.252028,-15.412192,-63.024582,-217.390495,-318.210347,-336.575759,-314.696666,-276.655095,-157.568675,-81.7018,47.912808,-36.546803,-187.687584,-455.177375,-461.149555,-270.446871,-162.179789,-44.311546,-53.437992,-201.946755,-404.44556,-472.941941,-465.113848,-367.257332,-53.638299,49.131727,-36.477173,-245.61572,-313.103278,-358.977537,-327.46642,-189.685745,-110.815011,-8.379693,-16.725921,-141.619342,-274.959314,-291.6485,-171.589999,-70.686296,61.241164,68.165215,11.9955,-37.575373,-52.586576,-77.609837,-74.35089,3.363229,66.302938,150.165039,144.435689:-60.82659,-107.62636,-126.776015,-143.036563,-151.883891,-179.843044,-181.13686,-102.220605,17.868425,33.724217,16.479717,23.012621,19.000961,6.169841,128.624972,262.32595,397.057066,284.0607,229.19019,179.586015,154.158602,111.736408,107.099093,81.266618,35.684937,15.530399,-17.820223,-8.694981,51.926551,69.969936,94.059081,119.705765,134.728426,44.294452,10.928336,27.607653,18.487828,-84.556308,-109.93267,-34.834512,69.719573,84.678287,33.065859,-0.399883,-57.677507,-88.07558,-122.600098,-134.284931,-143.912946,-108.024562,-94.36341,-64.290172,-20.397506,166.132289,279.332171,360.725637,235.579265,162.48244,71.996238,61.095706,104.004998,143.83691,230.464724,278.323427,367.002713,381.483474,323.187734,120.578629,52.307973,36.385635,43.302426,52.815547,103.046547,112.159793,53.467901,32.701602,96.102475,152.970911,256.532752,299.780138,324.044344,226.020506,146.656567,29.797471,11.102877,8.026131,16.489105,27.88086,31.679476,39.524257,45.944332,42.87808,11.0559,7.009174,78.747656,99.642112,29.900966,-40.716281,-40.61842,3.594865,32.738876,114.719297,161.85909,204.614877,247.555169,286.020306,265.369292,223.090539,261.344088,337.617333,401.890289,350.587266,210.781138,114.215176,61.038085,-1.16891,15.721367,148.261307,238.665503,353.988155,318.894028,237.249858,46.576554,14.825139,96.617192,146.753548,163.75895,141.185001,88.859569,-9.000211,-59.481415,-28.698026,50.537848,247.621273,333.254662,387.140907,303.10811,236.241237,125.007271,136.25657,248.644054,264.325887,181.152677,141.512473,140.904359,117.442642,36.836199,-173.263921,-233.827811,-212.017302,-146.806214,-45.407108,-93.003464,-148.341123,-259.83228,-294.621742,-310.945252,-325.156375,-411.129326,-450.298004,-430.67613,-318.765741,-272.436782,-241.078125,-234.398788,-143.328865,-49.683877,186.796063,341.056576,324.236095,164.824785,92.635558,87.270807,173.094001,377.711887,399.408498,301.315774,278.890922,307.754457,315.992595,304.240666,419.298899,532.555173,599.140623,418.145789,310.331396,115.131573,37.737628,-84.842979,-143.845375,-218.34617,-221.469266,-221.258164,-264.898133,-275.949476,-227.180863,-192.381356,-157.514031,-130.350787,-7.987697,59.556434,23.315416,-143.956295,-232.051641,-324.718778,-312.645853,-260.713697,-257.773512,-233.223816,-166.335553,-165.372164,-198.78427,-197.926023,-166.207502,-156.660479,-146.288371,-137.600982,-168.480365,-273.457698,-285.784313,-185.349033,-120.229735,-72.313351,-96.416396,-175.329525,-156.46831,-85.37504,84.744874,136.667427,168.896927,163.11174,136.504138,169.371659,183.591585,138.560657,119.25135,160.429195,194.071432,206.564236,176.814236,89.669769,3.620155,-57.503803,-169.054271,-184.834512,-131.303657,-89.92917,-71.399043,-112.953902,-108.332451,-47.951709,-32.977459,-60.876081,-63.494812,-56.289011,-111.036268,-295.486613,-364.042398,-358.392531,-284.169089,-236.987313,-212.857248,-213.404893,-143.330108,-2.344447,53.057017,58.87189,18.580726,-69.415614,-87.320685,-36.63947,13.559605,96.039578,89.921994,42.317514,-32.74817,-16.360462,60.085995,78.041467,80.662585,114.037871,109.406584,-19.338074,-79.706953,-3.528557,120.586786,342.058307,367.886097,288.569998,240.437541,226.5431,156.169873,123.916129,148.559511,196.818939,267.120953,263.676715,235.178892,135.134737,107.547368,125.671761,147.596381,198.524457,220.026582,246.747522,201.163299,133.155949,17.333883,20.681131,134.708945,195.512453,205.623269,135.280642,114.536558,63.773359,30.428461,6.62261,32.658516,114.94783,123.56897,55.424498,-51.691405,-137.988751,-345.267988,-401.939177,-345.267708,-274.510758,-214.490005,-175.509293,-115.91058,-78.168106,-125.509312,-208.245095,-194.024296,-80.198938,-41.520366,-62.690341,-139.306203,-187.172992,-208.100518,-152.04793,-49.034795,-61.248891,-187.673153,-265.218841,-230.05709,-79.913529,-19.467457,-9.573782,-50.666273,-99.223031,-86.297731,-73.98855,-181.038132,-269.973015,-368.999196,-338.235121,-185.074943,-95.128186,59.328347,48.842562,-43.466474,-289.492995,-353.47907,-278.602826,-192.811502,-34.657508,35.254119,75.224516,-95.511615,-165.294609,-121.729629,-56.49445,59.790018,112.998146,160.837151,99.593084,43.442768,-83.093686,-116.631672,-49.93023,22.926976,99.667903,72.075606,-45.850642,-94.508059,-82.788898,-46.08622,-25.742153,75.095951,146.595858,233.887618,220.360572,180.198073,66.723084,29.529841,62.585346,114.835362,172.625819,158.040828:-64.004652,-52.628644,-50.140411,-111.607533,-149.899035,-191.9731,-180.725568,-64.107664,49.734498,45.624344,17.312501,46.73726,123.977583,142.567199,202.951885,256.402194,334.060804,260.440553,193.453355,131.513827,129.240699,79.767524,35.937824,5.681745,31.379601,-3.394808,-155.923217,-185.119268,-117.920869,-87.168162,-48.018179,-20.74992,15.35786,3.897284,-13.4556,-37.174309,-40.631495,-31.641484,-6.436839,81.757794,148.929283,150.022525,109.862887,92.14145,26.437881,-24.681744,-90.677538,-107.040956,-113.480328,-117.961081,-155.831946,-203.151708,-134.375681,168.434622,287.250256,242.542622,63.387466,34.508242,27.013315,5.848441,-43.848565,-31.902501,85.982416,141.490512,193.295427,198.808623,157.696802,-6.695004,-71.827856,-57.674901,3.909664,139.041257,252.685537,279.708083,246.296873,209.189371,149.48079,151.08044,235.765289,287.810632,327.13787,222.362421,125.739181,-12.362083,-13.172793,62.055984,100.040543,143.908216,151.749418,128.238509,24.929569,-31.076628,-77.919612,-39.463704,108.656956,144.952577,28.06699,-176.940553,-225.545701,-214.031744,-184.029949,-107.242107,-62.516744,19.563878,142.703208,218.300333,302.622928,303.298367,259.086755,250.523541,309.288728,323.378953,258.375548,166.664003,94.28748,-50.754176,-39.420191,163.101038,269.206165,377.640247,433.211394,425.39183,320.942736,273.675239,193.043886,157.754479,194.296854,243.14859,223.843347,14.739883,-76.390267,-78.821016,-21.899104,95.144982,162.847425,287.966216,245.13767,134.615485,-94.034426,-95.249779,99.104361,155.920849,37.55064,-52.14805,-65.51528,-4.375843,-29.153751,-144.964679,-193.425078,-170.472432,-88.758967,49.486699,9.867381,-63.186494,-253.478789,-321.252162,-377.685313,-390.935018,-374.021694,-354.789996,-326.231162,-230.020739,-158.604092,-19.537828,26.632191,73.323944,119.115906,281.471881,400.012171,416.493888,336.048789,234.687351,69.377699,87.271802,264.69572,309.618704,186.702589,62.961699,83.540287,205.64979,275.028651,465.25519,569.002523,641.250779,513.366787,398.571841,151.734534,72.825723,-1.447962,-22.89608,-72.082569,-116.436936,-166.182336,-39.12758,58.607166,199.931116,186.512618,-4.859741,-67.612113,27.635317,184.70596,195.594116,74.459032,-9.80176,-74.639137,-31.80729,38.15463,12.549042,-12.941717,29.521071,4.698895,-113.519594,-151.292328,-105.407766,-45.001094,42.218631,76.656315,63.005168,-59.920494,-115.830055,-81.626771,-22.307433,38.500855,37.14017,21.894197,5.077374,9.51199,42.858461,57.459219,120.039999,155.596067,121.653928,96.133977,126.909177,153.486579,147.657292,145.628117,142.224969,123.030751,116.849335,123.264959,78.555945,26.254919,-30.878054,-15.871801,38.861534,55.991274,47.158573,10.786772,-9.491531,1.830573,76.13265,240.424886,230.283675,-1.205351,-148.698344,-313.749068,-323.743213,-326.510596,-282.733546,-220.423576,-134.795693,-147.372092,-197.297252,-113.164852,-40.868082,4.390871,-26.475254,-91.694086,-106.783663,-82.677066,-34.311767,82.786291,56.446594,-19.69659,-145.707542,-150.907355,-65.302289,-10.870895,56.195585,82.802532,74.028819,11.967651,0.106163,85.651947,175.473757,338.318337,349.82154,259.326424,190.948819,158.066379,68.232057,38.200539,52.400561,81.114992,127.671398,120.90792,103.582271,116.001811,170.229204,310.000046,350.131767,355.947797,361.683153,431.200253,369.874758,253.857298,92.107939,114.919152,250.999163,297.449368,277.65748,171.08072,131.075538,77.151973,78.012325,160.757583,212.665505,296.546793,323.084847,258.826583,-26.989405,-178.085488,-289.078273,-260.078942,-196.223042,-175.895049,-123.80239,-91.815222,-108.679156,-228.962521,-287.07468,-231.320676,-123.546584,63.136399,85.883982,15.184748,-68.187384,-90.892959,-90.850099,-68.969142,-19.085359,1.594711,39.434997,35.873177,22.120893,16.142465,25.709414,26.316556,9.075651,2.237216,8.751909,-77.847707,-307.713688,-422.445284,-490.997996,-422.00502,-230.018362,-161.796895,-69.77181,-64.883805,-155.170122,-462.48292,-552.017844,-508.931473,-451.826846,-340.170346,-294.391599,-323.111751,-508.083334,-570.585802,-526.617924,-456.066518,-282.594731,-203.371829,-166.44505,-245.529852,-291.810451,-334.28652,-311.713716,-234.467111,-205.436574,-167.895346,-169.343945,-217.153627,-274.708885,-290.973589,-227.714882,-160.839105,-79.83919,-72.1682,-79.970185,-126.272535,-163.360166,-189.976554,-143.811808,-45.589813,-68.509801,-160.822783,-153.02134:-115.174192,-64.042857,-60.844466,-99.737966,-129.208519,-175.763319,-150.256756,20.35531,132.483455,92.542685,-87.501477,-125.465125,-40.56295,21.654852,135.856166,191.974896,271.082281,287.988504,262.42487,154.975297,96.515229,11.944461,-10.059198,-26.549722,-67.700414,-103.185719,-137.921631,-119.961897,-47.744953,3.467119,103.26797,106.86682,7.907141,-106.746863,-140.088609,-96.032231,-29.343172,16.317836,-16.949636,-53.813362,-9.412574,5.732282,-58.465718,-113.05909,-136.281818,-95.339332,16.044144,54.629604,33.596461,-105.961268,-152.007208,-63.894793,46.864387,229.327691,269.258594,287.139434,244.983592,193.85317,98.505012,98.512757,174.127664,211.134113,303.625674,356.379288,384.007082,267.108449,197.412375,143.67628,144.757132,145.883723,150.584028,163.26441,145.674108,124.752317,118.512071,146.238939,170.642939,141.022148,98.110342,110.450751,118.52323,-8.503801,-98.743573,-146.625726,-94.073098,26.509095,51.473361,-2.016782,-67.576547,-70.200888,-84.076805,-112.514226,-151.045915,-125.142432,-14.333371,8.675024,-34.296421,2.277136,44.151832,51.232971,37.022483,86.686117,143.643428,227.18086,296.487731,331.269114,274.335445,201.213242,223.227559,325.526369,444.697235,412.640207,273.897266,171.798986,122.528526,36.98732,57.854027,215.014672,272.109582,304.6459,321.893993,277.712317,126.890182,113.815819,176.862861,184.442177,187.62702,195.576255,160.816882,52.335578,6.477046,29.575158,89.684284,224.628164,282.059797,344.858644,320.794766,271.239748,163.681151,168.303659,256.3904,269.767555,204.012105,161.40371,132.59097,113.538803,67.229735,-43.089845,-71.516783,-47.548446,-9.03251,25.753876,-79.295467,-175.400115,-317.419091,-297.817097,-164.572402,-144.813073,-241.675106,-314.6908,-370.210577,-253.877528,-206.483133,-243.04223,-271.985114,-155.224069,-23.204427,189.632807,230.519623,192.574786,93.709502,79.7979,133.28764,196.358591,354.090981,383.410114,327.097683,264.783482,232.355619,239.434336,314.771483,546.796583,636.938513,593.318397,359.806643,264.890416,139.387618,103.112883,77.863597,65.688139,12.069386,-24.880466,-88.753772,-94.791107,-90.736845,-102.013574,-113.573814,-130.423246,-138.042063,-136.632856,-67.118447,-50.984927,-161.684411,-248.157301,-311.307261,-251.404118,-71.845375,-68.58766,-242.489596,-311.890531,-292.569523,-307.179395,-328.947114,-280.147353,-208.120297,-70.484197,-75.740463,-131.467007,-258.225266,-280.856819,-183.718527,-98.319734,-14.964642,-38.898707,-112.689351,-162.550493,-158.604304,-26.081289,75.119287,238.574767,271.756983,190.951952,34.071261,-36.198774,-125.776617,-94.018522,81.609868,137.346799,84.338337,22.706023,-16.536264,-60.016932,-137.028227,-282.025605,-323.9984,-354.322384,-319.140095,-214.323082,-213.126005,-218.348355,-176.44766,-135.516176,-41.174759,-4.966626,14.624204,-3.015616,-91.096073,-237.194995,-286.854677,-290.731541,-279.896009,-292.022222,-287.648994,-197.696485,-63.763512,-13.209767,25.1676,4.959642,-84.049258,-100.745212,26.197289,130.670124,190.540107,12.311235,-67.914205,-73.700649,-46.768419,-30.499616,-3.427593,66.208489,35.241561,4.227862,-54.908616,-79.314709,-38.649399,46.847658,228.781445,259.257593,195.457953,114.036189,95.047314,79.363248,79.614038,133.605375,174.783076,177.076476,105.719222,92.379999,84.562687,75.119272,103.881155,153.261878,217.744268,199.19547,168.408809,171.680286,133.211735,53.89235,63.22263,151.455653,182.405712,157.313996,138.573448,146.885034,80.213539,22.124675,14.676129,75.715368,188.523039,168.145903,40.467305,-43.839559,-109.308236,-228.107534,-228.200854,-176.666852,-157.330831,-115.185025,-40.578725,-20.802101,-119.74814,-199.662101,-229.585582,-157.281184,20.629407,52.541931,13.141448,-72.509729,-127.494893,-187.813489,-180.362524,-153.542518,-143.438692,-117.91972,-134.910307,-170.027738,-221.930709,-205.718738,-149.429526,-153.972277,-195.377938,-192.10896,-161.101822,-211.714443,-255.856745,-295.235297,-278.854297,-188.086615,-123.368223,3.095316,30.383071,-34.366312,-298.624516,-406.438031,-363.110745,-229.068698,49.814436,104.609734,17.806522,-115.665638,-156.655324,-181.136173,-144.433078,7.501353,62.570569,48.1874,-77.195354,-152.391602,-228.421765,-204.080939,-90.502828,-37.334927,26.667097,18.307536,-89.252515,-202.390604,-230.562808,-212.246741,-168.78813,-43.156969,24.59208,121.804159,142.711909,114.170939,-23.052821,-74.622906,-12.14244,59.962557,132.011009,125.026401:forward
239.495092,256.764854,204.555164,26.546054,-50.819442,-71.773456,-27.009153,40.399818,59.494278,68.579983,79.752244,81.822341,90.486187,109.721436,199.717264,267.422606,406.824474,473.479896,448.166879,278.123363,194.70339,133.820505,119.444304,75.083719,7.505878,-57.324286,-190.12077,-206.741721,-111.973222,-45.769677,24.384697,40.522425,90.732475,147.102305,164.856659,157.586554,138.827518,117.035187,127.991988,210.64904,253.070793,222.884099,113.631381,50.393879,-63.934804,-99.90738,-117.730582,-86.627571,38.36629,91.721366,94.806724,124.184323,142.872984,149.487113,119.377612,31.122518,39.512179,92.001576,197.640589,196.759066,111.379134,90.243754,76.046131,39.724475,9.617024,144.071488,192.04192,119.803518,59.662771,61.828012,100.912375,132.15336,96.137388,80.782046,110.174616,125.311764,73.982936,43.286702,69.545893,110.832286,139.370332,7.958157,-82.920398,-147.858506,-84.712533,149.760528,252.925572,348.434022,316.900469,244.707181,18.383236,-69.339014,-87.384148,-47.201848,42.012293,98.837846,207.746628,180.397542,138.673382,110.899086,120.334852,131.971283,135.757286,182.43016,251.468125,259.279417,230.873589,211.923395,202.856742,236.031006,344.611071,391.059674,486.152157,589.088422,611.801486,538.060514,468.821636,396.436219,376.54223,319.351356,358.875603,400.018088,342.23963,235.419261,75.664543,71.418827,152.714764,217.631666,325.384885,327.04473,309.83428,220.020041,135.869959,10.957864,18.33474,122.496951,134.752121,65.456374,-147.324286,-241.468304,-306.377668,-272.533358,-164.449381,-130.499881,-155.297042,-216.458055,-218.00314,-221.948978,-227.29786,-128.38115,-29.502709,127.97563,200.161758,235.596163,307.920548,304.114182,230.716568,226.810794,302.762639,333.973249,351.677085,324.179481,278.057001,102.899687,8.119669,-38.336553,20.409659,161.050485,174.617362,129.123546,-5.505534,-81.00927,-221.423964,-255.031592,-209.498817,-160.377402,-100.458157,-137.124998,-191.447221,-309.824483,-327.62907,-210.371805,-107.012289,26.911036,11.209916,-8.226743,-15.27485,-37.384684,-148.420326,-173.031588,-62.767355,15.099229,56.488393,9.2754,16.929432,86.387865,93.840896,-2.203251,-55.888746,-53.895324,12.142189,13.484501,-42.400792,-66.186198,-76.196805,-70.872554,-48.141626,-19.760425,41.905288,-40.916208,-130.622738,-240.113997,-225.992258,-129.346556,-75.526759,48.468687,140.784813,145.051832,106.549455,86.565064,47.833198,11.430378,-98.972725,-138.902272,-161.438365,-194.77926,-225.798914,-271.413853,-275.114087,-241.8069,-210.716518,-171.139362,-226.125349,-281.715805,-363.64324,-403.889396,-539.237177,-583.853159,-540.924016,-489.359641,-452.411294,-467.457989,-441.104465,-400.515873,-426.33679,-464.060855,-444.36542,-428.962245,-487.527987,-506.428258,-520.785382,-558.581542,-648.331048,-629.462585,-474.885782,-396.365509,-334.197981,-400.484805,-435.459907,-442.070962,-412.067616,-309.430459,-251.452474,-169.627937,-196.426649,-226.309206,-274.524065,-310.79708,-353.528554,-305.012731,-91.177288,4.72335,83.232559,21.068307,-42.496014,-153.644562,-179.391863,-132.503811,-72.835284,53.798297,66.035361,2.380536,-160.058381,-224.795744,-276.399114,-252.171907,-176.618239,-159.01015,-159.943947,-166.192549,-183.720642,-313.911053,-366.858191,-266.647251,-181.192264,-144.009888,-143.012309,-128.147573,-144.505993,-153.616679,-58.369296,35.000145,119.059547,86.759014,43.856694,76.138171,81.212496,56.541694,29.455528,-38.5942,-72.223057,-130.113465,-164.774196,-157.811437,-88.254158,-57.308996,-51.0702,-58.460498,-65.364113,-44.675124,116.309348,230.411346,183.988063,46.739784,32.428875,81.012904,112.585301,204.20052,287.378254,285.25015,242.885957,239.130143,225.271712,175.347958,81.302724,109.855794,222.872583,150.341122,74.744855,-12.930924,-0.593116,148.008201,244.692742,376.095321,374.944327,301.802398,55.307666,-73.088779,-223.338734,-203.14949,-58.424631,-9.845196,27.176835,40.005932,46.510768,52.355751,46.8158,88.060003,142.492095,258.833525,303.343613,273.442414,146.679482,69.954302,-65.807768,-105.588023,-114.434538,-63.316213,137.354525,260.443521,249.124671,133.56307,82.76532,90.165038,119.642808,152.158695,194.722224,225.190661,243.773434,221.396237,185.018152,197.671421,208.573742,186.804718,209.291253,303.051287,295.083821,155.419103,86.191418,31.078622,22.145313,12.277572,-4.453539,-28.234514,-111.778394,-155.599482,-136.453834,-63.887578,57.961315,59.83772:182.687815,85.245516,78.368745,65.824654,39.144994,6.555537,35.229619,134.350773,137.800364,99.883316,41.853887,54.549962,175.89772,260.080636,345.645831,335.567617,353.558839,453.132335,454.355197,336.903458,281.888074,227.004392,215.27714,238.124207,162.088545,52.282162,-118.351188,-130.189037,-35.911589,48.923751,204.198675,232.250481,207.725017,194.128551,179.09057,107.949244,93.88364,134.293182,155.456467,210.731208,293.666527,286.432671,151.969906,90.066749,75.325108,89.540555,70.720805,53.670667,49.091494,51.781099,50.747102,53.076145,66.643302,111.493052,117.551553,90.775052,129.592683,177.589139,199.378537,144.885133,67.049118,110.631937,227.223117,217.763645,125.451667,118.672239,142.010384,163.825684,176.97273,270.276615,307.184626,246.177065,122.135928,109.16911,213.592274,252.072524,130.529564,33.637163,-2.568793,45.712565,85.128674,23.387229,1.671296,-10.842829,5.355581,109.007474,186.482227,331.386603,290.905115,189.499676,-28.094803,-107.714789,-163.55844,-132.121422,-49.309055,-31.368831,11.113793,56.531874,42.326421,-42.417825,-74.393309,-51.622148,8.884605,170.098297,214.643131,171.265222,91.615354,95.481177,143.239605,168.685056,264.088021,335.475866,414.887074,380.303204,356.513864,292.187215,247.465496,159.42936,132.732591,156.655946,191.937194,161.731482,39.093432,-24.826402,-94.379648,-76.363539,41.806191,103.930157,147.665567,127.860775,119.700718,55.783557,-8.269598,-86.25195,-64.826545,40.586987,86.764703,48.494362,-101.542293,-162.412382,-171.417224,-111.215975,65.707475,120.383307,95.298333,8.569857,-32.411237,-55.823488,-15.826258,112.96826,166.028927,199.435205,144.139531,131.891911,188.418661,213.142268,200.794623,196.490506,231.805165,264.275765,356.754131,368.997856,290.829087,43.707632,-49.964779,-76.048245,-35.207977,47.251353,40.03343,-24.023152,-205.555674,-271.672453,-327.909221,-322.836005,-212.299874,-126.831128,-68.12222,-193.254695,-259.704401,-308.207953,-290.430902,-216.641695,-166.642299,-56.398356,21.088411,37.819545,-6.592851,-61.330694,-104.004612,-65.102416,10.693168,18.280354,41.765215,85.173682,96.466676,82.921475,55.934734,10.625427,21.243133,100.386998,122.594408,73.375266,-89.312318,-142.063026,-113.089367,-71.197908,-30.772692,-26.149004,-27.29514,-55.71904,-72.880953,-90.587285,-90.315845,-81.347462,-74.284762,-30.814101,27.1635,45.742544,63.843526,38.284857,-49.533516,-55.248861,-16.670097,-25.014033,-86.662802,-115.049177,-136.026403,-220.743517,-241.220803,-171.678199,-109.594874,-2.47379,-12.491532,-59.294901,-146.818735,-194.032114,-305.972187,-318.294256,-208.48127,-142.912709,-95.055237,-137.15345,-161.081144,-127.961636,-86.025396,-75.37371,-101.180192,-98.296754,-81.666278,-124.124145,-267.856882,-324.009571,-330.112023,-288.178142,-188.228974,-145.382263,-93.972272,-114.136138,-149.010055,-237.338759,-261.492522,-195.221373,-116.907548,-34.542523,-187.661218,-299.549984,-389.29559,-351.803286,-212.359226,-141.194533,-25.363387,11.035889,36.587034,1.770735,-62.33476,-256.097706,-307.156364,-194.695526,-93.633394,7.206727,-36.98579,-72.793946,-88.472781,-96.615668,-210.168447,-280.221437,-294.671715,-234.535677,-133.241577,-181.831314,-237.999452,-349.520408,-365.687329,-295.879041,-271.610745,-268.555748,-207.704109,-190.075164,-208.623894,-217.086116,-165.70005,-90.076491,39.580976,41.004319,-11.500302,1.706528,34.01485,40.041732,-0.621671,-66.706364,-63.107997,11.315885,65.543402,68.271897,59.855642,47.53023,27.436979,38.140153,118.675339,172.391813,222.227855,186.16365,160.063903,124.299645,126.024083,173.792479,203.943101,284.380873,410.000146,452.887784,398.796557,313.01173,160.582031,119.307914,96.679886,118.008125,154.818511,43.725643,-48.531707,-95.226969,-4.933425,234.405843,298.206203,316.111333,233.321752,146.728545,-18.302796,-71.750761,-118.892883,-95.917783,9.381271,57.955982,116.953724,135.964542,127.201507,77.529013,85.159641,239.213619,335.463469,436.303161,400.036726,338.819278,196.012287,124.950283,-4.054458,-40.709232,-25.443456,26.501213,160.422112,247.057689,258.734485,221.060952,195.351441,198.231541,219.901743,248.851776,271.002276,280.833672,277.923582,276.336199,315.303666,329.034491,265.468045,248.199876,368.452883,464.016964,439.13224,322.170718,260.561129,124.253252,56.39681,-16.969779,-60.966303,-90.533253,-120.127606,-127.13618,-105.894458,-57.97041,37.139713,52.730789:134.138861,171.115274,182.501962,152.027963,127.184121,96.345801,84.998859,83.042136,75.88129,59.645748,46.661168,60.988422,145.955481,207.581115,305.812929,329.398866,348.211598,346.855343,321.232901,277.078613,290.959544,284.069807,243.563144,240.164648,224.434188,135.706199,-46.023036,-82.371607,-42.645343,26.525362,175.797058,210.254181,177.615394,75.632895,17.778869,-53.549689,-48.153186,1.862563,34.722899,143.497987,229.260349,230.427151,191.311485,175.841011,189.743439,219.059067,246.646041,222.528591,148.418531,135.753319,162.919245,190.651562,159.343995,75.501001,70.593503,146.009389,217.899637,222.554263,129.209355,53.067411,23.592509,81.677575,208.470161,245.681841,234.331166,142.846066,91.998981,1.999424,11.183315,163.434836,222.001122,215.230441,171.92681,160.769388,153.436557,131.990205,55.276169,47.720565,80.497997,66.243278,-27.127099,-66.288751,-70.136474,-62.885065,-20.746323,61.285826,62.095916,106.128597,196.80606,159.819014,-67.151428,-187.055859,-336.680519,-337.850518,-175.584148,-74.852525,-13.379946,-120.604671,-165.98706,-177.774591,-167.59633,-133.294444,-101.528422,-28.413294,47.527574,82.355437,97.314249,66.128914,28.928006,84.171618,280.954566,348.295381,369.937606,313.182865,272.845975,170.370943,116.875774,28.57455,10.406841,35.091145,37.668729,20.373742,-36.352617,-85.823051,-155.106529,-147.230428,-106.733442,-93.645591,-51.757908,37.761451,71.281817,47.170543,9.097147,-20.789911,-9.277316,10.852689,-29.493785,-73.570882,-177.417068,-214.146828,-198.08746,-159.644954,-91.685557,-71.76643,-52.957312,-47.282532,-80.646242,-193.640082,-188.193274,-2.103916,89.546658,122.855502,82.960956,100.93711,180.032911,186.068428,160.798717,192.816106,300.621567,320.645553,291.558276,192.770197,107.287307,-73.929827,-123.472921,-136.020141,-121.172286,-17.995363,62.029526,3.52923,-225.059958,-309.250393,-365.153778,-358.214157,-274.417949,-204.543464,-95.612845,-73.882044,-120.106678,-300.337348,-348.292078,-237.349889,-121.106546,40.727694,15.819478,-32.973151,-128.188182,-160.952683,-148.266353,-84.161649,88.254917,150.48461,181.046147,85.408336,16.430925,-68.218092,-56.619605,52.648906,108.659421,134.142706,83.217003,47.106001,-82.121908,-135.814417,-93.59934,-37.754792,29.286312,62.876816,102.631519,19.308813,-12.866858,-14.77231,-8.199574,-3.649481,1.711446,21.259074,25.681703,30.671442,8.728612,-43.656552,-144.072709,-139.014925,-33.828572,22.44534,65.879199,15.628378,-45.176987,-180.84752,-184.564655,-32.469927,39.605979,74.935691,75.509862,73.678202,-24.268205,-122.588917,-246.779717,-228.564191,-84.687447,-3.484901,58.161273,27.453775,34.708834,91.812986,123.063282,183.284492,195.401825,137.95045,41.326272,5.483267,-83.424074,-134.445861,-155.155716,-116.375435,-14.798002,27.956846,58.936513,-15.300474,-78.604915,-192.92483,-195.979252,-25.312835,90.569488,159.200536,-3.268431,-87.36734,-140.978109,-120.272036,4.448744,99.134054,228.275174,241.856526,218.669813,106.066187,8.353209,-115.316412,-74.46041,120.430357,180.221544,174.040127,127.395506,127.697073,146.413156,118.432759,11.722932,-15.431247,10.327355,36.286846,9.476715,-123.767899,-180.627948,-241.22219,-234.938298,-171.671477,-152.601101,-110.666863,-40.114154,-33.519402,-38.250478,-24.734197,-6.623205,-8.602512,19.029986,45.708776,34.578596,-36.35537,-43.060112,-42.523207,-64.410184,-79.035788,-35.33862,100.027582,124.074591,98.595268,59.544652,58.855379,73.507397,73.393896,117.090999,181.159641,258.19336,127.101458,42.283841,-34.494171,-30.674671,11.492295,36.321019,105.93859,239.091972,318.414673,374.223923,318.742567,164.629234,122.592948,82.374451,68.74524,49.949653,-16.729673,-61.446233,-98.06312,-64.386084,73.762046,147.933923,247.122828,170.274913,68.011655,-104.396896,-131.060439,-86.643393,-45.021453,55.17953,108.383719,168.023046,132.800293,97.904868,60.570027,85.269,216.625767,297.633927,463.385841,498.917725,418.140361,171.52876,77.96494,17.112528,40.47907,119.823626,146.87908,178.342242,219.871775,228.197553,216.005296,224.996044,229.229313,200.779977,191.212548,275.764493,301.705544,308.950537,302.321881,311.504915,336.375506,382.905646,407.748523,464.757602,419.793116,345.620592,236.92289,237.602974,243.294728,220.473356,166.970776,116.154092,91.437103,2.790995,-74.48061,-119.200531,-24.671967,224.032718,278.508248:72.463974,111.882025,109.717094,28.646412,-16.417294,-53.71589,-48.016994,-0.528393,55.884313,70.040019,66.155648,52.376095,55.287359,86.617611,177.435537,231.959019,330.794527,323.620797,276.308725,169.392067,136.910623,110.170879,118.403091,185.526466,137.475233,41.273892,-128.204076,-154.42366,-84.532227,-12.941319,63.914741,45.49463,15.0181,64.144442,70.375947,8.461167,-12.760499,48.503742,109.404159,241.875394,286.095953,242.102438,133.862098,106.40549,76.594807,57.256453,27.632735,48.825065,140.206051,131.159638,95.128529,85.038513,129.269091,225.637793,217.997606,128.543675,163.183286,205.590782,170.577625,94.280552,-10.692385,8.255422,98.110354,117.261753,128.331178,150.608703,133.560715,57.164723,48.17295,114.651658,150.350805,171.533815,165.13644,173.239091,240.099816,254.044955,117.279462,21.565555,-11.99771,27.990788,26.641319,-78.074606,-116.123844,-165.839227,-157.911047,-8.899578,84.81946,176.735159,134.69798,75.690822,-86.627431,-176.958137,-285.18362,-270.757918,-150.478382,-79.85434,21.813425,37.494311,21.551748,-6.319174,-1.595996,21.36242,20.33842,37.886946,125.562356,152.1685,143.708696,140.064912,191.432184,248.533851,385.252586,453.221267,559.331165,542.79153,488.399898,326.92433,244.45522,159.924172,150.323534,156.165612,159.89837,135.017298,71.899995,49.112093,30.047745,41.32159,89.441265,131.849779,255.009978,299.554939,265.499737,174.419979,145.550873,81.160245,44.55111,28.761493,10.44503,-55.26122,-235.733171,-305.410378,-357.462906,-318.0595,-129.874235,-50.034855,-57.148828,-184.107871,-222.691443,-247.219806,-232.237002,-108.848426,-34.158583,40.26024,87.535015,137.248454,219.152985,201.174039,111.108493,118.473392,237.928315,290.855803,320.314616,189.814012,67.00151,-132.007937,-149.207821,-59.287938,-15.813311,-2.657767,-23.165392,-32.046481,-97.329446,-164.236145,-282.351834,-279.196817,-180.651204,-155.655228,-177.954245,-188.77312,-208.003336,-316.501729,-358.317017,-293.233576,-205.369863,-41.403035,55.135242,80.59796,64.740435,21.94411,-55.822777,-51.837321,29.761686,69.669368,65.123111,-16.345791,-19.828508,13.929009,1.353776,-15.157963,26.117443,150.767851,163.864457,110.048696,-33.985735,-62.858997,-10.876621,21.584652,48.96735,59.715595,40.669289,-67.417564,-107.415224,-93.606624,-40.403802,68.519857,84.12685,65.556335,66.434684,72.599921,25.977734,-37.578873,-136.863798,-120.426816,-7.057768,39.569078,55.239936,-69.443022,-138.565069,-191.47569,-180.742975,-116.818486,-84.776137,-23.802039,-8.19843,-54.43895,-212.214184,-306.291545,-434.888229,-416.836544,-276.655496,-232.907227,-266.603343,-284.166803,-228.274503,-114.370375,-109.396977,-125.521351,-116.122814,-141.810251,-252.344777,-300.712659,-358.996947,-375.907796,-360.019129,-313.397096,-197.244794,-161.812433,-168.958009,-275.601196,-334.060491,-387.285969,-364.057468,-197.993132,-87.368592,20.935841,-51.194844,-77.988079,-63.482511,-67.86194,-100.491381,-76.023875,88.270816,187.221831,308.64798,259.642934,180.524044,-18.299976,-85.748708,-20.401351,93.996331,303.009546,338.211165,285.868053,136.208631,55.834841,-78.813818,-78.504337,55.159826,118.951419,124.078731,26.747673,-13.188094,-104.238329,-146.53932,-117.180307,-72.779063,-38.114932,-22.029083,-16.186401,-45.328832,-62.593792,-47.435562,-18.369347,57.45804,95.630151,135.660814,118.768029,97.825972,-4.743169,-64.120132,-77.890696,-50.208482,-17.643251,-26.578064,-37.442776,-45.113365,-52.606959,-78.105643,-78.416103,-21.343853,36.645341,146.184813,94.964318,8.734595,-124.136066,-131.132139,-74.491843,-41.94994,23.858549,133.863139,187.795801,194.760755,138.907198,9.111345,-20.614503,12.754224,57.174523,99.705825,5.139539,-52.628206,-99.712652,-83.011682,13.957263,73.626486,169.728194,136.078217,59.356875,-92.338808,-142.846915,-200.519389,-192.790422,-110.760526,-66.657193,6.085109,39.232116,28.515761,-6.101461,1.265384,90.066152,144.288655,245.794809,281.675262,223.828365,61.679536,12.22341,-54.989886,-88.238978,-125.684964,-91.516431,102.582904,229.945904,212.59426,99.278185,63.594187,104.062939,153.690748,230.209224,241.793314,230.984369,241.061009,257.894813,283.887548,304.5616,329.510379,315.049526,282.631923,286.648257,287.841864,261.221178,230.7128,145.090714,106.534705,87.967368,132.966271,143.606611,124.444105,101.422896,94.612976,143.865891,265.314641,282.040351:95.085422,78.199895,68.293806,30.330626,27.74644,68.52309,95.526256,138.504533,96.264936,56.929391,7.260736,-9.525116,3.574021,60.127514,241.011787,314.747684,330.004261,241.799654,201.305469,130.868648,115.613447,123.957112,131.925827,174.071666,152.831478,81.624519,-51.995885,-74.896129,-54.576656,-25.770397,49.068797,88.164609,105.883013,-11.367972,-85.797923,-175.609068,-157.267001,8.541953,102.446781,237.508443,312.251213,306.789334,194.299527,121.436656,60.075297,80.165553,134.720283,161.117624,223.105589,232.109296,215.759119,182.859415,185.241186,220.091831,234.659653,245.449426,234.099348,212.216913,77.610169,-16.643075,-60.666035,15.519968,165.607791,190.926178,228.11246,205.369464,120.69263,-44.461594,-31.585496,127.039355,191.821039,255.940865,236.410129,198.575684,135.149457,97.102614,-26.993379,-71.617455,-40.56751,1.123712,-13.802736,-126.040782,-171.887686,-229.192399,-213.794177,-47.866139,61.90483,186.661793,118.132548,37.184769,-138.095461,-222.664819,-318.103,-303.436377,-211.162509,-162.188098,-43.350918,64.362224,64.808924,-46.752881,-106.437615,-116.955335,-70.374604,41.3943,109.578479,116.921747,71.376997,52.657206,122.76135,204.756131,395.424284,482.986977,535.975571,383.701363,293.177929,183.393029,153.806294,84.890697,56.994976,90.961618,125.882006,85.153804,-46.041421,-87.128717,-51.001626,16.136704,166.275945,219.512563,217.249355,172.006328,184.78769,200.333087,173.466337,98.727158,69.412067,34.041508,3.595974,-42.895614,-213.577751,-295.507542,-305.754515,-228.60292,-48.000395,-9.106439,-78.141285,-178.702952,-220.074644,-297.247083,-283.96514,-124.669971,-38.397283,33.301662,35.46258,63.673249,151.212747,170.878445,195.34723,230.407452,315.421728,353.14795,381.209609,242.322845,124.561729,-38.313458,-28.950076,101.30885,150.072918,191.511799,208.687569,186.778993,25.194793,-87.760599,-196.957325,-156.980378,18.482407,98.67043,160.844802,40.222346,-65.356585,-220.875667,-236.790433,-132.611738,-19.895468,188.676286,179.649118,111.984312,24.443518,42.449872,125.473061,132.324731,133.31557,180.587106,219.008885,55.831857,0.513649,37.027563,89.26517,203.226501,269.839181,383.22513,345.602049,282.645422,163.296203,124.017548,127.441601,159.201183,207.308373,226.916093,248.511417,183.785298,149.992593,107.614136,98.088279,192.395346,291.278759,370.680302,203.721923,134.268984,119.588805,106.040747,-12.411009,-47.633163,77.322759,191.466027,275.349301,131.202475,58.366669,6.67819,20.641096,80.381785,121.368733,218.941777,204.818246,115.314132,-136.194691,-218.737536,-209.180723,-155.902222,-31.14729,39.425081,107.508173,62.764922,57.865837,75.158045,74.328285,112.511439,166.245882,212.741064,74.866015,-7.36088,-92.426479,-103.113588,-77.861754,-33.81202,88.570528,143.515,145.073984,-50.481284,-140.531985,-187.009024,-163.456976,-54.118858,35.817581,175.141583,104.97257,39.861569,-50.258704,-65.247496,28.016188,115.618149,247.439364,279.407182,277.435217,172.605726,106.551816,20.489412,18.224929,110.873872,186.390974,295.163538,257.010149,214.696348,138.665188,72.819247,-75.842547,-92.683148,17.810376,100.096449,142.576104,-47.024412,-152.422869,-302.798711,-330.084939,-211.796528,-108.618064,-1.346415,-61.191762,-105.706827,-135.827044,-120.782521,-87.509754,-79.959174,-30.469114,14.01269,47.66899,-12.250824,-56.133833,-153.007738,-188.449312,-195.196309,-165.583354,-109.395737,-185.147101,-229.181652,-200.496509,-165.125727,-113.834186,-75.818578,27.73265,75.083252,91.312675,-25.783027,-100.681687,-196.482849,-190.932108,-99.072081,-57.553283,-28.434606,37.134632,86.749101,79.058548,-7.666508,-190.072745,-209.97427,-123.891291,-77.683975,-82.635865,-166.662523,-229.570367,-347.243002,-322.88194,-117.800662,-23.587119,68.237148,55.891406,16.604113,-117.959198,-184.838065,-212.599973,-170.158876,-29.401407,52.626183,159.393772,131.604991,93.614153,10.985709,-4.332939,102.040169,195.9175,330.849682,322.440784,278.829281,173.001059,112.561275,14.766116,0.108342,30.079511,65.658925,132.655011,153.228689,138.223196,70.263881,63.516609,124.333088,149.643795,187.160825,216.615299,205.875612,145.561244,93.451576,33.858177,69.806804,173.484108,197.997415,215.038752,159.993412,101.053028,31.15545,38.360987,33.659544,11.501902,32.700819,94.492635,92.243787,21.030123,-32.354932,-25.55437,71.737396,250.086942,253.054302:70.512351,-19.333092,-120.493276,-249.775597,-253.954886,-222.647327,-196.189078,-104.490597,-42.013595,-40.187754,-39.359583,-30.937196,-4.398759,23.821345,109.304414,153.067215,243.609565,301.676584,284.083624,108.86514,-4.817435,-69.684785,-0.772754,158.176643,73.954543,-44.30028,-181.72021,-160.949996,-54.482805,-6.933688,69.890774,102.338971,155.515533,166.202873,141.381054,80.271277,89.960892,191.492081,238.254423,326.771605,389.206373,332.367028,93.629766,5.229428,-27.32121,-2.229753,47.496108,81.545766,175.739996,178.7805,149.399746,141.094043,181.948444,267.410149,255.605021,170.802666,154.881331,154.576008,113.01776,81.249727,41.270406,55.077072,137.403446,180.466264,269.767836,270.217334,208.143773,71.251759,46.400509,115.160151,168.976547,190.115401,82.236379,36.823239,46.527753,48.179398,-15.328364,-24.108542,38.253859,73.230947,106.793663,55.876692,-6.999206,-157.996512,-175.494581,1.352987,111.756922,205.312695,209.100941,161.109911,-43.647386,-126.023085,-130.64773,-75.825443,41.655127,86.438646,161.915513,222.888886,222.819133,127.211395,83.792769,134.815643,200.530239,274.393199,302.255054,332.414338,377.353757,358.004194,273.135647,280.70636,436.902761,525.630111,611.570948,564.682239,523.376334,452.344082,433.684046,425.00773,410.907918,346.526114,288.106502,276.95003,270.852038,268.709209,300.273888,332.60848,370.102121,393.055131,492.437159,499.628007,449.838148,333.997478,281.31163,192.70678,170.72917,217.545144,247.585829,175.952198,-33.855658,-112.262637,-223.058627,-240.456916,-156.911148,-103.658295,-101.545487,-174.271764,-210.324448,-291.345145,-306.516193,-201.388834,-104.36786,103.303695,276.826285,319.083915,318.307507,295.784977,279.413313,293.164404,332.391041,373.139302,471.357026,381.167462,247.712174,20.921403,6.64038,63.490729,58.233133,78.83481,218.847011,236.946221,99.004174,-1.016445,-106.715872,-69.664267,110.122597,155.05456,46.650483,-135.999295,-166.503143,-136.802357,-113.468149,-22.261523,52.601103,197.852809,216.351296,164.936085,74.944431,57.432703,39.243927,55.337001,124.460234,130.692622,75.071176,70.599672,113.789352,205.804022,199.462982,100.065197,69.544142,138.559794,305.997982,330.571642,216.733264,158.632762,128.056907,128.70923,159.250357,192.356506,185.014361,42.265729,-2.200539,44.071559,90.283761,130.335963,142.596743,245.036306,339.795231,317.958177,232.915486,216.646806,207.546375,195.478585,214.480648,266.409587,314.523761,173.26671,115.525102,130.855771,147.305689,116.893341,99.261126,106.772045,111.966582,66.357705,-101.732689,-193.507754,-351.364723,-381.039425,-300.505085,-226.669088,-144.92706,-182.475229,-187.590756,-128.092611,-105.26749,-138.558031,-182.749289,-246.454622,-218.508396,-216.080641,-353.63084,-462.442729,-537.282164,-462.624379,-244.711485,-174.60802,-152.38705,-242.693132,-296.089352,-355.528278,-342.084157,-236.474277,-161.111078,-56.248302,-100.961057,-104.715893,-55.541141,-87.423169,-211.795148,-187.158114,62.342576,177.142223,231.861167,171.574059,144.762856,82.848481,39.326299,13.469519,62.759399,223.355991,258.569137,198.910079,50.022106,-4.407011,-48.329078,-27.144871,45.619874,71.169355,70.909369,-68.069067,-156.518116,-267.94673,-283.219675,-177.076677,-79.393573,16.091306,-64.928913,-132.15073,-232.408202,-253.748349,-226.14822,-169.512628,-78.84592,-91.731838,-127.972366,-84.565119,-73.698972,-116.064895,-154.088422,-173.310772,-146.938463,-134.988384,-236.059524,-270.089456,-247.339457,-236.558442,-234.502787,-220.477275,-187.109427,-164.876353,-77.512838,-67.391965,-129.147473,-288.711777,-337.616527,-293.675659,-213.508063,-57.300138,20.571714,19.544365,-41.435465,-67.985814,-64.304644,-38.645222,53.556181,117.610679,178.17065,65.906688,1.564558,-53.758719,-42.611071,73.657481,157.13656,259.651921,230.766968,171.171437,33.426728,-39.566223,-190.872161,-211.700121,-104.339775,-33.588017,26.973724,-41.636566,-79.330059,-74.549494,-28.645453,70.026467,88.246597,129.948889,187.571385,164.5057,74.512845,38.486403,-102.465643,-184.039123,-156.426957,-34.350733,211.741587,206.905471,130.479021,-24.736857,-55.504042,21.530044,86.028719,153.629155,152.57837,137.415505,66.26502,27.482238,-4.546512,-11.011173,-29.780153,-5.979151,103.999982,89.49971,44.223082,-0.030924,-5.518523,-34.658285,-49.728746,-11.646944,28.131748,-11.844423,-153.140232,-197.252343,-144.506193,-59.311837,48.679511,37.335856:224.230148,85.839334,-15.006305,-144.083443,-148.570886,-66.438527,-10.310601,92.671391,131.982327,115.620429,34.921118,-13.110188,-10.001489,68.368327,259.910045,322.123711,329.808177,180.613289,93.771066,-32.459635,-64.540952,3.547015,100.537453,237.443831,127.122808,14.80102,-155.244824,-188.101362,-155.449301,-103.706584,6.408032,53.921295,99.732101,45.792133,-1.759431,-76.889247,-72.592807,70.893606,186.155532,371.155757,374.118955,300.560824,102.517942,30.473287,-8.574911,20.417297,147.661733,227.266517,326.555186,268.128232,203.035966,114.70933,127.111097,225.037878,268.338396,324.094051,354.070321,334.587416,166.418753,46.879171,-32.454846,53.390094,280.214247,332.276656,305.253726,174.497941,97.351334,24.621192,60.521183,203.373352,245.956014,250.075722,202.954455,164.455172,72.022199,2.947319,-132.725114,-128.491964,31.085714,105.938831,112.953244,-8.139212,-91.475622,-275.07765,-298.520762,-88.079776,59.527365,189.816963,109.792341,31.375043,-197.572901,-316.909101,-340.950879,-249.904178,-91.57,-31.455295,110.590978,131.033082,82.237713,-24.809284,-56.855382,-0.931503,100.262865,292.993736,254.242464,180.617095,89.293825,95.495752,190.802498,257.628479,385.260984,451.491286,564.371375,538.420043,465.808294,249.855844,165.528765,178.94577,246.030351,338.934113,301.604333,259.9594,180.333695,136.919535,100.938681,149.003685,331.64616,415.635436,480.616453,429.406603,385.305041,234.268952,164.895633,185.661928,243.150843,273.413062,135.927973,44.270651,-130.421965,-220.107644,-294.605999,-235.986971,-49.694877,-0.586734,-18.090183,-118.219442,-202.844364,-389.898551,-410.731908,-202.199488,-47.006896,162.405341,231.53193,232.072989,152.644197,91.945134,93.716161,171.883708,323.017474,364.487342,425.377069,368.576747,233.476848,-64.185172,-71.027204,157.790303,243.416659,267.646972,213.682281,174.543168,72.052167,0.752236,-76.894278,-34.095378,160.000778,251.694645,275.893402,54.86587,-66.67575,-168.069185,-147.281938,-1.540182,108.612113,311.351831,355.285653,290.940027,96.787728,39.930461,72.346181,123.941238,208.980809,247.025738,270.906551,161.818114,102.495349,66.619875,79.039329,122.637975,183.204525,391.39245,464.207881,416.138832,274.559042,216.46769,141.768394,126.824231,177.430152,241.013749,307.490955,197.012474,117.212701,19.672014,37.720168,166.68863,225.405185,307.912814,315.899464,265.460038,119.255594,59.3839,32.116954,75.056766,187.396356,219.956066,245.609881,213.397858,155.439129,26.641605,11.219994,101.841669,170.543895,261.126996,185.171834,68.803032,-210.723371,-319.720569,-396.730854,-348.596426,-125.311162,-18.863876,23.268695,-90.703,-122.517858,-108.842441,-86.303854,-19.205902,14.691802,44.228253,-54.21087,-155.67428,-333.063682,-374.713973,-327.09577,-225.285755,25.586496,88.212797,4.519501,-166.026895,-220.836643,-295.166634,-294.371987,-150.92108,-48.129571,86.162195,55.957787,-17.538411,-172.742544,-208.091256,-150.280362,-65.660422,154.300653,251.313202,306.231062,182.315004,110.993593,37.233997,42.316082,134.821961,217.026836,384.956456,335.293402,222.674878,33.510048,-13.594963,-63.084511,-56.964082,64.569108,151.510131,196.100139,-4.358079,-121.376077,-251.824404,-247.715101,-110.507761,-20.011688,73.603347,-7.864464,-95.729238,-272.1234,-320.296577,-276.644595,-202.760554,-63.639674,-16.120426,56.413181,43.871345,-34.9326,-276.312219,-353.460944,-329.024628,-273.771974,-178.87555,-152.118112,-182.396583,-252.993948,-257.773281,-234.241184,-221.862569,-142.761652,-54.880052,95.092273,-5.938583,-134.102993,-362.482942,-399.506727,-292.980252,-195.992985,-31.641451,37.101118,19.605291,-103.375359,-165.004182,-170.884206,-121.923273,-16.096978,33.718701,103.129952,21.536955,-84.727842,-247.248523,-223.753516,-3.393743,112.880034,245.067828,221.955755,140.604806,-96.766743,-183.926093,-170.587888,-101.143277,28.820122,88.445027,162.168573,70.52232,1.54063,-80.731979,-74.204224,21.045885,68.54962,163.578919,236.402801,199.555053,14.623519,-66.801848,-135.302429,-128.926579,-44.160293,19.138955,114.838329,121.400913,80.217469,-68.764439,-103.886134,8.106192,93.546676,184.267551,146.801786,91.164614,-29.759991,-85.009527,-136.142119,-111.788202,8.169251,82.3059,157.887211,24.596692,-72.48488,-167.834414,-149.932812,-56.88376,-23.453054,7.995326,34.921546,24.564743,-68.707666,-121.875479,-110.048052,-28.88534,124.923472,148.507966:-96.809193,-186.19785,-239.887489,-276.117479,-265.959054,-227.084668,-210.974408,-165.379996,-37.481294,28.323174,77.953402,60.160412,-4.251029,-24.109663,-41.473087,-39.656317,41.908948,164.031619,179.409767,78.335015,0.576476,-64.6617,-48.507367,-20.100859,-126.595317,-219.411232,-341.093038,-349.505783,-236.376469,-128.889732,21.926447,51.237617,123.157106,172.286806,156.233649,101.281047,86.154269,90.569942,110.296688,141.45208,71.447872,16.960643,-21.461859,-40.154984,-186.913113,-244.39037,-164.514918,-70.595608,27.257798,-46.882719,-80.146823,-74.05868,-43.661637,42.775344,51.354317,-16.920313,-62.336886,-76.07335,-89.461073,-78.605221,-45.708794,-23.111184,38.603171,57.063762,79.732296,98.064007,78.278305,17.789536,11.008795,58.548197,88.497035,99.728763,13.948513,-58.389769,-176.707996,-212.851424,-285.17188,-298.168814,-168.506329,-63.194319,6.607764,-105.6317,-165.191095,-258.409559,-261.416798,-120.939574,-35.899846,48.13528,69.289601,57.549639,8.106109,-16.18656,-64.422373,-69.736158,-9.095453,40.689654,118.364965,127.864135,105.955545,33.673249,8.982514,60.735419,127.453602,206.485027,138.048433,90.901467,83.47537,99.034808,71.66474,55.663531,98.846871,141.482382,215.410355,250.459407,239.801164,179.94024,162.755636,206.065153,242.803675,268.324445,290.396455,318.333907,364.37821,381.666095,431.560751,456.014758,468.664748,472.35682,491.942244,406.489009,334.410039,224.002548,183.796612,127.343743,119.627124,156.142682,189.007126,146.20786,-45.988551,-136.886167,-222.886687,-227.797858,-257.080621,-288.899592,-301.329664,-305.167362,-351.374829,-468.720317,-479.940211,-351.941868,-249.16234,-45.332435,169.581732,249.385186,271.731113,233.476529,161.754934,148.95529,183.829574,238.653415,342.40869,251.367059,152.050999,30.988378,28.10333,36.118435,25.683677,108.120101,312.619923,345.53274,251.433229,184.73571,99.576933,96.153131,144.495794,170.755777,183.025787,148.952954,128.5514,63.826588,38.174946,137.295915,258.9722,458.31563,424.244931,322.048485,108.650134,43.823279,-9.58082,6.514543,109.379389,166.522044,209.250026,147.018855,124.436229,120.501695,96.693958,-14.433155,-52.854322,-17.534222,77.70832,83.650284,21.118981,-6.614634,-18.246832,1.272724,87.413197,127.662487,102.735817,-53.291304,-97.23278,-31.206727,22.323809,45.456385,30.199956,48.726706,138.502503,155.960157,137.239948,135.242855,153.025337,162.5946,197.598328,225.424484,218.670945,98.442094,66.355439,59.97975,40.817772,22.652587,49.226168,128.838461,153.118846,111.797019,-51.26578,-148.069791,-321.247059,-367.476786,-357.955631,-322.278992,-230.350631,-209.295196,-237.040459,-248.983575,-222.134356,-205.245167,-217.185353,-196.957384,-175.725101,-209.271795,-319.237014,-370.203348,-418.350475,-381.674483,-217.626691,-151.827936,-116.570279,-146.504259,-186.977625,-314.104362,-349.253089,-299.308306,-251.198042,-182.493351,-147.94044,-127.123886,-105.029715,-132.010091,-209.876279,-204.356838,-72.967688,5.727183,102.903284,156.254406,154.977297,59.590518,0.091279,-37.758698,-10.734923,123.860436,249.206229,254.623271,197.287389,164.31239,166.534715,213.695145,235.389781,188.286367,158.37555,185.284123,160.498897,0.906945,-81.353153,-12.258402,106.954911,207.589563,126.514747,100.894124,55.862218,6.646097,-9.496351,56.804348,127.165508,88.316321,40.109168,70.80573,72.63943,89.523949,111.878795,112.095273,81.513298,26.594341,-5.321592,-15.562372,-7.13449,-12.398513,-75.219205,-105.258995,-128.952182,-111.507881,-7.495272,-26.439048,-116.422301,-278.988604,-308.10315,-285.666963,-248.407659,-155.467977,-109.648668,-114.094686,-169.157757,-213.626624,-269.721192,-262.920786,-177.168416,-92.787825,67.555569,47.448275,3.81368,-19.363938,-9.609321,5.303284,15.035279,76.607487,119.660644,75.812136,-84.91256,-149.902596,-229.160392,-251.772165,-245.476195,-219.473828,-215.922251,-285.124917,-283.801371,-238.56898,-228.900669,-175.830386,-138.261965,-111.421213,-63.972541,-25.323286,-25.281262,-72.838639,-177.658225,-195.616769,-108.945636,-7.410275,195.523543,218.595598,175.215575,61.680682,27.379711,50.876319,86.094241,157.486247,164.005303,117.75922,18.892672,-1.844505,-52.055958,-76.805954,-58.816644,-17.823225,88.053828,71.416585,16.581589,-70.476255,-92.685717,-97.189271,-69.362537,43.363747,69.957542,4.848337,-111.352427,-93.162377,34.509296,83.024785,39.401823,-25.373058:2.352418,-11.774953,-106.857931,-273.018881,-293.843679,-265.606132,-256.520922,-233.116586,-131.718375,-76.158748,-36.957413,-62.823071,-129.770992,-132.227001,-102.047159,-69.879899,106.119836,287.342791,280.729772,98.811489,8.758617,-70.050835,-86.450094,-97.260722,-115.004517,-157.847901,-226.953071,-210.55521,-106.328338,-62.755423,-10.50306,26.720033,116.146616,150.180114,149.448952,151.360855,153.962002,129.663931,101.656866,95.073687,154.305343,149.126895,33.341698,-53.456937,-174.306727,-175.644739,-128.186518,-108.146066,-58.023405,-22.917461,-33.287893,-38.878045,3.471435,94.384334,68.907568,-99.071996,-132.598794,-76.176772,3.85874,-8.993819,-78.006924,-89.056525,-31.419392,-12.222222,-32.341108,46.754517,93.15228,3.827958,-88.916409,-141.35726,-109.074468,-64.521882,-54.597018,-45.399945,-41.42382,-72.441081,-178.387244,-194.463454,-87.638346,-20.118372,0.179257,-98.011943,-142.064177,-155.407364,-125.347969,-28.265969,32.724057,169.969148,203.46017,156.274572,81.420301,90.783947,73.920743,26.113362,-2.32541,47.951191,155.636643,116.918887,74.768215,44.411551,52.301535,82.931699,99.044173,119.214627,113.0947,97.784558,71.198939,62.930442,55.499731,64.615711,96.257277,124.018094,260.451641,411.358956,440.204093,384.661826,333.027802,300.675564,299.183751,219.848233,162.861505,187.990131,280.874426,326.438484,409.987311,425.232132,353.744958,316.795953,327.255496,306.221709,278.503275,187.539148,104.977225,-29.271741,-34.610002,26.381835,60.403549,39.009051,-88.335513,-177.771687,-348.855639,-404.239145,-405.04952,-359.889596,-327.02357,-433.358134,-481.161385,-511.632398,-507.314877,-438.734035,-346.509518,-72.551591,130.849545,163.406205,165.451081,157.131629,161.750759,192.819821,251.136561,265.749823,314.808684,305.12963,233.729602,61.000845,35.86207,93.134493,108.280989,89.451466,106.758562,100.939566,24.972792,-19.024849,-84.221212,-105.208007,-135.595479,-138.160212,-86.014888,-25.620845,-29.95407,-89.169406,-110.725567,-68.631293,0.292115,165.439094,198.895263,137.291472,-26.6665,-84.380515,-142.942282,-137.022849,-64.406553,-28.417874,5.292974,15.288415,17.743559,-12.1937,-46.088817,-94.286659,-97.471841,-123.587199,-175.855381,-176.201519,-157.060277,-169.236429,-207.988769,-212.982748,-216.663709,-203.400209,-128.237956,-170.291201,-237.931144,-277.738101,-243.226156,-185.653119,-161.759885,-33.445406,97.4619,95.344155,27.750803,21.472132,83.641488,109.557533,73.106475,27.803369,-28.451273,-23.988272,-37.535275,-140.694573,-196.61254,-206.707332,-169.215215,-97.655234,-96.466259,-140.110202,-273.775409,-354.739316,-540.359261,-603.051226,-600.62925,-563.160666,-500.11343,-439.322612,-386.684522,-309.698685,-339.766868,-482.25823,-529.296565,-527.88058,-478.533204,-470.747155,-529.701071,-606.482699,-757.065792,-757.297448,-605.982278,-521.028036,-407.904137,-374.606865,-400.214542,-443.033449,-413.230923,-309.365461,-274.751833,-188.384138,-78.941364,-82.964207,-210.230697,-276.45194,-277.990133,-203.628985,-48.603623,-13.32141,26.976959,77.257675,78.683713,5.847534,-42.412716,-34.620157,27.762377,176.711699,259.329097,244.718666,159.021976,121.793501,92.073917,101.567411,102.90863,90.211018,130.352247,185.333526,165.405344,71.166436,45.10836,99.471122,139.61639,113.970759,45.482806,32.638928,29.875523,38.38026,120.072331,199.609051,306.133165,302.146492,284.333331,298.450685,293.349144,272.253753,244.348552,180.045037,180.272878,146.281778,-7.638183,-36.268127,45.672339,73.137433,11.559515,-23.933852,-18.487746,15.312693,133.696068,178.007914,133.578378,-13.580888,-77.585588,-133.609436,-127.599176,-44.308433,99.401082,139.143346,115.903973,99.792607,125.287679,142.472318,128.844314,115.071437,178.273373,293.851907,301.293295,248.253557,235.807707,270.511035,288.413177,292.775069,266.861677,211.679472,15.685663,-76.634397,-174.005549,-174.399992,-90.783465,-36.889405,31.587288,-0.282925,-41.236835,-96.105869,-94.454769,-23.088547,23.788233,80.293848,131.698968,163.509831,138.592091,57.147028,-93.206868,-90.561189,16.258714,66.259643,152.816799,242.281827,265.72053,220.438475,174.36368,102.122273,75.129913,72.279461,151.391464,170.263764,90.877743,29.016117,-14.208234,8.730454,67.192714,99.480717,194.769166,193.013521,154.235625,113.710689,108.19214,85.236864,72.152855,64.124713,39.085665,-3.256996,-72.859193,-63.671839,12.514635,32.423954,-28.59972,-64.395433:38.696086,13.014874,-29.80336,-116.127963,-147.308753,-129.481735,-70.735417,61.615944,88.624123,72.261868,28.93294,8.088322,1.083825,23.610262,90.60568,116.301587,119.842651,73.691396,67.432797,46.033408,2.292815,-49.169874,-19.679445,75.81194,31.612764,-41.115081,-116.622262,-110.411134,-67.995414,-17.072745,107.12345,133.807589,93.182548,18.628684,2.981277,12.960956,34.455222,129.985218,205.22975,342.766656,296.407159,227.10353,143.177222,99.931809,-13.667275,-15.489617,108.235695,164.574387,161.90534,83.086146,64.952267,95.812709,151.210433,303.893111,338.77745,225.81607,40.500499,-0.419974,-4.678787,4.573885,69.332835,128.479959,227.114946,238.437659,213.927258,206.766549,201.79285,182.369052,186.916139,197.628128,182.892119,125.594915,97.76882,89.417535,12.188685,-76.429675,-261.064897,-266.884591,-90.988549,-9.03421,5.13187,-90.96569,-142.805974,-215.20402,-207.450248,-116.545356,-78.448782,-16.565501,72.318303,75.950114,-46.605545,-148.407666,-332.13617,-334.693939,-146.111787,-36.885957,76.575488,43.12574,23.430203,45.452483,50.167333,35.854802,62.050932,153.431288,162.477704,128.158979,55.196131,56.316825,118.612023,167.4852,304.1699,365.703606,414.156432,413.675798,396.699228,294.152399,244.16431,231.556757,236.81673,235.317986,209.373291,162.98179,123.169301,164.791916,277.207215,315.837025,388.877327,451.266474,598.793213,559.975644,439.30044,202.402001,171.924924,271.77483,319.531616,286.309651,157.368474,81.8418,-64.371043,-126.094872,-215.946181,-229.517429,-221.621223,-210.398658,-176.345384,-242.016165,-307.10499,-370.96851,-341.111562,-189.629611,-101.959181,54.187557,207.306597,265.347499,293.265532,273.171075,251.812044,261.03501,272.240978,283.076477,337.977259,336.88497,258.478475,22.544939,-30.537061,35.229287,75.083434,120.426024,172.001196,164.145831,37.069098,-36.186634,-28.846362,48.616714,179.376364,197.568969,152.401247,18.843337,-51.597971,-139.407206,-139.705818,-11.891727,92.888494,253.060416,255.023989,198.247962,135.173477,163.111812,184.691856,145.560508,73.170925,71.526233,66.477613,-4.781064,-16.361409,41.258746,54.824895,46.745023,67.380427,112.293237,126.007,136.782315,154.779523,154.213605,119.629161,96.224488,82.783883,92.403748,72.772435,-25.371917,-59.512284,-65.110307,-51.523567,10.378308,46.521909,65.337303,32.154862,39.276839,100.629679,103.803639,59.06057,68.254543,112.289741,106.641638,86.912438,15.425511,-44.985457,-91.819643,-72.336597,1.789401,51.634232,121.806135,30.46461,-76.310345,-278.8217,-322.56075,-318.011443,-302.84144,-272.922497,-245.00154,-139.057238,-101.548721,-115.756933,-106.141875,-92.012334,-134.863002,-188.882487,-223.017885,-181.472359,-249.546746,-523.714385,-587.007377,-444.187805,-336.893774,-236.737041,-213.642097,-167.093194,-209.988344,-244.656328,-317.667183,-360.993053,-363.746961,-302.627686,-139.426222,-105.052617,-125.962279,-155.261523,-192.479346,-277.289638,-242.352107,-5.611394,110.491484,186.286722,92.230733,42.839965,23.934597,66.593628,195.760163,213.725751,194.109439,243.070839,239.36465,127.026423,56.107103,1.612101,37.645954,119.609137,119.609407,86.420513,46.562785,-10.024835,-135.03459,-131.928709,-10.925587,25.990681,-29.881588,-123.423005,-141.137873,-148.167606,-167.936798,-192.877226,-142.285714,-2.856235,1.7855,-76.733798,-106.077536,-97.335474,-83.485552,-94.385995,-98.138014,-82.250382,-79.407425,-95.591511,-99.631509,-78.333915,-48.071872,-39.266923,-86.107807,-176.273935,-145.22793,4.913455,-33.730142,-141.841221,-349.929492,-379.539191,-303.915196,-234.33821,-80.137335,-53.79117,-106.204018,-213.826879,-237.852038,-247.344307,-244.679651,-180.721099,-96.67268,77.700853,40.249913,-21.38163,-37.903957,-14.20967,13.482041,47.577578,157.358501,124.328613,43.300891,-105.90099,-152.946296,-205.600806,-199.594644,-114.285114,-67.548352,-66.138363,-125.176808,-131.121316,-130.712744,-131.976375,-76.014655,-17.977657,83.310824,78.605278,27.205326,-90.410869,-124.511387,-141.682427,-123.6467,-22.159932,61.575082,229.373476,255.948562,199.401425,33.458467,-4.148168,69.081205,106.912866,126.613216,194.900682,191.293372,48.909214,-14.316902,0.322972,36.335414,33.022828,14.356101,48.332707,84.042195,47.860342,-83.022373,-120.818705,-76.856482,-24.993879,54.858258,105.554008,110.640857,48.884683,-7.389456,-96.83586,-102.260374,-11.270696,66.254047:forward
-176.563197,-176.477603,-161.175486,-142.839544,-119.819825,-90.731961,-118.894199,-180.420815,-90.739169,-24.058574,37.094408,59.164585,138.210119,166.549726,202.224941,197.559284,74.131625,-18.999838,-11.182383,25.060899,57.743616,162.498928,185.206501,102.964962,6.384393,21.870488,122.636709,142.369799,103.565435,96.478426,142.630669,154.92571,66.614801,-96.03716,-117.488554,25.514226,129.106665,221.472069,206.268105,134.476045,33.211527,9.88555,121.184887,233.849531,388.763334,384.895299,312.442559,296.182967,274.96844,198.050274,156.003681,128.539945,140.346182,231.825665,305.817999,370.418219,347.034266,385.061971,520.163906,548.385612,482.495467,422.539956,347.774989,326.477815,231.824183,182.241684,208.355459,243.09779,252.702704,263.530053,204.117642,-4.488795,-2.678924,71.356938,158.179914,176.382562,259.301649,286.460996,210.616309,149.019098,128.099825,223.937015,260.918136,272.337682,271.675134,340.853282,395.145363,343.817191,130.61657,110.952154,217.374999,233.635631,159.104877,124.909879,120.212872,100.099605,-115.370576,-276.770891,-212.732975,37.630497,118.530958,106.140269,34.848946,-137.080013,-209.296401,-173.887856,-58.35498,-31.655586,-15.486563,-4.668102,-25.618626,-77.416323,-221.928427,-274.633475,-251.858333,-131.627181,-22.273205,208.478255,260.609203,212.410421,141.42638,147.541906,157.185774,131.277423,136.58097,201.752909,314.887292,291.818974,135.236653,80.559776,113.281024,231.923681,287.287696,293.862662,253.772924,199.24106,159.03629,133.627268,120.466671,122.635437,102.261332,91.822957,108.665951,111.483052,61.229304,36.351721,32.170895,24.521512,44.93425,116.089773,134.034121,68.77554,-33.205525,-22.819852,39.237021,29.192566,-20.040205,-42.660414,-123.621614,-175.587632,-248.217145,-236.901842,-220.283193,-202.193176,-197.395369,-249.639856,-323.514556,-496.86649,-568.103567,-522.944708,-294.118689,-189.296604,-194.720488,-290.99899,-421.488422,-405.402421,-358.097071,-362.817172,-349.627857,-299.170584,-278.018479,-260.966594,-268.308987,-317.228637,-364.400885,-359.925376,-283.3891,-228.428852,-124.047961,-98.779168,-138.01344,-192.036064,-315.889793,-331.10784,-287.936285,-192.219132,-142.145343,9.2667,80.634461,89.854728,-8.34905,-28.91967,-2.448401,20.045226,53.147596,38.459763,-62.848977,-121.841724,-197.076234,-146.960805,-105.106113,-48.94349,-16.022408,99.513166,164.566862,158.715118,41.240495,59.943905,200.643531,233.142595,209.364115,185.940882,111.859197,68.558648,7.6807,-58.586025,-82.029634,-37.838364,7.72059,38.401404,24.352193,-43.050917,-185.387318,-241.964375,-253.420617,-215.016446,-91.670011,-56.5682,-137.939592,-227.497875,-335.088982,-285.515283,-277.399198,-316.275983,-297.827694,-184.016409,-142.499075,-138.364314,-157.14628,-144.259499,-113.800039,-95.81247,-60.47587,-100.136157,-297.255918,-378.219864,-483.183398,-535.992161,-500.462044,-391.346925,-366.049226,-319.443903,-274.34071,-265.54571,-349.619057,-313.653315,-109.147854,-39.640709,-83.499513,-159.25392,-245.029515,-242.968425,-210.827452,-123.454949,-96.606055,-172.359346,-214.306624,-182.385664,-157.971176,-198.18898,-254.562134,-229.379653,-99.254763,-51.414728,-59.025372,-97.699822,-192.579113,-239.711143,-310.786305,-259.953147,-164.922301,28.37673,74.472658,90.050184,71.583856,7.157072,-36.378214,-57.934298,-107.431967,-115.479883,-134.820473,-164.776222,-156.705431,-116.880509,-97.731826,-116.143343,-107.649611,-74.770277,-62.433715,-73.039619,-85.347115,-90.323417,-87.039471,-72.378851,17.270258,108.107768,337.615023,394.717639,305.609785,224.840965,132.801187,178.918741,239.204881,341.799513,371.122794,417.484129,438.699943,436.948362,400.673171,383.955591,341.115506,327.763925,289.166043,227.07433,67.354237,21.352902,-1.40333,41.487713,88.561194,169.416314,186.597772,145.028403,73.062341,-136.734732,-252.146251,-228.139674,-153.438055,-140.236028,-121.51367,-134.985289,-245.35951,-309.679912,-371.842303,-317.456939,-280.963454,-237.951392,-217.378247,-189.350959,-209.430322,-337.456744,-434.287235,-392.293836,-209.079988,-153.57223,-172.284449,-226.158647,-332.937751,-342.069389,-254.499237,-129.738438,-88.32875,-68.266195,-62.716579,-27.571673,-35.359721,-145.578471,-236.226495,-228.678498,-124.50711,-63.75588,-22.219449,-58.50178,-174.998664,-225.598446,-308.90479,-304.148577,-248.268043,-65.985639,22.373284,62.866705,1.962948,-128.020955,-95.558628,-54.771608,-1.883411,30.129215,81.263362,68.252008,54.734432,93.686238:-169.080995,-145.629948,-116.2767,-131.621978,-125.534803,-73.078006,-70.144474,-97.119677,-73.739561,-48.587366,34.150122,116.026622,259.918382,258.692014,152.55462,87.199429,-2.341537,-5.254644,7.713241,64.960438,100.967332,71.927056,-8.514608,-160.455133,-146.683061,-92.40128,-2.31247,13.968796,10.480228,11.497823,14.313154,-19.148299,-137.733099,-149.735688,-100.379852,40.86236,91.749667,71.310162,38.555339,41.033069,56.533257,64.525797,162.007662,242.129016,320.328146,302.897785,273.579573,300.596802,401.475505,328.122115,217.662326,138.395439,200.269907,336.432049,363.059303,333.759209,326.51805,387.477848,521.276862,526.503018,466.478474,448.452908,421.026011,399.31795,343.175756,232.656565,198.497605,225.641675,250.739579,249.180165,210.675047,68.454539,40.276431,110.887356,253.283509,285.127039,343.004087,370.417369,302.40879,191.874497,-5.03965,28.410426,104.743521,218.873566,237.147471,250.627384,262.82046,234.877941,98.084016,70.104306,145.221302,176.209459,163.068891,144.425495,76.501253,13.503075,-175.03164,-247.355918,-185.605488,34.322121,129.524805,139.699532,49.621653,-159.797127,-212.351132,-161.347817,-20.484063,-0.139751,-66.414639,-91.588001,-92.46608,-121.620777,-257.021594,-274.32516,-201.940061,-19.509735,46.222238,95.997642,93.410081,76.065079,104.608157,137.622902,155.683057,140.119859,121.591842,113.035133,95.83221,93.215424,36.562434,-40.39863,-12.984664,199.903645,306.138199,357.964324,321.666363,204.549675,60.893393,12.883262,49.101676,110.804343,162.530935,139.75649,111.345626,101.521871,37.047813,54.077258,92.109759,168.393811,224.328271,309.024943,271.804753,68.378019,-12.962426,37.446617,160.277492,180.378698,138.46199,76.592926,-82.415315,-136.530042,-202.694586,-252.825536,-217.139637,-47.533888,-12.20834,-144.816279,-254.987479,-408.886815,-431.275984,-384.562381,-203.314163,-136.821419,-201.782162,-314.515205,-509.421399,-541.504549,-509.067419,-394.310603,-320.691566,-227.582109,-224.31565,-300.806104,-359.62171,-417.240312,-368.547387,-344.304593,-324.991735,-299.395515,-198.444573,-164.479946,-158.230656,-182.921511,-307.634778,-302.499986,-201.731941,-7.647487,27.359759,36.299519,54.13837,50.591278,-37.239264,-29.674078,68.456471,85.273215,49.319871,37.218847,-12.629892,-87.490888,-223.612048,-158.292817,-93.811946,-20.442537,6.882322,167.398605,259.502621,149.510168,-112.478318,-97.613731,58.298381,85.765289,83.529529,75.254271,-38.88092,-127.284328,-178.355638,-117.681761,-113.285533,-94.977647,-74.842524,-79.166252,-98.696348,-144.308027,-256.828118,-321.565119,-339.159126,-278.054148,-135.122851,-134.38237,-274.397042,-336.097817,-351.843431,-249.698822,-180.638584,-102.861769,-125.762693,-220.587708,-231.331279,-195.488036,-107.776486,-13.700128,84.761007,20.796291,-158.413668,-191.172833,-193.075092,-245.59395,-509.478065,-607.943552,-508.454961,-296.186797,-281.148883,-334.829118,-348.371875,-377.926074,-367.139198,-303.076798,-126.467279,-81.698566,-147.763752,-214.033452,-269.485625,-251.249016,-201.291479,-199.602545,-201.418984,-162.714667,-137.352407,-105.184745,-103.95479,-166.246075,-218.628663,-168.596633,-10.693573,2.587336,-84.594625,-111.476154,-99.522822,-109.733004,-196.13638,-221.798563,-191.014581,-83.166214,-2.518007,149.038274,147.657974,7.551421,-108.332898,-140.789671,-138.21613,-89.011215,-6.8868,-32.703632,-150.298897,-184.605541,-174.86486,-99.833286,-75.877665,-68.316263,-39.671726,35.512298,36.58871,-8.302379,-44.040683,-51.789642,13.291541,118.435171,386.725497,435.538585,267.590945,163.264947,103.14572,176.180381,244.516912,400.452831,442.238068,364.501182,270.963748,133.922711,165.031681,193.082132,226.72096,269.024896,332.480875,285.439354,75.669008,-15.380353,-88.821242,-0.425567,73.056091,141.091154,121.542576,41.967241,3.355336,-104.275633,-219.987962,-229.950975,-159.146329,-113.796192,-96.131974,-143.369735,-244.84796,-245.674378,-194.459356,-133.944401,-100.120196,-79.069107,-86.298087,-133.647377,-205.285686,-420.315531,-448.611616,-331.215632,-92.445896,-79.854352,-171.430147,-197.449752,-216.349661,-237.688527,-266.657209,-180.679594,-103.041303,15.859458,43.600974,58.446056,26.619809,-153.272253,-277.626918,-271.161797,-188.16253,-111.589673,30.340999,27.834497,-117.798785,-222.114643,-367.091589,-279.064621,-182.548797,-12.10535,46.698338,45.024009,-36.909097,-237.281151,-196.909126,-98.181389,28.587963,34.619941,60.938924,114.725881,209.314671,192.477977:-113.398191,-118.943525,-85.940727,-19.535789,10.484146,10.841481,-22.728057,-92.083379,-124.82144,-109.451787,56.783669,182.722328,304.174897,270.643165,117.250142,32.077717,-33.328148,91.874016,152.883533,234.67009,264.971342,194.738336,70.630909,-202.296837,-272.105477,-216.067865,-48.260012,11.830549,37.563004,1.584144,-86.476772,-100.871825,-110.903024,-136.709808,-102.412535,132.942758,245.06649,217.783704,127.139652,3.627734,13.326297,55.558573,110.828502,125.882352,243.563144,324.035639,371.20638,325.538424,211.705433,240.084084,265.151667,221.592861,191.755536,225.595297,274.695005,303.512426,286.713561,324.226235,436.810246,456.361371,393.07866,343.730619,307.725235,301.04955,223.094819,140.649328,134.651373,165.651521,174.049588,152.040641,142.57464,90.507049,0.753771,23.78883,162.467419,210.606335,279.660466,302.500184,200.094387,85.455775,-26.563098,139.72858,240.517229,261.390443,192.94043,88.587173,73.507478,50.26072,-1.658657,-23.958844,9.742004,65.262132,116.058458,94.672197,55.235997,8.772338,-181.783441,-176.027525,-92.452449,13.160366,27.008757,23.387086,-4.232515,-120.241415,-193.05527,-144.92421,45.949128,90.230296,14.316702,-42.159637,-82.946995,-100.514165,-231.254659,-347.864033,-317.671382,-101.311084,5.013354,72.834193,35.723548,-107.169842,-124.902039,-69.642831,44.378606,84.396652,99.722167,76.919511,26.398688,-10.515175,-100.354559,-72.893195,-12.078022,127.04684,173.828295,215.907186,237.294626,229.168568,66.662465,-5.459304,17.865097,59.639767,29.363903,12.153393,99.729291,127.592651,6.680692,-93.978221,-48.899441,137.381268,197.992343,208.909122,182.766486,69.929576,-61.60729,-70.370785,48.74297,121.523425,180.362897,151.193953,-20.715325,-110.254027,-162.042457,-132.072815,-100.875735,9.130658,46.353696,17.844021,-61.611599,-302.632356,-334.15489,-227.801692,-1.462689,28.676253,-144.807964,-286.49893,-437.261567,-439.892444,-388.573272,-284.380177,-243.699566,-209.002321,-213.731503,-265.128361,-281.666256,-253.008004,-163.93339,-126.474612,-145.731849,-166.962052,-125.604871,-101.533681,-126.595048,-158.288776,-240.288619,-224.90847,-154.660331,0.110217,55.448874,108.431361,95.025228,-20.650995,-59.249734,5.083973,127.437354,127.143223,57.054435,25.234473,-29.83427,-85.762675,-235.026625,-227.838104,-147.580587,11.314143,42.608722,108.448086,180.546632,175.600078,-84.014667,-139.402106,-45.361437,3.315927,-3.806061,-39.029676,-138.391768,-199.529224,-241.462702,-120.20755,-73.857891,-77.073084,-103.761231,-156.141909,-174.028917,-236.956999,-306.624163,-284.638281,-162.088637,-125.495638,-121.572406,-140.503357,-226.679926,-268.773219,-236.41607,-96.254103,-58.493129,-88.286953,-121.767726,-139.950192,-127.841235,-155.670541,-191.379022,-134.747593,6.046406,4.352454,-93.306311,-126.990587,-167.419088,-223.413387,-409.461033,-418.763302,-333.469416,-192.893843,-174.180162,-185.568888,-206.007454,-276.582903,-300.930661,-257.636239,-99.381144,-31.498339,-8.091235,-47.759341,-138.134455,-156.106988,-155.343487,-226.546381,-254.237276,-153.82125,-63.829144,16.197926,-9.554965,-124.495107,-158.050318,-99.061833,46.930019,82.502343,103.178204,88.002378,-21.641252,-81.444974,-108.147096,-7.701747,68.263368,197.188418,236.289289,229.785744,167.025563,-1.043841,-118.019299,-155.768101,-139.042664,-74.93375,42.397662,34.699497,-86.725098,-133.838547,-85.630068,52.006157,91.627799,156.523916,197.358649,220.762769,202.359591,184.970948,183.360784,154.875305,141.143863,225.154442,482.974892,524.48157,336.285126,228.477508,208.060677,252.45266,260.023939,340.123788,379.93433,342.229348,282.60653,160.419748,136.039322,170.369632,270.403899,326.606167,387.790916,340.802168,99.493704,-21.218173,-130.096341,-78.665635,-15.117579,141.371005,177.132991,73.699162,-6.325884,-120.401375,-206.550058,-208.389872,-123.110013,-69.325981,7.204465,0.965874,-104.336776,-161.558885,-197.80303,-112.466657,-70.850877,-64.967847,-63.281799,-31.623807,-82.660526,-374.114004,-470.390501,-350.924125,-103.470318,-81.804227,-159.798936,-213.748573,-308.693191,-342.651473,-333.531023,-143.517911,-27.873752,78.154433,67.986977,-1.28469,-69.09084,-276.66687,-288.835649,-195.328672,-93.007112,-113.802291,-124.095172,-91.517515,-77.246688,-135.124525,-222.78477,-107.010234,-53.183321,-43.441499,-44.562889,-38.621101,-70.039555,-218.3829,-231.173423,-144.214137,32.794651,72.081185,80.05629,65.472913,-6.457722,-37.675929:-28.008499,-28.08632,45.696656,186.599262,201.919894,117.846647,42.303322,-70.847794,-20.945745,44.124724,185.869658,270.28721,407.623214,413.416165,357.159343,340.81774,296.370226,213.581931,196.509039,277.977632,334.80024,283.653392,174.473137,-23.541251,-33.902896,8.356186,78.04509,102.16887,122.016847,106.89941,69.886159,49.05377,-29.44645,-65.744409,-34.298068,102.676266,172.263247,232.993453,231.148776,207.897753,133.465244,100.328248,123.281033,176.159864,313.332313,356.861826,316.767417,253.119884,164.532624,212.063438,240.721056,235.270855,230.218764,272.048777,305.529607,307.991315,258.51178,276.485831,357.331313,382.830688,417.717936,424.117679,390.910728,345.85256,192.071335,132.663257,191.118199,340.460741,374.901251,353.268536,315.234197,211.26978,111.435884,90.817916,102.180314,135.689479,250.575364,284.87784,196.174764,96.208045,-20.972904,56.2653,119.170084,173.442691,161.556166,153.356226,165.26567,125.245049,27.264153,14.550049,58.562809,83.448971,92.771714,84.252261,69.797754,45.35001,-58.806439,-51.994217,17.82283,133.81137,139.613539,36.551127,-44.891838,-141.057763,-137.448903,-115.13955,-49.093018,-22.472771,11.833678,12.939378,-74.660421,-166.271124,-341.127802,-346.722372,-279.895402,-59.555958,61.239714,191.889481,183.939779,81.463872,43.118645,109.92876,265.947665,265.176911,167.021099,140.90979,139.432862,121.579899,33.957429,16.183801,58.348746,175.815484,207.257294,173.871861,141.228191,109.56644,62.910106,39.740044,45.878087,53.728764,9.088763,-26.19169,-28.918569,-21.667768,-110.660606,-160.987908,-118.459054,-31.268782,-23.293314,-41.99977,-45.159418,-57.166263,-113.389411,-115.825583,-36.660749,12.224178,71.928654,68.749967,-8.467969,-68.291723,-199.070831,-255.498569,-205.089755,-27.083358,13.504002,-94.978504,-200.407149,-376.44354,-393.53842,-301.501615,-30.053657,32.667703,-110.216875,-240.204785,-354.384874,-327.475878,-234.217824,-143.102913,-127.897343,-201.733001,-245.280723,-256.265071,-248.562007,-284.146961,-314.117877,-292.4681,-230.45614,-212.974918,-183.747303,-158.594764,-114.268941,-137.166405,-283.371645,-313.722374,-248.676027,-90.491853,-39.447387,-24.549572,-49.482786,-128.800433,-197.676433,-181.610003,-77.088946,-47.325296,-56.937667,-61.155198,-76.579492,-131.065984,-318.065325,-371.671024,-305.019794,-85.673307,0.178074,79.948084,100.915202,49.330992,-69.934564,-52.204886,69.303716,97.121148,76.074363,30.732287,-114.763113,-167.862419,-175.02067,-154.446404,-154.806689,-82.72654,-21.387602,16.67731,-17.041139,-131.709536,-234.251161,-257.92137,-233.048153,-201.356141,-187.289854,-210.290845,-230.242387,-228.983594,-255.307982,-284.192961,-302.404032,-324.829095,-309.1355,-255.194683,-225.422931,-193.570064,-242.94647,-229.38319,-94.718765,-45.846305,-66.708532,-108.436208,-158.743242,-175.993452,-285.568093,-347.160749,-303.750742,-198.486183,-183.851973,-202.2955,-202.224078,-195.121479,-203.267978,-182.098323,-101.939991,-55.364507,21.94418,9.872486,-114.400506,-167.208772,-192.007392,-164.392395,-138.768514,-77.666054,-60.359885,-39.674159,-25.589397,-40.581507,-122.686071,-117.853316,32.674077,106.026311,94.086614,26.362206,-70.643502,-89.544579,-153.975077,-155.025716,-94.249389,38.822876,81.848418,91.185594,35.877969,-123.128031,-181.584633,-160.803074,-51.797126,6.980463,34.857848,-0.73044,-58.765005,-52.371185,-20.212243,-28.267789,-39.581213,-9.109663,31.420891,71.228018,79.606248,123.768869,94.144407,64.257906,112.425837,202.772757,404.242602,443.169817,350.318057,279.998762,242.446965,282.529794,283.536005,307.86369,349.376286,384.737395,356.928132,283.155128,262.570422,275.554583,325.867802,357.273976,362.154507,299.83054,109.917675,20.45154,-119.562155,-64.850967,33.113609,170.615533,168.397039,74.209011,16.062429,-109.168528,-203.709071,-190.598518,-110.81543,-96.360091,-115.946901,-145.766068,-221.112742,-242.346005,-258.448427,-233.015714,-199.125803,-137.670418,-132.43553,-168.562044,-192.520807,-273.984953,-356.520847,-330.740172,-203.988276,-178.249025,-211.993425,-239.90966,-287.919512,-301.364264,-281.768743,-138.534587,-51.66353,4.601729,-1.58921,14.886659,-3.905405,-156.705772,-256.272953,-241.880693,-157.198742,-106.423618,-25.233839,-26.186828,-89.776504,-141.573626,-284.785884,-288.075561,-212.418158,-56.40224,-4.591599,35.433109,5.767255,-115.208091,-123.87479,-79.144988,-25.523788,-12.741384,72.836733,120.1446,87.757037,28.753744:-2.010657,87.123813,156.726369,288.1817,332.844832,301.622691,219.659407,7.239071,-104.721434,-69.050236,174.054681,320.592235,455.717409,426.476371,255.95331,146.377492,43.666033,141.95068,196.083988,297.459109,346.40696,318.665427,210.590325,-91.734023,-216.016863,-167.977598,-2.341233,53.590602,65.036744,35.908381,-52.463308,-115.31724,-225.149714,-148.319334,-52.824627,152.674236,230.625306,222.868599,162.263026,105.653376,119.112045,122.844815,161.542104,209.813704,324.846777,348.494512,246.088839,141.927133,7.729243,66.773961,100.59683,99.604403,99.409759,141.937546,161.01047,149.681996,162.796672,200.662713,281.651826,317.178927,357.265396,335.284039,220.034506,169.179389,160.107952,225.020483,244.738116,262.577389,289.608637,332.177531,294.235474,116.041177,-17.284592,-23.176042,72.937662,164.761507,343.21504,342.19932,116.376144,-10.679383,-72.811665,73.409954,162.67595,248.09044,229.446028,165.717164,129.318449,-21.216914,-163.849252,-152.879284,2.143415,70.864861,75.742502,41.691873,-14.276951,-56.349475,-160.724623,-100.602136,-2.634861,172.773841,199.028797,85.669281,-12.80915,-144.149688,-145.47823,-103.849897,-13.723276,12.627658,61.800239,75.217323,-29.365561,-150.212357,-356.313844,-368.177819,-300.453237,-67.508253,44.118729,143.67781,120.299164,-39.167992,-101.315304,-41.435624,99.763367,117.793463,76.539553,69.831789,90.701402,72.208561,-42.499392,-75.587421,-29.779065,74.317898,106.741776,142.359221,128.778366,12.503253,-92.315174,-77.961561,70.814655,128.347033,53.845971,-21.480431,-63.024694,-70.377233,-184.353149,-243.360752,-178.286639,17.37424,60.969109,16.120657,-19.788223,-72.074674,-123.337339,-115.932414,-14.298215,65.13697,216.989631,231.281726,79.680405,-29.951319,-157.501407,-152.271663,-94.593195,104.055208,162.81563,59.8905,-67.419849,-273.686465,-227.034667,-121.190442,78.004781,110.818042,-10.399033,-119.279309,-238.02121,-239.204966,-219.641932,-134.155145,-69.117744,-5.841986,-15.845892,-84.579591,-134.97754,-254.348099,-313.728443,-300.396886,-268.539131,-245.287231,-126.78716,-73.257247,-121.668488,-220.852881,-369.354799,-266.427003,-182.878477,-66.601208,-11.181388,89.712054,85.346885,-48.617775,-64.162752,3.084481,98.788285,103.32759,60.360325,32.910815,-21.544352,-79.852865,-206.944808,-132.129799,-24.785046,152.279685,156.258835,103.264568,135.382973,120.933879,-177.269816,-243.789052,-32.21187,104.273599,130.40438,50.073942,-101.108227,-158.182207,-250.142567,-203.227885,-112.645662,67.546745,98.232012,60.493317,27.186286,-100.911584,-275.658286,-302.777921,-181.431883,-89.639999,-37.801392,-103.375696,-289.960445,-348.588852,-335.723569,-190.331907,-120.081811,-74.560908,-108.016472,-196.401087,-206.368956,-224.920715,-256.217284,-187.639952,51.694207,105.806803,33.313201,-12.762247,-63.085693,-110.103083,-221.479465,-219.335934,-175.815452,-55.646831,-15.953562,-52.809491,-105.760685,-184.012387,-181.27475,-148.375641,-61.018272,-7.495063,59.131206,28.258753,-109.969149,-172.314706,-239.16812,-203.547268,-140.140186,60.179972,140.082526,138.539169,80.454169,-58.283443,-100.669064,-38.962788,137.520673,193.067521,203.93548,163.480111,44.694741,-28.986776,-182.18267,-158.311092,-69.454387,109.379029,156.038729,138.328691,75.261295,-109.429196,-174.021151,-120.56927,14.128657,46.059165,69.975276,67.926907,0.785506,-53.1128,-97.470388,-12.40248,25.076585,57.298365,107.02171,226.415221,222.442928,128.084871,122.071818,145.110186,234.326932,332.401337,512.879979,507.529775,324.018937,227.800147,173.497725,229.739615,243.893928,267.906611,297.653201,328.306099,293.025204,159.482117,106.911259,154.402369,315.438983,371.534549,355.101309,268.666378,7.325526,-111.049258,-189.054397,36.776352,175.55337,253.235197,197.517086,50.628772,-12.455855,-182.938501,-288.371981,-227.34722,-53.817416,-36.651539,-66.326335,-68.192858,-111.511782,-178.731591,-300.598498,-238.966358,-177.19663,-78.059383,-24.397326,-5.631176,-104.420113,-386.203543,-497.366606,-470.911159,-325.779256,-234.559597,-115.846871,-128.600305,-223.542492,-264.930746,-317.956641,-223.215069,-128.459971,-12.839786,-21.196878,-124.265448,-190.242589,-324.805351,-393.316542,-356.793347,-179.318172,-104.179426,-87.866229,-129.387828,-188.147589,-199.262177,-228.40722,-181.580916,-112.697179,25.090344,52.263979,-0.47504,-53.583503,-145.03027,-147.753198,-110.173465,-6.410108,46.313754,132.093077,147.182564,63.573073,-13.60131:9.281025,70.484599,133.289249,190.79053,175.050953,94.474123,50.804583,16.433584,103.416867,189.700995,317.507623,325.673971,325.640341,352.442701,387.863705,357.378583,256.581237,275.694335,328.096324,415.412085,438.578413,427.451979,393.291927,310.740021,225.645013,210.832144,238.930285,246.347179,215.830232,183.039265,113.504539,87.044044,61.606272,68.509547,74.706613,117.194132,172.899575,307.486296,341.672673,254.545774,38.766542,-9.270237,83.255236,161.617823,290.574394,326.696775,283.326753,222.142803,152.101959,197.666616,226.398542,262.966524,289.05952,350.389964,359.756422,278.218937,174.164834,202.901424,362.2514,412.650192,420.587516,396.181376,290.876029,222.290744,131.485376,134.32395,139.198103,140.984067,149.282237,138.619886,95.662165,-73.748933,-216.814007,-208.519159,-58.079506,36.352594,164.390476,151.941538,-24.119982,-119.549714,-168.939875,-19.76718,59.468744,118.646455,130.571571,181.763796,199.315533,131.048945,-8.267622,-16.1656,66.884175,91.487384,50.144307,8.328017,-14.414252,-19.16179,-164.477019,-242.670179,-139.877882,115.717685,132.399325,-28.451615,-119.769441,-244.017805,-288.894492,-254.309423,-132.679938,-101.148562,-69.834664,-45.288057,-9.848779,-24.860093,-138.041083,-235.721977,-230.00501,-97.747955,4.234388,170.732305,205.195879,184.229904,136.364526,154.054157,282.365961,329.285465,290.309786,246.993847,239.852963,251.185939,182.679915,67.948526,41.756599,61.858499,89.464786,126.379972,133.614082,123.61786,56.702388,7.990091,-65.529033,-73.504497,-45.369453,-27.496899,-22.462912,-32.236431,-49.306544,-89.956459,-104.983319,-67.420243,-45.439345,-76.549786,-124.593647,-235.000784,-231.513957,-182.487302,-119.685248,-122.640602,-105.36231,-103.130114,-196.83809,-239.434096,-207.803592,-160.781987,-172.664596,-161.995511,-111.163467,-32.309718,-63.803167,-234.217169,-324.130299,-289.177784,-135.180512,-76.98187,-107.863686,-195.196464,-321.444071,-290.097693,-135.678251,-74.500695,-81.484919,-77.830783,-64.596513,-119.753498,-191.546705,-318.065443,-315.928818,-245.091064,-53.155569,10.112774,16.870149,-35.478773,-190.975941,-255.603197,-304.526884,-296.454312,-298.626873,-275.25105,-226.7501,-103.237102,-70.531047,-80.476232,-95.231723,-72.630871,4.069171,38.329599,109.805402,105.523275,-79.024209,-189.078773,-260.095914,-171.497584,-119.844765,-24.566874,47.081322,230.304568,296.204859,258.138581,104.781735,95.96037,208.847667,258.15761,248.957679,192.506477,21.923485,-63.616472,-178.951052,-207.673777,-184.434467,-50.729473,17.587426,50.333922,32.69615,-42.202543,-182.077896,-215.313155,-150.437904,-101.935695,-92.912407,-118.024113,-128.62209,-133.05591,-234.468042,-351.718226,-381.985562,-376.676949,-311.56286,-114.800096,-64.726142,-155.424312,-288.325087,-250.278465,-9.256498,80.254227,31.003142,-89.349578,-299.36992,-324.218327,-360.725743,-415.23839,-371.630076,-247.384343,-210.334065,-128.121864,-92.064245,-123.52263,-218.956099,-196.096663,0.834781,84.391611,49.438265,-45.984589,-184.294449,-192.00232,-149.222205,-32.07822,33.947037,60.010643,27.491665,-41.469456,-77.800155,-150.966033,-180.574046,-149.795512,-3.622118,58.062241,51.817444,-5.991925,-110.571653,-133.535371,-152.632147,-138.631781,-115.972168,-71.511823,-61.466448,-68.84336,-81.236469,-135.691124,-185.193004,-158.442402,-51.281625,-35.06848,-80.750958,-90.875817,-30.818163,-1.919612,-31.955621,-43.868675,-35.705612,-67.427106,-87.168906,-91.031782,-67.787223,5.809639,11.036172,3.751885,111.026039,241.55213,477.411952,494.894063,367.119098,302.101924,251.482644,257.844604,264.067575,328.367488,388.105907,450.620187,434.798868,370.671262,346.960883,356.504145,361.405078,339.565659,240.501528,179.720143,84.76828,45.247238,-27.245387,-11.858055,30.217609,89.729373,73.92275,-55.011592,-124.394628,-199.085892,-230.210491,-224.036817,-204.030096,-212.935256,-225.47863,-226.130368,-266.106231,-300.865125,-364.469225,-335.806309,-267.665323,-111.96288,-91.274578,-179.822842,-235.548234,-357.140944,-450.162078,-430.470175,-313.584317,-264.7588,-204.156,-196.266578,-263.513208,-305.494715,-243.067369,-22.779303,59.772616,79.13238,45.802231,-27.498175,-73.928784,-179.01493,-160.556042,-102.037546,-11.129698,-1.040793,-9.342002,-16.618174,-72.919932,-136.692354,-298.431603,-318.138064,-248.839087,-55.993986,31.770931,82.301035,28.916272,-107.058182,-102.477573,-26.798314,142.559541,175.768545,167.933513,159.283685,135.117091,101.965707:31.430071,179.228464,264.986391,390.872443,429.033746,418.762552,346.651173,80.850091,-87.885333,-25.581655,289.867448,426.205236,514.064057,475.122649,320.837299,255.788752,217.009377,261.790237,306.291202,450.840021,513.672429,459.489382,337.647201,53.836362,-59.588275,-16.546584,163.617132,234.126079,227.5762,165.174042,42.572183,0.540083,-52.032546,-7.545094,68.347513,302.008564,407.759498,415.122618,330.536706,178.089049,97.779712,77.893837,143.485508,223.355136,350.916856,359.413839,262.822132,182.751527,69.105837,105.89754,149.861345,231.807761,275.651475,313.923904,273.371632,112.228379,66.804906,117.400112,254.088635,316.046782,407.256046,390.046054,195.80858,88.465983,11.175406,99.395458,166.258784,299.729256,343.170946,293.858851,202.198879,0.503194,-58.88043,-20.832218,105.685769,170.992486,262.052837,243.697713,30.278459,-112.889465,-232.557788,-46.932488,63.976866,157.676283,156.43206,147.226612,128.654916,-25.966928,-184.34288,-164.160119,16.369229,107.021829,158.203712,117.481209,8.67803,-48.649574,-147.300846,-75.598479,24.654516,212.204519,235.263966,54.183192,-91.973208,-274.126457,-277.185524,-231.573244,-101.017771,-43.890817,24.261669,20.152672,-90.664004,-196.129149,-414.935117,-396.395777,-280.650066,11.132652,138.767314,274.552159,259.539814,80.949301,-8.290973,72.503113,289.66905,322.420569,260.451664,230.744764,189.469802,137.800828,-6.119274,-49.966103,-26.350979,50.722983,76.825673,63.847685,25.594644,-111.317192,-245.171735,-243.413206,-100.472629,-29.425347,-9.488961,-40.086096,-114.767606,-169.425639,-297.702213,-307.647865,-254.252686,-126.53834,-93.173052,-121.632673,-185.38615,-356.259339,-371.377145,-300.928587,-157.276317,-115.177514,-56.716335,-62.980375,-191.793391,-261.07897,-309.453663,-224.216717,-121.60602,69.484393,81.496403,-43.246999,-130.067996,-291.399919,-312.777851,-230.774864,23.661841,117.364181,104.355789,13.917369,-164.231455,-205.850979,-183.602162,-82.518151,-35.344841,10.796455,3.613179,-67.64622,-114.957017,-231.620393,-320.198256,-274.924521,-23.427021,93.153264,144.248851,71.690155,-168.410596,-270.092518,-379.157738,-374.386834,-312.019151,-126.752625,-47.124904,17.043424,-15.715196,-168.708555,-242.845275,-198.336999,-10.476238,84.962123,181.011353,151.16409,-52.409499,-182.94799,-341.85132,-232.642673,-117.432551,79.483061,134.556538,165.75002,143.34139,2.684781,-102.431705,-61.29381,147.644655,253.396166,303.721953,208.217191,-102.892889,-230.385556,-307.072749,-180.238968,-100.328766,6.444019,36.332421,80.021517,75.938409,-67.909481,-243.515581,-248.948949,-116.805787,-23.311127,83.446095,46.954906,-148.252417,-240.999793,-329.95776,-329.11812,-321.97819,-249.685293,-177.933149,-78.101642,-79.690089,-194.388669,-283.334879,-212.194066,75.685121,182.890234,192.527343,116.816274,-105.902967,-223.279141,-364.956552,-297.214049,-205.314088,-18.354261,25.602965,-19.433557,-64.475559,-129.51816,-152.180767,-108.497141,37.13116,102.246295,173.871182,136.012621,-98.177919,-236.841617,-351.753396,-127.466822,14.720153,123.766666,96.262381,-1.194241,-41.752083,-98.250417,-121.404459,-92.117338,71.902838,153.453887,148.771245,73.049001,-31.574293,-40.758178,-84.258422,-101.688602,-40.525504,160.376424,212.205098,101.273205,-21.026349,-229.57248,-243.498942,-169.498087,14.61393,84.452528,150.994619,125.834893,-37.57413,-124.099102,-188.953425,-134.41783,-104.374611,-32.102638,26.870206,107.345254,97.733764,11.998593,-52.850081,-19.685222,207.434401,348.444191,486.40572,440.735265,227.031502,141.294819,124.222977,236.490926,290.443358,359.589276,349.992965,221.736163,156.500154,122.821559,158.502209,195.067728,313.135139,375.869959,382.251961,282.59703,-33.552923,-176.06284,-285.751191,-96.655263,21.397193,94.454598,59.534059,-54.323009,-124.309329,-266.092135,-303.877935,-273.225036,-171.341477,-99.991956,6.129177,-28.576632,-234.040076,-328.036953,-431.856215,-362.118448,-248.059858,-0.964858,53.770974,-25.169085,-124.421792,-375.521726,-575.643726,-578.034165,-345.858616,-188.030089,-49.751577,-99.626487,-265.01299,-314.897462,-293.88066,-94.02461,12.839049,113.642827,107.490634,-17.343369,-115.385645,-269.295908,-256.540949,-197.705248,-74.758645,-18.272941,53.146379,32.767896,-110.73904,-203.470426,-327.01513,-247.183753,-153.997511,17.594925,67.658763,55.900082,-10.63699,-174.590224,-186.4606,-122.037045,24.17932,76.268352,159.826086,185.689526,118.131538,20.331116:29.070663,28.226277,57.113797,129.760671,167.361582,233.805897,229.029826,145.378811,160.378819,220.041295,279.735661,282.806894,344.85656,368.193954,308.290217,256.593053,180.546767,184.856494,231.800965,366.368356,416.839077,433.844864,417.96025,378.116974,337.893132,344.281822,391.336682,402.348714,345.626985,290.404442,239.945524,249.144402,237.531949,143.07962,93.374416,133.494408,233.753378,366.174457,329.238209,132.957628,-21.173564,-38.840581,47.244976,127.817388,269.703454,301.758594,305.456067,300.951824,259.802442,201.310147,220.203737,353.407587,417.031919,449.501866,420.254257,305.514775,197.07205,174.665529,221.461509,285.447786,369.758782,341.955013,172.168367,75.765839,-35.544387,-14.630464,17.184632,55.692922,44.755888,-45.00193,-101.233555,-191.923734,-254.013064,-253.992625,-170.572714,-106.398456,-16.668167,-29.885503,-160.687862,-230.915067,-264.453493,-91.842256,0.292754,40.929632,28.888706,69.688805,107.106254,84.395126,-44.688834,-74.08268,-39.488613,-1.673143,95.135734,123.1061,54.438445,-34.613076,-229.801305,-253.248536,-178.66128,3.23912,45.254976,-45.052231,-140.455414,-265.667672,-212.416273,-132.373563,18.213746,53.865378,114.550871,159.581254,174.515842,133.081697,71.344358,46.13148,21.776667,65.411435,168.192191,355.352602,354.415323,220.029758,167.186718,216.671553,328.752293,326.832289,222.386702,166.43313,122.663959,110.576024,40.070616,-12.597938,-31.821125,-86.142319,-87.278268,-20.550292,-2.293644,-76.911607,-189.941743,-193.482601,-100.647106,-57.198885,-16.506424,-12.818744,-58.334274,-93.144637,-127.563854,-141.182555,-151.851039,-137.095941,-103.659544,-40.872677,-32.641432,-68.071309,-126.938033,-131.284079,-105.28357,-96.353636,-70.399944,-71.516782,-156.892622,-219.226454,-317.150757,-260.476718,-173.287965,-66.286897,-61.28487,-22.756357,2.550055,-42.87817,-99.665658,-55.539969,102.393082,137.724849,81.799516,34.214958,-13.7726,-11.834176,35.065525,114.271813,143.403316,177.824964,186.279754,100.901489,6.852487,-94.914795,3.609265,73.89817,187.220051,224.632765,214.638138,153.285476,-1.123151,-49.291692,-74.560252,-89.639127,-124.739522,-167.960983,-132.188404,3.673177,66.457885,144.672533,141.950205,137.175735,210.978003,282.45535,333.775915,264.09065,68.275282,10.555399,-34.141385,26.228302,79.901185,123.838143,148.544007,282.48377,338.207989,334.073302,286.0484,283.724301,279.798602,254.868028,177.869346,127.936205,-18.400678,-89.021102,-211.876677,-352.611363,-375.881375,-304.565892,-263.493752,-197.605567,-147.126743,-54.659366,-60.744675,-86.429217,-97.368666,-56.144742,43.498451,34.989164,-124.097553,-221.447997,-339.813609,-322.09163,-278.007849,-184.578674,-141.213597,-14.178166,57.002697,97.953999,19.390695,13.983177,80.176988,106.332872,122.024484,82.008991,-172.074265,-314.276328,-422.860396,-324.333876,-261.278625,-212.762249,-197.799147,-58.190457,36.81842,49.725639,-121.619941,-132.389125,-2.293054,47.172679,58.842852,34.90936,-44.71538,-73.219627,-51.140189,55.738326,93.781563,46.294639,-30.600501,-160.641442,-160.245513,-45.162611,64.603867,88.588021,57.346702,29.426987,63.293379,108.199563,127.465644,87.823456,-45.87173,-118.196811,-79.454051,52.285914,68.826036,-24.823992,-92.471915,-194.846346,-172.590862,-104.020723,8.23005,12.400232,-21.657639,-28.186413,9.854827,36.235366,31.610863,2.101485,4.80834,27.814472,47.847143,97.622076,103.462805,50.871683,70.696874,132.35051,229.706219,257.233187,328.320885,345.10285,338.83644,354.681593,357.508473,291.68246,291.956714,358.728806,383.268762,353.521952,323.062442,322.785367,360.758282,354.921119,276.666477,232.325397,162.203201,116.435614,2.085372,-43.02201,-33.054528,81.880271,93.966482,20.034419,-0.166693,-42.169495,-114.976759,-259.109718,-226.785954,-159.786786,-70.866945,-83.866275,-176.953233,-226.465829,-253.695005,-226.694069,-216.153805,-224.731877,-168.933538,-40.36356,-18.239772,-31.213767,-63.042989,-205.700844,-304.43906,-267.170764,-142.396233,-126.469671,-152.296097,-155.847065,-134.394152,-122.114383,-101.334901,-84.214705,-87.227453,-97.324922,-92.949495,-90.639656,-94.064735,-64.889974,-3.086826,6.333695,-20.651648,-20.5679,37.693806,41.433665,-68.866096,-150.1,-274.448974,-232.826672,-156.076523,-5.841471,45.216027,85.056845,63.448657,-58.440483,-150.803058,-128.81064,21.161123,100.915055,200.053208,198.023001,72.235455,-27.123626:-219.454414,-183.201252,-174.357438,-164.094908,-134.122806,-51.343052,-40.945791,-59.454231,-16.447023,32.968889,116.002425,120.552064,118.126986,137.51366,152.928739,124.499172,45.605656,46.240697,56.23585,59.649666,96.157103,252.395672,317.093532,331.981817,289.621184,301.971052,308.248536,271.76454,232.640768,260.445112,305.75379,271.093988,113.070981,-6.992591,-24.510028,31.742173,99.387405,221.139711,234.78555,140.170828,-23.630708,-47.946807,113.132954,230.372452,307.48771,272.217408,247.081301,269.73798,228.201135,94.422227,59.836068,94.638135,153.213407,296.833333,357.714962,363.54599,243.600875,237.973703,345.086384,372.621929,302.066871,239.911415,139.983628,103.1347,39.925371,38.961889,54.331908,81.808167,112.072321,148.568164,103.232794,-80.846087,-165.984196,-142.607445,-56.65627,-10.614157,60.054302,67.710863,56.516489,44.371063,29.597992,163.776866,263.213946,328.319126,295.770565,267.684355,296.553765,304.161317,143.46849,99.643682,176.271155,213.700667,187.735307,153.693164,101.139396,66.907696,-86.347718,-192.913184,-160.519491,-20.77226,24.505924,28.9118,4.224574,-113.131678,-212.603768,-186.269273,-110.342552,-118.121682,-101.853114,-53.774634,9.256033,12.214129,-29.548319,-100.783078,-110.255821,-29.840171,63.382867,258.57426,300.607015,275.911337,230.833673,211.455884,157.866692,135.670215,122.856469,127.208074,132.848722,118.634376,82.750163,63.190431,37.056495,35.416979,96.056364,183.160695,144.884926,16.500784,-2.795011,4.061714,-38.533386,-66.710041,-49.565714,-7.771338,89.607718,107.343789,36.709132,-25.234397,-38.537756,-69.301649,-56.898069,42.108445,82.554493,58.8802,-47.268052,-85.811865,-110.761078,-119.834505,-126.664774,-124.414436,-156.644317,-191.597569,-282.618702,-295.990061,-248.40857,-148.038638,-127.887551,-128.644091,-131.988997,-150.551166,-183.176584,-173.831334,-117.064907,-109.569467,-169.978341,-216.213815,-261.302042,-255.606791,-220.099686,-161.432169,-148.265471,-123.181106,-88.852953,-86.340072,-141.083851,-229.064953,-219.63721,-196.068171,-130.324955,-101.601227,-66.723369,-64.909735,-93.154821,-108.337869,-108.822104,-115.657789,-141.792633,-155.866327,-109.178693,17.816584,57.818711,100.499507,119.112723,112.543074,77.889268,67.889853,99.811785,118.027257,72.270543,9.490485,-90.981745,-54.839553,-33.024012,-63.91376,-57.073761,98.850598,182.255685,197.784171,174.828885,213.029472,260.835049,241.003801,204.317191,192.682127,135.940887,89.771759,-66.116874,-244.793947,-263.331247,-143.893244,-71.42406,16.976971,50.266741,65.862728,-37.232598,-87.277003,-122.842791,-115.84743,-57.240154,-37.38401,-120.973126,-203.382071,-310.037729,-286.466584,-262.570537,-230.601173,-184.294715,-3.21381,80.513194,134.140174,71.190256,38.286846,7.248182,9.493271,22.449178,-14.384622,-184.392536,-257.877519,-330.15115,-305.226167,-270.018475,-244.231334,-242.21396,-165.764076,-88.403235,5.689855,-83.333547,-110.003569,-9.829272,70.249035,141.633243,103.971725,-30.408495,-55.998732,43.88782,166.078832,153.141751,28.219756,-16.876561,-37.480328,-25.546963,37.977953,79.513622,76.328092,25.926831,-3.24105,-1.876628,3.429501,-30.991776,-49.93724,-92.133173,-99.018868,-57.778492,65.030339,119.537081,144.982943,109.049712,47.398995,81.219384,99.369664,60.969292,20.860925,-33.196877,-38.053737,41.92149,115.3489,165.908234,72.75849,30.394893,-15.633218,-19.993834,-4.529456,3.259759,0.288052,-12.27039,20.967275,190.47679,280.442905,388.257584,398.578562,373.002724,371.114941,390.901221,404.271602,411.068093,424.826459,428.899097,448.147876,479.348607,543.187757,484.410267,435.881545,373.475534,332.494861,208.216276,159.784381,115.83695,94.685247,38.886638,21.569065,33.986121,65.990142,73.500711,52.604428,17.206337,-78.566061,-155.793503,-177.082179,-153.819036,-114.557412,-84.029877,-122.935956,-230.832409,-257.360748,-263.210216,-220.779326,-192.837145,-144.724492,-111.127531,-73.287444,-101.325591,-236.038919,-330.80107,-280.965682,-51.477246,7.047958,-83.986799,-155.340171,-207.931599,-197.274503,-156.23243,-102.264814,-76.694608,-81.165542,-107.496577,-136.609685,-126.939034,-104.021165,-106.604335,-97.619135,-31.120524,9.977196,30.543472,1.240094,-86.050644,-143.008325,-261.234657,-224.564163,-153.784291,-38.101391,-12.985605,-20.223075,-33.065232,-64.589313,-110.948088,-93.274632,32.990815,89.271042,114.267002,81.638172,7.457385,-2.360951:127.990472,251.140807,317.74075,396.787368,407.056748,382.893597,324.900617,146.315762,87.183691,123.817916,240.279224,299.718108,410.86157,438.989809,407.323351,364.541834,251.457938,231.171484,294.956782,445.477253,479.738561,427.893419,358.443934,202.710701,111.60356,130.853476,240.639187,274.204375,254.539925,216.972051,131.53724,103.110749,102.412658,170.180227,228.952757,358.582557,405.612312,409.871865,364.471363,229.17301,101.331293,62.765798,98.607803,179.675421,372.801384,425.283987,398.29629,352.67484,249.504356,215.206257,262.813084,395.880906,432.626035,399.732259,339.647425,192.314978,101.161587,116.583047,228.816291,280.027881,347.069079,355.98427,239.51557,121.133016,-28.677751,62.758464,133.843984,210.089231,209.454108,144.638929,81.950237,-103.851637,-225.1083,-199.099727,-54.665845,8.710058,47.81435,1.2895,-165.123162,-231.539827,-289.273592,-180.975023,-67.323085,55.547155,36.121072,22.303419,59.950787,59.819722,-70.404451,-94.562945,-72.467563,-58.743013,0.114875,26.588236,-20.534746,-86.633366,-206.697533,-208.765246,-154.091467,-8.184561,20.56477,-86.91014,-182.612368,-315.301644,-295.573282,-223.21002,-47.667368,9.041195,47.635366,37.017956,-14.48994,-40.140277,-122.416195,-191.964896,-158.866364,51.696548,180.472628,332.01178,323.879725,185.457191,40.614088,30.658178,142.273164,206.785638,266.386599,251.687407,161.543209,133.985667,137.930472,65.951671,0.809195,-25.673313,21.960211,67.166592,21.833689,-126.157275,-218.287745,-216.271962,-147.873429,-122.078048,-114.975657,-111.319441,-98.395263,-124.243718,-260.460607,-280.48873,-205.836489,-75.255604,-83.502278,-182.230065,-217.631914,-255.649977,-298.712958,-269.212967,-120.656922,-79.059474,-92.232833,-112.33347,-200.23999,-284.46415,-406.991319,-240.537585,-106.228079,12.489302,10.607885,13.476943,-5.699698,-153.979448,-291.929309,-274.549964,-57.793186,67.00028,152.335007,95.273458,-74.039654,-105.782656,-41.001713,46.453842,75.849358,125.884134,141.777516,98.944717,43.645746,-79.26599,-117.147786,-70.392909,103.082158,163.416151,110.58159,21.822871,-135.240842,-172.1073,-198.613095,-246.294569,-276.096093,-276.155725,-226.599902,-82.728484,-32.855911,-40.674193,-150.175344,-161.24512,-0.408118,114.009845,216.541356,177.331825,-24.298228,-133.897927,-216.709411,-120.053862,-72.284142,35.883436,136.283129,307.353227,319.172285,281.543326,224.421739,188.748235,193.428836,224.905767,211.917168,136.604597,-78.403789,-158.87722,-219.629548,-216.497256,-224.836589,-226.917821,-179.86782,-59.803929,-44.866762,-121.379378,-273.659087,-303.52436,-140.107998,-19.964242,40.436285,-13.180912,-127.170488,-177.675631,-330.518005,-471.190603,-485.700837,-354.422983,-232.291435,-72.934609,-66.338594,-82.21296,-81.215955,-75.749931,1.613957,74.279954,168.372386,118.782182,-172.513267,-298.556672,-354.604399,-275.137577,-193.707984,-12.226086,37.489947,23.174556,-18.97555,-107.129718,-154.268581,-125.186287,30.392282,109.12286,187.129006,156.685162,-53.780349,-162.842832,-179.12533,19.974434,94.83089,91.563545,41.622621,-57.014567,-72.276506,-15.179285,-0.593684,-12.128551,52.960347,109.168252,177.968907,186.157914,131.449081,61.834212,-99.694552,-104.058716,-31.138248,98.1367,114.814926,70.355504,18.075998,-112.300001,-143.382386,-82.505989,83.855711,118.661226,65.407669,21.130457,-12.05307,-0.815852,20.894452,24.943119,36.535829,72.642897,95.514097,111.067722,84.430074,37.131915,75.950677,126.463971,250.37288,298.547466,327.940764,299.473147,194.728794,159.193592,193.021138,283.484842,288.946174,243.346234,246.516839,300.817122,313.050696,301.966654,275.191471,264.322352,247.106559,244.244895,225.06513,168.491733,-21.288608,-93.108567,-134.450773,-36.079833,33.182584,48.642987,13.480448,-32.331487,-74.59838,-246.8456,-300.954632,-226.270517,-56.996997,-40.000904,-118.882726,-159.692711,-194.564281,-212.901359,-264.219714,-226.224301,-178.181169,-89.935026,-41.291147,-33.595963,-122.920726,-349.387952,-393.134235,-338.459369,-211.645462,-174.169168,-133.983069,-129.663321,-154.497093,-164.262004,-133.549023,-2.53509,77.255345,135.913701,106.711239,17.535881,-13.396152,-15.331863,31.268654,52.319494,66.593577,57.987541,38.518762,38.87897,17.178294,-38.047482,-196.999478,-238.370208,-195.652762,-31.38515,49.094577,89.211577,53.85939,-38.488079,-111.118795,-115.013145,-19.1744,66.984202,250.581109,282.381426,92.96743,-59.965391:forward
10.869455,136.777619,163.369619,138.449958,111.723303,43.934893,19.280038,10.808097,15.257025,25.056985,50.517623,56.489852,-4.69541,-84.203187,-227.594481,-243.244037,-167.580497,-71.122409,-62.212359,-82.594193,-75.430158,-28.693096,-7.512186,14.06176,35.867298,59.846577,132.324648,168.41419,194.111116,173.347415,58.398593,-33.466895,-183.00246,-157.882783,-97.324553,49.487637,94.022128,50.562368,-4.802895,-63.9152,3.623076,68.211679,137.770162,133.827213,114.269411,103.419225,91.384564,103.595842,178.373535,244.148451,232.303817,173.652793,146.963087,83.235226,45.803255,-71.067528,-168.349911,-164.974794,-113.075356,-99.477877,-133.551514,-161.974382,-170.7646,-156.934028,-123.331016,-97.72955,-103.313702,-96.799169,-86.493528,-139.203925,-195.699441,-302.178749,-265.66992,-151.54419,119.135987,187.804258,154.790189,116.96338,87.965504,56.192226,-33.222381,18.385207,75.96444,133.259152,110.715704,-12.987097,-63.888548,-74.99004,-48.591087,-54.556063,-65.784238,-34.363882,49.389642,55.394408,10.5668,-4.45185,14.604771,-6.828482,-60.095349,-140.758184,-150.585817,-229.031054,-293.115707,-289.184625,-184.064711,-201.493166,-304.932978,-300.916241,-196.020541,-156.930222,-147.675502,-155.819095,-120.232989,-50.723566,-32.255891,78.347972,160.171627,180.637368,131.091743,65.252696,18.604113,-24.52083,-111.199438,-118.190483,-30.919666,27.245498,39.758047,-13.912605,-104.960133,-83.047951,-71.473422,-70.677573,-53.918862,16.917254,43.420922,35.198085,1.357933,-2.395345,10.85754,22.667556,34.39767,35.999825,6.19189,-45.345036,-164.95021,-167.272952,-92.308255,138.382212,195.930447,57.661195,-93.571633,-364.541185,-382.767408,-303.484581,-159.390979,-130.440493,-111.76117,-88.40126,-57.635748,-110.593925,-280.148042,-252.840465,-183.630259,-100.996376,-92.10032,-76.965445,-87.431635,-186.754382,-188.714553,-118.92439,-13.092148,-25.54938,-124.92071,-157.575558,-151.472199,-155.468411,-194.091059,-189.261416,-170.751526,-139.965786,-138.683449,-96.997923,-57.66625,-79.833079,-139.564793,-114.020326,-69.681794,-70.604245,-10.725764,32.09804,16.30988,-35.753569,-168.354636,-265.467953,-255.273777,-117.518151,-33.143714,80.033008,91.291233,-17.440967,-192.604026,-228.747119,-173.38683,-113.10923,-59.150716,-91.010633,-207.975624,-246.419991,-212.536161,-150.611494,-163.818725,-190.362196,-161.856412,-99.56227,-102.345086,-149.129028,-208.050257,-246.934645,-316.155873,-327.435509,-297.923635,-267.52733,-247.528508,-277.271409,-344.744677,-319.748494,-272.836136,-182.079489,-170.284027,-217.902863,-272.030235,-401.767507,-408.520062,-346.755737,-164.097118,-78.204634,-35.090885,-79.207596,-188.84337,-228.857068,-207.931817,-77.456457,-44.966252,-49.474745,-39.946463,12.426573,22.016057,-8.807473,3.911755,37.164588,91.24724,115.162881,181.828941,210.478132,213.156336,186.474126,180.595399,319.694034,393.440345,425.452521,374.91658,244.187101,212.256843,162.549659,30.08913,-35.207116,-19.638032,56.898377,151.764443,127.626473,28.891282,2.700258,32.517849,147.17374,217.549059,312.602769,298.417196,190.442667,162.364456,172.35168,193.219836,192.571841,143.09154,130.300939,209.298744,258.608428,270.558895,258.06026,291.490195,407.132872,474.261151,548.406355,522.723625,412.372486,388.960519,392.887684,365.468353,353.524145,353.135894,344.148868,308.296551,318.502155,349.819633,310.023475,173.399422,124.159184,131.752756,208.723678,248.019782,254.764128,252.974778,267.461207,292.115295,319.295435,390.569814,420.277727,388.537259,316.006161,171.039685,132.397991,116.059291,167.013411,185.17813,154.37994,130.881925,174.82386,239.500273,325.909685,362.276429,393.881169,428.430338,412.193345,296.073424,191.78337,-14.18406,-47.082864,21.367793,64.85336,89.126516,207.140658,244.156302,178.668871,109.654651,-27.298573,-113.175954,-104.506805,-31.72205,-9.549447,-21.279282,-33.069488,-58.803784,-93.42999,-173.168696,-170.610747,-142.882421,-78.823682,-73.544657,-116.69602,-118.871148,-92.53194,-96.316904,-86.584027,-17.576893,20.412478,37.855647,22.257676,-30.733908,-80.740741,-171.262931,-89.364273,19.423054,206.64483,215.141574,140.907974,134.345266,169.030063,180.363735,191.103915,231.018359,271.497723,367.90787,365.742926,260.935606,210.875008,128.182099,5.719009,-55.325794,-78.648925,-27.802203,92.425575,97.548084,-10.568489,-29.690814,28.894647,178.748704,254.757995,348.817718,340.371519,269.745302,226.325095:58.865421,238.458126,286.524881,292.646149,244.90934,59.832398,-18.826385,-42.229857,58.3515,110.543464,149.163336,123.749882,21.165595,-26.489713,-124.530715,-184.663637,-227.548617,-92.89532,8.150475,119.474005,84.539742,-29.812659,-22.766727,105.671958,197.372404,188.705888,129.854829,142.465901,241.953745,244.662923,83.931847,-5.008798,-39.072077,19.497825,43.303544,119.43187,167.55811,215.38432,190.626082,69.873531,56.908252,120.695107,220.934979,207.183096,105.344715,58.568763,37.105858,62.196601,134.939585,223.976119,278.608996,310.239561,243.656101,45.258506,-19.53266,-56.264751,13.00305,42.506924,-22.233144,-86.70444,-160.580681,-152.913617,-84.925152,-47.661177,11.989233,-43.968457,-109.42171,-145.095619,-117.810304,-115.456453,-155.153848,-218.152168,-163.621132,-108.022534,14.822955,62.65581,86.038804,72.435441,51.207095,47.532519,66.35032,100.660303,94.700565,78.549866,87.353788,76.009675,43.323429,-6.651846,38.25569,71.448597,132.026066,179.169422,236.232915,213.113071,134.27853,101.503712,45.487571,33.1089,38.226652,24.860824,2.186932,-96.48708,-178.295161,-288.571703,-214.160814,-182.99203,-222.010119,-243.119497,-237.223966,-236.042436,-244.129772,-225.063421,-108.507328,0.398849,10.901668,25.371456,46.203283,39.954817,5.539422,-71.883622,-96.439133,-75.787653,31.028807,89.828078,111.731478,77.614393,6.928418,-16.949816,-42.00475,-49.482274,-54.248418,-66.520763,-70.051126,-48.854092,-35.677157,-54.165781,-54.671625,-25.015368,59.985981,89.07297,82.107628,74.089925,71.112506,50.116314,6.533548,-10.343357,-16.569499,29.834956,59.12381,30.689331,-40.51094,-208.932665,-234.077042,-202.429925,-122.263934,-84.796076,-48.916439,-56.82405,-122.031238,-176.682484,-239.456191,-174.385669,-156.254033,-189.891733,-196.333887,-146.756735,-123.879922,-135.888729,-140.526174,-119.327064,-82.20562,-85.573626,-145.247522,-182.582102,-216.08522,-229.640879,-245.04105,-200.115127,-188.13299,-197.622789,-205.899687,-200.006229,-188.111615,-178.616242,-147.404484,-128.491802,-140.66695,-151.527651,-94.008995,-51.299785,-96.081373,-185.382972,-316.74171,-275.200403,-231.093421,-183.10363,-174.858422,-125.400527,-93.782301,-88.317902,-150.156403,-188.879374,-214.547322,-169.145993,-60.687475,-56.730248,-121.847543,-161.487983,-213.112195,-224.396248,-222.550094,-173.388946,-127.5738,-43.879056,-18.761643,-46.148846,-189.675915,-264.109313,-338.925192,-344.443719,-330.758598,-310.871333,-269.249903,-260.796449,-265.22527,-267.304298,-235.239208,-135.327226,-136.623785,-278.770063,-360.001604,-458.717346,-431.067103,-355.703081,-171.285186,-115.47734,-130.859622,-176.035907,-250.443738,-260.794505,-177.922582,-40.977742,-8.922842,25.770946,47.281558,62.498805,42.961022,-39.951016,-51.664828,12.807552,173.222277,208.794429,188.337488,162.841702,158.187679,188.181519,212.372161,175.204984,186.745843,207.738773,164.164683,24.735498,-11.687121,-0.566244,5.077475,-4.02388,35.333223,78.31864,85.499205,49.074466,10.982255,24.290913,75.456057,136.181143,177.33175,267.344819,287.166265,195.857953,104.052744,6.620193,92.727483,138.119052,145.745354,135.285682,135.580372,128.80798,103.341849,111.301039,191.363561,333.411736,410.221423,501.396837,480.411217,345.721037,305.162472,310.763704,273.44048,229.804265,188.457944,205.939994,258.728095,282.169778,276.462403,218.306945,105.664142,139.727937,186.026365,303.715478,341.502828,285.701584,222.752591,171.932304,223.237203,239.95791,276.036006,311.560265,316.304681,262.840317,149.567945,122.613502,112.463095,140.250005,185.617096,282.061248,286.280581,205.510771,171.383881,183.040736,205.529479,215.747629,308.938414,362.985562,282.308853,142.74868,-90.632153,-112.315277,-45.127688,2.403443,29.413634,84.217711,78.104184,47.260966,41.249752,-65.499996,-186.541167,-142.500467,36.378281,56.449606,-94.220585,-191.303658,-288.812515,-276.891782,-134.928108,20.893328,46.652714,11.892962,-17.486092,-33.587723,-23.344899,-32.771901,-70.877109,-57.689522,19.476224,24.362585,-60.220321,-87.45157,-74.800554,-74.981393,-56.382906,47.177205,97.91635,150.096402,135.534268,49.412949,21.972074,52.55574,82.661604,58.128415,10.885324,26.374786,82.803951,85.330728,34.841997,13.570645,15.428726,-16.217778,-57.312392,-111.798019,-108.951891,-95.552139,-96.039824,-88.17276,-82.381459,-76.675061,-26.687662,0.999853,7.063067,-8.540009,-44.656514,-67.675618:-59.396818,118.224401,163.111182,188.458806,165.681433,17.887146,-74.705072,-123.268474,60.512648,154.6569,189.920309,139.75862,24.920133,-9.678933,-73.659003,-115.072716,-162.129306,-121.808869,-59.795503,95.083876,116.219123,36.520231,21.129132,110.530215,211.262842,227.535423,216.315636,206.061968,191.253995,191.244445,171.422699,124.534135,28.226341,42.795809,84.197454,227.650066,291.104557,269.290443,192.62668,73.510138,113.897984,143.577234,102.47099,40.820625,-71.466055,-89.024473,-44.135114,-9.938783,69.08222,165.360013,203.890387,203.879895,147.965879,19.221312,-13.696513,-44.217195,-19.449893,6.178475,16.19483,4.905067,-22.896641,-34.864087,-64.999698,-74.022411,-48.030438,-54.653507,-76.877876,-84.196779,-75.498872,-81.52454,-103.682947,-148.135986,-91.090542,-45.953078,3.227228,16.822206,9.410984,-27.933517,-113.89295,-121.097114,-45.761373,11.544655,13.329811,44.181028,65.07841,22.068042,-47.338994,-173.026565,-160.131064,-109.644276,67.905587,167.372594,247.013446,216.420446,93.056502,37.310614,-4.840228,-10.067555,-12.359776,10.817179,7.024163,-86.74168,-148.365582,-184.3904,-120.185366,-137.595589,-257.071157,-274.916112,-221.970385,-204.500767,-187.781199,-173.008737,-140.626589,-102.740968,-66.751968,16.177625,19.597588,-50.215986,-85.197801,-134.235999,-151.827966,-132.420781,-28.97412,28.137871,63.116769,33.8716,-62.182313,-101.34241,-131.607816,-191.245049,-240.207023,-253.048074,-206.686279,-111.565461,-103.834609,-144.712698,-155.85008,-140.140642,-23.447985,58.918706,119.482701,93.679992,45.848804,51.481929,101.840996,112.862271,101.542664,81.356681,72.618622,51.772605,23.311786,-80.375327,-147.661944,-134.61108,-21.549261,16.129224,-50.992662,-110.761534,-225.11815,-287.821732,-314.621729,-188.32149,-139.938461,-120.264819,-122.92686,-144.818835,-189.357067,-288.713468,-216.462453,-140.011539,-54.903242,-73.66591,-171.553144,-188.059491,-180.976175,-222.012196,-319.036104,-208.591513,-112.417235,-43.742229,-82.723318,-176.429717,-191.988121,-209.841895,-262.341032,-255.786482,-147.723742,-93.430968,-59.288748,-74.770716,-141.297266,-186.243277,-256.820605,-259.389742,-254.050718,-252.327648,-255.404171,-247.614891,-226.083627,-189.101445,-201.584565,-198.753724,-110.051108,-54.337747,-50.579167,-93.973706,-173.887109,-196.049032,-193.52024,-181.99429,-175.095004,-86.375462,-25.461352,-14.945582,-64.551883,-138.167821,-158.729019,-181.704562,-215.480859,-224.245649,-285.254845,-314.369653,-281.087869,-246.136472,-228.985574,-218.229647,-198.110956,-194.133363,-230.655817,-297.41583,-299.461541,-313.41523,-301.752777,-252.070053,-137.115343,-122.57159,-221.613924,-281.384866,-278.507746,-224.317233,-106.968321,-48.770346,-41.545339,-26.866386,10.894919,142.34391,167.429542,46.198226,-35.733072,17.603951,169.060516,201.209341,193.233305,197.250671,245.291879,266.731491,283.123456,278.233962,261.578374,172.466163,120.198561,64.473255,56.154821,91.966259,196.538321,230.560481,262.057199,285.828839,316.263646,302.452977,235.927128,203.012252,194.91554,277.809202,311.683709,275.060819,215.055317,116.888051,91.48377,61.478039,80.012317,112.136214,194.882895,218.556802,172.547099,110.832724,22.505782,35.857492,122.621509,168.061179,196.427951,286.19954,312.53268,327.776912,335.297202,328.762838,287.946291,263.503754,259.025898,296.572595,352.985584,321.210512,181.092359,115.621627,79.097715,184.105085,242.732072,295.792179,267.113405,130.465188,77.468705,31.910305,20.462558,58.711372,213.281063,259.08196,204.365071,134.36656,24.119017,16.243081,66.730953,114.522137,155.0866,233.17971,207.068964,54.527038,9.070543,-3.999837,-28.039705,-6.037725,129.871826,181.875066,140.774957,49.423162,-179.508399,-247.347886,-198.635057,-18.4153,69.187764,126.266923,67.15895,-108.584645,-156.17328,-156.571457,-97.159054,-40.822056,84.700027,101.151256,-39.509048,-135.275087,-191.14481,-165.641977,-82.842963,57.70517,130.20245,148.613767,106.592149,66.168898,67.433841,68.724223,98.461514,121.007155,158.896881,155.741531,98.274761,63.957381,-18.193451,-52.189083,-2.228615,121.994267,154.896666,164.362595,142.685491,87.736622,83.54767,110.806149,104.41184,65.412067,1.724651,9.906749,43.898747,50.687342,28.889715,10.393484,19.226337,36.766506,25.081729,-27.426675,-69.865085,-160.009782,-181.775916,-136.165891,-29.596712,4.561008,29.166556,32.25848,39.10428,40.285752,4.260666,-27.913034:-120.75105,125.37173,209.469499,198.010495,136.056484,2.338319,-34.277669,-46.041311,-29.663483,2.70117,106.530782,132.738717,43.18094,-38.975568,-138.00758,-147.651414,-122.441804,-65.16653,-42.111704,4.906507,37.842965,67.604362,46.426316,-6.617071,58.707882,124.299677,214.205018,207.90172,100.195315,50.410122,-4.695097,-54.121881,-162.762991,-113.759007,-27.242438,127.82748,146.320163,90.453956,42.237501,-34.906733,24.264973,73.210703,120.075281,129.466728,88.141789,37.789433,-7.307526,9.814223,65.472762,112.764863,138.365354,195.360329,197.727989,99.040955,26.797845,-69.486139,-91.934789,-98.73833,-80.460366,-51.014089,-39.947473,-69.087142,-127.534428,-123.554252,-69.919078,-77.134551,-83.031177,-37.706967,-23.708546,-89.609506,-134.051373,-183.452664,-172.259231,-119.815142,33.863378,90.765654,93.147187,57.022159,-34.672029,-100.533994,-195.420636,-136.482789,-80.286573,49.128305,90.895438,35.631637,-35.08278,-140.903015,-146.027219,-128.340192,-70.783662,-9.57022,124.263418,125.202631,-33.890961,-111.87348,-102.707727,-25.918462,-25.481697,-74.40613,-113.507546,-209.725598,-265.419811,-352.005013,-298.127334,-249.101137,-225.339625,-234.468148,-238.171902,-233.752136,-254.800782,-292.217592,-286.13543,-91.614134,-14.327277,26.790141,23.476278,-6.123481,-25.611032,-56.981788,-85.598487,-91.89325,-59.362801,-18.920791,19.428384,-12.686166,-109.010689,-136.636627,-127.835484,-93.636872,-92.527312,-76.925199,-53.729552,-58.422904,-106.34998,-214.598014,-217.911129,-185.961904,-88.879359,-30.719675,34.664382,42.980272,80.666877,98.249436,79.885075,32.363179,20.61763,71.812459,112.398174,84.586032,3.015082,-208.172338,-277.670035,-239.656465,-150.055309,-126.843247,-107.430679,-96.92062,-96.471281,-143.010921,-272.817911,-223.458934,-138.106795,-2.000005,4.874046,-94.832213,-170.933264,-303.913287,-299.064396,-243.752446,-145.012395,-122.723529,-93.822536,-85.715839,-117.230125,-151.551308,-172.721165,-118.197348,-123.204802,-210.424529,-233.999678,-189.174421,-160.774112,-170.78849,-161.366751,-113.504173,-16.546064,0.533655,34.514042,70.313322,31.796117,-73.625459,-235.259414,-197.209518,-161.815824,-77.800496,-21.381858,84.147684,104.266742,35.992329,-60.565069,-85.719607,-86.294388,-53.350502,-6.498383,-37.097751,-160.90582,-204.180899,-198.023707,-194.743659,-215.156523,-172.750578,-102.263587,-3.29755,-8.933232,-92.087328,-195.410998,-249.102794,-283.697571,-238.604593,-162.054421,-180.542076,-242.719227,-243.908447,-199.955501,-175.172276,-176.916707,-179.058689,-187.328067,-235.453288,-270.796362,-353.163494,-365.237167,-313.503855,-140.148407,-65.953396,-98.332467,-193.093624,-300.487362,-280.219532,-175.66175,-92.7011,-75.883487,-44.867988,-34.970926,-45.023186,-47.103832,-41.911244,-31.594979,0.116087,115.56565,172.715838,222.337642,220.15717,225.082807,239.417345,281.317513,339.640817,367.252076,365.181443,310.177552,162.10761,125.268879,101.777206,64.511764,64.376353,127.134745,173.280527,239.107127,255.809936,254.84816,221.656804,174.644075,274.387406,331.375276,406.813881,418.616224,332.569624,251.509835,131.589862,120.792502,138.435265,198.535001,239.469163,258.989957,220.517666,162.358535,166.934758,217.386097,317.298499,386.41294,498.676022,501.110615,441.91774,423.650951,418.307829,372.521217,332.907075,301.360787,316.740477,340.425595,329.00034,237.875871,163.263775,64.811684,120.811195,167.447824,222.029296,216.111686,114.695711,56.464333,63.618997,205.173556,259.119119,285.254479,277.002901,245.71913,223.363118,165.778872,118.210016,13.820398,42.683707,110.151418,216.869194,206.265352,100.526012,67.552453,68.157302,113.498646,140.487636,136.432064,111.619215,50.285286,-2.54748,-187.374358,-286.171535,-319.854092,-103.521787,11.569987,120.05521,101.911046,-21.189385,-71.603352,-113.06642,-104.99845,-64.727315,44.131005,65.665935,-26.928332,-111.545452,-215.541241,-223.500408,-183.460148,-84.644613,-30.249563,26.829425,12.193723,-33.685614,-27.497224,29.162973,100.7222,120.392417,113.665916,102.52405,85.805174,74.895757,26.049149,-11.063689,-16.10288,105.638471,156.79589,202.996459,206.688412,208.951668,230.964175,279.877654,242.121032,218.681004,222.46271,245.143539,287.517384,277.260274,201.306323,161.935231,104.669355,62.333896,39.719016,7.08364,17.702189,75.796182,72.994396,-8.896725,-3.944794,56.227303,213.277935,270.317147,310.55266,305.889103,239.020307,173.540833:-174.832013,60.287734,136.4657,157.245797,120.334625,4.392509,-54.056613,-158.472545,-134.987298,-51.629766,152.97544,217.813217,161.541375,44.044244,-186.72984,-220.282417,-144.592381,-45.751237,5.441204,85.66643,84.246795,-5.475391,-59.043219,-99.730038,-29.218228,30.685564,151.549356,180.125517,142.518595,115.184799,53.949877,-15.760467,-165.198929,-113.619007,-2.912294,202.582711,235.378948,169.566805,85.605061,-94.558296,-88.2914,-34.053968,52.565921,72.847869,31.540665,-37.826276,-180.585234,-195.016102,-69.96207,108.025282,180.171649,256.887441,233.602277,80.47906,-26.43881,-187.083594,-117.152601,-42.572663,51.246924,67.915075,37.916023,-9.211442,-118.616715,-152.871376,-142.345924,-69.164372,-29.727032,35.239624,30.159582,-52.164853,-94.939424,-156.079443,-99.781868,-25.859923,77.232723,79.215072,24.100007,-19.100584,-113.519032,-146.031761,-165.655088,-145.020645,-92.537437,77.905622,109.482926,-6.756529,-90.375596,-174.598309,-133.370036,-94.76033,21.55049,94.108643,152.013458,115.124226,-33.979998,-97.989599,-85.527091,26.634201,61.968298,82.944128,60.777211,-75.836997,-170.118253,-277.751751,-200.560531,-139.945083,-94.459522,-106.883332,-105.521803,-95.123375,-149.884047,-207.4214,-251.001438,-144.357578,-70.351035,30.038733,37.236828,-11.890637,-40.381064,-85.195214,-85.457396,-45.969287,72.924155,121.197143,136.310839,98.941375,-31.304679,-101.249287,-147.953899,-46.614665,8.353965,29.747185,-2.551237,-68.356982,-84.080411,-98.305109,-127.806244,-139.34287,-62.269777,16.059735,133.929895,167.347476,206.1673,207.623043,189.273359,117.594762,90.57515,160.632153,204.519582,114.588467,-7.932982,-193.090325,-155.59227,-100.405008,-5.001983,24.169265,28.622582,10.34473,-36.630428,-62.791156,-125.801949,-146.593763,-104.32693,40.376396,60.881035,-50.77657,-122.644226,-187.890305,-104.692215,-39.27803,17.122147,6.884587,-2.576916,10.275059,20.23497,-2.45985,-58.383445,19.793524,107.653608,180.820232,112.536424,-92.024273,-139.68165,-104.589218,-26.690891,-7.54974,23.22656,67.369027,157.944604,158.262454,55.3449,-28.606655,-164.502316,-133.993448,-63.986147,41.779447,44.531582,34.191901,50.685552,96.457755,115.529759,109.536352,119.940577,141.809477,104.405019,32.7555,-115.999885,-156.506254,-148.901456,-121.693653,-100.086917,18.139073,77.683912,64.487708,-10.272443,-135.743074,-111.901307,-90.430765,-75.149485,-69.432564,-78.490367,-88.581977,-77.582069,-55.317904,-2.011501,20.478096,26.941629,30.686708,4.692517,-94.960786,-145.259064,-199.749844,-163.822667,-138.214868,-71.638525,-18.247203,2.417406,-62.70019,-220.942965,-257.981783,-196.235505,-45.284984,26.679475,122.593286,126.305817,93.227302,75.0583,-2.15044,-24.61804,27.686145,151.068303,185.086655,216.910675,214.226324,196.280682,212.986616,276.853609,281.587817,273.090723,235.812688,176.901151,18.748148,-20.287056,33.96301,93.082054,87.734141,83.861556,100.144043,157.261662,178.249484,93.457087,6.587249,-6.338495,142.1804,173.489371,183.868264,182.818658,109.454908,40.642265,-55.222782,-31.578288,2.92199,72.888124,90.028641,53.932974,16.265817,-63.745628,-86.130869,-31.165615,79.037929,127.686471,216.773047,243.859155,214.954089,157.394717,71.93341,129.872013,167.365481,227.661262,249.588615,190.3541,121.91985,1.568758,-30.1279,6.826065,94.743193,119.964673,131.051838,106.733655,11.263879,-35.11341,-79.330163,-11.565036,44.934204,172.319273,234.797834,220.052156,135.777056,-1.836409,-13.747099,16.271227,69.143081,135.465436,257.421699,229.20666,24.971921,-50.940844,-33.568835,33.391753,28.376137,26.975993,52.092228,54.349231,-12.432859,-241.827157,-317.870887,-241.820063,-42.818856,34.554974,143.986938,158.14562,47.151628,-51.192361,-164.201412,-69.093026,20.30104,174.450211,206.680119,145.47166,68.015495,-122.825254,-190.459954,-104.3002,136.199543,187.119766,129.891898,84.068585,53.467473,41.37776,-6.010161,67.033861,122.306605,131.972079,95.383105,6.930541,-23.048993,-60.515834,-83.259084,-79.556266,-0.224647,27.57263,36.471058,36.691806,60.023831,58.529586,-9.2631,-34.677067,1.282568,91.03384,101.107332,55.564923,30.820559,-38.556521,-82.561618,-75.960101,-17.174037,-35.686763,-124.344524,-159.273764,-206.155765,-236.133966,-292.469172,-224.340151,-140.113185,18.549054,55.430184,39.924793,7.872099,-87.444285,-140.728797:-113.72972,83.625083,130.509833,136.77097,133.931369,79.038644,22.787646,-84.514897,-80.083212,-25.010827,81.082139,104.394044,82.577918,36.106293,-59.940258,-73.322635,-18.604244,19.699461,6.763349,38.425687,82.564461,17.981402,-88.942064,-168.576847,21.70086,121.299709,209.699224,206.505613,142.675738,105.078306,42.023576,-7.630093,-178.179931,-253.879878,-167.990953,128.810486,199.771211,68.035457,-37.945091,-76.943961,105.100821,182.808733,188.588199,162.388543,169.242679,183.320129,160.24856,121.86853,68.226952,113.123539,158.94007,240.141698,227.267856,74.423725,6.78216,-19.02817,-39.509406,-60.67279,-34.010351,3.896564,-14.733618,-70.486975,-104.95079,-84.722293,-87.966796,-116.650251,-114.266874,-87.068647,-84.855406,-151.303762,-208.095055,-272.504228,-183.270497,-96.222623,78.555932,143.498137,196.427475,189.973112,130.094399,70.49597,-44.131546,-9.084068,54.172934,112.222013,67.323866,-75.496406,-120.477289,-173.685576,-197.87194,-167.573434,-37.030544,22.143364,50.029178,24.601351,-41.81987,-66.031251,-40.809222,62.212128,77.467879,-19.483066,-107.469823,-258.765702,-269.38569,-155.267157,-50.43819,-42.019525,-53.059021,-47.91669,-18.969663,7.38497,61.635011,57.408652,19.588717,83.731792,140.077791,246.051023,280.291537,292.833358,284.404195,242.977322,166.583411,110.816823,19.358799,22.681898,107.280699,163.327408,229.593363,194.631586,51.700059,27.934489,42.380745,29.12756,9.498383,-34.733468,-63.560899,-101.606269,-83.166862,-58.545226,-10.760755,14.948915,75.774003,87.448838,73.787204,70.428897,52.681166,9.40747,22.834349,137.264626,185.402758,146.574682,54.146633,-198.043891,-312.436534,-275.884299,-151.243269,-121.61865,-130.917332,-124.377844,-43.786831,-21.842095,-77.96915,-49.596609,27.25494,136.524843,124.200863,29.568385,-28.279667,-191.443817,-266.898978,-207.461641,-2.270588,79.330781,151.815057,161.758073,146.618003,104.071326,3.343975,54.554922,127.91571,195.04945,155.642884,43.993452,29.588204,85.864387,172.715569,211.878556,268.242728,294.14733,346.63357,362.59047,380.635352,356.521418,208.348041,160.439406,213.25449,327.833986,364.408614,466.293969,513.277649,429.142124,206.997541,153.234218,181.088192,213.104817,211.915821,178.902475,108.560173,82.20896,66.608733,41.519511,7.700523,-2.586751,28.380839,67.82472,61.757751,32.92205,25.650659,28.539376,44.002232,59.082048,77.843505,70.223583,38.700799,23.868902,19.595325,67.867956,93.680572,123.535761,129.947572,111.500858,75.233354,-69.075965,-147.429666,-97.516957,91.422094,155.150753,108.916835,29.211669,-61.131133,-59.208695,-49.343614,-62.885224,-80.731013,-91.161352,-59.768032,6.7007,-8.235228,-96.924546,-35.284824,59.089845,193.102567,208.664275,211.021401,212.785399,171.83481,135.905901,155.105152,313.116998,389.548386,460.667046,438.045814,285.975183,202.5617,86.935567,-7.680738,-48.634939,-81.063042,-60.65317,-1.477578,5.525894,-36.80648,-80.990064,-126.461992,28.920012,123.289695,168.401034,132.383578,23.863664,-34.174971,-116.345535,-132.927082,-135.007737,-129.489128,-118.193878,-116.199845,-114.668247,-75.445777,-63.879437,-83.152711,-42.909788,23.960383,147.000914,164.846121,165.701433,177.840303,203.211168,175.650613,129.016944,10.991867,-11.952731,9.812956,16.878883,0.026644,-29.384129,-144.35953,-167.317673,-101.84419,45.465809,64.63212,-21.421656,-74.288021,-55.418877,30.801373,43.619057,129.315934,213.30585,231.238964,134.610951,-81.32667,-140.492059,-94.39296,82.268985,137.953196,117.980128,65.822813,-25.230081,-36.782461,17.670707,110.765647,130.764578,119.467162,109.035171,71.368725,32.511779,-89.170319,-140.259771,-94.515993,138.609398,260.720969,377.584681,346.781591,201.551932,131.889643,9.604484,-43.857446,-22.834991,95.613449,154.854092,142.424618,77.393529,-29.784386,-47.055809,-27.366386,48.688401,71.494151,27.348821,-17.710902,-57.815201,-30.305052,35.678672,-5.391068,-38.698311,-29.545925,-6.62823,-74.693607,-158.621019,-220.379147,-184.766831,-125.409647,-63.741161,0.64445,98.112263,88.607052,53.243245,76.324893,123.175929,134.644926,159.16105,227.211801,258.247613,266.229769,223.642977,110.335771,77.268203,28.307763,-90.165196,-168.621241,-236.419301,-194.170874,-76.254899,-69.999945,-164.791563,-192.720351,-146.167479,-40.60646,0.654072,91.828435,124.992,85.805701,8.450503:-241.69281,41.925874,196.200767,252.751981,164.262076,-13.835121,-61.62789,-125.162242,-91.259159,-30.657482,111.203365,175.9449,211.529728,157.324864,-24.689568,-110.226844,-176.892495,-51.76484,28.985675,88.469596,49.986428,-114.94923,-188.260761,-183.176316,-29.379044,35.489783,120.178016,144.257881,103.003591,38.311659,-105.760916,-169.726645,-245.006793,-180.731922,-97.982137,67.499818,95.47988,19.764151,-62.591962,-233.778806,-192.703623,-93.353652,99.066147,161.911499,153.354709,76.140539,-103.536599,-155.888327,-137.316132,-15.826845,57.534924,195.557729,216.409745,93.451448,-18.923521,-193.178801,-177.457453,-119.872256,4.347063,64.939177,110.172084,54.278743,-151.697434,-222.407285,-176.497696,-49.552064,-26.236755,-17.015335,-18.181108,-79.653135,-134.434011,-204.448542,-130.386701,-42.286529,141.608104,204.200199,239.571801,214.648616,72.496603,-30.126483,-137.00418,-36.335304,34.354143,101.655732,67.635397,-59.204597,-96.476522,-150.272122,-174.535204,-133.723153,-5.721716,45.332822,102.483177,95.871875,-5.121214,-61.494529,-65.251855,15.190296,41.048856,5.288408,-64.631663,-202.769117,-235.294548,-243.55926,-163.388242,-109.729386,-28.001071,10.467069,11.62958,-45.713442,-166.867581,-202.014797,-216.906741,-104.491066,2.99165,204.593141,227.679333,132.988454,93.241024,72.598971,17.675561,-10.884602,35.201241,104.021904,168.69271,124.348762,-20.921877,-65.109384,-40.997491,38.484893,50.882184,36.382417,28.893466,1.120497,-40.20621,-146.865709,-149.027732,-113.317375,-11.386528,55.336266,137.656821,132.211208,100.757849,91.14427,65.201306,61.882647,100.011798,227.125388,253.258499,144.914525,33.642217,-172.796514,-185.718403,-130.538771,-17.489062,6.161242,-24.35648,-58.60286,-122.666217,-135.546248,-85.390541,36.910855,95.629283,163.196249,160.232176,66.185949,-17.491401,-169.849192,-206.748644,-175.139162,-31.25631,52.898168,166.013959,183.47772,140.19307,83.442753,-1.088541,66.313017,140.587196,245.837682,218.705059,48.469686,-15.598375,-41.064717,36.37012,94.752803,177.872599,208.901398,283.228894,291.549065,138.626952,11.468202,-75.193272,120.27076,215.723396,317.738244,344.689413,348.586893,321.348431,240.825184,174.654211,155.459711,194.241489,237.994569,230.395073,170.823735,7.30067,-83.720946,-147.521819,-12.69298,29.269607,-16.078413,-55.595549,-28.016132,31.286353,36.267282,-119.595101,-138.392833,44.654095,149.004033,151.463035,84.972421,-16.931332,-44.576204,-54.925158,7.988572,42.751224,56.436503,22.784527,-71.730935,-100.807364,-136.355106,-162.286827,-143.77785,-40.791795,9.020686,-12.709399,-79.129813,-186.375113,-201.490912,-140.791999,-5.430843,32.544446,8.856504,-38.994682,-148.675269,-175.007404,-168.635267,-117.042352,-45.824122,135.152491,188.934386,196.142272,177.800297,143.717397,132.146125,134.907223,209.926814,248.884317,269.36784,266.018193,222.552308,152.847511,-44.772489,-127.091969,-103.002461,-12.654105,28.138741,48.621591,14.539174,-91.226241,-124.471518,-58.142181,128.479043,193.891537,249.408419,248.50049,154.266768,57.757758,-126.759085,-118.043366,-59.285972,18.146552,13.222358,-67.106283,-124.654475,-201.985659,-195.908633,-90.599104,60.939151,113.662397,128.413398,114.250809,116.271266,110.988656,35.715247,-0.991229,11.787773,53.125462,61.365125,13.320767,-24.167552,-79.392357,-104.279823,-134.894121,-15.67303,100.572063,223.644599,172.730582,-7.423458,-65.974212,-84.00528,-10.712623,38.079882,161.775043,226.923614,233.471975,155.858717,-32.987854,-94.293679,-86.563721,76.260717,169.705081,240.116919,195.602304,49.137822,-9.838576,-66.268223,7.228686,61.121827,115.583634,116.263612,52.225637,-4.932842,-122.080001,-170.643714,-128.720305,173.308414,318.696833,397.568026,346.319612,183.991965,100.071236,-30.519116,-10.435011,61.463931,238.892896,301.135226,258.351249,153.604246,-92.706409,-175.880064,-165.706938,-13.206942,45.741289,109.981287,112.736705,41.62838,-1.0042,-35.520648,3.314414,34.439399,58.649434,53.290227,4.946732,-42.110407,-174.406683,-240.414988,-247.346837,-89.301682,-22.340523,23.144584,15.905505,-16.737896,-29.106013,-54.654638,-18.335181,42.074779,180.065208,229.132673,193.313124,94.396473,-130.325974,-192.320355,-167.286741,-54.631797,-30.999861,-53.790496,-74.122379,-132.590613,-192.018499,-334.831126,-309.769201,-211.281238,36.954157,122.150339,134.386096,86.703007,-52.784192,-133.360774:-180.465653,-23.727785,34.427872,28.143987,-4.85245,-50.086417,-53.793345,-75.114564,-124.639202,-106.747564,3.931915,39.198439,15.970789,-1.814028,22.218024,21.272112,-55.489931,-57.119411,-32.127788,-12.959445,-26.85483,-141.218141,-217.761772,-246.809336,-34.821119,117.63823,311.245596,326.108932,273.89678,232.165704,187.596185,184.502756,103.628438,-27.104429,-20.25854,134.455435,172.414778,67.27638,14.087882,41.507732,142.954865,186.111895,248.271199,286.001853,368.955006,376.751127,275.902038,191.635582,101.199616,197.997721,272.433616,338.928747,296.736489,136.566242,83.422661,72.502566,145.894356,181.111127,164.735851,133.989231,87.939372,66.696388,38.643187,34.846055,20.945823,-44.949416,-99.419739,-160.429692,-144.313695,-100.004981,-102.09721,-124.754921,-104.038349,-49.581469,159.857825,270.498469,359.610388,338.579494,286.607249,273.457361,205.588213,109.140746,105.763941,162.521059,166.367008,91.371482,57.058518,53.015787,18.647139,-39.997367,-150.158208,-164.624865,-148.775469,-142.437076,-91.572112,-26.685554,92.445418,32.258437,-43.48413,-103.75405,-83.626078,-29.534389,14.072596,109.553199,142.84772,151.98404,166.289157,166.77798,154.905925,150.946894,205.118527,250.426256,275.794629,237.2927,232.023059,304.598646,375.450442,478.563223,468.615517,335.343095,163.709635,80.097994,-71.77497,-95.816385,33.33195,128.928343,194.735494,154.290904,32.275936,-1.04954,30.074201,101.300012,100.979091,59.964868,57.727051,96.511162,99.460223,78.99582,37.673939,36.61672,83.100938,99.244731,55.841021,-7.498776,-156.001254,-177.495992,-134.542239,-31.485494,2.931085,4.721851,-30.907549,-178.806805,-320.184681,-339.24173,-303.588963,-258.758891,-142.200747,-102.285512,-20.668484,35.785408,67.13059,72.201329,150.436164,342.243947,357.172917,230.198617,153.864259,57.214439,91.243679,148.538643,253.26162,295.524342,372.211603,385.80539,296.876226,211.919243,137.408458,190.819469,180.76472,80.271195,40.566336,36.310519,66.934055,145.5179,177.157395,176.037815,214.092162,279.410113,401.923661,413.235741,365.263756,325.741362,233.265436,201.485298,227.239786,329.329645,387.491782,471.785392,500.738739,499.520913,380.721277,315.040811,241.718328,236.67288,210.977005,172.823317,108.463015,105.142951,146.249155,99.545213,25.399168,-57.137248,-46.916133,-18.031108,-11.657075,-36.338908,-38.860513,-1.537949,45.392349,49.788132,81.987172,89.577666,29.234822,-15.756444,-18.653346,63.989371,91.378905,120.411689,126.2873,97.75835,72.993796,24.012329,6.133949,36.895912,133.904858,162.11414,120.592003,55.785917,-75.675946,-115.276392,-144.090366,-160.775293,-167.176734,-129.834326,-90.444829,-31.805052,-21.21863,-37.235875,-71.734053,-70.517812,6.736584,64.964576,99.120842,69.257061,28.994946,28.576659,58.311396,189.012199,258.766341,275.378224,242.425082,231.865753,246.387896,182.079654,17.560102,-56.116599,-106.905393,-67.400996,26.773196,16.704162,-125.963953,-215.562254,-264.65377,-56.285812,40.560614,5.82072,-85.019008,-184.432404,-163.555184,-89.408016,-69.731516,-81.072658,-115.444823,-115.752066,-86.581302,-71.19365,-45.701921,-52.014831,-103.744393,-69.120043,-6.321115,78.607017,60.549832,-30.060952,-45.978792,13.295036,69.864383,48.273865,-59.145016,-104.839368,-168.91654,-185.451037,-172.327108,-168.901552,-198.002213,-227.744161,-233.873456,-168.66025,-100.868295,-17.314726,-24.130868,-71.080677,-80.117937,-63.405815,10.761504,57.362189,69.420332,-2.297994,-199.272086,-238.647118,-154.138766,-61.49538,-81.976812,-216.577686,-262.709712,-208.229329,-136.918283,-44.420685,-4.023952,34.205182,103.725176,108.739167,40.142084,-14.281684,-77.101747,-87.763829,-98.039596,-35.964632,11.789836,53.255983,48.249396,74.295056,110.119271,62.831186,-93.033807,-107.917953,-39.846227,-3.663644,33.763885,37.625813,22.404149,-14.027036,-104.197925,-59.343266,5.354448,115.848053,132.021353,45.339298,-23.47818,-83.003371,-88.841863,-120.28449,-185.807941,-195.080332,-215.945455,-222.444704,-181.984162,-162.8619,-163.43885,-120.584539,-57.808731,64.405921,56.361487,-92.977342,-142.917836,-94.732474,-25.988541,-13.768375,-0.747777,1.092665,-10.159874,-6.033408,39.739613,40.551561,-68.881542,-209.009566,-232.995067,-146.22321,-90.18788,-102.288273,-154.81888,-275.771616,-296.910999,-236.402184,-82.919257,-27.929006,56.216829,81.076068,72.307234,42.300576:-171.628146,15.16993,70.812936,59.319801,39.302734,32.875323,37.044708,-13.029142,-92.407023,-86.617237,-12.264488,20.621905,9.371315,-46.322946,-160.48313,-182.643804,-154.316108,-43.790934,-1.069968,-6.554636,-26.272682,-15.525735,-9.272918,-50.14005,-29.617348,28.154863,154.328529,196.645012,236.500164,237.993956,203.729138,157.194681,19.012749,-21.83881,30.779972,179.347184,200.728936,106.593515,63.022798,71.086659,110.818804,125.522597,143.375296,160.119306,211.478106,225.997921,228.053149,230.726911,264.199249,298.289397,302.695916,276.845405,233.314835,121.847065,78.974512,-8.972658,-45.578196,-7.886343,87.628892,99.881585,37.888437,-5.244896,-22.174654,-1.17345,35.956142,20.287452,-8.749087,-31.302269,-22.54261,-60.470235,-109.464149,-169.120772,-83.630172,9.382793,151.798196,155.383736,112.778254,127.199562,184.66704,169.91532,115.399293,184.893273,224.852579,187.553456,109.457859,-70.041912,-121.063426,-151.309088,-188.645296,-197.704166,-145.451754,-113.857448,-139.183649,-164.130369,-86.430239,5.826265,142.759952,50.129658,-77.384116,-267.19234,-268.842363,-177.037975,-135.041091,-83.926643,-69.808389,-85.697678,-88.032684,-36.882136,63.973107,75.32982,124.8562,189.532685,275.718786,166.399356,100.981624,146.172431,224.398858,280.354557,256.183623,178.982881,46.545135,-52.487936,-234.003751,-228.432089,12.126113,134.299196,186.992351,138.718688,-7.511352,-148.68082,-192.057843,-143.103895,-82.099479,-43.627289,-54.871561,-73.97151,-119.517427,-156.838811,-183.976056,-151.675952,-96.157952,-121.265897,-243.418335,-302.235834,-404.270744,-427.814769,-361.404449,-159.131238,-99.202145,-135.484016,-218.613495,-421.968635,-489.223174,-448.159036,-328.312841,-287.183162,-254.160227,-234.907473,-155.418474,-140.408801,-244.347183,-329.649366,-284.648655,-90.697102,-2.802416,72.502185,36.962464,-131.658592,-123.509739,-12.882562,185.087849,187.463293,47.691772,-0.459037,49.128053,67.211218,-34.101616,-95.405558,-80.066153,-86.612633,-124.539072,-144.262627,-100.559,-32.369084,-30.868752,-15.309815,20.007863,33.461165,64.037677,85.418778,129.475334,99.763093,-103.980253,-245.596969,-213.075773,1.263123,97.856829,165.900314,158.520776,67.375516,-112.09141,-192.829852,-208.689586,-149.222638,-61.046396,-49.009846,-45.734677,-60.539294,-103.21162,-149.488506,-197.212203,-244.106438,-194.147066,-60.636281,-41.072093,-80.727143,-155.385766,-208.8565,-324.077093,-345.107571,-291.360727,-264.836488,-307.36928,-364.262239,-436.831304,-385.646846,-323.736404,-175.179733,-133.883788,-184.904413,-245.070494,-345.080838,-350.224578,-319.436931,-240.790613,-184.498252,-88.979099,-99.668985,-203.738484,-235.249787,-175.304248,-70.64969,-61.441927,-91.995053,-98.737151,-66.75414,-31.115225,-31.943708,-143.59897,-156.541956,-48.081244,20.545484,102.194126,124.001982,113.698028,69.921793,39.344612,181.90917,242.997981,294.442645,306.375731,308.875673,305.829842,246.941388,63.618208,-19.668051,-35.691132,41.514262,222.124875,229.516435,63.642317,-13.064947,3.285704,129.811421,157.34944,144.059311,142.291812,147.056166,143.687597,158.178574,220.933994,234.561488,187.700781,170.04583,220.288241,267.903497,304.920653,272.007478,233.754738,376.89179,472.886802,565.526306,533.940698,399.820091,355.843659,346.492329,389.482876,395.896903,341.248466,311.146112,312.190552,333.436017,351.308801,336.672358,262.342181,167.227144,157.186977,223.318527,239.715449,189.770798,186.094216,283.046516,370.786796,385.56641,409.443302,424.624185,366.009814,279.219013,124.614136,92.633677,95.064305,76.507915,17.761186,-87.794734,-70.935227,76.988474,147.350862,179.318751,206.088785,263.277387,364.696461,375.374645,334.190683,290.839895,178.93772,148.361597,180.808667,209.094666,216.466066,286.366816,325.5918,301.924933,233.802541,83.049102,40.292438,51.456335,53.003756,49.077313,87.843152,106.50786,55.089517,-11.251604,-116.805287,-104.915114,-81.922375,9.427255,67.420405,56.589236,-3.131209,-80.917562,-60.013487,-35.168542,-41.301804,-69.791399,-102.171662,-92.094217,-78.016462,-117.14864,-202.323437,-19.240669,132.505035,232.616727,147.132208,3.900433,35.698164,136.627205,101.691622,78.412931,134.227492,213.350751,352.201076,355.587851,245.186381,181.201058,88.527341,-33.747338,-93.698954,-40.082883,60.714358,178.402952,157.013234,48.667517,25.311983,58.594744,152.142068,210.146749,343.427112,371.365629,245.060214,140.362678:-122.026024,-29.668648,-7.216858,52.235403,70.050043,-7.645734,-81.901473,-169.66201,-109.539433,-58.295357,-0.470764,14.249543,18.903059,-10.342039,-103.091898,-139.829226,-137.801599,-43.629794,-15.313224,10.756476,22.624897,-41.669895,-116.268376,-192.793961,-96.593717,-35.083159,61.099225,91.614569,77.522504,44.183632,-16.021918,-47.499537,-134.954783,-157.86623,-126.753225,-44.706946,-13.833003,-13.206618,-45.604699,-125.392399,-188.897007,-197.463023,-97.3541,14.844647,203.63209,205.671155,83.015028,32.623066,-12.122319,31.296977,79.995031,103.907372,63.972956,-37.551192,-72.892602,-90.607786,-50.157124,-26.628199,28.44491,65.734143,90.052581,55.706013,-33.145108,-66.47413,-115.303837,-124.750543,-116.130476,-110.956353,-127.624998,-215.705624,-267.256022,-279.625606,-138.147621,-50.713349,68.687665,97.465895,113.014226,109.917657,90.351159,56.111489,-21.288537,16.567752,54.825052,54.627113,24.392443,-18.716403,-30.648393,-64.638926,-95.742567,-99.378921,-103.153587,-108.348119,-84.411816,-44.052839,-12.030607,-60.854126,-154.96068,-78.540853,-32.407949,-33.452572,-69.57634,-144.666258,-147.496563,-64.496987,58.705693,94.789587,43.590302,-9.401914,-46.776055,-36.279776,-18.803403,-27.967307,-56.158021,-32.494282,3.516275,134.403248,198.923775,202.332924,155.758142,82.37817,10.108291,-35.204042,-38.979751,4.323581,22.323676,-12.44809,-19.940853,5.101673,-6.699221,-45.46566,-42.433629,-11.346178,-2.864027,-20.736739,-36.936267,-76.065601,-107.289859,-96.553232,-8.671742,44.994135,82.681167,67.17889,45.134116,34.302169,-13.765743,-50.024807,-49.664905,47.632668,109.566155,70.722689,-25.100825,-233.602282,-287.874643,-234.397419,-148.831155,-163.058679,-208.483263,-199.588627,-111.927589,-63.270244,-20.298399,-22.440432,-16.903599,55.04492,100.441735,80.605308,-5.019393,-198.111855,-126.122328,-5.918378,137.460765,156.114072,177.274284,177.27593,151.263106,129.294611,93.23896,100.878658,109.808716,65.712204,18.763349,-1.972894,34.268582,76.853445,58.289047,62.801858,105.478127,146.180012,220.420336,220.709463,186.200543,167.689546,107.399438,116.186833,151.418354,173.356149,176.313944,263.022205,295.382186,189.624801,89.463507,110.416097,172.155377,174.131938,112.896941,68.678296,-29.817266,-89.567681,-157.823588,-113.389099,-95.541396,-115.096519,-122.029126,-71.646675,-37.602785,-41.076357,-57.507962,-43.864437,-37.3157,-31.220762,1.121443,-13.327211,-87.377304,-99.969205,-57.062713,-7.400468,2.614926,41.941074,81.75703,144.528719,121.065908,-62.51992,-164.640491,-125.157217,8.959723,42.180073,-22.376055,-88.054825,-176.976684,-198.858442,-204.397374,-157.836148,-135.842228,-128.942668,-127.243578,-75.512987,-45.536702,-53.373936,-86.022794,-54.621047,114.23427,204.106193,251.553608,208.513162,113.392348,98.249296,156.237761,285.053787,324.711304,297.690608,252.294184,174.240417,160.336901,124.183411,14.450336,-15.48547,29.351066,73.354867,88.888204,35.099874,-88.667841,-93.619828,19.655881,121.621387,139.285242,154.43719,144.974021,96.903745,57.888494,-56.897369,-62.669596,-16.465289,19.154034,13.396864,21.141142,9.788832,-33.245308,-25.76798,15.329653,40.5576,78.399392,176.782106,180.04148,99.913637,70.658439,58.212325,74.33488,83.825084,20.150403,-48.655895,-73.743543,2.463667,98.471807,45.449164,-81.679404,20.043416,114.348887,200.26522,178.435113,69.162675,3.682878,-80.541678,-21.290775,48.629292,158.118898,182.215522,167.61715,115.54118,-24.105661,-66.703603,-88.380327,-85.801259,-73.269227,-64.665014,-87.334866,-126.83195,-101.304486,33.532342,135.514367,153.118152,141.879438,106.811913,-3.710827,-48.670522,-87.838772,-89.998429,-21.316505,154.088898,230.52374,274.439067,243.339729,159.907119,144.015784,114.201759,41.266315,36.758247,100.021142,149.101588,230.10639,229.487793,135.278874,76.913129,51.695438,111.562544,113.772373,86.679925,96.729401,121.203584,95.127092,-11.471489,-63.156483,-50.569605,-2.504251,1.32711,-65.516987,-115.419161,-177.839779,-185.603436,-130.803801,1.964408,55.927173,106.919249,99.062957,55.369293,57.564179,85.196033,54.940288,54.118168,161.273896,233.960835,236.586739,157.361463,10.397765,2.074592,54.606062,19.295092,-8.926302,-1.133292,12.588678,-39.113401,-109.27924,-217.466142,-153.185361,-80.193219,91.857242,174.730598,221.950225,180.062137,75.303423,22.906938:forward
265.193665,112.359869,55.262996,54.898857,87.900284,139.337843,133.466214,63.715718,-4.814628,-24.281302,37.227433,126.821612,286.212092,308.573235,233.873956,159.786375,44.505194,12.937669,35.770653,138.760666,149.800434,62.37805,20.877037,-28.448906,-66.523807,-67.848971,-50.120274,-47.74875,-7.910313,42.591007,74.329826,10.465118,-176.287147,-258.674915,-264.717107,-280.08515,-287.081987,-193.373298,-95.896515,11.175044,-75.593797,-126.960123,-135.800093,-99.40256,14.788253,93.528409,227.006809,231.539427,87.689697,-125.878717,-171.980626,-80.73698,2.404735,117.107071,140.991815,110.01517,-22.56896,-89.093699,-116.05424,-90.246772,-40.823609,3.314276,127.806801,160.142669,139.853948,67.033599,21.981877,-29.811952,-20.820697,45.79619,66.076379,5.873164,-62.529827,-65.434131,-41.6576,6.07215,174.811986,252.510661,351.167195,377.47512,369.501768,288.306086,249.513995,192.05277,159.799828,137.544095,149.915459,135.271332,79.923726,61.088833,83.188263,120.2926,139.743833,109.946964,56.377011,51.51032,56.241797,27.159601,29.494954,130.034881,205.850153,357.829372,402.939113,359.478203,302.906452,298.130855,284.160949,299.332565,373.631304,396.291256,359.953498,310.147574,195.376407,12.615641,-79.822388,-71.255852,34.494855,240.91415,277.359201,239.084496,162.44648,108.793948,-32.405445,-76.826155,-45.494005,-3.707272,17.279381,-0.375541,-40.534196,-135.263397,-186.791719,-157.509381,-61.697861,178.633596,246.974974,182.039933,30.698771,-9.583383,-74.89703,-102.833383,-83.826569,-36.628551,54.257863,59.150928,-24.417141,-92.426692,-91.807695,-95.124773,-108.673649,-89.96688,-63.656785,-37.521698,24.009215,68.50481,104.424125,107.772449,171.729087,240.555976,351.975125,348.382687,234.731348,130.913494,130.590348,184.233223,200.818395,205.507882,199.581291,185.0566,163.767817,121.30445,-1.192864,-42.081912,-91.380925,-118.669945,-135.288958,-123.117429,-170.743544,-348.592829,-407.955463,-361.650433,-305.29756,-238.118243,-232.462757,-281.808473,-261.713388,-201.613242,-138.78442,-128.076812,-33.02124,12.221342,-27.681337,-85.314909,-142.88198,-85.904886,-31.936932,74.553219,104.832697,116.270506,120.386719,140.289914,118.085498,81.827415,60.460006,89.567712,92.41661,43.193345,-77.382976,-109.628289,-80.210244,-79.810718,-124.338284,-222.33498,-280.854739,-412.88834,-424.789153,-295.900065,-246.821643,-310.829036,-384.04037,-340.460736,-259.78099,-264.291694,-306.134254,-310.989309,-272.089994,-326.193159,-387.462612,-420.246126,-378.253732,-204.36976,-120.111169,-167.036081,-334.144997,-327.040459,-223.882168,-210.206048,-233.626549,-224.534751,-175.907391,-168.923128,-171.124278,-166.534827,-181.25661,-239.327608,-278.253744,-318.001384,-286.841638,-142.692457,-37.390735,-31.304527,-31.493072,-19.588238,-16.506664,-14.527916,43.564413,81.536075,115.228713,43.510099,-15.234914,-66.596572,-43.397541,109.13929,190.819779,133.867811,-105.170432,-159.308489,-127.866354,-98.148317,-30.623173,25.539261,77.241642,26.02918,-93.013887,-62.562032,-26.403456,49.854943,91.260705,91.482753,35.865951,-76.750541,-158.420676,-225.791972,-330.865423,-324.164215,-261.890097,-230.284075,-172.255401,-156.885258,-163.92108,-264.630598,-319.138975,-248.042651,-141.805335,-17.256777,-23.065502,-64.892919,-53.939949,-28.921668,26.411012,24.535382,-55.630479,-80.612043,-88.06764,-132.16554,-289.693668,-383.453021,-389.429469,-298.788402,-211.762851,-52.880763,-24.258651,-100.551446,-230.065738,-260.178249,-234.751294,-202.465729,-178.021605,-187.277882,-166.10155,-129.080058,-91.31671,-226.856015,-323.396824,-325.437888,-215.75318,-6.020467,13.545211,-75.144896,-162.642864,-192.877344,-179.144014,-111.46283,91.987027,185.574838,283.267342,274.55052,205.578154,163.655899,159.74277,175.996813,186.93773,228.103131,260.539191,300.339724,260.828947,203.438998,56.036101,2.437074,-5.8766,31.887818,89.350718,71.746285,-21.384842,-115.561535,-149.300318,-137.759108,-101.374128,-43.452378,-55.157217,-183.438072,-236.828799,-200.707093,-119.205111,-75.834109,18.386368,27.837656,-31.392629,-53.713643,-60.693389,-145.151644,-203.321989,-230.440112,-197.369945,-39.564547,67.907454,160.754379,27.514734,-40.942016,-22.622636,54.357499,173.946833,186.417069,205.610652,222.443009,203.306667,111.632139,64.026715,19.575763,22.178041,83.438276,139.670591,196.64262,68.804638,-40.56192,-146.952661,-98.828693,61.676556,117.322277,155.103906,134.483045:206.046008,47.77648,17.106454,69.263423,108.05598,179.659486,197.209834,150.947231,119.067638,138.347369,226.204975,273.61352,299.798344,265.01072,132.20928,63.538552,-25.041698,-22.137809,36.391655,184.994187,212.960349,168.174774,127.484366,25.081702,-99.330469,-144.174554,-165.292959,-135.222516,-25.301119,29.709493,60.545213,5.082024,-160.447799,-206.140425,-192.849933,-177.409864,-181.381,-164.488687,-139.88335,-126.915084,-199.679881,-231.027765,-194.433248,-138.571885,3.383319,88.059182,180.270008,150.169224,0.494283,-137.153217,-156.2061,-56.642481,20.270011,84.651364,71.353598,57.840978,57.459788,29.569579,-15.871619,12.077651,152.904063,218.465011,258.26216,242.512257,198.227524,109.126407,44.162923,-55.745111,-68.627126,-17.142405,7.011532,-39.323522,-106.714075,-110.734752,-57.027017,-7.201686,110.902537,176.360426,310.926135,349.454983,265.983517,81.051354,41.646796,37.32815,36.690883,67.281149,78.555707,12.187011,-19.009899,17.085419,152.644436,240.711822,345.170622,314.71351,154.739346,90.924866,33.803831,9.175763,39.190779,184.409866,227.539889,199.128744,183.801993,206.191669,216.456863,215.729432,256.840624,299.123706,360.662018,355.926811,286.494027,258.530169,211.623517,81.806638,39.259805,63.65425,107.862757,264.49604,350.60278,383.476838,208.176584,91.791998,-40.32724,-27.969933,28.602079,30.30547,-22.185677,-68.325253,-162.158787,-237.545118,-243.91469,-167.922939,-99.596817,35.040484,70.069892,82.704384,40.485008,1.202826,3.172161,52.409201,107.027525,103.950402,99.888058,80.534213,-18.769352,-114.726697,-119.138574,-23.574202,35.304925,134.06424,181.560372,208.92733,155.254393,141.918171,187.196057,242.870276,361.434097,388.737475,397.766263,395.23366,309.491235,157.864491,149.326672,288.186431,354.478212,378.047452,339.051245,194.328182,81.447551,58.064107,-5.01165,-52.60325,-77.496581,-60.126571,-84.472144,-117.251951,-161.291313,-224.8876,-256.53232,-290.541717,-284.431046,-219.277586,-206.266331,-284.458356,-285.513706,-222.912018,-123.077487,-97.71473,-31.249107,2.036385,14.202142,-9.460566,-68.597971,-82.120396,-66.50842,25.544838,89.488353,167.453795,152.868293,82.654422,72.58021,51.349438,14.287882,46.726059,124.500539,103.351767,-62.053846,-144.236615,-197.791399,-178.384926,-175.703411,-210.223673,-255.802655,-342.120706,-344.756829,-311.994016,-332.032569,-353.745436,-340.298162,-304.249306,-260.878329,-252.871144,-225.207847,-224.895058,-287.549549,-370.144768,-391.21481,-388.501063,-347.017906,-176.499261,-122.208844,-226.590977,-383.10496,-380.559091,-277.025743,-251.922435,-281.740103,-285.532936,-264.926158,-272.998544,-321.444729,-343.968621,-322.669222,-250.27262,-239.746759,-269.447423,-266.85001,-190.744389,-147.521167,-173.921315,-225.299596,-201.054992,-87.674821,-40.972269,-19.911573,-50.579048,-117.541344,-100.823113,-80.883921,-42.100032,-15.441799,48.900096,70.427274,64.252913,-32.064987,-104.043573,-163.219147,-108.749479,93.679009,161.53283,134.258603,78.129413,16.282689,-4.594473,-16.655236,28.627801,74.540825,68.509447,-4.005255,-168.941972,-239.080139,-258.205093,-264.107268,-248.893533,-212.130458,-166.190601,-63.571551,-71.468206,-202.768021,-324.074751,-334.49432,-214.706335,-124.689836,-28.849105,-36.117197,-133.879744,-219.148684,-209.875194,-134.359157,-101.983733,-69.067203,-67.781596,-138.725152,-211.819928,-342.491334,-352.922837,-306.201141,-213.324363,-203.367698,-185.383137,-157.810097,-138.673467,-176.153537,-201.923473,-205.335317,-172.191128,-125.131892,-129.415676,-160.548576,-165.054206,-123.622575,-144.772195,-184.007003,-164.386749,-97.063622,-1.340769,-21.296519,-154.510706,-256.563923,-267.414965,-213.930833,-144.985092,45.756938,133.928119,265.253084,307.890741,332.820238,234.881632,153.138736,55.332968,68.442114,150.829217,172.451319,161.710104,121.870274,84.663833,35.467923,55.080221,176.450167,246.096805,276.620015,213.096795,48.767296,-18.181865,-36.284555,-73.616479,-74.682059,-74.081452,-123.354248,-262.738358,-222.177039,-165.69518,-108.294113,-75.757597,55.056767,100.61221,59.008069,3.282701,-56.669901,-47.127727,-48.539345,-53.445841,-47.300736,3.058399,54.452569,127.912124,63.898385,24.883327,72.758366,148.739533,234.398931,213.206488,139.086006,121.958299,71.282356,-46.317958,-88.223221,-95.005256,-60.57695,16.490484,16.616499,-29.54961,-50.828846,-78.713754,-147.347579,-127.520147,20.526302,92.202242,157.15501,146.607585:174.726943,81.409577,68.892051,151.82952,199.70898,211.227745,187.425488,154.139157,182.090405,219.19177,320.432221,359.260669,357.530727,316.039649,210.133092,170.861981,111.704467,68.089009,87.494609,177.128979,199.551283,201.975481,185.284923,54.456425,-126.052786,-173.449617,-187.680612,-181.858279,-125.185404,-57.899199,42.643018,8.757064,-177.886495,-284.183654,-276.51249,-236.489154,-216.178847,-115.977425,-70.19006,-104.978244,-209.84966,-238.138442,-208.430902,-155.164711,-24.32398,40.045326,116.895855,82.424241,-121.292444,-214.153653,-172.351435,-43.595817,2.949767,23.387018,19.006736,99.186623,130.089847,54.877102,-56.412268,-27.364624,93.827803,148.052479,235.312128,254.921402,184.417507,13.037395,-44.860826,-69.445085,-46.732329,45.287861,76.44401,50.942612,-78.323758,-155.989372,-154.046608,-56.091129,149.922052,207.581619,238.473887,223.677439,160.739469,83.949533,51.566105,39.303014,52.079997,49.977155,17.906385,-60.488681,-56.435943,-40.116203,-15.323387,6.360268,99.899339,131.595817,62.280354,11.380431,-13.187228,-40.001374,-67.485998,-74.4152,-42.521241,40.169458,69.074542,83.09755,77.388822,84.491972,107.669777,117.392211,157.893306,183.12671,189.62236,167.961468,61.817681,-82.733855,-108.584096,-57.128739,-6.6957,119.782834,182.51527,276.205892,223.752665,113.83306,-90.144945,-127.677469,-133.860638,-108.086597,-33.446278,-42.517756,-168.771625,-276.374845,-273.780498,-172.483731,-109.952944,-47.576616,-57.165051,-54.335628,-9.573384,-28.644466,-90.081601,-83.548822,-21.160016,4.77957,-3.036661,-28.152177,-62.49197,-85.979406,-73.969804,-0.122082,24.86642,73.38088,120.79767,197.513274,190.833202,170.638787,160.678055,170.449403,210.942152,267.839667,396.562613,401.692476,243.645207,75.85285,88.210522,235.767874,279.979586,258.025867,219.193299,134.097736,66.219563,30.900557,-40.878577,-59.8335,-55.464848,-38.506533,4.133212,-2.236455,-117.347445,-232.771988,-248.244606,-233.701353,-212.572676,-154.475488,-144.181143,-205.767824,-264.157733,-242.309058,-101.418602,-19.829324,40.814191,13.410591,-34.183864,-21.581534,13.650317,-24.089643,-18.376659,131.26712,215.829673,266.837772,237.859081,158.278377,111.1857,95.118288,122.728267,163.9168,173.123565,119.156058,-41.69145,-109.916354,-159.27282,-174.725874,-191.453626,-183.814695,-156.442558,-113.133048,-107.390548,-96.62147,-145.599089,-211.846417,-240.302307,-164.763072,-11.938492,14.434613,-14.115415,-65.472614,-217.183352,-242.316777,-193.832541,-150.654689,-147.992304,-54.436006,-10.122757,-98.342104,-256.909476,-261.263317,-144.979447,-101.027692,-114.350004,-125.262157,-139.368742,-160.705092,-186.149496,-211.081973,-227.92194,-206.90782,-180.473525,-139.702232,-115.74128,-82.745019,-106.722313,-115.231484,-96.586654,-81.901122,-26.521775,28.87717,124.579375,110.159142,-30.974232,-97.954523,-61.94906,105.87624,183.581018,211.90657,181.651809,124.329103,43.020224,-25.229104,-88.157293,-40.338682,102.720069,156.014109,226.679249,217.103696,81.112754,-11.870617,6.118024,110.655552,163.724585,200.057904,160.321401,5.295378,-143.708889,-194.385562,-197.990481,-151.259636,-34.243756,27.479039,91.6851,61.601655,-40.082181,-121.653354,-137.689889,-73.918161,-15.978162,66.466436,65.967812,-6.366894,-80.695225,-106.580435,-84.462577,-20.139995,144.923322,195.127441,79.900891,-76.803016,-332.251711,-293.298663,-193.997176,-8.337155,40.097348,54.934185,23.104641,-85.576812,-128.43106,-120.120883,-37.332072,34.758763,149.546621,171.535549,169.930728,153.317494,65.00772,-28.659596,-28.791019,45.587731,81.83091,86.239903,48.438589,-46.90598,-92.456917,-93.490228,-18.058799,52.466941,163.550763,191.758767,233.663219,248.156694,259.311865,250.355775,233.692351,149.682126,98.20591,87.473309,113.109351,93.077965,23.882775,19.486548,89.211645,140.617647,231.721517,256.389894,185.169977,98.373554,-61.296233,-144.184998,-140.494818,-79.272194,-70.762343,-132.23039,-169.108471,-221.565366,-280.646366,-296.937893,-223.478216,-136.904234,5.059447,33.200087,35.73902,12.728844,-57.760089,-98.899186,-103.89565,-63.939758,-8.901327,86.978934,80.419673,-28.829059,-122.763916,-115.88547,-7.042933,44.855799,55.722468,47.668875,81.539412,86.628432,-8.963619,-160.884257,-198.662452,-151.52002,-108.466649,-83.27187,-89.144882,-104.859933,-177.082523,-224.661819,-188.054934,-100.14599,24.480479,36.811752,34.412554,18.297058:226.471648,117.737522,69.190459,22.420927,5.013659,7.284574,44.449596,120.698226,153.634364,168.316764,251.704389,327.479892,438.985208,432.896504,318.725715,239.772794,91.843461,27.759163,56.124951,159.811235,176.119122,134.831739,103.067876,-23.153249,-206.323513,-258.066629,-254.556105,-221.491083,-128.016605,-64.246127,15.06414,-21.88704,-216.172031,-383.720109,-388.787498,-226.180555,-132.276148,-32.992168,-16.312574,-31.074251,-124.036908,-181.970224,-192.095478,-132.665956,-4.233316,31.45151,58.305124,55.098508,-40.300302,-201.586014,-222.788916,-121.379771,-58.132759,47.2795,102.108865,137.738897,-26.165353,-134.941705,-221.897619,-185.436746,-53.101954,-2.54297,31.495093,31.850997,-15.892303,-158.501401,-201.26484,-152.863118,-96.550657,37.088,96.502367,69.746423,-86.123831,-118.328078,-60.601587,-13.717645,55.377523,102.092582,228.123818,255.828291,194.397204,113.963736,109.198183,138.602148,132.069641,45.418683,-17.807709,-121.56785,-127.401356,-107.98188,-55.554179,-20.736018,26.800325,26.266213,-27.02146,-61.96568,-101.630533,-142.792415,-135.979692,6.768758,111.970727,298.475895,339.390856,261.897339,157.477434,139.600974,174.585389,227.38886,285.240698,244.686965,69.929089,2.250326,-41.708735,-160.900638,-229.361854,-166.034774,-56.998779,104.628305,123.786077,122.920482,110.575919,48.057533,-138.409689,-184.204254,-137.818517,-89.276973,-43.211163,-55.12735,-102.807035,-168.274793,-182.034718,-85.313245,-8.406951,90.725567,103.283054,56.22882,-49.413719,-120.964806,-239.093809,-233.515499,-97.316048,-30.935791,-19.341186,-56.598775,-116.507722,-105.889963,-78.783379,-34.866515,-31.86113,-40.884177,-46.924828,-40.290738,-9.879744,-16.538152,-3.781252,56.355695,208.801815,263.379053,311.745245,284.991338,143.291197,109.433417,173.924697,312.001741,331.358327,303.959836,283.226912,222.247152,116.629638,61.856044,-9.122167,-18.594157,8.408858,17.094263,-20.496357,-54.906086,-138.367011,-214.675619,-247.94888,-294.999994,-294.429582,-244.398215,-212.958556,-172.119496,-165.94791,-175.004388,-144.934509,-84.414069,32.346018,58.353664,68.143435,52.315011,-31.084258,-99.73541,-64.10364,150.589674,234.470969,218.285453,180.161482,168.467811,145.717394,115.920925,111.491986,138.572645,169.427915,151.317657,50.765176,2.801353,-51.226803,-140.835324,-175.174149,-151.113808,-131.03027,-153.641949,-168.062234,-145.421286,-172.611812,-225.430626,-243.061085,-167.904869,6.792186,37.700693,-30.957112,-90.986994,-167.263887,-237.511498,-289.784886,-325.719899,-262.460383,-45.562474,10.015869,-83.908063,-209.51858,-211.576518,-114.803105,-51.713063,2.90119,-5.428875,-43.641388,-73.125937,-137.39814,-192.306798,-197.718309,-131.917993,-95.724798,-84.12154,-80.039078,-32.266964,-23.645008,-52.669678,-91.040412,-66.982418,55.762681,134.585702,231.997595,220.218781,161.506361,151.562862,144.734295,123.561112,122.471347,194.290153,254.088709,244.110873,32.789574,-54.314658,-35.039552,53.785895,201.431069,227.134975,261.027524,266.891153,187.258631,103.314727,110.606811,203.269378,254.972616,266.884265,210.282786,58.721123,-68.640334,-136.279437,-221.18135,-215.148923,-119.417027,-41.872281,69.583825,60.946808,-36.238377,-93.389581,-80.807964,-3.726511,36.476974,131.523987,177.494465,185.021828,98.512399,48.847675,44.033629,110.412388,207.012107,182.233875,58.352359,-16.96183,-167.880748,-222.635208,-181.199009,3.08709,84.65748,129.79023,110.528029,51.057979,-10.203199,-28.177604,0.823616,38.088354,82.742391,71.920009,33.290539,41.884132,46.909829,-116.045966,-197.328714,-152.397763,-50.851699,84.145043,78.426549,8.72287,-65.594352,-110.155628,-105.080541,-9.0322,246.283986,320.39341,322.246082,284.958467,226.213767,211.751399,192.964109,105.000817,63.196959,83.296776,133.261499,159.618647,33.589207,-49.591292,-150.450492,-134.800307,11.869915,103.383578,176.805765,122.240592,-80.571019,-212.035135,-218.723739,-163.314942,-138.661507,-105.337245,-99.530889,-144.312723,-180.351756,-177.467243,-136.463106,-94.649688,-0.450129,25.106348,0.567713,-49.137425,-191.50237,-300.393114,-312.394812,-277.051098,-259.222855,-187.868922,-118.837111,-38.507995,-115.690601,-165.322116,-158.355144,-90.435897,46.099054,74.256248,83.182315,74.134154,16.827987,-100.47365,-154.331488,-151.388896,-89.210234,81.221421,127.894298,58.62091,-93.940874,-164.331514,-222.405365,-189.978451,-90.611545,-47.426883,41.428949,66.335265:205.238465,91.46419,56.028429,100.509074,143.332462,170.474601,152.302721,103.157458,109.455808,147.894529,306.783904,398.336916,503.239476,496.494477,385.224825,305.032033,100.928525,-35.202077,1.246212,172.777838,217.375957,180.732637,131.952531,11.611224,-157.658601,-236.31036,-276.543313,-239.976183,-139.32883,-92.040249,-64.780579,-111.877823,-281.218915,-387.673593,-367.815862,-199.022142,-78.560064,96.894008,89.536321,-30.769758,-134.301342,-193.915248,-236.323042,-198.278395,-99.672559,-58.206839,5.609947,10.386084,-71.742984,-195.767476,-217.358971,-172.14716,-125.872401,-2.126783,58.602784,84.506577,-56.018827,-140.47262,-222.528995,-215.029974,-131.930593,-76.737695,-35.050301,-54.697356,-103.865109,-162.117719,-192.3246,-194.971626,-137.961282,85.129612,173.751926,130.888949,-84.664749,-156.617003,-97.992428,8.515361,221.922618,286.037099,285.544769,234.88,105.808223,16.164043,17.912523,76.542815,102.087882,137.732132,123.956429,-33.698436,-207.723511,-221.177465,-128.97651,-81.241131,-1.014481,35.736976,17.595141,-41.21874,-166.860741,-226.710976,-214.308947,-115.095837,-61.493132,35.213434,80.094794,89.690147,19.027828,1.961824,32.958191,60.282047,80.857162,81.034202,46.611463,-7.418234,-136.956341,-238.625712,-256.48809,-154.877221,-50.911499,140.565245,177.597899,136.20805,27.807786,-50.396139,-186.153021,-207.892777,-130.937652,-44.891048,71.585177,40.145697,-121.003135,-169.126349,-132.108356,-3.500371,69.108322,136.501054,90.839102,-77.005057,-175.391523,-193.753933,-166.8988,-129.481771,-68.699986,-57.338908,-71.467082,-84.97439,-114.819479,-181.455449,-201.755088,-165.55391,-129.741937,-34.766686,14.357881,4.690554,-143.952505,-186.226874,-68.127897,35.535535,132.638572,148.608339,198.779235,195.623476,96.157352,11.471607,20.2481,114.702391,160.900216,225.737884,245.252414,181.025258,-29.104465,-121.134407,-150.200466,-113.218871,-50.419007,-36.935761,-62.321478,-109.413299,-272.834436,-414.014566,-409.821999,-287.483211,-233.382661,-169.465368,-146.362771,-192.297913,-278.769782,-275.393458,-183.073696,-113.632487,-9.054131,19.786027,60.764459,60.520946,-17.899864,-156.608676,-171.140346,-4.465889,109.853461,195.045471,150.612835,11.419346,-47.663301,-37.047371,52.689146,113.793394,191.784914,192.382577,110.111422,32.700573,-135.857161,-221.527996,-228.31258,-199.759818,-164.331269,-65.56743,-38.321805,-69.375554,-138.526393,-175.542456,-179.689533,-118.616167,23.11151,48.487537,5.623437,-28.450852,-79.586856,-133.11031,-146.820591,-156.395297,-145.107291,-60.261602,-40.304331,-118.129739,-229.775873,-272.105203,-254.828219,-176.697211,-6.397219,30.69481,-22.220983,-88.096176,-194.99077,-236.788712,-235.400239,-209.997649,-199.842812,-154.657264,-119.266107,-97.44489,-180.190466,-224.226901,-209.530747,-162.946129,-75.449357,-28.405901,79.050724,103.884829,48.016018,-19.378299,-2.001873,62.586199,67.592608,71.283311,76.405523,8.648644,-158.401965,-237.566362,-254.734836,-167.709066,43.327822,93.94741,92.052807,69.981027,7.042821,-59.982312,-70.566378,-9.186778,59.278323,167.984608,150.158789,22.270722,-108.4191,-194.818682,-293.156676,-242.00913,-47.645996,17.662706,19.528085,-16.8573,-70.679969,-127.744307,-136.280419,-25.1442,65.944619,218.005886,242.428107,162.169835,82.271511,75.722698,119.542281,159.512151,205.956675,203.99636,130.452762,48.005837,-139.135979,-160.771709,-89.647052,66.367731,126.078169,221.494671,228.625038,139.176745,48.262187,37.640386,90.999853,138.116975,234.496823,277.415271,302.182734,268.068561,104.326646,-70.362554,-90.442571,-2.297459,67.217401,151.402656,130.790522,5.936087,-79.049921,-77.941114,27.731353,126.955037,334.469448,395.302612,376.58737,319.751084,204.158753,88.291314,29.800222,10.452682,56.853652,146.047083,139.037192,25.578326,-98.358342,-129.022155,-101.187615,-55.112429,43.22318,79.817777,78.532816,30.10851,-114.884183,-193.812344,-153.606644,10.877312,51.484777,42.880364,27.172111,-65.22897,-179.151026,-189.473417,-81.863021,6.933666,133.640227,156.609936,143.401737,107.295738,-24.269802,-169.933261,-192.545106,-125.088307,-81.672319,0.239898,49.60528,80.91434,-18.830041,-60.43476,11.160107,113.654196,262.66346,271.37402,223.893486,194.199821,136.000519,44.795984,-1.246115,6.166912,62.050828,169.27403,176.10109,113.889227,15.496373,-62.636294,-169.347263,-138.449317,44.420104,139.757508,212.208389,176.840239:193.229671,109.579601,69.769069,53.197046,51.402918,10.436993,-19.016645,-89.100454,-94.326751,-36.855861,158.300559,250.829213,328.175404,311.256278,227.064749,171.116967,45.795199,-14.274603,8.099023,74.829087,67.881909,19.97914,12.595388,6.330943,-32.454672,-68.392225,-101.707494,-70.190423,16.970612,36.866989,47.414363,33.805373,-83.407966,-275.818587,-334.053656,-236.462972,-110.353058,116.073666,173.485059,117.332351,-67.571215,-139.163591,-157.211249,-95.453358,43.880035,80.795025,115.224202,107.741347,-15.283584,-189.28779,-208.548902,-61.186754,48.463569,188.104316,199.004656,127.312779,-17.706786,-96.372352,-190.951379,-194.809193,-112.892878,-37.752652,48.275227,31.711295,-29.713332,-107.746927,-155.110111,-165.181341,-113.841081,22.04712,57.646549,10.559053,-84.728935,-108.350562,-83.349071,-23.800471,179.837536,284.745688,367.682776,334.761455,251.260188,230.208883,222.864806,192.470355,163.820837,109.07924,88.01384,-12.449893,-140.557715,-159.296303,-113.455063,-74.805195,-44.318935,-68.828667,-117.418848,-115.190554,-137.117763,-228.267899,-219.63768,-3.792268,142.862331,343.69554,373.216225,320.881046,239.596834,213.429571,192.88841,191.091406,210.540913,239.581399,214.06493,119.080521,-71.637465,-184.781331,-250.583896,-271.813698,-175.754228,110.985294,209.991815,253.525361,158.510663,82.387018,3.948062,23.452082,86.99782,115.634819,162.406678,152.615893,44.855662,-63.646349,-72.526447,11.324125,86.035282,201.041755,192.545344,56.493661,-79.712317,-138.921682,-243.165358,-265.595316,-216.57116,-145.443323,-13.494801,-12.700698,-118.536388,-166.156556,-139.845614,-62.225663,-38.096932,-19.293778,-27.277985,-104.715523,-181.911172,-180.951198,-109.839884,-50.052014,67.735032,113.215004,164.88117,148.371986,30.149494,-97.200172,-118.381944,-40.478666,17.793366,70.672834,67.726043,56.005457,41.350784,-2.386066,-131.681129,-160.924485,-112.175808,-70.275948,-79.173283,-161.197011,-372.493606,-469.590912,-483.768742,-459.888101,-412.872251,-309.70472,-294.362276,-347.070968,-362.505253,-333.968895,-278.272211,-244.451823,-146.097751,-107.018248,-98.648516,-127.758038,-159.537367,-107.312629,-75.238665,21.931981,69.310732,71.571598,55.620813,69.665707,46.869986,18.540444,55.831152,114.372035,151.381013,106.873107,5.255894,-6.36013,23.092189,21.262906,0.112756,-65.62348,-112.950575,-183.387714,-173.509622,-115.205773,-175.025778,-240.007083,-255.516434,-204.103512,-134.784147,-144.248739,-229.400711,-273.543044,-313.115315,-333.331241,-346.986737,-367.617706,-357.053826,-234.800109,-159.069694,-127.652473,-146.176873,-131.140658,-122.648729,-136.200099,-141.676815,-116.941889,-69.731756,-68.085258,-62.151169,-75.077964,-99.458468,-111.205361,-105.781235,-137.680426,-161.661152,-157.729229,-102.061893,-105.232294,-151.350707,-136.674747,-7.376072,62.897024,123.259809,115.354762,88.649133,49.573756,-16.644406,-161.773751,-155.056213,27.1888,87.705854,-66.815267,-312.114003,-343.478295,-249.72545,-159.994495,-7.16358,6.465553,-83.874661,-162.051532,-288.912886,-263.891687,-198.857673,-52.327884,-8.507055,-9.29312,-34.904675,-114.0027,-276.139265,-363.560991,-397.948813,-338.277193,-249.288164,-260.452804,-282.545538,-273.77641,-279.677012,-324.86713,-335.878913,-231.731874,-117.431593,61.696548,70.638792,17.738551,42.636535,64.853397,95.103679,97.818491,36.454797,0.903794,-31.0753,-59.572164,-163.265604,-243.914139,-249.354233,-175.526571,-97.461795,81.475925,114.680731,26.480193,-52.386108,-68.625407,-102.396281,-78.878818,55.2898,93.942139,41.051378,-4.526573,-1.539949,-8.55551,-84.106495,-180.939092,-122.732573,104.985494,179.356693,147.121066,-32.46489,-121.993057,-111.139362,-2.181956,179.174703,201.782826,174.590667,136.09535,86.169606,149.422697,178.729746,176.109513,161.006899,155.084163,161.739521,160.475546,130.451393,87.768578,-100.922323,-208.57664,-229.208782,-124.059624,55.487642,38.946871,-112.942757,-182.352073,-154.294164,-61.262228,-49.885436,-80.206595,-91.228402,-100.541298,-74.263316,-65.909021,-63.312343,-23.306182,90.114294,98.650419,50.914858,41.000615,31.173365,-41.65468,-75.074416,-34.568484,34.19304,183.213631,220.750845,171.953108,91.18074,83.400615,117.599231,155.621219,253.522904,297.362659,338.758746,329.019474,273.672578,182.355975,134.16789,126.815405,175.567812,312.089408,362.211271,333.156701,146.259302,57.152233,26.889214,93.881798,249.000739,283.007008,264.484967,228.381746:72.339408,-66.499821,-82.941953,50.706276,151.725174,235.177022,184.242413,-14.767968,-114.386583,-81.606725,139.698197,282.851347,487.678446,516.663192,417.993065,303.814218,51.377937,-54.168021,-13.989424,142.718529,185.746024,204.088778,198.625614,87.818724,-95.174082,-148.641242,-137.847291,-82.273688,77.453081,158.822264,231.933099,176.717865,-103.172466,-360.575446,-373.881228,-117.211969,56.638046,234.652613,208.291289,11.661808,-147.065621,-183.895489,-182.473379,-136.097921,-1.366025,54.004227,99.744276,77.945138,-91.34172,-323.391454,-363.153245,-246.170346,-131.834349,125.547524,214.132635,146.61126,-176.474861,-310.997324,-321.235067,-230.403911,-82.357424,-53.213247,-43.399553,-60.741946,-141.923137,-267.178491,-311.775572,-231.954897,-105.068649,160.3758,208.109583,80.329763,-76.791079,-107.156678,-85.467169,-19.319945,195.906409,282.262465,276.17508,212.162746,128.316882,128.189038,149.259717,169.904288,141.557635,78.613907,55.345972,-64.088801,-229.097151,-267.189866,-230.675143,-169.363062,-32.965144,-2.31409,-70.519453,-148.214698,-281.785252,-289.075805,-238.096479,-73.997638,25.998094,227.590004,279.39385,198.624501,26.694374,-35.679933,-21.633225,67.382582,237.265079,258.614939,167.63064,79.551174,-102.81098,-273.127032,-324.861317,-221.694765,-73.681959,188.853975,225.718822,173.742579,106.018021,55.549416,-38.204039,-47.097494,22.02105,81.862111,159.432571,151.055774,66.233516,-43.889646,-65.349709,25.427192,105.162798,205.300935,204.199358,110.551127,-31.824696,-110.667023,-238.42388,-240.167682,-100.301183,-8.237088,70.168896,41.530518,-79.516092,-177.481039,-180.012727,-115.785405,-83.572491,-23.937419,-17.310296,-136.67066,-289.867196,-292.579963,-149.544045,-65.928919,37.308464,79.928727,170.820857,175.337875,42.144835,-111.131933,-94.829819,114.949789,206.777284,243.401358,214.548442,103.696785,-43.226601,-112.858846,-175.479208,-149.713524,-46.196775,-6.828326,-28.900665,-101.136889,-304.992043,-472.832724,-503.815081,-417.276372,-334.89801,-205.981826,-177.049237,-194.267941,-253.844502,-282.873884,-282.157433,-211.723711,15.110673,96.861528,116.750828,77.783178,-37.718411,-131.947225,-129.643958,21.154153,124.212865,232.414723,232.421153,153.80359,19.658284,-17.122897,33.477328,92.857789,191.331527,212.419156,149.044383,64.433658,-97.890488,-182.872822,-206.051895,-159.350059,-93.087584,14.971523,19.837309,-93.175313,-260.380115,-304.561013,-246.514625,-166.50587,-46.80513,-32.628577,-103.975209,-175.234447,-274.383725,-324.858969,-356.511181,-365.356183,-308.678092,-110.390528,-47.81568,-127.100222,-326.130541,-381.836959,-314.693133,-222.358303,-118.403059,-121.033023,-145.729732,-166.829275,-242.920096,-318.821007,-314.159479,-203.912179,-149.691429,-107.19157,-102.956829,-126.831404,-213.486146,-268.36049,-311.168572,-275.718902,-136.197699,-61.989229,42.929296,58.368606,25.125218,-28.061822,-43.484935,-53.900841,-46.029731,49.176133,100.31306,-1.379434,-318.578588,-439.352321,-421.373011,-284.836528,5.56193,74.330874,54.780862,-5.140621,-171.084577,-276.974567,-240.136105,-21.208457,85.640023,175.581474,149.217865,7.370713,-143.613674,-233.220577,-370.903138,-337.676423,-104.927957,-12.149453,-25.158684,-107.690197,-262.56656,-279.91593,-227.589547,-37.049451,68.920405,254.868925,293.93135,206.263659,68.463945,34.957395,81.193975,154.952748,281.366453,289.710006,171.231566,61.116164,-153.569704,-175.176566,-83.671606,169.014745,251.001687,308.596696,316.578432,241.702027,56.177456,-14.633645,-6.7473,70.637498,240.216416,292.787608,278.15435,210.401889,61.64633,-45.75818,-63.754931,24.706889,106.323644,243.596998,256.1205,105.346295,-92.260714,-123.190276,-20.131604,92.384202,307.562649,350.902826,279.859484,203.370763,51.778649,-34.029413,-25.721446,65.187025,107.436346,158.274382,166.457122,101.510485,-74.471887,-174.261376,-285.70957,-263.172887,-81.459247,24.162719,97.126562,43.796308,-159.883777,-332.601859,-343.665263,-216.885542,-137.020236,-44.003976,-37.341671,-70.642457,-91.186159,-96.638181,-59.795273,-3.483115,115.524833,145.10052,118.407918,75.190956,-54.771432,-218.178077,-248.942265,-131.548797,-31.029332,121.250382,152.122699,125.374972,38.234847,-6.44231,-13.962754,55.04032,264.681425,343.995443,391.62312,361.945155,211.409884,40.445301,-14.870418,-3.455599,77.27547,303.979864,369.879993,298.530997,82.672525,-27.058365,-104.397937,-15.271883,257.015824,328.198121,286.792707,206.514369:-7.755603,-105.612113,-135.603587,-190.352575,-217.407464,-195.244632,-169.027338,-190.94157,-203.657958,-181.156093,-92.388901,-17.217642,135.362932,164.879147,127.359009,90.282213,15.549838,-32.974093,-13.687817,114.811305,137.576822,-3.472762,-83.830472,-140.033117,-101.661685,-34.904012,112.429342,128.407176,77.761315,73.640818,120.274469,119.498793,8.776831,-132.055813,-162.548173,-117.627171,-58.730033,51.476636,61.677183,-24.024415,-86.365223,-90.368221,-117.137181,-134.26192,-91.767094,-29.409663,71.985912,87.410044,88.835342,55.133714,40.350059,132.906603,228.67938,359.954322,363.995486,284.387114,128.493291,47.540936,-29.913053,-26.381201,44.650998,91.898289,85.951365,37.981431,-16.345863,-73.327514,-141.717558,-223.124812,-190.009864,-38.594534,28.286183,55.453666,-19.762153,-43.30038,3.491084,78.261818,267.728857,341.803084,415.85061,416.64957,347.060865,246.909764,218.9505,212.083732,207.667163,185.260524,176.793229,115.526306,-31.18599,-75.127008,-13.8413,49.405836,70.069593,-2.932283,-221.920583,-297.391363,-341.232313,-344.103354,-315.323449,-163.204278,-72.891205,89.806088,166.664535,276.987322,265.887502,215.075372,131.850768,140.463511,202.463554,212.842132,184.541166,166.52119,110.310546,2.324904,-35.580808,-19.092164,42.845228,283.405065,409.477671,499.85064,446.559767,423.639312,421.015777,445.785801,468.364716,433.990467,295.737275,226.88657,161.321033,108.064137,59.364601,-16.102207,-17.555938,79.132642,139.929915,121.969498,10.54022,-13.497368,-53.916208,-82.807425,-80.922145,-40.794435,19.670294,17.204325,1.512913,-3.835967,-11.990351,-33.56266,-38.588793,-8.657612,6.034752,-60.936133,-217.931882,-260.411598,-177.432202,-93.096797,-11.431777,0.986046,85.220073,106.354145,-48.509025,-279.187285,-338.865492,-371.021476,-377.359504,-362.075328,-337.644604,-291.716355,-212.750868,-187.80633,-213.363523,-221.251744,-175.496627,-154.388909,-179.107968,-204.793159,-219.222552,-285.596111,-343.946306,-368.483095,-318.745704,-169.46843,-109.251318,-98.108253,-193.774552,-245.999488,-330.319474,-352.6979,-344.901438,-304.338432,-195.879976,-185.781109,-236.480374,-211.17008,-174.492751,-131.297427,-117.333944,-32.965612,15.334904,18.473313,-22.156316,-28.137322,-8.312518,25.096594,82.254478,73.102676,31.525937,47.766095,105.802556,33.195244,-14.422662,-11.030328,13.84714,36.735762,42.124547,62.78893,94.247969,90.068105,38.799833,30.827976,41.317117,5.957578,-133.256478,-180.200989,-206.260376,-286.29388,-341.341164,-305.478707,-214.444232,-50.880195,-2.919332,18.404302,-17.58142,-23.754335,-21.027791,-19.143127,21.432915,60.469919,74.275144,39.358383,2.333991,20.391969,15.702502,20.236715,53.619929,109.035635,100.6653,40.073155,-55.125783,-93.254267,-92.049139,-64.662317,-8.381266,21.898137,75.654783,84.44862,77.349187,13.245586,-57.791825,-230.380672,-276.439294,-188.607319,-114.704988,-154.439848,-348.042094,-401.212978,-393.597528,-344.356606,-240.634493,-253.555982,-451.835603,-579.717533,-652.508225,-440.062674,-345.277403,-284.621424,-276.275502,-214.79268,-164.850559,-139.179981,-319.635668,-428.900118,-487.649193,-433.088825,-293.100012,-244.259836,-219.614801,-250.892027,-355.911038,-440.701754,-447.026533,-309.157121,-197.028221,-51.516673,-19.135788,55.227727,144.786537,156.226643,86.541227,42.506554,-12.371894,-44.935152,-128.411676,-148.614201,-104.008478,-67.458668,-109.671286,-228.832914,-217.719712,-21.233776,75.793165,130.102532,86.856332,51.090934,-17.224257,-12.260713,77.129024,115.706465,104.134692,56.136818,-35.081909,-61.144475,-62.693669,13.395714,94.425669,199.465942,191.233473,108.227012,5.210537,-17.709939,48.230993,101.898728,122.762805,92.429911,35.261545,20.273538,-9.674469,-76.645475,-96.176652,-71.161977,-58.096732,-19.921127,46.517604,224.382482,188.461093,56.204682,-193.955362,-221.096173,-133.409968,-84.49327,-58.373826,-85.309371,-189.526094,-262.207888,-262.231349,-186.667367,-122.463913,4.440642,49.887671,69.038425,34.203661,25.6093,37.297791,65.384209,159.609737,196.61414,220.509007,199.486965,84.800981,-9.200414,-7.56255,107.020291,189.578795,309.074614,331.058381,324.754648,306.600758,274.493967,177.162061,168.204164,273.045723,349.317996,467.659454,483.08493,421.890473,372.071785,354.502763,265.278246,230.856384,317.999533,407.363406,476.380457,348.04448,245.654079,100.043371,125.754686,297.365187,339.338416,307.198615,277.899324:40.018613,-47.245796,-95.518784,-83.381777,-40.935286,4.705722,-4.559773,-55.479763,-108.022695,-113.936573,-14.366555,69.85254,154.230399,150.717468,99.731675,47.977294,-56.105385,-138.633488,-168.584215,-131.0442,-94.05138,-137.364035,-196.440296,-225.736438,-138.572342,-105.984021,-101.689239,-104.54816,-29.064377,49.948499,118.363814,49.654463,-152.96162,-253.69361,-286.706618,-296.132636,-245.556143,-38.73989,58.981886,63.263764,-74.897035,-102.687218,-44.243409,-3.788532,21.328461,33.159643,102.053771,134.952568,154.042411,95.239672,49.876965,41.489681,104.796247,273.824673,314.746019,275.005052,155.617377,73.391808,-42.35637,-42.36949,12.324403,43.326971,73.224775,77.495431,148.997013,165.859579,105.213136,4.406385,8.393188,68.080321,87.753838,66.026959,44.581926,60.929225,114.646144,148.393753,239.885645,301.174802,419.748434,446.142979,426.782093,365.82535,329.184503,232.773002,188.953547,195.805282,227.658035,215.9604,96.30815,31.702194,-5.664377,38.290406,124.137789,113.458512,7.649135,-59.001518,-166.877557,-223.320526,-211.621303,-48.797745,83.084908,317.139848,367.985892,309.568573,193.528493,142.796626,72.671411,98.680538,258.70622,327.039598,339.592713,292.919147,190.090171,66.196376,-10.684056,-15.511869,89.198153,327.670786,389.181753,410.532291,387.583661,348.698124,241.789827,226.833811,277.413911,294.391709,272.799175,251.303787,179.256589,36.666982,-10.163475,45.831295,114.541065,202.673448,212.464999,175.388769,63.271639,-1.855753,-58.593732,-41.950683,-6.110695,0.663667,25.119378,29.332197,-9.659321,-32.949766,-39.987676,-102.677821,-129.920032,-86.731341,-39.619273,-20.623166,-80.037195,-91.478561,-27.130691,34.650184,107.500604,125.370845,202.79821,218.609062,70.272483,-166.611576,-216.650116,-164.890176,-128.187306,-77.224034,-44.326984,-14.999333,-25.125188,-36.439811,-98.576945,-128.910725,-177.209645,-206.678658,-227.540261,-211.713192,-228.215164,-399.108047,-477.87926,-436.144981,-350.421326,-245.598422,-228.335186,-186.802314,-200.809762,-254.598803,-364.882138,-382.322656,-327.997312,-260.538737,-138.022905,-131.840354,-194.761789,-242.506355,-223.90333,-78.859521,-16.300786,-15.20487,-31.081535,-44.184533,-77.854994,-84.712664,-22.81565,32.974106,51.930774,-4.761225,-123.507111,-136.825194,-90.843479,-69.654313,-62.107289,-29.654002,-47.292641,-175.958899,-210.305561,-74.41705,84.493767,67.895544,-37.354488,-39.424366,33.153054,10.37769,-226.849157,-330.064955,-335.162327,-338.190698,-357.306333,-293.357725,-232.384142,-134.617718,-109.97697,-148.907657,-200.635212,-186.708372,-119.29864,-91.399602,-52.421963,-44.65988,-79.56281,-88.317677,-14.106428,-23.545731,-97.786755,-166.098305,-116.271108,-36.721253,-61.505747,-101.08333,-31.10701,-7.802756,0.169006,18.754052,76.853084,101.421151,134.86343,136.249479,120.797848,90.640624,49.554623,-90.648776,-148.13778,-82.890959,9.268602,6.70354,-193.882244,-240.706585,-255.908413,-250.834007,-165.09254,-117.726925,-205.907871,-329.18666,-438.125022,-256.474104,-165.033377,-115.351901,-138.750075,-145.84365,-89.03495,7.112873,-133.985841,-244.106142,-343.820208,-314.05237,-185.079941,-132.965704,-111.407184,-133.741962,-199.423723,-305.847994,-344.988509,-219.751677,-73.287618,125.347924,139.088727,131.478132,213.8864,260.596469,268.107003,228.266469,105.028309,65.569734,48.42,22.783689,-38.791937,-50.672951,-58.032803,-35.652932,-9.291731,21.12085,40.096729,90.436136,43.097562,-28.76261,-123.747449,-98.608991,-30.76989,-47.58299,-105.647484,-96.497122,-11.49136,-35.080701,-103.695722,-143.059291,-68.453691,150.176552,210.600293,130.159714,-40.486867,-78.032886,-59.903259,-31.583182,61.36266,121.120669,161.709137,128.338711,93.208952,138.849888,127.460879,36.252102,22.299749,133.505606,217.495375,304.631639,208.486555,95.425942,-126.556574,-171.267814,-153.264566,-145.411315,-146.027812,-133.123528,-116.118062,-154.131892,-168.480706,-129.404875,-81.733908,-1.693037,4.817189,-58.186742,-126.334852,-120.020039,-19.72217,38.588685,98.37783,120.100973,183.857674,185.336363,103.868304,12.119396,-29.340633,-59.799357,-28.369808,112.887623,193.418652,320.163431,322.7663,236.691926,59.459668,68.473973,221.071928,292.116588,361.893253,345.021557,243.658884,239.150762,278.498672,321.943239,297.954097,225.332549,218.843881,248.809807,217.325583,154.908112,43.61885,51.605842,144.016348,179.854214,184.435311,145.364752:175.153016,37.018333,-36.095606,-51.641459,-26.832779,-19.377193,-46.451129,-147.102728,-125.592518,-49.081013,91.538433,136.382302,239.682345,294.987228,289.832795,212.095559,13.697812,-95.51508,-63.012469,102.380489,125.365195,73.575672,80.783989,115.447066,56.941793,24.303433,46.591669,73.447388,115.628671,164.114693,234.965118,172.230862,-104.689538,-253.721123,-213.319235,-24.017155,43.13501,128.88576,153.925412,63.849979,-103.038501,-151.191104,-160.04614,-114.264429,47.521202,135.23657,239.452709,218.695254,71.46095,-14.003628,-3.998821,48.167601,71.595951,149.106808,191.798053,160.237623,-63.299396,-169.629956,-229.084593,-191.934886,-95.120429,-75.271757,-74.24697,-57.546836,-18.80351,-140.584944,-232.999634,-241.298096,-141.942882,60.659533,90.243192,5.875693,-121.334884,-164.247703,-157.147241,-92.995266,91.101384,176.14047,262.126472,226.48312,91.05045,106.549296,165.06648,233.104135,215.582067,162.870166,128.21827,-50.098406,-197.932346,-189.959859,-145.786405,-158.008599,-178.305681,-176.094248,-216.776169,-237.990063,-212.51113,-233.98252,-254.114444,-130.444378,2.457433,232.625552,291.749935,267.312213,139.997905,96.139951,99.73475,130.189252,171.719593,176.750721,183.95725,176.9344,95.27739,-43.57429,-96.22816,-100.091872,-47.909297,134.127378,231.606172,320.068623,272.546345,234.175631,155.718642,128.717292,159.379521,229.766142,343.028892,304.545043,98.968611,-9.593853,-7.782195,44.509634,81.360266,143.468947,142.257777,50.382594,-79.719002,-132.340217,-170.917157,-159.587845,-128.316153,-102.028802,1.338503,30.845791,-27.601097,-72.892787,-48.023248,31.511242,51.423293,47.033598,24.924316,-95.446834,-227.743507,-234.929607,-107.650156,-21.634191,81.334408,117.034687,161.64938,127.920201,-13.74424,-115.794691,-118.441145,-43.544231,-37.645141,-98.714218,-101.694163,-69.44079,-112.199809,-155.155298,-193.749185,-173.416209,-109.931404,-101.627567,-129.280425,-139.518908,-176.983672,-323.409015,-391.78658,-360.827341,-295.657154,-233.845051,-225.779972,-197.614245,-204.556937,-209.632443,-186.843361,-190.423556,-211.431486,-172.414189,-59.565001,-58.315978,-125.458776,-149.904047,-136.93412,6.92518,122.326989,253.324607,231.025671,101.700709,24.005324,20.621432,54.584749,85.420182,132.537857,138.006827,141.678931,137.539473,101.159447,30.768249,-6.655452,11.760849,62.456241,96.64901,69.51628,34.662581,-16.42945,-86.069042,-179.562495,-148.071227,-23.900462,-11.642437,-94.425968,-123.284145,-112.861453,-182.583916,-229.438403,-193.60566,-140.431517,-76.343462,-59.735792,-37.480869,-51.124141,-65.994883,-86.127389,-82.246359,-15.184842,39.220672,102.85679,97.342048,45.092157,-38.646678,-64.233697,-27.792861,-1.677471,27.034929,36.546638,-6.631095,-85.456755,-105.859956,-125.803197,-117.106395,-25.965915,45.096884,176.247666,197.874226,142.812797,133.815717,135.598944,24.215794,-53.222422,-57.000106,-10.269955,-94.842895,-334.805089,-392.488068,-364.030271,-302.447742,-174.407163,-145.746349,-166.640589,-220.318127,-336.741667,-260.587072,-159.627415,-15.692576,-10.515395,-39.678386,-56.968373,-147.218635,-259.987874,-313.278516,-341.406447,-286.982974,-145.95873,-104.185989,-73.822455,-87.378944,-160.241334,-219.795624,-216.030769,-95.313716,0.850676,158.908131,191.997952,139.742882,84.228595,110.391684,200.874422,210.326036,148.780648,128.118453,113.518793,65.051425,-72.115458,-121.419551,-118.408699,-25.727713,48.857971,157.81771,194.11384,218.096363,120.417363,30.727404,-101.68045,-76.668093,48.232984,66.340333,70.466552,84.00904,58.861584,-1.264739,-1.529676,60.132419,90.24128,138.751144,173.931865,171.816328,5.019384,-71.955509,-30.560674,71.27749,188.209853,163.980937,95.948986,90.77705,53.05661,-71.491804,-107.416695,-66.940282,-43.26193,-29.648023,0.814255,47.891319,-106.131015,-218.73282,-323.251188,-297.591133,-203.320503,-176.059746,-154.01606,-157.49183,-248.940714,-405.350047,-419.909242,-234.433815,-128.151719,-96.538206,-122.384772,-100.819422,-1.38638,18.670996,-46.147099,-64.392634,12.72267,51.347557,74.392788,64.87163,-18.613368,-77.154189,-67.712607,-1.887167,40.701707,133.838661,172.870079,169.119765,67.354951,8.915603,-35.501916,12.161908,200.803153,285.340403,360.722377,355.915988,235.670158,24.621705,-30.75841,28.939155,110.4764,269.028131,302.864875,221.6755,58.125678,1.806142,-16.841136,17.579866,101.576732,138.668623,211.671721,214.560244:forward
-213.78735,-311.648501,-337.109494,-342.392225,-320.782866,-272.905404,-251.668955,-226.696358,-222.259106,-235.607785,-320.501807,-353.826547,-359.069571,-359.863698,-363.956196,-359.901977,-344.9853,-336.888435,-330.639972,-271.382106,-239.61954,-237.563909,-260.422708,-371.691273,-463.434375,-444.349054,-367.162591,-343.483715,-334.206418,-363.474269,-504.122243,-586.006777,-628.570276,-440.07775,-328.53429,-186.31874,-155.455586,-177.771177,-229.105955,-384.849613,-506.301834,-508.974509,-415.375729,-341.03881,-192.201953,-150.16299,-166.500594,-205.036136,-203.525151,-88.027963,-56.729443,-42.4285,-55.486807,-152.917376,-193.665108,-150.123001,-5.202113,66.752571,180.668653,205.533801,122.106674,37.828023,-50.491975,-56.602633,-76.593442,-122.929142,-148.724651,-130.180832,-95.698347,-86.770193,-110.355488,-103.340066,-5.901053,38.239467,86.645279,106.316145,123.928546,106.30596,70.850305,51.838793,-34.256565,-75.509309,-65.766513,-23.435269,7.318224,71.908506,88.541153,24.620045,-35.268846,7.141923,138.062708,179.26039,191.820621,169.258651,91.251173,28.401672,-102.612819,-126.025548,-81.673723,76.433188,137.58012,156.99427,128.102062,-7.379925,-190.56305,-216.379637,-81.96458,7.524999,31.106256,-42.332694,-210.315445,-256.202363,-250.143547,-170.700358,-150.109963,-124.225577,-86.359479,-8.488451,5.297128,-8.969667,-26.712452,-15.029392,119.701714,230.398941,330.143389,283.171374,150.161287,96.479848,-11.633866,-20.170533,27.164153,89.190014,77.855303,1.508932,-59.832453,-207.526718,-290.015015,-279.078109,-185.950019,-122.196324,-16.522675,-8.401973,-69.59026,-103.999158,-151.042458,-160.024912,-157.806455,-134.740824,-119.186851,-169.362887,-237.239805,-352.718509,-311.519455,-247.005443,-154.927678,-132.501345,-130.002141,-168.162472,-287.672427,-338.693464,-374.660299,-322.320553,-287.672655,-187.851746,-107.334556,30.6412,39.745574,-48.81198,-80.738151,-31.194804,124.578968,204.052967,305.961421,301.922762,235.422679,198.853293,141.060412,176.57389,215.667551,297.387715,330.36761,308.883697,261.775168,205.897518,226.001261,218.155043,154.665066,162.939782,278.706753,294.310447,165.238819,83.648673,-1.35367,17.992929,49.17116,117.439311,134.711176,108.213645,81.429303,25.510584,-5.611841,25.541785,165.493677,229.544392,259.960509,222.782999,113.446827,57.807674,-73.775415,-179.852738,-179.725514,-44.060103,32.218705,59.586432,36.109013,-2.276142,13.17202,44.861264,89.167515,101.279099,116.946212,96.369281,24.949155,18.044828,54.741176,61.414882,63.023409,156.438398,247.976577,366.612422,343.383005,161.550379,39.812848,73.1063,194.262712,216.451174,215.207549,198.714637,58.865041,-47.797363,-199.737942,-283.237068,-329.667794,-351.075422,-302.606446,-165.973041,-122.266752,-121.169278,-141.735441,-130.977992,-89.314986,-49.897043,37.858855,39.343578,-33.319991,-58.710935,-92.117212,-212.915389,-277.919074,-279.174682,-218.241145,-151.492839,-174.391932,-225.393697,-232.421466,-227.635147,-148.57297,-47.944553,203.566219,275.81591,249.953814,206.584598,214.553345,354.386032,416.789176,449.769378,412.790857,273.006933,226.252073,208.788127,126.194479,63.496079,-11.383721,-14.107886,26.928216,55.032489,93.158004,90.40945,67.659817,162.325969,268.16071,436.646642,434.962582,312.967468,258.0037,219.344512,257.164898,312.613179,465.525359,525.652282,531.855538,473.184343,327.42379,258.726646,109.553386,59.082741,71.936593,103.791825,130.346655,184.344682,191.916009,161.793784,120.718786,128.144534,197.465477,252.112807,355.548446,356.001238,254.712018,210.366692,185.554126,165.380122,138.340042,76.121856,55.613899,29.543861,30.689125,50.493524,-18.456455,-61.346323,-48.484683,-5.562097,-32.304174,-115.052392,-158.977274,-93.752709,-11.476839,-9.899035,29.263064,148.462891,171.580183,132.28581,119.357531,123.546448,61.172449,46.786292,112.444834,147.170246,207.139426,239.700022,192.153622,90.699298,-102.375237,-117.652097,-87.828543,-11.787345,37.956952,82.931292,42.899917,-109.824081,-192.38868,-179.508074,-95.680606,-37.294696,66.510656,79.19468,34.086779,-4.237861,-136.748047,-239.219498,-221.09685,-102.920712,-56.014314,-53.637837,-74.359547,-95.005537,-97.7076,-95.550881,-75.982651,-56.126937,-6.996935,18.676447,86.309629,112.587738,102.381876,102.493074,129.30326,159.744051,137.867718,58.193045,34.847942,-0.421358,-64.022652,-73.714717,-51.265075,-52.859538,-121.732932,-172.118381,-191.602946,-150.355804:-271.888187,-309.38271,-303.959832,-283.562733,-301.907846,-374.318196,-380.820052,-315.837262,-272.279633,-291.979989,-356.595462,-343.118361,-267.972246,-273.871128,-355.483897,-389.141372,-420.903276,-465.975366,-492.341486,-463.714795,-418.414966,-400.495838,-440.158709,-534.121446,-544.957201,-520.740012,-461.755784,-431.467284,-439.289194,-494.245741,-602.210696,-617.094115,-558.098214,-431.205711,-380.73338,-284.287553,-229.544888,-216.030168,-262.215229,-351.580908,-415.757174,-426.312216,-346.496765,-267.695606,-127.247106,-95.195069,-130.89336,-183.192824,-238.612691,-147.000459,-71.798978,31.831485,17.448938,-117.621914,-180.71835,-200.350724,-75.701439,-21.958838,-13.429474,-12.723461,28.544954,43.053089,9.872073,-47.425706,-142.566086,-115.691757,-96.01834,-55.283514,-29.921207,-49.49577,-96.707276,-171.095278,-189.054981,-165.194392,-33.159129,26.186052,-7.420438,-76.244145,-161.533023,-171.541758,-194.942904,-198.255412,-177.028226,-129.140962,-121.24424,-137.770565,-154.859957,-223.850943,-241.00271,-176.404681,57.818726,173.369047,272.12241,239.109089,78.953236,0.883163,-33.843447,53.029725,91.043589,161.662336,195.34847,199.017444,159.708738,46.456518,-65.660805,-98.230239,-41.936904,31.585344,108.869837,82.576936,-48.459201,-135.637453,-284.496088,-286.320294,-237.196878,-94.339506,-49.960621,-84.068857,-115.633021,-143.871413,-191.218134,-206.199982,-110.475295,2.475218,166.80734,157.832071,56.134036,7.157312,-73.875021,-78.986103,-33.330101,75.463905,82.732586,-22.319105,-104.803846,-258.24639,-346.404573,-337.443179,-169.586465,-48.879392,108.550737,119.280255,26.301968,-48.491956,-114.075948,15.532263,83.886075,83.941108,46.483252,-9.337807,-49.256371,-196.606971,-266.066239,-223.055595,-110.632905,-74.533133,-7.09567,-7.434756,-151.641571,-233.733645,-201.967243,-3.892944,53.049734,81.15461,98.214015,178.60924,216.925543,199.413594,135.703053,138.126136,180.336352,207.307581,250.620215,239.500574,136.309114,87.881356,123.168055,261.287186,305.993627,345.007743,349.946075,281.271869,211.645567,95.902661,64.971008,62.95407,71.409149,113.508961,213.265319,206.045365,53.688279,-56.225696,-210.295681,-171.750235,-116.363806,-67.956281,-82.679033,-62.230652,1.869067,87.979428,53.101635,54.485071,133.564908,176.177603,189.22156,172.836226,123.465356,69.424039,-65.694864,-117.975564,-103.282253,-1.466494,44.847327,39.781037,16.737111,-24.0983,-16.169441,27.106904,103.288214,125.956162,157.140431,129.345551,-32.12908,-90.675666,-16.467224,125.031974,156.666879,224.659074,246.934279,171.786301,106.596115,20.920027,49.358643,111.545967,183.942095,163.328729,128.420818,127.809638,31.306765,-75.165414,-249.245477,-280.995124,-269.34957,-201.540427,-171.723327,-200.537159,-227.257102,-171.809405,-0.791016,43.462375,-11.227797,-54.043743,-93.012325,-90.635079,-41.493543,-22.285019,-62.018114,-159.243477,-196.148593,-192.785805,-155.464946,-102.284749,-116.301635,-173.727581,-124.263742,-84.266996,-58.445616,-31.543116,149.474185,265.176479,385.303864,383.089451,391.908773,497.508415,530.351066,517.268077,498.21795,426.959044,369.822485,262.412244,213.153043,208.229618,190.373986,183.895551,215.061753,228.872027,207.067397,190.847907,185.707776,222.475346,267.435922,363.460619,378.101394,378.321484,387.606127,369.445272,360.669374,391.201071,448.458223,471.810417,489.186938,449.345463,296.058784,212.877842,86.99328,78.430018,112.134244,182.264903,200.194029,181.357447,149.909463,90.373191,85.535381,98.801336,123.959006,137.616998,153.906169,149.84308,143.794645,150.236228,158.314021,144.544397,122.863792,74.143524,68.73531,59.564781,26.232824,-78.847636,-113.407642,-90.473506,-4.18998,41.276622,66.065891,43.549227,9.189935,2.276447,-30.663924,-16.55307,40.026913,176.030787,209.681895,224.544272,247.014094,290.965835,221.714556,190.702328,244.324578,300.115872,352.795006,337.860715,212.160613,101.89167,-64.571752,-44.396514,-15.759876,12.344845,27.767158,48.690644,27.860501,-55.667968,-93.341656,-89.581359,-20.733776,62.716013,191.465312,178.916354,88.924113,34.86982,-150.519388,-318.569864,-320.019049,-174.140177,-98.32483,-59.500528,-83.92179,-137.196087,-135.961732,-115.323973,-46.992593,-9.790822,20.34446,13.413287,35.037595,78.011804,155.296214,164.460619,160.418991,135.308453,100.082926,41.852884,44.05429,18.067884,-88.990018,-102.931609,-49.564307,-24.427644,-46.801805,-110.18568,-263.151803,-306.381559:-177.646878,-227.417275,-228.848594,-157.432674,-130.60513,-198.256029,-249.300079,-271.224085,-254.020273,-251.090162,-209.012743,-177.692014,-203.779712,-262.079324,-345.975755,-347.047487,-297.10981,-278.474475,-287.633067,-283.896991,-288.02225,-359.918332,-412.533859,-510.450341,-506.293188,-443.98555,-309.380665,-288.690643,-353.991646,-414.913582,-498.590302,-505.975273,-457.664754,-347.231548,-293.886335,-203.142635,-179.069009,-229.561208,-283.399491,-336.295367,-307.191538,-288.189661,-219.982051,-169.733003,-126.168446,-135.639463,-127.695361,-118.287187,-154.051526,-163.786256,-121.416536,-41.210651,-57.249854,-170.914368,-218.539711,-257.017719,-260.355824,-238.716713,-103.013631,-17.854606,41.70704,2.333476,-108.62919,-132.392475,-93.235526,-63.223458,-70.173125,-68.64856,-67.772156,-123.842199,-179.166282,-254.306547,-206.29091,-161.507218,-120.560357,-135.81127,-157.151383,-146.322038,-181.667619,-242.378665,-309.134691,-215.586979,-169.998213,-180.431763,-216.653868,-270.221812,-281.611527,-290.519778,-247.584394,-179.42647,87.979645,245.700977,348.377676,250.147878,-32.108702,-104.523129,-14.431271,183.701992,243.994255,269.220322,239.084591,137.645826,96.818014,54.350586,-3.241658,-28.137246,50.855153,150.46007,235.432471,165.247711,-56.696296,-133.17104,-142.617732,-75.227021,-76.78924,-145.989329,-187.536854,-237.680135,-254.866413,-325.95527,-366.572251,-332.439404,-176.619161,-82.549521,30.260721,20.446306,-74.692012,-128.084774,-197.576015,-194.142746,-177.356041,-131.687921,-102.937805,-89.245302,-139.447064,-305.696748,-342.829535,-279.295344,-96.948098,-36.249106,-3.658355,-6.202516,-48.609272,-108.612855,-213.569676,-140.060262,-79.019185,-23.817365,-28.097803,-84.914138,-134.608082,-264.962837,-313.733242,-264.2911,-123.315254,-86.661911,-66.894352,-65.782379,-105.226253,-134.889194,-95.246845,14.981381,39.019909,100.916201,138.741574,184.758383,210.652227,232.985726,180.60138,170.892885,244.687013,298.526857,338.064724,292.025875,82.107322,-17.064117,-55.344589,106.575649,206.587239,305.701693,276.931938,144.835206,78.114799,-29.805311,-32.654233,-2.332028,70.970819,118.510763,174.187291,137.799343,-57.764567,-162.390478,-249.098595,-164.268192,-91.514875,6.068522,-7.88086,-116.560297,-151.494056,-111.430093,-18.782972,-4.978137,10.283078,53.834147,184.492542,226.404615,165.409485,64.453933,-133.19665,-105.77562,-16.413489,122.043905,130.27559,69.864988,41.211479,9.094522,-2.55229,14.679502,121.107586,197.079818,251.532044,182.710405,-49.487778,-119.731954,-72.012779,55.594403,87.635004,153.490904,203.878038,305.593057,339.94214,290.972708,201.653168,213.08872,239.65433,205.436706,105.12316,85.651109,68.485355,16.827846,-126.581734,-155.402206,-138.072737,-96.60632,-94.33474,-147.433472,-174.614848,-151.594064,-44.250418,-15.699988,-38.488869,-44.727735,-8.187441,-2.510923,-84.046467,-145.269578,-186.545643,-143.487178,-130.160941,-55.457709,7.76098,27.307975,-38.412383,-136.638573,14.618175,121.337787,194.141643,178.33361,218.248701,295.803551,433.519458,442.321366,409.063246,466.049694,523.356636,558.277964,511.867499,404.468269,379.357448,347.381118,355.346502,380.681678,374.424929,328.796605,237.99515,223.777774,257.197333,279.512497,285.946579,283.745432,306.021792,391.812739,422.175393,387.479022,341.369436,284.581338,340.330943,390.414392,450.903259,461.024406,415.313302,333.733776,145.830783,98.839851,50.312407,-34.842831,-42.180123,55.07496,96.729892,56.446171,-6.144908,-113.097053,-94.814123,-53.956475,-22.226489,-20.587904,22.133326,32.873146,-33.002727,-76.603185,-62.246342,61.475316,100.045067,88.070967,63.074093,0.266673,-56.229105,-194.941545,-164.65385,-80.608947,61.748326,87.950472,55.423946,27.217148,-1.962902,-31.899552,-113.962927,-54.789559,26.93121,171.56268,205.853454,198.62948,184.107286,184.772291,190.267468,175.270586,164.352028,197.051341,272.182614,268.925332,130.299625,18.834778,-113.21677,-70.935754,-59.233452,-128.646199,-151.238173,-73.766372,-41.540688,-86.929617,-83.299458,-32.472652,75.819586,110.85365,128.155237,110.412965,37.959391,-2.888474,-66.912243,-142.573749,-196.516085,-226.679274,-177.613994,-119.135619,-155.985208,-212.435649,-130.345387,-90.927875,-76.713262,-65.750145,-26.248711,-28.244186,-35.104022,-24.341431,-25.092683,1.886378,51.742424,121.264569,83.592831,-77.781324,-124.94105,-136.291906,-138.513891,-132.549735,-99.959573,-91.318504,-124.309032,-154.677557,-202.429869,-220.938676:-187.407388,-264.596099,-314.421127,-313.217943,-270.279027,-239.862604,-249.818715,-249.637218,-247.84437,-251.148249,-235.811712,-208.9131,-166.687924,-172.42855,-195.086196,-202.919464,-235.365091,-255.868813,-234.902398,-127.647907,-98.705051,-184.21552,-261.807335,-405.072444,-439.504936,-403.994536,-340.160187,-328.822289,-307.397781,-305.384139,-333.35553,-351.213669,-356.995525,-222.986931,-122.327262,-20.631232,-41.488919,-151.099955,-200.029978,-265.652605,-310.571237,-312.066664,-275.58323,-240.185991,-147.037847,-106.325783,-95.708665,-145.872332,-274.478227,-243.95753,-152.520605,22.214025,22.414033,-109.829541,-170.582443,-228.286135,-149.627324,-80.232654,8.424023,40.712172,87.143974,77.855941,42.678878,27.907273,-36.752187,-143.190266,-192.693369,-209.618975,-182.948563,-167.479853,-193.647061,-245.794061,-188.012333,-128.14358,-60.500418,-35.93169,49.003878,78.740853,70.906436,34.918677,-64.475226,-66.061173,-24.131011,54.182214,65.408435,37.09674,9.8533,-89.665861,-161.984869,-127.427358,65.734326,171.764736,246.233,192.843318,32.320742,-29.565033,-86.998638,27.124603,144.968347,353.724575,371.920457,232.595916,151.214509,38.147251,-62.002744,-74.569349,33.98542,118.096777,172.050053,111.719772,-72.208836,-138.768618,-161.57182,-95.621594,-67.046549,-30.178731,-38.218858,-106.238743,-128.041002,-160.70411,-197.198367,-172.827049,-40.342856,39.812697,134.58131,120.155495,18.996714,-38.011545,-126.791226,-132.027742,-124.443672,-124.699961,-123.086739,-132.865959,-164.059923,-302.23693,-424.593695,-417.71697,-273.347394,-168.880415,-20.69883,-24.322948,-136.957516,-185.815183,-223.002718,-233.566881,-227.723432,-178.559437,-162.283286,-179.658065,-212.608882,-363.536918,-423.903646,-352.953387,-169.022738,-115.329237,-82.584653,-99.516437,-215.120628,-297.748939,-374.231298,-245.252572,-162.429502,0.052447,90.05314,181.974586,149.282001,-17.559994,-56.945823,21.92497,197.839678,239.640384,254.344609,235.488306,168.248337,142.391799,131.677531,198.86913,252.58118,343.533355,365.74093,362.746282,336.551733,214.325528,92.955545,76.272106,95.753738,123.210094,198.234604,213.404155,100.362582,-33.717662,-254.669886,-188.18557,-118.834394,-88.402674,-107.134952,-72.958162,-21.795997,-18.144565,-86.766759,-63.398978,56.337998,121.130384,209.78726,194.997765,72.912745,14.824598,-70.187738,-113.592565,-104.888888,-39.608342,-10.90203,11.519188,12.447908,-34.961105,-101.715344,-93.407684,21.582621,89.037353,106.31931,53.709357,-46.191388,-70.525777,-91.129414,-25.904383,45.436986,180.2189,214.764779,227.803798,221.898967,178.922147,169.250978,205.628436,261.399605,246.549122,170.455533,134.410005,59.009365,-3.812234,-177.182851,-301.386724,-309.651167,-236.21498,-197.228521,-174.708952,-177.852205,-205.979274,-218.895636,-194.1102,-105.093655,-55.074736,-35.327587,-91.656072,-201.955262,-202.682501,-190.640154,-250.284677,-268.827881,-246.356138,-212.12352,-169.696108,-196.164918,-266.469877,-196.282058,-125.230133,-10.116905,38.220015,154.103591,189.196573,199.161116,214.724405,288.427074,375.478908,415.445586,436.483839,396.684751,262.333647,218.71806,207.013684,191.539147,164.150946,94.705556,79.214875,103.559225,118.379131,126.47028,134.464675,204.245091,316.619153,357.76621,429.403906,456.319001,402.541293,327.630823,253.406669,366.437102,430.93547,495.957486,524.893879,551.134124,491.632742,256.264344,145.252449,28.763292,66.205362,114.771183,181.638433,185.858478,148.844969,116.677456,24.083736,-50.808467,-53.215531,21.281566,92.320108,196.429081,199.902467,164.900354,134.182172,54.335508,51.311056,76.032544,95.822633,70.6353,-13.933583,-44.4757,-91.913019,-111.158489,-107.072299,-95.703092,-70.442652,-0.283967,5.927137,-67.029425,-137.537134,-260.939505,-238.85643,-178.571935,-28.201879,25.097648,27.987927,12.048873,5.184103,-33.829703,-38.454534,57.696704,128.708765,198.250358,184.606357,85.346784,9.614917,-118.433935,-131.120887,-116.588834,-65.363785,-26.371222,-4.215971,-46.066097,-171.228859,-210.493229,-174.455413,-53.946791,-5.6037,48.398301,72.491874,122.829697,119.258952,-5.672884,-162.196994,-182.00384,-115.971729,-87.071063,-113.775605,-147.022328,-177.670608,-121.643443,-70.38647,-7.633949,-15.285087,-63.918618,-68.675231,-1.844196,31.13112,20.821178,-9.74164,2.945854,59.673372,58.864597,-12.980532,-39.668096,-69.114566,-133.390999,-136.503058,-61.044231,-33.205456,-64.600204,-99.743682,-151.630048,-163.796272:-283.118027,-205.244778,-160.761906,-118.735867,-136.252528,-244.612361,-291.648431,-281.452335,-210.989413,-188.350759,-143.188072,-119.945622,-137.306555,-178.61276,-278.842132,-316.195969,-291.391619,-148.506944,-85.755844,-61.691254,-98.968405,-182.762729,-227.047784,-383.119554,-404.79187,-306.425254,-133.658938,-138.625033,-205.69366,-216.293934,-251.457542,-282.734469,-284.932257,-161.898997,-79.838081,-1.086955,-39.900815,-201.631518,-268.557588,-295.054209,-203.426814,-182.302021,-221.595603,-221.593802,-136.593767,-94.241172,-109.352996,-166.527413,-267.380442,-187.622266,-102.93753,-28.94224,-58.589104,-144.450561,-178.623808,-237.082197,-200.25707,-139.736063,-31.608462,0.163683,44.680524,48.081442,-40.113894,-118.314865,-241.374022,-229.725455,-184.524855,-135.379676,-162.302488,-279.078339,-326.077347,-336.110221,-252.484709,-210.035735,-149.393074,-111.357941,-73.942676,-105.439337,-224.749985,-278.973308,-289.828604,-186.235958,-128.067323,-19.081524,5.148022,-23.755305,-47.711725,-133.160717,-193.421087,-145.68092,73.843408,180.336536,233.491845,183.168762,52.561727,7.323734,26.475573,186.880873,280.115184,430.448763,436.929977,276.082924,180.361271,56.072278,-23.244821,-28.453072,102.89243,214.6646,299.635744,224.301397,-12.195875,-97.593409,-143.830154,-84.044515,-40.1647,32.411175,26.526278,-64.160296,-107.776833,-186.790455,-228.178461,-192.879498,-29.305011,55.696068,111.640938,67.690777,-51.077982,-89.009999,-148.676201,-152.106393,-130.130507,-105.068006,-117.150097,-181.25919,-222.323566,-323.133552,-397.303964,-377.457935,-214.5464,-128.126595,-42.999132,-30.510839,-75.008457,-142.730017,-239.161443,-167.822049,-129.275703,-100.027523,-70.583027,9.101305,-13.708132,-271.079414,-390.548754,-279.662946,13.23818,78.132833,28.112857,-29.822551,-131.468559,-176.02731,-171.337489,-35.779144,25.319612,129.885679,186.973555,265.428595,255.81421,131.579388,81.525486,130.017929,242.123112,275.413015,316.249938,299.614503,147.807188,69.141682,68.224855,222.064307,294.659146,391.174221,391.464068,275.572481,192.159874,36.127483,-26.696486,0.801704,144.18227,231.304724,298.22893,240.411789,-4.457317,-146.133362,-295.051169,-177.524983,-79.315938,30.441324,19.536999,-10.38579,-8.325019,-77.289279,-115.80848,-50.195854,157.420376,229.094442,214.679559,170.168274,123.088619,93.217936,17.021149,29.365846,73.62,204.184468,245.372986,193.212544,123.777692,-0.428033,-15.62435,12.700374,128.408759,203.517946,211.573417,137.972354,44.900201,36.844981,13.300137,71.132699,148.310871,294.137176,330.652164,352.360928,351.505005,345.767171,384.156636,418.927067,446.756098,427.357243,355.225442,306.684543,170.349136,92.323328,-28.233764,-89.070832,-87.284789,-7.212086,29.000817,-9.336779,-60.286755,-105.588763,-67.072539,-56.205244,-38.801645,-5.933255,44.552327,18.237749,-112.077697,-167.749083,-174.978396,-97.293937,-77.483506,-66.594536,-41.167984,24.719984,16.501951,-114.230485,-149.511051,-78.66197,68.553557,104.491944,141.076767,154.577079,183.770445,200.517102,240.142353,329.071875,392.539738,459.779616,425.606448,259.352735,183.452584,139.454352,191.494783,187.652656,147.926382,173.326605,239.112193,206.633615,58.039035,19.589833,73.149545,188.144273,244.909073,340.159146,345.634279,248.798149,177.308809,65.610962,101.405477,175.487633,318.825844,342.678518,275.602313,210.756351,63.732622,-19.969675,-171.822249,-192.837912,-134.468191,36.277968,74.649454,-4.245674,-80.493648,-222.203944,-245.632019,-205.697897,-100.842222,-57.111439,-47.679494,-76.833083,-125.957615,-149.841997,-202.666446,-154.856367,-82.400954,30.544583,13.781016,-158.317869,-259.845634,-344.627537,-252.588855,-194.071402,-101.064823,-73.152646,-80.307312,-98.153864,-128.399135,-162.855135,-262.627218,-240.807034,-176.345293,-46.877194,-13.65066,-28.403644,-59.395653,-112.981281,-80.256558,-31.476938,95.66599,154.805213,166.107723,124.34762,35.511974,-20.57842,-132.084072,-119.248624,-98.291106,-71.523308,-44.201321,-16.963392,-44.017305,-101.454598,-34.692039,33.536042,128.490545,133.226964,84.942326,63.082649,45.014715,26.095225,-72.348018,-171.284267,-185.809999,-148.552992,-127.973238,-181.604562,-246.144109,-340.711419,-307.04845,-247.472044,-101.245226,-55.836514,-99.963519,-153.628064,-185.914793,-180.727613,-226.070719,-248.678256,-202.806622,-79.319705,-69.925515,-125.273398,-149.234312,-227.673193,-252.728468,-208.673843,-127.157408,-119.48459,-158.345429,-195.699276,-289.595859,-325.908778:-150.802315,-136.057681,-149.936343,-142.380147,-97.119903,-64.215654,-86.556057,-63.289223,13.036347,-9.44677,-127.549434,-146.322527,-101.540487,-90.509019,-102.345069,-98.174616,-65.881404,-76.429035,-98.02526,-71.708358,-29.900354,-36.598111,-106.090585,-265.959531,-250.203804,-190.303718,-155.704058,-169.024832,-124.97198,-118.362413,-286.031648,-404.269974,-448.835149,-216.527778,-127.3423,-120.82845,-141.224891,-149.809187,-162.947838,-238.84773,-315.437393,-320.370746,-274.481311,-227.673709,-81.979734,-32.266929,-73.681514,-117.53858,-115.405068,-33.334298,15.920479,103.261773,106.170241,32.518511,3.426115,-2.584159,20.399266,54.238745,155.338235,203.125278,222.999052,176.501804,31.265,-28.736428,-57.092613,-49.242671,-78.990657,-150.811884,-177.8175,-200.698215,-180.898441,-125.187595,-106.08061,-77.709453,32.231218,82.611999,113.804965,86.509006,34.270306,51.155986,116.368453,130.406397,122.542368,138.479411,181.504908,284.089945,298.906588,226.680486,138.016244,114.223641,131.322323,188.655058,312.848902,327.102114,249.594111,170.835296,21.941168,30.850684,80.795326,198.078462,256.78737,331.495272,304.845481,75.517164,-122.492729,-110.528098,42.79841,112.980512,145.004988,100.758384,-65.703238,-154.800683,-205.401786,-49.585255,32.68077,94.150716,74.876649,6.221858,-20.252269,-52.322357,24.504371,100.389511,178.260245,177.441058,181.980793,178.561352,112.811207,49.592888,-49.979138,24.595662,84.562864,101.934265,63.985591,-62.388263,-138.324426,-279.622873,-320.241409,-273.612593,-194.742602,-202.836453,-219.828879,-219.739946,-240.602701,-249.260342,-291.35662,-348.139937,-355.552667,-343.942377,-322.920002,-320.513322,-379.620241,-520.744535,-444.841209,-325.829101,-121.272744,-80.369475,-96.428466,-140.798827,-263.82572,-336.877173,-475.797268,-423.225879,-325.291097,-159.223207,-118.465544,-56.218992,-21.365378,-73.348043,-254.105215,-263.84903,-59.549888,49.277072,87.008015,77.061285,131.399854,141.873556,62.375231,49.010575,107.796223,284.467642,357.250544,382.511943,339.939094,256.084989,229.013654,200.739058,134.882787,146.021121,210.912046,208.593576,132.163804,65.386405,-104.267527,-162.144534,-134.980037,-58.289808,-33.330405,-26.182798,-33.455531,-94.353884,-216.179515,-234.16798,-114.51637,-5.708815,127.888077,103.856515,-22.603155,-63.154351,-123.068058,-229.00161,-258.906913,-180.36019,-84.16385,71.751239,74.803573,-33.925441,-48.963901,-1.538165,62.603589,62.207932,12.235617,-30.501874,-94.117701,-112.290228,-141.624809,-77.199746,-6.922831,165.668862,243.249039,284.875761,249.536748,113.217848,-7.348673,4.640085,158.696398,250.186679,335.805042,306.067635,168.777626,84.120539,-113.28019,-314.373559,-372.541084,-306.175275,-228.571544,-184.558394,-216.496535,-273.175873,-240.503427,-196.141239,-123.561993,-84.653879,51.338821,104.331983,46.487091,-39.250582,-154.158877,-150.161794,-146.226872,-152.800381,-140.068815,-75.118057,-56.578292,-95.342772,-148.248639,-154.717183,-109.728501,-43.364507,102.092244,116.993765,57.887054,42.284381,102.574204,251.488281,305.385571,314.695883,280.367457,157.360093,78.54382,-75.675614,-173.5934,-178.065814,-119.953866,-88.381898,-63.296057,-80.707035,-125.498703,-121.60897,-75.788499,42.316449,133.311143,275.755368,280.146814,182.725221,145.703697,120.22624,122.132351,181.046189,334.99694,348.802744,252.060056,191.985514,91.085356,40.058525,-37.299878,-14.78758,9.550837,54.843776,75.428213,82.750417,64.404094,-22.750699,-92.851916,-88.435569,-35.325225,-2.346561,55.667283,75.746296,125.111097,135.710498,76.081722,46.465109,54.420305,50.966855,45.480331,3.322607,-37.545735,-76.477423,-68.637041,-71.361651,-86.397918,-87.87563,-103.712396,-138.061023,-201.551182,-209.675189,-193.301511,-141.047576,-123.957113,-88.777164,-57.127421,-24.165991,-41.241837,-91.861933,-86.068955,-63.795973,-10.625863,16.226083,64.183334,82.722326,98.020913,67.750876,-62.346437,-102.332307,-84.853007,-64.472187,-54.308509,-56.256006,-92.539539,-206.732048,-273.019648,-265.221801,-177.504774,-101.242079,34.65184,49.236118,24.863649,7.914424,-100.002506,-175.260315,-124.82269,39.114762,64.22658,-12.758035,-41.481071,-23.948279,-7.160214,4.726694,31.851435,29.581396,-0.608195,-1.561029,59.251247,85.973067,41.62611,15.883347,50.08172,75.809358,41.894998,6.357138,27.928516,9.768149,-117.875389,-154.145757,-157.048977,-140.987245,-98.217707,-97.452288,-121.642221,-112.991601:-228.194656,-171.603049,-151.374809,-179.786833,-193.591148,-167.445181,-143.114144,-127.950647,-148.97152,-146.518741,-107.141932,-85.015682,-60.900579,-66.05302,-111.590792,-136.827394,-138.109982,-67.762083,-29.93374,42.579425,64.678771,5.360473,-83.149183,-315.054113,-410.983372,-359.654,-165.80365,-96.547233,-96.843335,-145.441179,-255.531021,-284.063242,-237.192235,-105.973603,-46.533936,5.586593,-4.489033,-73.097161,-123.981391,-254.559917,-312.45831,-263.402709,-122.928988,-94.502107,-92.858623,-99.980982,-162.229189,-206.749215,-240.695757,-187.686085,-137.233491,-21.01421,8.577214,-33.989735,-82.709608,-172.772065,-161.954475,-97.716219,81.017783,158.99664,206.618123,161.209687,-14.619052,-107.685986,-214.455811,-224.685738,-229.37543,-209.858359,-187.81881,-186.564024,-201.884148,-242.857651,-273.009214,-248.954927,-113.047411,-27.313947,79.837561,76.695748,-11.356979,-68.576985,-124.260819,-42.331577,31.270348,173.162739,210.804766,184.0396,139.409321,23.237255,-71.160637,-78.805938,39.98852,153.562149,294.138414,295.845998,277.124544,242.459515,120.021562,155.703143,236.4486,382.021031,403.983534,316.836514,238.72261,93.139204,19.291135,35.81198,161.038723,230.22278,259.37931,193.365983,-31.978208,-138.2021,-245.573487,-129.702111,14.163895,263.943598,257.485294,21.536812,-66.036113,-59.261794,-39.585435,-48.069144,-19.267166,32.319352,119.670898,109.898069,2.494195,-58.587356,-121.352281,-69.105535,-23.026938,8.948205,-13.453694,-86.60122,-148.504987,-353.340519,-450.082896,-380.193042,-134.97011,-38.409822,17.545691,-20.832983,-123.925683,-161.692368,-234.689438,-258.008843,-230.5472,-140.9498,-105.419871,-92.214446,-138.822429,-355.174153,-432.730281,-340.550702,-103.774247,-32.311447,42.995809,55.225167,-30.278828,-139.145103,-335.720998,-244.01328,-129.816261,64.517112,126.341323,146.144088,105.086348,-23.931667,-96.08258,-54.60611,146.472817,224.599578,245.615133,230.19724,204.868338,173.031497,104.732885,154.385385,217.94169,382.679667,447.992431,411.655024,319.692819,164.721899,137.745558,130.241803,151.68323,220.23252,353.083206,333.221963,86.017553,-92.983364,-331.346908,-247.283247,-158.87132,-36.8448,-7.749632,-25.22457,-62.944699,-159.004124,-195.798111,-155.895935,-23.047512,45.389618,151.217474,149.182719,36.003058,-24.340658,-85.379238,-86.730907,-59.736637,97.465432,190.952621,229.658798,171.667916,37.923605,30.104846,79.233171,179.078893,202.138149,189.232703,149.087619,4.778972,-61.974161,-52.884271,91.146398,156.468912,275.779349,319.635697,298.814613,242.865132,124.783843,74.571556,103.134962,252.81065,333.393571,413.193124,394.76138,232.198029,107.104677,-104.116432,-180.197421,-165.280415,-29.071084,34.71175,-2.90067,-75.556179,-155.946172,-113.266244,-91.282386,-72.140774,-33.824422,74.597816,75.577934,-48.879839,-116.322361,-167.497416,-173.175014,-164.28421,-58.109542,-3.036067,-30.877199,-97.374759,-219.689411,-230.231446,-176.966222,-22.097116,44.436972,134.242241,134.603509,43.857278,-3.582918,-16.830836,111.306038,206.813146,340.436654,331.717229,175.881828,76.185547,-86.193029,-151.44033,-144.255386,-72.361172,-23.796645,-17.08792,-71.6205,-135.016171,-117.879015,-91.312144,-63.763592,-4.766876,189.287939,262.366853,229.828463,148.174681,20.27101,41.657681,90.131216,192.887592,235.072438,279.439907,253.765073,74.883136,-44.597987,-191.190484,-112.164739,-28.500038,109.019743,133.629051,61.972416,-27.34048,-250.336156,-348.272,-292.600699,-42.609356,54.347374,49.62376,-13.606927,-93.320828,-95.364833,-119.180621,-137.933534,-89.948712,49.0861,50.20575,-118.821953,-196.428039,-234.277801,-221.644506,-204.363707,-154.168348,-120.873358,-74.029907,-96.78127,-213.936913,-265.315617,-285.037592,-231.779415,-201.010619,-91.826252,-26.125508,14.331794,-6.77497,-47.666956,-83.7902,-91.533932,13.24945,118.601279,255.581952,238.698752,81.912811,-10.048645,-111.678132,-63.396471,-17.940298,35.591018,34.706811,-27.059529,-84.439076,-205.645312,-222.857718,-175.361472,-18.936514,62.342046,142.432179,138.815114,94.416236,36.881731,-156.031062,-220.976935,-162.942573,-40.439219,-48.298997,-192.982749,-266.316573,-324.169871,-254.883143,-174.62309,2.260794,64.111615,37.931476,-48.232193,-187.589415,-208.903332,-210.646669,-156.647275,-106.241637,7.325258,32.232511,-22.795273,-76.972031,-229.692158,-338.095329,-312.342323,-172.615792,-129.11509,-162.408497,-208.897483,-257.291207,-249.659288:35.781789,24.980521,10.142066,44.461128,85.597474,118.434184,104.482063,64.451995,30.490443,5.446249,-30.565001,-8.241361,62.808383,58.22256,18.846664,47.004073,159.674987,142.596272,101.19527,113.34353,165.712083,203.506918,164.345904,39.075607,-65.905566,-87.160806,-81.354845,-56.547364,5.958996,-5.584076,-127.162421,-196.147277,-293.232558,-295.116429,-274.064571,-238.630735,-234.04598,-234.040154,-218.95471,-192.218768,-206.931631,-202.709815,-135.079349,-75.108447,23.793342,33.717724,31.260204,41.782652,49.083733,50.20657,64.405349,143.911755,190.107563,183.675812,131.935006,76.165789,203.267446,280.824248,275.275421,220.195227,178.983376,173.587761,76.795203,4.092933,-80.942134,-94.260918,-101.999216,-118.740373,-107.400362,-26.663301,7.063532,-35.135342,-154.21631,-173.053765,-96.24698,-39.06119,9.503307,12.762524,85.966658,142.146363,204.629278,187.194886,152.547769,135.394699,189.378516,325.775487,355.80721,330.596338,254.225948,218.020182,218.97222,276.309937,420.557394,459.435155,459.391849,428.570728,302.478681,160.053099,144.897723,264.378233,340.462007,382.008918,327.955672,114.977681,15.016321,66.084268,170.267298,165.659126,122.441889,101.570732,22.463789,-36.731836,-117.998446,12.439299,138.773096,280.954163,238.020721,56.656901,26.6119,99.23831,156.235415,155.492853,85.895946,45.301924,33.236603,35.68602,-13.71518,-39.86967,-0.236947,129.079539,179.373236,206.858959,183.716998,91.689866,38.665703,-78.625389,-105.480559,-54.405853,8.990329,-15.321424,-59.643315,-57.930783,-54.988376,-67.806706,-87.216881,-56.453596,-68.509585,-124.796776,-91.95253,0.643122,-53.536543,-273.826898,-238.550957,-136.078751,-43.861862,-65.59855,-90.217868,-93.299906,-182.234692,-263.23346,-415.261838,-500.856403,-506.628132,-368.024586,-252.259232,-129.315718,-149.179649,-312.34414,-456.988139,-446.453939,-321.692584,-251.520957,-133.519545,-100.688062,-82.876005,-107.844723,-256.43347,-330.384368,-267.362104,-50.083376,23.124949,42.75617,43.541948,92.262741,84.426772,69.2582,64.944508,58.551374,30.123607,20.974554,30.215332,40.621042,48.765141,11.570229,-39.159119,-117.885699,-112.881981,-63.150316,-48.675865,-104.288267,-218.841391,-229.470389,-91.787888,26.281578,176.017878,151.957614,-25.588288,-99.056793,-123.256758,-120.567443,-152.179291,-168.440714,-95.604906,123.188088,170.575409,129.744983,130.783537,125.869927,19.994785,-46.239624,-126.192354,-137.996773,-80.577793,-32.509461,-29.543291,-45.654949,12.85398,198.276158,256.645226,213.760783,129.261028,-70.756699,-161.819349,-125.193327,29.450519,103.697539,194.214721,193.890893,106.751605,35.622077,-93.087237,-132.906546,-146.999516,-195.466177,-201.447821,-142.534433,-105.136977,-127.325541,-217.809545,-213.787812,-79.509228,21.939662,190.933415,228.435556,216.813554,178.841053,70.010651,-7.575181,-24.630585,-21.87002,-17.104347,-75.42955,-118.141,-100.781963,-34.48016,-37.455058,-68.352426,-50.922751,39.287961,52.996037,-16.000646,-63.033611,-100.233376,24.630816,96.298149,112.93091,82.111254,6.173672,-52.343465,-187.317144,-269.252919,-285.885545,-283.355693,-278.295544,-279.066575,-289.839197,-325.500787,-324.812848,-241.465693,-114.941843,-71.778785,-45.145976,-61.614861,-137.737975,-147.487748,-46.808938,5.633403,-16.892142,-51.244548,-38.200865,-15.842173,-36.945059,-101.146461,-135.560317,-225.832839,-266.321547,-267.776168,-231.643725,-183.099474,-76.542532,-24.748616,60.497084,-11.176091,-102.05842,-237.362813,-235.818771,-127.349161,-56.990007,56.075202,66.220702,-43.219554,-125.072317,-96.205517,-8.538426,-2.602504,-59.165498,-77.184887,-51.566597,-35.136672,-62.922359,-170.257441,-206.912418,-201.394844,-194.071179,-192.105895,-192.122206,-238.200058,-253.813994,-209.274476,-75.820267,-27.978757,-39.992493,-81.409264,-139.81832,-157.505881,-139.34987,-22.856144,46.936356,134.95324,145.700379,121.380838,98.544536,27.434922,-35.893886,-30.413268,41.967111,81.466318,100.514138,80.971368,-4.635196,-117.066083,-136.314062,-126.994858,-102.803677,27.088086,91.185309,113.609604,84.644466,12.986429,-35.600507,-45.535227,-17.038499,-2.961211,-32.320838,-47.52647,-34.897424,-41.07904,-46.51993,-33.661928,-19.028946,60.362372,119.38328,216.269929,238.269835,207.505964,123.09476,96.679489,168.876753,254.551213,309.474569,234.942392,-4.412032,-120.468123,-90.835629,14.90528,38.768369,43.448268,31.456348,-8.845945,-18.792767:-69.488579,-92.861827,-130.975184,-186.891491,-164.575879,-45.35019,5.73151,-9.808368,-103.027416,-112.902755,-97.985281,-109.025047,-190.858357,-233.634561,-227.280277,-200.10851,-163.809488,-97.329677,-83.962888,-140.031062,-155.204503,-112.8833,-88.58195,-121.118633,-183.533303,-196.862045,-272.445509,-315.776822,-304.261401,-268.301215,-278.410315,-354.900593,-518.594181,-437.964575,-320.209673,-123.214941,-92.675463,-143.389835,-193.217192,-339.569171,-456.582278,-447.901153,-308.854483,-202.417386,-14.368852,21.873601,19.3146,27.505168,64.5401,61.490524,52.171599,90.991191,111.884806,28.269266,-38.058244,-48.854909,100.018865,184.28309,283.187625,291.617868,221.700614,137.986622,-57.367734,-127.920083,-165.014589,-96.899784,-77.696705,-83.533114,-76.473575,-43.791169,-38.196051,-45.806723,-35.338821,-15.179254,58.774876,104.333385,138.586646,115.902024,98.553071,121.543176,109.687129,3.084151,-14.706233,111.334952,206.987241,290.670084,284.302207,245.429963,181.618258,143.48696,99.474861,123.844063,218.586066,225.08196,132.974199,71.522914,-31.75854,-95.091321,-91.094324,48.152216,160.022591,297.249668,266.658352,15.981752,-193.047376,-169.019313,8.41159,66.167267,76.922324,42.96217,-90.734247,-176.56791,-277.658833,-174.566663,-94.070486,-26.628282,-33.291237,-19.554201,16.792699,87.682072,151.450805,200.845719,264.267427,261.656227,219.236663,170.020787,3.951103,-72.209112,-56.941821,137.29214,206.556133,229.541466,201.330568,90.317381,30.743081,-53.985902,-132.53313,-151.706947,-126.095338,-105.866929,-91.20868,-105.982468,-170.562403,-201.438098,-211.196646,-131.005843,-93.044667,-68.660017,-68.980399,-137.292924,-220.176641,-350.204727,-290.703996,-220.155699,-128.144218,-104.465353,-65.430229,-100.13916,-320.877411,-425.031208,-495.736528,-480.836423,-465.524907,-357.608735,-263.685884,-131.532513,-123.988643,-180.296345,-245.196214,-260.139239,-226.616922,-159.873716,19.305527,86.245685,137.967637,97.274421,-82.92299,-126.568267,-77.17132,27.014275,52.838138,57.747986,62.66554,99.203113,83.554206,47.017055,-28.458775,-29.578107,72.641216,119.984815,80.27367,15.452021,-66.415082,-37.319443,-26.962563,-12.713944,13.609393,46.308499,46.32383,27.637351,-48.570144,-73.39891,-8.026514,68.491867,161.851696,144.481766,43.681654,-31.4559,-219.815554,-306.528679,-294.900283,-183.466056,-95.293199,21.716819,17.055663,-54.475094,-49.89465,-11.110112,55.766823,74.591656,61.811317,21.695876,-33.379177,-18.349034,31.378286,50.046519,76.536015,231.060304,320.250255,346.428659,269.913354,34.627612,-84.740834,-42.39256,113.832944,171.123513,261.487319,286.157758,194.039671,90.834215,-80.991991,-155.134767,-173.055882,-169.001674,-153.610046,-120.748713,-105.545978,-111.873669,-135.45175,-124.439696,-98.971269,-83.19222,16.519424,80.570188,118.935113,78.917773,-41.040952,-73.61873,-72.996415,-101.13218,-114.307684,-127.354151,-139.298184,-176.862557,-173.347401,-155.918621,-108.990482,-58.406906,48.321108,59.326004,44.663026,44.269896,62.120452,217.940964,328.892938,419.258993,361.701151,152.894402,92.977604,96.857423,18.663181,-74.097158,-185.896345,-150.873676,-30.287834,-26.500433,-62.58501,-56.542562,-39.669614,24.03885,90.875794,215.954079,237.682906,207.581828,199.73106,196.771391,117.485285,96.184921,155.490241,206.857506,247.283392,203.159724,60.087487,8.842646,-42.846434,-44.759078,-27.454051,66.237454,134.294206,202.814249,194.577805,139.225874,54.39975,34.201765,35.808781,35.790509,62.279857,97.873581,184.463813,223.750366,220.348321,106.93435,66.548517,93.701316,146.692677,215.212825,203.501105,122.268634,63.942528,51.373962,-2.038204,-36.057927,-84.959663,-115.46728,-178.85481,-183.493777,-126.094679,-49.797823,-19.34931,43.189358,56.468558,12.444114,-11.410678,-11.490622,-20.000895,-37.278085,-67.051651,-55.048952,56.543273,115.3253,114.275135,58.821936,-81.529355,-124.125905,-80.644812,34.680228,62.170973,45.700712,20.647042,-35.675977,-83.877395,-87.952577,-92.624058,-95.81162,-82.028895,-81.22001,-93.337318,-102.00989,-130.733349,-120.190384,-72.996384,58.191306,68.363407,-78.177879,-140.135121,-100.253931,-37.99323,-28.525533,-14.360187,-2.626258,29.253657,53.474161,165.620705,229.314203,245.238637,190.945384,163.555623,85.212354,58.971099,57.36949,61.665051,41.830554,-17.226832,-38.477973,-1.402076,40.431672,60.996776,25.956028,-25.215621,-6.838072:-132.448914,-63.00009,-49.175731,-69.376193,-86.016893,-73.974332,-48.167777,-39.474741,-71.708078,-83.880879,-84.931455,-43.963492,114.688368,177.113682,140.682962,67.789036,10.592566,58.600607,81.513983,169.615821,201.244186,140.382973,78.026881,-62.297941,-200.35037,-220.770389,-153.324609,-92.52108,-1.643434,-13.973009,-125.831061,-173.070139,-212.587508,-164.809182,-114.817855,-37.117297,-26.433763,-44.995062,-65.384892,-169.902121,-310.376604,-323.109475,-244.903033,-188.483509,-89.551268,-77.292612,-132.222952,-178.761281,-230.899141,-147.40017,-91.899757,-4.933054,42.473542,104.34576,95.072619,34.175601,40.877888,68.311876,79.918236,75.27607,67.574874,33.355103,-63.273625,-87.80432,-109.469176,-157.775761,-193.747997,-251.111901,-247.346368,-182.309556,-151.365271,-159.86161,-187.542793,-157.415716,-44.709473,6.100237,56.836428,53.835208,57.573383,75.069445,87.303458,33.96417,4.790735,57.207314,127.887827,246.526089,290.778806,266.061308,91.08464,70.216482,208.102272,299.769942,409.342843,404.635654,312.527003,260.75684,195.284379,205.057026,241.821462,338.225922,366.604289,356.973949,324.040334,236.061584,155.331658,113.597657,72.780173,100.860849,165.368701,131.061388,-27.244734,-71.547811,-31.581545,85.524643,151.60371,230.285733,189.682556,37.025477,9.186212,50.432056,78.52773,60.381036,25.593856,52.617191,143.223583,156.622858,118.581283,72.784733,-38.683363,-25.923794,12.240991,63.247575,75.031843,32.693081,-21.527864,-179.608557,-304.498596,-275.707072,-121.375048,-70.641998,-9.950308,5.641507,-25.567866,-44.41639,-61.841766,-116.148393,-159.313387,-213.03828,-179.838354,-77.1562,-105.094444,-274.797279,-231.369057,-131.510402,-27.221919,-34.893302,-29.112951,-3.603613,-10.213737,-75.738523,-291.75892,-400.200567,-373.030672,-222.474734,-122.027748,41.018271,60.228603,-98.312014,-303.877408,-294.615847,-160.189327,-110.32834,-23.419702,11.848262,19.389326,-14.400121,-114.090715,-107.686959,-51.373843,140.100765,243.347365,320.039357,274.678101,142.802663,84.406226,81.819782,153.876952,205.160809,230.503191,203.978725,95.031772,7.867722,-139.261023,-145.545195,-126.417971,-70.873103,-48.61156,-77.061524,-98.119688,-112.75562,-227.894856,-296.238526,-287.666799,-214.798341,-77.71097,-54.594615,-54.847975,-63.627413,-109.617213,-115.564722,-87.242578,7.776274,68.878567,142.669891,120.82999,51.649489,106.998987,146.815495,92.77265,25.752808,4.740239,44.484522,89.507098,64.190368,-88.758743,-134.7265,-52.854372,147.225283,184.58658,112.540066,59.314939,25.794653,15.156679,3.332653,43.24448,109.225694,209.175597,189.415561,58.5587,-9.012372,-101.741196,-152.433786,-166.54285,-161.056661,-151.461587,-144.050406,-138.584701,-137.536269,-176.246814,-163.086866,-59.374474,2.89926,90.748283,70.88471,-78.989331,-138.924928,-143.648569,-115.287633,-119.748193,-103.507759,-94.361786,-143.582972,-163.962914,-158.796084,-186.374501,-180.98362,-89.349539,-45.47207,14.704635,44.827068,28.469712,-21.189997,-48.725432,61.495135,97.151841,76.344413,44.059611,-44.253484,-91.069949,-167.952618,-240.916213,-261.92932,-236.161758,-198.478476,-127.875741,-129.041954,-200.00486,-214.057324,-106.094823,28.038452,29.252079,-21.67938,-29.687872,-7.275353,33.497363,87.101107,23.689243,23.161135,111.996107,134.433603,79.519607,29.423905,-71.483449,-100.993745,-85.154816,-81.658244,-114.354301,-92.353191,-20.26417,46.964435,10.548895,-80.636185,-90.387821,-68.720475,-61.448924,-96.469493,-117.757138,-65.08048,35.644905,31.667878,-27.681814,-35.421395,-15.718823,14.759648,-10.268074,-148.741595,-203.861988,-225.06891,-192.962824,-166.366006,-148.346575,-157.556855,-173.451369,-179.428415,-139.899831,-90.733731,-88.152206,-189.246216,-190.66087,-111.816359,-92.905763,-144.170188,-184.023731,-219.63391,-154.317961,-87.473981,42.313595,83.134681,136.103156,158.758731,171.540803,140.089623,39.867142,54.862605,85.005525,85.779481,85.84138,124.600388,126.195761,16.271572,-107.50001,-108.717611,-43.324117,-0.674661,97.19824,135.185305,144.94725,104.964557,-54.960229,-152.268243,-135.334427,-52.737798,-24.649914,-46.690798,-75.136773,-90.099912,-40.170163,12.138832,78.492004,71.425058,61.583691,94.385334,197.042724,188.642064,2.200692,-116.202623,-102.150197,1.710765,82.75735,215.789396,209.475118,67.046059,-10.389682,6.928097,34.170739,28.630171,9.915124,-5.54812,-12.58919,13.648479:forward
-11.432863,104.235907,140.887542,140.663684,148.785759,166.167877,137.277547,-0.929975,-96.727009,-70.958631,34.035241,69.893643,162.370714,226.827473,260.738154,197.231781,60.078943,121.31814,178.536188,243.647901,275.41282,323.578011,299.019068,154.218151,24.100837,-13.221814,-34.852513,-3.208225,116.547984,135.325127,36.332222,-23.39837,-60.031685,-17.530131,-14.137891,-55.435788,-61.683988,-30.087317,-6.906819,43.455696,91.943348,124.557603,210.149502,242.83427,236.440194,217.349322,206.742866,183.889595,52.806113,-89.513324,-137.074922,-110.928775,-52.988825,-8.890014,-46.174734,-172.395937,-155.437406,-48.6439,214.585285,300.858372,313.289727,260.501612,195.097923,203.983846,194.376754,141.655851,144.202331,216.656273,260.230787,254.817069,198.190046,129.832215,211.285264,273.354813,381.980142,407.997052,385.12145,377.307222,420.087945,418.508908,315.286518,206.35231,159.438075,149.352226,191.547852,199.942191,140.981432,0.91301,-18.438912,33.457273,141.812088,161.452916,187.912652,222.704578,295.386698,292.919531,183.302979,127.576868,162.188642,273.204939,321.749576,323.431697,273.082344,198.513507,214.712496,221.772548,215.508551,237.548165,328.846811,335.506594,244.308791,200.541807,168.935184,154.727248,117.358723,0.605059,-22.894515,19.882936,43.218606,18.400994,-49.151576,-70.168371,-106.851457,-106.080999,-51.355968,-39.574695,-65.5048,-69.43914,-34.508074,21.499734,52.28049,141.87909,185.855587,198.096916,192.521389,208.637939,149.319857,103.576949,61.938268,68.572296,149.344948,191.615644,165.574507,119.939546,75.473175,68.577943,60.092689,104.574461,147.853787,139.084245,98.795118,66.771699,140.897927,221.428347,342.191791,343.374636,308.190166,299.418548,280.296974,249.263295,192.426622,249.563063,271.869845,224.588496,199.442735,198.986515,195.742651,162.775215,164.792893,184.490005,198.238578,183.077666,137.481165,105.351561,19.301395,-19.46832,-66.953762,-106.640592,-136.242516,-156.048535,-120.740911,-48.991429,-65.584731,-184.231523,-228.788992,-181.081302,-55.662054,-46.873548,-143.81837,-178.490718,-140.537358,-120.826889,-142.247776,-122.654636,-97.562661,-97.755849,-136.00492,-206.014062,-180.623619,-118.035892,-239.399174,-272.670768,-173.40581,-128.113367,-159.797041,-188.342389,-196.690901,-213.052445,-299.560022,-339.790132,-344.174592,-344.791566,-347.781216,-371.473888,-371.87911,-369.835969,-393.242513,-381.940095,-352.764094,-363.92641,-425.063807,-442.362376,-362.919625,-304.003386,-317.056017,-363.436751,-337.248854,-263.514695,-249.194394,-328.022364,-405.536138,-449.132119,-287.955203,-197.417126,-81.434684,-61.741856,-87.992167,-113.423617,-140.016688,-161.121343,-251.420805,-214.751982,-119.955518,30.574343,17.001081,-173.287035,-281.093119,-326.117149,-185.81926,-137.843137,-72.718497,-2.473293,176.941778,233.935555,216.552841,149.239457,-21.649058,-141.262609,-151.939758,-89.344422,-73.933155,-148.249759,-185.803514,-202.239893,-199.979531,-156.251447,-26.381752,8.417756,17.868246,-2.202541,-93.584473,-138.328991,-142.303817,-50.226552,-8.071428,36.160985,34.962888,-51.992971,-119.269286,-170.797179,-85.246868,-42.480619,-6.20935,22.771045,143.751972,195.43367,196.549464,153.464799,24.533442,-51.175713,-28.747641,145.570621,267.648808,430.480954,417.699108,205.585278,-19.497428,-48.229613,65.81197,165.825286,303.654753,295.619414,179.173632,129.963891,110.013042,145.652184,162.663808,207.267484,230.295464,219.917516,188.895101,122.445464,125.296397,143.400584,135.231087,150.276492,260.345884,284.072352,163.768431,51.172389,-123.945561,-165.541955,-162.798061,-115.805662,-74.596101,-18.507383,-31.217898,-158.631298,-261.720416,-258.382018,-197.982983,-156.000298,-34.554156,16.141907,-34.481359,-132.124077,-252.663619,-145.94694,-105.591194,-181.549508,-236.681808,-249.842082,-239.727033,-280.838919,-313.841517,-300.074427,-239.777539,-195.967357,-123.142412,-116.857626,-117.782842,-99.268171,-39.627502,60.901437,146.571565,351.606042,407.220564,356.640814,309.51046,243.90224,193.432616,200.299279,247.2038,274.357505,349.98595,358.162185,246.643043,171.620024,107.871911,150.146812,166.61143,125.1707,60.904427,-102.199016,-157.006395,-220.746109,-263.00308,-251.268132,-194.592969,-163.011405,-95.651076,-91.800395,-193.004626,-264.689038,-320.37116,-242.05258,-198.161023,-125.198809,-114.726351,-220.904355,-289.601974,-351.498586,-439.296219,-476.929012,-399.46949,-305.066797,-182.93419,-183.626783,-217.771565,-224.248914:26.853227,78.2328,85.50822,70.620487,88.988074,115.862507,64.111953,-141.719972,-226.158466,-180.568072,-47.841144,-16.773329,2.590539,36.577928,88.567532,47.855936,-59.09355,37.156852,152.924963,384.169811,433.499308,341.373698,259.112304,182.896038,164.802749,131.564429,148.641561,222.442082,247.197383,154.270369,2.921477,7.749425,43.058899,-4.199568,-25.60118,-12.478869,14.0848,57.933718,57.499601,2.847749,37.138769,98.675104,156.419712,145.012468,138.818937,159.299683,173.140624,134.738178,28.413205,-5.232782,-11.098912,-40.838838,-67.502755,-147.453456,-201.652687,-299.563921,-249.962745,-155.666137,75.281052,169.508247,237.615815,213.10401,112.747992,56.086227,18.122449,159.464726,243.501812,314.325006,299.839636,156.870404,53.757781,-7.794992,121.332561,195.583318,336.300973,377.033777,386.926936,397.111071,399.046232,333.614714,167.499496,223.470081,288.309708,274.591376,215.726905,154.890972,128.838126,-41.187029,-116.837411,-45.633121,100.112178,123.417039,143.30303,173.626557,270.08381,290.010223,225.182583,179.621115,203.012664,329.56159,404.70045,418.217906,337.532476,203.630316,261.098427,290.593361,249.407504,216.339848,225.289678,246.443611,193.620523,111.992953,-21.343647,39.018485,88.573224,51.04524,-17.796718,-92.329068,-86.462381,-80.548598,-108.901031,-105.710302,-27.906284,30.843876,113.144604,104.393297,-14.054424,-64.299543,-0.662887,191.758546,251.61446,269.829341,254.776469,175.462348,131.340639,96.957898,66.617841,60.096522,105.123215,133.180676,139.671129,121.205218,70.70813,52.725845,76.978945,107.72811,106.766365,139.362275,157.571929,149.717354,153.202405,198.135063,256.424308,302.253094,387.529964,405.594769,401.959121,388.297884,316.76346,252.608414,165.514562,197.52745,223.126651,243.238222,248.824039,255.274817,219.854589,89.502988,106.669563,171.021286,251.843611,252.260218,231.926784,223.078655,168.14032,102.321619,-20.774691,-30.76488,-19.480487,42.509136,90.820298,77.908817,-13.580452,-235.468096,-246.892777,-149.523761,60.521006,96.014351,21.037669,-46.606462,-175.971443,-227.238362,-253.578678,-181.508478,-153.156468,-134.440205,-129.200126,-126.141235,-117.222843,-103.099581,-176.931512,-206.79141,-120.502206,-34.55442,-10.380089,-98.981897,-294.67663,-341.336913,-364.355737,-372.250737,-350.715578,-250.60049,-226.744697,-244.383588,-253.843939,-332.988228,-414.548977,-382.615727,-249.109867,-201.430705,-200.380567,-240.483415,-310.62289,-318.406707,-330.324568,-354.697575,-345.833523,-306.784122,-298.115356,-307.744032,-320.183835,-350.507736,-288.367621,-197.137769,-0.030151,65.307516,108.80041,92.421012,-24.767666,-133.377707,-294.708266,-168.330552,-61.572927,46.271952,31.584662,-125.218144,-232.725446,-315.895044,-200.045452,-147.175589,-67.482351,-7.737943,129.454512,168.945918,141.987461,96.774105,26.552933,26.042228,44.02874,52.111309,17.863136,-95.151935,-133.586454,-169.262521,-212.533511,-187.721318,-42.545692,5.206803,-40.70727,-101.96749,-164.578934,-160.786435,-155.96317,-127.675304,-90.21262,-24.98155,-24.323613,-100.559633,-147.378965,-176.299094,-130.878807,-104.029314,-36.039025,24.731369,102.755556,71.144095,-28.476824,-53.307028,-107.054833,-134.010692,-72.653576,169.62058,265.806502,294.16096,244.757491,79.20082,-3.664978,33.125624,183.094927,259.802203,332.66945,325.128955,312.363099,317.692717,290.979792,212.560698,183.276461,207.276834,241.004252,239.688269,219.196408,184.049927,135.681244,115.929379,143.628867,220.768851,356.385179,325.452996,109.131554,5.918385,-25.92772,67.382638,59.046857,-39.151981,-54.296055,25.033896,43.063105,-112.93766,-262.781572,-246.849411,-173.353533,-149.923566,-86.401984,-53.48566,-64.670981,-119.507267,-220.205522,-220.021575,-204.666662,-162.10201,-148.687421,-144.232021,-136.952368,-117.456701,-79.964006,-44.799858,31.91624,72.961533,107.783999,82.74243,48.452256,63.77746,100.376627,159.276477,218.084035,356.080425,402.529359,385.881066,334.96685,249.449468,283.221484,323.407407,345.092953,330.17332,314.462611,313.757539,254.445453,200.27868,171.673311,206.356664,185.415436,102.977924,74.15077,24.292026,-22.413114,-170.492276,-232.650137,-208.324174,-165.06662,-156.341626,-148.23366,-160.134254,-219.623207,-267.189422,-349.703254,-295.657927,-232.584917,-156.099398,-160.467037,-224.11214,-278.091928,-406.67329,-460.800105,-455.104839,-370.983823,-285.953414,-189.182882,-219.726228,-250.94255,-210.817699:-78.866083,-52.545245,-41.053681,-46.700993,-28.507091,13.554123,-35.017705,-263.382124,-303.270559,-195.917391,29.534902,50.061402,-41.576543,-67.305549,-54.204873,-58.687355,-46.846982,82.227121,178.145677,362.121755,391.620007,290.696624,228.219472,178.728965,143.873672,113.784251,137.563924,188.015582,173.543369,109.82205,20.734678,-2.78572,-7.405664,47.127581,59.942688,88.972581,96.746902,41.360059,14.581285,30.52564,126.488855,176.683131,219.975315,222.415796,184.592997,150.109584,114.91938,103.113667,54.718173,1.014518,-38.441124,-88.944793,-75.050314,-70.074005,-119.813899,-233.751328,-187.309921,-109.774117,51.228736,110.665105,149.619756,134.061095,92.22861,72.651085,73.784848,184.865371,236.357709,198.136321,115.993283,-63.922717,-111.141881,-30.28673,179.864199,265.275538,351.405346,360.659555,344.193793,336.347749,319.529211,279.833968,192.618125,250.496724,278.111664,239.792789,231.06248,216.444239,135.963187,-93.268023,-91.635179,-4.881833,119.28479,114.145542,67.810091,105.630096,314.760919,376.519356,325.906344,322.510005,353.864143,405.493512,425.393753,402.04041,333.805645,180.2106,193.66589,235.862843,284.393224,289.453693,244.026644,184.582855,47.757294,1.851724,11.745611,93.764416,100.605853,35.873913,-9.466654,-56.862919,-53.322096,-87.976234,-127.113985,-88.198767,47.838337,90.496229,77.016962,42.072056,-26.4071,-42.348994,-27.237005,0.491507,36.074705,175.055029,222.442905,139.255096,58.835001,-33.853271,-23.387709,28.937035,130.819073,141.098102,109.654667,88.867497,45.718447,33.028486,83.011662,190.139005,231.318149,275.25371,254.905589,139.990143,93.004478,88.170665,231.188201,321.381216,387.892076,356.024933,239.82287,190.392697,156.850358,151.083984,147.077559,187.085601,186.409849,113.424292,81.747727,86.552463,84.744063,32.873608,109.010954,195.958192,306.252544,308.786235,244.036258,196.079212,111.272742,86.435653,73.580678,106.368691,116.730156,99.687619,91.260554,35.0857,-32.201207,-154.826575,-162.694575,-135.671184,-44.187716,-1.018021,-10.878198,-64.711348,-208.473357,-275.668203,-306.843335,-161.013867,-92.746116,-73.893258,-97.672999,-113.439937,-101.503173,-91.731432,-155.075373,-195.524603,-132.568928,-37.133952,40.958623,-12.270529,-175.660723,-239.117285,-290.26611,-304.188179,-303.363772,-233.782173,-201.622943,-232.174249,-254.562861,-280.61083,-299.722965,-267.089768,-138.720584,-78.919148,-67.054056,-116.310703,-190.044144,-196.493641,-255.756273,-334.47137,-310.513022,-186.023256,-161.474998,-209.955752,-234.769773,-259.706809,-229.744491,-155.965534,40.51259,99.060804,90.102421,49.910564,-38.30699,-93.016587,-200.807684,-153.219016,-81.311638,-14.679365,-38.222926,-95.226941,-101.946813,-120.246432,-131.261888,-103.032534,29.613836,112.358966,242.024703,283.496133,297.589927,261.75177,141.911236,52.289641,31.701643,18.178675,17.194588,-34.810302,-89.07558,-178.605558,-190.470961,-168.192841,-85.06699,-27.77939,38.199948,14.403538,-76.043338,-110.365319,-138.210429,-115.850667,-84.064571,53.914257,119.645905,80.457934,-11.718802,-147.358513,-54.176801,42.390692,202.004272,252.08062,240.982836,172.206327,41.470311,19.799093,12.499867,4.45668,18.450573,72.491605,97.096454,160.304796,184.723049,146.304993,144.104227,214.675428,366.324518,391.057817,367.630614,359.523608,347.634277,329.358796,349.795966,428.453014,428.857884,377.878066,358.24307,330.25929,325.271071,324.706038,282.76054,255.266957,289.019428,353.677585,398.547626,334.888585,130.246716,41.816697,-53.069621,-67.719236,-37.811988,47.735412,50.62006,-19.136757,-49.848311,-67.464907,-128.120009,-180.810959,-227.680576,-220.280664,-204.03978,-178.743285,-108.748739,-117.137834,-214.938986,-217.178642,-170.322811,-69.721022,-56.788884,-145.055765,-179.675961,-75.860915,68.022351,76.266622,25.928002,32.560865,127.621702,153.693718,86.999307,20.765821,-51.94607,42.485267,132.523475,299.279518,323.860575,261.437404,235.913913,220.819674,193.269001,187.200492,203.039766,214.331046,225.030139,228.594082,211.000104,177.871381,113.912429,114.678131,120.279652,97.057974,65.900143,-45.836925,-123.022951,-242.54926,-208.100704,-181.667314,-233.745192,-260.412234,-230.310552,-225.49814,-290.65986,-325.489608,-316.22872,-176.653311,-113.912788,-118.867104,-166.978889,-231.011964,-236.833911,-273.78224,-369.256791,-395.431774,-320.425985,-221.89487,-108.934003,-159.316412,-271.508026,-256.25769:4.003772,-11.503269,6.1771,103.394604,152.57361,98.102991,-3.185457,-200.776664,-221.576919,-141.752509,61.342497,104.886803,72.23887,71.009697,122.568096,109.719636,51.237439,141.353262,199.438285,232.922609,224.286806,220.356876,216.758157,108.739606,-53.76747,-73.064368,-26.200779,-14.808132,-25.773789,-22.526034,-11.734588,-34.686739,-120.811827,-113.078977,-68.687565,1.070723,4.14904,-5.341538,13.959561,77.91206,131.683648,176.665285,274.440746,282.9286,219.573304,186.372355,148.302357,119.472802,28.223225,-45.113706,-78.759092,-86.046515,-41.59773,1.451399,-49.152657,-199.887965,-156.525446,-40.244912,153.316546,192.013204,262.597732,293.343046,269.125904,212.071845,96.612505,117.449487,169.020669,270.746399,289.145122,200.065321,134.127777,118.972794,275.533923,356.031885,381.886029,336.807594,293.870188,343.224586,460.136438,440.650742,304.592526,241.158477,209.733132,137.90031,145.472887,199.54649,168.510504,-2.049802,-19.308147,57.674522,213.113494,253.513,298.364804,329.043796,368.126445,345.425597,271.689345,240.625648,230.971848,301.387111,384.538357,420.036666,321.501836,109.548844,163.333183,238.836704,309.037945,306.357435,291.054452,281.62982,231.498564,188.37166,115.421176,162.612919,204.226024,197.831081,161.675087,105.950416,95.527936,50.109819,-57.078302,-72.891659,-8.528652,28.147978,61.435946,57.838636,10.568727,-26.71736,-29.950913,83.075166,132.249374,228.036948,272.822229,261.744923,218.728565,143.582472,89.391882,81.566086,131.760989,179.195628,257.903021,265.116004,192.364558,130.451504,78.579545,187.741676,257.239965,320.002322,296.207588,202.967124,184.230009,194.825209,251.985136,324.919346,435.180654,420.824045,325.857919,289.525862,234.052015,199.295292,158.808785,175.347036,174.551269,143.750602,142.189319,164.119821,152.529705,99.476637,151.898422,218.847727,284.354391,265.656797,208.738755,180.469922,142.306169,140.937687,130.930001,101.165402,96.230554,161.557647,208.940049,152.727733,36.116589,-187.849597,-202.054262,-136.433294,15.160445,42.411567,-50.60875,-124.989785,-202.603703,-215.531201,-256.971925,-232.657594,-179.582697,-94.351911,-94.434217,-159.635136,-190.031002,-226.739024,-297.876738,-315.536893,-222.204579,-151.492452,-100.24267,-115.555495,-183.491066,-230.280093,-314.278512,-364.446235,-363.939358,-299.446721,-273.213469,-277.419728,-279.404362,-305.022159,-387.658485,-386.411594,-286.992916,-252.124593,-265.411153,-278.201212,-275.46086,-290.48589,-389.129979,-414.584269,-375.873847,-305.363987,-320.091461,-434.544522,-470.285583,-436.371006,-330.703874,-265.525764,-164.024969,-126.268539,-22.953621,24.644947,-0.391985,-101.570341,-328.146943,-299.354206,-226.159077,-144.050312,-145.212948,-185.122424,-212.024315,-261.239256,-218.54039,-145.09204,55.386364,159.095622,317.227509,341.852516,272.126782,206.085461,69.761128,-54.472579,-90.079357,-80.051155,-77.103658,-159.063674,-212.957827,-263.406706,-251.965808,-219.0606,-78.59193,17.709019,134.294227,113.951018,7.161389,-32.773095,-46.257811,-1.830017,12.569043,43.581351,56.228732,13.270328,-34.02167,-98.120761,-61.092398,-5.998652,150.639624,228.713678,284.191559,245.16548,151.947388,132.319359,70.111405,6.957673,36.476667,239.901415,348.569,397.50875,341.052928,159.860759,63.400448,113.293614,365.620382,499.948711,624.073582,596.366535,443.712304,365.65353,324.979325,431.298132,467.931241,476.258729,471.188399,438.106122,417.963015,358.455048,259.39163,221.809498,197.965932,228.710098,324.435632,321.958034,168.158238,55.822454,-107.998113,-147.148933,-161.015561,-174.144926,-152.644192,-118.897882,-138.430471,-216.933699,-248.262676,-230.53065,-192.540539,-182.836879,-154.468503,-160.225728,-237.551495,-278.751319,-306.072199,-240.528879,-199.345406,-161.784249,-185.000276,-281.722566,-297.506841,-258.783005,-238.768865,-232.743677,-234.095339,-222.65342,-152.203392,-134.262209,-137.466497,-130.06138,-110.86719,-63.479187,3.295896,182.137204,230.490368,186.382326,133.289498,37.31763,30.411508,55.501898,71.183178,82.186536,150.616997,154.823066,65.545449,37.340709,94.795549,164.330426,160.929076,123.730166,92.800549,-36.308044,-114.729161,-222.493061,-195.977762,-133.700415,-51.872592,-54.153269,-106.208808,-152.268338,-209.943403,-203.73291,-182.492979,-176.698928,-173.458188,-125.846259,-96.539459,-135.478797,-190.935679,-260.924818,-279.131906,-273.552926,-232.609598,-202.59095,-137.642351,-125.369337,-121.412666,-114.079559:-92.477597,-97.054345,-70.127611,-51.165787,-71.141657,-125.356578,-144.600765,-171.434328,-112.567339,-42.008986,90.728178,112.491914,44.580159,0.695628,-6.861988,6.992906,11.282562,75.55072,155.144332,328.669382,349.252188,213.297368,127.257309,39.054541,44.823452,72.567784,148.324224,172.578615,116.100423,52.411308,-35.613129,-59.421328,-94.122001,-53.191079,-0.120458,94.840633,89.265222,-2.242043,-12.947361,88.662891,201.848667,228.093973,252.86021,260.468111,245.455177,238.961096,244.17792,231.723266,157.128752,10.74998,-74.815518,-91.287733,-6.285512,80.496823,9.643801,-190.088092,-120.890956,-0.082926,130.237903,127.344112,135.800124,163.282902,206.489597,183.180075,101.151353,164.703111,227.055482,291.340717,267.909084,136.185881,84.093053,90.398268,199.491147,271.685607,396.281715,436.053133,419.34852,358.491904,234.340864,202.686332,218.966099,311.543555,319.201293,241.13044,226.216156,252.238276,225.844007,87.987571,26.998898,52.991451,156.908008,211.54945,283.973752,307.722129,373.040346,383.236706,317.191483,272.602109,284.600895,388.668556,451.734552,414.741761,294.696964,99.238935,225.860666,319.60135,373.972168,362.693629,299.226095,250.999875,179.524507,156.853684,173.122392,291.702615,322.511576,257.346527,186.677689,102.027045,123.797991,141.975263,14.447108,1.206591,126.544741,182.784815,182.215967,150.012672,63.779142,32.336449,57.67687,94.326369,105.582681,211.351871,282.287137,322.702346,284.441964,171.680628,178.150613,244.382574,364.654086,372.990409,289.425293,229.106071,156.644778,168.637615,269.867505,305.29489,303.461148,368.116881,384.666274,278.531438,219.971263,237.589606,334.811423,374.639759,417.608731,416.696646,371.509044,335.547128,279.601155,258.675696,229.25281,248.985713,272.389873,316.131292,325.251283,269.007632,209.604426,146.732965,229.554114,299.026135,426.271852,447.390718,360.667412,287.479859,193.933009,186.748703,236.61302,294.023633,283.810836,248.25959,252.098482,237.722096,196.912683,80.574535,71.721227,137.033329,257.70787,255.487221,112.175645,13.607926,-107.836997,-124.190675,-106.489843,-16.275619,52.839192,151.333611,147.466763,72.646661,34.296176,-35.550847,-106.137939,-105.229142,44.078728,144.543446,230.002497,215.648484,105.733158,19.885145,-112.785026,-133.197687,-108.273174,-7.814831,32.68076,43.078997,22.104121,-87.081794,-163.117539,-141.410048,-69.294653,-44.691728,-35.39566,-52.681075,-93.563704,-117.9607,-204.976057,-258.351592,-230.078822,-106.765898,-77.352942,-136.526276,-182.833618,-263.509628,-293.990938,-264.321537,-109.054421,-6.615129,121.133132,114.858747,-6.222293,-90.769742,-205.99528,-173.131265,-125.630376,-61.239653,-78.633115,-175.406825,-204.793762,-229.731057,-216.777371,-174.730141,7.054896,116.546061,217.730146,206.368718,132.274739,63.704657,-91.38901,-94.173588,-55.357277,-68.701399,-137.270388,-320.025485,-407.947977,-519.53892,-450.194238,-349.681249,-136.394158,-71.904579,-81.119118,-140.57771,-249.062366,-271.075914,-271.240199,-273.414025,-271.704191,-218.440792,-192.210635,-216.109986,-266.188308,-370.059536,-287.578659,-179.144654,6.706922,53.549159,54.318145,8.679432,-136.431448,-202.772607,-252.198377,-192.233893,-142.674342,-49.259723,-18.461949,22.146567,30.462836,-43.974099,-147.362453,-130.316824,56.910221,181.525387,330.915081,321.510625,163.803496,71.774676,88.259773,282.954041,308.111453,250.531175,237.569777,232.429217,215.547836,149.287902,75.874898,52.633383,111.645426,205.377171,296.691604,211.482802,-45.90962,-111.995207,-101.823816,-89.697378,-107.988047,-114.763891,-104.283643,-117.980826,-149.091527,-217.89828,-235.238851,-222.687108,-167.132474,-139.373537,-163.924026,-204.023376,-211.030084,-200.279464,-232.377548,-194.547696,-142.465602,-89.311605,-95.541949,-121.827507,-140.48731,-185.816981,-120.363983,-37.602537,80.081444,98.847425,104.505823,90.927959,17.057037,-43.353752,-123.765964,-60.954864,31.319573,299.399929,390.823783,364.59462,293.015648,154.084244,149.101319,207.960907,240.40842,180.932484,107.340087,143.342993,193.756911,150.335404,82.767081,159.798319,179.089008,143.465824,108.932359,-16.721146,-98.686296,-228.404199,-245.319076,-208.953574,-105.815053,-66.977161,-82.93116,-133.045904,-188.173574,-166.237151,-125.009717,-143.544971,-133.005186,-77.257422,-98.132004,-283.473824,-368.996445,-403.297546,-386.645046,-387.034945,-314.504505,-224.05856,-116.758661,-164.443265,-316.872392,-346.979229:49.510454,84.96128,92.273584,107.603902,134.090973,160.880354,127.010653,-40.699442,-108.526564,-63.874483,8.049349,17.775614,45.723467,44.167219,-3.010703,-19.23166,-19.829265,6.250941,6.446334,-10.741663,15.772403,128.894102,131.925746,-80.485755,-285.845764,-307.387704,-264.100233,-212.069148,-79.078303,-59.894079,-159.434545,-210.313228,-215.784548,-128.174872,-89.035504,-90.180446,-103.337488,-64.027836,-12.539526,79.820842,164.101999,218.673064,268.786334,246.271809,199.014911,208.52161,288.657281,320.906624,247.598251,9.007754,-92.560513,-101.303838,-26.164797,92.701302,93.071259,4.903901,-15.520754,55.809909,238.724385,281.195268,242.412267,202.782874,187.281374,186.368375,114.600977,98.594452,146.041468,239.87812,249.757433,214.889079,208.966024,259.263804,319.07922,338.522957,363.031083,357.904709,280.794507,232.372418,267.014119,342.473402,391.241067,232.19243,144.27026,101.58791,127.921767,151.68844,151.967592,138.183881,92.77847,114.891897,275.830749,366.930225,479.916954,470.634835,342.115978,290.533683,294.932341,292.004229,265.733599,284.603159,317.919747,274.169144,194.515076,117.059747,206.430539,225.229567,197.338191,205.365202,277.573444,296.462909,252.400995,230.738719,300.256264,386.558754,347.147365,192.609834,163.242908,228.377413,284.195996,320.245669,177.5651,103.491748,55.966195,57.76914,88.498428,125.978566,182.036038,172.509903,107.964818,101.985712,155.012585,364.313816,459.540725,470.864209,413.177552,301.373673,216.662248,208.073399,267.377647,311.97396,391.792874,399.625776,318.935956,264.550619,173.803715,100.273843,108.39033,232.488297,292.009462,288.517092,229.469043,120.220088,204.98558,314.755226,480.791741,477.297408,369.066882,331.956868,355.796344,377.302563,332.565558,262.497916,263.390669,301.387641,312.203447,324.614192,325.868645,269.962862,223.689974,263.999559,404.197579,439.288568,362.819671,265.444105,84.467904,57.152649,135.678905,174.781505,129.825094,93.883458,153.867059,247.322195,211.26767,36.547158,-33.133261,15.501253,143.508677,156.678349,66.413456,21.945916,46.500917,84.491751,140.462266,160.014631,129.777998,34.449268,2.520602,-24.760108,-26.297107,-28.280706,-61.993181,-69.485866,-38.903594,-1.333148,112.054648,126.960952,-4.16958,-74.309567,-103.565895,-88.613151,-85.158729,-123.854235,-176.614256,-217.339557,-177.217947,-132.439036,-188.175486,-191.638074,-169.545704,-174.617906,-225.401185,-240.037291,-124.880872,-33.897407,-15.643769,-160.319346,-204.874948,-210.91754,-215.694363,-284.730102,-323.356186,-341.991196,-272.497627,-209.317252,-104.791774,-79.518127,-11.054212,33.173429,44.7709,-16.145832,-179.611501,-130.564535,-38.209352,41.604114,-5.064851,-171.805425,-269.704718,-433.766717,-368.28349,-271.073231,-103.766103,-39.393172,86.036137,119.677133,57.197682,-19.858182,-182.959502,-277.029803,-287.505734,-267.399297,-267.416596,-327.003824,-359.117274,-396.659328,-367.582901,-300.24939,-148.627375,-111.980195,-124.537089,-140.405322,-140.512412,-151.098327,-189.797023,-150.233033,-135.903104,-153.640155,-154.414898,-154.193077,-178.708067,-247.427554,-239.396087,-203.078881,-121.274672,-71.325668,65.601275,122.596101,115.795462,43.536944,-127.96607,-134.043811,-66.712701,105.542443,170.807574,195.3288,136.127713,-119.807388,-310.011828,-280.078905,-7.031247,152.810654,304.502253,269.767005,89.949453,17.309429,2.255351,88.515545,126.849938,121.492057,87.581259,49.9302,50.822898,28.527715,0.580541,-10.777619,-52.564733,-29.594089,103.238092,120.615755,-20.567524,-145.747548,-360.234117,-354.377724,-329.752964,-340.238931,-317.293313,-204.386342,-206.28005,-385.432469,-485.285656,-463.74764,-394.15327,-340.220033,-144.065711,-63.530793,-112.273075,-199.633891,-268.22054,-203.119846,-188.817527,-218.303444,-238.80481,-283.328924,-310.60662,-355.73887,-347.435255,-311.935841,-201.317563,-148.210614,-101.654065,-116.00229,-163.956362,-182.255803,-194.415787,-84.768052,22.295217,255.334743,332.81541,328.771033,260.910326,121.120671,117.311232,151.722542,185.968231,206.656868,305.93808,330.945342,244.080094,188.987445,205.647876,277.451708,286.338383,280.281977,255.084313,118.051895,39.292387,-52.557879,-60.040382,-26.962232,61.669702,70.415652,-24.747012,-79.339295,-34.104806,34.881776,39.515651,-5.62296,34.306393,131.598638,139.038394,69.38839,23.702012,-40.449623,-118.713074,-157.118321,-139.194597,-66.237316,68.151431,58.749226,-71.714375,-146.640498:-44.913109,-33.884181,-16.155194,71.683731,127.050637,148.213829,86.613994,-157.242112,-241.568209,-136.766696,116.471433,150.39015,68.47252,24.385002,-3.933738,-7.149367,0.486783,71.259696,108.470864,148.512577,157.865699,149.960714,118.868528,-34.684349,-200.643325,-214.339144,-102.29615,-28.728908,8.091612,-44.04312,-153.548489,-177.020664,-194.866983,-90.773743,-1.53366,114.060904,110.735793,20.732236,-7.017234,42.100927,156.627202,217.772473,297.96904,297.656353,240.85725,227.886676,256.323357,232.334463,53.37418,-89.835436,-90.881867,33.367638,98.027765,113.706373,71.553152,-54.903866,-63.870498,28.093866,241.047579,288.812103,262.118077,217.533312,151.926869,135.231025,104.039675,107.73374,136.659137,252.22611,290.000653,202.507015,126.802387,93.016102,258.329602,370.674185,481.525815,459.233068,361.676195,333.825681,299.071858,255.677334,208.885138,304.732006,323.454946,260.647814,235.076911,230.205832,220.627856,151.45697,116.163683,173.61576,389.723126,479.611412,546.961579,525.630277,404.462861,340.830561,314.179908,393.673262,417.113169,461.963382,499.366639,474.532639,384.572793,215.327459,287.672331,369.441804,438.134788,425.476104,380.309272,353.222898,276.981136,226.987348,182.089104,302.770204,361.871513,338.157991,291.331502,240.389775,230.342245,185.598924,146.507824,147.067561,126.33211,109.957519,127.865721,155.988836,158.593154,115.815422,50.896075,87.238761,148.941317,362.327004,444.696187,414.993745,346.493024,230.62436,181.824999,229.117621,388.469134,416.925801,396.80911,386.707735,307.06665,225.280921,124.89085,242.163853,330.364916,404.797991,366.293437,242.734579,209.419564,155.690594,193.198342,302.75182,504.208981,528.795794,489.432726,438.097931,280.925668,221.719944,224.790434,253.831864,243.41136,302.280954,375.176648,400.001759,324.077683,202.613389,314.087449,389.513578,449.804782,456.132874,419.155326,353.02479,204.263185,177.515137,225.359672,249.212272,233.939396,284.056882,352.132162,384.784719,321.503616,184.146928,129.883258,127.751254,207.689142,263.261153,229.599486,143.114095,12.393028,-12.128881,-17.299288,34.70697,69.799433,157.5574,196.19697,182.149152,122.848462,-16.629897,-72.006201,-47.986797,86.869111,164.167945,248.102595,239.436017,132.019494,67.799419,26.030658,65.923609,76.173272,68.512001,57.688169,36.142757,27.40378,-21.567999,-65.193876,-43.519525,59.46006,109.2329,137.287293,113.108387,73.011692,54.175581,-38.323791,-100.281028,-95.605344,-62.01748,-81.183965,-218.09175,-274.087346,-304.27803,-255.744276,-183.431746,-13.288187,47.498436,113.321561,110.267999,0.976242,-92.044212,-215.152008,-141.075014,-68.594978,43.970129,39.785408,-158.281283,-306.242345,-475.813347,-342.602528,-226.812728,-32.579277,53.59471,142.150421,104.185321,-47.417284,-109.671651,-206.470334,-269.607503,-276.689873,-239.711529,-231.672638,-353.817883,-454.71021,-561.822707,-505.83321,-424.53171,-220.041957,-152.874504,-169.949575,-229.37586,-330.49776,-361.018891,-384.111211,-354.809268,-333.670425,-290.505811,-280.118452,-303.468735,-324.985407,-370.872164,-370.381903,-345.993234,-273.133341,-206.913617,-80.553976,-86.288693,-205.781752,-267.67713,-358.698381,-343.202168,-280.187978,-119.5192,-72.929611,-97.054795,-140.040972,-252.073628,-319.456593,-284.209327,-76.475798,56.18623,229.956291,218.367069,22.018559,-81.699487,-91.270601,87.771479,135.25546,93.88981,53.796895,10.344485,2.60372,-51.095969,-142.486436,-159.195922,-103.295979,-30.528577,94.255501,59.222534,-192.068742,-303.702979,-336.110639,-258.397463,-264.626188,-290.89039,-248.506312,-134.422824,-145.151579,-318.929026,-461.274347,-456.754012,-304.915643,-202.488241,-92.168262,-100.695717,-146.929091,-166.10149,-211.758944,-142.072918,-37.257733,147.163587,150.596192,15.167869,-61.401293,-163.477696,-127.60862,-58.723648,46.628869,67.571645,104.564206,109.08896,15.920941,-68.006852,-134.940116,46.244411,184.133171,438.516519,498.816857,395.198098,271.424861,53.324642,21.075812,62.789443,127.884304,141.308698,185.414039,205.923857,147.132923,78.203387,55.123131,185.814039,212.161624,188.928753,165.581035,54.40323,-27.843655,-158.361737,-155.227551,-109.819278,-42.182909,-28.60946,-9.183303,-23.704151,-78.851759,-88.814777,-99.319824,-124.588494,-123.922975,-69.412075,-44.585835,-109.353734,-190.071318,-332.49024,-378.54494,-347.135624,-178.472644,-81.542461,-34.661163,-110.617392,-310.417283,-372.286935:7.896489,53.821437,20.642935,-79.530447,-100.448674,-76.647014,-65.575625,-85.753257,-98.332855,-93.865301,-127.379295,-138.740072,-49.879246,-17.435219,-164.423926,-275.076209,-290.99152,-136.450203,-107.373972,-117.482549,-87.28958,24.521301,24.327896,-161.453468,-420.721052,-503.8672,-515.237064,-463.669079,-357.155549,-345.077015,-399.077812,-414.328549,-361.077987,-329.090743,-338.145296,-280.583788,-202.739013,-37.889019,32.162595,106.995653,95.894622,116.395807,199.982724,224.085653,244.801695,244.336946,217.637232,191.64896,60.268839,-106.955772,-145.466784,-134.026561,-104.830407,-24.590175,1.380961,-51.684012,-140.78615,-128.254816,-63.569724,-69.487759,-107.816813,-92.359153,-35.016858,-26.601026,-27.599641,-32.986381,-35.185611,6.825006,56.742888,140.62671,145.378497,113.605922,135.574141,175.549709,241.100769,240.424481,190.282964,168.31159,151.055353,144.14903,145.069424,140.420622,91.132079,-19.864652,-17.841208,41.890741,54.161098,60.754447,60.779816,56.219602,120.55955,213.755603,394.830765,399.116672,226.995487,126.326523,13.601685,-12.185843,-3.030299,56.7043,99.433002,138.910527,110.112027,9.096357,-66.068967,-76.987189,-31.160091,24.894058,187.101499,251.821169,260.017271,241.007411,237.089092,191.347192,128.125224,17.399188,17.078423,83.244128,114.449672,140.262564,120.508339,103.554089,26.724919,-23.30084,-29.779229,20.369701,108.752659,112.177131,70.217416,58.59817,85.75959,218.949747,284.41167,283.436813,241.849023,148.151999,13.014048,-30.034564,-22.655105,9.081988,91.581129,134.605303,164.199608,125.57272,-4.860399,-55.661675,-52.012131,-25.207516,17.979874,117.052241,111.555545,-9.136096,-24.724891,54.946071,244.48773,280.862355,232.842927,197.578478,191.997883,217.630408,255.101649,257.295863,238.047387,215.060249,248.439765,321.961596,311.421271,228.495774,180.291448,186.638273,256.026044,296.365634,274.336804,205.447505,123.294078,136.30926,149.697853,84.535077,43.241354,49.758512,115.929882,269.26731,305.858179,257.835315,134.197888,101.806966,125.871494,146.012266,137.365145,131.689231,178.491367,204.264436,233.00038,266.008777,238.260738,118.813462,86.353152,81.664972,81.759002,36.271996,-98.093029,-145.869584,-124.462501,-70.66997,52.349772,81.722054,24.311215,-45.618391,-128.222639,-47.896486,-31.805745,-104.862541,-125.264945,-89.172715,-68.789782,-62.996607,-77.769871,-62.424054,0.876384,22.670344,34.999378,47.125268,129.047568,161.082927,147.748683,132.11215,95.708654,-37.453343,-84.273173,-109.10602,-89.76323,-13.461198,14.98881,-0.805305,-31.309447,-18.521802,37.495007,60.26499,100.645017,85.830823,-67.997217,-194.401752,-200.671023,-164.533471,-148.508341,-169.039613,-203.374291,-247.576316,-224.343832,-194.328081,-138.20221,-127.417509,-115.643663,-112.022974,-147.962893,-198.175151,-318.779076,-382.091881,-383.485314,-315.823259,-288.524972,-337.941609,-372.92729,-367.447395,-229.230828,-141.007395,-112.242639,-163.322581,-189.363239,-146.554696,-68.622956,-79.470527,-191.655989,-237.919043,-209.954665,-113.736957,-70.721953,-34.389833,-44.162033,-104.581111,-179.454651,-200.410727,-151.182147,-57.644897,174.326124,223.751734,128.356123,36.272494,-106.809474,-81.997807,-11.610871,119.912067,159.749937,180.730474,147.626046,-7.947297,-136.433868,-125.086042,18.149817,91.926739,130.379519,97.177338,33.537323,13.397701,-24.94954,36.36843,75.864875,66.563791,58.045617,68.581222,49.898187,-1.675245,20.709482,20.695143,-42.230542,-38.919232,100.607689,162.080589,123.668073,31.896546,-156.328972,-223.535121,-249.592437,-306.890082,-279.699256,-120.945614,-85.819486,-195.294071,-305.930209,-309.890827,-277.623156,-228.698422,-59.549016,-10.054043,-75.698764,-143.743394,-237.264135,-260.938264,-253.803219,-226.482224,-219.328733,-234.783638,-259.608552,-290.146448,-259.961902,-231.325251,-115.474787,-38.582107,42.880673,24.78521,-32.120323,-41.03413,-45.332876,-6.025175,16.832597,41.28862,69.614902,162.954963,185.017658,131.121678,114.717146,164.022673,282.613556,332.033359,404.145431,402.710492,336.044229,299.191501,267.719365,338.416404,393.361234,462.361622,463.059108,383.239047,318.256502,217.457264,222.600504,255.338584,308.61512,316.969818,287.662079,247.133673,169.139884,161.969592,197.353927,213.462396,213.927387,261.727364,297.917038,309.830343,290.935232,232.99078,155.321277,140.481586,187.824221,243.977091,307.890246,254.124545,71.736056,24.95032:36.276702,87.867087,94.756084,65.076006,62.314441,67.779543,46.833783,-34.347376,-57.402309,-24.860807,59.711673,103.550181,160.510243,128.515686,-30.658657,-95.094888,-80.793736,23.641671,34.911701,32.274093,60.023944,151.689471,166.05168,1.901372,-283.138227,-360.210955,-326.173588,-234.18197,-33.905745,-13.220717,-139.155327,-210.25479,-269.231081,-212.679855,-169.62391,-143.361379,-154.209115,-139.630417,-87.606808,50.528784,62.122659,54.595908,166.468728,244.955683,280.405427,255.221693,235.336604,220.297787,97.435522,-66.540104,-132.097665,-139.317296,-70.699875,71.06585,94.313441,35.021267,-27.667228,14.771454,184.40911,216.450255,95.060187,9.995971,-29.205762,9.373664,66.627719,6.284738,-31.791929,6.84249,78.934593,153.014305,132.896446,145.428157,234.669774,235.810976,208.85045,235.410258,342.811716,385.560318,402.429274,378.271474,310.993836,235.05736,180.727477,123.538513,151.946022,226.119067,219.695512,130.962315,99.929674,139.463017,259.145148,297.101402,289.462936,258.779474,233.908497,235.832013,191.428305,130.938021,99.960032,42.926223,61.358443,185.462424,214.949113,111.684802,-63.878649,-110.724035,-79.034105,-4.553684,191.125083,247.744855,208.766911,163.486004,98.313586,0.207882,-64.711664,-147.455171,-145.468758,-86.734142,-55.152481,-47.192035,-131.525565,-175.480558,-219.624519,-233.982933,-247.75622,-222.805665,-136.384282,-108.47845,-77.227325,-20.001524,9.566442,51.629843,69.607221,82.226257,70.18407,-18.172269,-133.227695,-133.704611,-68.57328,-44.889331,53.614807,125.316469,129.302602,46.934055,-129.71669,-245.581806,-266.915508,-191.428235,-125.338034,-63.274698,-71.596629,-66.777963,13.292519,56.962904,97.10801,102.81869,123.930323,124.434682,107.02916,106.577548,98.589178,103.006432,119.903175,123.705195,114.55282,124.544034,133.462224,112.478733,69.186391,72.429471,111.919558,112.067332,75.199761,46.9723,-48.969098,-103.504612,-174.751181,-251.396553,-309.184597,-312.981252,-219.978872,-26.436104,0.523918,-69.309065,-199.672931,-234.950272,-178.496671,-121.689602,-77.526851,-86.59776,-80.655577,-70.371709,-74.198995,-49.828981,-42.020545,-105.842547,-161.28897,-222.029291,-203.994506,-139.399602,-190.33401,-229.376783,-197.300209,-143.831157,-88.644408,-99.629036,-166.735673,-213.91525,-278.49732,-291.207321,-317.053608,-402.29698,-436.372324,-458.832852,-430.133472,-325.455799,-295.278125,-311.248387,-317.193736,-305.76518,-309.615414,-305.120892,-208.139479,-163.586276,-191.98721,-226.479847,-231.628526,-260.63018,-267.063949,-271.324757,-283.594571,-309.663045,-252.916286,-186.012432,-102.468736,-118.004279,-177.898068,-173.108134,-96.228356,-74.872182,-121.558781,-182.026737,-181.130107,-132.159634,-128.88636,-266.337321,-371.852607,-449.731073,-336.079146,-272.829222,-199.30315,-169.261153,-61.295549,-9.206324,-21.782059,-84.203189,-228.113705,-305.684679,-307.291002,-266.847851,-255.75767,-276.845312,-282.831602,-242.400701,-139.271495,-52.470526,109.005037,113.890714,6.457315,-31.389014,-24.707165,-28.246627,-109.347229,-75.02677,18.423141,177.189482,198.33339,187.727314,180.58455,137.065569,77.2076,75.682451,108.244266,131.216118,229.094597,296.204433,361.70745,331.169707,198.04717,138.719151,159.566561,291.427542,382.209249,488.10002,455.146066,232.971822,76.8914,88.661789,219.032696,289.772509,358.939545,355.859668,325.583521,318.577587,344.621955,439.478491,481.540089,472.328453,445.994426,441.396561,453.818449,402.413637,304.156581,305.069224,356.794602,381.990186,448.753152,466.378228,343.547298,211.30955,26.608306,48.985603,57.350551,0.217651,-7.959551,81.235039,119.659213,71.347645,-21.365667,-39.518615,-26.067652,4.82962,75.72746,83.877267,9.473681,-64.784057,-196.13825,-214.82836,-200.686979,-168.555596,-151.190616,-136.290144,-157.522483,-243.83546,-272.756887,-263.159185,-227.935342,-195.141014,-136.283912,-127.200883,-116.993253,-116.423648,-127.387161,-38.687937,36.798574,187.277552,252.408572,284.381252,251.780634,191.891528,192.817906,213.246106,260.561966,279.591637,303.731344,290.214496,205.527518,158.498825,97.341665,66.001782,48.287739,30.67115,33.696934,-21.450474,-96.897096,-249.808878,-245.597491,-198.665264,-150.522845,-150.07348,-163.821802,-179.384908,-175.376945,-162.177005,-198.61131,-210.471085,-170.091765,-86.010214,-66.717362,-75.52731,-102.583585,-221.886133,-358.552924,-361.63129,-229.820752,-155.327283,-122.133443,-155.320446,-171.25399,-149.069461:-92.592726,-77.692062,-70.855123,-94.409104,-89.138236,-5.148773,13.034795,-97.677049,-200.81617,-193.340095,-130.899142,-89.510191,-3.000083,3.87603,-101.059344,-183.068533,-270.002158,-156.732523,-83.250432,-17.067586,2.414935,46.061283,26.633576,-140.348235,-301.788046,-328.745476,-329.756005,-324.748282,-327.04599,-351.282067,-396.603363,-381.803492,-335.410455,-314.036802,-274.346598,-110.262816,-33.78031,5.047087,-6.287946,7.90731,54.986909,70.86293,111.502225,138.826533,158.236959,145.377441,141.065831,147.496892,72.393036,-78.908122,-114.543202,-87.744973,-67.923804,-78.387142,-86.186515,-80.319481,-87.230265,-58.670681,55.122698,91.728616,85.644645,63.958804,39.868954,27.978054,-22.518279,-52.096613,-37.936445,56.46692,109.795137,143.464704,134.325069,139.026687,187.168906,215.742681,193.852331,160.38499,193.07361,221.504405,187.259204,168.866477,184.998225,137.90184,85.006439,63.698345,99.79044,105.147373,71.794412,70.961021,109.983033,122.550907,196.670155,254.383794,331.917608,334.757478,268.351688,214.666689,172.077127,249.299233,262.476346,220.260986,220.46462,264.430035,264.351238,216.128435,228.20222,267.400523,311.475017,280.293013,191.145616,189.479683,240.055442,253.614995,261.871149,262.811887,248.608801,212.990474,201.634076,181.901179,181.366888,167.490513,36.758807,-26.945507,-20.591971,16.648935,31.512768,20.430219,32.16928,48.220307,56.572592,61.20758,90.275009,242.9419,319.496339,302.270623,233.440156,107.820328,10.105275,4.402734,94.141246,139.268755,158.078384,152.203907,169.100711,181.081258,180.567812,157.240633,136.249254,137.112232,162.135663,126.162513,56.519938,-32.54122,47.671927,116.023846,186.554646,190.876878,198.785768,188.930823,147.297027,151.580249,193.034606,146.703254,102.196983,84.284354,107.356958,144.388837,155.4345,166.870281,153.093694,151.444447,206.311317,237.567106,178.888138,91.677521,-3.779819,33.063742,123.106086,79.083011,64.965565,153.387649,209.573173,222.636651,197.141604,165.573954,127.84372,86.074083,29.828344,37.973583,42.12082,20.837299,34.32063,91.35448,214.019529,181.395734,88.962312,-102.252887,-130.070662,-80.955196,-68.87337,-136.144263,-245.466188,-265.497802,-186.459411,-94.510452,91.016614,127.233048,65.939067,5.236559,-96.428615,-135.686504,-157.983402,-178.646322,-144.362892,-91.841644,-108.465667,-134.435697,-101.05072,-78.877279,-70.654807,-88.866756,-104.510087,-86.217229,1.69373,51.004009,71.524477,32.704255,4.420856,-71.562756,-90.288816,-67.329986,-66.840982,-140.696662,-126.352944,-65.98508,-4.972842,-15.411582,-1.583799,37.982885,81.809853,38.610042,-105.673972,-121.282397,-95.902186,-67.930769,-89.902139,-231.146242,-297.35145,-312.425576,-274.335358,-246.208553,-129.261503,-59.764893,25.020582,19.474239,-54.213463,-90.345037,-205.523116,-360.461323,-373.834843,-277.668935,-249.094427,-323.535504,-366.424034,-320.289085,-164.534762,-93.367131,-9.011196,8.794857,-5.435263,-35.499167,-85.070932,-110.211117,-170.25381,-164.153982,-153.691983,-142.240365,-130.128121,-111.303405,-127.567846,-193.025854,-162.523558,-117.525404,-60.463601,-36.908868,28.365096,50.932857,67.755581,56.443931,-26.411318,-38.658075,10.888088,92.5495,92.90396,61.489268,27.431404,-142.552977,-256.378496,-216.750192,-73.822954,-4.250085,156.529161,205.583898,120.446501,23.72106,-49.444774,99.893821,151.460445,135.818588,126.253746,96.079129,46.913122,-53.703805,-57.729449,-32.429477,10.697175,42.103868,154.133478,171.054197,-11.619356,-154.910861,-291.590551,-239.55477,-228.988568,-238.4955,-215.10251,-150.327842,-169.726533,-328.14027,-379.453268,-319.616287,-167.579101,-91.962585,60.504341,90.602917,22.260762,-40.560508,-132.733912,-123.810324,-96.884167,-10.533458,25.678131,-22.970193,-95.486892,-200.135168,-147.950111,-77.425361,17.098931,16.833015,-36.565636,-71.441663,-116.367621,-133.01152,-129.403994,-9.472384,69.342584,218.43771,271.67244,257.124111,186.083708,44.678367,57.498196,90.59495,133.93506,162.92338,225.369278,215.851788,130.308952,113.01421,148.617208,209.244534,249.037905,320.948589,322.566439,195.587222,106.182835,21.676527,53.261408,79.107286,100.675666,95.201338,87.677691,88.510623,97.418439,99.90536,83.802349,116.707645,128.174147,81.91407,69.595878,115.162888,128.06495,39.776202,-55.124742,-22.001034,149.056156,219.58741,227.374644,159.457776,-21.1274,-95.08873:forward
-5.957941,49.464589,67.223525,100.816169,109.139965,133.960538,168.991772,265.248419,342.130215,339.622293,250.346576,205.81101,154.358989,131.954769,76.972121,43.563701,-3.533691,-19.621122,-42.828489,-133.48658,-179.646097,-175.744191,-125.565142,-66.355021,-83.051025,-80.556613,-63.331211,-67.447852,-174.693098,-266.479289,-318.416607,-232.884761,85.846549,354.886114,395.686916,338.833302,301.075087,316.192757,355.958174,394.134796,342.070491,297.680939,237.235574,218.006906,114.273465,48.23358,9.963272,49.663096,166.798291,118.876935,8.098755,-195.929736,-238.360633,-240.684244,-217.871475,-132.255287,-0.344978,53.675246,66.0597,13.299469,-165.733201,-236.748472,-260.970438,-225.572261,-129.926824,-152.982178,-218.99637,-291.655881,-274.173454,-265.658286,-307.683238,-362.943939,-218.953628,-133.477979,-117.926566,-179.632418,-324.76005,-363.735936,-313.312569,-248.852417,-191.363673,-296.711873,-341.429879,-307.074579,-282.907478,-284.43997,-247.654243,-48.481273,110.446823,112.778491,0.564847,-61.713797,-135.925152,-146.916806,-71.648697,23.363504,252.01371,370.671495,358.730043,257.784929,213.116553,174.819145,177.864307,201.165505,173.562486,140.787969,113.843697,105.758011,8.101874,-33.648466,37.470929,109.86438,202.842115,266.442846,294.508018,309.669484,293.501069,206.359753,147.376053,81.744871,158.055986,210.977031,182.7789,92.057336,-71.284641,-64.05334,106.341732,192.307636,273.807466,266.325991,259.258743,264.14014,244.449559,174.405653,160.356456,132.958206,49.750034,-10.993407,-124.256541,-147.020897,-111.217698,-62.422063,24.197601,33.378581,-4.877926,-97.779134,-148.807181,-232.795589,-276.998268,-313.087516,-257.23616,-15.770263,196.653738,204.393454,79.411641,45.942264,75.387079,95.497054,162.752146,210.562576,245.105045,243.340846,253.487326,197.180573,94.353074,-89.33947,-75.325466,46.186132,35.971709,-32.070891,-208.189307,-255.112055,-250.682773,-227.789455,-154.841777,-97.092886,62.666237,70.912827,-17.549749,-147.4042,-164.530555,-223.425353,-239.458869,-139.123755,-25.49329,-24.367706,-67.520423,-76.777727,-100.155093,-135.987385,-201.175511,-185.220269,-8.349016,170.276976,175.461125,72.707532,31.857463,84.331804,166.680414,348.664289,432.668064,396.445599,277.789698,261.152953,244.882872,197.122898,120.562316,157.65481,310.889971,307.596514,237.330067,92.73932,37.177013,-41.066593,-54.268818,-55.402521,-76.647631,-88.68124,-79.562218,-62.159847,-72.301007,-96.007752,-84.79684,-49.083835,53.808053,204.668262,262.16376,253.930771,199.638902,102.872192,89.270591,110.454823,121.609429,106.579403,12.50898,-63.887882,-215.394638,-249.002356,-221.266012,-198.082012,-109.660722,18.274291,30.49354,-21.442568,-41.924177,-20.37453,3.564007,-49.453237,-193.938652,-221.507249,-185.141603,-169.292508,-211.997845,-229.763892,-129.225542,-48.108192,-13.870054,-91.622003,-90.85418,-52.163397,-64.51011,-61.599492,-5.280076,113.405447,152.646869,132.177272,5.88128,-55.760557,-67.575433,-33.719464,6.553602,10.842929,28.06929,58.478955,82.576112,46.963815,-51.470313,-232.12156,-231.873068,-89.238985,76.337902,110.582619,69.273784,39.102415,9.112236,-16.125906,-78.25262,-66.59603,76.062761,165.639386,142.022503,84.816569,84.013833,60.455849,28.841311,48.044748,228.638395,301.312484,318.584605,297.958679,217.39119,164.267991,105.758222,112.364095,196.212848,201.017853,140.565117,55.04393,69.786631,158.277258,166.308827,38.485317,-20.981728,22.274487,80.990679,50.554709,-60.549158,-87.379906,-0.800629,95.708594,224.717949,177.19353,122.940351,3.877217,-60.580954,-156.661808,-153.435208,-62.099632,5.924722,7.475773,-29.970262,-26.262188,69.723284,123.180353,156.238944,150.442767,215.220145,312.413542,293.395347,166.780927,108.162625,77.357097,116.673068,192.7945,130.64247,88.141428,81.528798,92.21779,29.671059,-17.091519,-26.105403,-13.70972,-44.597889,-13.184767,58.630326,135.685557,89.31878,-41.674097,-51.36107,28.234834,103.802777,112.19689,67.379882,32.283367,-15.237344,-27.595981,-47.024569,-44.826115,33.901727,92.02044,62.719757,-18.54428,-50.221129,-140.111027,-193.483802,-262.917713,-232.547995,-185.550551,-125.212358,-137.820364,-208.932791,-220.789029,-174.387232,-177.019706,-293.330795,-388.981048,-396.437957,-378.718507,-368.223156,-330.061934,-311.713546,-301.844,-254.688083,-241.101541,-296.497926,-312.898601,-238.5581,-183.657166,-98.593943,-68.696807:1.522956,53.891146,45.846485,26.729241,37.542033,129.849698,188.326233,235.961585,240.606807,232.424419,121.68557,36.636983,-93.647273,-118.582006,-79.620472,-37.827271,19.777093,-22.055368,-71.027461,-167.350854,-215.53214,-240.731125,-192.297009,-63.106905,-25.516644,-29.964324,-15.908,-23.854942,-133.142016,-181.458377,-135.321908,-66.033779,55.490611,128.164636,177.766193,245.417567,207.193106,97.83164,105.464236,220.046014,277.081981,259.262785,196.607792,157.388048,47.862926,9.079428,34.575125,92.182247,201.486566,97.803291,-29.296687,-217.327807,-248.265192,-265.22796,-253.451518,-95.702048,128.928593,163.032387,96.717352,32.462972,-142.424278,-202.502787,-168.662751,-112.330384,-34.238054,-85.157115,-148.482248,-227.002722,-235.063914,-236.069436,-235.593275,-216.618056,-99.909931,-43.643888,-120.777449,-244.32015,-425.63036,-408.426529,-271.851074,-250.761556,-305.609498,-336.71477,-343.356667,-354.80094,-343.297817,-251.670488,-185.622395,-65.911416,41.890648,75.054963,7.4293,-70.21154,-130.589725,-95.592127,-10.484771,18.404669,131.116416,240.512858,214.193291,77.896624,54.070136,140.963722,200.424445,237.56842,208.86097,199.970718,180.796089,146.48079,41.520551,14.358279,46.187301,87.130544,167.332478,157.496886,124.146713,132.189648,183.621689,220.572927,162.699341,50.571753,65.712258,71.094839,76.446349,63.034153,-36.444677,-73.129426,-59.887413,-18.371348,122.009994,146.020551,92.995466,15.170295,-4.442684,-41.70143,-31.328004,55.828681,82.553538,41.574793,-83.789772,-157.322423,-262.664725,-235.69041,-89.915541,-47.18047,-23.521129,-93.479961,-172.29594,-284.951886,-283.356571,-189.212524,-109.760141,78.062937,174.006325,152.377321,75.246581,69.085158,60.705106,23.973904,-42.455281,-31.573913,50.25967,123.513215,141.645862,76.307911,6.39023,-69.221517,-53.164766,28.811086,62.032118,44.490588,-20.875065,-63.742923,-117.543885,-104.755015,-47.034909,-15.885305,91.431977,137.130906,82.474012,-82.500083,-145.824129,-206.737594,-196.695112,-70.396769,88.171854,100.378914,-4.394081,-62.529996,-115.018513,-106.950516,-38.251546,-0.292138,53.755742,110.645963,124.796082,78.290237,37.865984,21.750136,69.718326,240.4678,295.585615,226.624894,93.643274,102.523689,143.191675,112.914943,37.322914,60.339775,181.99066,164.964915,93.131077,-83.6279,-147.52016,-148.45707,-107.879408,-58.002554,-99.257155,-146.088289,-214.506283,-211.167382,-134.390601,-73.051273,0.598844,-15.386806,-67.875325,-19.601343,30.809334,110.652063,121.804568,68.070931,42.586897,127.075252,234.27647,200.067954,20.418893,-56.83982,-139.129731,-161.379143,-187.792347,-173.053997,-49.319999,48.303783,39.512715,18.881675,34.60215,35.100166,-1.163426,-83.374521,-121.619333,-123.077824,-104.429377,-106.984742,-182.389817,-210.085388,-121.308851,-25.712958,111.615575,17.849434,-70.108931,-134.609983,-98.254716,19.259258,64.328594,115.516516,167.606239,171.074299,58.481447,-13.430226,-43.971108,-17.274321,18.333593,33.093944,87.191374,97.269306,62.122916,-72.186969,-151.654609,-242.092414,-208.853828,-11.837241,117.296731,109.726761,75.726593,79.803008,43.577768,0.828527,-32.984308,-23.146804,12.922297,83.415457,100.205219,55.860535,16.670476,-43.191325,-51.0296,20.125313,194.554148,255.83094,226.567848,169.591859,95.704146,85.801193,76.980287,77.134314,86.997406,79.614689,69.214487,30.974894,-7.197819,-60.611769,-55.777384,-76.653307,-106.718444,-78.325047,-53.197728,-105.29052,-192.529947,-149.319689,-1.235607,29.017449,35.955088,15.859375,-15.487303,-67.541617,-75.660618,-66.925505,-47.613372,-0.972471,88.471866,140.133416,124.91057,45.860871,-108.109929,-105.467485,77.841058,166.637115,196.07576,161.832903,121.56824,-9.909176,-34.469573,49.841379,99.393413,122.448884,133.126126,132.937705,88.48676,75.309421,87.733691,98.059095,101.444906,83.399695,41.496863,62.060384,72.014703,41.578855,12.907151,-5.960175,3.961434,-29.537077,-70.99261,-53.07703,-21.337992,-21.235803,12.962489,66.401584,166.320799,152.285966,25.524438,-57.492013,-77.395917,-119.08805,-142.208477,-155.72032,-153.772348,-196.35206,-231.430046,-215.659997,-171.82324,-176.197298,-239.17786,-249.524794,-163.9291,-109.620357,-73.018847,-150.863283,-207.100015,-251.633694,-245.609879,-213.824292,-173.539221,-122.900055,-182.250422,-196.825313,-140.321248,-103.749928,-85.939068,-82.332112,8.027757,85.133148:68.308924,186.181881,183.785272,93.659053,57.100207,74.95205,105.764915,128.951905,146.48608,149.043183,59.659837,-10.030101,-67.656583,-53.99675,3.941639,55.441134,177.679234,141.857715,44.085552,-184.105475,-252.998704,-185.843364,-87.328127,24.355246,12.453632,-12.304108,-95.139846,-136.315149,-171.122552,-160.465808,-116.8109,-86.845536,0.903442,24.585795,7.602519,-6.798932,8.125861,80.395206,111.639102,121.905993,139.431199,156.533184,165.214142,143.123447,57.444396,21.326841,58.885506,151.09629,321.313942,191.430695,43.45551,-180.559379,-235.215184,-262.683683,-221.124948,-61.298668,65.08624,85.429929,46.153609,-15.557266,-195.472251,-251.515491,-201.619969,-130.423901,-25.966005,-53.475247,-83.970644,-133.776597,-163.336726,-178.657415,-141.197304,-22.457839,42.309614,41.076402,-59.692901,-161.461055,-281.664842,-240.753022,-124.597509,-120.463241,-161.333604,-187.734922,-214.966166,-295.135634,-314.716715,-256.265319,-185.07221,-33.588093,18.591187,0.326808,-74.437111,-115.934837,-177.240624,-189.769822,-179.591452,-139.214495,11.160214,77.763096,61.810642,-7.083188,-45.842361,-48.395782,14.580749,179.760742,217.754833,174.009347,36.083717,-19.704183,-61.512864,-45.611982,37.770192,83.797838,126.041343,103.638275,72.760198,-32.02964,-65.790928,-0.100496,51.28519,26.857072,-93.163187,-129.408994,-100.351205,-57.256865,-14.547801,-23.758855,-50.569382,-49.25593,-8.152162,-1.029752,-18.420566,-38.877506,-52.644816,-100.297355,-108.402831,-48.333582,27.415716,9.383096,-111.340996,-162.412583,-182.950238,-156.062068,-83.695144,-59.154379,-55.847508,-158.182272,-242.945314,-360.253569,-362.694091,-277.597718,-205.178257,-48.104844,51.996341,60.184381,-15.073974,-77.201307,-159.931557,-151.876295,-64.377948,-17.651688,37.772203,32.404602,13.776012,-76.501085,-139.786758,-212.578721,-209.632375,-145.873556,-54.611065,-40.20154,-118.933448,-184.504235,-268.136292,-276.397284,-225.433644,-154.224895,39.289738,79.601478,13.460057,-121.494401,-140.673222,-131.889173,-121.343411,-15.497472,128.354709,119.053373,-38.003535,-104.915944,-155.409441,-150.579113,-74.4013,-14.565324,76.821551,149.664132,200.762355,195.187379,105.141037,-32.813183,1.888373,209.3795,349.23092,321.954126,126.409815,35.433449,-7.911207,24.746348,89.166154,103.813182,89.04267,-28.950434,-114.251055,-238.056664,-253.886404,-228.930905,-226.071411,-262.831899,-238.135824,-205.525227,-176.751397,-170.965907,-142.173401,-110.019507,-14.489648,23.589695,54.074103,48.933187,49.773331,60.30658,48.403696,5.014375,1.46569,43.61581,53.52734,6.766185,-123.211821,-162.252435,-174.75927,-166.274689,-147.202557,-112.924241,3.750388,16.032464,-9.523745,-18.837094,-16.631401,-51.830748,-63.92762,-31.07954,-29.408636,-35.305583,15.426829,36.790172,-38.616417,-102.082536,-119.04801,-62.752817,71.610863,100.175464,92.781112,87.602321,62.506133,-20.807991,-23.054218,81.93588,178.226571,183.546109,127.870862,78.717049,-11.094595,-9.96836,70.965677,114.522761,149.577987,42.114621,-22.335946,-57.309714,-56.904589,-72.7584,-65.001436,39.989632,173.448839,169.856485,60.796367,32.862314,73.458864,95.176397,85.713045,77.592333,72.32845,62.826943,81.196414,146.308731,149.592132,75.692535,46.846215,110.080272,259.657081,301.714181,306.839946,286.539562,146.807663,46.742793,-11.202575,45.74364,146.619558,114.645865,94.808676,50.268114,-14.477685,-136.509486,-130.151137,-36.632079,24.512851,32.669398,-37.287443,-136.577022,-320.119523,-291.209375,-32.731805,75.46893,156.577227,113.676555,68.824562,-0.391258,-19.37733,-38.262822,-24.787551,55.01987,122.476367,133.064709,108.461155,56.72131,-89.637708,-114.224443,-18.276334,47.202151,110.286721,85.863046,56.810219,-29.264179,-74.861593,-82.403858,-48.978638,-0.251385,36.841,51.829849,45.460486,15.414189,-47.666692,-26.857657,87.27393,115.415854,105.013625,69.763546,34.329708,-45.08812,-67.50782,-56.529612,-40.052829,-31.077837,-26.524007,-12.30924,23.423562,25.267121,-2.286137,-1.588628,46.414325,62.07445,-1.89119,-127.225272,-162.329543,-199.457562,-209.987699,-168.179879,-128.423977,-64.007868,-6.067732,-14.345607,-143.847095,-204.326254,-184.219218,-123.528779,-19.537805,5.391172,14.471998,-3.75269,-28.220177,-119.286688,-169.057488,-185.454681,-137.476191,-54.739703,-118.143014,-144.139072,-79.271506,-30.427825,31.885331,70.220873,181.580844,229.051159:-40.884601,49.554576,107.372493,151.802196,110.697008,75.671828,144.838087,344.65426,419.241079,402.807404,329.456684,293.557495,232.575231,218.848123,225.148724,219.173074,211.923082,210.323584,173.373319,26.087853,-39.503902,-7.619869,62.180521,79.792378,-88.402705,-163.760023,-178.19225,-137.212408,-137.341045,-185.347254,-174.657625,-89.055488,103.866664,180.033899,192.234349,217.598824,203.488596,168.48044,204.486687,317.698925,300.179616,266.706225,267.846129,262.058757,107.888837,26.465885,86.859248,211.069056,371.248172,178.605997,20.982104,-153.870273,-172.01713,-183.981491,-170.041627,-71.316583,23.717937,22.778146,-76.97023,-146.086925,-252.43702,-266.851541,-207.392463,-162.660341,-92.70376,-38.222676,-16.358915,-5.614505,-32.699045,-113.59294,-133.002305,-96.789155,20.413979,63.174013,12.087084,-73.935772,-242.442916,-258.142171,-143.689274,-95.6751,-119.991644,-176.782176,-181.513489,-181.18421,-196.912073,-220.127616,-195.562346,-63.886082,32.789167,1.38077,-169.410717,-242.047139,-311.403371,-303.281682,-174.496548,-67.842733,148.585205,271.806631,281.397018,217.766141,168.24963,97.73222,97.877597,138.53348,146.253011,131.182093,62.70828,15.452599,-37.80786,-20.325487,78.219839,127.789994,163.997064,123.141855,100.790061,90.775398,95.584069,67.474242,20.839708,-55.434814,-25.324227,-16.645381,-66.837318,-96.884292,-109.166866,-80.99776,67.491072,175.423313,342.991026,307.986249,247.678893,179.93834,166.818632,126.231351,99.109076,26.74846,-31.476996,-50.930759,-108.500239,-140.868444,-176.850802,-166.878137,-134.471683,-143.961807,-162.6388,-168.256119,-194.369485,-254.842555,-278.138137,-303.448593,-282.483314,-133.618375,57.022665,91.716317,18.518272,-32.727148,-91.50884,-96.465544,-38.157465,7.796858,78.889555,138.883917,163.832416,134.319885,72.435971,-40.16844,-64.097029,-88.534891,-83.66531,-91.855137,-170.902938,-220.548496,-296.641989,-299.357548,-201.216643,-115.090453,70.004094,88.730656,10.125393,-167.529947,-224.27527,-253.8422,-210.74255,-44.684707,93.571125,108.129601,19.964302,-28.159336,-70.110591,-97.806201,-126.888121,-73.165384,108.450495,168.660636,143.898642,95.713328,93.578516,126.904788,169.187512,303.341077,417.415302,403.67373,286.470121,249.715221,172.192843,112.311454,110.28814,187.180136,300.929028,209.725684,129.649362,1.724598,-53.259863,-137.789636,-133.87602,-65.412299,-114.57043,-172.307915,-220.317303,-206.538249,-146.064895,-110.491937,-63.078361,-58.58378,-50.160797,-11.756272,11.525665,24.035987,-2.230569,-49.180611,-35.680747,5.307976,-29.42126,-63.230103,-133.887513,-172.049221,-231.61605,-243.562688,-277.9434,-291.517756,-189.241647,-42.392111,-44.184953,-136.276653,-177.802802,-188.336538,-146.67101,-62.154369,-115.218479,-153.306338,-147.652894,-141.060116,-198.668471,-209.303061,-119.507372,-68.975588,-17.484829,19.174409,16.782845,-54.104804,-88.465336,-76.27143,-33.515331,99.844223,227.83488,231.382414,73.009231,-26.791178,-75.617528,-14.590143,124.801069,148.512829,117.947197,66.884778,73.49964,110.050368,71.001807,-72.807125,-77.130966,88.600067,216.011427,192.962597,58.116409,18.310864,2.676103,-8.076056,-38.089888,-35.2587,39.157038,108.883742,123.933683,159.722387,169.758701,117.685578,65.755569,23.457759,159.275302,237.084134,261.111395,235.928162,205.083461,176.701864,67.604722,41.103092,138.355077,209.791974,179.922202,117.520001,109.865352,116.71117,120.996971,103.832163,81.437876,80.23487,53.699207,6.633886,-82.739706,-67.38696,59.415125,120.597975,202.716768,171.232424,107.937328,0.19156,-37.763052,-101.827442,-100.721143,-36.047472,17.681253,29.615618,-7.515855,-53.869623,-107.016238,-75.327656,55.182245,96.634079,124.615868,129.587833,93.013433,-15.072882,-39.284705,-26.155661,-10.05446,-15.676486,-74.918276,-83.699832,-75.938933,-89.964467,-126.174898,-112.035574,-37.614112,-21.955493,-44.011163,-41.225362,-7.852627,34.923434,-7.471276,-145.838795,-171.465862,-122.226681,-36.876611,-5.892725,-8.250325,-35.275768,-70.376605,-62.159366,-29.257478,-18.064436,-4.752159,-47.546347,-93.017022,-137.176902,-127.098226,-80.816294,-63.403663,-103.471028,-152.835604,-139.81843,-115.826732,-141.670246,-215.110274,-223.160558,-180.762136,-150.025105,-112.404453,-178.291062,-245.447439,-313.737059,-294.058556,-225.319624,-205.31611,-216.80389,-242.202048,-223.390086,-155.862255,-132.024935,-101.409206,-77.87197,45.493966,131.558402:-45.030213,90.176815,96.133968,-8.104236,-50.058518,30.253201,122.145241,256.746986,334.621311,349.051989,277.156135,218.690482,178.021473,206.511581,287.233034,320.717053,369.856976,305.994382,227.744895,38.139467,-42.96607,-76.676058,-46.245948,12.895395,40.790039,8.216765,-151.168915,-224.597193,-261.617889,-225.061613,-106.912324,-45.809398,60.886185,80.675623,63.76521,37.451171,48.553219,163.451266,254.32877,384.314152,347.792073,292.206601,204.554035,173.185011,109.068712,108.135242,242.009817,342.575688,414.845689,253.053656,145.073907,-48.544295,-124.220483,-150.904307,-92.581972,49.466786,72.50794,39.44651,-68.296145,-146.029869,-303.026239,-318.984662,-183.401104,-95.628691,-27.803957,-51.127398,-58.138725,-104.049398,-146.461405,-153.467431,-101.92582,20.333244,107.365284,112.227699,4.333232,-86.999298,-223.835381,-218.816806,-116.071662,-61.798667,46.249111,31.705705,-43.527562,-206.771736,-244.571173,-178.171739,-111.287485,-48.900689,-96.670001,-141.753856,-253.631101,-314.927835,-431.615069,-459.649989,-348.21515,-203.942363,62.940022,87.996148,58.757444,60.607901,82.869673,105.529986,115.663429,180.337755,242.435639,227.373542,101.401438,19.358484,-93.347271,-85.632987,29.437684,86.233758,136.30872,103.457273,60.822185,-59.450213,-111.631095,-118.825953,-82.55004,8.418605,39.480211,-10.646542,-164.180619,-196.699003,-118.069881,-40.224119,109.880421,186.79347,345.451132,353.81708,289.969302,140.797365,83.380462,41.984774,55.61153,83.898327,66.987057,49.327442,3.330461,-41.154911,-155.093799,-175.222654,-93.94629,-25.762983,62.625629,12.132953,-59.423041,-256.956859,-350.301077,-374.014973,-302.33902,-150.457803,-45.097994,-19.955909,-44.249643,-84.307325,-195.175666,-215.861271,-82.940202,17.441003,109.503083,85.825185,70.54544,15.430193,-50.857311,-147.447195,-116.364856,-15.464455,-64.264811,-121.821482,-213.602684,-243.470946,-284.057708,-279.168026,-190.532777,-111.758393,89.983896,135.619456,43.796443,-192.862908,-265.106768,-280.880175,-229.680035,-37.819458,118.240009,103.911158,-57.960149,-119.079421,-139.678076,-133.159946,-89.411911,-29.980031,117.180796,126.524457,60.576501,-99.23267,-132.513449,-20.715193,87.610756,267.242623,350.461547,331.115198,202.571945,129.57006,17.829681,9.763588,155.039824,273.286102,371.835943,197.485207,80.026431,-91.595023,-129.045418,-122.75164,-109.195455,-112.854205,-135.266716,-152.520339,-174.291307,-178.552301,-215.191365,-214.960993,-116.206766,-54.999051,30.954275,91.668849,78.931037,-68.660807,-131.334568,-103.435758,-59.861514,-1.62417,42.105563,19.479588,-132.998066,-212.962284,-297.557917,-292.474323,-221.556539,-192.481581,-142.586378,-62.43676,-43.552284,-99.588043,-149.403375,-192.975309,-188.868443,-150.142966,-68.416198,-50.901393,-77.05347,-102.940356,-178.58011,-205.1514,-167.82324,-110.053245,-6.090701,-57.742668,-127.287079,-200.113128,-192.704054,-147.588597,-107.846273,0.879799,29.805167,-15.837003,-147.536206,-194.033928,-192.698517,-136.901929,-27.439229,-12.819096,-10.613992,-42.282211,-88.036041,-206.267227,-251.164724,-225.96621,-158.13989,0.116675,124.141909,149.408294,89.606988,18.57522,-103.377759,-96.679384,56.947954,129.689871,155.091759,140.922402,156.605512,158.546305,129.869785,87.60532,84.543169,96.582044,188.402348,243.581206,257.709077,206.547961,34.290695,-38.333449,-56.145257,-11.916484,106.183772,162.017887,164.564184,169.498247,158.51774,120.700031,127.664364,189.153005,231.113045,217.748859,76.165811,-41.667441,-198.280025,-155.159978,94.25065,201.821317,313.527437,256.417644,172.106014,28.013413,-13.956703,-26.401817,16.419989,132.563424,175.476417,151.650933,38.446605,-26.184725,-110.915295,-89.411985,99.238421,205.996737,284.705292,152.107266,70.008436,3.41766,-0.131378,-15.814206,-10.874367,35.411185,90.41632,116.300401,129.850965,105.059131,11.170219,-9.676621,28.03751,43.766409,81.723841,119.055442,107.249425,29.679002,-27.650269,-92.335435,-71.356207,0.220621,54.177484,73.942022,60.365225,23.225258,-72.088072,-79.689815,26.621869,88.064589,135.301775,52.293477,-16.02662,-113.851118,-151.897477,-185.876031,-148.573987,-24.816927,37.364085,20.682145,-78.963649,-119.164336,-131.636696,-114.551429,-80.714005,-64.960508,-21.566767,-56.137159,-120.450145,-257.833329,-296.103264,-258.179337,-201.745775,-145.857449,-155.526791,-146.379929,-121.147275,-124.189164,-117.462963,-64.863583,98.677067,157.491469:156.366763,167.653787,152.952677,133.459197,135.247533,240.590436,354.171298,565.911372,633.350261,634.409849,583.305613,535.911085,463.643864,443.973651,388.458926,349.533027,288.141682,259.268531,241.497795,125.584658,50.82091,51.91204,110.862539,108.52535,-33.811749,-84.007238,-115.474415,-111.220938,-181.9799,-268.827775,-339.387075,-243.18943,122.545514,310.027807,302.124105,270.054335,272.50157,322.27563,378.168595,473.816376,411.632047,349.914374,269.546386,231.489701,116.06719,85.617482,167.043873,251.441686,324.348683,111.071813,-24.117053,-120.172454,-102.817185,-84.045041,-89.75243,-95.651865,-57.298178,-20.629166,2.22281,-47.252965,-229.221826,-286.538553,-245.627184,-198.62816,-152.933795,-172.527474,-194.750351,-222.604194,-249.446621,-290.148218,-254.792343,-130.127571,-19.050638,25.260445,0.156518,-75.257815,-211.079393,-211.51516,-121.656278,-88.688194,-46.589606,-2.951473,-2.994577,-45.674868,-83.722636,-138.755328,-112.547727,37.056286,118.22571,67.235781,-141.106564,-214.656829,-233.323534,-202.534239,-78.526374,9.804071,191.224223,358.003653,408.40825,330.175897,220.135432,65.97526,57.557407,100.568848,145.92952,150.746997,106.372196,66.001874,-48.206109,-98.04579,-56.364749,38.732025,234.652447,289.146776,261.848279,155.195699,101.290672,45.582326,45.902123,61.488739,43.372888,23.149427,12.456675,2.520537,-91.183339,-116.071711,23.61513,160.879768,417.707906,438.960846,350.172987,202.985891,186.433855,204.663538,219.76811,199.035306,91.069588,32.888772,-37.886911,-46.553638,-56.214581,-75.041599,-130.809621,-137.712991,-69.199762,-48.997807,-92.000101,-178.278404,-189.036655,-167.443099,-134.737917,9.973741,147.97007,145.260702,46.518336,8.797273,-18.241432,-15.223128,47.155097,91.473472,124.743397,131.470382,147.513129,120.604483,56.657541,-57.47574,-69.77609,-65.692839,-100.653506,-146.851103,-273.066698,-309.719345,-288.561334,-249.009524,-157.942397,-112.691664,1.922495,57.442923,10.421259,-151.697292,-223.8483,-321.697795,-317.738533,-191.624155,-70.138811,-65.400835,-163.53312,-214.526304,-266.422321,-276.956569,-210.618794,-118.516705,94.092574,161.408354,115.549041,-18.455315,-46.292357,35.158685,115.148943,233.321585,287.898645,291.764321,248.441223,226.917082,221.440634,225.811994,249.054032,291.60222,407.717896,391.821241,318.250227,117.402199,15.37863,-88.962243,-75.838737,-74.676917,-209.65501,-255.892473,-190.888723,-124.581159,-84.93254,-111.09053,-147.126794,-128.107542,-35.315482,27.962233,40.246892,54.657205,46.299396,15.986734,15.54419,30.140917,17.5837,11.159793,-29.383205,-85.83204,-215.392976,-258.058926,-316.350512,-337.545352,-281.137318,-134.855006,-119.909547,-233.716354,-281.668575,-246.914354,-197.32024,-131.248715,-130.079108,-145.473027,-226.448404,-283.900665,-354.738327,-347.961397,-262.139665,-221.234341,-196.906466,-156.471871,-128.767418,-113.801524,-139.400453,-199.771737,-181.61484,-46.98845,40.266787,25.513905,-116.414557,-201.647737,-253.553239,-217.250898,-117.618737,-77.731924,-27.635928,-51.693364,-77.060972,-105.607797,-136.846849,-248.898973,-273.28327,-148.896287,48.639009,63.242065,-26.204075,-55.246879,-129.607347,-190.69087,-195.071279,-116.138536,46.499988,90.002627,81.270218,48.4455,19.186561,-53.238171,-72.172638,-50.905889,34.756536,81.329417,141.729656,144.050335,21.789437,-84.854194,-196.605636,-169.084515,-1.296631,109.344242,91.621188,37.309572,55.403028,154.882222,168.482906,75.047165,43.569647,76.108952,109.720738,91.757872,63.58501,72.736273,145.2514,202.690229,259.906412,151.21428,68.111809,-19.374069,-25.852856,-77.363212,-112.796091,-75.292969,32.002165,30.973437,-44.151821,-50.366259,32.1323,91.980025,188.914398,217.221957,272.163173,282.678764,251.222382,207.795956,190.391328,98.162948,72.064815,116.326217,133.539573,118.695381,82.997669,59.943675,1.950907,-16.543001,-5.363299,14.874436,48.922502,95.36981,148.086129,216.590383,166.085991,10.749655,17.931277,166.815552,247.00105,253.321459,203.118615,127.538811,-70.408251,-118.391643,-24.012013,65.496313,195.049627,218.763252,192.361392,147.039411,131.724876,44.819129,-13.654615,-71.092539,-44.719222,-29.921629,-18.245816,-16.09066,-31.820958,-44.699285,-58.029914,-65.006762,-112.670775,-240.712249,-315.420229,-360.38677,-310.898843,-200.625012,-200.949694,-248.27877,-196.74487,-173.368126,-238.658912,-277.477562,-226.611717,-162.636493,-78.314412,-45.50384:84.899475,218.317282,219.133742,153.941831,130.794837,164.218048,226.401184,401.528747,573.720638,618.695614,564.819526,495.49936,368.291894,333.889801,373.128854,440.361745,560.993408,430.997365,267.266481,-11.974431,-51.901266,45.712538,113.35596,150.635291,51.391301,-31.485059,-187.649478,-234.891161,-276.153728,-270.716116,-179.592007,-91.093436,131.683078,245.84968,231.967048,161.928992,149.704424,237.948464,333.334417,527.758574,585.642854,524.768009,294.893838,188.261469,66.049269,71.052067,222.167927,326.578455,435.872037,268.413017,125.581176,-54.543654,-101.434387,-189.967333,-183.380894,-31.651244,38.534327,1.404536,-101.426356,-165.971648,-329.834751,-360.083897,-237.82123,-152.421196,-60.461114,-80.584501,-113.794031,-138.656274,-137.453063,-145.132521,-129.359527,-13.416743,157.401775,186.595748,42.293702,-72.994088,-183.996365,-143.524718,40.280154,111.873029,151.775981,79.232371,1.972729,-185.464941,-254.243472,-253.120225,-188.746455,-12.722695,54.701448,-5.045218,-220.567109,-319.587032,-424.602684,-406.562856,-243.577187,-133.585882,120.81804,318.533215,329.986359,199.129401,117.996478,66.898517,92.150509,164.119657,254.108205,265.173109,129.397556,13.538116,-149.870823,-144.233383,40.727401,163.97831,313.710794,270.966341,202.65184,17.899705,-69.940174,-103.343184,-53.789458,26.878831,6.358187,-19.106556,-41.413887,-59.746405,-138.364519,-128.652306,100.323749,262.442916,490.443462,442.534136,314.450653,53.168747,0.762482,48.735523,95.834418,165.764851,198.037461,164.465747,-28.133543,-139.605731,-251.204193,-224.427757,-70.966872,3.309379,91.143746,48.34177,-20.398518,-190.139748,-279.212626,-347.829286,-276.259658,-2.524355,196.229853,206.40311,74.807047,-8.247828,-113.402702,-125.447451,-23.582336,75.49422,211.87894,186.780491,162.613046,84.653398,1.766176,-122.752117,-108.695049,-19.23291,-14.425754,-49.227804,-179.788654,-265.398276,-371.240195,-345.416555,-170.828541,-67.682042,107.825912,114.359946,28.775238,-190.191693,-278.995779,-324.249094,-259.813291,-73.356084,8.338205,-31.542242,-190.095182,-233.533014,-267.165979,-286.683625,-228.554834,-120.351296,114.819599,133.047165,67.439011,-68.095918,-82.100374,35.707212,118.578966,261.444621,397.906801,414.477621,277.924796,169.718849,3.346082,-12.130806,136.390502,267.792752,440.088222,314.414743,197.024797,13.101088,-40.946672,-87.644584,-95.101561,-120.944321,-161.68538,-170.974002,-138.039853,-126.002782,-208.346481,-262.36404,-226.339721,-146.169246,-38.90271,-56.340587,-66.650958,-103.034374,-142.268828,-161.670412,-109.557634,-7.13076,-44.021653,-86.837122,-172.068715,-225.725505,-344.943578,-377.450145,-374.730777,-342.6618,-213.135464,-145.886776,-193.44277,-379.041968,-437.788728,-378.131694,-286.07241,-108.060451,-38.662899,-58.546044,-176.959533,-249.693603,-353.752668,-364.707644,-336.021658,-302.33103,-153.369938,-22.581623,-39.49209,-233.546476,-336.477423,-329.291551,-213.947759,36.848708,101.527497,27.170045,-239.809646,-339.088721,-357.679184,-302.247225,-150.612551,-75.239584,15.619351,-14.615748,-47.740332,-142.331532,-214.665777,-275.702957,-215.989642,1.206514,130.816272,119.583938,1.733928,-68.254173,-149.926492,-136.94725,0.954652,89.482355,202.525239,204.398601,161.990425,41.818549,6.654861,26.862394,60.84664,112.333914,174.977137,208.371064,198.037139,134.623919,-48.747202,-102.275441,-51.572199,19.537286,175.20145,250.950998,208.504124,25.468972,-29.636513,83.909398,214.770341,408.054758,403.454002,338.468582,154.705359,72.210863,-26.479193,-25.059182,88.979231,178.598465,325.014578,276.749421,186.140687,-4.485454,-77.909798,-90.547052,-16.410543,142.309352,162.597208,133.385944,30.116404,-35.675022,-116.35003,-86.10624,82.915848,167.592237,300.980997,269.289573,156.122117,-61.787114,-91.973638,-33.922903,16.652853,120.318088,189.298226,187.499249,67.937593,-34.713429,-161.270988,-131.417043,2.221699,43.54512,132.402963,228.625188,216.333292,91.209241,18.545154,-60.323703,-36.039948,97.394121,177.639807,167.075823,71.876102,-1.961918,-162.289206,-192.905682,-77.400443,20.089956,139.789914,95.713863,33.840493,-72.963311,-97.710731,-68.818118,-25.384495,42.193973,50.090272,31.564276,-34.277137,-71.779562,-133.00171,-142.794485,-85.004435,-13.15798,127.838746,46.715878,-75.540004,-248.586314,-264.987525,-248.785788,-239.842294,-183.054541,-88.867354,-74.360858,-128.965797,-181.378145,-270.827722,-244.436837,7.604973,153.400266:-94.730793,-54.209451,-11.272344,54.853804,61.011442,113.420355,197.521566,422.189025,556.589579,569.077417,539.22332,527.649376,504.946283,478.391045,432.187492,427.073961,395.95513,249.344479,168.869276,108.826266,108.602878,50.751833,-11.23445,-114.683895,-126.528037,-122.236889,-120.000766,-128.294448,-276.39064,-408.104613,-493.111099,-369.35093,18.646284,187.814939,167.334127,131.303994,160.808936,276.768927,349.372307,420.537668,277.958008,178.650889,87.896463,96.059339,43.399962,-28.439608,-72.71769,-17.897494,110.2463,51.15263,-29.31931,-106.796018,-100.275493,-95.997504,-104.30931,-103.921185,-82.987433,-80.424444,-122.362672,-166.697663,-272.005246,-309.018548,-326.788605,-315.571009,-271.605895,-252.490422,-258.668332,-260.636883,-271.873223,-314.922113,-295.417647,-141.291928,26.11853,69.374481,67.205101,57.255425,75.607876,93.431107,139.488518,167.209909,190.894178,153.887473,132.626777,134.973116,135.271934,61.949181,12.326775,-0.21616,73.158273,75.416973,-35.713816,-106.974982,-199.638729,-223.259399,-229.855242,-202.162868,-52.489864,141.026079,193.85073,174.896445,116.4797,4.823909,1.683166,82.435027,146.106085,136.216427,66.291686,50.19338,44.276315,42.188862,108.285344,171.18595,262.119507,315.465374,353.223071,412.744076,400.580725,305.576138,263.701386,232.349697,192.661651,132.732137,3.922391,-22.478114,-36.756103,-34.984916,58.710131,138.707645,241.40887,214.298006,184.069247,186.888239,208.513027,232.117908,249.63556,280.363181,218.292065,156.795492,13.547175,-39.635324,-41.30175,-6.869257,28.124322,19.945168,38.490022,117.875199,146.281306,192.937791,199.647425,128.964286,98.02861,166.902611,300.406407,310.825592,181.685377,116.684661,128.746729,157.862378,154.584472,155.858453,208.285937,248.128974,255.232888,253.869046,234.494662,137.721517,92.429743,65.754633,36.751344,-5.475587,-127.624365,-166.17363,-164.099,-163.214731,-193.726525,-172.717812,8.292497,118.356061,73.550084,-87.028053,-150.92142,-262.529837,-314.053132,-347.516727,-254.573611,-228.999687,-309.153865,-339.997435,-291.114178,-253.876272,-215.353475,-195.236933,-65.382324,35.466511,13.216672,-45.181435,-44.526095,-28.948184,-23.11007,7.150543,97.54035,140.280884,152.034819,143.251186,116.736279,104.539884,183.1236,257.847209,329.507165,269.682817,199.35532,-5.625209,-103.925556,-193.910238,-212.158294,-344.584062,-469.949771,-443.493511,-309.837843,-274.306244,-294.152832,-312.453437,-291.269896,-246.511328,-97.761861,62.126481,107.249512,92.700966,49.811658,-26.209536,-48.791481,-81.542047,-53.82991,-10.75118,32.397284,11.531844,-56.679089,-85.971347,-160.867002,-185.192301,-88.003081,28.803185,-0.247517,-172.420661,-245.136011,-268.510092,-229.260296,-123.593942,-88.067065,-98.631179,-103.872767,-105.35529,-191.802865,-251.733325,-213.210225,-119.151644,-10.423961,-67.378377,-92.354074,-44.224808,23.322978,152.816048,172.084027,115.423621,70.061803,73.83861,51.322566,5.468343,-60.732466,-59.638483,-59.069667,-73.660472,-99.584818,-105.428341,-100.0028,-54.454115,-41.638126,-133.112819,-188.319546,-129.469126,-23.852476,-38.618329,-111.410336,-126.673906,-149.557562,-172.093309,-168.378187,-118.205463,3.506722,49.627421,47.222792,2.573445,-31.024647,-58.504057,-44.794978,6.214826,112.362496,181.352094,238.73806,207.964401,53.16526,-40.791014,-133.283321,-118.337438,-25.162173,48.738849,52.421351,19.763111,13.119767,80.259824,134.601935,168.193826,130.154209,120.169359,92.908457,81.656247,105.91558,121.6867,154.52651,197.292098,257.403533,138.568989,57.449938,-12.998128,-15.829265,-11.511547,0.009729,13.783439,-15.945152,-41.881823,-87.277095,-81.40835,-39.75586,-40.934134,-25.373531,33.055994,185.330672,229.447371,208.250012,176.777965,160.415034,86.638753,77.405606,138.003332,131.357187,102.116337,66.597372,70.523917,93.378409,80.467199,-0.443529,-30.909729,35.092829,241.284179,313.344867,303.728085,247.426955,101.395463,61.677423,127.440496,219.46819,231.275837,201.921127,160.864693,-0.098928,-88.832021,-123.365031,-53.724261,161.126155,286.043328,293.124807,296.875677,296.743458,233.869501,197.020133,181.497384,228.163116,266.370672,319.166837,323.793461,257.194583,197.058122,130.141076,111.501036,11.592059,-144.901931,-217.783166,-300.978704,-306.364062,-301.981907,-295.49983,-221.778096,-130.971873,-135.4433,-271.55059,-354.090051,-404.626911,-357.084234,-180.271335,-100.17589:-107.942721,-115.044215,-117.409972,-93.271718,-48.885936,85.838869,142.646715,230.750748,327.106672,360.143891,399.308383,409.032972,328.65392,240.357275,126.165135,123.147785,99.569373,5.327087,-20.321982,-26.179459,-38.51516,-75.330777,-72.866899,-42.791778,-43.280942,-46.249113,-41.42823,-58.889064,-247.774107,-396.669623,-518.969808,-425.201855,-58.032752,200.946712,228.986358,203.617126,199.003783,241.182279,269.56375,266.101797,213.157491,185.414753,136.488409,116.063079,4.070264,-80.980616,-130.906096,-72.722769,54.506092,-19.272467,-106.776753,-191.441172,-183.018882,-186.469413,-215.093451,-242.782222,-115.962356,-25.057371,57.142243,39.145078,-70.907109,-147.08596,-268.143196,-285.721518,-265.230221,-309.206454,-356.256693,-378.561938,-357.532429,-332.228609,-326.906129,-275.171058,-84.429632,6.772353,-0.666182,-69.328174,-146.058681,-135.872477,-100.465629,-93.55099,-97.995137,-111.996552,-98.701855,-54.306799,-72.131435,-177.788476,-206.848605,-140.461785,0.371803,40.720169,33.475963,6.762098,-61.005677,-94.499033,-110.154838,-80.534494,73.380719,239.347738,245.350181,142.706176,92.252582,55.190427,75.233116,154.977056,173.993131,159.190353,125.741903,89.107546,-49.362307,-97.342407,-35.688761,42.902106,215.752813,368.250846,403.657125,387.543407,340.680947,192.548375,124.110558,98.041254,223.983838,261.732384,164.838597,70.363911,-31.609511,16.518549,257.578667,354.131907,378.609086,306.353818,290.368475,318.443195,331.063479,324.650981,317.942919,258.973521,168.631651,131.279291,35.31851,-12.761507,-33.619803,-3.150923,66.234146,78.008746,55.952878,30.127796,22.780911,21.748427,16.214055,-22.541657,-18.383462,104.176525,242.320529,231.619261,74.239454,37.170758,127.928091,180.979479,222.62266,232.336253,251.009352,225.585234,184.072538,95.884884,55.328754,2.839319,34.481291,179.568383,191.091529,126.275855,-60.967742,-143.460246,-175.686834,-140.465889,-112.910026,-119.435723,-69.655246,-1.372383,11.897298,22.218398,-1.464423,-120.954582,-169.38221,-181.164568,-155.74941,-140.262971,-91.129934,-65.488454,-76.654286,-113.697731,-144.848425,-121.223087,0.159314,117.048422,108.742888,38.662173,16.146632,-18.259062,-5.923957,130.041638,247.125186,248.009497,207.730838,198.482617,165.295196,132.78622,132.648094,194.023953,336.770467,276.714344,178.051869,19.510156,-20.255424,-67.838569,-82.263547,-118.393873,-161.730388,-176.807571,-190.144776,-176.532115,-123.915066,-117.502254,-117.761637,-77.723575,93.795171,204.338337,199.780663,162.514762,148.020291,126.693159,131.751467,126.478909,66.362665,52.128578,32.829773,1.682247,-58.595245,-69.32423,-111.129288,-147.864041,-128.921192,-8.6742,14.358208,-11.455761,-24.553695,-4.10834,4.510053,-62.939471,-150.935407,-167.294079,-162.360178,-146.279409,-150.772628,-168.292796,-103.669321,-33.493665,13.614202,-36.019932,-31.267172,24.286129,33.73333,33.824671,56.594213,127.086666,150.651377,131.991979,51.03596,10.997729,-41.780655,-61.439738,-81.451379,-68.499715,-2.867004,50.687083,64.318169,39.050025,-19.768013,-144.891553,-154.290513,-65.625722,35.540635,49.280506,13.105165,2.944963,22.777051,37.833007,71.065753,82.892695,123.122357,179.384489,186.51487,179.123239,173.551502,162.699283,161.109275,179.938601,299.270554,374.830051,381.526051,323.436437,203.127059,145.220237,43.035254,16.899346,81.963612,177.874377,166.819064,135.558788,162.563784,233.764828,228.579572,141.908467,141.985106,181.297384,184.9063,153.689834,113.195308,92.610951,72.754533,98.086351,181.267442,212.405754,194.983795,111.330458,49.160144,-57.716806,-69.696184,-30.785694,-11.676547,-19.3015,-9.174047,31.025949,119.123716,124.998735,69.600441,62.509776,210.014834,382.937374,379.62049,266.535685,215.275225,165.967352,174.936181,221.807376,186.964136,143.812814,93.757661,91.566588,46.931365,-11.06029,-74.2053,-46.119497,51.259198,169.590491,232.613596,264.754895,228.078578,124.74273,87.111961,61.496757,83.470948,95.780893,62.073759,24.443005,-52.242205,-86.316665,-79.947401,-24.939477,131.716677,229.86276,249.078453,245.176599,197.233912,36.277485,-22.710288,-64.924602,-84.984982,-90.943157,-72.71233,-53.837342,-60.869766,-89.272698,-119.346173,-133.384562,-272.326025,-481.229098,-527.434156,-458.119086,-386.45019,-288.102657,-295.13399,-392.078061,-411.198194,-404.660195,-434.920814,-434.417558,-375.476056,-340.344797,-262.830557,-235.530862:194.581549,234.235224,183.67213,104.332621,98.059524,203.233677,315.233886,512.249957,577.94373,587.839906,583.073091,579.703985,572.202108,540.241075,464.291217,450.858652,411.183812,297.107094,240.605067,132.287474,68.434305,-5.482929,-13.143285,-49.961001,-53.424184,-46.608365,-150.795537,-247.711941,-356.624588,-337.032788,-216.115378,-139.238087,47.49952,196.231281,212.762562,155.537571,140.49505,266.182317,388.429908,530.173821,409.844704,316.845521,160.18724,109.399698,127.057682,168.958837,179.022858,175.789813,258.021608,232.726543,120.392308,-96.548291,-121.708991,-68.678931,-45.090819,-24.347179,-62.181115,-124.236306,-257.121483,-286.677256,-297.929907,-287.186988,-211.884088,-169.634538,-102.839475,-83.638796,-95.107319,-139.789898,-194.501175,-286.918643,-249.373603,-66.83703,80.804418,127.43673,139.315069,128.281429,136.193436,137.300241,125.946044,145.174466,221.495638,192.511994,129.50532,46.788606,38.481473,25.677087,29.466843,57.727151,48.214999,5.464295,-138.556679,-194.522037,-245.848101,-247.537478,-181.805054,-126.152271,19.492683,210.978974,274.769268,268.513892,205.645857,16.081767,-48.35797,14.614089,172.590777,171.625502,32.173171,-19.06522,-22.933609,-15.443901,32.531434,102.838169,223.481664,192.549418,180.300575,208.098529,196.693703,122.013779,107.754618,121.303252,77.664077,19.413992,-71.613096,-76.011104,-95.438615,-111.884304,-22.420941,86.601509,254.856591,220.778628,180.321402,161.219076,162.275699,150.503448,159.687746,203.07367,169.112616,111.987591,-20.413575,-60.146044,-74.514556,-67.462978,-14.564036,26.3451,94.974222,102.734891,72.775769,22.757016,13.955288,-23.07446,-40.650869,-8.662212,111.434999,157.296317,96.725652,24.61693,-58.557168,-66.802124,-5.201421,74.590922,240.158045,261.951354,223.237582,124.081102,75.236404,-0.942557,-7.65473,17.640917,-24.187325,-50.187974,-83.637648,-114.869324,-193.970432,-207.764192,-135.135146,-62.394851,99.470558,133.395704,56.674425,-146.314027,-204.754419,-230.48026,-214.047338,-159.311028,-90.706419,-75.824811,-164.155559,-234.543885,-311.122233,-303.919585,-210.576367,-133.512636,36.154563,60.686913,12.087635,-73.882156,-101.600429,-99.366311,-42.72926,114.822623,165.505082,142.628251,98.575911,101.565137,121.26778,127.644771,178.712153,233.736411,335.848051,298.080539,219.150888,32.654117,-26.199388,-33.92662,-37.252057,-157.404532,-250.713045,-249.998945,-258.668216,-287.645433,-394.746928,-436.337825,-371.772856,-280.633988,-82.883854,59.755745,88.241346,43.900109,-24.653798,-147.205782,-153.857344,-104.234044,-46.426253,-10.063448,-5.277709,-66.626014,-216.723923,-246.902255,-231.061154,-210.346866,-144.114017,-130.165502,-171.20558,-291.229027,-327.129927,-278.103888,-208.971723,-105.38425,-90.83721,-82.144551,-32.083019,-26.285814,-153.707066,-241.152819,-227.99825,-134.941559,26.817063,57.044716,10.055828,-115.016986,-126.582692,-39.611578,21.424147,103.55528,120.089287,102.805122,-15.962375,-94.846611,-159.515966,-121.003472,19.112877,49.642499,-45.066345,-123.992551,-103.264212,-78.591968,-125.757882,-212.607201,-164.537058,45.42478,141.081172,135.99126,34.731004,-31.484568,-75.581443,-67.244783,-12.687103,42.595828,105.635882,61.107567,33.324538,-6.179256,-3.318745,67.188742,105.761251,114.392752,102.273783,124.12571,201.403529,229.909586,172.222676,81.239124,-48.324079,-22.157809,160.535325,266.88537,221.744026,35.670262,-6.911151,82.90843,143.162879,165.98147,197.175582,217.688291,183.05519,164.965833,174.223008,174.866562,170.898501,195.904513,268.737838,156.31701,40.534255,-138.671881,-168.214758,-85.88997,-11.272589,56.644312,-9.245593,-53.989201,-119.464449,-138.527213,-134.758851,-118.394837,-76.443615,-29.111243,139.520749,204.433691,165.246231,96.61123,80.31128,53.599548,70.512779,153.194903,158.338568,117.852261,17.894366,-27.18434,-92.22882,-88.823995,-25.12674,-5.264126,37.711645,170.270631,234.648807,259.648079,214.494326,113.691842,102.359704,136.734835,201.003844,227.423368,119.936421,-11.851438,-187.913931,-166.403621,15.310411,105.344157,222.714981,252.674608,208.316436,88.101866,90.394185,169.88946,158.31528,28.35913,-22.903492,4.483433,101.585925,149.456319,178.125424,165.948305,164.603415,157.709097,68.414129,-15.834609,-26.876331,-43.488436,-77.476127,-165.350929,-170.843447,-99.982628,-84.432728,-107.798109,-133.693956,-132.117661,-152.542155,-149.568628,-40.740235,34.622775:forward
-65.252029,-54.79132,-49.37723,-100.997219,-139.310292,-191.512156,-189.098454,-154.218715,-153.939962,-159.055299,-153.526376,-138.952634,-103.975824,-94.640773,-64.818636,-39.128145,36.157039,100.850387,95.604542,83.681985,102.463839,121.036039,108.469505,54.425068,6.930905,25.685091,87.919333,65.921055,-54.613467,-78.450435,-28.392348,-6.664507,3.005185,57.954056,93.548686,102.760182,59.328037,-66.279729,-103.26973,-121.213298,-95.290694,-75.428395,-37.215437,-5.80785,46.825731,38.635915,-23.516592,-40.610813,65.331176,289.382687,320.507129,183.84926,101.602058,0.679877,-28.728944,-32.507478,-7.326113,-27.435844,-99.979611,-108.634283,-117.033057,-152.158508,-208.249483,-196.292046,-104.539947,0.023354,25.578536,46.645871,63.240617,108.10861,127.083791,151.890557,131.372373,85.758459,-29.104619,-58.038513,-73.536877,-90.330684,-143.717573,-180.379103,-251.964937,-236.298004,-184.272798,-80.120786,-90.147301,-220.027841,-266.716214,-238.199649,-138.35818,-111.024125,-188.545578,-270.795447,-333.78842,-291.296232,-184.42953,-158.945909,-94.066591,90.201065,166.649284,167.118623,123.253614,54.027506,30.882393,-33.265613,-99.127338,-109.22626,-46.870878,8.863671,65.056723,76.342208,199.320692,278.654466,301.400208,206.729613,155.511284,77.504256,39.431779,-69.437736,-107.234176,-112.772575,-135.092815,-174.597574,-243.205798,-234.209974,-167.029552,-144.135713,-128.618961,-118.653032,-55.900005,-29.163946,-64.248529,-133.555296,-143.842143,-133.378509,-102.8905,-37.723451,-37.844145,-46.039122,-72.564765,-85.58401,-102.402394,-110.343303,-111.257705,-106.240192,-128.276338,-139.286941,-113.942111,-75.287097,-93.923881,-152.373536,-146.097933,-55.506437,55.747234,89.243354,85.297687,78.554696,94.690304,97.606248,96.939881,102.954784,132.914952,192.431432,208.249249,188.235494,172.316868,156.565416,165.014117,196.105556,138.623134,83.026068,33.762579,48.19429,59.695152,45.913602,30.859228,32.365619,75.59301,177.965864,202.131005,160.453698,117.387275,18.394264,-7.021656,49.872202,68.11722,9.336507,-110.796669,-123.677345,-148.394138,-207.661021,-347.936802,-375.089682,-293.384524,-120.42145,-88.676239,-162.025893,-204.855409,-174.017426,-90.764543,82.761228,98.030739,53.472977,17.660613,82.940835,209.533052,156.777677,-52.729918,-77.966865,42.074244,167.935246,206.758469,296.91614,342.260402,353.979082,332.431902,298.347464,308.00167,317.928466,280.179555,236.760851,131.169834,89.491136,103.737707,133.946113,162.215134,232.562395,259.353082,196.611018,130.633304,37.6953,39.184367,89.621623,57.748452,15.883927,-25.754641,-24.810939,-61.163797,-105.649259,-132.351139,-90.730202,4.002956,46.186425,64.781414,86.56644,66.552022,-0.038965,11.014498,126.329473,194.135751,185.074167,101.349487,43.422429,-47.87225,-48.135365,39.438079,69.311178,30.872617,-62.228623,-113.292768,-191.111146,-221.906631,-326.548878,-381.802896,-410.670728,-322.068883,-257.826752,-169.066913,-150.146488,-124.455361,-102.415849,-6.153487,50.240532,93.173655,58.546947,26.881094,-31.385442,-57.765575,-109.732825,-108.807081,-17.866224,103.838088,133.17213,91.775541,37.745618,-93.182276,-150.696418,-144.421612,-84.581216,32.659257,134.699059,167.984685,118.843086,49.360498,-44.863514,-32.178066,11.872075,-12.149085,1.764541,68.345164,84.285354,79.110877,66.830818,76.758533,125.590694,273.987316,327.281926,297.731718,230.503709,219.022548,208.614313,198.381183,180.419982,202.545494,224.866964,216.247603,170.37335,45.350387,-4.220938,-47.165181,-63.496609,-94.403078,-39.379307,-9.547089,-20.78606,-38.209722,-39.20965,-26.145084,3.167542,67.713841,112.636167,111.720337,54.20703,-82.962589,-128.001111,-140.990207,-107.599889,40.02789,132.911605,85.555759,-102.410569,-163.899437,-147.406186,-77.735838,58.863723,47.015683,38.098707,88.878598,91.999768,-51.63644,-149.41856,-197.763246,-162.283147,-121.057639,-75.533548,-52.191864,-73.021464,-104.119421,-157.634718,-154.995859,-89.371889,-65.40671,-85.298233,-137.178918,-141.543764,-126.674603,-135.353023,-146.355734,-120.026705,-48.24885,-74.593517,-121.957337,-116.036869,-48.04706,16.778156,-13.103025,-61.32538,-17.275525,-4.612855,-72.494521,-120.842558,-172.158648,-201.855775,-304.18021,-321.165826,-183.188951,-38.142805,-63.155662,-188.964856,-210.574427,-188.749096,-176.012168,-168.625646,-133.123622,-92.421415,-59.190785,-72.800125,-74.920452,-69.900023,-78.464214,-58.993073:12.551573,-45.085541,-20.899942,-17.539452,-70.700326,-138.544606,-119.253496,-55.666688,-3.097998,13.934543,4.141904,-15.843852,-50.366363,-57.070397,-11.201067,44.544479,176.125837,250.315591,221.497373,107.883679,91.393667,181.362455,236.495967,203.686736,94.522955,77.985527,34.632694,-17.789206,-141.268927,-183.175382,-196.4913,-178.963876,-93.317222,22.214464,47.439982,5.91772,-43.720182,-129.427591,-158.876124,-185.233817,-68.607645,3.880726,-15.8398,-94.34299,-186.80126,-156.38659,-75.273018,-78.013875,-50.643427,84.222012,113.765634,68.665066,39.357033,-15.095289,-44.977248,-56.371018,-15.242104,-19.656837,-75.935646,-97.952954,-175.820626,-241.190382,-306.977136,-276.997217,-131.598508,-8.550669,6.319915,-20.549438,-36.277816,-40.174903,-26.092755,22.922162,73.450065,80.773505,57.930686,29.945225,-74.154691,-117.722308,-102.247557,-91.006195,-133.898356,-119.340014,-88.375579,-77.905152,-105.389025,-155.7137,-162.609191,-172.452528,-198.85889,-223.448309,-246.319966,-234.101577,-208.29233,-177.926313,-37.902227,20.042489,52.036784,132.105373,173.741356,113.656097,28.43448,-73.115943,-70.594823,-85.789594,-109.729689,-86.900184,-54.933943,-64.311064,-61.49231,-13.333089,166.639785,225.117795,186.935113,144.344688,161.630437,151.636702,84.297982,-71.791815,-101.956481,-66.689763,-0.879095,-11.384272,-142.200329,-210.93082,-247.842385,-208.976099,-71.915441,-2.975354,112.811061,160.947135,133.110645,-1.77376,-59.303385,-45.529473,2.158959,31.102497,30.48406,58.558202,103.678533,93.665489,2.588443,-50.192555,-84.694787,-64.630983,-20.976392,-0.475372,15.456793,-30.896861,-121.012763,-255.614239,-227.993863,-56.332935,91.345423,128.867814,111.732111,86.338116,102.152935,133.802815,163.905514,141.006204,88.371038,98.245525,90.590604,35.367798,9.661967,5.419941,15.778264,21.517711,67.609759,100.216549,87.551456,47.031502,-19.526556,-24.43806,14.94864,35.20913,87.880234,153.316934,134.840051,11.888735,-43.485506,-103.86864,-93.749878,18.443685,100.539195,77.975236,-40.979467,-96.404684,-194.860804,-248.785173,-324.324989,-334.966717,-281.462674,-161.238409,-143.502674,-205.683416,-248.118758,-272.458531,-232.559581,-85.495658,-4.863108,-28.312898,-80.038646,-53.24039,-21.77779,-68.219338,-110.727138,-57.549768,51.026374,45.388892,45.919904,148.722254,201.204695,163.01382,118.116958,138.305419,226.117174,225.499915,105.985935,28.584528,-65.020272,-66.771662,12.047446,57.222765,120.89426,165.801269,145.392211,40.05806,6.859281,21.77561,38.649821,14.567845,-40.892351,-64.493555,-96.677141,-93.482344,-95.72254,-113.226971,-89.385912,-21.163278,153.577234,211.309045,178.221665,63.784222,26.175431,29.963756,46.192244,56.64793,91.806581,115.720486,67.553594,-5.034317,-131.570004,-152.783391,-107.158983,-61.102803,-8.747649,-76.865441,-127.047954,-192.190041,-217.50172,-277.409344,-298.975,-288.326734,-178.426443,-107.150792,-57.948669,-67.976571,-62.573181,-45.169272,19.015756,65.348238,144.075206,130.626066,105.78471,85.463572,52.619795,-55.240666,-52.443605,73.755364,163.730728,168.897002,95.125187,33.930937,-42.152929,-38.835611,10.390023,34.740652,85.298369,158.921491,176.900177,126.070486,85.664779,74.183024,96.94414,98.256758,91.722034,129.04842,190.207663,171.945478,96.525867,89.341291,169.780113,222.296821,276.383432,285.050041,278.188316,269.470198,257.102555,172.356482,144.970889,215.620224,328.669446,336.811097,201.522625,101.332999,-41.704102,-67.130319,-26.163843,0.019046,7.074752,8.836865,-25.475312,-152.497915,-173.754948,-106.124072,-65.502666,1.597904,59.82637,49.403005,-73.385108,-132.541139,-160.913638,-143.71698,-80.372619,-70.341726,-88.027946,-17.675415,19.226889,-12.255583,-74.994645,-173.878956,-161.906382,-58.263672,30.898648,65.178374,74.577725,25.33397,-128.199552,-178.182996,-188.932065,-184.214673,-158.181443,-79.606351,-68.643163,-139.572451,-191.978656,-257.926798,-252.694,-178.567774,-119.917277,-131.895325,-220.769009,-249.026174,-225.116899,-211.389172,-215.283919,-193.61205,-80.525919,-43.777345,-67.058339,-77.748172,-64.757829,-77.297396,-94.897076,-79.034812,-5.450352,20.175782,20.016026,-7.209433,-122.082038,-185.765977,-230.817116,-199.129295,-60.581455,36.388259,17.067687,-57.741388,-60.944846,-78.320536,-121.463832,-175.827071,-102.004101,-73.119241,-85.538198,-81.019668,-62.281959,-70.199447,-67.474247,-46.127166:41.074953,-62.945065,-74.606596,-30.661908,-19.679778,-61.358679,-73.140666,-11.636049,119.196371,152.74434,50.878843,-43.570806,-148.579745,-141.616579,-41.650697,35.502402,186.008153,180.347048,122.101045,74.033008,94.206333,148.419226,159.979211,141.036071,132.901719,105.877428,-34.702136,-91.633059,-112.180991,-118.233731,-181.980798,-211.91275,-189.859298,-116.101642,-95.743099,-115.348165,-158.295167,-210.360224,-178.877119,-69.294409,-10.482196,-7.132296,-74.439009,-133.84241,-215.427794,-207.517354,-119.714243,-86.228741,-53.7337,-26.766245,-54.60318,-179.553935,-225.233599,-230.789545,-205.824948,-136.172474,-62.536723,-49.720346,-114.45308,-167.004341,-237.640733,-250.898983,-241.486266,-229.967339,-188.642638,-125.272001,-115.970385,-128.598102,-125.948861,-97.298229,-87.381604,-75.535184,-20.377485,-1.203189,-21.000434,-24.576826,-17.315407,-39.122979,-100.342753,-114.071554,-119.883871,-105.075798,-99.226627,-132.192213,-168.033234,-216.543832,-218.381789,-197.929085,-166.741036,-161.833606,-191.035098,-233.592102,-325.103649,-313.10036,-144.086518,-56.203203,18.363947,55.510538,75.535537,45.661077,-6.612376,-94.614516,-112.431435,-124.780741,-111.337023,-99.333561,-140.433985,-189.843086,-240.042506,-210.376989,-45.767172,47.650292,140.546042,85.041384,46.498164,-1.445951,-31.031393,-95.774944,-113.030637,-103.408736,-76.568889,-92.699552,-203.314769,-259.753289,-302.29428,-279.822177,-150.990049,-81.769192,-4.913232,5.933122,-3.903019,-25.299569,-23.126604,34.862026,80.764961,137.948207,158.637216,165.676295,132.530927,82.839044,-36.736713,-64.101388,-48.571942,-51.056065,-79.692918,-54.236758,-38.54402,-70.349696,-130.859401,-249.173778,-248.77352,-108.063267,64.466457,87.045768,46.509352,45.363839,55.4431,40.385143,40.960118,57.473373,85.064873,128.49889,126.913843,34.076048,-50.601386,-180.407418,-170.346633,-57.866165,-32.378843,-49.986575,-56.460435,-69.102582,-167.443338,-203.814907,-147.269868,-67.405164,100.204832,113.928265,61.277563,-64.270372,-126.74249,-190.965197,-159.296538,-26.160528,31.135601,1.285239,-104.929919,-163.228683,-306.633631,-357.622668,-345.853573,-304.30699,-207.174392,-177.009557,-196.048425,-235.230879,-247.755151,-261.714063,-247.708645,-151.097478,-29.497467,2.247263,3.130396,3.81613,20.110907,18.669726,30.824519,54.412437,92.899218,111.530799,108.321174,100.142238,114.62757,155.029592,159.14295,139.048821,152.127005,148.7096,52.744409,-0.745319,-19.019394,2.375784,19.11795,18.532646,62.17692,56.90578,18.095646,-53.829162,-86.519356,-115.930013,-93.283515,-43.159114,-24.280721,-11.03478,-0.169944,-10.906537,-60.231797,-68.400259,15.544594,80.303465,171.803119,235.806539,245.099346,110.98192,-10.124519,-105.267074,-44.488533,108.231836,148.9939,133.077482,54.277228,10.079438,-36.810386,-37.435976,-13.42997,-1.624756,-26.99098,-110.605526,-140.988192,-181.150557,-217.984568,-302.062667,-297.417145,-160.647184,-26.647146,-14.526396,-31.592215,-26.013109,-18.76472,-8.691958,79.387564,132.278484,172.016256,145.620195,136.892422,114.993612,65.678666,-37.129139,-30.633767,48.113953,167.922038,227.675941,207.238181,135.064554,-27.843824,-82.001564,-32.18696,57.224095,201.469039,185.069131,125.248856,26.366317,9.180489,-24.665833,-48.470501,-42.106733,51.332121,74.228575,35.808191,12.81272,4.479621,24.906538,139.514568,216.895123,355.311204,396.903569,358.221728,233.054318,178.823446,106.831681,98.5424,164.709943,239.29273,225.485668,119.125225,69.644889,21.850682,17.520538,22.127888,19.530789,1.694269,-27.034855,-50.622693,-119.587076,-155.987518,-153.367609,-98.298892,33.349971,71.395895,44.697278,-53.626088,-88.549577,-123.856946,-148.544937,-174.83782,-161.570222,-105.394138,-53.526437,-45.902364,-70.172398,-90.864791,-96.652117,-68.973506,13.007621,76.733758,79.026629,3.917566,-58.150462,-157.202165,-173.29018,-159.389286,-146.412838,-70.526519,23.490515,18.515496,-72.513296,-127.712615,-194.30334,-188.225775,-132.662224,-103.446749,-125.280678,-238.23663,-286.878431,-270.45389,-212.70096,-89.520613,-52.72875,-5.765725,67.050357,85.101297,51.447281,30.059257,42.668411,59.444036,79.359008,169.407896,215.259235,199.851948,156.118112,47.676044,-5.609009,-38.044927,5.759712,153.001344,154.111748,78.092953,-51.934953,-60.925451,-28.33426,-24.082616,-39.904485,4.696171,38.922318,45.606957,21.308498,-25.804707,-30.459276,-9.170379,-3.830056:-61.154022,-52.107833,-11.99648,-6.03842,-39.020022,-102.186517,-118.466837,-87.064332,-12.647041,-9.775288,-97.389808,-142.414946,-133.598323,-94.254736,-24.368969,-9.461294,42.190207,147.788033,148.438333,70.462231,62.321757,96.688972,90.478837,31.515049,27.304582,54.291486,94.550754,92.932208,49.088992,19.81136,19.073406,50.770255,77.598624,30.571544,13.02142,-10.092614,-40.574699,-147.250324,-183.767191,-171.818992,-100.204255,-54.464662,-41.463558,-85.481638,-166.17292,-183.226955,-196.362163,-192.591962,-123.762153,-18.325433,-9.675377,-85.356279,-129.371969,-204.050376,-232.912951,-230.357068,-136.888279,-85.588209,-89.630488,-142.919368,-246.217279,-272.619657,-262.331134,-230.257277,-130.240153,-62.929598,-72.981232,-115.532669,-119.32906,-93.177942,-68.260888,-33.980897,-14.257503,-5.262108,-25.56238,-46.173996,-106.229147,-163.962737,-313.845495,-372.300954,-389.439662,-309.255818,-277.443428,-283.009762,-293.826309,-258.944239,-236.941817,-276.080925,-319.83446,-295.497984,-265.566248,-297.126574,-317.139067,-263.210694,-146.795357,-123.350226,-59.71307,68.72571,98.112981,42.934785,-8.850011,-109.870254,-153.370433,-189.381879,-152.833045,-128.861032,-135.592618,-156.397857,-143.178089,-106.602783,1.322067,58.747799,111.802951,54.788104,-0.705156,-112.091363,-157.467053,-205.461355,-205.192549,-211.797252,-248.733712,-283.833779,-391.967516,-426.871244,-404.192507,-366.627807,-290.852708,-256.734192,-191.679855,-154.157234,-168.450263,-224.007047,-228.899159,-197.956964,-170.211745,-77.989829,-62.225788,-109.158856,-171.1905,-163.37907,-187.187748,-226.819208,-247.354897,-222.732828,-181.02551,-184.672694,-191.693314,-190.491071,-195.651876,-216.886429,-197.30525,-41.995901,153.080208,189.639614,133.006521,105.674656,90.915773,74.970498,106.334438,159.77737,230.420368,249.644446,240.814453,155.692044,88.028653,-5.77876,-4.297507,80.388257,168.153056,162.204909,36.884691,-37.076058,-115.6054,-122.840205,-98.356966,-74.124665,-28.750407,-4.194416,4.888197,38.899453,45.939028,-36.552235,-88.796112,-79.475656,-9.561469,-8.539914,-87.047798,-143.060744,-277.624557,-346.632891,-402.645971,-387.283123,-301.174269,-188.187402,-165.420043,-196.07749,-216.923958,-174.678237,-93.880159,40.366483,-39.235385,-95.637533,-65.688637,-6.784429,2.070271,-36.210257,0.085252,62.041433,104.253846,43.982024,24.442576,93.655123,163.737492,221.036361,203.306946,191.337565,231.36206,239.472612,199.407983,152.725134,13.665332,-48.003966,-43.096062,15.281836,122.072419,163.89567,158.777852,108.891385,76.184104,13.49014,-2.61102,-13.57732,-7.406468,9.5266,18.320871,9.142657,27.206661,42.084579,35.701775,28.928108,65.762732,145.014011,147.131712,63.648075,21.782539,21.814888,66.672108,169.699711,233.40073,261.001411,252.934449,203.701127,96.571211,84.085774,141.910708,159.669837,125.36883,52.212122,-5.243382,-119.017022,-147.02992,-187.529345,-223.030902,-259.994126,-177.651915,-139.824443,-150.185811,-167.511382,-141.299296,-93.62765,8.248698,35.152391,64.188107,135.03672,159.043945,95.896354,14.293563,-145.336064,-170.737238,-53.236695,148.097288,203.32021,161.378402,81.704106,-87.61332,-128.567197,-74.726872,-20.916384,33.14587,46.70491,40.312955,-18.301996,-50.253099,-79.736034,-75.657338,-46.570524,-46.258593,-52.301468,-49.43184,-39.639075,-11.191557,-3.589746,51.383208,124.394899,293.120368,356.476192,335.474373,286.369923,271.01979,184.092974,136.395674,169.886759,273.582078,268.688892,149.293202,91.10978,51.017483,59.376811,73.999454,49.68727,-24.741022,-29.193683,-35.152839,-73.272902,-73.625507,-40.585555,-24.444746,22.100376,122.872426,168.812538,105.839891,5.290404,-157.681063,-178.955474,-135.423335,-102.364514,-5.280692,100.690599,86.040691,-48.14825,-88.9668,-49.035552,-2.97823,44.821793,39.517355,42.363396,30.237447,-7.370301,-121.11148,-172.947178,-225.392353,-214.947958,-108.014929,30.804014,60.713722,1.307608,-73.134647,-204.115629,-216.268275,-153.151119,-95.541236,-86.82921,-117.778435,-138.002159,-116.549258,-81.415777,14.887883,67.686757,146.083396,172.660471,149.637053,82.779898,73.829931,65.939446,56.537731,76.073059,165.966204,202.737691,148.486252,80.150475,-1.347649,-15.337342,-20.035171,-1.744379,40.230886,34.015324,15.76954,-10.951648,-23.792302,-97.828434,-143.417729,-170.931776,-90.674416,-37.347662,10.777608,2.580139,-42.318399,-65.002266,-67.938505,-46.410873:47.289502,96.616733,107.94672,61.671234,30.795176,15.0795,19.323527,38.029442,88.569134,91.792109,-6.591183,-83.602464,-175.518521,-163.103171,-54.52653,10.416912,128.311885,177.83011,150.600684,67.312666,44.519298,30.152055,30.670466,66.935794,145.977,166.442157,124.153585,89.34231,20.473102,-15.389668,-29.769634,-4.580645,34.318095,26.418408,20.584177,-26.031755,-78.982608,-178.020571,-189.709547,-101.311918,69.117936,109.284138,30.198503,-40.181406,-118.555921,-125.533499,-107.251133,-82.470392,-14.502281,-9.144885,-47.911719,-139.062447,-179.283881,-246.952713,-257.781542,-228.274041,-164.665848,-125.294719,-77.515612,-99.768535,-253.946566,-334.280362,-316.021815,-226.028168,-110.942448,-186.154632,-223.85194,-199.225308,-177.643107,-196.454278,-208.186747,-157.460643,-25.368703,23.984514,28.55009,-9.824574,-143.503209,-203.513161,-237.203645,-221.087776,-176.192861,-182.607624,-196.819777,-236.602787,-273.594664,-321.708893,-297.588589,-199.537798,-186.333943,-217.060172,-308.891587,-355.771591,-367.266241,-314.650242,-161.116715,-88.046722,39.641033,49.624698,-4.417002,-99.498981,-119.079601,-156.787596,-190.719744,-256.104225,-207.914271,-150.777592,-113.437929,-160.893805,-240.753571,-192.654778,3.565674,69.574474,93.126531,23.629461,-12.726763,-85.927195,-148.752923,-263.778705,-271.988383,-236.67093,-188.78549,-173.988112,-246.216367,-324.479019,-432.281636,-407.698418,-254.572741,-202.050852,-161.219175,-105.668718,-89.363324,-126.520657,-178.924389,-210.812941,-142.678927,25.801473,7.561841,-64.921469,-180.442397,-184.271432,-181.44578,-209.597421,-239.559458,-221.187395,-170.464498,-147.119544,-146.383687,-188.780083,-236.74713,-279.484883,-240.006604,-89.337001,32.577783,46.244607,65.422531,111.096604,138.076063,95.834564,97.722629,172.466134,312.433624,259.162026,160.62901,-27.256112,-71.882757,-102.697088,-111.245512,-49.680308,118.782143,139.060856,-10.524927,-101.698818,-189.939392,-183.893583,-131.837831,-107.686052,-36.25312,-16.537827,-57.740914,-106.335568,-95.070807,-107.224792,-126.917095,-104.298775,-40.143458,-37.147241,-117.64764,-179.922562,-325.301907,-376.289977,-339.765857,-289.565681,-225.344477,-153.884041,-114.005562,-125.476276,-181.011715,-214.426864,-152.294655,-12.880378,13.108196,4.891466,10.823607,35.710721,63.246499,51.741921,85.786173,147.683748,251.674951,211.747866,162.768566,155.49128,189.281464,212.228867,201.247063,193.998507,226.746092,224.318516,101.842279,18.052621,-63.281275,-59.222227,3.120862,57.001622,165.491051,131.691403,54.482988,-48.530401,-43.650793,-27.447586,-37.921157,-30.673087,27.392368,52.540657,72.102231,62.642194,18.497659,1.387293,7.200291,28.751975,99.43893,191.990921,217.468767,151.789687,79.874167,18.350457,50.599593,143.84133,257.266618,295.441813,236.18335,169.37646,69.434273,42.321427,37.887251,60.000695,134.881015,156.329847,108.739439,-40.722976,-100.494756,-159.370182,-167.698172,-144.194838,-88.904999,-83.116202,-102.004128,-107.610144,-114.739217,-103.311181,-19.656612,29.396914,101.314099,144.324712,152.787019,118.778595,57.101235,-60.504054,-51.669736,105.111754,278.159457,300.474362,217.132738,162.335491,44.136915,-12.342223,15.358601,80.202889,108.819195,8.018724,-39.606746,-140.270632,-194.554932,-220.673737,-182.206008,-82.591585,-19.966671,-21.93515,-84.136819,-101.543316,-41.008554,19.332385,137.300945,185.379005,248.915929,239.213174,214.316156,170.629906,140.409175,55.838832,37.489096,103.195306,138.321625,95.253259,-11.792927,-28.876547,5.929305,21.776554,-8.250075,-40.281523,-49.242993,1.827198,-0.425268,-85.045605,-137.414017,-151.848846,-102.296877,35.932011,143.902457,142.456233,22.085699,-46.22978,-139.799446,-166.632936,-155.895755,-124.57129,-33.160412,89.794924,114.569206,29.743215,-30.087472,-44.076485,-17.696311,1.023004,28.465742,37.937282,-37.73952,-104.924483,-199.661948,-210.77478,-192.2396,-190.249685,-144.348251,-12.775782,-6.165059,-146.180438,-224.301159,-270.567144,-230.371609,-122.353003,-70.651168,-59.144611,-91.221241,-116.075479,-114.734797,-109.622047,-102.548029,-80.267548,-6.05289,54.454983,81.776782,126.421101,116.796344,59.46355,55.475879,113.105684,220.372579,269.846724,268.200214,215.286527,85.209919,37.695413,14.64605,45.926556,190.617753,249.034873,182.129382,4.058322,-40.755594,-38.321559,-18.115626,-2.622708,38.440208,74.241695,76.52949,48.500101,16.463748,14.677166,-6.315467,-27.535519:-97.916138,-88.37475,-124.336522,-180.788847,-174.986862,-169.081699,-177.222828,-169.416281,-132.358829,-119.33182,-160.959339,-201.223746,-209.605352,-169.584574,-90.101911,-73.054101,-21.536469,79.414656,89.135823,17.379638,-25.589565,-86.065274,-95.42229,-94.133026,-96.573928,-65.923634,53.548408,97.286098,77.076356,33.84163,-19.431031,-18.408009,31.181469,136.827573,174.700505,121.954823,39.291343,-110.803558,-127.613939,-58.046549,6.704004,13.639543,20.602535,36.277964,52.663697,29.271793,-22.19078,-5.402352,97.538238,168.150836,164.76589,117.101093,102.78863,89.641056,71.899806,21.603188,1.533276,3.119713,6.708302,14.140106,13.55634,-20.770602,-119.71392,-149.862917,-141.758604,-45.411871,9.095569,81.340345,91.078612,57.493201,53.279451,125.698521,163.448501,136.8473,22.866785,-48.597743,-172.419296,-210.824066,-246.837214,-271.859038,-331.082362,-262.935535,-203.7015,-166.00588,-181.858442,-207.393407,-195.537364,-156.410828,-146.32102,-132.180736,-162.597471,-228.034065,-305.739082,-268.862194,-114.508983,-56.273562,-5.006388,80.154216,125.283589,161.761632,161.17021,82.993106,-8.992422,-177.45166,-159.42845,-113.972673,-49.985905,-22.717225,17.232412,24.375355,78.959223,129.317531,196.672448,117.406362,34.037544,-46.379817,-41.519881,-92.703712,-145.926504,-199.631069,-180.000738,-186.000623,-246.890737,-263.164867,-259.309447,-252.124949,-192.948311,-148.12388,-103.679458,-120.235901,-145.057148,-211.158568,-233.145066,-211.281739,-169.849626,-103.354433,-137.801151,-173.617956,-208.348323,-210.341248,-238.563309,-274.194433,-314.929892,-291.193472,-230.646578,-269.788165,-300.013288,-265.587883,-218.225685,-177.344453,-171.682497,-97.340515,99.734766,197.510779,211.745725,160.248256,125.866462,148.360212,201.126928,209.699131,209.56118,233.83523,248.442627,253.089531,226.009031,147.326292,138.42391,166.440084,157.906468,126.747334,-26.600577,-107.615618,-134.697315,-107.305478,-114.453606,-145.042027,-118.056418,19.887713,49.591099,27.832021,14.732965,-20.339739,-33.481092,-17.584786,-27.365515,-66.534063,-172.953228,-205.485107,-229.49988,-237.839758,-223.179473,-200.809231,-138.476185,-93.287457,-121.094655,-202.798894,-190.167392,-15.438828,86.029095,106.226661,-36.066518,-76.549577,-79.641328,-62.043365,-12.04072,6.227425,-5.687528,-36.040698,-88.423542,-47.727513,-6.303953,118.281093,186.419532,229.616416,222.918093,231.979129,218.858832,201.667042,164.175447,129.181392,25.597365,-19.169,-37.098469,-5.915345,108.248017,201.258595,205.817115,149.34108,105.260454,16.295008,-17.40158,-61.567072,-59.025327,-25.371723,40.094365,40.97923,10.135456,10.220652,46.692333,44.333961,15.121976,101.93698,143.737794,114.356101,80.252767,93.061348,140.495258,184.476312,146.861462,162.768768,198.322041,173.255476,134.996424,167.430258,251.70907,241.864054,127.710729,-19.741782,-110.118459,-240.030958,-249.285994,-243.051729,-261.550702,-319.093723,-323.531232,-309.942211,-286.161771,-270.383241,-207.621484,-161.815331,-82.163552,-65.258104,-64.51665,-22.762644,5.799361,9.544143,-9.271201,-36.481462,-33.021652,34.454846,161.952233,213.362815,175.962561,72.79176,-135.902194,-168.979308,-88.53961,-24.686138,43.322682,72.00885,81.497438,33.532892,-8.825137,-60.724495,-66.133069,-51.595302,-32.011317,-17.236237,6.589371,7.604163,-34.204718,-67.442931,-53.756755,10.739751,150.37988,190.985357,196.161242,198.496539,172.438635,110.775338,113.202754,184.92388,261.299475,263.72371,155.797048,67.408394,-43.582393,-35.182812,21.253122,11.160693,-63.34069,-76.6769,-64.937652,-41.416573,-36.499481,-39.627967,-16.149491,130.694782,273.111759,283.31479,143.414061,33.92414,-90.151753,-81.904044,-29.928114,-17.590409,43.442698,129.370946,120.284529,32.376644,11.961364,77.371121,138.022246,189.00916,90.787386,23.031498,-47.962785,-49.403999,-77.708394,-111.199067,-130.835236,-104.612085,-3.982989,79.507627,72.657347,2.922043,-25.149468,-41.818282,-27.766899,9.25862,-22.776223,-57.164875,-76.573521,-46.882996,17.261587,9.914959,5.857135,57.789266,188.27206,197.108161,148.29131,73.741996,62.799728,25.209123,19.355921,37.960049,23.167004,29.044488,16.915293,-36.304776,-156.62078,-178.356459,-157.450338,-142.577919,-107.999233,-59.696891,-62.158432,-140.787197,-184.86865,-184.361166,-133.663925,-60.264378,-50.410652,-24.185402,7.783197,-3.478544,-40.408987,-71.324805,-125.022339,-112.734604:34.210978,59.565658,57.195022,8.437749,-36.171631,-107.0044,-103.839959,-15.16369,104.753993,120.799979,31.910827,-10.744883,-14.214152,-9.462921,-4.384409,19.141557,128.781868,222.457174,202.297181,92.017157,64.161193,39.114624,14.597252,20.946845,132.553911,162.853022,165.304126,180.518829,177.32005,129.814127,54.339337,72.044511,188.6464,217.625045,170.862507,59.521747,10.698338,-92.671401,-119.659432,-62.502116,46.524736,76.107943,51.505014,16.895983,-10.310491,4.428301,25.023889,24.781187,102.570499,229.086602,204.496251,-6.238905,-87.903477,-116.598805,-113.442124,-131.461101,-94.5005,-50.32827,-26.070259,-60.775736,-162.969874,-201.575023,-173.314758,-112.891224,-20.266036,-28.093096,-54.001617,-99.859166,-106.603807,-64.681039,-11.395546,73.381771,61.428018,45.858611,-11.023988,-66.195669,-164.938474,-177.764157,-206.001664,-257.656547,-316.011075,-172.933906,-104.44367,-132.112613,-177.983148,-192.069906,-183.274459,-200.588369,-166.492282,-121.3468,-103.331616,-152.12003,-275.407382,-293.730601,-181.028265,-85.398497,82.446114,147.940605,114.090662,-21.339421,-85.540713,-169.975775,-185.737872,-203.818178,-164.87818,-107.504392,-28.808651,-41.323016,-94.556411,-85.420551,8.110972,58.733114,100.86405,18.716657,-68.370989,-238.418331,-292.458242,-318.483745,-287.688863,-215.331237,-198.148826,-225.786854,-381.63283,-459.79787,-490.531123,-448.611693,-329.264588,-274.114383,-188.351898,-208.66282,-256.112974,-287.7844,-266.153395,-209.488363,-185.284939,-163.402625,-148.322703,-150.815368,-222.865591,-280.4767,-371.38645,-391.756939,-384.258777,-356.964267,-258.801678,-205.020074,-229.728342,-301.45498,-318.7656,-306.656683,-267.928703,-123.849612,31.361513,72.692834,72.880795,64.742893,72.609446,82.592089,125.50687,166.311523,264.728181,269.505216,215.479317,84.818908,32.912426,-38.411061,-37.329568,80.406068,194.943315,179.063256,29.76693,-46.209615,-140.120412,-170.556925,-192.913285,-162.869242,-20.13854,35.593422,4.245153,-10.440929,13.919833,-15.607764,-60.873103,-63.073741,40.151756,64.803712,-34.239353,-129.407355,-276.617688,-297.79422,-238.05931,-191.183056,-81.533199,43.015011,42.022361,-83.140083,-130.670159,-99.348246,-45.133198,44.361732,75.032562,78.561604,67.132884,57.473719,30.717852,16.471102,42.680935,79.718286,146.183073,175.22032,163.332289,154.537747,169.318738,188.188593,199.710707,230.071714,192.673084,140.05014,15.008038,-34.512358,-117.585347,-149.703551,-104.607249,-23.263007,134.629371,191.097678,168.652179,43.315662,-21.321883,-67.812495,-44.416055,18.803137,22.110393,13.563359,26.451795,42.986824,54.925628,61.473163,94.000118,98.305197,95.248581,154.443339,175.888607,117.432816,63.109831,-1.2218,6.650912,110.498833,242.317795,261.364141,201.290382,168.49984,132.937554,120.191307,113.975976,109.679844,74.824891,26.189138,-12.43364,-102.520893,-135.719541,-188.197852,-210.043342,-244.895771,-266.518757,-274.182546,-289.635094,-284.701256,-229.184399,-183.813605,-68.464106,-7.939472,85.534869,145.072642,143.512414,49.407148,-19.170573,-91.836628,-69.433594,64.600267,225.70238,253.939277,146.755466,54.500413,-70.62609,-76.232501,-0.810429,38.405883,59.604532,37.446252,15.359266,-68.102087,-121.062508,-169.331246,-149.740862,-95.04978,-56.908512,-35.564111,-48.032663,-71.52795,-32.133466,27.242163,110.299457,115.718099,100.47923,143.752821,186.973013,193.766907,136.714782,28.752762,32.19323,133.568671,165.205498,129.215646,26.573635,-11.362559,-36.743072,-38.896255,-68.586314,-102.327231,-170.559248,-166.042492,-141.904989,-97.159647,-99.025034,-156.42157,-151.340115,29.634381,188.109978,163.049132,-29.32394,-104.15389,-103.363655,-72.147367,-46.23117,-43.438669,8.094534,87.339676,106.134587,80.471368,28.976386,-96.023301,-128.453922,-97.204812,0.73857,13.573011,-81.841147,-143.830554,-233.99523,-259.219116,-216.722151,-151.30026,10.369026,101.810096,67.641897,-77.677591,-115.095722,-82.408744,-51.58477,-39.111358,-51.064167,-45.01009,-36.657569,-39.232948,-43.730366,-38.106097,4.05596,19.121988,53.488351,163.511442,191.692852,137.93471,84.363134,13.14543,30.379519,141.241296,193.68169,168.947033,62.516519,17.878175,-29.342222,-49.471336,-78.142205,-58.855375,56.01858,73.558144,0.271784,-127.271289,-125.881319,-73.234611,-62.730655,-80.880505,-70.727178,-39.261206,36.105571,47.89452,-36.644598,-103.303999,-130.506127,-76.73321:-57.533368,-8.49118,-41.296054,-113.370688,-94.283416,-54.86192,-80.396367,-101.841332,-48.490557,-41.855996,-59.343128,-48.068871,-9.072587,-25.725389,-80.578085,-57.024509,100.93561,225.729687,211.327522,63.999969,-6.619332,-105.14887,-158.910567,-240.203498,-192.299572,-130.73434,-2.52391,28.85769,-8.706994,-39.622557,-34.965405,0.918144,134.936544,272.026574,274.879346,166.151501,103.133685,8.412864,-15.166234,-5.832176,22.026829,31.944625,90.238479,144.41283,199.587901,172.325727,114.816965,135.313695,251.815896,365.787812,400.149219,407.19671,376.632247,268.052453,211.642459,113.650535,41.154048,46.499185,133.532459,173.62272,168.173418,126.688602,39.110147,7.079661,-10.043437,52.189098,83.384047,141.903307,174.41771,185.842685,183.700073,260.148353,309.166182,271.54887,157.733623,131.06021,120.59529,92.090975,-45.672125,-130.08992,-214.640136,-89.099957,-0.780591,49.558837,16.691273,-21.941923,1.471536,111.956537,247.200009,270.707499,142.38978,48.333725,-10.948982,9.365896,32.652273,42.616617,134.469272,252.659506,248.428479,166.138891,162.571506,188.662035,145.425769,-58.365494,-195.5291,-184.046646,-54.940182,4.341436,19.800143,15.441823,107.048705,168.976758,179.003036,97.776244,66.037039,23.128942,3.917021,-42.788291,-56.94544,-6.258333,65.973093,54.71952,-1.157426,11.706624,89.284177,98.76203,134.309105,201.673431,298.567202,213.917266,114.20233,-74.122273,-109.549158,-93.692852,-75.093921,-50.55992,-119.458569,-184.943731,-248.10705,-227.121416,-173.158459,-187.543236,-289.8107,-335.596037,-377.913216,-351.766443,-302.538605,-189.555136,-152.698681,-87.663065,-46.302876,-1.216315,16.642129,47.920062,93.025645,83.225148,34.929493,8.093852,-19.505888,-1.961485,69.402813,126.556403,157.31016,241.180033,247.150181,123.547879,71.637606,94.259692,38.054175,-70.132209,-294.311363,-318.011014,-177.262248,-107.243986,-63.593207,-63.305002,-83.669259,-66.024279,-27.069173,90.721298,158.3247,219.766775,211.640805,165.496711,37.174713,-42.87926,-133.649856,-114.627787,-12.225019,-11.26061,-109.725939,-132.906837,-97.371008,-53.34088,-37.713007,-3.864662,23.580829,96.938872,120.36123,60.040441,-118.851038,-170.792006,-117.876558,-50.095771,23.21454,-17.83356,-176.970879,-210.196186,-147.076914,-54.84914,-17.87413,65.565502,105.679717,131.62782,116.831512,82.65518,95.579957,90.153172,-10.307462,-65.603846,-122.453394,-142.149587,-132.638355,-85.871139,46.431995,148.115752,160.784953,129.827811,105.868486,58.496095,50.543454,72.041691,51.465429,15.346314,-51.177253,-53.159998,-29.80885,-42.904773,-39.368604,8.597324,56.564388,-23.022868,-57.896461,-48.524192,-25.613213,-2.924055,26.661165,107.104417,70.942226,39.320498,-3.672212,-20.048295,26.615039,85.099226,125.847003,69.475106,-110.53441,-173.852409,-169.117056,-220.152102,-283.991912,-393.758763,-410.1665,-408.679455,-418.877789,-409.616121,-347.599877,-293.3531,-129.820381,-56.911682,-5.203925,-9.958402,-44.171819,-77.300735,-74.929494,-32.002037,-15.336289,-33.26145,-48.898233,-38.6778,45.216791,85.714381,83.078724,47.649123,-27.881009,-44.718639,-5.486578,13.055304,-37.445475,-30.596462,30.923373,111.055524,88.332358,23.103457,41.130768,99.727151,7.40964,-42.214881,-26.312531,8.282585,22.697759,10.999068,33.585844,61.723607,89.462753,109.167322,133.545259,141.613838,108.470442,32.512583,9.600543,17.453232,83.463883,97.368549,29.011427,-21.433596,-66.330917,-68.961996,-77.735226,-107.927163,-242.823395,-309.028629,-269.938456,-144.833055,-113.068912,-87.875029,-54.49984,40.662421,118.017336,146.13859,127.60842,78.961831,2.045894,-7.128078,-20.961181,-30.236104,10.281693,64.695968,41.639711,-4.538203,21.208418,97.454494,109.818392,101.416353,103.916217,83.953265,-65.459949,-141.887152,-147.29221,-104.562437,-52.868767,-62.682775,-79.098847,22.119708,65.900666,58.169985,34.127921,13.201355,21.609336,38.222221,-4.38365,-36.028793,-60.734358,-49.695728,-30.718644,-33.368806,14.644483,78.405296,173.689058,138.247352,112.454926,130.251671,125.690678,-22.259127,-109.434644,-158.560474,-116.485114,-115.830379,-198.642154,-250.037781,-315.710676,-348.79119,-376.470107,-344.168947,-233.75925,-190.497729,-211.693911,-238.187156,-215.845908,-159.657438,-131.520352,-64.904023,-103.13061,-151.645667,-195.763721,-176.786577,-93.433714,-67.996606,-84.067241,-98.251759:-116.280304,-73.034604,-96.528961,-159.761238,-155.932713,-133.611669,-134.835145,-165.480984,-214.802049,-220.268351,-183.373676,-156.861231,-152.632456,-174.527779,-157.093372,-102.826154,14.25953,70.765018,71.907212,56.443914,39.437712,-74.773054,-140.623985,-159.9353,-118.796868,-107.880442,-76.349601,-57.805062,-56.244132,-67.4271,-63.722687,-48.540851,4.052859,143.971249,210.097737,189.58027,127.102419,30.508067,-6.953216,-103.307307,-78.602568,-4.516625,111.215521,143.187441,198.238679,187.628723,94.986496,84.157539,227.214708,422.38571,447.054137,342.007439,279.881192,222.790262,207.208297,147.849969,81.50128,68.656632,71.503129,81.870345,75.389568,28.535888,-82.178981,-93.63901,-45.570845,-10.454085,-1.640517,77.862044,150.728702,302.139382,367.239949,371.668487,178.05233,89.753025,40.267131,54.061268,25.855358,-35.25054,-151.891,-183.641654,-218.448377,-190.668954,-147.102335,-53.28059,-30.166209,-34.042479,-38.95821,-44.452633,-0.61036,27.383413,-48.829871,-138.998475,-216.817843,-171.275494,-49.797216,-25.92881,31.150398,175.64053,205.998971,160.768794,141.716507,129.345393,99.982876,-21.877379,-128.358705,-141.793802,-52.419508,41.393689,198.786452,236.427049,316.625728,357.133809,343.462155,241.994319,182.893501,54.468824,-5.789697,-75.639848,-74.369148,-20.912648,34.092925,38.542607,-8.803972,-53.595877,-135.095707,-143.65049,-27.585656,73.86732,175.208972,61.398251,-30.538152,-115.856968,-96.623248,-63.366507,-68.911834,-86.24776,-126.281186,-166.59385,-246.914108,-254.265171,-219.832576,-212.679656,-218.284917,-229.561873,-295.139829,-306.439655,-239.773768,-44.672511,5.524005,-24.319907,-52.188311,-30.601218,70.216442,102.215797,107.80387,107.765008,92.587406,60.444667,13.587189,25.402243,88.678549,147.670429,168.753787,200.137497,200.629459,138.705097,95.972806,28.086071,-65.328387,-100.765565,-102.467983,-89.831144,-62.738213,-47.339347,-20.984604,1.031099,80.876672,129.744344,116.486294,95.205742,103.424759,67.689785,40.092381,82.854744,91.738963,18.205579,-131.794464,-142.636165,-91.442909,-82.528093,-141.19629,-190.113134,-197.805905,-46.1496,-12.369676,-108.80917,-140.143412,-13.249571,98.878012,214.776574,76.771797,-28.680453,-133.707213,-93.229442,53.362408,50.200765,-92.829904,-128.964828,-47.797071,98.487169,141.973336,198.391026,235.221647,284.180459,274.930997,225.630606,240.852529,252.647799,175.17142,104.05481,-14.531811,-49.381742,-29.361962,13.260674,89.455878,123.267367,119.73344,116.756544,121.638649,90.867714,62.256778,38.061629,9.198812,-29.946905,-114.573605,-127.663329,-124.678189,-141.337349,-140.335412,-91.343635,-25.818211,-100.349179,-124.441291,-66.527789,-16.69332,46.77525,64.307041,86.026454,118.960577,148.326179,146.736413,106.483342,53.630133,71.688421,155.718018,176.303112,108.4205,-54.591152,-129.830717,-197.109899,-208.876946,-275.125329,-310.568664,-325.339218,-257.415326,-212.716281,-167.251037,-153.440242,-84.680663,-35.581272,85.906457,135.11633,105.272715,-31.318531,-74.690561,-16.622647,30.172605,-31.600636,-90.159289,-40.009858,125.218188,138.613875,16.751297,-48.909074,-156.72668,-212.753412,-215.957185,-153.288792,-54.065844,37.675003,117.481475,213.958404,190.678909,88.340487,60.978343,45.919401,11.365738,-3.519751,2.904236,21.288879,6.961118,-36.730159,-41.39494,28.507477,176.32315,214.025062,206.677957,187.202623,168.339664,101.431209,85.106756,126.16254,210.558015,241.575459,202.835576,149.428223,59.036963,17.998662,-53.821965,-85.550119,-149.670909,-118.169739,-65.389153,38.557509,85.379875,138.685658,127.987705,105.814176,221.312904,294.559055,278.507705,201.07385,59.431292,16.925893,-4.135139,13.165975,95.015008,173.130181,153.211048,18.418765,-36.015,-8.812924,57.271612,130.313139,70.168318,41.104652,17.308071,32.491328,65.220405,24.23593,-110.26533,-139.488648,-100.422631,31.460827,80.843981,62.685284,13.513139,-63.466137,-57.033142,11.789095,-1.632075,-27.094716,-2.859767,30.058669,3.781939,-57.627307,-107.187444,-56.245414,70.179332,57.533469,17.096309,-4.172648,16.666796,-1.736403,-39.995113,-68.661566,-94.826682,-143.681244,-240.133207,-244.416432,-211.136822,-228.136612,-300.92419,-303.049708,-232.757874,-201.612584,-226.707697,-276.021451,-262.034721,-172.312146,-123.198231,-61.278156,-23.582659,-7.373173,-67.766627,-128.342053,-132.577779,-85.146094,-45.621563,-39.475054:16.268821,112.778947,110.939836,-15.072874,-66.325634,-40.543537,4.248968,33.075143,-37.421996,-56.18824,-35.170203,-15.073003,18.332349,11.166017,-17.566347,3.274395,133.635316,188.107791,131.555429,24.861109,28.23475,48.059544,23.546173,-90.45781,-135.968994,-91.567404,32.9836,71.77877,37.007645,-21.198048,-32.772855,33.66842,137.531617,82.702135,44.09011,45.432815,65.163234,76.367068,66.517784,16.585494,12.392276,56.243184,133.797235,143.763744,116.019662,67.333814,-42.497556,-53.470296,46.683134,225.515907,271.094967,162.675129,62.297299,-16.79746,11.772733,76.235893,79.450277,61.867778,-0.561343,-34.311461,-92.537687,-106.917778,-79.415484,-60.849195,-58.108105,-2.677643,62.234455,151.41225,119.661673,-49.9151,-82.682956,60.534206,170.924951,142.802979,20.266498,-21.281551,7.629582,53.741427,43.648342,-45.690877,-216.331606,-152.605919,-92.141198,-62.356199,-83.059501,-126.987991,-110.063286,-12.523041,32.638003,48.950057,25.234398,-43.044265,-143.984796,-97.906657,117.555667,174.845913,98.046124,14.719122,11.9521,40.286774,55.629133,7.772665,-56.434704,-140.585965,-89.7697,-39.651801,14.590931,13.761864,-2.908836,-2.097531,67.219094,116.506852,110.36439,-28.870978,-93.091881,-111.803957,-73.952973,-70.373945,-122.052406,-184.495742,-152.62793,-146.967099,-226.874788,-282.580667,-245.07273,-161.420262,-58.405849,-47.276931,-18.987399,-31.765596,-73.547594,-132.087095,-122.49352,-101.358723,-106.711657,-123.706563,-126.148915,-108.296641,-137.692555,-203.655605,-322.544817,-345.473658,-305.890974,-277.222274,-303.558859,-328.659393,-307.433444,-260.279295,-252.015543,-237.942708,-217.277371,-138.320004,20.870205,105.73458,168.734349,151.176392,75.400756,21.694919,-27.25603,23.283836,202.023033,280.889611,272.141054,206.645175,154.278566,66.866676,62.675502,123.271135,192.204065,154.881877,-116.18133,-238.103913,-248.224021,-195.538051,-138.406352,-127.109117,-67.378478,-29.954269,-64.836416,-75.131471,-2.349494,99.817576,77.917553,1.696866,-36.912017,-64.015427,-124.546818,-132.914689,-145.904209,-162.699691,-136.181293,-93.731949,-70.582235,-80.224743,-57.266957,-30.725007,-36.31065,-27.78447,-8.954182,-15.855325,-114.51244,-150.624867,-135.401541,-96.548012,-52.694363,-71.186441,-116.756074,-113.450294,-63.468788,-57.53851,-102.1713,-69.34117,68.365468,293.89533,266.064633,48.379612,-54.297315,-46.321793,-59.680444,-97.331916,-146.344867,-135.703361,-45.200691,11.145745,95.232711,201.524356,224.738662,128.827949,74.696978,54.065292,49.749172,8.633362,14.774249,39.485261,68.063954,78.22229,95.329787,76.433286,39.339539,57.554049,113.754243,120.770114,105.727153,24.889352,-40.35015,-128.879308,-111.641214,-1.425726,53.580215,53.515738,61.436593,90.778578,193.786996,235.147625,213.24293,159.15018,86.904961,50.752844,-25.816943,-213.626128,-249.749766,-268.015995,-284.745211,-294.571156,-266.920971,-264.58391,-322.343555,-341.536959,-230.026351,-121.664617,40.49824,69.781066,51.878906,41.781687,56.69263,36.119346,-4.885534,-63.231247,-52.128282,60.79399,145.88448,132.333495,64.340624,48.775085,58.739302,67.856335,74.29982,57.954242,-6.761339,-1.978186,5.861952,-39.643833,-58.961446,-89.749871,-130.912911,-164.56123,-6.163699,89.082129,89.558927,1.74123,-77.605801,-31.192786,60.493449,71.346943,79.031397,98.218115,104.669169,74.627361,31.848877,-19.336541,12.591348,131.261511,149.749623,118.81703,18.399359,-37.917571,-96.365147,-103.587084,-104.510417,-88.623202,-77.376383,-127.321521,-154.481628,-152.915215,-114.768851,-38.292088,-10.979783,53.376077,125.719894,151.094917,108.448448,45.561397,-48.029236,-68.011517,-89.296095,-80.318363,14.394558,120.834031,122.616581,79.530092,55.218446,-25.186024,-50.111943,-21.1217,15.090509,-1.774785,-130.011441,-196.248367,-210.065839,-182.079398,-150.510921,-118.686529,51.929684,190.442365,156.979553,-5.754833,-36.785051,-37.89701,-67.229107,-89.839924,-2.476758,-2.076843,-93.952499,-109.338241,-31.914629,13.015858,66.256858,86.174056,120.70167,130.845976,132.972202,177.561511,168.966845,-7.159147,-75.185352,17.064345,127.411052,93.641744,-70.51129,-122.173514,-121.271509,-138.424045,-246.4366,-267.70821,-182.480701,-71.04225,-51.192216,-59.170502,-66.115196,-89.697088,-88.348022,-66.054454,-103.198712,-121.8209,-106.136906,-75.777625,-20.89135,-29.42723,-119.177058,-141.616676:forward
73.837833,-92.427623,-180.001477,-234.979001,-181.124134,-63.035551,-50.010272,-63.68927,-15.995847,25.388352,41.851635,27.106337,63.976709,107.756647,180.299169,209.329127,271.85018,315.909679,298.140038,201.086069,161.647812,112.105738,97.745819,116.546711,184.47335,216.735801,261.550969,293.765095,384.342325,417.125326,460.49143,470.351404,396.623382,264.282862,239.427867,265.798165,268.640894,224.589237,213.848977,220.023636,152.605536,83.90629,-81.718162,-151.404712,-186.113593,-156.906772,-90.061112,-84.810597,-149.437548,-193.626615,-191.638474,-158.531712,-107.914804,57.13439,139.023969,220.348674,234.453059,240.729443,199.531507,163.035049,144.172385,162.813765,176.407121,150.043101,68.164936,10.448953,-14.630678,-7.562325,46.253828,153.921369,179.966712,192.268174,150.906645,115.783567,34.453656,21.567909,102.342372,140.52189,109.286991,74.437324,42.66795,21.131576,3.442635,6.051916,31.418824,73.259692,94.894537,141.717779,125.508638,109.511601,76.729813,60.705688,48.796402,52.144366,86.626001,106.446974,115.963444,136.344177,143.594183,151.229335,205.631682,424.324195,499.705694,471.22351,358.082378,303.526468,195.462467,158.188303,138.676414,163.861658,305.083223,373.000073,361.138728,209.772074,121.660344,19.341215,51.399183,224.339019,299.83961,332.17964,170.742306,52.264916,-103.298382,-111.352695,-65.915794,-53.254459,-40.530794,-15.258465,44.56559,82.580511,94.54881,100.991705,123.202214,265.593491,373.619806,537.222813,524.715467,480.453846,403.536172,397.411817,450.496922,472.122084,459.537077,434.861346,338.429938,227.874545,182.329523,68.075727,5.131257,-48.222831,-24.026683,66.562495,96.676592,70.212937,3.411705,20.730493,208.419139,321.229575,447.030285,453.736275,386.98995,298.881282,267.615248,217.464046,209.213253,218.353247,210.40052,137.8471,-9.957103,-92.918276,-176.44952,-158.332591,-75.521017,-35.318834,78.039424,140.604977,154.424239,39.857403,-23.11046,-137.186501,-152.681468,-48.583842,23.089602,47.432243,-58.499705,-86.428478,-46.934402,-7.66432,57.088966,94.504161,218.060416,272.447895,275.689119,214.979633,187.330108,114.476167,71.836821,57.461,110.765337,255.95383,287.8862,249.574217,61.422863,-39.940784,-78.998851,-33.739823,61.276213,87.980534,93.555828,80.51064,50.987101,-37.173131,-55.152126,-49.011642,-37.267104,40.55048,106.624889,92.654569,-13.122988,-64.928504,-66.719923,-18.248016,119.756487,180.585447,211.096325,102.980392,27.960837,-36.63758,-22.090532,-26.418852,-51.21944,-41.563338,15.101167,5.489652,-67.473707,-78.003223,-38.391939,-21.415739,8.972785,9.772439,-66.98624,-80.416403,-42.947035,-48.729134,-94.843771,-129.162496,-98.909253,-36.638807,-116.136799,-183.464737,-254.264394,-269.579807,-293.206638,-295.362469,-300.392789,-317.62402,-340.456183,-272.382423,-239.129102,-228.00769,-226.304298,-160.757681,-85.401599,70.893223,94.756331,60.791359,-81.665173,-165.253135,-225.975751,-210.705228,-147.041135,-89.262941,-5.102434,-63.539205,-101.026051,-98.228261,-70.02872,-39.039193,-39.721571,-61.962355,-111.83439,-140.012644,-216.06494,-254.953446,-288.644792,-274.897182,-162.522796,-91.219445,-82.01803,-234.923176,-300.54814,-336.029144,-321.777784,-288.471651,-270.496979,-247.545417,-267.662873,-261.78861,-235.62924,-260.098071,-366.81683,-397.997918,-332.811195,-253.026053,-157.268757,-236.11957,-303.69836,-365.38427,-327.385355,-175.02159,-113.548195,-64.625052,-63.451062,-76.289986,-147.800098,-193.021052,-180.311232,-104.771333,-1.479101,-29.41253,-130.948169,-162.088742,-178.495923,-220.469313,-212.690953,-106.848429,-21.904678,146.23072,176.112281,120.861906,-45.537881,-114.807339,-163.721766,-151.458128,-79.892415,-31.506063,30.825477,17.190244,-3.41907,-33.595685,-39.145612,-31.780131,-12.935545,31.607735,-44.466121,-118.550647,-212.357711,-224.785832,-241.240108,-254.018052,-257.145865,-252.324529,-277.636905,-312.128474,-306.463142,-209.808414,-123.60832,-2.673847,-10.037915,-75.273633,-37.742757,8.471437,39.197616,-1.599388,-163.545207,-227.89168,-139.109259,-1.75462,138.063014,-9.454312,-74.741191,-104.667424,-99.208001,-67.789084,-40.858559,5.323044,-19.459171,-53.853634,-105.144151,-100.733339,-52.365534,-42.041096,-62.646992,-86.440275,-174.415104,-224.725549,-223.064803,-242.890599,-256.887518,-214.114099,-147.037856,11.910403,-17.048304,-99.835409,-187.607451,-173.802364,-128.904553,-123.834355,-134.255133,-139.261492:-30.116095,-180.098465,-216.114676,-187.802859,-134.749687,-21.695658,-1.435174,-73.545116,-142.19616,-140.30957,-110.257182,-79.251491,48.497882,132.908427,254.876431,262.876898,225.779777,197.979226,177.048691,174.72825,203.749701,236.472556,220.35129,179.965146,164.943107,136.991552,92.626548,129.652833,230.623486,240.448309,243.44204,257.330548,247.50131,183.632254,158.081043,148.773546,163.035593,217.324872,251.428021,277.85954,165.620272,64.385307,-139.554073,-210.265541,-250.874428,-222.760198,-150.410044,-138.392107,-136.570962,-145.004212,-175.362966,-208.437946,-156.038656,61.972497,166.375662,216.629771,179.447282,193.789716,166.16845,130.424322,227.346147,345.68569,442.38406,379.50297,185.472209,76.848478,54.440331,97.271688,162.257943,256.049027,265.950674,254.388016,212.247385,182.374718,135.401398,136.466543,178.344394,188.135087,170.900309,152.976365,87.365454,66.3661,89.047509,117.233229,105.224922,107.471178,152.131998,230.407993,161.019742,103.724354,37.065959,29.910467,32.444918,35.84159,64.461257,79.023965,86.586982,109.929232,125.196765,166.921793,224.477622,424.032769,515.600023,548.0083,413.435719,327.864869,193.215161,178.586048,223.901832,255.969897,356.428609,406.571664,426.86613,288.138751,189.589942,128.612035,192.252733,375.093164,425.105608,364.357666,175.407769,80.330458,-76.204311,-116.029211,-66.654837,5.629263,116.804169,112.312209,10.422237,-23.227533,20.30307,136.028636,166.670983,204.970521,253.349925,377.548108,364.905058,308.160601,182.61877,148.026759,194.232149,255.134275,355.518719,368.485201,318.181185,233.359962,212.900507,242.770419,269.256185,308.418603,328.684379,330.45257,239.903739,200.72046,191.521455,219.484519,333.757348,395.199586,454.198164,454.666209,447.362329,404.816448,352.005449,243.215501,235.24412,314.890663,354.640057,320.628848,167.729458,117.027137,129.891626,163.706455,202.372774,214.004318,291.961622,342.261438,348.218412,196.652307,113.933356,48.320862,65.918051,129.378597,148.650173,109.773299,-26.339443,-105.465144,-157.710256,-91.414685,110.975126,184.933061,278.911328,300.016781,276.854586,217.191601,181.827209,127.750986,115.756534,99.433441,102.499426,164.20401,205.615893,159.031844,-47.752755,-108.797362,-14.749772,71.911996,174.974185,187.537937,139.106044,50.292497,13.168492,-49.068103,-85.654992,-148.514957,-141.024585,-55.545392,-34.722909,-72.577917,-126.170707,-98.4083,6.987625,49.887309,138.462127,191.476462,234.669132,110.999769,23.424308,-47.808987,-24.495082,18.424343,12.942091,7.904675,52.438051,62.852997,51.720627,63.879269,107.514146,110.435326,139.245177,168.121239,116.936113,-20.596475,-25.622822,41.40664,24.632614,-88.288937,-88.035862,17.630505,-45.478001,-138.586044,-293.531128,-309.709177,-204.911704,-155.668014,-182.230075,-214.250661,-232.068707,-214.301152,-185.167701,-108.74361,-95.63486,-115.592725,-102.891355,-4.254594,11.319545,-57.188148,-241.209912,-279.628523,-239.725419,-237.473389,-292.094352,-285.047418,-191.850361,-183.64984,-218.685182,-216.065554,-157.197744,-65.374234,-72.340709,-102.363455,-97.351892,-113.02263,-169.998853,-196.17994,-248.516424,-250.537886,-156.658095,-114.120901,-163.570278,-309.560011,-360.128491,-361.279284,-315.531075,-205.925423,-178.408036,-169.147973,-141.776897,-124.998785,-147.296008,-179.255378,-204.073897,-180.272078,-120.258729,-117.745279,-121.182645,-83.611019,-94.862561,-142.292906,-117.559097,1.347054,40.638271,33.42451,-46.097104,-76.87495,-124.755793,-165.075331,-199.501602,-154.505516,-25.000258,-9.483405,-100.234338,-231.912379,-284.064192,-273.265426,-208.015943,-82.653999,-45.33482,15.154358,33.134114,14.2606,-66.289044,-112.055084,-149.404648,-134.67659,-78.251933,-50.222623,-20.787446,-30.35772,-47.52099,-80.952162,-73.561154,-3.987727,45.932992,95.880212,-12.900824,-102.831131,-249.123222,-273.368087,-239.348541,-211.254735,-153.515951,-133.012125,-167.273912,-263.90651,-279.347432,-180.352946,-89.232423,48.945782,63.422664,28.386371,2.221157,-9.415102,-48.460076,-62.193311,-55.853686,-39.945026,27.883574,79.975384,127.713575,32.693341,-25.396689,-114.862997,-150.865144,-161.844082,-120.014173,-59.158601,-144.855158,-211.981545,-305.940972,-292.551166,-169.102015,-132.540608,-169.515402,-208.030108,-303.622208,-373.803408,-380.36786,-355.300658,-323.705931,-260.069103,-240.349251,-220.127138,-233.275841,-245.326125,-286.968376,-299.511039,-261.669632,-237.306111,-218.077225,-227.269363:-150.330738,-221.935091,-231.969108,-246.756501,-234.25035,-128.488355,-69.329744,-51.183495,-134.722593,-183.028739,-237.414931,-212.274529,-53.91538,36.56405,156.113355,189.349077,213.694857,159.966663,132.640277,137.420552,152.186392,147.844099,130.939971,67.507428,-14.507271,-39.418806,-54.955526,-41.99777,21.763076,57.003894,124.713373,157.997307,152.637007,28.04431,-26.347368,-20.168198,33.129967,148.540859,169.420163,114.022971,36.432314,-29.165201,-214.414437,-265.899281,-226.913761,-174.331736,-86.297361,-73.836599,-126.746474,-229.433523,-266.162857,-192.610285,-76.610459,129.603495,160.809922,151.918272,187.60667,193.238724,119.700767,101.168166,217.464814,308.30441,400.431975,372.75503,190.838071,24.451348,8.00787,86.308796,134.480813,189.650971,214.267833,235.879851,175.817989,154.39922,195.997772,235.66852,242.617496,220.752613,224.057576,228.985597,136.718546,-19.446312,-62.238386,-25.093902,27.302238,84.914317,91.11101,121.221699,143.383416,120.363916,48.838205,19.247213,-28.512035,-29.310437,38.983887,60.963392,-20.674968,-71.342365,-22.451637,141.661962,229.941627,398.336746,458.943885,491.117714,461.356058,429.479732,278.406325,219.579673,263.496469,313.896985,384.978376,424.011148,476.352058,323.555285,177.670562,37.372379,102.872359,297.002199,321.208256,183.914429,-16.295332,-80.419859,-147.778855,-166.309076,-157.353652,-104.497461,53.053543,78.291445,-16.99948,-86.484809,-52.949007,109.630521,173.96252,248.925254,308.892456,423.253137,346.898344,259.724616,116.935994,75.800258,66.496845,110.691419,248.327087,282.089552,257.206428,197.656182,175.855512,213.784278,249.221321,256.388553,241.275422,217.721109,200.926739,194.053885,158.245482,134.146415,144.071897,183.159553,259.560327,298.185209,379.955922,311.131405,242.122657,230.754278,282.610574,392.602788,445.433172,468.972945,306.807893,222.444709,180.072146,218.310253,310.068088,336.737247,384.694075,407.813796,375.054128,249.112115,191.868675,125.134953,107.572222,101.327164,108.077119,58.056475,-80.266242,-126.350413,-78.45829,8.784635,170.12469,209.378969,262.39741,274.981893,217.000672,118.013464,97.567262,119.317843,125.993809,105.104986,116.262549,186.33734,126.310225,39.340713,-106.340477,-136.819058,-89.911334,-4.2581,201.228261,245.113798,154.762034,6.441958,-34.695173,-100.598235,-149.109859,-179.574914,-119.351631,10.124923,-50.976075,-118.360748,-166.23448,-125.840413,-17.70054,10.829903,44.41909,71.070104,137.963775,132.247803,90.767775,56.075356,79.624883,114.696588,115.836373,117.164938,95.521128,77.991313,80.588965,122.119323,250.174898,291.487397,289.978446,259.284639,171.75941,63.636047,9.22027,-31.49541,-11.416223,68.359103,103.960398,72.301121,-51.385382,-89.574051,-140.259407,-151.052311,-92.140147,-51.674316,-43.833826,-83.935382,-213.68806,-267.442162,-224.772519,-92.959308,-69.753882,-66.263653,-14.1093,109.302233,11.783626,-86.683652,-232.211343,-248.084672,-155.524528,-97.233377,-86.113979,-129.241953,-187.352139,-120.460691,-91.338724,-81.674014,-56.414749,18.970083,20.682241,-18.173866,22.685561,33.758106,-61.882314,-121.203224,-172.619577,-170.330523,-104.892896,-68.271608,-84.368849,-177.555401,-213.985357,-209.570383,-172.171986,-75.612014,-28.943387,32.439385,20.055963,3.039243,-20.913096,-29.780783,-23.707609,-2.088642,60.483287,80.252691,69.987837,88.539482,104.898317,107.425183,127.454805,221.5824,255.024609,198.068849,43.536415,2.417815,-10.470873,-1.201469,41.05462,63.036638,58.969185,20.090585,-42.681656,-27.196315,-48.019386,-113.618329,-95.347079,11.524903,36.348887,14.094522,-9.149546,-33.233312,-114.611312,-134.139907,-122.416397,-118.394175,-116.513545,-120.181248,-143.553463,-132.745737,-116.805052,-89.432565,-73.311866,-51.712074,-35.726837,1.535123,-64.337355,-121.291913,-205.302667,-222.072851,-203.00579,-170.729244,-86.136453,-66.319489,-108.707964,-185.094087,-202.747624,-170.354085,-137.64138,-68.8715,-27.737856,37.580766,50.544135,46.084856,15.27247,1.408953,-3.724881,4.980859,69.128894,106.010575,109.218816,50.413948,12.307445,-65.667669,-88.379685,-63.608804,-15.968293,22.254875,-116.075359,-190.026803,-262.715002,-261.437242,-184.334134,-142.568523,-148.952056,-190.336181,-253.921324,-264.305548,-280.578948,-302.245867,-283.98964,-212.552268,-177.372072,-139.882183,-147.31701,-163.613687,-229.388713,-241.278479,-192.16607,-170.37753,-171.425048,-204.681707:-104.685375,-211.131929,-242.886884,-253.498738,-213.074337,-73.982379,-13.398917,-12.347014,-114.751189,-135.757224,-75.081843,-19.056683,92.321594,140.7626,202.697493,214.695128,223.665836,226.477989,205.335078,125.940769,99.182763,70.473473,53.386025,26.316798,2.384383,-3.319834,41.283896,83.550807,124.286951,130.149419,226.570632,291.898278,261.632016,79.858397,30.677907,39.059677,49.719435,42.544868,37.165606,41.2485,20.602596,-28.379839,-188.064853,-255.322831,-275.594836,-247.843726,-215.605196,-221.574942,-271.089073,-338.294073,-364.760542,-295.930428,-184.433989,13.633798,62.367295,133.966537,185.560607,170.853333,45.780425,-9.754806,53.031222,149.699046,259.305982,229.051014,67.274422,-78.335605,-109.18789,-47.375223,20.843148,97.221553,110.850981,167.215256,159.236115,113.328717,65.300671,86.889087,136.366729,137.331248,105.725887,76.218552,5.839345,-19.131293,-33.456025,-94.848639,-107.703113,-47.909767,10.051083,83.50309,33.071754,-4.763498,-57.857209,-66.430938,-26.009098,5.993782,56.191886,75.834799,77.294079,41.764619,46.429006,152.646374,236.69669,396.489819,467.41601,524.204996,391.50133,304.05545,175.890804,138.306082,133.145726,173.743907,344.238233,438.992161,513.057575,336.796621,185.585765,27.214609,73.728876,248.069619,292.621467,252.851613,114.461816,36.354313,-108.518607,-153.001297,-136.266135,-85.041757,36.961122,73.086783,64.553286,70.89046,95.454327,143.605799,178.9141,338.447064,454.734336,593.059645,478.428251,383.725434,260.52938,247.601357,275.497369,292.165561,349.516598,380.958043,358.208771,236.959402,170.334796,61.756931,40.723347,104.367011,169.502545,237.321866,143.361675,75.362782,-5.430793,10.237095,151.899489,231.86912,326.262555,339.129288,308.903335,249.621794,220.044224,195.787088,217.122797,297.812176,343.516694,377.576867,209.372637,75.724034,-61.363996,-14.152767,171.070316,230.141197,276.744152,287.710893,267.93656,171.707009,119.665578,67.905968,59.127759,39.924944,46.616096,67.51728,10.91557,-12.626344,15.93949,65.909447,167.598642,179.323295,165.109578,174.84003,192.071689,159.595701,133.430308,52.734293,-0.428162,-31.890546,23.492826,173.144879,156.362315,67.378225,-159.425559,-210.847844,-119.647963,-47.450404,72.64802,130.625289,144.653121,35.091519,1.960432,25.919404,60.535084,71.799125,47.96843,39.216772,37.702462,-3.764787,-120.083269,-135.854171,-52.110711,0.504159,89.236674,131.380099,119.976068,-31.50251,-98.037106,-96.93952,-36.813058,64.296138,64.726239,-11.986181,-2.124879,38.459764,13.512796,-27.06531,-4.911892,25.167046,26.107697,10.250602,-20.465799,10.406357,34.099769,10.03906,-20.772423,-43.529927,-34.912721,-16.444434,-77.019919,-134.753541,-206.848039,-200.092567,-165.189714,-174.903229,-234.628305,-263.084673,-292.090566,-226.466765,-170.827712,-106.801003,-92.183319,-4.810953,73.696056,173.503889,109.201782,27.743646,-216.543094,-310.169108,-272.750043,-191.833324,-88.365163,-62.961571,-41.733377,-73.58113,-95.721015,-94.32575,-61.023832,26.710887,61.755293,54.756244,-47.57707,-96.751835,-158.019061,-174.309269,-186.633121,-167.270722,-59.284932,-19.028591,-78.890213,-192.948174,-214.356389,-205.539953,-193.68481,-162.953265,-131.137938,-67.850097,-67.192542,-64.978513,-47.230651,-51.432727,-81.759986,-80.217238,-20.287357,9.338888,28.870136,6.343292,-21.294065,-26.060836,15.164884,101.822549,130.784272,165.666984,117.261921,64.135437,-28.136491,-33.437909,42.678712,87.799543,139.213828,154.01792,166.113139,132.001918,83.173059,-9.240386,6.345098,125.335053,167.390177,184.749125,166.454853,137.725298,-4.855445,-87.960737,-138.733858,-101.041574,1.910907,29.25353,32.469687,16.973089,-2.01694,-10.803325,27.388367,126.417764,165.68072,211.769202,86.736872,-21.705803,-170.615156,-199.990464,-255.251338,-293.041349,-273.671367,-214.505871,-169.407408,-239.11742,-260.035067,-223.564717,-164.67491,-10.249811,56.223805,116.980667,70.633922,45.073766,23.391328,11.258687,-11.027651,-8.443814,53.364656,114.720892,185.303265,61.090414,-20.036255,-63.334936,-28.005981,47.789322,69.965788,68.281929,-37.490961,-109.645995,-203.836993,-198.283697,-71.501933,5.648674,46.211771,-8.80083,-150.177993,-144.252544,-115.867527,-133.546543,-167.334388,-165.371975,-106.870384,12.329036,-41.90035,-95.431233,-118.430264,-99.465401,-88.650785,-100.213346,-110.416343,-110.247887:-133.418647,-261.414869,-291.331677,-241.854985,-210.529718,-165.290432,-125.737627,-108.88551,-223.857861,-250.388195,-196.572581,-158.059037,-78.803876,-8.587647,170.653196,218.778861,171.019258,49.09728,9.682349,10.527942,37.694412,104.751569,119.382423,64.960297,12.724257,1.515577,-67.603237,-88.64148,-1.212672,73.57859,160.268289,148.195558,50.685066,-49.225663,-86.342254,-80.944301,-36.580108,59.15711,83.612574,68.676191,-27.607882,-112.236803,-275.169132,-296.873571,-193.722971,-125.31594,-96.305657,-144.253583,-280.556553,-338.585559,-328.09583,-211.396759,-110.369087,55.176923,87.083917,109.727281,137.682275,100.834322,-63.774964,-102.70704,-7.138407,98.082886,262.300398,239.908459,2.5728,-214.348218,-241.279681,-143.296072,-67.929684,41.518033,77.77872,78.842891,-49.663268,-101.405402,-54.040786,14.862221,100.397161,128.141252,202.714866,195.269674,44.162857,-87.893995,-104.147218,-42.396116,0.345807,21.034483,15.171048,10.178479,-1.193285,-15.483383,-54.130361,-62.499206,-37.667756,-5.082593,85.546312,108.890186,36.288526,-66.619712,-57.968238,103.281436,213.766536,404.433471,479.872576,513.958725,338.847406,229.504249,87.871742,86.435401,210.773348,286.494996,406.589017,455.888355,516.029252,439.05771,328.115748,139.269334,122.176882,139.149455,129.961292,88.329674,15.207763,-59.761028,-257.155153,-296.233785,-165.937668,-58.036309,108.440185,143.5678,98.619828,11.824506,12.390743,101.860605,153.517098,269.831183,339.928718,437.543534,409.274804,342.426021,195.325937,167.529819,192.908502,235.835402,409.543149,484.044215,434.870044,202.443885,100.125347,43.185018,88.191084,248.245367,298.47302,201.386666,59.247698,54.547454,31.109912,-16.066982,-16.071124,74.037848,276.812677,303.676391,224.207389,126.885565,106.604973,187.66026,275.075882,384.808634,388.380779,355.055498,208.517149,96.767071,-34.50039,2.658996,215.202325,316.17876,414.049483,406.507849,340.997758,269.137307,212.97124,102.517044,87.496801,187.1352,250.603024,222.905722,90.782101,39.535115,-22.484369,-11.135528,104.292905,179.06643,275.248718,269.484876,173.168229,59.672687,14.632313,-16.477004,-0.445226,64.09371,101.206988,120.779637,26.750604,-43.644239,-184.584058,-214.07477,-96.637602,27.112953,233.669905,249.059194,109.332074,-15.39094,-24.705921,11.754773,15.880399,-32.532672,-33.146166,55.761876,114.522646,70.404224,-127.796956,-182.974661,-124.441128,-60.11744,48.394125,70.587823,82.230158,56.977089,11.406163,-47.799041,-21.86145,133.55174,217.859731,247.441843,133.34089,84.289165,30.699445,45.824075,179.602879,246.415713,259.982258,214.036747,145.565697,145.190709,147.897574,199.566443,225.668602,203.243845,185.881214,173.370057,104.808218,46.083313,-61.418564,-83.482336,-79.31967,-65.288828,-16.50339,-20.664807,-139.82069,-250.291517,-270.087747,-276.133706,-248.191687,-117.692786,-50.955134,10.790934,-61.438304,-153.973448,-362.473543,-408.505546,-365.833121,-332.495126,-253.187001,-187.086613,-119.367988,-235.957919,-282.235655,-201.157419,-114.529218,-12.882198,-5.280932,-44.911077,-145.326183,-199.352595,-256.64549,-255.441356,-238.348577,-215.762903,-81.611818,-20.73014,-105.260074,-273.186387,-271.436408,-176.40257,-147.785474,-75.636191,-2.293225,77.107879,1.264222,-24.679863,-32.310376,-41.651768,-56.522885,-35.665537,73.164035,120.737767,141.841001,123.939321,91.690928,42.303398,71.500026,219.085556,292.176352,317.713538,175.09922,80.179092,-59.296691,-64.148732,26.912627,79.675393,157.243277,170.225517,148.935337,103.780077,66.679468,26.794747,58.592962,181.042953,211.775995,152.411999,80.639568,63.980454,-53.48019,-151.37772,-236.915489,-186.548944,-16.644015,24.976488,-9.536959,-63.303082,-85.153729,-72.180278,-25.836386,67.670601,102.755136,121.753384,-6.314575,-74.984287,-146.634973,-174.826248,-245.86528,-263.827841,-224.884178,-203.369299,-188.890341,-212.309442,-249.716972,-244.015798,-165.592256,28.214083,88.550661,101.833786,1.335172,-56.084711,-98.19722,-73.728031,-7.049161,0.62352,25.068816,64.5618,51.556437,-106.414315,-156.030894,-150.763523,-125.668594,-72.526382,-50.308463,-85.554872,-216.005078,-262.518908,-277.632433,-259.440752,-213.576744,-185.575651,-94.584686,-59.176632,-79.211183,-171.396341,-214.135806,-221.073164,-184.895331,-96.115897,-52.935538,-7.426715,-61.144208,-121.216338,-256.798016,-278.207457,-203.226053,-152.859701,-77.29932,-77.880558:-122.588203,-268.585418,-286.241471,-190.784839,-105.564874,5.325764,20.509227,17.367884,-30.562624,-46.028285,-1.611516,34.826256,67.49443,77.799329,162.753579,229.332103,287.107798,226.692184,192.580944,153.289919,130.666734,21.282692,-28.607088,3.508676,72.013278,69.703912,50.2509,60.711875,140.351325,200.850549,291.071014,285.251071,198.048616,88.54393,35.82083,36.033821,99.947418,161.601416,104.893899,-24.657262,-1.75181,5.486139,-76.770435,-116.356031,-105.056569,-86.490233,-117.143889,-146.566296,-156.788814,-197.512526,-245.229381,-218.127797,-123.937302,-5.323667,-3.827104,52.055852,128.407039,109.804884,-14.311133,-61.017018,-35.400669,6.656911,53.377579,44.464449,-54.444091,-164.440945,-179.114967,-154.596019,-123.453058,3.08367,68.303028,68.911602,-44.62979,-78.691995,-82.915395,-63.626107,24.31434,74.292481,98.764308,67.159191,-7.272453,-0.224213,24.83768,18.865391,-21.840662,-72.974488,-36.672249,78.377294,20.054899,-55.033222,-134.419785,-119.515932,-61.788016,-46.267769,13.459956,66.183485,90.967297,-10.474702,-50.359387,-17.019523,88.781502,397.67393,489.871406,426.291328,222.609854,147.314605,102.417137,128.869615,225.4658,275.153866,386.983056,448.025946,492.729544,313.26987,172.715958,32.447441,68.52909,200.544978,244.323669,255.885311,92.607127,-18.497327,-146.394451,-161.897778,-141.968801,-104.009557,34.18421,103.426939,152.723341,110.91409,100.977378,170.809607,230.688201,342.178174,415.356223,563.166776,537.248669,478.706782,408.250593,405.651251,370.137722,321.953366,295.414291,333.637508,352.378822,183.604386,65.624441,-65.691273,-51.789504,11.518534,21.000429,13.798889,-10.095598,-40.026797,-101.731141,-90.172617,52.516698,146.52801,245.201197,229.918225,138.089045,75.09666,69.803153,86.225298,92.509549,86.996788,80.259449,57.429212,-5.557118,-46.801259,-101.093431,-105.881731,-63.653021,-19.016436,100.362919,154.430674,175.082147,43.217173,-52.530934,-143.209548,-102.213835,40.071116,83.720253,73.992714,-11.332204,-23.091451,72.94604,146.25693,226.437353,220.667137,212.128559,222.465963,188.48025,123.366884,114.967186,106.448449,85.352788,36.015634,56.831518,230.106833,344.610997,303.926548,89.541148,8.432652,27.634648,92.506512,241.187817,306.898388,316.128868,210.486171,193.58657,261.897629,308.751953,333.468007,313.512828,292.231364,302.229785,271.114616,142.365736,88.12985,74.49428,107.028078,205.879438,256.235901,268.277032,167.589232,124.355681,102.275697,101.107277,71.297871,58.220364,55.568295,48.765421,23.121162,-76.154447,-111.952446,-76.620994,-27.527737,44.281983,34.74622,-73.374377,-99.769312,-85.808468,-117.348337,-134.703078,-119.490315,-103.855991,-97.231521,-155.418785,-195.434066,-263.413043,-291.020003,-300.535493,-267.362937,-225.53628,-268.521536,-377.18594,-337.344973,-302.236463,-242.403416,-191.033007,-54.13192,16.428002,118.769848,58.039953,-37.113566,-220.116931,-238.948515,-132.715817,-96.806831,-138.164885,-164.292646,-203.298307,-260.424997,-275.881337,-229.310678,-177.863449,-121.8261,-131.472978,-202.872078,-322.233763,-360.603286,-364.431757,-351.018345,-322.808294,-299.597403,-188.522444,-123.074632,-109.463834,-265.238237,-351.450134,-402.742849,-359.709797,-271.016422,-263.05884,-294.162718,-338.475469,-331.687757,-244.696921,-215.132509,-284.137542,-340.227634,-325.021441,-256.001703,-140.23724,-185.452552,-271.891642,-420.793014,-400.75845,-221.707049,-150.596662,-73.569584,-38.450215,-49.798709,-134.961101,-179.03878,-163.618779,-117.970911,-37.542705,-3.639208,36.641514,-28.666627,-89.202493,-141.932811,-108.549701,46.566212,121.918922,147.86684,63.542832,19.771084,-95.594069,-154.018838,-170.514855,-139.831619,-84.302922,-75.380997,-79.165919,-54.508482,-65.288358,-114.939352,-103.347975,-20.326492,26.750865,102.080057,72.876048,12.040475,-183.310958,-289.938994,-426.825394,-446.178702,-417.308862,-388.840624,-343.587303,-342.133967,-359.523437,-342.055223,-264.435969,-55.632888,18.357499,39.612604,-75.237553,-96.700802,-27.189655,-18.367779,-100.641888,-106.56755,44.494399,111.413343,48.838873,-60.394792,-46.952402,31.77134,58.949763,82.65466,78.318748,46.011691,-0.884597,-18.529013,-41.832322,-62.398092,-66.584091,-25.772908,55.913372,55.538833,-9.860797,-83.517213,-120.355179,-135.054369,-91.249646,13.427875,45.201637,60.115973,-17.952048,-53.15173,-19.96822,27.636692,79.021141,65.121389,28.079196,31.384445:-109.633564,-254.461959,-315.672707,-329.898236,-251.876649,-41.155045,20.812077,0.138086,-127.607951,-172.041002,-151.530972,-90.806535,48.243244,102.937357,202.608965,223.092662,164.704361,81.940472,58.651886,70.255551,90.353259,126.385299,142.32379,124.969193,4.847888,-64.949658,-117.136512,-69.685441,117.480685,206.71329,314.736646,308.031597,139.598465,-79.31385,-132.509394,-89.282456,-24.46844,100.422703,140.810698,147.984155,13.994794,-104.064254,-280.100767,-269.346107,-114.929974,-63.456809,-122.312661,-187.950022,-272.262291,-355.847744,-401.524767,-345.927336,-222.369037,40.507967,107.72019,132.748369,139.734388,119.379519,-43.004738,-121.461215,-80.934415,12.149305,134.98329,106.061267,-99.484916,-275.727464,-314.159007,-313.903669,-273.002957,-118.708253,-31.530925,55.362812,1.31759,-31.74969,-42.56373,-21.93961,42.881906,75.35806,133.373735,145.136134,71.203186,-80.189668,-140.476425,-162.886338,-130.883626,-56.719464,-29.791342,-34.697318,-124.929475,-183.047261,-270.66463,-266.830268,-174.465502,-122.146564,-48.877292,-41.728247,-73.381013,-91.055442,-97.543149,-33.328754,76.004161,369.979467,474.433528,442.473349,198.519462,120.246099,124.756004,152.565656,200.422472,245.51147,393.997486,466.201556,486.5951,290.018493,158.320412,18.011227,38.250824,185.768134,280.282548,352.927656,116.297449,-32.459671,-187.217552,-185.508333,-103.667165,-48.819188,120.806446,209.286341,207.819784,49.395596,20.556597,144.824726,260.004491,450.346849,513.414447,563.709626,435.498944,341.437798,220.789421,219.044769,318.999556,377.230105,415.498872,393.461734,311.394536,196.658141,136.224343,103.794705,143.510517,250.216654,275.833074,202.512623,10.296937,-83.329216,-190.711904,-172.707199,-2.90688,108.140496,257.55623,243.998624,35.669174,-160.695665,-169.275078,-37.575847,41.800776,150.443266,208.950628,319.81526,183.19915,16.686672,-194.698215,-147.364689,77.937142,159.180112,267.839922,303.028115,263.826863,79.29888,-33.095472,-153.459267,-133.970475,14.274678,104.129567,181.188812,124.653698,91.483257,60.493204,79.042661,155.722681,175.047489,173.822178,167.864767,91.828931,-62.092189,-107.265684,-93.860169,-65.255309,21.874605,84.662079,178.138682,148.3181,68.420973,-148.333833,-199.309715,-105.425637,-12.322949,168.907816,233.426229,231.214186,101.802081,65.839914,139.81761,199.70762,235.98531,234.454026,233.67114,168.287456,109.782332,-23.12414,-65.030766,10.620214,112.8369,272.485768,280.556718,172.889526,19.888965,-38.888519,-43.395089,15.467218,152.129472,188.26145,166.596154,45.278143,-25.9224,-117.460253,-123.637699,-71.46561,-27.337042,62.238532,81.071321,31.281578,-52.256882,-73.855138,-64.779661,-38.304154,66.313342,132.171687,182.087526,50.082624,-49.269423,-224.996886,-270.76864,-223.407951,-151.543636,-81.466981,-125.845575,-272.299788,-368.155666,-398.544668,-364.499927,-281.995877,-83.889875,-9.256847,35.423427,-92.915494,-184.450125,-346.140604,-392.003248,-373.868279,-329.524202,-202.137764,-131.22701,-102.631525,-300.569087,-411.261102,-399.246866,-265.275131,-24.750753,-2.453792,-64.359774,-154.874424,-220.528844,-311.562785,-302.309588,-237.781743,-201.846636,-112.991935,-84.183393,-125.735558,-292.412778,-375.675892,-384.664213,-292.912861,-91.154983,-54.479683,-122.366647,-224.353731,-237.060624,-223.519636,-221.89866,-201.63619,-159.276893,-2.478987,73.554531,74.190687,-117.001514,-210.07553,-225.786082,-158.403448,-6.037446,75.32757,223.333088,154.389299,35.657848,-134.773797,-123.303817,24.240158,103.70652,215.587085,247.403325,243.217413,136.478261,53.182289,-80.440066,-84.410043,56.902382,163.510335,282.989017,199.38587,119.792705,-53.432129,-126.249222,-136.654615,-70.678938,62.768602,78.837059,50.945804,35.748873,19.218618,19.094686,62.806526,170.042671,217.175128,267.007145,148.911069,61.387012,-60.863885,-94.53896,-127.831755,-137.948342,-148.649284,-153.819771,-205.51593,-318.810516,-372.643577,-322.555264,-200.086629,51.565511,114.914957,123.418918,51.082635,10.560065,-54.515463,-77.357879,-120.05201,-118.121658,12.013758,83.305895,42.8164,-107.194928,-145.833557,-148.228122,-125.755612,-29.530845,31.509197,32.050594,-169.59868,-254.877073,-323.556876,-325.173209,-227.94057,-139.080455,-32.3689,-49.153586,-148.410898,-208.508381,-208.113203,-156.035773,-121.796975,-59.395586,-4.048486,107.371553,-2.096169,-106.056978,-183.704482,-134.393784,-0.080576,31.074133,56.451529,56.934029:-226.327199,-301.370033,-296.540681,-193.809466,-115.037948,8.712742,36.673486,22.967544,-18.533131,-2.54077,55.317353,53.721962,35.598483,65.528164,193.127362,232.386651,186.091266,111.526028,93.2745,35.164743,-15.151115,-100.671589,-108.604403,-76.649129,-43.390945,-18.415659,15.716679,6.994585,-13.2613,-10.393873,2.57236,-5.786846,-99.012503,-200.083168,-197.269002,-84.218431,-7.789295,66.633761,42.857514,-43.646816,-62.883419,-57.23523,-73.060892,-73.363451,-26.494037,-16.530323,-22.023337,-4.119677,28.340327,-70.24523,-143.801886,-155.839592,-83.733518,32.89311,30.282551,12.061108,117.800996,161.564606,72.187736,-12.221582,-27.6518,22.132414,15.718411,-60.984573,-226.197823,-284.812824,-291.228738,-285.110246,-258.116383,-175.450372,-138.020612,-80.931299,-60.708016,-87.413878,-219.300809,-245.012671,-84.429723,27.031852,129.834904,134.50625,125.626778,112.071038,109.243334,86.270104,33.82905,-111.19478,-127.944762,-24.848164,-23.165349,-72.714563,-102.675611,-81.511682,-49.979033,-48.904651,-22.022915,16.004771,44.730404,-38.952183,-79.717654,-54.103562,29.962319,218.350844,255.187594,194.429107,56.87588,16.864142,45.995081,89.060077,148.007792,157.434543,206.128963,263.079071,372.999389,320.164125,227.235858,139.861371,191.349369,296.582581,294.562165,216.237619,67.345908,-2.755615,-70.228086,-81.696128,-126.057133,-168.871514,-171.246374,-89.183148,87.484837,61.396387,8.161156,14.337058,83.365695,215.720054,248.344964,272.202008,257.287237,233.259251,175.586924,156.129985,150.608045,154.592501,149.740475,137.145174,102.303361,25.221985,-61.439028,-247.141266,-261.892035,-132.95853,-82.809858,-151.784115,-279.979534,-289.593118,-233.938725,-201.999854,-132.617548,-87.819521,-25.090508,-27.065623,-79.749536,-114.359791,-109.932163,-120.933979,-155.269697,-221.387165,-220.06833,-174.095466,-145.816424,-138.90148,-152.492915,-168.044515,-163.080382,-134.822831,0.486785,78.115182,108.93116,17.801304,-38.367815,-126.945319,-131.171073,-53.844852,-7.305363,1.589608,-38.466607,-12.610793,63.417103,56.247785,4.837541,-5.541456,-7.816406,-0.492114,14.291966,-2.640854,-22.516427,-65.974883,-74.024046,-39.809117,15.708065,199.447765,287.924852,244.185639,65.095723,3.619389,30.294553,95.368016,237.326872,273.513943,217.554313,125.921085,125.880767,202.520312,240.548438,249.229449,250.348034,316.466961,384.77211,386.204669,273.437758,180.037403,102.572232,140.174704,260.809913,304.50095,302.547133,212.039803,147.408689,33.633082,36.587632,105.233554,102.925869,31.376636,-46.449451,-90.214586,-191.806893,-221.147114,-181.827652,-138.530194,-77.384412,-73.454257,-128.081325,-179.0537,-202.631722,-263.997364,-272.022957,-248.030173,-230.141934,-198.04347,-290.740898,-359.734333,-419.525094,-427.440022,-443.379807,-426.133633,-348.00134,-347.554805,-440.30125,-430.468882,-386.092745,-331.241651,-317.371909,-245.031275,-176.827922,-57.119754,-18.540914,-9.004725,30.046554,70.422263,139.08636,125.293356,34.246789,-4.502803,-71.96778,-173.441003,-232.939961,-286.546722,-259.639925,-187.042007,-178.999393,-224.73997,-290.431947,-300.378158,-270.410387,-240.462055,-165.187076,-119.639747,-26.945068,1.587751,-15.331292,-119.914873,-188.484365,-227.934841,-165.754978,-62.385221,-98.430462,-272.055594,-283.8597,-195.767971,-85.297174,-117.120387,-192.505183,-188.716371,-142.135073,-123.949158,-127.116188,-194.376982,-247.279555,-309.662831,-275.487257,-113.013575,-53.233152,-41.306493,-83.720745,-93.377422,-70.943861,-57.303816,-84.974785,-120.808864,-124.795004,-79.771318,9.246439,4.343149,-31.587842,-72.782823,-56.40281,7.005606,42.211799,114.994948,115.083788,71.358881,-59.493728,-126.431258,-258.526785,-315.493396,-332.678919,-283.670912,-185.435231,-199.805287,-215.975164,-148.857492,-73.1013,10.338127,18.467804,88.003633,145.881559,129.104579,23.656743,-39.186793,-147.060857,-197.517248,-242.569715,-222.581091,-201.379779,-262.684898,-285.226857,-232.907013,-145.031239,34.867558,60.642474,7.855689,7.812193,63.822514,168.362999,142.128476,-3.98706,-36.247911,34.608433,96.871958,128.766476,38.220333,-13.799078,-59.786258,-26.198908,86.155982,112.926958,61.252939,-3.468723,29.974867,158.309246,173.891786,91.786674,52.935425,64.509211,117.755614,241.546826,195.814139,108.870435,40.279247,108.037161,269.487495,293.390285,299.785074,297.509736,274.081893,227.974659,239.471351,359.540394,410.740673,355.792011,289.414772:-144.493645,-232.51738,-259.287336,-247.313687,-201.827885,-103.087462,-77.712045,-88.5291,-88.933593,-43.896941,6.478261,-17.418017,-36.206601,-2.689555,87.460774,121.37349,198.982513,260.899041,234.14052,96.821836,40.653824,-8.634322,-21.048215,-71.087069,-90.925072,-50.741244,76.15489,130.348142,186.962418,189.917417,201.019829,210.03463,152.602838,49.624249,38.806155,98.287071,129.052834,93.720894,47.019452,10.807808,21.039376,11.863776,-65.896206,-100.592895,-76.632791,-62.288448,-74.899351,-61.481527,-13.672365,-47.164092,-87.422994,-81.865308,-25.449151,44.15276,45.064943,77.830992,149.898759,161.713833,101.857281,59.660244,26.541403,21.133169,-22.703234,-60.141123,-132.69494,-187.54569,-206.831857,-191.169522,-172.320412,-172.203114,-167.345967,-124.150701,-102.401764,-108.737353,-179.30712,-210.272455,-165.861919,-108.501586,-0.969752,20.442514,-14.652791,-33.819451,-30.374954,-44.349477,-60.432294,-70.472191,-31.513278,63.029553,-38.169693,-111.028677,-105.596593,-50.163946,-12.02714,-29.465625,-14.996452,16.068631,64.023663,113.316143,123.77901,94.650409,116.705649,318.519006,419.055837,377.374726,131.665557,72.680228,93.677651,91.922849,24.003819,11.937023,119.161619,209.482377,284.365649,161.924214,93.234699,50.78025,79.707914,164.034647,194.270682,167.183566,-9.469551,-98.769158,-210.316534,-240.376725,-261.156594,-261.676862,-204.147302,-132.867585,-43.071474,-96.552082,-138.852181,-161.620762,-104.981247,102.288866,208.908019,359.840712,380.831181,356.47175,285.089184,252.637353,217.371759,200.812342,165.213282,171.461839,202.223637,103.104701,2.528358,-163.135179,-194.02564,-171.677974,-139.587842,-115.077335,-219.74137,-268.287987,-209.659655,-87.641398,206.251276,274.345011,245.343662,229.028591,218.162036,163.494117,128.102616,34.107898,-12.827019,-79.207444,-108.181912,-187.582152,-294.989131,-313.944678,-275.519942,-255.838499,-237.529043,-211.129208,-36.671183,63.432027,53.416175,-107.830382,-155.576058,-241.639664,-277.572008,-239.133612,-169.625424,-66.562975,-147.959386,-205.941576,-184.55466,-127.802072,-76.608698,-82.476164,-38.845452,10.815279,16.193207,-68.535439,-93.611438,-166.069899,-222.043888,-265.090931,-223.783945,-74.03757,50.768978,65.521077,-89.493595,-225.459494,-329.984775,-259.023448,-48.099771,26.46228,72.470192,1.910787,-64.230922,-151.361772,-136.262123,-47.644298,-6.157018,106.198025,222.767315,231.24234,119.706995,29.146004,-87.897302,-81.735788,66.568151,179.246941,301.322519,188.734249,107.698765,26.454983,8.333854,-66.404869,-101.398185,-111.943276,-100.457003,-92.868965,-84.465789,-105.244038,-183.072949,-195.904186,-126.304173,-91.841174,-135.388457,-227.659475,-244.569726,-207.104978,-159.385389,-98.466079,-100.955295,-88.552062,-109.200741,-165.377378,-301.612529,-352.906154,-380.632959,-365.132375,-346.97916,-359.406081,-366.44409,-247.774924,-176.690271,-117.133523,-117.281734,-95.064258,-52.555296,76.360555,191.902177,233.831803,230.340069,185.686436,132.654345,135.915934,147.64232,153.622543,97.9302,-115.490965,-207.688733,-188.478455,-112.443603,-43.193439,-59.790498,-93.363445,-154.522197,-195.727195,-234.052374,-223.984117,-179.626959,-157.160745,-40.770561,61.498377,156.529435,-5.303981,-105.612991,-200.172682,-184.332914,-103.801339,-84.224904,-135.801308,-237.532802,-242.986511,-176.983767,-162.447452,-219.243803,-274.725052,-315.123398,-250.230786,-39.12605,19.083831,-65.557905,-290.459611,-305.076802,-128.009316,-26.87412,81.42923,86.682755,72.950172,-28.915548,-98.53496,-87.45902,-20.135832,26.228014,-9.573366,-51.834937,55.423012,99.347163,55.218304,18.239601,65.108486,140.810306,240.381502,126.257779,25.146568,-105.925301,-133.345581,-191.216367,-225.160709,-234.394706,-196.632598,-121.772812,-150.622842,-168.292548,-88.299022,-26.024009,-26.018794,-69.774546,-99.051326,-48.531912,-27.94009,-89.272957,-171.786721,-290.997857,-300.962437,-279.717363,-254.916074,-206.176242,-236.27335,-259.014936,-213.961668,-144.416725,-16.370831,25.989522,84.270369,81.168174,77.118109,84.242818,44.85178,-125.445946,-173.094848,-70.436919,27.697843,91.259782,-27.481673,-80.606071,-110.833672,-88.648748,-1.049521,41.385798,79.746307,97.769194,119.778013,145.875992,132.867793,95.059872,93.305219,118.019373,132.935074,150.114126,138.491786,124.178273,107.601651,108.240499,102.386285,116.221614,224.268416,276.209463,251.851233,182.49013,156.342408,154.92853,178.544745,226.057463,232.798879:-230.234814,-319.089553,-322.126233,-242.074039,-160.611007,-15.935068,12.971754,-28.659842,-155.934208,-196.621417,-141.374713,-84.052056,-25.358214,5.605174,148.707005,202.81945,146.657574,104.088352,137.278285,132.334677,89.231346,51.609567,59.429842,52.745199,13.413543,22.206353,54.289543,42.466494,28.767989,51.861859,121.733671,144.22752,105.059003,-40.648053,-100.570424,-104.498706,-52.565957,65.284609,86.761591,44.05031,-26.253263,-49.510682,-79.168101,-73.826018,15.703275,53.100692,-18.181344,-97.072606,-182.127698,-182.519742,-177.448319,-90.244994,1.720608,134.272954,129.85757,103.065085,165.112747,181.900345,103.470707,49.894338,56.968031,86.217274,47.16907,-20.960625,-159.573547,-226.359679,-255.324297,-287.209438,-248.974142,-98.084626,-36.446437,-3.837272,-49.402383,-61.47836,-88.366627,-108.356028,-78.982146,-25.639115,80.271383,95.142199,27.135631,-32.298454,-39.132273,-63.154858,-82.090706,-113.664183,-118.086327,-116.798255,-167.872603,-190.404021,-184.43326,-185.496275,-197.820645,-180.420126,-80.045064,-19.485614,10.410365,-67.896018,-95.232969,-13.964937,99.506669,286.274854,305.457691,261.484807,161.292822,102.893107,17.873675,12.533829,154.659696,261.7875,340.20175,310.831878,259.764954,236.73661,183.760384,37.094946,11.793709,82.162669,129.128876,136.45409,-8.454478,-78.094077,-111.437144,-108.331324,-126.618731,-118.849191,-1.156803,83.859584,179.611837,129.580276,91.415226,100.157149,157.155607,288.464988,320.297074,324.413786,322.288502,328.210262,334.13545,312.372115,198.947935,149.518405,177.20689,226.629485,246.952499,86.560941,-22.643163,-124.486968,-96.031288,6.559498,26.582825,-42.391306,-120.730246,-117.303443,-64.056329,-42.620226,-45.42497,-43.253821,20.690998,34.6801,-75.794751,-155.571838,-132.630749,-91.060432,-118.770002,-183.280752,-168.596559,-142.247292,-171.136215,-165.171105,-172.255321,-188.982097,-124.169884,-31.340528,172.690002,235.625752,186.061686,-16.092362,-77.966979,-88.418908,-86.547744,-64.602458,-25.292328,35.734399,56.847923,74.10927,131.694023,159.465661,178.260087,167.711143,117.592623,88.753225,38.839655,0.362977,-24.303835,-87.309497,-103.116435,-58.998291,5.465615,177.158745,192.368453,108.136063,-52.409018,-65.837423,11.868515,61.07374,142.43128,173.297841,183.19419,150.477296,124.250056,80.878209,95.389883,167.723769,200.652159,240.710284,282.957437,318.190114,253.037397,132.307988,-28.097921,-9.141334,121.236469,172.066169,173.701918,132.299747,107.344343,9.585311,-29.275475,-0.146818,38.18255,24.545762,-91.438917,-130.99958,-196.079294,-233.103583,-249.373196,-245.671363,-243.047288,-213.860337,-151.418002,-193.346547,-222.37405,-231.116304,-212.679821,-139.600107,-89.391284,-37.710175,-148.613663,-220.001794,-301.734966,-332.024113,-347.348708,-313.37419,-267.73674,-292.224114,-375.208218,-441.753913,-462.515114,-404.427143,-330.90184,-220.324188,-181.201136,-72.187864,-48.924417,-90.558871,-167.507512,-166.955056,-133.903962,-146.675642,-202.122448,-203.771429,-184.902238,-248.762503,-304.179784,-317.157414,-246.654758,-82.309988,-59.622899,-149.466972,-187.121835,-161.678904,-220.33185,-288.706157,-281.449693,-199.289253,-19.114011,30.297859,-5.39567,-199.036158,-295.352697,-296.011403,-212.040259,-113.923212,-142.983607,-234.678266,-216.12644,-170.964494,-92.251784,-91.795844,-141.746473,-142.965992,-73.433917,-45.668224,-78.897378,-149.013757,-172.342263,-166.651706,-114.302657,4.844881,33.184996,69.548614,39.368197,-18.814134,-122.08133,-115.038294,-0.237713,36.866592,67.841689,119.340923,195.853241,39.914645,-53.144853,-85.440311,-45.322552,66.473596,139.891037,254.705323,204.300471,147.574355,64.847353,31.441925,-32.332489,-53.887224,-58.145628,-53.058655,-57.589667,-31.323239,-19.79418,0.368251,46.839126,183.826979,222.977093,205.016846,137.389598,110.087003,47.649095,-10.152676,-143.802026,-179.906789,-196.108226,-208.754379,-190.176779,-94.108869,-120.847204,-277.982541,-257.691649,4.09227,118.231414,184.463828,139.354596,117.167167,76.291543,45.15264,3.484051,11.455698,85.104637,123.82456,117.812905,56.193672,14.277212,-74.785534,-74.10628,6.488325,37.502728,47.72153,-14.333413,-65.673078,-117.745464,-88.311578,51.301014,90.633551,14.935012,-29.90715,19.168063,59.852724,22.788019,27.007889,102.129652,231.918616,247.2362,217.760426,136.650373,93.546244,63.396039,80.891594,152.333379,196.109176,248.545091,224.232662:forward
409.275186,300.00596,225.716749,135.913068,150.967437,174.502768,154.119506,188.887644,374.272511,463.555177,510.401281,466.139614,352.02037,322.050554,375.215221,449.473807,514.366039,373.866394,302.507143,277.530142,320.011475,448.435088,499.747252,517.038602,407.632915,346.713761,308.271865,319.140669,352.923089,377.997054,451.898703,477.38735,420.115295,283.593672,229.912211,186.607942,186.14017,114.347171,48.419665,-2.565916,24.957396,10.803657,-41.503194,-41.343673,19.002522,56.607633,94.841948,91.334521,29.589696,-93.698492,-136.90353,-152.789257,-145.197228,-129.347124,-94.043766,68.950232,149.124951,129.868215,82.550948,83.725329,134.910315,154.295796,119.511561,73.022116,-15.990655,-102.531313,-189.232228,-373.063919,-399.105971,-340.06882,-303.728363,-275.251649,-392.595551,-493.473083,-537.597973,-446.092677,-255.412637,-224.095919,-188.872065,-136.730166,-59.889167,-129.189631,-183.044732,-230.422187,-206.696479,-120.094954,-94.19275,-93.230071,-129.728056,-167.557727,-255.098916,-260.416777,-104.695442,39.150568,301.263579,356.193037,268.700149,76.495524,-19.00715,-192.531906,-238.183587,-248.607943,-225.669542,-148.796636,-118.645619,-109.574779,-81.970403,-70.46729,-39.737929,-23.406146,23.294235,60.674491,111.966665,93.67548,56.03616,-41.016518,-61.550317,-39.337956,-21.520899,25.854391,78.76117,117.084396,223.564255,242.857575,191.027858,185.291063,306.460935,369.098409,327.51527,211.523752,175.232571,59.944275,-29.646308,-94.870554,-19.973587,177.597017,198.726356,172.169136,142.320073,129.88601,83.371433,55.395723,23.402083,34.847273,65.783566,-49.5754,-138.068289,-167.889699,-104.885706,-39.678089,-60.056205,-50.540854,-11.190843,-26.396614,-90.761513,-127.646115,-152.073981,-134.956952,-84.7711,-48.858167,-58.805908,-233.193979,-308.463575,-334.511569,-297.272096,-253.813474,-264.199348,-261.579783,-251.934963,-270.325931,-359.514846,-416.960085,-481.069997,-460.035628,-270.065452,-142.853398,-56.73474,-153.126451,-181.959886,-193.77364,-195.422041,-232.167557,-238.530762,-111.851428,14.192594,-5.699477,-180.157618,-273.25847,-319.408707,-271.884768,-132.894723,-74.705071,-69.014734,-188.301137,-216.307315,-165.694976,-135.562543,-106.083861,-70.288317,14.048606,-37.097512,-79.070954,-125.619829,-140.716656,-137.439901,-132.422452,-164.972069,-178.070525,-151.330166,-99.441649,-73.809773,-30.211797,-19.031312,-52.744926,-93.396288,-154.855937,-101.045977,-37.204814,10.35415,-16.36996,0.463225,56.444916,117.580734,108.524647,72.080702,-26.714789,-125.359679,-299.590827,-320.137413,-254.631924,-199.039555,-112.853396,-95.370781,-91.908711,-127.243106,-170.241665,-206.861218,-186.261276,-126.060524,-116.684927,-150.616853,-134.068817,-113.934617,-169.215003,-230.084899,-280.102646,-244.468344,-114.60137,-31.758357,-33.140156,-120.227839,-166.403219,-142.002565,-75.774723,72.408117,121.442043,118.609144,107.457263,137.709583,159.898218,126.17899,107.187702,166.301504,297.48501,285.371504,252.156108,183.584403,137.724266,67.554485,72.890138,132.365926,125.562359,-25.317064,-182.996265,-235.917359,-303.43089,-288.89478,-210.718306,-196.428823,-203.946827,-173.627488,-137.484152,-112.104654,-141.859747,-147.323247,-69.959861,132.313101,157.746827,29.571812,-90.068303,-120.958669,-146.586535,-128.848886,-26.876641,41.083258,112.248021,35.738743,-5.875517,-19.114294,1.251762,96.32005,156.689425,275.331903,326.803721,312.248346,125.046821,7.712102,-158.657898,-135.719625,102.957735,217.185579,256.125283,100.28613,44.281525,46.619432,66.647595,84.289275,84.815863,127.128156,166.265093,179.169538,121.453298,80.2754,-25.915903,-67.016161,-116.503041,-136.278229,-143.351782,-79.249145,-29.810943,8.310935,-9.098596,-23.366311,-16.607917,36.75152,95.379876,194.824549,177.133212,116.955659,-39.986045,-85.56912,-75.061287,-32.723725,84.806662,134.216342,115.012774,41.436307,10.915689,-1.075209,11.521517,53.556652,75.8532,63.883558,-23.220417,-60.347865,-49.430152,10.672074,129.903194,145.824278,111.709882,-21.445272,-113.063812,-248.918395,-267.910451,-226.995429,-202.421452,-161.853423,-135.636701,-110.884472,-77.654137,-29.141575,26.971582,1.729464,-26.957594,29.798277,205.989703,261.538582,251.025286,219.844262,211.016767,276.161286,364.176209,495.176897,454.55665,229.213225,104.683422,72.783837,-71.320467,-152.390194,-190.513626,-155.107285,-98.804719,-123.868035,-140.307585,-170.370451,-180.600139,-166.884599,-172.803074,-239.17157,-252.833317:346.844804,167.292636,120.663294,158.82011,202.791735,289.626484,345.007727,439.140314,435.537535,424.947019,437.037529,444.723197,412.463697,370.681611,325.541284,347.181661,358.557521,218.654929,156.223912,157.464182,191.716518,279.866032,359.634793,528.501542,470.943195,362.867693,170.129061,144.863052,235.603161,292.065274,331.850681,329.691722,341.95689,384.334963,399.136996,375.939176,339.598167,233.776218,176.719033,134.874318,154.293195,111.806771,-21.648467,-32.428435,68.702424,121.469886,155.646902,139.978341,35.155812,-68.111035,-70.064939,-34.849581,-38.64691,-65.807101,-41.975161,102.594363,200.677738,190.575283,107.018903,83.937225,124.28163,151.41286,146.391147,111.689152,14.186871,-66.835657,-101.926986,-170.311362,-193.941797,-194.296543,-169.200197,-127.100008,-183.64976,-226.063278,-255.405195,-223.919999,-103.670872,-71.553839,-41.400131,21.749171,131.731995,22.487054,-50.396694,-79.630505,-54.406173,-57.985652,-94.737405,-143.987458,-145.905546,-170.4864,-232.341889,-214.071662,-90.360115,-13.424365,172.19311,229.211334,108.989914,-115.139475,-187.047652,-298.490715,-346.426296,-395.948444,-370.10685,-234.714607,-132.911029,-115.556952,-166.686897,-206.06363,-178.78733,-111.567526,70.651751,148.293744,158.394803,65.353774,43.283628,27.576482,10.764967,-9.090204,21.673174,107.761205,91.84403,71.469257,23.646993,6.159964,71.573988,131.224604,214.31575,241.138239,207.135993,42.670346,-21.908409,-65.932802,-73.194905,-62.908518,-33.872674,19.887741,66.903131,103.635033,117.306219,75.34705,-17.31821,-33.807862,-6.81819,23.831727,36.677663,-67.846905,-111.986519,-102.319893,-80.347595,-77.126773,-65.367015,43.853242,82.59308,36.93369,-116.819001,-174.58428,-171.592276,-149.129044,-110.503784,-63.639416,-9.047748,-132.953682,-205.660295,-244.483098,-221.145661,-184.43549,-177.639949,-181.53101,-227.736839,-249.246287,-299.437385,-340.449938,-418.069928,-398.091508,-156.753674,-22.821092,1.783005,-120.00963,-138.164055,-153.708903,-166.635067,-135.748662,-89.476317,-31.913585,-72.623987,-110.381038,-216.948293,-264.361975,-235.713242,-161.956093,-48.718643,-65.66351,-214.554904,-309.872063,-315.723854,-288.610468,-256.485083,-190.977514,-165.414287,-106.203001,-108.477116,-149.404062,-264.054872,-297.483403,-276.938551,-261.739004,-304.25056,-339.845309,-314.924276,-165.071722,-118.454066,-108.994603,-98.645758,-62.324753,-48.943572,-42.543216,-77.21814,-98.467078,-136.729975,-124.638263,-1.767948,52.943183,48.874498,24.43927,12.251656,-61.311528,-142.919115,-248.56523,-233.06449,-120.705973,-61.964619,23.623879,44.593986,1.712082,-84.852993,-38.515266,124.243601,129.393681,67.34483,79.731978,169.143708,216.320202,178.977224,18.415481,-29.503222,2.896406,43.252926,80.092668,55.055093,28.020961,-133.04674,-238.574507,-253.996114,-161.25234,4.733124,26.231687,-21.937619,-48.801685,-52.323335,-33.312569,28.089533,202.355364,237.672975,161.647043,107.875203,129.648774,162.020873,146.110805,104.161843,107.547177,133.322234,102.199344,-60.266146,-150.003229,-168.47773,-223.074763,-223.664202,-151.390931,-112.065488,-59.027415,-63.436662,-76.051394,-86.705212,-93.308275,-64.406846,-10.23149,116.27662,131.651087,28.342899,-60.023526,-70.087748,-11.571002,58.26111,173.749066,187.026277,156.357138,110.57223,80.329177,-24.001216,-71.228066,-16.128363,75.373389,219.72468,226.62732,134.41065,45.749084,3.116375,-52.275139,-19.273072,146.637128,225.685785,249.479857,77.157965,7.483816,40.06005,92.217349,97.243329,76.916858,134.61479,182.855907,187.873115,166.080746,161.89209,112.130252,74.64039,35.205614,51.233617,93.010084,21.48807,-36.568396,-111.955724,-121.963884,-121.28877,-122.955273,-96.001387,-54.890505,38.25942,77.356087,67.778443,31.178201,16.545797,-23.851349,-17.348379,130.533403,222.322738,189.980316,105.485309,80.111601,9.667861,-33.080905,-16.537033,46.017252,131.923376,72.103019,19.32716,7.653688,61.403198,158.748258,173.987804,140.766132,-2.832707,-100.606888,-247.600096,-266.080365,-211.947301,-169.272299,-60.942216,-7.012395,2.424065,-48.962645,-29.059755,83.40842,113.451031,90.951766,99.496793,239.553535,415.062236,445.660517,363.726832,302.430305,322.280145,422.154671,578.581925,523.572853,204.336628,26.325035,21.875009,-16.873979,-70.534765,-146.873269,-134.939855,-59.896112,-38.393549,-59.305379,-125.888143,-141.564249,-147.855068,-177.316557,-258.198226,-266.369544:333.104838,168.433668,171.709095,154.316809,131.639186,213.632134,313.249832,454.864234,445.628273,429.502307,397.365651,373.573499,343.635607,336.351066,306.8696,277.583165,177.855466,43.482869,-16.599178,-66.439796,-26.239,169.819128,277.010207,393.773344,330.251237,254.993487,98.024018,66.242208,134.258788,189.016249,232.837114,219.084327,245.108497,296.03781,260.587355,181.038738,183.198877,198.068584,189.943579,177.196073,135.697718,87.209351,28.740925,56.151768,138.775953,130.07048,57.448545,36.788215,-31.254043,-127.740861,-123.861246,-26.05259,3.258765,-35.874855,-57.372618,25.942974,138.336181,138.773666,91.52586,79.862482,135.607953,194.742959,239.294784,196.082526,100.243953,58.388681,12.494767,-107.443567,-150.6676,-171.311235,-149.214665,-121.081806,-130.655042,-115.266658,-43.656701,-4.635848,33.184117,24.160294,11.481809,44.021873,110.62167,34.700887,-5.131687,-22.2222,-22.623387,-33.111131,-51.664234,-123.441039,-161.877039,-158.762445,-158.734568,-155.813219,-120.445194,-92.561082,-9.630268,24.971416,-3.47725,-90.429793,-120.380791,-192.530616,-253.518707,-387.521934,-403.721288,-305.446255,-242.674328,-248.689337,-250.788276,-218.319734,-119.366327,-100.38475,-70.469584,-18.180056,20.156598,-81.14562,-104.88836,-49.264707,-2.416945,38.193606,33.908514,32.181595,45.758507,44.680366,-14.896228,-49.372603,-9.240816,50.734555,127.41614,131.34022,92.025661,-35.427418,-129.294073,-233.081059,-203.838344,-74.949911,-44.298236,-84.955308,-61.415445,-11.472782,1.990977,-56.716087,-180.317716,-179.884262,-59.452925,-10.794714,-34.933126,-105.150294,-110.514567,-70.258513,-56.738056,-8.634349,63.519996,193.997734,129.472343,59.924106,-62.704719,-90.518682,-35.971347,18.847525,59.078274,13.028855,-124.920691,-140.482426,-126.312998,-122.724523,-102.134315,-50.057733,-75.014054,-216.54381,-265.109436,-245.079149,-245.854937,-262.28146,-266.946841,-248.194371,-151.494696,-113.03587,-179.562511,-237.850209,-213.648788,-184.872363,-164.531092,-34.950465,37.375152,51.108972,-40.837633,-67.64958,-156.833626,-211.71342,-185.309527,-115.281464,-46.917882,-80.720885,-199.396701,-266.103392,-293.773816,-344.600602,-326.135085,-206.89624,-149.994515,-80.939513,-77.748319,-114.263941,-255.390475,-311.556418,-305.542942,-284.894346,-312.906262,-342.202321,-323.268442,-223.55207,-199.984618,-140.653136,-82.224492,-16.917305,-22.37825,-81.743465,-138.862249,-124.745024,-49.250996,-13.188413,38.761455,58.095957,121.689836,145.294628,107.736013,-0.70455,-59.777854,-112.535467,-109.680859,-106.738002,-75.483338,79.472007,97.586177,7.539196,-146.338595,-98.132456,131.705128,186.766655,179.02323,159.03507,119.860695,148.786648,157.349013,99.6343,87.21055,152.453531,175.58398,121.308598,92.602931,109.495188,26.025761,-76.250916,-156.588428,-103.902165,40.081921,91.707577,84.565864,-50.254651,-98.921153,-26.908358,79.1248,231.325493,251.989627,256.243375,208.529005,170.23468,97.208987,76.40493,131.970265,190.789104,210.910273,149.047875,19.384873,-15.730706,-48.513097,-133.518455,-130.468416,-20.569627,49.156313,149.277805,152.27262,94.516678,-104.77449,-154.10726,8.281938,141.032855,217.891072,155.16475,32.821258,6.337158,-16.067139,-22.198235,16.221148,80.489447,98.346583,122.72305,81.525831,48.89186,-13.462766,-31.420606,69.041529,183.670787,349.01889,350.145724,221.068686,67.162988,31.359065,83.563113,158.495866,319.357655,371.279565,351.150449,162.774417,74.101037,35.9746,62.554443,99.867068,104.648701,127.676006,151.593904,198.949419,205.344691,206.723636,220.320313,192.619386,96.215567,89.512527,124.755496,114.252777,87.574813,-64.385955,-138.09886,-82.204627,-8.935783,-3.175117,-36.168868,-1.063023,45.405302,0.219301,-96.005968,-65.172233,55.479998,79.186398,94.68125,119.092344,125.901518,104.838923,86.215158,21.719955,-45.062306,-88.758517,0.811757,213.061603,156.602997,93.947983,106.142465,143.302681,174.679331,189.651077,211.25328,41.832381,-78.136641,-136.107774,-93.296351,-74.873603,-83.180176,10.899371,67.327804,31.767154,-96.795883,-126.452516,-48.37718,36.782058,146.166178,167.875507,263.862772,427.669151,480.431247,461.086764,412.097349,364.014589,389.339227,453.79006,433.689791,220.21706,-63.143395,-140.00337,-149.40496,-128.356983,-128.717531,-139.713652,-107.559625,-65.431471,-75.401725,-104.208942,-113.590051,-156.104353,-191.381216,-279.412188,-315.384192:271.062415,157.633427,130.111754,106.643867,133.993716,206.260924,244.150622,381.802128,477.645429,481.212961,403.082479,329.036059,238.712402,238.262982,273.311818,289.320883,211.750206,60.499398,32.144575,79.987991,143.978046,283.607446,335.353449,388.437279,348.932537,293.81746,182.716923,177.553735,288.400534,350.680188,413.858094,419.574677,346.950913,162.653233,71.347667,34.109046,80.910513,121.797852,106.207576,71.584483,36.392831,31.838492,32.344631,16.030536,-5.375554,11.966786,49.884626,43.40549,-55.188311,-218.349547,-252.134527,-215.886394,-205.720599,-216.121726,-185.358222,-14.677739,108.30453,89.298999,8.697832,18.375266,113.833912,137.108743,100.29168,69.052098,-13.304061,-104.766807,-149.004215,-214.033314,-203.912277,-110.859607,-70.58764,-50.554375,-110.737834,-157.847261,-202.180725,-183.770905,-125.376909,-118.524761,-90.230417,-30.612147,58.238962,-13.284301,-47.808033,-56.780933,-37.252159,22.011851,40.179536,48.266678,4.442979,-41.502268,-117.764831,-114.962636,-20.97062,39.856056,135.6378,175.567436,201.462416,76.525624,-26.56802,-211.15526,-267.859391,-335.782448,-329.16803,-202.299716,-129.546634,-146.894187,-185.144126,-176.375345,-120.746072,-97.318279,-55.096208,-35.615033,-46.249917,-71.84329,-78.99028,-113.217136,-122.00822,-123.215631,-126.245031,-100.064108,-46.147545,-26.087052,-34.330212,-53.250158,-53.36392,-40.956515,16.400143,72.249381,138.932575,5.635129,-112.733132,-237.513307,-178.81835,43.282581,100.68568,50.99323,18.451907,74.51277,172.200847,143.216698,28.157021,9.032119,45.482962,60.201361,37.456595,-45.771884,-88.939739,-48.363704,18.273896,67.351568,65.310527,120.253679,109.962505,43.281087,-133.489021,-190.948994,-141.106241,-66.916741,8.490306,-1.078585,-56.592963,-162.310796,-235.696183,-279.036131,-223.523104,-149.938132,-176.693129,-272.699778,-311.697811,-295.641576,-279.759647,-301.390674,-349.555,-346.238534,-224.007794,-127.876039,-17.918402,-36.190366,-71.909427,-139.800211,-142.462668,-112.431567,-83.84716,37.835954,156.635238,166.838674,40.99994,-51.791733,-94.485687,-42.2285,39.183988,24.757464,-79.426136,-145.913301,-154.275538,-137.231319,-98.530227,6.549529,56.739677,166.720936,233.086958,215.531799,43.292925,-73.707351,-194.45881,-189.089672,-147.410534,-137.616664,-149.195375,-149.967744,-136.227039,-64.913509,-15.873021,26.576762,18.334061,-5.487787,-49.080247,-80.544703,-92.125862,-48.663929,112.795072,180.52591,199.553809,173.667763,105.761995,-23.009282,-107.945772,-209.948048,-206.098057,-136.667017,-77.041532,77.21451,128.040302,72.577423,-62.581789,-60.520792,41.258949,71.473663,104.581867,124.442207,110.418215,59.898502,29.133195,-35.737122,-35.352801,26.159895,53.620604,104.288896,156.329857,133.953479,-53.601198,-152.368693,-159.421029,-74.050809,102.489625,144.027706,130.636022,119.079932,127.646356,157.84423,176.785159,196.034437,215.754167,278.965592,274.866196,249.478474,202.533931,178.901378,140.041074,136.896279,181.870968,211.258296,163.399722,2.902237,-69.978575,-163.797078,-151.498516,-1.996582,78.71149,149.311607,111.522222,69.715993,-70.656414,-142.09372,-138.841581,-74.113632,40.333652,63.499492,36.020156,-75.434169,-145.241541,-163.294293,-100.732902,-15.392864,-6.233101,31.475384,74.187505,73.057931,19.478131,9.35355,156.909114,272.858698,357.03889,333.362139,294.189068,193.951168,100.405818,5.915692,73.54754,312.258118,385.461352,395.518199,284.721451,217.282574,115.953852,88.191172,50.990473,38.94038,125.853955,210.126858,238.090111,122.966522,87.630552,57.158144,57.668644,85.985245,99.642258,68.595215,-17.84897,-39.532578,-81.785293,-120.153931,-170.590168,-184.88668,-175.672997,-119.867051,-3.528859,-32.309824,-88.212926,-238.036644,-287.522402,-229.308068,-126.827839,93.706352,142.937403,111.044449,1.421413,-69.443323,-168.075326,-175.502731,-110.228114,-37.345605,93.392381,41.00737,-32.625833,-110.47957,-75.239513,85.336754,145.324468,134.173664,-13.409877,-84.651241,-151.867959,-186.730839,-300.165326,-315.598924,-162.081671,-66.251241,-74.382365,-184.048396,-179.165842,-74.828396,-5.762065,122.358212,175.282372,271.789001,343.356676,349.318747,307.288653,288.629746,341.837287,409.352038,497.287173,484.644785,334.80952,99.883517,-1.776937,-144.125321,-171.76398,-138.172702,-97.778959,-25.128818,-45.972275,-94.244144,-185.116074,-194.009636,-176.539833,-197.715517,-260.014495,-250.897853:301.15123,166.892654,122.57521,70.816429,108.033405,288.016772,368.759187,430.995465,364.955131,313.840713,223.497872,200.188714,203.937463,203.450221,238.486025,270.658289,166.95645,-97.320381,-182.928926,-185.777159,-110.786826,83.679998,160.846703,255.398122,270.617416,236.579491,110.230699,77.703489,158.564626,236.117739,334.964758,334.924911,281.99798,170.42996,90.744078,34.454116,67.305574,103.950578,107.91574,116.808913,61.748412,39.512493,16.334788,-8.97716,-71.585402,-72.38096,21.161367,60.697699,-7.356375,-201.905277,-271.737786,-275.079202,-242.395879,-188.741398,-148.166563,-13.467949,71.884287,65.466324,14.125808,6.042935,81.04752,144.351224,192.466531,143.06275,-25.724049,-103.321116,-117.119471,-133.474337,-119.016301,-11.015963,53.721771,81.551868,28.990546,8.710664,-17.301798,-0.270959,66.623917,77.408611,91.76782,112.67016,125.857881,75.724189,51.798736,66.628557,109.724925,165.276197,133.572692,12.805538,-16.305948,-10.465965,-40.866871,-61.109664,-70.935976,-58.631645,-2.943792,24.878669,20.793894,-92.040518,-164.879858,-224.838218,-200.975325,-176.565195,-181.696523,-116.255493,-84.652786,-131.880601,-184.309128,-125.119939,23.90279,35.877985,26.219809,34.860741,-15.983605,-114.167956,-142.358301,-144.753996,-118.82251,-69.725978,-63.240861,-84.489552,-112.482554,-120.259331,-146.437509,-149.25573,-102.942589,-82.174515,-43.209439,10.025076,117.932604,29.002103,-80.620172,-181.866973,-110.02688,105.97227,143.127916,58.409558,38.061185,74.49591,84.237237,43.778963,-28.63881,-20.308973,85.628144,120.799242,47.418071,-72.696104,-109.319677,-89.971312,-32.223261,104.391429,172.615987,246.262491,132.40289,45.321614,-97.448935,-131.004262,-67.961005,11.560127,132.278583,124.952631,-18.81696,-174.759902,-219.701818,-212.37743,-162.038535,-65.012085,-47.143097,-98.18224,-187.312358,-206.363141,-244.511668,-277.404992,-329.801759,-322.171932,-187.914724,-99.510644,-41.803818,-117.537787,-157.687293,-183.217755,-152.63553,-46.531952,4.943126,77.046766,91.584159,61.450856,-93.025007,-151.885335,-71.968236,3.287069,3.502377,-50.696724,-127.971136,-137.553693,-148.66328,-180.031595,-147.908573,31.22726,124.808298,210.377413,127.826167,45.439191,-148.098952,-222.709061,-227.150276,-175.726529,-60.918308,-29.782187,-74.74149,-128.008269,-106.938091,-14.637108,23.15035,55.289544,57.908502,67.801677,80.997924,60.732253,-21.964129,-34.546253,62.742351,137.367465,236.718051,243.261558,181.271483,51.632044,-27.173041,-79.307615,-51.567887,-36.23173,-21.823054,119.097525,152.107039,70.536455,-89.851219,-86.335986,68.506641,162.226189,269.210614,252.246819,131.346997,64.440451,50.15662,39.266296,59.62833,104.466251,94.680575,30.834847,4.94376,-6.864324,-93.100212,-142.569911,-161.773291,-128.452085,-14.559103,31.016444,8.247783,-100.662533,-133.864134,-100.881766,-51.108539,33.34769,77.129614,181.307237,148.542029,56.927956,-127.235234,-150.056532,-74.119402,-28.136188,25.87405,20.592823,-53.284443,-151.00547,-198.792098,-240.066622,-206.605989,-43.398794,44.881947,86.235004,-9.384784,-35.367822,-91.931733,-137.884017,-140.128118,-91.247622,-1.951049,10.062229,-66.637275,-206.502297,-260.730875,-235.78913,-158.486514,-58.945219,-51.518939,-21.193659,-28.774833,-56.405128,-100.270366,-89.800747,54.185642,151.51357,272.976332,307.986178,331.110671,190.01552,77.324978,0.155096,104.22615,405.774695,462.755549,327.618962,151.527409,104.759466,35.672321,6.639611,-48.690589,-61.478489,34.079844,108.16471,151.145797,119.331428,112.912713,98.393897,86.582991,102.595401,134.345839,116.601749,-10.442597,-55.16178,-184.578615,-265.249608,-281.729045,-239.86414,-199.227395,-179.355013,-82.252382,-47.786345,-98.025035,-194.686379,-187.298296,-129.731152,-94.100926,-35.166075,-87.49697,-108.200284,-95.005942,-106.317505,-182.940244,-198.820593,-101.478985,-25.75816,42.381291,-0.95286,-22.665041,14.778313,60.647822,157.419586,215.472873,268.42958,118.923621,20.524333,-114.484976,-150.888309,-179.516903,-161.382475,-31.61246,34.997083,8.324077,-148.664399,-194.069922,-125.348812,-27.273397,155.863827,210.958563,270.559158,334.759133,356.278324,329.131506,313.262704,330.490712,346.868711,377.616429,371.907275,225.395195,-45.520351,-149.62077,-201.638333,-187.403472,-190.75857,-185.634982,-99.833741,-79.0215,-133.835463,-247.011555,-251.129329,-169.249655,-134.323975,-144.104753,-175.055696:207.451771,188.121572,139.336509,42.169006,45.174587,48.698855,29.272273,101.916664,309.369821,375.22521,349.451596,285.660881,224.325493,257.939344,361.027061,380.593715,311.922719,193.788612,148.993623,157.191902,233.280894,432.290323,470.221584,336.162593,167.713998,164.142953,230.130346,247.029394,274.098844,305.973639,368.603988,365.68627,285.084258,136.353874,42.087091,-27.291133,22.260315,69.46274,33.185894,1.258681,31.400255,2.143058,-127.736144,-168.307509,-167.576873,-141.304474,-64.763597,-64.345417,-218.053802,-344.928343,-323.528384,-220.804554,-202.013156,-247.063632,-259.678566,-131.513361,45.082639,60.489496,15.749923,12.528871,51.265858,60.282611,19.177057,-21.848225,-111.01051,-148.517959,-168.254258,-253.540096,-275.632522,-208.845655,-149.60898,-98.200676,-177.307224,-233.793505,-308.836639,-298.636134,-181.006279,-135.174127,-138.704695,-144.880553,-115.323291,-103.945607,-92.055994,17.30535,90.473554,151.739731,132.792877,81.459404,61.033981,57.275853,70.969675,85.266383,123.967258,153.177116,237.913238,290.990729,334.055676,202.219029,93.24115,-87.378542,-111.521423,-57.574075,-27.627869,-9.419182,-22.969022,-20.782216,-12.906639,-11.929246,12.756703,20.990097,2.135956,-1.039405,19.547894,5.307767,-37.678535,-149.10987,-159.094234,-85.966299,-50.126959,-0.184654,43.989033,68.031079,94.549021,87.277451,29.560883,-6.739972,29.527517,122.553917,289.315644,273.396609,225.35573,138.063011,129.989326,182.653577,201.676029,181.272512,151.370095,163.579841,236.137521,257.257128,206.68432,160.770853,137.571329,162.622098,157.619256,-20.874751,-121.42006,-167.674116,-105.230336,25.888602,54.12679,80.457573,50.247377,19.334748,-54.802496,-103.134488,-148.607181,-129.26543,-84.350868,-95.630524,-221.616906,-324.856359,-318.417026,-222.731388,-162.803157,-138.526244,-170.938516,-212.315643,-248.682554,-265.036627,-297.031276,-342.132774,-390.736387,-336.249675,-166.043142,-116.313439,-106.302077,-96.224704,-78.283099,-97.321342,-138.796584,-195.954613,-147.550667,143.237251,328.734361,282.08069,30.025779,-77.067577,-94.810198,-46.090938,54.864491,111.846875,164.270182,93.274663,53.381062,27.833227,66.890946,221.484572,289.088387,336.380149,303.401442,280.731053,168.48236,84.515532,6.912324,25.891669,79.275876,101.521774,125.890728,86.967142,58.127867,41.27805,57.823939,30.60685,-36.63911,-117.956408,20.66636,101.182239,134.828868,117.42085,182.27289,261.936829,342.422468,310.685725,177.591314,60.259291,10.866793,-43.394661,-41.364103,-44.440367,-42.947195,49.824719,144.659907,127.368801,-25.963983,-117.472958,-207.044848,-190.921863,-88.750889,-48.280888,-51.663429,-76.934339,-96.96987,-207.348493,-259.116535,-231.296373,-159.798221,5.736127,97.735333,67.914815,-138.940792,-223.897538,-147.917347,-18.244892,188.320018,208.783702,174.280255,255.831401,303.999314,255.870858,194.153745,164.645055,203.577551,290.309441,321.230074,321.688856,273.422406,213.240837,74.998456,34.587659,61.279681,100.694291,72.719602,-141.965956,-257.630169,-342.720562,-301.536596,-221.641427,-227.485277,-268.896176,-291.055344,-273.789423,-201.703084,-188.223913,-177.597712,-141.945767,-12.771362,35.351183,-10.534803,-189.02823,-270.944077,-285.216273,-215.658771,-86.70603,-55.985714,-27.091548,4.581541,47.825409,129.639986,136.184677,183.937747,238.965743,312.256042,329.299646,330.903213,242.211488,158.337172,29.26595,54.607875,188.047707,213.388224,173.484182,76.106084,31.793658,18.361586,44.301145,48.873627,14.359709,8.60929,40.818771,30.431162,-25.095881,-30.265251,-59.292822,-112.762697,-277.636744,-328.420471,-262.383301,-136.759416,-117.871472,-168.698276,-196.982414,-162.847398,-125.384886,-56.807366,0.237501,112.892173,55.762296,-38.770525,-219.370683,-243.806101,-159.613903,-90.812107,18.82012,12.277202,-8.837019,-16.841726,-23.151463,-86.193855,-121.795855,-73.810723,29.188548,252.163655,235.386132,120.368131,-83.620983,-81.751037,89.72561,171.689425,175.797062,-10.164623,-117.809781,-259.100949,-277.972683,-248.861913,-215.195829,-104.23407,-61.198243,-95.58991,-146.185407,-143.123143,-142.197241,-117.707052,21.280409,81.134775,88.69527,45.480948,60.180069,113.474922,117.321384,191.972983,296.239362,473.242035,473.225446,303.340236,50.763868,-63.91476,-218.107462,-233.237087,-151.507765,-98.089075,-86.664073,-212.166162,-252.100559,-216.959195,-176.07038,-131.011961,-142.323909,-164.276293,-144.577027:282.229589,219.189087,161.704873,71.859785,86.798161,184.809683,223.874122,267.121105,255.942804,221.222053,137.061785,130.781719,200.134978,226.213869,231.453826,219.608286,87.884298,-148.480592,-222.401432,-170.380742,-52.996758,183.502555,232.15557,206.289662,134.94358,103.089048,45.171587,57.968431,220.316734,302.182182,335.63001,306.110785,224.703934,96.445574,0.927547,-137.653827,-121.291928,10.568261,47.635817,2.56118,-61.811014,-69.481604,-91.135943,-107.649635,-100.143621,-70.991267,5.316267,19.669332,-85.220373,-248.203957,-265.401551,-194.172498,-169.876132,-157.321875,-114.074884,28.492066,57.0542,26.638174,-34.825915,-50.217837,-28.023621,5.162648,31.621093,-2.718235,-105.894979,-116.83235,-95.579776,-63.637855,-61.229736,-33.315709,26.044868,161.450969,124.614318,50.031167,-51.712521,-37.96161,67.314828,106.803094,129.905427,130.960573,107.006023,53.02952,33.919314,67.827303,133.304929,261.487658,276.737689,234.348192,178.542794,132.238563,-18.34388,-69.113179,-26.919763,27.483952,117.662904,148.255391,136.885972,47.008295,-11.884065,-128.613483,-140.950669,-58.068652,-10.971386,31.113019,56.729463,65.69476,15.566993,-8.552773,44.553799,95.141124,172.438532,175.794434,68.58544,-75.79033,-127.093173,-174.55079,-162.202842,-113.286084,-93.087759,-53.528554,-36.170139,-27.485424,-14.984651,-28.457721,-73.391178,-77.531595,-4.237667,49.505974,92.865627,20.19984,-37.61103,-32.907261,57.47322,215.897437,207.530659,71.07988,30.880142,66.959063,99.142496,80.934142,52.030482,69.157604,191.795378,244.490898,164.182803,-94.033201,-206.506453,-220.656711,-118.237412,116.588462,195.13557,236.715015,153.614758,89.29276,-88.405398,-153.675315,-85.257382,1.916272,82.818107,69.74742,-3.667656,-98.898261,-146.375383,-167.332012,-125.769715,-56.533954,-51.538008,-63.753318,-152.222732,-210.244162,-289.244061,-315.429293,-336.013124,-305.499326,-168.151851,-119.549191,-117.216984,-134.262399,-154.809159,-212.538468,-218.253865,-147.048152,-63.434952,95.908806,95.117562,72.011881,28.358502,-1.96447,-15.810331,29.999366,164.057316,186.340442,93.50071,-44.569972,-87.497707,-65.467146,6.43435,181.482931,239.556689,261.007943,189.98667,143.915925,57.634806,3.790402,-77.468201,-53.024529,112.806632,184.681695,161.255162,5.985104,-48.735367,-43.364426,0.312083,58.250124,56.575932,46.989112,62.108847,68.777135,82.47592,93.877404,133.250312,174.020471,308.220486,347.502618,230.051533,13.552521,-42.627152,-24.070422,5.574971,3.879969,2.852617,97.231659,172.848182,128.432536,-66.749575,-107.179991,22.970937,109.409228,187.624581,184.598986,115.309799,37.843628,2.157326,-118.855025,-175.537617,-155.467088,-82.711069,63.975487,71.877341,-11.543661,-287.280647,-368.188698,-237.253789,-102.836153,47.114302,50.192296,6.284774,27.535425,50.546865,55.431045,50.266815,82.679393,128.779976,192.787481,110.609811,45.884704,-61.665755,-90.005254,-82.052001,-62.271427,7.104781,41.837511,-1.918676,-212.670755,-329.443749,-431.52657,-386.455911,-204.513024,-128.883805,-99.967835,-195.142574,-239.719888,-334.927177,-374.772015,-323.745103,-248.080816,-108.084679,-66.333118,-112.774987,-317.373732,-410.949342,-418.540173,-337.670505,-168.415286,-116.483805,-81.462176,-80.205236,-70.277506,-74.090921,-76.572258,13.639394,78.810083,132.074558,136.975426,135.621158,59.430357,11.516763,9.96897,83.324474,273.082356,315.176952,260.265695,119.743598,58.525518,-37.320731,-80.587852,-112.579674,-80.034245,88.153947,162.714513,111.701082,-25.536913,-31.532868,-11.142155,-34.999447,-87.653201,-77.73667,-85.491757,-203.875503,-248.58071,-318.534501,-362.9787,-381.947821,-330.374282,-162.753659,-90.079784,-46.543179,-116.603224,-179.818891,-303.410802,-321.013778,-266.996338,-202.549307,-14.771262,42.874968,-16.790025,-174.753191,-215.266355,-183.870243,-141.569307,-47.675728,18.161128,159.636091,127.488499,41.534102,-40.32581,9.053845,149.286023,188.435312,203.020522,87.50131,-20.819193,-219.540878,-261.382677,-212.64451,-143.664578,41.05927,109.682171,43.226318,-191.938821,-267.69014,-211.311721,-102.556459,107.32796,175.610496,267.917591,274.074477,231.749031,149.999427,152.341631,242.855858,312.747085,427.931088,426.66121,234.866115,-76.248926,-192.698911,-268.527106,-247.361026,-194.981803,-165.335587,-96.90907,-129.240604,-185.26238,-294.592697,-307.519722,-221.081053,-171.110675,-156.192461,-169.271166:-51.56049,-25.323999,-0.601644,-61.779655,-108.948369,-137.851565,-140.095309,-119.916979,10.888328,87.893316,161.087993,151.204979,101.69484,83.807862,89.058676,106.027286,84.22691,-3.769462,-32.043022,-45.517335,-21.244499,80.933627,100.167794,17.811062,8.560698,61.570595,108.810212,86.788554,79.391505,113.912398,195.887479,217.864804,189.477032,65.431825,-5.869425,-73.950102,-47.816662,5.115689,-14.895298,-57.727975,-18.687083,-0.405859,-23.405769,-56.131336,-124.328979,-145.951414,-114.551377,-72.684794,-84.458583,-187.557577,-201.652788,-163.15998,-152.332318,-202.040745,-212.50156,-103.223496,80.41368,149.002505,147.251151,92.330916,55.953194,88.2958,126.864749,113.148539,37.058727,4.336587,17.383931,11.40003,2.503141,8.170186,5.671966,-13.186581,-64.959002,-124.021961,-293.093164,-341.843492,-255.608358,-190.696412,-177.688214,-188.973765,-173.485686,-145.73144,-127.24757,-68.137627,-16.664138,88.590846,108.032559,104.558259,119.452745,126.244006,119.252294,124.079547,207.644674,266.175182,347.587322,368.805661,362.036118,316.649903,293.728406,261.820712,255.063909,220.518186,188.017394,121.955563,95.238013,110.19473,130.009012,113.934726,86.208655,78.084825,65.163255,67.422593,62.372338,67.374562,62.231826,-16.395695,-47.617147,-6.779356,42.492284,124.238509,179.31012,238.116364,397.684653,429.865468,328.139189,239.911294,191.036879,250.384962,337.224859,312.932032,310.984837,312.05346,299.908612,276.71594,275.55569,287.645707,280.176455,277.707158,258.892958,207.791828,53.98081,-4.13667,-67.34009,-70.066533,-31.740844,-23.164119,-53.096912,-132.408035,-120.083487,-13.988312,13.125283,23.9962,71.826588,94.229719,60.233558,10.428948,-41.036637,-28.48763,3.550053,2.174324,-50.333376,-95.967646,-92.061721,-54.284634,-33.750292,-1.122829,16.636027,31.536752,-17.044518,-37.39298,-91.84139,-160.330897,-247.666948,-203.309528,-53.750908,-24.575095,-44.986373,-6.0943,34.642002,65.264851,64.982927,98.87139,141.449717,285.416783,371.672544,341.159481,209.461476,165.615674,193.66223,250.984681,372.159402,402.8852,352.907017,236.552518,199.325396,204.700206,253.424685,365.63722,380.474132,334.566035,300.260097,293.946755,258.677174,236.503205,210.148274,199.834229,208.732632,241.27109,274.010307,207.570143,170.672259,125.40926,113.620607,60.208611,15.467789,-25.616013,50.439608,104.778013,129.020989,91.888934,67.523726,115.131111,235.576148,244.949429,120.022371,15.968677,19.31987,30.773694,4.003604,-51.828824,-40.618076,38.483055,124.611892,160.117845,138.781309,87.085661,-8.204022,-56.611704,-173.598476,-197.391981,-133.468548,-81.757045,-115.359027,-256.156959,-296.562886,-218.66094,-129.666851,10.048916,59.203591,58.719767,-17.018588,-65.626763,-15.900087,67.966785,172.714832,198.583058,264.303445,295.322537,281.889761,206.47149,158.133885,75.450251,70.497452,152.789319,226.460536,226.02719,126.276113,37.251812,-112.667095,-139.37756,-55.600558,23.426389,70.037645,-90.054024,-182.662346,-259.53552,-240.943983,-223.705345,-247.773979,-228.555569,-160.723963,-174.024795,-251.904127,-276.633851,-239.167558,-172.115085,-32.549262,-11.982268,-65.162554,-127.379928,-137.046533,-92.819585,-66.686545,-75.894928,-80.65811,-36.774728,18.182339,64.117569,158.901839,159.089005,103.210105,95.272544,133.975666,162.344269,179.982853,107.110586,41.88969,-37.711868,-12.917426,56.996213,76.127856,135.302174,93.9946,30.693654,-59.350892,-84.387656,-121.942699,-128.816209,-101.074535,-74.87311,-61.40513,-132.736084,-182.9069,-284.99674,-330.326041,-381.175394,-374.474488,-291.481302,-215.759205,-188.773862,-121.845978,-115.06714,-156.227786,-161.470753,-105.28192,-53.38709,23.695319,-56.115875,-159.027861,-327.221322,-319.100907,-144.606109,-38.838636,99.432277,113.962897,102.107535,63.320832,26.675186,-47.061553,-48.8245,72.074206,163.831353,209.040985,30.28977,-71.666156,-182.752505,-160.151303,-11.442935,56.191735,109.774705,1.214972,-92.567324,-245.958082,-290.608587,-297.798152,-259.850625,-164.543996,-150.772127,-217.506499,-220.212843,-165.258891,-45.67976,1.146633,51.03105,37.332974,-7.827012,15.176326,39.288204,89.555736,133.776832,257.406379,296.205555,309.596614,302.232041,240.592931,100.973167,11.391468,-132.81911,-139.23959,-33.042552,24.030845,47.106103,-41.919059,-68.596729,-21.56271,25.229157,89.276049,76.601885,-7.071768,-9.004264:139.725063,166.624864,138.297979,25.778631,-14.108965,-114.921039,-166.325455,-99.426983,96.189558,160.273238,259.369538,285.209019,211.19122,155.850635,180.91858,259.434555,351.927348,256.768649,203.999498,181.191039,213.65048,308.88235,320.869046,245.969382,171.556549,182.502827,262.947931,276.33433,223.918987,215.061544,315.27101,369.241359,332.661263,202.267824,157.60785,114.968225,100.151961,7.65778,-45.060185,-13.466838,54.96123,31.819409,-77.006525,-117.092315,-88.351363,-45.452048,-13.193295,-26.166727,-80.37165,-145.183863,-169.135187,-190.101132,-191.641046,-206.859539,-193.191195,-43.947236,88.348922,90.667509,32.114655,7.924086,20.788798,32.444108,4.359381,-21.336182,-92.109678,-146.545395,-179.448793,-331.565619,-388.635083,-333.785736,-276.613755,-243.635708,-333.699107,-413.39107,-510.446756,-476.110565,-330.614137,-290.705384,-292.460627,-303.655653,-292.525821,-210.507118,-182.382522,-185.98982,-182.368306,-154.311274,-135.260725,-86.26582,-124.071252,-171.111195,-201.07994,-157.12818,16.351125,115.24282,283.959405,315.18483,205.312469,66.161759,36.677511,-28.403894,-59.255323,-54.295084,-31.282612,-28.225571,-83.613721,-68.149839,21.873981,35.157225,7.207846,-3.510734,23.31139,64.880038,127.411057,99.15195,57.071169,-75.576758,-129.275442,-108.475604,-28.344167,133.012768,182.691478,231.635653,358.82624,361.579382,256.096167,195.472418,170.130849,228.186185,340.30358,326.240634,318.136387,271.335444,197.98253,79.327373,98.417084,197.218519,166.948384,130.324632,122.007146,130.897799,106.105321,67.722015,-36.895255,-72.797925,-96.734747,-178.149938,-237.10197,-262.415625,-224.217922,-167.928232,-168.896579,-150.106498,-81.215513,-65.274873,-102.728843,-129.658424,-155.182556,-170.32872,-199.356614,-206.841662,-268.223294,-353.44865,-376.631185,-380.235357,-353.237119,-300.792116,-298.18908,-288.723853,-264.00105,-259.669758,-327.362737,-394.538469,-422.479364,-348.429328,-135.240418,-60.442322,-43.980923,-105.034614,-122.232419,-124.854925,-119.430838,-110.365434,-73.488745,84.669129,108.997619,63.52307,-40.53388,-79.355826,-65.603047,-41.065578,-44.483934,-49.137949,-50.603912,-63.972319,-67.952633,-97.209797,-107.954758,-74.448801,-44.579612,-33.469865,-48.142899,-29.162841,-19.842686,-48.205922,-65.960794,-54.615443,-75.348337,-88.766287,-64.321451,-23.08189,-13.872119,-1.943798,0.973804,-74.469626,-150.987913,-223.973761,-115.063753,-37.623414,33.544939,9.148663,-57.259674,-64.680463,-51.993333,-45.426111,-60.589699,-129.435737,-176.578926,-275.603934,-317.420832,-326.745313,-280.618465,-176.005782,-162.486349,-166.808467,-196.153274,-232.569594,-260.573819,-249.184027,-267.538821,-286.889931,-258.484626,-209.8512,-242.72801,-379.007507,-424.351829,-411.05982,-348.203942,-142.678958,16.782224,26.2948,-69.396007,-112.515915,-93.326653,-51.217693,93.549841,191.946619,306.176272,308.386076,283.217904,175.772992,125.762182,106.93753,140.365579,239.064523,291.921554,286.34603,157.252847,38.434089,-140.11255,-149.176583,-43.819154,15.371277,-20.136759,-230.660696,-306.314513,-330.676076,-320.797257,-358.394183,-379.097902,-319.971606,-256.127579,-247.3175,-182.792499,-137.827831,-83.829691,-51.978654,38.165729,56.142519,25.264217,-11.723072,-36.617667,-61.647227,-25.993969,100.709537,147.578319,151.756466,88.789233,92.557642,150.716432,150.863961,144.667378,185.469892,336.709045,411.404378,426.714475,247.307713,135.904836,5.80158,25.234766,144.973994,196.842085,216.806801,118.898269,100.562278,131.356672,120.561599,96.433609,113.105394,155.584124,174.690435,175.008539,75.705248,3.690778,-169.0138,-245.261075,-280.485432,-230.012756,-107.204065,-62.112296,-26.553215,95.491011,141.93763,156.810121,134.140174,102.66237,122.489031,218.831042,226.052381,150.160524,-11.870793,-16.320362,86.577868,119.775211,124.039122,124.880952,138.392977,175.704351,171.078103,101.581186,65.4475,91.60572,147.445863,180.849467,36.299902,-54.910733,-150.463831,-134.67205,-58.673984,-34.0221,0.558324,-34.430536,-80.112286,-125.929076,-137.810196,-207.513005,-225.471575,-114.387856,-35.969804,-7.287172,-36.717341,-15.227196,32.872056,30.419692,-23.541751,-35.898158,63.808066,170.293589,176.639075,145.088583,130.649695,162.861611,219.627334,333.545555,338.663995,267.375493,224.804396,180.619053,-26.024265,-127.545716,-209.948318,-190.500802,-72.04978,-51.891245,-105.555583,-200.932592,-204.842076,-143.761753,-118.060694,-146.742686,-164.609291:1.826168,19.680595,12.107568,-14.739095,-2.326159,20.820857,15.024125,33.785593,70.214115,81.186836,136.003325,169.181656,180.333612,165.390107,150.566196,140.857572,52.900464,-99.994982,-158.358304,-175.997761,-109.183806,87.161675,115.132506,-10.053105,-109.608171,-91.004322,-5.231168,35.612457,118.889533,141.517707,158.879585,157.721126,55.293639,-93.511811,-133.918874,-150.307822,-123.165883,-59.805116,-60.036526,-100.18925,-138.164607,-146.644698,-152.229892,-145.272726,-84.563108,-56.245597,-58.818954,-78.601327,-119.734213,-147.426907,-158.228498,-213.819578,-254.256357,-315.006627,-304.551529,-129.081277,75.346332,95.409447,-11.528209,-66.800703,-56.674753,-12.083783,29.693915,-10.866359,-171.117082,-141.260853,-26.523264,145.400593,152.676691,82.978778,42.02846,31.409819,80.406153,63.916554,-75.422082,-137.774362,-130.905198,-103.736084,-86.305156,-68.659339,-40.440257,-56.724626,-45.838032,46.232968,102.639514,152.599347,159.350724,183.344835,173.443229,143.165987,42.828913,13.082284,94.46885,151.418991,145.867451,133.996648,175.264902,198.009096,189.026063,125.817546,95.305846,93.344164,99.855714,40.738471,-4.483509,31.151834,95.219148,84.741988,64.343678,85.511481,113.170983,71.249879,-65.478914,-60.323597,-54.627431,-174.881051,-222.651314,-186.101771,-143.210419,-64.505402,14.243135,46.98103,29.08176,-14.233845,-34.841242,7.081391,67.050261,72.270576,156.643542,270.484776,262.977734,155.404135,139.940892,210.119341,217.365033,151.761156,151.76726,200.956004,284.374268,242.826956,26.378379,-41.324146,10.6786,52.314117,6.398059,-70.792349,-81.609507,-95.901958,-78.352386,44.042718,107.90295,144.600616,39.110698,-29.475279,-111.63003,-112.298738,-21.136155,30.525172,37.182871,19.834297,-2.971505,-83.192944,-129.779247,-134.12716,-86.527279,14.645913,24.129009,-67.958005,-169.624309,-165.20525,-147.008945,-187.712224,-258.504316,-231.748048,-152.374326,-138.050536,-86.09053,-43.812511,-73.386023,-181.909882,-216.201733,-201.354166,-137.495656,90.70558,213.790464,184.198958,36.006162,-18.012836,-4.632647,34.210822,112.474068,151.117938,179.365442,98.035386,52.757656,73.036265,149.413624,300.862855,316.840128,219.860764,85.564293,66.089333,87.278703,86.718559,62.161666,51.31325,58.038754,83.030899,123.760796,77.662827,38.634739,-6.128338,-5.341679,-31.781123,-59.698297,-23.789282,78.96869,86.45886,18.305638,-6.541282,54.467806,116.517192,202.896231,219.661147,170.179126,23.733741,-8.945379,54.235482,63.8952,-35.738882,-45.457738,94.841573,136.409121,102.66668,52.7511,34.352268,2.877351,1.148835,-10.163326,-40.135446,-100.789545,-42.837106,-9.250645,-107.900582,-208.081994,-248.775097,-145.107522,96.703539,60.913852,-32.38953,-162.054518,-151.865521,-2.434533,76.164199,157.648274,182.919145,210.837887,201.402595,215.282077,259.288235,230.292592,67.5071,33.510129,156.938344,242.215059,189.835554,-13.968256,-92.128173,-81.773671,-8.267733,99.060493,88.427559,15.473054,-93.039584,-183.849408,-309.052451,-284.936327,-174.394857,-164.801212,-190.254356,-130.184674,-79.455055,-100.708722,-195.889881,-304.425274,-233.476631,-14.061555,13.909513,-116.479498,-189.053033,-161.736386,-87.679854,-56.232814,-40.84146,-54.64468,-24.420921,55.983768,82.100191,123.553795,135.867643,153.937405,163.633149,174.175348,187.767894,184.918255,120.958653,81.657726,-19.305758,-31.994508,66.242743,131.555638,219.470057,196.112215,147.438386,15.678042,-60.178022,-177.615539,-201.254648,-153.978612,-87.538567,26.682897,4.55575,-42.784853,-125.793356,-140.576604,-130.827857,-141.493757,-210.178188,-229.170143,-205.105366,-148.605592,-141.150946,-158.590793,-157.246684,-102.343477,-49.853776,28.915104,-33.196284,-105.568764,-226.592291,-242.501395,-183.201805,-112.462134,59.349777,122.655836,124.737662,79.052939,0.571102,-151.741877,-141.022968,81.309848,208.835924,296.511968,222.565138,156.46878,-4.51345,-43.252123,32.886434,90.427489,127.160759,79.073429,24.510185,-111.716411,-139.7901,-43.459817,28.620639,105.579906,103.19635,-6.272583,-144.25016,-151.958722,-72.691852,-19.405132,100.579233,146.105242,167.492056,163.204742,162.598722,150.10735,164.15195,283.214155,358.63451,453.04608,434.102357,187.543141,-51.870601,-72.687361,-78.49402,-89.754602,-64.485414,-25.504844,56.324046,-7.668166,-79.507673,-140.489635,-114.540954,-42.541359,-40.914373,-50.348463,-16.937408:forward
82.126357,83.260435,62.47359,1.371942,19.572034,174.27482,235.647193,172.854465,-11.041761,-56.308939,-30.222722,-16.31285,-43.726114,-43.360012,20.389587,38.204416,-15.13249,-51.008237,-26.770508,-6.670582,-22.911509,-24.40925,-3.85543,104.943578,217.190902,195.722221,82.796211,57.560456,64.855537,69.134244,75.237119,103.234629,196.584441,211.893612,189.291711,84.77264,6.297893,-72.639625,-37.004147,100.840726,104.973297,25.703947,-158.749303,-214.036763,-206.955467,-129.011877,113.179651,222.429481,347.75176,308.622386,227.814271,29.713213,-34.053738,1.399434,75.023514,175.47292,149.721354,115.268092,29.437796,-32.82449,-167.626965,-206.231325,-204.113646,-174.149038,-126.039486,-197.49603,-260.901762,-352.962958,-363.247037,-325.698827,-305.174426,-291.507722,-268.198465,-248.881992,-234.326427,-244.727025,-219.517479,-158.001355,-67.827876,-84.993605,-107.676613,-69.618101,-96.501667,-225.261059,-264.100167,-235.636917,-204.92037,-114.983844,34.20953,63.328254,58.046225,65.021428,23.292708,-23.873571,1.54978,76.313547,128.819095,19.437343,-5.646758,-17.654935,-49.656319,-91.28694,-69.628689,8.316293,81.189369,102.933775,83.789294,33.162686,-104.222899,-138.953969,-99.592351,-59.804907,23.939143,101.651084,114.282265,76.615281,42.430294,61.040981,133.879127,286.128111,300.941932,272.194784,270.236612,273.10471,191.006445,154.595753,228.787987,320.009354,377.017955,171.334418,89.312175,38.204096,6.919199,-74.727044,-97.222554,-81.824219,-30.536659,-52.79452,-188.927729,-240.338516,-235.045074,-188.71424,-29.404456,82.215048,263.859436,244.397544,217.151445,183.684142,124.764249,-84.03707,-170.843635,-170.064696,-60.391253,-53.992457,-120.552164,-158.951007,-223.177399,-232.867697,-202.948597,-175.95005,-100.644608,-16.153668,22.221578,39.049596,11.274167,-39.247807,-28.784,81.251686,164.271754,151.622771,56.93157,-5.647135,-108.921812,-123.871499,-80.488432,-35.626196,103.7344,159.867519,120.027193,47.890219,28.335644,-11.062537,10.4478,173.126186,300.023669,280.690297,152.387363,124.15489,218.041106,293.161706,320.732045,261.41613,127.930929,72.474523,74.697899,82.879372,59.162041,1.824047,24.432983,173.542278,205.832693,149.342183,85.07392,86.812437,37.586083,-3.11652,-69.844463,-85.24558,-7.938555,122.233239,145.014212,103.336719,53.499019,-9.222395,16.092667,110.690644,120.013552,86.257529,-10.072321,-64.19496,-141.929861,-130.718224,-21.381485,27.641996,49.270564,16.134498,14.496435,-1.5589,-60.665436,-228.944793,-275.412253,-235.649562,-108.517941,-61.205562,-34.722398,-56.674485,-163.462686,-204.264868,-185.750106,-145.651904,-20.270219,91.536212,95.292998,29.598355,-1.350879,-10.989247,9.180831,51.669554,-13.171764,-87.724066,-190.86631,-203.567492,-190.820222,-161.240305,-99.593774,-105.231399,-163.354217,-174.666176,-176.61197,-256.357123,-316.904432,-379.59533,-385.891705,-359.500233,-265.749977,-232.012655,-221.864368,-233.167596,-276.170922,-298.420634,-307.026166,-272.141437,-149.025643,-89.004548,-91.247518,-159.942245,-209.388691,-253.397555,-261.447525,-258.233813,-153.181079,-84.193391,17.35903,25.94701,-20.815363,-11.906111,72.793731,85.912182,71.343913,86.057587,67.558671,-68.684196,-120.159331,-29.314052,59.109901,148.423497,159.806946,172.958078,275.30311,329.912456,304.224053,249.876918,202.985312,190.794767,103.440478,43.740699,60.00271,112.871911,91.30455,7.532483,5.253544,58.494015,99.755509,88.530204,-38.560811,-122.554218,-193.240995,-165.554794,-33.005937,46.990754,135.42523,62.250962,4.515187,-96.350392,-152.973873,-206.17004,-146.750934,57.202127,40.139988,-54.080732,-175.133727,-165.850495,-96.805516,-70.013364,-52.872778,-60.000292,-86.591896,-133.54697,-159.173955,-211.922144,-219.860509,-107.223341,-16.971737,50.39727,8.220037,7.779867,93.384643,145.929111,152.743289,112.319865,48.406838,49.295192,90.670179,138.525239,174.309974,179.401786,115.131289,74.360786,174.491643,388.484799,329.589037,241.145,139.856804,131.886623,93.792821,49.208533,-18.319257,-2.423529,93.514464,80.196341,33.702685,-35.31749,-52.305087,-114.612456,-184.039676,-306.094989,-309.431001,-297.377203,-225.537834,-159.37897,-39.134399,-0.261582,47.227653,74.454828,138.450841,85.624334,36.605121,14.80663,7.318391,-43.426499,-58.113859,-32.740327,-7.205536,-46.437007,-201.043454,-244.204733,-113.173092,21.316098,161.590028,140.513816:115.704193,157.222863,106.598692,-52.646747,-55.429249,114.446467,197.998041,211.125806,122.53749,96.35108,3.023486,-91.608348,-232.045086,-226.888165,-90.343146,8.382065,149.504835,182.465069,174.743595,68.717625,-6.331778,-40.783897,4.407524,104.762478,50.507294,-29.128368,-78.74605,-18.848722,133.168094,162.473932,127.255407,136.824242,239.431709,232.088325,206.957827,133.896901,44.101762,-104.784289,-66.959138,166.156274,206.697753,128.595907,-22.061232,-75.98245,-144.589862,-117.277984,71.346663,166.904486,216.670717,130.917123,73.535832,-65.636278,-99.101634,26.104727,138.194551,239.967841,95.013977,11.371724,-30.901571,-44.473767,-172.996004,-230.939562,-214.265197,-179.300962,-193.510884,-278.187649,-298.387296,-317.672409,-336.996898,-378.685028,-389.238273,-358.475923,-283.25572,-270.658252,-307.762699,-330.699814,-308.897643,-257.743602,-157.651633,-129.034662,-86.877513,-112.946019,-167.207654,-273.144085,-287.381007,-278.769469,-271.120212,-169.649452,25.019296,75.65605,38.6524,3.951279,-6.462232,25.759662,137.540526,186.139466,199.251546,117.279195,88.098598,82.056593,72.239288,36.609898,37.139549,66.438894,102.212744,123.040887,96.891612,26.800714,-99.38083,-81.570612,57.954105,98.618858,83.529842,87.762407,104.225459,87.298255,58.747571,70.220314,131.059015,287.7995,310.76307,247.800451,119.30101,103.266284,129.229975,144.694993,194.279697,252.804133,374.6097,249.259134,131.334288,-11.007352,-44.596247,-114.27419,-145.660305,-123.44629,-38.409645,-38.794014,-108.549829,-133.286436,-94.647309,-49.545272,62.274372,154.425127,273.129587,71.593086,-27.671346,1.10908,61.352121,37.48552,-33.721271,-53.274539,-13.380531,-79.387583,-242.040822,-246.240119,-123.587241,-39.179848,93.147981,104.264411,68.160125,145.328051,197.7994,149.00332,92.298319,135.350972,213.431031,293.327943,258.150022,240.714805,218.656535,190.332974,116.365126,100.413134,85.315679,93.500818,206.156805,250.404788,205.23081,122.432048,94.144183,65.521516,115.270552,315.000636,353.269192,289.345422,175.464998,159.717626,227.15295,289.215857,288.025536,220.380916,146.641934,119.537424,72.055996,20.426291,43.743095,84.986931,95.025331,162.797122,152.56739,80.369842,-15.806938,2.049476,68.804108,80.903658,34.662481,-0.119337,-14.20633,-23.360188,-26.035331,-2.576791,2.883773,22.534964,49.239776,116.029196,199.999872,218.588044,125.978043,34.119673,-112.954826,-138.738237,-117.311462,-98.750202,-87.494193,-59.535703,-17.074578,37.755815,-6.989303,-185.508384,-221.671094,-106.417461,-23.81259,-46.20405,-110.157076,-138.165112,-207.504671,-223.641941,-182.1847,-132.813138,-12.57951,-13.090256,-63.744412,-139.791735,-148.340221,-114.18931,-73.997524,-10.216487,-84.80026,-137.433266,-111.884798,-73.795074,-96.593125,-127.43357,-128.318441,-104.399969,-53.114004,-33.910811,-48.067163,-198.067255,-318.380149,-425.836173,-390.682274,-315.349514,-314.302841,-311.758047,-287.709426,-298.581777,-348.237702,-349.821016,-340.710748,-330.475082,-245.40861,-197.860144,-226.620444,-333.145527,-362.378992,-335.587671,-309.165864,-225.260834,-134.190232,-121.038066,-80.269091,-54.006534,-85.209253,-117.488843,-81.840328,-5.691984,133.256084,112.081161,64.758872,-29.458284,-47.007392,67.089594,177.634672,311.674749,258.81643,234.740706,240.961909,225.670545,132.23275,96.999773,116.939541,128.904858,70.288676,36.319123,57.414951,77.11851,27.751705,-81.865977,-50.487827,128.63599,145.444439,59.298175,-194.653639,-300.627262,-361.915047,-304.421139,-47.935478,94.606452,174.046944,-17.29476,-75.276205,-86.110868,-109.423532,-113.869157,-45.241347,85.754783,30.800277,-27.720986,-126.345437,-168.773345,-170.233439,-115.967185,3.001236,37.7287,42.758938,2.656037,-9.185859,-63.636753,-97.779052,-58.664118,6.345561,76.631596,-12.214814,-62.118581,-20.292976,41.349534,70.832608,40.065469,27.228313,77.169641,231.00098,256.827758,192.259968,67.13716,81.713874,209.140863,241.571525,182.223475,100.749231,93.529768,126.173085,132.517335,88.839619,51.333694,-6.217618,-1.004386,60.450233,43.414473,1.368639,-72.921802,-93.633559,-152.306657,-202.789125,-265.931014,-198.624983,-148.539186,-99.538358,-85.439194,-16.924945,25.786147,92.479578,126.057058,178.637261,136.454169,95.993856,63.547168,63.981519,81.155275,121.092826,206.137567,106.230216,-4.179823,-173.258619,-193.438884,-107.1334,-21.241443,122.31538,145.517865:139.726852,90.455718,-12.463643,-196.184882,-191.293173,0.796093,107.710642,164.14703,47.013114,-12.940101,-126.067048,-190.058045,-245.270975,-207.086637,-69.848846,-18.763682,1.622314,-11.030868,-20.081122,-75.614429,-104.27725,-95.268438,-67.413184,-21.601735,-67.343451,-124.319831,-163.11505,-113.698282,25.183606,57.628408,76.783733,127.781479,250.029293,187.288181,128.44195,50.010265,5.213274,-78.090991,-46.516517,169.007995,182.02589,54.46584,-204.43798,-240.138041,-113.015488,-7.799603,138.48625,156.344737,107.611469,26.040453,-17.401152,-100.378317,-104.208567,9.896143,113.09948,252.470174,78.09493,-37.54276,-78.651722,-64.832756,-124.222529,-153.159275,-116.902772,-93.22597,-175.208403,-315.44858,-324.56867,-303.154128,-325.726048,-388.872641,-405.23305,-380.690869,-297.839323,-286.551546,-368.387958,-430.417772,-428.430849,-315.850496,-11.427757,66.831776,9.287842,-118.825169,-181.348413,-321.03948,-350.938428,-281.349106,-230.024642,-142.314641,-9.949216,50.086652,49.583383,-2.715055,-34.330839,24.999204,138.267944,133.670088,101.612018,146.978877,151.480255,34.336064,-52.417265,-95.386122,-37.670317,82.114733,109.266155,129.381243,166.492085,124.590197,8.746665,24.963908,157.143162,179.834813,90.220777,59.187112,97.605608,133.449169,124.705227,186.27904,266.21952,415.584915,326.624116,205.094182,106.398441,131.106862,135.523427,126.742177,180.806673,238.557201,321.709209,254.328616,186.766441,48.181796,-6.106102,-80.401577,-101.992745,-36.526495,74.034553,61.775763,-63.894635,-105.974652,-36.655794,38.60024,113.620991,126.446437,152.637289,36.849828,-18.589066,33.081488,77.575181,54.088875,23.816122,56.256463,80.413472,42.346546,-64.290993,-99.339246,-73.227006,-10.524617,124.909264,159.501535,152.012157,100.503604,88.649869,51.711395,9.713379,-0.647915,71.498246,287.638284,361.190811,307.13246,154.703759,120.164876,166.740745,203.48034,188.877318,163.303599,233.416681,305.402549,263.653215,179.369764,182.920841,237.347672,285.676548,386.740677,367.282352,326.774718,294.158764,307.640224,329.898822,319.678392,270.398642,255.03846,249.386667,186.06897,125.193831,33.597081,29.62572,88.438106,137.695108,219.039737,133.371377,61.551361,36.893275,60.528326,55.141999,47.211721,77.397122,85.913747,72.300873,41.510395,18.918904,-8.736778,28.090102,180.039978,214.371228,198.416182,255.306357,276.301076,184.350556,97.697968,-17.474216,-24.046112,11.001557,16.570184,-40.668686,-89.397526,-72.548266,-23.937634,-36.301998,-100.368462,-86.694226,20.614163,-7.213042,-53.344858,-57.028209,-42.407909,-95.084811,-150.378451,-186.565294,-126.92771,72.939501,113.590216,26.837673,-230.473664,-279.709317,-107.707631,-6.607998,-21.090608,-154.419705,-173.524108,-57.656034,29.98551,84.816381,63.027024,88.575033,139.196823,171.288145,75.159133,30.918882,-63.527208,-130.124899,-190.22049,-170.601402,-122.540314,-121.941714,-142.289001,-224.202572,-268.646485,-277.022103,-256.483767,-256.927887,-259.218849,-220.15265,-208.639343,-234.741999,-302.936051,-312.710736,-252.263404,-195.724386,-113.592057,-130.502129,-159.511846,-216.301552,-216.555067,-143.431415,-101.308809,-38.255858,-9.415808,41.95125,85.673058,105.348738,99.682577,75.564025,107.162096,191.828911,381.857359,365.875563,286.061811,197.231585,205.330952,189.060593,151.305941,100.542119,83.43139,24.379099,-21.432282,-41.108584,-75.191345,-62.182061,27.770089,80.029284,200.169765,237.110341,155.952302,-128.002028,-241.758584,-290.9494,-241.272222,-78.313507,5.531449,86.450197,2.574473,-53.153355,-135.525546,-157.470697,-73.980035,26.154676,150.961051,43.492871,-46.917689,-191.006429,-218.13482,-137.847132,-73.812932,-3.251203,21.959,65.17573,10.01393,-52.436868,-154.11545,-145.35397,-34.169241,0.916104,21.029217,97.272168,109.802317,50.806919,40.741357,127.229952,169.456054,131.630081,112.466023,217.973484,296.029315,227.646038,-29.323783,-83.603663,61.810455,162.768964,219.459174,150.785493,128.197313,138.084911,141.72468,83.760921,39.932771,35.589773,88.081087,176.331091,104.534292,39.837146,-7.877701,4.678694,-36.614358,-105.800478,-223.984266,-159.80311,-81.4357,-33.780803,-74.013827,-89.411789,-23.003949,153.194044,180.897219,73.718492,31.719446,52.230405,6.527611,-26.515745,44.228012,129.915286,242.592271,100.222593,-42.381597,-245.951449,-259.814309,-139.912157,-38.123521,122.415072,146.244643:115.588597,69.943741,-14.078751,-134.048027,-106.486121,54.198988,111.872005,107.780091,32.018617,-7.622731,-97.974819,-144.380454,-192.148178,-170.795798,-55.357127,-8.006373,-5.916969,-25.990758,-24.326742,-75.315432,-116.032935,-125.716499,-89.408796,8.159937,-20.843664,-96.170442,-204.721931,-202.927228,-170.15036,-160.928743,-126.524534,-88.884254,16.574065,62.72679,52.66434,-25.610324,-96.320739,-197.001209,-175.93314,-7.736881,87.300999,35.003407,-150.766569,-208.233288,-177.698323,-101.675717,65.157331,124.745092,195.110634,185.409101,160.852124,80.908115,19.131,-14.682153,64.875923,229.172694,122.918391,34.516712,-37.002608,-51.360159,-113.075576,-135.261972,-101.789981,-65.877317,-84.204954,-199.593847,-221.90438,-193.763599,-180.687142,-174.291954,-162.804009,-116.273258,-118.169193,-159.29042,-245.387288,-247.342083,-156.219941,-93.311394,-9.34505,7.759048,16.952285,-30.917568,-92.986104,-234.464577,-277.75937,-284.098574,-258.688901,-185.204818,-99.473842,-66.514657,-46.60294,-39.860188,9.169028,25.173105,7.614854,12.853371,72.355872,116.055361,132.052167,99.526482,43.703197,-0.923842,34.500642,92.900737,122.047698,164.727062,203.724471,141.51229,-56.611505,-109.004564,-54.167716,14.140789,122.870201,138.583249,108.500786,45.092324,35.147477,76.648617,132.80358,244.997797,211.914652,160.236762,109.454907,99.214475,77.950591,89.260805,164.823666,221.119514,301.23243,197.872899,115.685343,47.305199,61.645478,79.407483,42.374823,-36.746131,-13.892879,-25.736136,-127.142859,-161.383555,-151.222175,-116.683648,10.673225,89.083823,219.98257,237.921736,220.592148,166.198509,103.677826,-28.782415,-35.307447,60.664908,68.065357,3.976083,-114.256157,-127.306922,-90.22235,-51.597842,21.711513,32.738635,36.50261,65.321763,69.889053,20.148644,-13.653882,-21.44335,9.086499,113.780512,175.564283,155.384734,59.568902,6.84306,-59.194825,-35.848376,110.012968,189.480491,295.367048,243.395589,175.030798,82.378636,63.741671,68.896755,105.741065,235.824027,346.896878,370.487219,332.86703,286.978197,271.072759,319.311878,391.696392,376.660567,286.991288,157.597262,101.218918,50.762377,48.010865,99.347487,163.982243,283.658159,215.116558,130.407976,62.689712,85.620497,92.962401,70.9986,54.292871,70.431985,137.764004,154.098087,119.328915,30.868192,25.848866,117.486566,178.103392,255.241243,245.480426,219.38527,161.226556,109.392829,-22.852742,-50.497567,15.019406,76.527694,178.908662,166.46308,121.95386,22.027489,-37.607101,-115.994498,-91.254077,17.907798,48.528172,44.017476,45.465368,33.88424,-32.934433,-69.712893,-133.089773,-130.788673,-23.783352,3.828046,-36.608657,-124.779767,-142.435222,-79.907569,-27.323057,1.435099,-55.705175,-80.383827,-56.332779,-8.173339,67.77798,70.288098,20.914182,3.922714,45.962689,50.740136,19.07449,-47.043315,-78.886612,-114.054882,-99.20366,-4.34012,41.147321,8.063251,-73.341628,-91.984196,-115.881473,-142.250958,-221.751769,-227.493574,-124.321636,-67.05596,-81.982395,-155.807416,-196.386292,-211.248188,-171.541506,-33.217027,14.315732,-21.522128,-80.836091,-64.57335,14.671062,49.65818,115.137603,158.178359,214.108209,146.220877,94.43478,12.700691,2.644122,130.068883,230.349084,323.238466,293.493109,270.656981,237.2687,218.666391,153.842804,128.507542,125.306231,125.65903,102.523339,90.792474,84.403749,16.810228,-29.472825,-27.431119,23.07279,128.75401,132.019446,63.287819,-121.534372,-168.407614,-137.98016,-88.86747,25.987187,83.499345,142.741718,66.53351,13.804312,-91.083855,-162.193087,-240.997407,-188.516196,6.7624,-0.650476,-89.372644,-225.471093,-229.660103,-137.747674,-83.48713,-27.946639,-6.221591,33.175911,-20.87896,-74.562338,-180.145081,-204.649047,-134.194194,-61.531893,46.171427,76.226336,76.050854,86.609492,100.283056,110.711979,106.664676,80.448537,64.572999,67.877956,113.845884,122.343391,42.09886,-5.524667,30.368416,98.107787,182.336345,159.691941,143.636453,117.953733,87.653601,-11.862752,-44.565281,12.243671,83.239913,166.677012,104.617774,67.856204,47.636229,33.131888,-52.99536,-105.560449,-208.785296,-273.22997,-264.502087,-195.8427,-168.610471,-146.192534,-127.02479,-32.048334,19.688332,30.291172,-15.347033,-17.908443,-24.330873,-31.85387,-8.802792,10.864187,21.308873,-32.956003,-95.373828,-216.484607,-233.326856,-157.495721,-79.164671,78.238737,129.491251:108.085079,58.168146,1.742224,-124.349563,-137.779843,-26.197501,43.301297,124.15121,124.423138,79.673348,-74.720634,-149.889719,-272.008818,-308.640079,-220.96632,-102.375065,75.910706,83.564141,39.969581,-130.411376,-192.526217,-145.520686,-81.074507,2.521118,-58.68271,-139.762535,-261.46061,-266.588387,-203.712468,-169.028665,-75.952067,6.27293,124.998384,27.439372,-49.553086,-158.54617,-188.514811,-142.029289,-59.606441,118.821916,109.142966,10.386976,-172.401973,-183.359835,-54.858984,34.643355,165.115617,200.772193,177.913412,46.608178,-3.653489,-75.260272,-109.976262,-78.911352,14.321284,205.994588,148.851656,72.692975,-12.529192,-55.259086,-140.727995,-122.752673,-19.245617,3.660419,-63.077378,-236.413055,-295.186881,-318.484411,-311.442538,-278.324336,-248.79673,-160.727241,-119.894996,-152.681203,-272.03569,-321.365913,-273.055621,-168.240564,-11.074199,-9.295407,-20.641751,35.993303,24.279756,-137.035161,-218.692719,-243.517507,-208.084688,-116.929097,-36.431212,-31.178847,-116.573026,-178.93842,-204.341645,-144.182299,7.457606,57.076011,84.970627,25.322762,-5.912212,-37.476559,-35.875792,18.815186,58.493398,117.378511,162.616913,189.358293,207.671314,167.683493,10.332339,-43.930842,22.039515,101.894819,180.308657,185.900906,168.705793,49.031042,-4.33556,63.242978,170.623645,322.504708,225.61383,151.929573,107.510821,101.607453,71.610152,77.246924,161.408481,233.997964,340.911859,261.445738,175.23968,16.453097,-18.253768,21.739549,58.390094,116.956518,108.814713,46.275298,-159.483125,-236.937428,-187.625157,-73.944585,123.592855,159.294262,177.281623,140.484678,98.906779,43.804033,23.57717,-14.578511,17.067981,169.478293,159.159062,93.353872,2.527917,-28.06669,-62.981667,-39.040189,65.171042,130.932457,229.914604,137.13078,39.62274,-134.902158,-166.891609,-56.471039,42.746966,190.294037,222.993261,197.066491,86.213122,33.702879,78.406446,174.575641,291.971812,282.138675,276.715629,262.887259,191.954402,12.993216,-19.134347,82.452936,160.877669,260.780888,298.175384,285.545897,223.83816,212.356144,258.195594,290.509948,320.919244,328.390499,325.39544,207.727946,98.936066,-117.558776,-164.778493,-70.162375,35.024705,192.958834,123.719639,48.691749,-4.310682,4.909074,-8.993406,-14.570433,37.121066,74.458829,119.051282,94.903284,46.756489,-74.723843,-70.481801,90.594603,154.96455,192.81466,216.460837,215.486141,157.320091,96.70867,-16.91331,-19.840984,82.517183,140.195037,176.005412,112.596956,79.422776,24.77411,-12.00306,-62.459973,-41.127049,60.976861,40.832288,-5.930319,-14.264691,8.542443,-49.097852,-125.66434,-191.783031,-132.527121,38.40936,-8.487863,-97.763627,-236.327854,-232.767177,-69.416068,16.161919,45.094261,-36.889145,-52.382569,-12.161604,5.896633,21.19641,40.573441,91.964071,97.526946,62.522409,19.492158,-2.574605,-99.786554,-159.345347,-149.291871,-76.98285,55.466258,24.781037,-49.784306,-164.188215,-174.26856,-164.91533,-175.68093,-243.411347,-262.380316,-200.939863,-202.853553,-268.93635,-403.636875,-419.868069,-295.641082,-188.691854,-49.080554,-89.175829,-142.394798,-209.842611,-198.827674,-100.563642,-37.823869,69.439635,116.249085,195.662485,174.062094,138.513357,94.667599,95.403805,189.204639,274.817478,389.504271,354.935776,302.666326,187.118941,141.500976,95.241983,92.70528,112.253466,133.955063,171.83421,147.502083,106.042812,-18.703825,-57.220733,-16.036465,37.455847,140.0985,130.377255,58.342962,-98.714581,-143.333873,-182.852494,-172.821971,-41.45431,68.508133,198.264595,102.864321,41.144628,-10.193617,-23.7275,-52.92876,-34.697046,115.509239,204.784671,145.282212,-74.506517,-149.977372,-105.732539,-20.079283,101.312418,113.071462,78.951843,58.718431,63.885117,24.494043,-21.204809,-64.704422,-38.722075,105.012115,263.647231,277.315539,166.756848,91.332712,39.098285,82.66048,182.263465,198.180608,167.688987,86.678218,40.561567,-54.300652,-63.018605,87.409553,192.568586,277.396579,243.638634,220.400682,159.323097,108.792211,7.264547,2.224631,115.323135,196.595263,289.317279,216.113042,153.536806,101.246933,116.536149,159.675532,159.040024,70.888641,-27.594265,-26.144631,-18.015668,-61.086209,-126.978801,-92.917155,51.392089,105.414712,105.169189,53.556993,41.177175,-28.106802,-69.496633,-71.317719,-42.186917,44.281917,42.895486,-47.509767,-245.887423,-277.658019,-213.552889,-143.06146,24.357391,89.375339:99.226108,106.986172,88.098022,38.989193,45.791967,121.603401,154.082411,151.322526,88.793052,28.967093,-123.115736,-171.472436,-168.579714,-138.116506,-81.823265,-66.630489,-82.62993,-114.411816,-112.123743,-140.280566,-182.816097,-221.291882,-192.175998,-84.91269,-7.493416,-3.843583,-61.216631,-101.372198,-131.605375,-122.238216,-85.470893,-26.172438,158.483454,162.680968,91.346527,-52.313514,-106.683656,-149.748462,-114.717985,50.479324,99.839529,2.420899,-292.856255,-390.24411,-358.028435,-224.679454,118.406313,237.094826,295.268974,225.641909,181.38992,71.439609,23.254404,29.01401,64.493354,106.406939,128.90642,128.146786,60.794189,6.092185,-107.113481,-150.019823,-138.948503,-81.855091,19.012885,-20.222515,-70.060728,-127.524685,-120.645935,-116.944784,-148.261382,-210.622041,-189.914922,-175.480348,-206.838037,-231.673472,-182.312156,-114.186175,-74.174733,-126.648013,-170.687993,-59.060056,-54.882746,-195.986596,-253.88739,-241.138741,-208.328802,-164.05905,-127.352307,-105.380355,-66.547853,-62.91163,-107.661545,-140.626207,-176.383349,-163.904133,-97.280554,-59.611291,-68.116897,-115.815442,-125.414847,-43.247671,35.075665,125.85871,80.712205,66.696682,81.723433,44.439888,-155.274535,-235.751676,-213.417952,-128.835951,69.467682,129.308269,91.83242,-22.009122,-65.211528,-39.957017,26.233136,172.02404,241.843832,226.876892,155.031954,113.323512,28.139991,32.179238,201.621172,312.889256,390.134801,282.693876,246.282707,193.737028,131.15103,-5.493524,-30.437285,19.124426,43.190506,-26.743137,-239.347516,-284.703554,-227.01203,-167.771771,-12.570149,88.100552,281.959035,318.887219,263.556352,84.202941,9.287354,-36.015605,-37.101028,-35.493081,-15.147287,-23.500039,-76.729176,-107.364095,-159.701207,-165.436315,-105.865347,-56.488997,-13.342319,-63.055516,-86.543727,-157.85265,-205.51652,-214.33031,-164.901267,-24.210156,24.352789,-19.397452,-132.234079,-157.041356,-150.075028,-107.885447,36.399681,81.028071,90.326881,57.180199,39.168187,17.11674,-6.627964,-31.307965,11.876813,173.217966,325.445408,374.477976,356.636871,306.187941,256.561974,261.493354,255.395001,256.331449,265.546126,150.732212,79.032282,30.389185,31.248203,8.318894,12.191878,122.645888,163.485036,113.169297,48.977754,50.148335,12.768744,-8.515054,-15.326415,-24.029103,-16.466461,69.012434,127.295191,176.598307,142.601081,56.695264,51.380992,118.280296,148.521692,114.129552,31.423527,9.262671,-33.324773,-52.294245,-20.186526,33.145462,158.271102,223.55889,211.723909,92.84222,8.191478,-113.280607,-133.731105,-130.879574,-115.642507,-99.296246,-65.604671,-74.293771,-150.679824,-176.891481,-161.088777,-133.218813,-56.47067,-34.802639,-52.132922,-117.441244,-174.974371,-291.972577,-287.436791,-94.152241,39.10863,-15.784152,-202.052152,-241.439417,-185.766024,-119.360354,-35.26666,-63.036355,-168.483143,-174.600999,-155.636737,-199.880435,-272.022205,-354.811572,-326.458694,-200.155625,-117.224784,-121.238173,-138.361151,-132.070739,-171.629072,-221.049941,-280.554412,-258.672534,-153.310646,-80.387719,-67.016897,-161.135749,-259.659646,-351.181173,-310.366863,-183.497687,-135.455305,-139.501596,-117.796311,-81.464472,-35.217229,-34.22863,-27.187595,-17.584702,-21.782535,-79.349473,-114.956869,-143.21898,-121.89925,-57.300852,-38.940847,17.211176,130.025844,153.092546,101.206146,72.484914,64.989912,69.367933,71.058791,61.095728,21.582622,15.331168,33.48137,22.092686,-18.650428,-41.888431,-4.706884,88.952529,102.744184,58.489361,-41.083519,-55.634999,-30.605464,-13.41574,40.336051,93.340826,212.382536,213.598237,163.097841,32.162609,-35.815678,-112.727167,-82.527306,62.296597,60.969395,-8.3405,-64.308141,-18.526419,61.580697,54.610198,44.063934,71.287033,105.642716,25.836084,-36.922883,-160.895125,-180.227876,-22.118228,94.730045,201.15893,230.173089,237.06966,209.194202,194.317058,180.600189,163.937496,94.319006,75.265775,150.902924,247.496515,243.448039,160.351251,125.027399,170.349237,237.009429,309.727994,314.226749,316.454632,281.294397,243.626424,152.193673,107.79013,88.384053,140.732875,284.579729,294.511796,279.834499,300.253003,293.479279,167.908022,86.821506,-15.987841,-117.051741,-188.80337,-255.144017,-225.496676,-126.248033,-86.631622,-47.503581,-41.926475,-16.92559,26.821037,33.734997,-45.32484,-117.058794,-181.05818,-160.233931,-76.900599,-44.859926,-94.126952,-226.226809,-238.705503,-141.079247,-63.758305,88.069634,135.32892:142.663409,53.928233,-15.164313,-86.110194,-51.539391,99.038771,162.395724,218.0359,147.442044,63.281884,-89.085998,-132.873327,-176.999904,-166.597023,-33.786787,64.824449,159.054372,62.792841,-5.960702,-125.803207,-158.84108,-129.388539,-80.252121,17.725031,-8.342811,-83.855906,-233.572842,-254.386184,-194.587559,-160.615416,-132.497788,-107.196747,-24.435569,-47.888137,-110.244943,-206.560948,-191.467195,-58.802363,1.419139,51.794846,40.358181,-6.146404,-169.23528,-246.034054,-262.280863,-173.678566,100.928146,216.569877,303.506729,212.939409,140.032597,-18.277227,-75.51088,-14.435785,84.781735,217.328993,166.112982,91.441835,-64.347676,-116.029815,-162.620009,-147.853872,-44.273749,12.317752,59.275483,-26.59817,-97.376274,-204.429148,-207.490919,-112.842661,-58.022749,0.08246,6.661207,-9.035509,-96.114717,-167.314505,-203.375613,-126.282599,24.077697,41.795744,49.814265,39.941587,-6.263073,-142.407062,-185.915417,-157.666362,-100.763794,-15.744055,-53.01847,-94.523631,-176.485997,-211.696892,-240.562153,-233.26841,-202.686,-163.783552,-65.309633,-92.179893,-136.345348,-195.486632,-198.735622,-95.556138,-6.916128,121.146354,181.038834,190.351796,89.666932,-16.653933,-174.082164,-174.988564,-73.802221,-21.836503,58.27313,83.733173,51.589771,-32.189895,-40.61359,35.339764,107.042242,261.87995,310.80736,260.317226,67.221196,-32.090692,-108.39725,-45.044033,188.580406,281.386446,341.70996,235.398991,142.66816,-6.776756,-33.53079,-2.535249,38.240144,136.055305,92.165915,-16.740375,-252.082523,-315.89101,-279.50884,-198.546636,-3.89514,96.842783,239.841109,186.140301,116.549928,-17.398005,-57.81472,-15.973984,50.025549,152.241796,131.842433,78.825032,-58.632058,-106.530532,-112.494446,-86.024157,-16.680293,25.082476,100.48384,67.120227,-18.208293,-219.966099,-262.325437,-203.97821,-134.03591,30.573495,45.432424,-43.122967,-227.170872,-258.938191,-171.473956,-58.390439,187.271018,263.86442,293.800991,137.115099,29.634113,-88.495737,-91.020316,5.225633,84.165381,237.614032,355.405008,368.557364,285.126489,223.405177,207.314152,271.991105,390.163072,390.141707,303.134269,115.526333,-1.695405,-146.648711,-142.199363,-7.394617,82.62357,197.894286,108.873244,2.378939,-128.147062,-132.692204,-79.766334,-16.718412,92.467862,95.603028,78.74173,31.928165,-29.50088,-125.987747,-116.573659,11.212591,100.737555,216.651107,161.17264,101.536757,4.050289,-25.742549,-47.399786,-32.195257,58.223856,122.735862,234.802865,212.420658,145.684856,-11.960317,-64.98773,-53.636979,6.92544,114.893029,94.168874,69.539949,32.990241,-2.632486,-110.603499,-135.03454,-83.00081,-44.610254,-10.070189,-48.866434,-93.165744,-201.245337,-226.217576,-157.344566,-95.763851,-25.803324,-47.017943,-67.317228,-92.159013,-103.158202,-97.57055,-56.384761,46.043631,65.930769,17.895042,-96.491986,-142.388707,-202.056908,-231.315731,-246.786312,-203.922028,-74.056834,-53.9773,-93.783304,-178.439027,-204.18089,-249.173585,-269.599364,-274.729792,-252.584285,-169.66601,-108.272892,-126.155698,-276.170109,-342.403466,-294.093339,-197.603042,-6.624851,-45.118258,-164.424727,-316.744613,-273.852836,-95.880927,-31.253504,40.496138,74.675961,150.33891,103.715061,34.090034,-59.864627,-54.965033,34.161368,92.923127,182.634831,210.774553,191.010122,105.213232,69.110323,46.668827,51.972549,69.417571,75.923687,71.795742,66.504148,49.048362,-74.122938,-129.074828,-59.453648,41.623654,191.463927,182.837341,128.355619,-40.540156,-116.403859,-130.62961,-50.780374,185.571433,271.446373,244.015499,81.821753,61.414081,51.418677,-18.283102,-130.433158,-71.086635,188.902104,264.533395,184.18478,-47.863484,-114.304182,-53.235106,30.800401,162.373704,190.089332,161.560193,83.094469,43.752051,-36.391058,-40.418102,73.535278,145.888695,237.923469,253.163667,226.941504,139.126921,85.66757,2.43181,6.129649,86.290363,135.635898,214.1833,190.835141,136.319533,32.264422,29.263342,138.141727,212.148078,297.696168,246.786421,201.241449,143.992249,104.246835,-3.747053,-6.979845,139.861189,228.650213,300.01089,274.138054,252.457434,196.931426,176.219562,150.783577,130.297396,55.510773,-24.741962,-59.016108,-113.00097,-121.234036,-101.309538,-83.107621,-20.895538,35.749439,120.421388,1.241555,-97.802084,-208.374802,-209.811201,-155.941351,-114.765991,-1.12698,48.290072,-15.997215,-223.928022,-280.31147,-214.339522,-118.097886,71.171879,146.069689:130.996511,113.454099,92.58779,11.137611,-15.851708,32.401846,85.981603,105.809197,-0.827849,-35.808341,-56.805511,-84.516995,-153.198195,-151.157685,-136.596092,-152.368788,-166.029206,-224.311285,-281.180463,-313.608672,-285.843763,-216.612147,-185.740432,-142.720578,-87.333398,-54.76148,-25.393173,-43.540646,-93.856402,-74.588758,41.972397,101.665879,161.611345,93.705749,39.223026,-70.499604,-132.688629,-225.992108,-236.16861,-186.612714,-140.057159,-198.667948,-465.372507,-575.499037,-567.582241,-446.710246,-121.449928,1.325722,118.5044,141.841239,122.16099,31.474001,-8.928696,4.724374,59.926072,213.469044,287.390854,253.649206,169.666383,167.744908,186.321019,180.470162,156.276225,163.542805,235.331883,227.444387,165.340143,13.668796,-29.755754,-12.892683,-6.378268,-123.025009,-271.151163,-280.714013,-228.999976,-226.35233,-255.469775,-241.787569,-198.479589,-204.143138,-200.400454,-124.572368,-116.404854,-234.031276,-304.315715,-267.670127,-178.093416,-89.281941,-170.378235,-201.873264,-160.164385,-133.814015,-188.555669,-233.439834,-227.578714,-188.499205,-121.737249,-91.931975,-80.212981,-89.246512,-104.229049,-73.924765,-19.51111,125.021439,171.375319,128.722121,24.003954,-30.484051,-210.11763,-285.594636,-251.235457,-166.154571,4.772916,84.051795,82.710927,37.626264,22.136149,81.061599,133.869096,190.388239,231.660019,255.414555,224.80156,147.144026,-20.938035,-20.689162,192.264785,331.464478,495.529327,418.45461,340.958948,259.196908,239.550264,169.492461,132.025687,88.774107,-1.755089,-92.744305,-271.219574,-301.677812,-203.14572,-101.154949,125.476101,231.247437,371.553524,331.341545,255.759665,72.018884,-15.545451,-110.270792,-107.637638,-28.08073,58.685399,50.234599,-28.983121,-46.518516,-30.249543,-20.304796,-30.809077,-49.765461,-57.449727,-5.801991,-0.007031,-94.819436,-163.633029,-252.89141,-269.615236,-230.327359,-131.078513,-111.032063,-125.010373,-123.660819,-69.567202,-5.755448,168.509068,240.789647,288.531775,228.47795,206.546947,172.310716,130.086599,61.035565,75.120704,181.651099,289.088101,312.659924,279.121488,227.484913,113.819327,77.914555,44.287362,43.766879,88.053327,117.286509,102.380451,-0.88882,-78.200712,-160.013906,-138.12827,-31.860276,-1.28704,-42.853775,-124.555574,-131.943342,-104.175112,-81.429205,-88.341692,-121.623279,-91.070641,80.36795,143.10072,169.737692,154.957455,155.886872,199.264926,312.045352,301.722943,242.454343,95.919638,49.406339,49.045206,69.40807,102.324546,124.160085,171.878733,168.726711,145.412856,17.461797,-90.794525,-261.732872,-283.025412,-265.108582,-203.361734,-148.924451,-55.300396,-33.356606,-45.29116,-78.953153,-204.954396,-266.556014,-236.194952,-44.72867,24.734935,-22.95278,-122.042825,-244.476415,-208.416628,-39.176958,17.495344,-31.657892,-169.219375,-202.766513,-186.09547,-159.259518,-173.821117,-225.632318,-275.625319,-221.357874,-193.987481,-204.041687,-255.280913,-374.197077,-382.611285,-246.597386,-94.565173,-83.077616,-117.389193,-117.93332,-98.959869,-98.55176,-143.048716,-169.376556,-125.139564,1.799765,32.522367,-75.71955,-197.088879,-333.180757,-306.04913,-182.501988,-103.814131,-120.592484,-176.442456,-163.206814,-161.823462,-189.195245,-183.733657,-164.550156,-175.756849,-218.682629,-243.803616,-280.366129,-280.833388,-269.982136,-253.827824,-137.087518,-1.331855,18.334605,-11.835718,-17.646263,40.202745,73.944698,57.855122,17.871967,-18.878436,14.127319,25.280769,-6.799292,-39.828252,-53.375852,-25.860173,43.601895,80.949752,78.774634,52.550182,41.060176,27.204627,12.818366,-15.647756,15.662894,165.850878,232.251349,212.712292,100.71117,23.216484,-57.26479,-45.479902,-19.915535,-23.676671,-21.216766,-6.652396,19.926021,121.929287,168.32985,184.593709,145.435259,7.007131,-83.277807,-70.296726,4.040202,36.319604,142.573315,203.239848,259.231588,278.765174,281.149906,240.75762,208.143565,161.341889,141.948804,77.424345,54.58561,95.406244,159.425155,158.115095,107.874759,95.356117,169.575276,241.346054,370.543256,447.631373,451.680236,373.117382,300.469469,154.313544,117.038649,141.920787,170.650977,181.846328,199.021416,230.984896,257.243171,240.633193,215.300996,200.778424,86.722515,-110.179693,-191.236151,-246.038551,-228.619372,-191.707669,-172.603357,-82.686983,-30.538027,45.41728,61.387171,26.418398,-134.308531,-223.72186,-271.554697,-216.856394,-88.700949,-133.077402,-214.349573,-314.356449,-273.287318,-61.962496,23.471782,59.74884,53.346605:76.057746,82.681765,59.041969,-4.350613,-4.653036,65.938965,104.730054,100.008506,-30.150554,-96.665706,-111.990182,-73.555844,-43.476325,-69.205944,-138.328949,-139.20149,-69.943922,-59.833562,-81.050311,-145.808469,-178.896781,-177.362025,-145.332059,-82.13287,-8.554722,22.251556,18.835146,-3.138119,-20.000609,6.308426,90.276186,123.96792,172.126542,162.37971,135.117732,27.681935,-59.237402,-180.557178,-177.426903,-134.025174,-157.428324,-202.38819,-324.864036,-386.007086,-410.655428,-327.137802,-80.289433,11.060121,130.779923,182.286516,156.45031,16.212778,-44.397344,-33.046335,19.991001,82.528907,95.500578,105.294173,27.836336,-68.718309,-195.242634,-191.567491,-157.578366,-139.080666,-35.651373,68.514765,70.523606,-6.801543,-50.368272,-91.127639,-107.427578,-202.204994,-278.981174,-252.059131,-149.228091,-133.523788,-139.274285,-105.606687,-20.942164,-22.7596,-68.910298,-104.468303,-145.852335,-265.60837,-301.753365,-266.648017,-218.288377,-142.188466,-99.333531,-88.552105,-47.817965,-12.798349,-28.076259,-84.465347,-125.492755,-78.817813,27.636096,16.546583,-2.492179,-24.541703,-56.338329,-140.326712,-141.366619,-10.582296,138.169831,143.045966,6.199688,-101.9873,-267.352289,-284.326135,-212.909664,-150.882162,-6.391574,105.176323,118.936529,75.348094,47.726439,76.444063,130.409742,212.402586,264.806947,292.111795,312.556549,273.771138,130.177117,111.423818,273.262233,403.798021,566.646057,469.803159,399.64145,367.474574,359.36409,261.269042,190.379939,81.615716,-16.412533,-90.245428,-221.478842,-237.873647,-142.564735,-61.876969,62.117162,114.188882,264.639975,363.869301,339.818676,145.152787,11.884789,-191.77793,-225.116616,-132.997706,-17.996231,-49.868381,-179.276903,-192.910715,-188.087585,-227.666757,-316.316062,-286.916021,-73.723757,72.489695,59.347308,-91.991487,-169.418781,-217.70769,-210.693034,-183.951696,-83.634952,-43.873775,-67.505943,-101.826802,-134.289938,-112.791164,-4.190918,54.982064,137.184938,138.022656,108.800992,20.824624,-20.886145,-18.901399,42.581344,220.221346,326.731234,322.610551,275.854508,257.731149,190.517488,148.757523,105.385258,96.518412,62.611991,55.951408,90.716439,158.654538,141.488236,66.541917,72.876325,155.655541,175.636,168.180256,191.298807,182.043575,22.70144,-64.438064,-116.909074,-99.151143,27.838693,234.259439,310.50219,303.214229,209.829345,72.681339,115.094022,273.79342,309.124297,271.124598,114.73886,43.634381,55.230405,112.996397,141.054844,103.58236,69.895598,147.045875,175.335553,112.615302,40.088994,-81.664531,-127.13677,-182.188983,-135.676396,-103.547607,-81.831324,-81.725579,-93.010892,-96.125224,-74.900066,-58.12157,-14.764009,63.17623,102.695785,102.940233,55.039133,1.633598,33.231585,122.284058,77.26654,-26.935094,-224.364125,-237.975893,-145.209294,-90.053494,-37.765211,-59.350286,-148.676257,-168.730937,-156.667073,-200.587305,-261.789825,-358.20268,-361.190223,-274.350663,-132.755532,-77.606608,-17.373276,-12.080466,-63.33294,-94.765374,-101.632623,-82.439141,-14.894939,106.514835,155.571335,97.078013,15.908663,-74.148672,-79.056625,-71.387226,-31.992712,-9.107712,25.075596,40.305645,58.970445,71.725071,77.116455,43.650633,-42.320599,-79.611107,-95.072444,-144.323841,-158.487277,-130.78124,-104.496346,-26.351523,74.019881,97.229525,110.803345,138.015084,240.457022,275.562067,219.828103,147.047403,62.821356,88.809195,109.022242,120.394116,85.736588,-29.544881,-60.361641,4.973971,172.216142,205.472905,94.354708,11.675796,-70.087566,-79.545972,-65.877069,-7.607788,181.672727,216.768102,182.998061,74.226474,-12.77493,-121.052374,-77.990593,64.443088,32.099973,-4.844467,0.229443,12.517297,-11.336341,-33.400817,-46.715042,-36.042573,-41.79966,-148.605577,-186.27486,-143.382844,-95.031016,19.842574,81.326239,129.503655,97.477971,90.075309,132.255848,162.937014,128.030322,62.207158,-14.09526,15.578509,110.233456,135.680898,159.771022,184.721215,151.789259,175.378888,276.931448,459.1381,440.568671,372.073823,221.485728,173.005554,132.55424,116.664629,65.180103,55.112759,88.293743,105.194427,113.676246,105.984294,59.666689,-58.948107,-90.635257,-102.698165,-183.897776,-267.977051,-316.946905,-242.034117,-99.753781,-90.364346,-116.120866,-93.121919,44.64312,86.635887,18.937522,-185.856927,-253.613352,-233.964842,-169.00582,-73.164563,-185.757861,-296.679463,-394.788961,-344.987155,-158.444653,-83.960132,-53.654632,-61.264794:183.806834,152.914147,85.730495,-56.312145,-75.268753,23.964394,77.921412,72.009135,71.742499,84.57487,-10.369296,-100.01442,-168.275842,-133.774198,-60.440703,-36.221043,5.040376,-77.543695,-146.680173,-200.899234,-199.789273,-175.205064,-132.459714,-36.999359,-38.201157,-64.395379,-135.343518,-171.177816,-195.666075,-175.186798,-92.06481,-43.324242,11.037874,-32.047116,-47.692688,-45.058259,-69.499725,-158.456987,-167.158422,-40.896857,27.368664,-72.366661,-368.226979,-422.980815,-288.810901,-172.264256,46.241337,137.189749,228.469871,186.713259,156.705108,113.945222,84.021811,38.925968,45.08935,99.569951,187.697738,204.862976,107.096897,35.985143,-0.102735,31.132181,90.111,105.54799,137.582119,163.348804,128.019162,-79.429507,-163.870322,-134.591384,-89.395992,-86.267387,-110.718875,-122.136783,-154.492606,-165.794111,-154.676627,-118.509392,-41.543544,-32.199456,-25.042561,-35.35605,-65.473584,-123.596688,-128.522987,-80.145004,-57.189531,-73.174042,-98.591977,-107.107069,-141.97485,-151.501727,-100.337323,-52.015618,-37.669988,-91.998125,-222.137532,-231.997251,-187.944546,-141.510188,-157.971216,-91.87165,8.055235,142.078799,115.694935,97.565938,104.68308,90.212232,-34.584554,-96.570951,-99.022528,-59.339615,-9.623996,-51.941029,-72.248466,-15.750821,34.795016,97.640022,115.248799,154.653023,180.483917,164.315701,111.898798,84.806704,15.799868,14.092331,141.006471,225.415772,295.802034,254.926884,242.375676,183.983851,119.13868,17.453837,-2.388128,-11.003976,17.501742,8.789013,-112.219016,-182.715957,-229.51384,-187.291519,-21.777318,55.776358,163.609587,214.816726,207.293568,70.108892,-42.110215,-148.928255,-115.176807,-4.154838,65.640175,68.592773,2.369532,-41.881666,-108.439491,-124.98416,-98.547804,-43.658395,76.248271,29.750474,-47.155924,-224.039665,-299.496534,-327.315407,-278.382004,-200.649404,-245.304965,-277.133753,-311.204338,-308.222556,-225.946608,-132.108955,94.892008,162.451362,166.288568,70.969759,16.519622,-54.359071,-72.723281,-56.282059,-8.047404,98.770412,163.234572,199.519105,260.303605,262.167974,218.462273,204.270281,211.746929,195.584785,101.424996,19.74585,-6.932673,-61.497522,-98.430535,-154.054063,-137.25323,9.608486,65.300736,-5.632051,-171.005203,-200.692953,-177.027095,-149.405761,-97.349653,-76.161369,6.992105,80.452995,60.690598,-4.659664,-9.461515,-4.44227,10.886349,121.301082,215.472328,192.297255,55.736927,6.753253,23.645971,66.536216,126.442744,149.708183,225.998351,217.277102,146.779098,-20.202919,-74.105704,-126.144778,-130.693751,-69.935847,22.390658,28.768381,-12.208312,-35.700861,-107.855084,-144.283652,-166.931609,-166.192746,-167.486426,-99.413817,-45.409634,-80.641589,-164.978218,-189.538438,-99.288581,69.33337,89.438455,80.100881,51.007428,4.175841,-90.143189,-66.911967,39.143318,20.906246,-94.343784,-39.307827,-1.357024,-95.315574,-186.085872,-275.567608,-264.813499,-176.340456,-87.181752,-67.918281,-44.264433,-40.410888,-63.607823,-77.244642,-120.567919,-145.28413,-115.13204,-23.14461,-18.301297,-148.87995,-225.544887,-209.65808,-139.8287,-51.585433,-79.607444,-123.434934,-186.330888,-162.521016,-80.335871,-78.95589,-115.113669,-95.610692,24.061777,16.795787,-65.202091,-205.948727,-204.706317,-61.586208,25.711762,127.299825,152.17266,142.566418,103.957685,77.905249,6.871614,-24.202748,-35.809649,-18.426127,30.383959,-5.959623,-46.955533,-63.307762,-49.927208,-15.380271,17.852575,97.870165,88.91356,22.588543,-111.332726,-126.405552,-70.006498,-31.96252,6.288126,25.204118,129.120132,221.98355,194.792386,30.442283,-27.730019,19.733804,93.304878,161.92394,49.905092,-28.704058,-76.983768,-25.103653,154.07426,233.397171,265.593116,217.942932,113.896138,36.435618,-3.336117,-50.862747,-20.837089,134.020472,174.034929,126.20019,139.565012,167.549531,156.088141,134.25062,115.259823,107.031791,73.198152,65.188361,101.326707,183.355088,219.770777,182.100433,125.566575,130.049147,169.440238,172.921874,207.906919,246.532722,258.838752,222.950049,91.395285,52.440142,161.883232,253.05631,293.019359,197.623944,191.674039,301.753935,345.635467,292.881481,211.580977,27.4431,-59.96775,-64.490492,-115.327682,-176.474204,-234.207607,-189.038019,-56.862031,-27.399765,-58.789719,-150.547227,-166.144663,-125.852829,-128.293563,-184.481215,-182.681075,-81.448578,8.297605,-25.999766,-216.483711,-279.206193,-192.767145,-65.177441,141.779674,156.74866:forward
17.802304,-25.723192,-0.94672,140.970045,193.808611,195.575093,171.276821,111.225681,62.31838,54.098668,54.893306,60.640323,43.18424,15.466617,-14.927585,-7.095868,22.946574,-15.59163,-56.065069,-49.968141,-9.399838,-1.865065,-37.727193,-69.743032,-3.559071,48.606804,177.462721,247.196866,318.629236,319.773037,327.558522,338.909513,387.772066,491.522758,559.310225,705.313291,736.046346,629.843392,530.878652,344.312271,223.60876,201.780459,221.518232,266.77066,423.378883,486.937322,460.556415,393.244594,370.027212,516.247897,550.06281,438.791278,345.817976,252.323746,242.727211,168.226765,87.499732,94.474337,138.76413,145.556802,83.261926,12.701287,-96.508381,-104.913111,-101.076983,-166.688284,-192.714832,-126.667461,-63.153579,-4.055786,-20.981739,-118.957045,-196.250269,-198.971803,-182.364248,-185.03056,-243.241845,-281.652166,-306.609727,-303.323958,-256.134227,-61.155677,57.285889,188.547853,203.907721,244.358695,257.057251,193.56608,202.596462,258.201957,356.144416,381.318437,333.620468,256.254822,90.364424,53.22373,86.299116,92.371332,91.15644,160.202083,188.903055,176.622898,154.748395,109.233684,164.313357,232.545517,329.428276,352.273366,415.086745,453.498603,462.592913,396.454538,168.483994,64.00723,83.591405,153.702764,165.777411,145.706458,128.785966,58.077867,-15.681416,-27.055806,-38.195554,-31.46589,49.424279,98.949963,104.588108,64.151381,63.624392,165.051417,184.286996,156.859341,114.091994,-23.473784,-87.596542,-136.735077,-89.797852,-61.349922,-11.886432,30.832227,101.649982,84.464705,-45.744578,-131.258983,-242.132778,-147.134469,-54.503312,43.160997,17.496414,-95.647356,-129.79355,-138.070941,-171.611446,-193.783336,-193.299931,-165.172161,-106.189873,-105.124458,-148.456089,-176.170996,-189.480063,-83.728247,-15.149697,16.34915,-40.761309,-163.429487,-161.115299,-91.367826,-101.377341,-112.049415,-64.66269,-18.114136,42.133133,43.986826,-4.099034,-59.993343,-146.181991,-63.596893,-8.189811,-18.603687,-90.141912,-250.31268,-293.31411,-324.49813,-381.645356,-434.01678,-486.049193,-444.409064,-289.630501,-221.681312,-146.830935,-156.637318,-240.660039,-229.422164,-169.522885,-2.555362,69.953023,68.606512,-34.412134,-330.284733,-388.775368,-295.287206,-82.374521,-21.928268,-1.080223,-22.798056,-89.288742,-126.199274,-119.307457,53.035067,118.452932,105.964576,62.038689,-76.965477,-162.569136,-244.967704,-176.961294,-136.734425,-18.806735,87.924548,259.265508,277.086032,235.399894,188.535679,124.101735,224.115961,269.328125,240.944766,198.550204,130.307014,102.191478,4.656878,-33.098519,-8.192167,-4.989601,-24.53589,-10.013383,6.101618,-73.07121,-157.126442,-231.437605,-143.708863,-94.951283,-43.84984,-54.734989,-169.574373,-259.245187,-419.158054,-436.352381,-385.228304,-267.204991,-234.508494,-210.148221,-209.329383,-260.640361,-318.537116,-410.930749,-349.105657,-295.033709,-243.118378,-234.979636,-202.231385,-191.102149,-263.80668,-385.326932,-397.332174,-304.766874,-234.445493,-137.028126,-138.734231,-200.775176,-208.337562,-148.851573,-67.607686,-28.506219,87.439861,143.956625,132.014188,56.837164,-113.027089,-93.449075,3.078545,182.225316,218.283587,249.204197,280.982149,364.04144,377.526503,357.194614,374.351812,401.613368,448.713243,440.441124,338.371556,253.961909,73.444976,8.769883,22.966502,54.713486,66.578848,102.449087,106.424748,56.720121,23.24791,5.554993,33.595279,42.994664,79.586568,98.925442,74.177291,18.024569,-153.165878,-253.054641,-241.915178,-120.696227,-22.114814,111.481313,91.052053,-63.089528,-133.924902,-170.358034,-127.307891,-111.921128,-83.107324,-79.497257,-156.170381,-210.228607,-266.325476,-270.033762,-246.830302,-132.840325,-64.085629,-27.954568,-53.254747,-31.915837,-5.099558,-67.958318,-100.472316,-39.071365,103.604639,126.346147,65.09484,9.279141,-73.050567,-104.575219,-146.938342,-273.206464,-290.347685,-209.182415,-164.508706,-153.110311,-184.434246,-215.057983,-143.988961,-105.205427,9.427363,82.732377,140.473721,112.453336,0.998565,-85.581951,-95.917231,-91.620945,-88.808554,-93.727456,-90.111522,-63.656721,-94.61598,-281.215556,-360.438823,-284.05125,-55.986301,-5.028661,-3.873244,13.343743,59.833621,37.972034,28.644424,71.442092,126.59716,201.396358,160.382765,-64.902737,-193.168635,-339.294331,-275.165391,-221.19742,-129.815425,-76.59658,-37.488645,-81.226883,-203.123646,-213.675,-170.909559,-82.008631,-51.966389,-0.172315,9.287974,-41.827539,-99.000047:123.485101,258.625977,331.64583,321.167089,249.602414,156.445868,163.904868,200.770061,143.775718,104.411513,165.703127,237.734877,219.496625,150.02042,94.776393,106.443428,141.647793,163.724561,150.66212,131.982911,162.842813,231.42785,215.601534,156.743523,197.352903,235.55446,338.074515,415.042156,546.067941,566.720236,528.431906,490.045706,472.648974,566.615621,607.184782,643.968576,657.955082,600.138117,489.987751,267.508414,263.520827,308.532302,396.762902,436.300909,462.605595,421.959099,269.280075,207.403505,207.199979,322.243606,367.7819,340.735115,282.50882,182.779818,144.569522,105.178141,137.214628,137.601284,122.200124,137.469167,126.920506,69.625635,-51.570252,-75.303888,-76.995358,-98.837125,-101.119933,-70.174357,-47.202156,42.057735,77.116595,14.803573,-89.672977,-97.433216,-56.534481,-47.181475,-98.212973,-131.186399,-158.633059,-168.673947,-144.995548,11.081202,103.094513,194.461948,197.773301,222.376013,236.510229,215.144955,194.841349,199.838778,273.533537,332.695764,356.380733,303.327263,143.389439,85.660897,109.299584,211.079737,240.453484,250.782715,227.412645,137.371537,91.63432,66.703284,152.262542,200.816122,296.653143,342.739193,363.031992,349.572241,334.735086,304.692748,183.648375,115.847954,119.077692,146.77398,147.061169,139.101858,149.547204,152.709392,89.537926,65.997736,103.664832,142.404875,138.856029,107.89746,111.343525,136.263549,129.830455,98.696697,126.921656,228.707954,229.533545,68.567658,-43.795189,-186.386925,-176.43444,-132.8416,16.902352,103.099165,164.32976,113.437857,-64.803178,-141.351823,-182.022639,-67.381985,-5.517385,-10.329342,-73.770043,-156.76621,-130.112521,-37.670694,-97.826761,-163.618773,-196.687206,-159.617032,-111.66289,-124.000337,-181.827544,-218.563917,-221.731926,-66.866247,19.669085,63.715014,8.576464,-99.285873,-110.532623,-145.987187,-159.221634,-99.624388,46.622609,77.871151,49.221017,13.250646,-59.490921,-93.493023,-131.091751,-101.950244,-67.457592,-14.295813,-23.075265,-115.384271,-185.735866,-327.368958,-397.529056,-393.681452,-296.302086,-227.504107,-167.012411,-180.669273,-236.001414,-276.776277,-364.255889,-314.438829,-208.232388,14.83293,47.560108,-27.575051,-93.338634,-244.987007,-294.193057,-252.115962,-139.611621,-102.665597,-75.632399,-88.612581,-185.398111,-232.419903,-207.717468,-113.578852,-77.691273,-76.411734,-137.105306,-308.500667,-373.413707,-426.451961,-359.802093,-297.53925,-150.682879,-91.616834,-80.86295,-105.923235,-129.044129,-139.645774,-126.898333,18.414766,94.575358,128.494217,79.524357,-69.193877,-131.440001,-173.021783,-109.385466,-108.406668,-195.318029,-209.024925,-150.830962,-138.7823,-197.82979,-236.359055,-247.649108,-181.451462,-138.0682,-51.418771,-45.918232,-167.342745,-241.315335,-325.159756,-382.31227,-388.861948,-275.480349,-187.658242,-149.590694,-203.231698,-292.130167,-289.389029,-237.420057,-219.112789,-201.635651,-102.169009,-70.23858,-135.161735,-208.902586,-324.798165,-297.614925,-247.305669,-79.745966,19.930524,76.076853,8.358617,-168.786232,-198.382949,-95.363664,39.997737,73.034134,92.753369,83.30241,27.116113,2.366858,6.973715,44.016337,85.383693,222.800459,274.676262,293.680656,284.978911,220.452728,163.115509,179.292389,395.684805,465.531211,456.739419,414.484833,275.073647,185.056909,74.702697,93.194807,100.701294,103.628415,126.160109,168.794764,157.491403,84.614523,43.623286,2.645289,61.308759,106.843591,118.485108,70.795915,-37.167111,-51.849156,-2.893524,13.802752,-20.851076,-50.081941,9.204171,141.30647,131.454372,-69.600396,-192.849873,-235.39885,-7.683323,95.247361,94.929448,15.907576,-107.091472,-136.452307,-200.451358,-209.753492,-169.229014,-31.256524,42.207664,129.390234,139.585972,125.134414,96.292559,25.379769,2.05379,14.625018,115.006251,179.772808,199.651096,141.525297,4.181129,-54.785193,-87.434856,-154.786521,-140.596373,-106.01518,-136.86797,-235.610535,-276.187676,-271.717252,-116.699152,-32.887275,79.996372,116.110707,157.186454,142.192398,-5.265931,-145.454358,-145.433478,-93.430477,-106.92742,-244.573623,-301.647958,-282.967877,-265.1908,-326.173701,-353.208407,-289.244243,-110.834576,-79.871769,-122.601084,-129.649767,-71.376856,-15.743407,11.510168,116.470929,168.730734,168.643117,118.362115,-16.044837,-88.652759,-192.578988,-129.565517,-44.25267,102.636909,118.385956,44.059842,-9.245213,-90.801869,-67.942983,-0.168313,128.635361,143.165075,86.490466,39.051955,-33.168697,-46.180635:163.718897,240.828378,289.474414,315.512699,263.305501,91.892544,9.190295,-60.355443,47.093542,109.212702,172.962689,177.61388,131.541228,103.997685,94.897444,104.842656,127.961086,103.652843,80.568697,115.036375,167.692427,203.769022,163.094138,73.676363,121.552035,207.967604,424.771428,485.176503,424.813319,371.469109,361.096534,379.122937,421.28193,517.616246,571.06259,605.393029,587.449961,508.309069,419.889089,187.941903,147.098738,198.436457,263.654991,258.137185,224.277346,208.436358,168.030936,154.952313,202.964724,265.545113,261.779278,178.655977,128.089638,123.72485,146.221839,136.751478,127.333303,130.15768,142.408277,154.398285,129.69899,92.327728,16.146101,-21.07329,-57.44524,-32.861131,-26.495413,-37.856867,-25.545556,80.854412,119.314067,63.814641,16.693295,27.613754,64.307019,72.47119,19.790515,-14.93389,-30.016611,-45.185029,-95.643184,-2.630235,90.320376,220.808972,236.530191,231.123157,211.974222,141.96662,182.123732,243.755213,340.955836,350.728769,250.921497,163.686391,18.547204,-18.044108,-20.785769,36.919347,95.328251,159.142507,111.214435,-36.968636,-81.213855,-86.342567,42.44654,135.533106,275.321011,291.972013,223.170246,181.571568,144.214718,117.215018,26.260068,-2.387053,21.553855,97.224022,130.544508,178.058848,175.745656,93.141314,28.851348,49.569205,145.994146,176.738977,172.999785,158.065019,135.937359,139.649492,195.383052,247.287198,262.58561,304.818413,308.161509,192.670044,92.858,-28.176375,-17.550959,-10.193471,32.325997,93.935825,198.019147,171.891548,-20.267463,-104.885106,-111.385575,-17.583782,9.534367,3.408749,-22.935764,-56.629566,-45.737455,-0.155825,-27.015478,-81.930364,-171.74555,-172.889045,-133.265228,-139.277247,-221.642006,-248.447289,-184.696112,-47.964757,16.004334,37.843266,-31.929391,-189.287796,-220.299338,-224.028118,-160.236156,-89.129133,87.141991,156.797035,178.994532,134.954881,-8.047454,-72.951109,-94.43067,-67.607337,-69.491432,-37.331916,-18.252037,-47.669698,-98.287275,-237.247009,-310.062227,-292.419166,-182.275051,-133.318258,-131.104552,-169.047246,-264.18762,-292.017353,-259.417747,-155.354375,-89.830694,50.205567,94.812194,72.127365,-2.337997,-204.895706,-304.362804,-279.365472,-100.707173,-17.819612,-19.433866,-68.294181,-149.384439,-193.147371,-272.341389,-224.708933,-160.986182,-101.622228,-145.193825,-314.68163,-391.663124,-446.503446,-377.287025,-332.872211,-235.079237,-201.919996,-215.720665,-231.998809,-263.954283,-287.815269,-254.927781,-133.546769,-85.745102,-34.843859,-59.594703,-199.908479,-256.799679,-265.297234,-203.056388,-203.029692,-248.410824,-236.559583,-186.98413,-208.802947,-326.291918,-368.43408,-326.564665,-197.888137,-167.47537,-180.057345,-196.4232,-236.50103,-253.582723,-298.024996,-379.7047,-387.64876,-283.150022,-209.259359,-125.344166,-124.099764,-158.467059,-166.44656,-129.89204,-79.370735,-65.390919,-11.116797,20.431014,-15.778703,-98.164441,-236.225401,-167.739614,-93.85159,76.642475,150.889677,156.521077,85.41843,-66.911693,-76.090565,56.942929,153.554817,146.04977,94.441028,76.04725,51.212167,33.189871,28.608602,99.649835,140.569651,230.574959,276.476292,291.511739,252.262284,151.138153,118.426928,170.499848,380.847791,462.627996,432.851591,339.467118,173.341248,131.647027,66.123953,32.629817,33.880188,41.064718,53.302054,76.414722,59.689005,-33.689964,-72.517878,-40.874842,97.749176,152.056697,136.445259,87.389695,21.144821,1.991046,-53.750189,-65.641329,-58.189902,-38.241014,-12.81041,19.555141,13.428401,-38.803644,-82.390723,-103.952367,-6.333405,36.936716,57.388804,42.369505,-21.89516,-72.992713,-149.049061,-122.051264,-90.931327,-9.422098,48.749716,151.21382,152.136703,50.827957,16.932255,80.123847,169.133544,182.647176,178.684555,168.735125,135.977988,109.599369,47.82688,78.419916,111.343108,101.348907,64.497296,-28.518053,-81.373175,-172.706088,-213.028105,-265.097785,-165.658087,-72.547805,71.415505,90.367405,32.123388,-30.79065,-158.213467,-148.624686,-115.262116,-100.489235,-119.339354,-195.616971,-227.387938,-227.915061,-223.28046,-270.851185,-273.151975,-212.221976,-61.785563,-21.157551,-22.058173,-42.423168,-67.209582,-48.753525,-13.814827,146.459319,214.971147,147.729159,66.700089,-4.347445,-24.880756,-117.405126,-131.066502,-49.426893,183.3631,229.546114,132.381801,65.426845,2.339701,37.633379,106.044596,260.403218,288.691369,210.866384,129.450053,10.912841,9.203578:95.086288,101.657877,106.341063,106.220942,85.844599,52.923541,54.529158,49.466128,1.870304,-35.543336,-43.139484,0.299163,56.056945,54.938937,40.811614,9.303081,-60.057396,16.723055,78.250299,143.849493,147.858208,95.10165,35.893876,-101.693478,-107.82742,-31.948241,213.005774,316.975781,350.150121,310.310056,270.850723,280.12427,312.551126,348.805001,394.734254,532.492769,567.326242,504.805788,425.905254,253.20541,179.696569,180.044647,211.047673,248.940181,307.819833,299.55254,233.623834,203.597262,217.523826,279.488361,312.492075,360.246071,330.566137,179.048339,117.258418,65.668896,58.481918,65.555382,124.527245,162.881361,136.648144,74.574367,-41.601696,-92.249792,-162.733553,-166.617075,-152.416011,-80.126706,-35.533042,17.522442,12.415875,-52.212726,-71.201859,-44.806845,15.437111,21.074464,-29.741916,-62.120523,-113.531553,-144.412276,-154.623079,-43.668295,33.853188,202.239402,251.037058,232.288063,196.905331,172.994279,295.157457,344.590844,320.652213,317.347605,335.240878,275.97196,51.461074,-16.578097,13.647416,56.762467,57.328241,81.845007,88.587967,74.638763,65.316096,39.365646,70.831994,120.819277,209.016479,236.155567,293.95903,318.441872,290.795268,225.344671,70.794448,49.025768,98.343486,182.98196,172.770703,131.715937,124.60538,35.888768,-56.309723,-46.002084,49.105178,113.835088,210.413028,213.463456,162.356739,152.3375,186.004305,178.747606,182.779541,276.588486,314.974454,230.8386,123.476266,-64.69358,-121.40616,-103.963981,22.065336,109.779442,181.013703,142.002949,13.895763,-53.606201,-116.627613,-5.520108,64.315578,103.547497,70.519982,25.69403,52.396329,105.325304,17.32659,-38.743487,-64.173228,-44.554869,-33.023523,-69.141465,-206.766615,-263.654314,-249.491997,-143.201143,-89.644887,4.950776,10.958809,-46.581713,-61.927492,-82.894401,-116.75875,-91.813228,55.183608,130.011176,189.246558,172.974094,72.018238,2.263603,-83.426356,-32.733203,29.19081,131.278526,114.459497,-69.244196,-184.803379,-342.12632,-336.798607,-299.698774,-225.258094,-174.190809,-55.475737,-33.669138,-109.096301,-176.404869,-241.017048,-141.275737,-43.045927,167.683459,212.662796,91.865117,-33.353845,-235.385363,-258.005561,-222.301958,-108.262208,-43.43667,19.829445,9.874363,-67.163661,-134.104103,-211.773077,-99.205742,-22.362026,26.543381,-17.360864,-171.996943,-243.154596,-323.924204,-317.391691,-286.910381,-188.604822,-126.135488,-45.463372,-43.181579,-78.82985,-104.932517,-94.292428,21.324878,54.268518,-35.274379,-139.278521,-292.209308,-301.242815,-274.715626,-235.719331,-208.287232,-198.191851,-204.237594,-161.226266,-125.461167,-142.675025,-192.358455,-232.496658,-205.46589,-190.480304,-99.226383,-63.759025,-139.753267,-226.385813,-386.9616,-396.743477,-337.124326,-224.626468,-200.949907,-187.898335,-191.910211,-204.513419,-208.101044,-235.258589,-258.542329,-227.80991,-85.495386,-25.103232,-32.95088,-96.717706,-232.15121,-227.682446,-179.079589,-80.357819,-41.105921,-15.53612,-42.348125,-116.334317,-131.841482,-84.302256,27.08938,77.45065,169.54579,199.638173,166.64285,114.789638,28.384341,46.780003,100.675706,214.122298,246.353102,268.88427,277.313336,270.134628,226.139368,147.470965,266.381116,372.549884,501.85542,481.514693,294.772594,178.691911,20.234087,2.218916,36.106626,104.042883,98.974592,33.871779,7.60987,-20.174327,-40.009042,-61.787776,-30.951004,-24.171716,-6.200426,17.642884,63.22629,54.015485,-88.747835,-246.09668,-262.778263,-170.590975,-86.987651,-5.58437,-43.349381,-144.55262,-164.412351,-144.897952,-62.395452,-32.892486,-31.650054,-42.761597,-77.837955,-110.981886,-224.409708,-306.162729,-279.751863,-94.233887,8.25316,62.937174,22.41784,-22.381063,2.366251,78.556334,93.878982,86.052454,112.806137,126.492322,61.857228,14.933873,-14.244803,-21.493581,-54.05542,-150.531876,-166.573817,-122.958527,-105.937016,-119.102832,-135.948664,-149.56727,-122.516023,-92.564838,28.123944,93.906919,99.957314,28.889169,-135.759873,-164.687501,-157.13713,-207.249531,-232.492398,-193.336411,-154.330651,-138.955645,-185.136354,-342.153947,-361.163483,-272.623748,-65.71737,-29.199038,-14.00339,31.487329,124.780291,81.866766,41.623608,50.125293,99.868019,126.712059,68.004521,-78.985476,-129.924972,-177.184288,-154.043884,-117.709661,15.624881,76.936714,87.316299,43.153495,-75.096834,-84.272773,-26.541154,85.847157,108.067956,96.325695,62.014928,-32.121232,-66.523687:-27.036695,40.342462,89.871747,111.897021,69.893842,-31.948543,-63.075978,-79.576205,-67.817668,-76.16208,-44.66723,10.952284,83.984191,82.849907,29.619944,-3.121199,-7.844288,46.672995,84.286099,172.579199,192.068002,109.612987,27.901429,-79.600148,-32.72331,34.635906,200.712763,255.908088,238.308975,212.305121,225.492085,242.853477,266.589939,258.470944,266.0007,348.454372,370.328568,263.593895,172.325374,68.952931,95.530345,132.309216,208.701504,237.316219,248.100386,227.256429,144.636014,102.138618,86.475685,156.493365,189.441324,165.018029,108.055752,34.480828,24.385689,-26.312209,-26.76502,13.129785,106.013025,124.685659,82.644973,46.260304,-23.537901,-60.958225,-125.456305,-135.85423,-121.758111,-93.272432,-86.224096,-38.279336,-6.567333,-18.859341,-37.415255,-4.776393,66.917662,71.759496,40.463717,20.02409,-73.110927,-136.152297,-118.730788,58.087529,121.210575,186.044352,195.584927,162.177819,131.740823,109.306486,205.201851,256.39525,285.02758,275.370954,209.263222,152.084678,-2.453637,-78.595088,-108.474015,7.539909,68.426159,98.006894,50.096463,-80.521801,-134.003386,-214.68215,-161.730947,-85.461581,28.806181,52.878121,87.119223,102.301445,108.006787,84.332835,-10.561561,-48.202368,-19.782342,64.328124,92.463148,95.336622,54.843578,-71.345006,-102.56153,-75.046795,33.695489,114.250933,231.07423,217.180787,66.269819,1.209601,15.639587,135.343571,199.346343,293.625926,298.830641,186.400053,83.625474,-80.004784,-55.476668,-6.885592,98.946737,163.44173,213.933984,162.20553,-30.128938,-125.508604,-173.696689,21.69711,118.270008,126.727353,70.486117,20.830061,34.210053,69.84126,78.159173,53.581817,31.728933,46.707848,-11.760987,-93.153922,-241.038291,-283.833407,-292.356105,-171.400004,-66.10754,70.072989,53.549495,-16.078481,-38.690772,-106.179127,-98.888845,-34.070613,157.807769,233.163599,236.716821,185.090991,46.07379,-24.999834,-59.824591,-13.224642,9.479881,84.394287,92.485229,-8.169445,-82.721326,-219.416305,-219.404673,-161.89804,-79.891579,-67.912459,-40.31808,-38.590169,-105.309314,-141.756476,-140.756257,-42.083092,49.507597,233.096819,252.898409,126.822563,25.338238,-162.978105,-194.391677,-131.74336,68.511074,155.438512,200.008169,145.381614,-75.639433,-182.491645,-224.299692,-115.397595,-59.27476,41.357358,45.004116,-106.58315,-207.800123,-308.480464,-296.516439,-281.58326,-194.986668,-126.265642,-88.271479,-123.276974,-165.474359,-165.955862,-141.215653,-54.011876,2.982163,53.320946,-11.319001,-269.41797,-372.978014,-413.849195,-275.454283,-199.713709,-132.128929,-128.934285,-127.074039,-128.947897,-188.101345,-247.688339,-321.572751,-227.473925,-151.151248,-65.767356,-71.13111,-165.144367,-239.96618,-332.911964,-267.137964,-216.902463,-114.310697,-55.788032,-21.123837,-58.14844,-145.911699,-168.712047,-127.489766,-37.091348,-2.522217,98.912101,154.754657,157.14371,89.491919,-49.924376,21.384288,114.928047,241.826749,248.122896,190.504163,148.467613,33.201373,-17.647978,-25.336282,46.003008,96.339104,197.587099,215.297482,179.240903,137.816733,33.563068,41.652615,99.953226,234.897012,272.440095,216.440788,157.558254,85.025911,75.917709,139.763811,308.989747,388.565783,441.258972,404.531418,273.943696,198.940789,20.199887,-64.510316,-17.945173,135.957224,159.863413,67.964304,2.154814,-119.659835,-159.619917,-113.949081,18.706613,58.676144,87.627135,97.922888,66.153634,-12.458781,-233.251866,-292.449054,-252.872638,-161.775113,-125.693635,-62.892746,-36.10225,-69.118363,-132.752801,-161.927279,-2.005441,80.051219,143.894494,102.750061,-56.229772,-118.010631,-166.013012,-135.101223,-84.968161,74.491428,152.724663,166.33455,98.425794,6.139584,23.069181,98.103521,168.032612,206.795339,260.897174,256.771243,197.588689,154.687371,71.513638,82.027897,105.302925,96.729586,73.937627,26.241774,1.087477,-42.583881,-63.267404,-98.163722,-63.159245,2.221821,157.492613,181.879125,75.542757,-18.907513,-178.894347,-168.57027,-129.69798,-98.00107,-88.606235,-93.792926,-120.779737,-158.98029,-168.969598,-206.940844,-209.149046,-187.523688,-131.549199,-97.608989,-32.189403,-19.606942,-32.305734,-3.776893,30.661896,113.665468,147.662172,124.797902,57.704039,-121.049387,-189.264916,-216.261906,-153.133937,-98.757385,33.255649,55.591707,-7.951773,-49.770595,-104.746466,-55.96627,8.256892,116.765245,143.744015,117.153478,51.042679,-97.915837,-126.640299:45.833393,-36.55652,-18.330977,140.588523,209.276238,161.546392,75.761288,-7.478801,2.696598,-47.938769,-147.752668,-110.345522,19.184893,22.858427,-63.531547,-95.450029,-61.87874,39.15549,67.974212,66.868877,48.219446,-14.56167,-61.09767,-169.303641,-200.532584,-165.677726,-15.065013,74.310476,150.43542,136.633971,165.218769,212.826851,271.112721,289.024896,307.568516,396.092847,438.254887,374.429835,258.890739,36.568825,51.126367,106.616694,185.407103,225.16825,309.782597,340.630832,380.040338,387.612841,425.563249,452.061268,401.377493,250.883839,209.127762,184.423355,172.5715,107.211887,64.26088,102.909992,235.77197,256.762617,130.072458,28.588611,-98.705308,-126.900007,-194.893327,-260.004212,-239.699108,-84.417403,-17.188403,-14.045508,-58.622237,-120.141138,-62.087425,-37.808277,-67.372903,-87.872523,-112.02841,-137.965544,-204.977816,-206.766594,-122.210294,-48.300861,-29.96818,26.510152,69.440155,129.262405,108.268494,33.96276,170.793387,276.495252,363.344935,353.955328,256.015804,155.624803,-42.665963,-90.09192,-98.184481,-80.257736,-83.944942,-61.01172,-21.781773,13.469757,-14.023471,-85.104042,-11.088676,93.765809,277.793319,302.274175,293.266457,321.140296,413.277026,405.661929,233.32175,71.112747,61.211086,109.984418,112.257675,47.511612,-4.263669,-122.983988,-170.968093,-151.108872,-50.360718,18.123845,106.296723,106.400698,62.452546,38.50462,35.745179,144.262511,214.660141,249.480467,202.843377,82.676065,27.696942,-87.206391,-106.516066,-57.059,54.936876,93.833223,130.333755,101.327118,-54.726499,-125.579148,-113.815759,66.199675,165.718038,262.867631,223.526252,72.549126,34.12217,33.862921,-23.874846,-73.016367,-113.192532,-96.678855,-75.715495,-110.607732,-252.114073,-312.815304,-300.866919,-130.665339,-42.701449,36.683574,0.423261,-138.715597,-155.415298,-78.529697,-33.582276,-21.488464,44.737937,103.607386,174.656244,153.252145,81.977105,69.964757,58.275854,32.135078,43.57267,79.370297,40.355002,-125.59096,-180.216537,-227.580854,-278.96021,-289.633936,-264.598792,-224.585556,-94.920221,-29.094845,29.001075,-4.250372,-98.39214,-5.4136,91.135578,216.096976,228.220193,182.541804,112.4102,-102.574986,-215.660386,-188.200959,-30.067383,53.323781,159.900716,178.792548,141.294369,78.649547,-54.448701,-23.522407,51.619581,184.988707,182.756362,1.091911,-115.850169,-214.962018,-152.441098,-118.536374,-27.527925,61.177687,220.447915,240.324317,205.69434,176.442799,129.33183,140.726589,162.48796,137.080693,57.333536,-97.475921,-104.650025,-44.341657,-11.973862,-7.900944,-32.009264,-42.985159,-20.919856,3.961412,28.727306,3.544982,-73.549693,-38.420161,17.278982,58.262647,16.497751,-89.627899,-134.189111,-255.478572,-261.818412,-174.148248,-31.358831,-49.116019,-128.96434,-124.377566,-127.01755,-191.781201,-321.032641,-220.204264,-127.076091,-20.64511,-15.748608,-58.294598,-99.980228,-199.650156,-182.383069,-121.930262,-45.994348,-56.125369,-106.260364,-122.69067,-126.091293,-128.696355,-186.106347,-204.010578,-131.93577,132.235579,221.214317,158.943196,53.696535,-135.560037,-121.783279,-14.947122,211.323821,249.68624,185.937766,153.634322,196.057882,232.043757,247.756178,317.520427,405.599975,565.192359,575.743312,410.09852,257.936098,9.05168,13.545205,51.948872,46.156225,17.767617,-21.112736,-36.294176,-96.807943,-129.743658,-96.816809,-15.527965,-20.767132,-32.480205,-1.069502,59.730759,36.422025,-123.816902,-242.737149,-243.437285,-139.356013,-55.856227,25.192822,-20.29471,-174.808414,-202.799002,-108.741479,-4.569428,-14.847317,-82.188707,-87.427344,-72.80828,-86.201757,-175.840062,-283.419271,-286.526844,-164.034862,-87.089603,-5.060324,9.228139,21.990404,3.919602,-55.230016,-45.438517,-10.691902,81.796575,93.336526,-14.291513,-80.34233,-124.944268,-150.622455,-200.592904,-336.560731,-367.106918,-259.236119,-149.026208,-23.726948,-58.048539,-166.385889,-165.255557,-145.455088,-53.832285,6.691423,43.324533,15.849085,-33.936849,-7.424483,-10.150749,-106.188469,-142.519769,-98.249411,-45.215925,28.285331,8.149658,-172.113159,-276.115146,-215.172532,-47.018865,-36.483305,-93.306318,-86.254931,-19.700837,-43.742226,-72.785304,-35.202513,18.155474,41.56951,-20.066359,-213.219121,-303.185975,-419.428826,-443.170511,-420.661342,-263.621466,-170.849857,-137.002882,-192.497786,-304.705885,-282.615768,-239.115729,-216.816954,-231.780391,-206.898205,-174.088844,-169.073896,-198.036756:27.146275,-42.939715,-22.818624,72.442922,90.300511,34.150576,-20.485166,-91.095186,-83.755419,-94.99173,-117.553751,-93.622352,-39.546759,-41.441659,-100.889218,-134.067248,-115.55119,25.939935,113.989302,211.568901,194.994127,83.251104,4.010442,-166.823463,-163.756572,-66.876144,173.094793,229.815036,139.919178,65.576354,52.483554,95.106187,159.431626,237.437041,305.112996,433.442757,447.363258,360.880258,292.842774,165.586257,126.617039,156.363441,232.655419,261.880831,342.072251,380.258676,354.528742,292.629278,221.40342,278.703188,312.111994,332.649747,302.936101,147.326985,51.890307,-51.387071,-18.530862,16.141835,129.301932,187.670457,140.782549,28.489794,-185.221501,-231.662313,-205.202983,-141.78747,-130.023961,-110.48753,-100.9642,-128.437779,-166.466413,-207.716977,-151.797942,-115.525576,-46.698694,-27.183383,-66.423067,-109.132077,-178.437567,-191.26592,-132.421914,6.388941,81.37337,206.255782,212.974128,71.321015,-22.000832,-52.109529,142.246921,238.544391,307.417482,276.113846,127.265778,54.0184,-37.570605,-71.330295,-81.057612,-20.781821,2.978692,22.300068,-1.758882,-137.635129,-215.714321,-290.764075,-185.840681,-80.077175,99.590468,130.800811,110.819606,97.695683,77.09311,55.310871,8.038222,-10.815648,5.603152,85.797983,102.649269,16.851687,-67.169726,-246.881949,-282.28903,-210.326709,17.997458,114.612411,152.554838,89.561611,-69.388366,-91.387406,4.845939,98.644583,132.351739,205.398556,215.11969,106.511239,9.682183,-127.424308,-139.833426,-128.441612,-65.304899,-1.248978,91.818798,68.659962,-93.018172,-171.885372,-207.169587,-58.339646,63.776224,215.364682,185.94329,52.790708,36.45437,97.517925,56.339904,-9.285284,-65.330219,-59.405958,-106.835326,-174.290376,-342.299353,-409.517056,-434.890776,-295.430295,-192.925901,-39.700077,-25.585535,-87.671217,-126.789662,-169.849134,-121.424374,-60.03382,86.442217,147.257613,156.248405,77.164933,-136.891594,-178.656981,-124.49077,-75.648875,-33.461493,81.011115,88.152558,-19.326321,-96.869706,-241.623979,-252.504653,-208.041389,-114.775938,-57.169657,93.012977,150.888196,151.582936,86.524215,-73.586215,-28.212319,81.672791,281.491157,314.135028,243.249962,153.0676,-47.219279,-52.135289,10.325417,102.56115,125.540845,170.537273,173.096844,77.382425,-7.619042,-137.694865,-66.007566,40.286802,178.733446,157.823154,14.716253,-71.258918,-197.001684,-166.353804,-121.130381,-3.800806,85.027567,212.503996,209.539054,131.500505,85.023928,57.086275,130.761383,164.991243,188.956327,161.847214,15.787774,-61.278316,-112.555649,-74.841618,-57.554116,-17.666311,3.634123,4.351855,-10.810982,-88.161999,-163.567811,-234.990995,-86.329734,-5.781901,80.995249,87.54528,-13.023164,-108.92671,-259.236948,-199.020729,-96.592569,106.87212,146.993787,58.580411,-16.466207,-87.333686,-92.652671,-106.423216,-70.542296,-7.467351,143.397285,188.943651,166.583271,96.917862,-62.905795,-3.639419,103.92919,267.44668,281.567699,187.682447,113.821145,-20.509574,-73.689249,-89.618319,33.566769,122.271415,322.360354,391.832199,344.533309,235.442758,-4.553515,-31.485534,64.277601,292.812268,343.251222,281.275171,233.110567,219.156996,226.309822,253.740613,357.460607,409.474698,466.404587,478.119476,429.875836,326.813609,34.838071,-53.97124,-8.740354,102.393458,125.603477,43.437286,-51.172603,-202.139095,-214.604784,-105.497315,47.339573,79.111162,88.482824,84.895385,20.371657,-45.212632,-213.131323,-310.936742,-293.767089,-172.229343,-102.474952,-44.984782,-82.487797,-249.690344,-317.387458,-264.676318,-50.82733,11.368936,-27.127421,-73.627576,-106.609454,-118.186474,-224.157882,-339.739245,-314.43255,-77.780837,42.371476,67.347556,3.212566,-64.660062,-44.688236,15.153389,44.202726,78.145396,182.687913,189.272954,78.104162,27.243847,-28.66261,-82.841762,-98.364517,-107.375041,-96.858316,-47.122112,-30.655876,-96.196486,-172.874575,-238.033226,-79.801248,8.399986,65.350945,45.214595,-31.530678,-89.816554,-221.128095,-247.857791,-221.23083,-143.923865,-105.054451,-56.433627,-43.654594,-54.506357,-97.692796,-225.869188,-280.856803,-244.205816,-68.850104,-1.498389,-30.80263,-91.580442,-139.288314,-46.962769,-8.916468,10.800696,9.312369,-64.515426,-142.426125,-295.804827,-349.449773,-384.415546,-334.648923,-299.102764,-204.087823,-164.212506,-185.501829,-229.362661,-275.375199,-245.213923,-215.14006,-156.832603,-140.252788,-156.538309,-188.412335,-280.454464,-331.730323:164.608971,28.775962,2.005399,148.095815,256.712643,329.781131,304.725092,198.008967,36.589938,-31.19324,-70.611022,-28.635816,112.935685,152.423735,77.851598,-1.514046,-34.351826,112.755793,158.20218,165.308663,153.36967,80.562176,22.601437,-82.853932,-51.359896,37.497207,214.936757,240.564575,192.293842,166.894876,186.508776,216.118005,210.142377,145.012364,141.645374,196.025692,199.474745,106.857689,54.863469,-2.529697,-28.782155,-38.42023,-33.184426,-4.563593,101.64698,170.919292,283.187804,288.925226,239.932832,242.243155,246.231138,220.371843,193.802966,134.791554,110.212518,45.084846,39.191218,108.254516,288.158098,318.213667,212.037743,130.689149,-18.388622,-107.273676,-265.191481,-315.763364,-304.572486,-143.325681,-23.202496,38.198482,-52.935139,-281.924015,-291.613041,-227.568543,-176.366352,-187.253031,-111.915795,-43.131536,-36.187703,-109.465531,-218.633464,-140.939814,-74.872602,18.632958,31.111422,40.311526,66.997759,93.0627,78.781151,116.693509,235.325747,244.580555,102.587847,-10.668055,-182.011297,-214.663697,-212.208352,-170.538346,-164.395861,-204.396398,-221.298168,-194.278088,-157.060643,-102.391611,-56.665539,-4.947742,109.743239,167.774825,300.049206,341.135873,313.673257,257.947824,133.00721,48.945564,26.697573,2.248589,-7.426224,-10.3092,-20.586678,-124.144949,-220.181277,-229.962174,-194.20099,-128.152623,67.115774,128.214588,76.863429,-3.739026,-100.321632,-98.68763,-95.849367,-73.968217,-61.816524,-49.56738,-26.281315,49.747713,95.082934,96.286695,79.669971,98.217275,212.990242,259.645131,185.450093,78.738614,-22.017077,138.127668,222.800957,256.538011,215.251326,124.868544,99.060834,55.786242,-1.89195,-35.545522,-83.087358,-76.914728,-56.368828,-85.187103,-192.33625,-222.0116,-193.639015,-103.258911,-45.216999,79.89233,122.935546,138.113884,127.3111,108.844714,131.801686,159.93183,186.47049,190.330348,207.47474,218.163687,227.300709,215.928406,178.71398,205.840056,239.568632,220.332755,147.544119,-9.754767,-41.072797,-78.899016,-177.857892,-200.357835,-177.861758,-152.514208,-47.769667,34.535217,147.482667,127.068857,-0.359482,48.242948,146.727634,244.122946,202.074966,101.088953,94.82446,51.349281,-56.381445,-69.011007,-35.807276,-3.033768,128.3321,196.509771,197.334335,114.753566,-77.615123,-58.761347,27.731735,172.956884,180.817227,61.251218,-24.24036,-162.945118,-192.77081,-164.697599,-92.461156,-42.110164,83.044215,129.674975,144.364073,121.821769,135.135696,231.376137,233.396069,152.508646,116.802217,83.044007,82.914071,84.487881,-0.957882,-42.67108,26.309497,100.796509,128.02515,105.330308,141.192825,162.248012,98.93008,60.067012,98.890718,189.401014,184.682109,82.357062,38.534142,18.571458,64.213165,94.092305,98.092861,95.649239,125.354521,116.452936,12.07647,-39.34948,-62.156599,-87.067676,-125.710439,-85.197929,-2.760929,71.101633,45.448483,-38.803568,-67.633599,-28.888701,74.15062,88.848732,9.865317,-47.656908,-87.406754,-97.401785,-176.745583,-231.143122,-217.850531,-73.680151,21.217171,38.83873,-49.33298,-236.589593,-247.378335,-176.323699,14.878235,87.215201,128.893652,112.445205,120.583128,161.374431,211.67555,189.307008,195.986059,257.825203,271.945905,198.155632,130.478541,-12.971176,-113.638401,-117.707605,-42.906251,-4.401188,-1.552047,-20.905039,-11.651707,22.809136,83.286056,85.17886,67.622138,27.200862,25.341007,53.583209,46.505279,-57.348889,-125.943895,-107.037602,-14.937944,26.696441,13.037889,-35.026336,-98.377319,-104.945152,-89.138235,-65.504854,-66.167823,-53.726718,-56.278082,-110.865444,-124.075288,-128.26743,-234.699312,-295.01594,-278.765402,-194.017674,-37.603546,-3.369305,52.76428,76.686044,78.441084,37.369215,11.005197,6.94881,35.374153,81.53303,75.661098,-27.420259,-184.747715,-233.501255,-254.080836,-228.984026,-113.903282,-47.374359,-1.6973,-48.617139,-158.659085,-128.235173,-100.764316,-30.064467,39.642176,120.579197,83.479003,-21.190611,3.483944,40.774822,91.894676,103.310133,130.602727,158.633265,174.516668,121.884975,-72.061047,-164.813602,-118.936998,18.127624,18.485059,-119.349624,-176.335508,-174.847612,-128.218751,-114.002114,-89.387711,-84.436955,-117.125451,-152.877427,-264.912798,-345.447782,-467.424882,-452.930673,-433.339571,-365.468613,-307.107339,-230.477672,-232.595172,-335.910286,-463.322717,-447.200455,-325.061,-296.994916,-309.11846,-306.120559,-268.314453,-265.116396:-40.446114,-49.491205,11.779578,133.801963,174.495648,271.535807,303.703213,221.070873,47.659779,-16.340902,-40.982316,-0.73669,90.872342,107.089794,80.327312,46.365966,-22.179293,-45.495442,-64.308916,-115.148549,-125.884422,-117.181282,-113.811407,-155.917755,-158.976266,-98.638563,65.927663,127.151301,192.975562,222.871181,292.988263,304.019248,279.958977,317.101402,368.299561,478.036569,493.260808,383.184086,296.806762,148.153015,57.178275,29.470919,4.165235,30.952906,176.679514,258.551543,340.391529,326.53798,296.791177,351.127676,355.33834,287.350985,249.705967,196.333207,173.335556,138.264617,159.419801,197.926041,251.950323,234.997184,90.128201,-7.463426,-97.601907,-83.221667,-82.116136,-204.139199,-241.502686,-144.62938,-70.362893,-31.678408,-58.06594,-164.875205,-266.16672,-272.730171,-230.332501,-207.531267,-190.280351,-193.92273,-210.514983,-225.831719,-218.690451,-108.581702,-50.973283,11.351608,28.691028,55.344357,44.235954,-38.695863,-6.086894,73.480577,179.312048,169.331609,47.182851,-39.305506,-171.510919,-189.986203,-168.343277,-178.548678,-191.847024,-160.903096,-123.379223,-94.102465,-116.545345,-144.821353,-31.330091,63.574695,228.088605,281.042063,348.373776,368.265975,341.186237,269.961812,64.867897,-54.230265,-75.184916,-98.966201,-111.649867,-147.646863,-167.043809,-190.390086,-183.586274,-190.23462,-216.747377,-186.228795,-32.474317,29.739575,27.859883,-30.322458,-154.263354,-174.003132,-151.624475,-138.702862,-175.708324,-269.136749,-284.317,-202.96999,-38.098595,10.544733,33.046929,60.183093,165.520631,187.146186,71.884161,-26.549805,-112.537548,-18.12922,42.353028,82.745394,29.792369,-152.789061,-208.395246,-219.894177,-233.027849,-251.88054,-246.330102,-204.295327,-110.679751,-106.078606,-191.070744,-242.62085,-244.110208,-128.799667,-95.030741,-104.442356,-103.603854,-37.63346,-1.687603,-19.779307,-82.738063,-75.301724,-24.77565,-10.266719,-12.426766,-9.657554,22.583875,19.076219,-50.85813,-47.980955,-16.552807,-29.614796,-70.1051,-132.00868,-164.343983,-275.229552,-327.880299,-317.07524,-269.075679,-217.301712,-102.001117,-72.804495,-58.819589,-73.947812,-127.551701,-77.845287,0.121011,159.842513,178.25975,67.63307,-19.865955,-209.96434,-275.183391,-218.26339,-84.691232,-62.136312,-41.221271,7.222971,113.89355,86.451841,-64.442159,14.460807,126.114402,248.604615,222.724651,75.575305,6.125822,-59.765801,-28.356983,6.778765,110.323904,194.901676,342.700743,357.677968,300.39264,262.486518,272.834413,404.803977,432.021296,342.801741,271.239682,189.205576,187.544537,173.390772,102.030863,72.489312,49.841469,55.947813,98.437867,129.95379,134.163069,78.322687,-39.807949,15.860548,81.507809,116.734748,57.444556,-101.490059,-150.252548,-198.668851,-181.005342,-151.120219,-135.671831,-144.688934,-125.028293,-118.672851,-167.192125,-194.274227,-238.232647,-287.154093,-283.792944,-219.05992,-187.509798,-170.182976,-186.722046,-269.629696,-333.110572,-331.54106,-302.821832,-266.07131,-136.972544,-81.513647,-59.943489,-95.147177,-218.47928,-303.872821,-284.506786,-111.55987,-19.797642,25.783243,-25.908828,-204.331758,-234.594945,-151.274837,8.781084,43.650942,101.569102,141.361849,196.415215,188.766946,150.816244,185.911455,235.809753,353.39114,373.183645,244.286122,131.499986,-24.262756,-24.181753,5.656542,28.948449,6.700869,-28.865244,-7.390173,67.987449,89.647197,93.758892,75.52878,84.013712,145.801605,139.682479,-28.211796,-120.698123,-159.418261,-103.141353,-79.773831,-2.830171,55.325312,109.8224,79.994848,-6.391732,-33.587046,-78.228894,-116.499331,-116.8162,-67.964564,-31.295006,-7.813152,-32.974115,-128.423899,-286.55595,-338.047223,-266.402665,-181.482031,-96.765711,-97.610554,-77.161057,-68.655506,-72.010751,-54.778867,-50.862592,-31.69669,-9.197169,26.497869,2.557744,-160.218629,-275.599808,-294.142133,-339.617452,-333.913898,-199.286345,-112.954063,-49.03106,-96.958407,-221.460776,-169.825457,-99.373729,44.702102,107.272171,168.70963,159.12355,74.273257,-10.857291,-12.254822,37.128766,64.512732,110.337423,146.225965,207.108327,167.671094,-56.268634,-183.607649,-156.36817,-62.978929,-53.60815,-57.457603,-26.346945,19.733229,-24.701932,-27.874578,34.66498,88.258138,157.869132,125.598803,-49.074629,-140.505793,-249.849733,-268.058668,-252.285593,-158.045323,-107.75556,-79.364776,-96.081411,-161.647662,-194.67705,-162.247622,-51.552608,-13.182536,9.366014,2.53832,-0.025975,15.083927:116.392742,11.634576,-3.482697,77.759138,132.705379,156.302462,123.322723,44.930747,-20.508629,-89.307852,-232.512287,-226.096605,-103.144417,-72.954265,-78.48226,-69.868537,16.268501,105.680721,113.948058,97.61319,81.148529,16.336309,-17.492943,-77.733959,-142.770936,-136.030251,29.779434,136.491611,151.355533,70.578308,5.058932,49.151707,135.820714,142.149789,157.84266,264.717706,294.866672,204.740646,141.437796,75.531659,64.605699,88.803068,143.249462,149.764408,169.803019,203.873061,250.119913,231.562606,194.219862,201.991973,186.265603,161.101323,162.485252,134.46106,94.155981,-26.596784,-62.392243,-10.795046,105.750243,106.039791,-6.802892,-64.763916,-148.42844,-200.56876,-279.544705,-258.023015,-233.482292,-154.040222,-112.567925,-139.541523,-207.724662,-270.792183,-121.796668,-59.930161,-41.368882,-36.959002,-43.662257,-79.392387,-172.791943,-206.764935,-228.492761,-186.756081,-138.800601,-8.81134,36.721973,53.144226,44.728566,29.927031,117.088309,190.275518,239.698895,222.289597,173.37455,114.773779,-69.66478,-141.108009,-184.519155,-115.162871,-69.544155,-57.088238,-86.801533,-116.869672,-105.303737,-101.940276,-79.782448,-30.197646,100.138188,158.764098,246.494692,281.880327,304.365544,261.377592,75.117162,-58.802623,-35.972722,95.582957,115.129422,60.891493,38.341876,-5.919083,-35.079902,-33.883945,-17.461318,23.388204,132.365435,137.464873,66.756823,40.635607,8.851569,-3.567145,2.598562,23.26153,31.594672,29.81337,23.470511,4.444898,-3.000881,-1.038808,27.206247,68.443561,162.061622,162.662869,5.924744,-92.203127,-101.472554,96.799971,188.770043,269.885743,240.975101,137.88105,147.744123,223.014405,85.425957,-20.471343,-98.826967,-89.390354,-144.010009,-212.041018,-299.339965,-301.42681,-271.274715,-210.639929,-165.696064,-47.577851,9.845133,63.140263,53.559304,28.455218,106.936123,169.198082,259.745436,283.198272,272.254914,234.792381,129.791374,89.40126,118.722015,214.078617,215.43706,164.941996,148.236455,75.42135,1.265169,-141.912462,-156.622496,-123.110693,-59.354243,-25.304704,94.394466,156.005579,133.500379,32.723055,-108.597062,49.481422,145.713861,180.386779,156.429949,198.794713,247.634441,158.888309,-62.344352,-93.882528,-17.518917,45.437099,122.380391,114.795707,60.964205,20.162948,-84.480308,-64.996014,-5.006578,67.75516,52.721058,-47.082196,-92.334442,-131.226403,-186.449196,-213.793193,-145.629595,-41.852026,119.212625,117.655676,47.352586,20.890697,17.354272,108.605078,139.741575,87.596705,33.175486,-58.855553,-73.871696,-59.285568,-83.746212,-84.710629,-3.057078,36.966743,21.277246,-4.842195,-58.326226,-102.790273,-143.599076,-46.494812,11.081744,68.568441,72.939435,70.425281,54.023949,-15.350067,-23.83841,-6.763851,-12.424329,-18.123985,9.184778,12.575025,-19.281695,-44.078824,-116.333804,-140.710745,-105.305225,35.973454,113.558167,196.665362,157.577935,-97.661384,-224.841877,-157.17785,4.434472,26.589771,9.445222,-2.639736,-64.462571,-107.058292,-125.812133,-58.704386,2.375999,191.680101,259.833451,171.090886,53.044907,-128.978936,-107.032725,-15.95395,168.914295,207.182937,182.474085,153.32004,145.850121,176.849505,264.584124,282.426873,254.250621,222.584059,240.085941,269.940049,232.499457,-2.789412,-180.033216,-159.0331,-21.120899,45.386776,87.132878,38.435901,-99.467839,-125.904446,-106.968542,-119.537173,-126.059701,-67.568281,-17.227351,53.307717,35.228994,-172.314602,-289.023686,-229.442648,-94.857803,-88.389458,-158.463946,-193.122616,-239.183248,-267.385742,-257.843347,-102.883308,-61.696019,-92.352024,-101.446486,-94.840791,-113.551255,-206.283148,-298.713748,-323.162578,-262.348731,-155.729362,57.286078,92.366085,83.701089,71.594367,42.555208,19.940168,24.413817,95.257097,122.928684,81.778262,38.259051,-32.413536,-92.562536,-128.27467,-200.095779,-214.338761,-164.979411,-119.293025,-61.357569,-62.868495,-89.582978,-52.082515,-5.532602,80.875398,82.48613,-30.700801,-109.490999,-211.419919,-142.362704,-64.325393,27.420008,34.263855,84.12967,145.38604,193.293231,112.779343,-126.781939,-150.653507,-81.033051,60.267268,78.796777,4.422576,-29.798718,-28.91618,-73.739026,-103.096211,-89.268043,-65.251988,-61.382274,-95.993872,-243.530958,-331.878468,-403.771135,-321.859787,-281.484914,-180.195709,-99.599534,-10.818238,-51.074421,-215.955309,-280.754258,-247.858894,-134.852041,-98.817098,-124.738791,-165.038171,-190.560211,-177.918946:forward
-136.630867,-243.345158,-270.142951,-240.155797,-166.867158,21.866351,80.179374,83.799527,-3.096094,-42.360267,-30.946571,22.346184,141.071385,169.986614,130.484521,69.837788,-61.427201,-76.351642,-28.814559,131.233892,221.848536,326.206398,315.001731,176.949867,-10.436581,-48.209096,31.534973,109.89691,218.368212,217.164959,118.44678,55.999916,-16.161399,9.207854,32.822506,41.696413,28.660987,6.618595,14.326382,36.566573,-78.828324,-146.195102,-99.683176,-27.012789,16.736345,-4.498781,-23.621221,-13.326437,-12.128407,-3.793287,40.418005,122.534336,113.547638,5.72861,-66.001895,-210.758344,-341.909443,-380.771719,-409.909281,-415.388272,-374.563975,-324.164586,-246.049705,-241.307894,-279.961806,-252.107942,-174.113905,34.374737,110.156742,126.863609,64.708179,-121.610869,-241.987226,-236.582607,-115.630012,-56.744854,-7.976665,9.913338,71.729452,107.801252,150.73822,146.93384,147.165186,161.826197,174.748137,172.378257,159.375542,177.177779,152.698437,108.388468,113.559068,180.108869,292.093175,285.273431,154.115708,58.759143,-94.084586,-103.865198,-68.331943,59.816297,145.413832,240.790666,235.647869,217.366064,188.189971,178.911024,171.588538,125.453155,7.345563,5.740835,49.564668,18.290629,-161.911447,-216.510136,-160.594774,-65.433671,-57.811871,-25.096537,35.847196,142.021854,67.359243,11.798668,-6.757112,19.779694,91.514035,116.548487,49.394649,-50.290006,-276.444122,-333.175866,-263.152401,-71.697895,-15.887087,-18.935294,-65.32529,-173.05144,-189.591922,-170.231381,-109.162615,-78.331582,-57.324669,-71.474015,-93.784926,-81.689379,-61.197508,-38.021077,-10.130624,18.067036,17.000623,14.197875,-0.77976,-55.027909,-86.146676,-74.063384,42.369234,117.251309,230.034637,260.234769,247.72469,216.26959,121.158339,20.058939,-9.993431,-11.952367,20.774303,69.856264,56.997147,-11.667628,-160.304049,-216.436202,-128.990445,-16.970455,173.975296,209.263673,148.686954,95.601343,19.334851,7.509659,35.072449,82.5055,78.011895,75.913839,84.06105,52.963919,14.683924,19.621193,49.02693,74.463723,171.092983,213.915357,187.814519,137.709858,33.989266,-0.558635,38.986039,135.095812,146.404614,104.807887,79.903574,55.192237,-7.04144,-33.421364,8.504238,57.314635,143.2032,156.059791,124.071933,120.742693,112.461311,13.734422,-24.716476,-23.669777,-3.89737,33.102641,37.210266,-0.460897,-71.161521,-95.049188,-68.370991,-34.11343,-12.31176,-56.50581,-243.641746,-319.801491,-341.183059,-264.356766,-213.78838,-121.21048,-60.050789,85.304697,102.644619,-5.318253,-103.84519,-103.470788,-42.911309,-18.017046,15.827083,35.725653,50.083703,32.163363,-36.048999,-39.895097,12.135441,142.522065,192.334717,202.953695,147.485264,-9.768463,-139.113593,-173.035155,-124.513335,-83.545689,-107.169753,-157.275562,-219.175274,-208.360563,-163.795923,-128.202261,-100.140407,2.095213,86.926834,169.054525,101.334476,-94.388497,-149.819569,-131.458141,-59.700944,-33.389544,-11.483956,-7.922846,-38.608023,-71.323048,-131.192121,-136.902809,-109.456352,-26.944023,18.623037,90.802462,91.991671,51.972048,29.731142,31.045396,80.278903,116.947811,182.632744,207.316016,222.716068,226.860104,244.502367,204.426014,178.210134,220.352061,289.122479,413.785889,434.627307,361.750476,178.188155,97.355162,66.061021,116.367009,225.780934,213.604903,48.224427,-11.708184,-17.840056,-54.140701,-82.645721,-56.440399,4.362933,90.453755,72.778161,-19.311236,-21.624174,38.327404,187.544348,218.301668,220.24221,234.380643,255.583874,238.003373,153.649826,106.245548,132.642417,205.912019,217.844871,205.607057,185.035394,75.99994,-38.032362,-31.669395,91.45325,160.160844,264.654603,277.082063,129.84022,2.716586,-179.58082,-159.541766,-94.568957,12.924173,35.567416,16.501128,-41.322353,-216.85482,-267.567367,-199.583256,-7.992984,43.949061,127.755659,189.961023,201.002089,136.783381,11.893716,-11.491784,23.418227,137.638475,194.495347,244.477938,219.272737,141.827291,122.611239,149.817214,247.063589,262.612408,205.806075,172.200607,128.783828,117.571341,104.050321,107.418097,120.998703,156.079869,173.406158,155.276767,107.680948,28.759464,68.60117,110.957147,153.517884,163.413049,230.744745,256.222904,203.490481,162.493867,105.918282,31.16811,7.067194,59.771578,141.321343,266.750854,238.397063,87.099538,7.238298,3.692063,81.914093,154.594514,285.289359,300.153996,190.51825,104.689568:-96.619983,-127.01991,-130.541802,-119.111588,-98.231033,-10.637179,36.135103,32.325631,-58.515888,-65.213739,17.48188,72.695047,152.895209,159.295325,83.821753,22.619639,-45.686299,8.620641,39.296028,32.133322,28.399307,125.381449,187.091635,173.095287,32.3714,1.701287,107.545082,210.866731,338.126565,302.864281,91.683079,3.748969,-15.325057,60.540727,66.495354,36.383361,35.966398,41.394375,31.363567,-5.458283,-73.599532,-84.209977,19.397158,67.73323,18.192187,-16.790646,23.618085,48.185014,-3.006947,-12.031222,40.542345,124.660657,116.515746,31.911054,-30.721734,-197.686251,-331.459298,-344.559868,-296.801434,-262.303268,-187.126704,-168.630951,-186.034093,-187.665575,-201.590563,-239.741788,-190.286052,46.114748,128.388164,55.524954,-34.287397,-127.697025,-176.381814,-187.930929,-122.677995,-84.909346,-85.825098,-95.836951,-72.775069,-55.555452,-54.995237,-27.429308,12.007455,65.174285,81.925017,157.752879,202.971633,201.81186,87.251103,64.620003,152.496184,206.062744,214.435582,180.965262,102.442624,56.947309,-48.236138,-112.446666,-111.895928,-29.288842,42.822121,150.070866,165.105507,156.802804,108.756001,65.628283,6.596253,28.632398,139.635248,168.912844,130.154745,88.181706,-21.099742,-107.018232,-108.593349,-37.676979,2.272287,-30.398277,-93.151353,-166.160032,-155.821136,-139.331572,-91.418505,-63.865155,-6.261188,17.131665,-5.789931,-68.646557,-253.285729,-338.616573,-287.615589,-99.546933,-38.909778,-58.579317,-119.40868,-257.562807,-311.393966,-280.217803,-231.56097,-257.820283,-268.028086,-218.90814,-114.725554,-87.423852,-67.369356,-53.881885,-39.441842,14.913408,34.887212,1.699447,-18.839275,6.478098,-2.510184,-23.296267,30.707212,112.56371,265.620279,289.99198,233.924501,180.607797,72.637285,-33.501352,-78.784639,-79.32428,-24.066144,78.788989,90.968372,48.292306,-118.8738,-195.933016,-169.691776,-82.304468,92.967829,127.577652,68.045416,10.374614,-87.153704,-95.588092,-62.156934,28.004791,79.73611,131.730742,99.332486,-21.620798,-48.95863,-14.121846,51.692118,65.927359,113.356972,156.613899,191.73097,155.981368,59.356177,57.406142,85.115092,139.315388,153.985907,146.836902,127.905397,46.115285,-46.177802,-49.702765,-30.113938,-40.705721,-46.581978,-30.290078,6.800862,13.139307,-56.030701,-135.241056,-116.894825,-0.223259,54.245562,53.291931,-0.013611,-97.431083,-175.12958,-217.200646,-213.631452,-155.91057,-34.670505,-27.760007,-109.454274,-143.54689,-163.193971,-169.866797,-157.125302,-72.713376,0.341861,142.737098,161.877105,66.144675,-61.310714,-84.825319,-57.635136,-29.392902,-20.659484,-56.182038,-119.224213,-110.616206,-75.060067,-95.897528,-81.242822,65.91322,164.047401,220.149235,146.131767,-52.216953,-162.517255,-184.523682,-168.801633,-163.383142,-222.239017,-255.833993,-259.756798,-235.540142,-209.029194,-235.18321,-222.563585,-79.334563,21.96308,123.736783,110.643469,59.803953,4.195597,-19.90379,21.884864,88.315729,181.338899,157.682307,8.539247,-57.133871,-90.61462,-14.272223,41.346987,146.520044,193.001254,308.689007,355.571338,293.659035,116.320941,84.788406,170.169266,228.19181,252.155959,207.446188,104.717179,105.671281,162.558295,109.58033,83.108276,176.378413,248.565713,293.856608,272.49114,187.650633,76.380226,47.346294,75.767632,112.539214,164.401606,151.29768,52.334928,4.916428,-83.696943,-215.916207,-233.456777,-56.77149,76.694385,170.543007,106.94144,-33.260972,11.750632,66.987248,147.577283,189.742876,302.444574,336.131103,270.903345,176.7309,-32.815098,-46.726038,25.022071,169.210747,211.325637,177.099587,94.455587,-104.889344,-154.075077,-97.600181,49.885679,104.08497,168.301158,179.470415,130.761027,67.848693,-38.614073,-45.262899,-20.835747,90.057243,158.103347,206.063188,170.447297,39.953452,-60.116748,-56.665933,-2.427151,-2.294668,10.407697,44.133348,37.285441,-15.245764,-97.278802,-34.811479,38.089818,200.90072,268.519581,294.059939,248.603922,141.72134,154.802436,203.382226,296.607109,316.635827,280.272996,232.162632,111.971659,65.88548,44.861963,91.629144,117.849256,144.938209,163.158665,208.248244,201.352303,84.540743,-42.136768,-44.065413,87.967308,179.454285,290.128829,291.087713,215.841695,156.817182,26.162837,-6.494498,41.204187,136.357567,133.915742,88.854294,85.857566,68.758329,-36.767849,-69.512879,19.490726,123.323597,297.836782,318.8055,237.376598,151.350322:-108.510715,-144.076136,-178.646203,-205.504644,-163.125475,-35.008041,-7.722982,-56.012637,-156.661603,-179.301452,-98.040447,3.069351,194.132396,195.836233,17.611225,-71.33811,-131.099737,-55.416193,-3.907154,38.56599,47.94189,87.323312,91.687201,18.772378,-98.681313,-99.662648,55.730949,141.821123,170.777832,119.033432,40.168693,40.282024,19.031374,9.169134,41.157905,90.377691,79.592574,5.604651,-36.397728,-121.950001,-177.745633,-168.197155,-118.896413,-105.057812,-90.78778,-78.370843,-44.385838,-38.153619,-69.00175,-47.295016,16.467406,146.488903,154.598985,15.096364,-101.751927,-298.099961,-360.033943,-337.197104,-244.750731,-217.313328,-247.299237,-294.415049,-354.369343,-326.816129,-226.905763,-205.646793,-191.657467,-73.228964,0.10422,28.261895,-15.180511,-84.674981,-111.019171,-136.709818,-222.846799,-269.394975,-334.255549,-340.657368,-298.535132,-260.956666,-192.340183,-131.972661,-99.464151,-20.890449,42.534901,153.537608,150.162159,44.188125,-1.661096,38.301295,144.284952,155.88096,102.234933,65.788083,-18.102328,-72.440204,-169.399018,-201.296409,-200.169102,-135.710396,-71.0221,24.547825,33.825377,-12.222357,-92.433356,-102.04045,-25.44723,31.601833,124.58821,144.770184,98.068703,51.325375,-4.729978,-0.27452,3.896453,3.199342,-17.484226,-127.5955,-188.028657,-270.143238,-267.459168,-205.394115,-64.268324,-35.27051,-33.933943,-39.564049,-52.843606,-58.023259,-85.862836,-133.841061,-157.826735,-192.133547,-181.968953,-126.366331,-129.491883,-237.894078,-347.925612,-351.779668,-297.734128,-279.061604,-236.349809,-209.965195,-195.918872,-209.346371,-219.903329,-111.277802,-45.023792,4.357371,-2.144924,-29.209501,-27.200835,15.169679,-44.594861,-89.844473,-9.881122,101.45181,243.723968,236.32811,150.987992,105.596303,43.328054,32.47666,20.328601,-44.626843,-65.37365,-25.954704,11.830166,20.454912,-107.886589,-171.992254,-196.085268,-150.043857,2.511711,46.36611,3.695717,-45.8378,-108.779096,-53.732814,14.862305,134.223087,146.061355,58.562589,4.206308,-24.857091,-29.418626,-38.020596,8.118136,49.020336,70.626918,61.594603,40.317456,12.343718,-73.756444,-144.235729,-160.81743,-106.012397,-43.965263,14.713601,-16.399121,-100.227808,-96.85236,-79.972744,-88.459334,-105.199192,-113.41588,-127.378248,-174.981281,-170.185697,-157.667118,-214.002056,-224.378348,-169.016265,-142.727073,-176.838571,-204.608202,-206.64989,-243.662725,-270.4985,-240.569362,-187.725242,-99.282993,-105.032935,-220.52477,-277.828956,-307.503082,-302.23362,-291.244058,-175.951256,-89.479918,-23.502788,-58.451577,-123.204336,-96.075557,-81.269645,-89.128375,-87.035119,-68.113081,-83.486426,-156.565287,-185.711151,-216.112229,-174.327388,-99.903569,97.784569,172.986118,193.597534,127.929257,-55.103619,-160.165545,-171.672292,-153.435999,-146.233981,-138.276246,-145.88612,-185.499926,-181.88392,-129.032437,-105.167843,-98.020165,-11.509148,62.321194,130.819037,109.647512,55.070541,21.892518,28.956453,158.783966,238.856937,268.444875,241.709456,236.135498,233.941401,165.719058,197.69019,297.438393,505.299234,535.599858,438.225867,373.023021,311.748134,273.743374,263.082469,253.544233,237.089539,203.692366,184.992722,133.334996,124.826833,190.478202,255.887311,267.91791,326.093452,360.004717,329.349466,262.563445,125.287244,51.67764,45.504914,122.217887,191.9919,265.345349,223.707768,45.771036,-30.989776,-112.01106,-94.346612,-44.03351,68.034368,88.841524,57.311907,35.11138,30.796457,78.859296,114.722287,212.728696,287.499327,417.572834,400.372072,202.658785,92.840017,-47.160754,-28.625265,39.583952,182.563745,208.540141,120.885318,23.586273,-161.299088,-154.824256,-69.698549,126.349765,191.719975,219.887573,195.118235,134.470442,104.735137,32.593983,-0.275256,20.952239,133.271034,193.384833,232.39841,209.88594,130.397513,57.783924,43.102775,33.924661,25.852139,36.75371,46.098253,-11.479658,-64.803444,-92.935866,8.192385,63.89867,143.769541,179.556506,240.234236,241.694613,175.746299,147.756628,192.012794,334.063393,365.295287,277.692688,199.510219,73.085603,19.942504,-36.233339,36.238642,83.781526,163.581118,190.175776,171.539122,139.782664,76.366419,43.978556,69.478034,206.276288,268.231052,259.795849,210.245437,157.689066,148.526294,71.002022,8.92656,37.849834,150.525302,191.08308,222.232681,195.766737,57.953717,-31.586796,-35.055786,31.855297,114.549799,304.549998,340.317954,248.137961,158.171001:-127.83056,-176.475596,-214.768447,-228.043131,-172.738834,-57.456039,-38.02753,-42.739185,-127.866295,-178.712747,-178.424282,-123.099533,25.909389,76.692817,47.963147,-31.199053,-185.695447,-115.617131,-20.332658,127.131493,168.163652,182.719907,147.623991,30.238144,-55.866849,-37.858818,113.906221,180.553389,227.470639,211.611732,94.661517,35.777968,18.929294,48.466585,27.938895,-46.86416,-69.201493,-89.405894,-83.827353,-47.484112,-111.568563,-164.65561,-172.485844,-130.198348,-53.059835,-34.055211,-30.376256,-46.26575,-104.912772,-98.399942,-43.187168,83.612629,121.192728,125.353746,82.586619,-82.276949,-283.808005,-349.007329,-342.336125,-309.859471,-314.115639,-353.235279,-400.333864,-378.486603,-336.191398,-346.328636,-298.07852,-63.927841,43.654727,26.169568,-89.935577,-282.848386,-331.521332,-347.648215,-350.21653,-325.017025,-271.139452,-262.012883,-228.930005,-189.615181,-148.186848,-122.297705,-77.335262,34.534912,94.967876,209.014338,224.056622,167.560272,126.833146,127.949354,153.773776,152.873173,109.582169,68.677312,-69.673792,-140.311987,-200.754171,-197.573147,-191.446752,-124.941948,-68.339372,-1.194282,5.033174,11.2059,-0.46327,4.949348,65.128012,101.88239,169.115558,187.61836,109.845734,29.42401,-69.532816,-80.633256,-103.014952,-153.849324,-141.356637,-94.824398,-99.475551,-107.810863,-55.48813,-17.708321,83.182738,134.728919,229.678262,255.938719,177.585476,103.479811,-3.084629,-65.041207,-65.929104,-42.148209,-51.967659,-110.151486,-144.529612,-229.381698,-303.370851,-294.996126,-222.82004,-208.540929,-220.523217,-224.000176,-200.728389,-166.092605,-108.768896,-130.339442,-125.63443,-31.699851,22.115551,63.2209,59.214933,35.764983,-1.275363,5.744666,73.227561,104.684603,160.301396,178.840867,147.324759,113.927364,46.821499,-26.314098,-46.390357,-30.861977,-4.211079,40.570286,44.627458,-38.764113,-234.652434,-279.759029,-154.511548,-51.229948,56.462719,54.676156,34.488301,30.215198,-19.911173,-62.243966,-49.722568,5.55112,44.173196,98.397141,82.967893,2.939468,-12.566854,14.848951,83.854392,94.594313,73.664523,70.526441,81.065633,69.822308,-6.256379,-105.12671,-137.713253,-111.676681,-61.035278,36.859866,61.570449,25.494123,-148.007898,-219.32669,-176.620782,-91.203016,52.297949,72.978298,-4.673666,-74.309324,-165.892006,-147.674931,-112.682917,-39.226526,-18.218413,-48.910456,-92.352803,-156.705991,-233.569893,-273.321834,-249.358101,-188.23842,-97.850064,-128.739025,-303.059126,-359.400235,-370.790711,-341.093053,-299.757367,-175.043768,-113.96784,-46.682846,-50.038163,-125.689951,-230.33481,-251.179426,-211.54559,-172.157998,-95.47772,-69.27936,-49.71222,-52.049676,-97.602813,-112.755914,-47.594444,175.625116,270.742225,284.368335,196.125477,-4.208672,-127.581755,-169.929707,-173.476693,-146.031578,-120.129382,-127.366615,-138.485519,-133.668393,-116.367721,-81.62805,-68.886245,-35.868051,8.972051,101.406061,113.470574,84.746325,16.421836,0.20168,92.872958,179.126434,294.838739,291.482241,233.697101,216.546044,193.765505,219.094495,266.889923,368.904934,402.539837,405.627556,376.864779,333.93835,355.241004,365.631254,318.741287,289.442564,319.48975,345.557497,339.889256,332.735823,304.869994,241.151586,248.690829,373.535908,462.106072,592.831415,590.117262,419.175223,192.959271,151.236598,210.32325,255.368947,298.151932,277.874701,136.535424,39.256745,-136.769281,-208.399793,-183.024573,-73.526649,-26.768251,25.750824,16.209419,-71.267887,-21.307171,86.016776,262.739543,295.121066,348.335906,356.002067,244.088528,181.113232,163.501904,163.006778,132.074773,83.931038,109.131222,181.19535,158.653487,4.186671,-66.291083,-22.580319,148.562709,227.571828,294.427697,270.699443,156.090301,105.411386,51.293786,27.797697,31.499057,80.705835,111.049239,98.690966,57.589277,6.119044,-14.83597,-28.198154,-11.601758,29.96508,175.939382,238.641949,201.751622,118.472657,-9.887304,1.564081,40.46729,170.494586,251.58862,317.178149,286.855712,219.526198,200.314674,201.784331,228.11172,235.7181,226.346423,216.706288,162.121991,123.198095,81.70731,98.485452,110.474395,121.332405,124.208425,111.071282,84.866419,-2.221844,-63.650675,-37.98756,120.368896,197.499987,271.233921,273.859092,218.776181,168.235215,78.2759,84.245134,117.637184,165.853507,194.342926,289.137865,296.198842,152.885063,20.964152,28.420144,140.369934,202.017644,294.373306,320.547343,299.360202,225.703514:-174.775729,-249.197576,-233.454651,-120.525612,-51.382238,10.915099,-13.947119,-128.31047,-203.613038,-180.600491,-75.804718,-24.546727,86.388006,112.716409,25.96376,-63.827099,-235.356261,-215.099237,-117.037769,100.964492,173.302019,196.323383,157.846753,43.378243,-28.564366,3.17299,189.926051,268.470133,284.598581,228.796572,58.241063,-9.522002,-49.896389,-28.431931,-26.880318,-16.629768,-1.598526,-8.456509,-36.085391,-103.642114,-172.488167,-179.3445,-103.346293,-50.506042,39.190039,65.300072,21.558635,-42.16634,-143.019055,-90.880835,-17.415285,130.630564,177.699645,150.763312,61.572668,-167.30099,-320.168266,-346.157726,-301.640255,-261.433947,-213.583587,-230.445096,-322.687829,-348.457531,-359.107037,-353.949614,-301.747293,-86.707267,17.615739,44.046068,-35.972351,-223.705472,-303.690608,-311.058795,-364.022489,-382.338203,-274.582361,-201.857755,-193.483221,-239.983468,-308.609434,-239.965443,-164.674099,12.899856,106.567309,203.282235,175.407596,62.550084,25.341534,37.360425,84.431718,108.029781,123.984726,94.104562,-21.498041,-70.681184,-157.319054,-223.063457,-210.838739,-83.196453,-12.154455,-6.967065,-64.656199,-145.26524,-113.817656,-51.94694,115.431384,173.332372,213.06417,221.751206,205.76012,143.990806,-73.308291,-179.42846,-153.502169,-73.657719,-57.381882,-105.31935,-147.827084,-156.948404,-58.562835,3.132392,109.064218,159.320275,234.817883,228.233837,149.683849,113.520842,56.0596,12.852862,6.427935,10.378222,1.511409,-67.208451,-110.172273,-213.92884,-287.839513,-260.817033,-153.843215,-125.605779,-112.183793,-102.657399,-71.745823,-78.420961,-165.025163,-146.615589,-61.772129,112.241756,154.14175,127.405483,90.885579,53.650926,26.39466,15.497761,29.688386,63.715793,183.254844,225.537883,196.093321,143.200478,56.595592,65.708674,65.05805,13.440746,12.645031,105.307556,142.616993,69.552142,-50.88041,-28.735617,71.080557,83.09684,128.047291,172.344277,197.906394,167.177295,56.342829,0.432789,29.458121,169.218873,242.052103,292.037854,256.680976,138.155872,98.717423,148.78312,295.449219,325.164866,301.048458,282.886828,239.260566,200.753604,101.317391,72.026336,107.935692,196.783322,220.818593,233.261161,223.771347,160.193243,41.217749,9.900383,101.155721,179.718946,221.23052,179.623793,113.543878,110.137366,51.836929,-58.02844,-65.232105,65.671564,146.97186,127.299477,28.202814,-154.749311,-175.695549,-121.868353,-11.236596,2.135981,-22.293598,-48.408194,-137.645449,-199.157813,-312.638784,-262.664384,-174.710286,-6.801362,20.293014,-39.8859,-65.265727,-56.862014,-67.966867,-87.926647,-116.450667,-95.661856,-6.328066,2.214555,-68.908705,-97.78134,-112.309072,-40.20221,48.035438,222.406317,273.129524,273.289603,215.577499,42.512281,-98.314562,-123.121692,-73.065283,-32.091093,-22.808494,-60.1098,-131.816732,-141.770051,-132.573534,-91.038514,-63.745675,-0.58176,45.150173,96.610413,74.131663,-11.464255,-33.226996,6.725793,154.058511,234.525514,326.101244,310.784038,224.816719,187.416733,159.438963,263.531184,340.890904,475.439085,523.74551,494.499444,415.494995,265.293995,211.821447,208.824999,158.264716,106.121734,88.34521,129.400128,188.683345,181.600278,88.3525,38.680954,84.549814,247.829229,306.006617,303.355197,256.012537,91.764705,-78.824169,-85.068262,70.839202,157.503405,212.667011,186.156645,102.059099,39.356228,-167.557744,-308.194241,-291.104828,-163.77825,-113.802188,-105.321176,-124.218339,-183.881377,-195.500422,-122.062,94.748002,164.076221,198.460559,178.626799,90.60607,25.838708,-115.268389,-135.205803,-94.12979,1.548488,46.032876,44.935631,-21.131272,-123.856131,-83.099432,-44.653293,52.61737,112.421513,169.595815,146.137211,68.268914,29.557926,-55.063223,-61.368135,-22.448085,91.786956,132.028737,99.624676,49.511812,-24.748258,-61.303624,-63.048116,-4.66838,52.421092,145.56846,135.70169,8.121848,-68.327474,-195.50679,-211.850613,-161.900923,-9.820784,59.562576,95.762506,58.98807,-26.003031,-62.844155,-46.996384,52.965338,97.020606,94.756659,48.078521,-87.868417,-150.116069,-208.692402,-125.948221,-72.8648,-67.975404,-95.739657,-112.252766,-109.00178,-192.05933,-351.794627,-355.362862,-169.851834,-55.102802,64.647467,59.496775,-3.04245,-24.887099,-43.435579,-49.789022,-41.603213,17.088649,52.079609,83.692073,80.738166,16.378846,-99.045791,-122.476518,-57.796489,8.085762,129.058859,152.038709,94.881291,15.822505:-46.5432,-188.464451,-216.6195,-117.19502,-14.768234,88.977913,58.927154,-36.797927,-48.966323,-46.515892,-39.176698,-16.065416,74.066225,104.424674,42.609276,-9.516459,-24.271397,36.130802,86.399105,238.65112,313.758974,348.006014,298.079047,160.82297,55.340352,36.55543,114.24072,171.492121,204.223852,197.37535,168.431028,133.653029,72.038534,61.14535,42.122553,-12.097548,-9.427392,57.285033,88.936128,62.871342,-90.749155,-158.402593,-159.633217,-108.707265,10.451717,59.016489,69.825763,30.875555,-58.160315,-32.94055,32.340133,133.739448,151.490056,137.651228,79.805471,-96.19684,-199.487136,-218.509661,-215.103932,-201.677937,-174.308665,-178.547378,-245.367254,-265.308626,-208.274434,-188.408064,-189.275491,-58.286242,40.682687,63.994418,-34.038523,-235.008395,-263.249683,-232.711185,-117.894496,-54.355224,40.854249,85.013697,130.653415,99.158964,-1.38888,38.519207,104.421274,172.205526,149.429026,56.253329,26.62329,63.081638,116.525249,112.778392,121.461005,152.630437,193.714124,160.158126,-1.197245,-80.323654,-133.254796,-50.65336,-1.337166,62.383395,87.223868,115.056511,119.721629,192.803042,298.837361,303.693748,236.385211,182.283423,87.090229,81.336095,102.577762,79.798947,-44.884199,-148.565477,-148.607736,-47.468565,19.573578,94.722414,95.979777,53.129245,50.780641,98.231558,178.533987,158.239236,137.820289,197.833933,255.032858,180.949118,-47.34894,-158.721801,-148.071591,-24.90387,79.323728,223.684023,201.847221,94.901278,68.53648,44.233679,-30.256675,-21.409318,94.293614,129.770268,98.360906,59.605328,-7.453757,49.717666,122.803113,214.433298,211.404434,161.049923,132.207282,105.554226,116.015409,124.899084,148.460305,176.723366,277.264713,309.859123,295.899242,281.173702,235.778992,174.236448,169.152277,160.035314,131.437943,82.259126,78.453464,45.315395,-49.99824,-70.501179,16.62355,99.679654,233.749193,251.566946,221.500423,199.319987,116.079302,65.288439,88.692598,165.05799,201.068502,254.059489,257.09543,208.635457,149.784976,170.512601,323.966909,391.408261,377.584183,314.692949,189.626141,151.872276,152.827901,155.035572,92.79999,-30.143048,-1.115425,162.58259,218.734653,220.016445,103.508171,66.934755,144.628265,214.968983,294.075879,297.680292,271.653893,254.86674,197.08977,161.916533,176.213243,214.796997,245.664423,366.263775,394.820088,262.761059,60.264736,20.547708,88.370126,160.876363,234.507334,180.034027,-83.575256,-197.366306,-231.785864,-107.740733,-25.05476,62.113148,50.353942,47.234268,70.479585,73.289506,14.95134,-12.236366,-19.574182,18.633988,141.265124,203.816618,277.753865,246.925668,107.743098,119.72221,182.785188,258.241872,265.769841,251.752612,216.431274,94.431249,-42.173,-78.672574,-71.668477,-61.829649,-67.759042,-73.555917,-120.554163,-166.695036,-257.049086,-264.213703,-221.954278,-99.094026,-53.367913,-91.795369,-187.44753,-354.695211,-291.428855,-197.52579,-48.79638,-39.816764,-83.254032,-90.449872,-94.05446,-104.961422,-104.488425,-78.927363,-79.438319,-81.135385,-60.571914,-6.118546,-13.177095,-80.608086,-59.734956,-2.675551,90.251376,86.0264,45.915809,62.847506,131.44956,134.224178,84.099164,29.647477,14.275368,114.087681,231.446166,394.658532,391.295627,276.069745,80.578535,1.143082,19.788399,80.045536,74.980356,-9.636744,-163.207508,-160.919429,-101.500873,-168.56365,-211.353383,-230.492941,-198.511361,-89.936704,-69.973086,-126.243062,-118.478482,-65.452399,39.368499,70.864932,109.079785,98.974393,7.174701,-35.940106,-68.185485,-98.05566,-111.654934,-93.303629,-71.216362,-54.125095,-55.861792,-54.732657,-98.674109,-108.371297,-13.541061,44.261547,86.642892,98.076069,84.029344,10.080458,-253.287727,-352.127168,-280.672263,-115.367617,-100.905407,-196.183731,-255.16795,-296.304153,-275.621254,-268.64094,-207.133386,-134.791454,64.873214,140.846556,104.059765,15.803543,-108.147421,-79.967394,-42.734621,42.201815,95.103336,150.749835,127.401565,0.714207,-119.757969,-112.791114,-5.313569,-2.928079,-131.018645,-169.60682,-161.087885,-172.550092,-253.702711,-297.931513,-275.776701,-180.332116,-147.351703,-192.69673,-263.049951,-400.270327,-412.006496,-355.100517,-202.132652,-137.905709,-1.936255,49.005656,21.540329,-25.360706,-97.470205,-151.167899,-158.216368,-78.215484,7.353469,124.946833,99.236445,-64.110286,-176.964461,-178.879184,-121.960917,-115.791902,-138.103447,-121.339089,-68.018389,-72.299931:-95.659588,-184.207131,-188.385307,-86.459825,3.408413,98.001221,63.160511,-75.575105,-132.468417,-113.605488,-42.392723,-8.888677,60.333056,92.770508,94.205384,34.532298,-130.505098,-87.8204,18.054551,236.415497,316.490473,379.49168,350.898057,191.6294,48.599032,66.037436,236.740335,313.511301,373.529831,350.04128,219.434432,168.017957,144.721595,145.513036,139.07697,127.652398,124.432111,91.0215,61.485521,-13.302705,-124.102465,-146.623641,-50.616731,33.639544,181.7845,211.290113,122.423048,40.349544,-57.84512,-11.197677,47.700821,178.718587,235.16271,239.521216,163.668291,-43.47149,-160.655912,-163.230312,-107.099378,-84.831731,-56.246216,-47.587614,-112.107982,-179.794283,-278.150841,-242.444769,-181.182178,-15.132196,65.450747,89.583659,23.556894,-138.202942,-277.247373,-321.101768,-308.198357,-256.399539,-121.61032,-89.038791,-124.370503,-151.857442,-186.181594,-154.44223,-99.69406,63.842344,147.32333,201.554906,162.698384,64.06316,-0.069611,-5.209608,57.145741,98.466694,129.527428,93.117627,-59.394673,-127.877946,-189.829612,-149.5694,-119.527185,-80.838789,-66.714383,-79.914242,-88.804963,-36.726179,5.728573,17.913612,107.131082,180.219594,289.489294,279.815768,149.576423,85.803307,-18.274934,-108.763889,-111.845787,-34.032257,10.959013,15.198348,-18.655286,-65.661232,-43.330843,10.669211,180.547768,252.612337,353.650347,385.645882,321.058637,218.213139,-4.487462,-83.483617,-53.415728,37.732722,59.403787,43.430263,24.581494,-23.091286,-127.486962,-158.707816,-109.533412,-51.630189,47.554387,50.587036,-33.765,-79.524843,-137.845707,-110.70978,-53.110513,73.286178,118.19263,159.030617,154.233616,103.991908,39.494332,40.836791,148.182923,227.631352,312.588478,286.220167,151.940574,100.231713,86.896187,87.100129,66.322177,80.060043,129.723169,157.881574,84.238953,-140.788843,-203.608291,-137.363514,77.766517,155.840859,211.066035,215.615912,197.73595,174.693962,106.87073,70.738051,101.796893,239.99552,303.965889,334.453728,320.960235,315.461627,299.615593,288.93909,298.650386,333.430599,438.002788,445.741217,343.268494,289.079545,201.071949,114.908567,115.550901,270.816942,382.031472,484.371794,453.820444,308.709189,151.8629,128.398965,251.206255,326.841655,350.417249,310.700546,226.332883,216.468515,227.510666,192.721914,171.100182,176.84241,222.348315,313.356221,292.736156,135.134483,5.199595,-6.480789,53.684029,104.376769,201.348113,192.479994,-0.309578,-121.064521,-262.149886,-188.039837,-76.705475,141.458775,195.019185,163.163939,94.147926,-54.680544,-122.371488,-124.98521,-76.265724,-24.027258,116.701917,172.474083,168.573863,109.86154,-52.002305,-92.860223,-22.709048,193.142063,279.238541,295.942009,228.911729,81.760918,-19.605791,-57.989552,-89.372391,-91.378151,-92.07134,-89.447237,-89.302378,-102.996239,-188.941069,-280.389111,-273.297905,-157.109465,-82.110167,-36.679384,-89.676061,-215.70469,-256.722126,-240.688341,-108.455119,-8.478022,180.252663,223.999484,124.691068,28.445042,-64.65764,24.290943,95.869044,191.769048,205.759002,191.871895,173.628712,120.752467,73.315642,80.522847,117.238393,109.62324,81.940032,97.62445,155.524956,142.077787,-30.168388,-166.028853,-130.745272,74.941257,176.709243,283.616124,280.294479,149.82094,-77.03615,-142.431892,-118.852914,-65.768623,52.08688,70.020979,-44.946613,-128.739583,-232.703321,-265.229561,-256.93155,-212.068091,-191.899939,-155.819217,-143.257374,-168.46617,-211.432904,-196.887212,-86.795986,-7.71722,120.440725,112.971202,-45.600481,-114.823836,-135.313497,-118.998526,-123.355156,-131.30927,-121.667043,-111.187131,-124.646544,-168.323026,-197.077259,-169.56029,-21.404243,56.495996,146.985156,152.454307,85.873157,11.037557,-202.063616,-273.25958,-209.189068,-24.506618,53.491336,100.291562,30.383327,-180.614733,-215.250233,-164.984572,-25.758779,57.088402,210.478464,225.735799,90.564774,-23.212261,-239.993975,-271.975323,-199.97687,10.228524,102.517922,128.133245,54.806175,-103.907522,-180.056709,-180.185475,-79.766628,-22.659749,-25.032083,-81.370671,-211.561656,-261.242503,-333.149009,-286.545688,-217.363477,-106.028425,-97.998221,-181.87933,-240.372536,-373.92026,-486.394072,-451.749814,-202.458614,-76.162473,26.597596,13.945288,-66.432939,-122.453455,-214.444254,-216.530169,-182.304325,-44.814201,30.517921,83.628638,51.470808,-79.363769,-197.046112,-199.490062,-100.646392,-44.87765,16.973506,13.949545,-47.127822,-96.521521:-67.536437,-110.053195,-98.266355,-48.718738,-22.98631,35.851211,63.177847,64.792113,-62.581849,-136.430796,-200.895115,-191.186116,-82.215874,-4.916704,75.87001,93.859186,135.968876,80.215911,49.759202,165.370828,289.353802,427.634185,391.470656,212.390769,63.58517,19.986354,1.242513,18.640022,64.50268,56.717315,-50.200656,-99.259445,-98.211568,-26.780839,16.157103,77.137969,81.218168,62.639707,52.96787,43.125288,-30.543693,-112.559102,-206.48488,-172.318417,-40.454481,8.985074,61.99581,71.486692,24.503954,-12.230092,22.99052,136.515368,169.198725,126.554339,73.607404,16.934443,-10.442085,-41.139778,-99.512751,-109.550258,-88.459249,-70.253187,-59.379188,-73.336541,-134.010504,-146.75339,-87.597545,100.242694,165.495806,155.95878,88.753847,-75.246317,-122.225073,-93.631702,-29.92239,1.066135,124.353556,191.850701,184.461571,112.751243,-4.638573,43.500608,118.793136,199.286085,158.523453,5.909931,-42.60509,-39.694997,15.647726,56.883823,160.006061,200.197928,237.433692,221.317414,90.943864,16.760623,7.248894,176.110961,250.072744,275.830612,243.354034,163.302441,137.001881,135.644127,144.53005,128.744631,87.266745,92.05034,138.212594,140.273394,91.701321,73.707483,27.517972,-44.778331,-52.191526,7.244292,72.280139,198.770288,221.614323,204.894435,146.941301,101.913135,-10.659599,-66.729654,-91.509411,-60.600906,-24.031111,-38.55426,-136.715265,-237.790524,-240.688198,-170.882311,-109.882825,36.541739,85.485871,110.308271,115.573437,128.89804,186.383786,211.480602,244.837866,269.820773,284.219425,242.628167,119.664445,132.975319,189.006429,216.942604,170.54539,95.700731,108.935025,211.753,285.330602,290.955045,328.332568,365.946682,377.13673,328.503994,246.782322,276.597775,362.128101,257.240066,169.405148,72.784022,79.786789,130.557412,139.863243,157.076038,197.889197,210.140381,227.241373,252.833284,361.758257,409.986571,368.702228,298.400771,209.76041,201.560084,222.274673,285.926153,296.652229,312.446309,333.201132,312.955485,202.727877,180.605306,247.405714,285.70883,314.552865,309.323219,218.800401,139.85783,16.868181,-53.466874,-85.524843,-125.231289,-129.520024,-118.761587,-91.524576,43.15546,183.138831,222.41689,279.374365,305.951928,376.393244,418.089924,454.511768,442.849663,379.607283,311.421789,301.474991,340.628174,386.869928,484.13269,495.291278,423.732578,335.616542,311.291888,322.482722,347.376215,337.465854,266.490372,25.014844,-63.665873,-34.668754,110.02867,163.727284,225.558933,239.508384,263.687822,258.944882,143.743229,1.273331,-3.429784,86.28408,127.036363,204.853756,278.403348,439.980116,469.814681,409.919351,292.184418,225.58963,103.554401,100.949052,218.822454,232.884817,69.664838,-46.907605,-35.462285,11.901729,6.993144,-60.613344,-92.09283,-90.9286,-70.136027,-92.067764,-214.586949,-250.44542,-225.324649,-205.058835,-273.766491,-357.584661,-474.51897,-494.751066,-494.083223,-419.096602,-351.041691,-260.368566,-262.72327,-298.229868,-287.63475,-241.568636,-229.913792,-216.688606,-221.913945,-248.968728,-260.401877,-238.484454,-202.473046,-139.48224,-73.604613,59.71678,93.549133,128.72571,158.661029,185.052063,157.025772,100.843685,69.076331,56.588241,128.431937,219.255144,351.825174,326.641605,115.181977,-107.721097,-148.638666,-79.424094,-39.614965,-57.527194,-85.683898,-91.001994,-72.86206,-82.241275,-125.189255,-112.216029,-65.330814,-46.908777,22.34937,54.424867,28.061791,-70.104648,-98.02205,-95.903107,-88.366584,-81.734308,-95.067407,-182.849989,-216.328843,-176.261497,-100.897163,-95.588313,-139.085319,-149.068843,-100.75229,-87.994045,-123.940711,-135.918685,-121.427415,-99.952258,-114.854552,-165.267297,-176.580395,-182.277914,-192.29504,-243.884702,-274.661946,-257.148628,-191.796705,-163.534318,-156.340737,-176.696819,-229.57953,-276.97321,-263.67921,-149.339395,-104.837864,-70.765808,-67.28465,-144.318262,-208.172716,-262.154901,-222.552341,-195.197678,-148.719358,-145.115496,-174.113807,-176.414574,-172.03229,-291.569816,-374.004653,-483.191393,-520.299381,-526.340269,-485.187405,-458.424534,-480.996655,-484.178854,-431.681405,-406.881749,-394.215568,-388.496196,-345.355413,-328.733548,-333.984389,-362.917849,-350.054516,-251.336798,-212.686272,-163.396593,-103.12007,53.290987,81.404803,-0.378224,-129.857758,-174.705925,-190.501627,-142.633437,-4.284531,17.891403,-46.452486,-126.57759,-152.084544,-164.428454,-150.89985,-93.501352,-67.11318,-74.510613,-110.295691:-39.383328,-155.53075,-201.886945,-178.184355,-121.140948,-0.283188,37.978484,44.296059,-74.493522,-144.923531,-181.56661,-154.770141,-84.612271,-53.003417,-33.170582,-48.494791,-62.425467,-22.540967,-7.437621,7.182701,41.496655,169.822566,200.344789,113.896643,-13.452623,-29.323978,19.107756,47.980246,89.280514,90.075636,-7.522518,-83.599868,-159.379088,-142.275131,-134.785989,-105.979052,-76.209438,-33.598257,-42.656422,-70.232222,-84.501961,-114.775449,-165.70915,-153.759366,-77.19131,-36.714191,10.811721,20.856365,-12.488611,-78.081805,-60.628993,30.67014,45.019506,-24.844752,-84.303796,-179.93753,-272.559845,-331.059282,-405.141531,-414.083292,-380.080739,-330.488089,-248.955228,-247.165487,-261.00581,-208.318805,-160.160828,-69.84941,-29.904642,-14.086308,-71.749439,-222.780672,-239.365553,-216.987673,-156.228679,-95.661331,61.31931,112.526832,97.37704,60.654584,54.332276,124.266218,143.786499,90.773767,50.251976,15.769358,-7.723475,-49.222763,-12.258857,19.718524,109.530161,169.755757,282.37501,290.91105,152.381799,43.504663,-64.788321,58.325502,140.667606,208.593722,197.130743,162.644875,165.674611,219.673302,247.522853,233.468338,149.925708,72.193872,-53.061783,-60.777181,-57.721149,-85.357114,-184.414695,-228.119787,-215.487064,-149.99285,-100.285313,0.500929,44.205938,89.70887,28.041804,-13.171622,-83.089135,-131.164156,-174.324042,-151.703919,-152.207763,-199.790326,-354.097107,-478.863739,-477.126592,-318.873028,-191.815703,-34.239708,-51.032414,-119.180327,-8.679104,73.741405,109.461698,64.948771,23.773721,55.129012,141.947708,156.743474,60.330016,4.355522,40.166276,42.506764,-6.126816,-87.002694,-103.140724,-58.951095,30.195312,49.766015,75.772943,110.049804,190.63428,194.383565,145.487009,135.581681,124.417325,94.108634,84.939987,66.644197,63.701591,58.215173,42.182194,0.849076,-89.447437,-138.98822,-76.795077,31.022844,211.349964,232.581106,138.588173,80.404954,83.378634,170.693365,180.398791,112.343045,87.225971,119.642713,140.352616,137.918597,90.482475,69.972817,52.35863,48.569455,63.816992,64.18509,-27.645444,-86.717552,-132.257738,-133.393275,-123.448167,-111.086908,-132.80325,-194.777122,-184.845261,-58.537452,-15.906317,-43.645624,-36.672276,-1.214642,66.533002,94.533616,126.675589,119.2991,42.61991,-28.517311,-41.958731,-15.186272,41.310064,161.361862,167.658405,88.248972,3.211217,-34.16707,-30.021164,28.437757,117.752817,73.707156,-176.97381,-289.843297,-320.872451,-175.629188,-100.56233,-25.550845,1.901976,76.999424,84.638685,48.012604,16.581612,-10.163285,-32.815771,-10.979213,94.532956,177.344668,320.205598,343.350003,271.893319,180.735072,181.936147,206.995299,217.332104,203.849442,149.415654,4.41935,-85.584364,-89.179514,5.072948,54.800454,32.153384,-21.985524,-46.013879,14.423006,133.741693,128.570344,127.661463,189.381524,208.557946,91.207679,-25.74952,-184.162424,-176.675475,-144.548954,-55.837853,-10.142015,69.778445,98.951982,67.971192,8.386255,-108.648189,-133.535523,-109.26405,-75.521278,-63.642433,16.713433,52.655364,54.204336,74.085293,117.013256,224.08999,265.234097,358.07919,416.433319,445.74716,400.0383,294.222801,290.650389,328.344744,454.76389,527.325205,592.652729,569.871422,462.836848,268.154084,179.128524,178.916151,251.671946,361.750472,348.62099,248.46028,237.107293,282.772119,227.737738,180.175151,187.743125,243.817484,279.732676,218.144655,61.845346,4.058721,21.992331,116.316348,156.463852,177.924291,152.906819,68.72195,59.873581,130.261826,188.386816,188.535333,169.578397,165.279541,171.980206,187.840297,195.82576,99.473387,58.923152,101.76783,138.682647,132.834225,120.109725,127.976047,114.21684,-9.776125,-108.14153,-99.810856,-76.163498,-88.281977,-83.556099,-74.378226,-135.37714,-252.080966,-273.696627,-212.625555,-140.311507,78.45856,159.199666,83.1076,-13.49783,-79.81023,-6.654046,19.13,66.401394,119.940913,218.789826,213.765652,102.757396,-65.31939,-117.881829,-83.757817,-62.793829,-100.527384,-112.305861,-92.185739,-81.171936,-61.780839,-27.565626,-17.210704,-15.84659,6.007256,72.113217,55.719124,-67.308086,-60.842387,25.012186,197.984962,229.190285,241.996337,262.029793,297.733902,295.811797,218.11896,103.131384,97.680188,182.043917,229.717548,295.489241,306.435117,244.058676,99.99733,54.28847,117.923152,203.738132,320.042042,308.755018,165.051755,73.777915:-61.802842,-157.142485,-145.179865,-17.514667,73.712317,173.383714,133.200752,-28.513551,-120.610661,-135.802531,-138.479716,-129.614564,-75.388713,-40.313883,-42.454996,-66.511075,-62.712009,5.5709,74.940368,256.223631,317.972203,335.912547,306.692065,217.390561,62.560407,-20.838488,-65.384843,-32.559537,37.961176,45.196162,-5.140981,-19.34926,22.822387,92.222183,138.703167,173.62064,129.731048,2.310526,-20.936737,16.246198,-51.854488,-121.25146,-200.023163,-193.219662,-87.196127,-20.633941,17.635864,-14.368289,-107.625341,-114.856881,-41.142974,160.594593,206.724675,115.853941,20.11261,-125.533706,-167.670221,-144.044318,-51.221784,-32.063668,-20.930441,-5.859277,-48.369552,-112.280137,-209.986894,-236.464101,-222.09322,-78.032034,23.390297,89.421927,49.535626,-6.175364,-63.175957,-119.233986,-157.411936,-122.497478,-13.364884,27.263741,5.491449,-41.77462,-110.621373,-117.153289,-98.939963,-24.734569,13.43613,35.371612,-7.177995,-140.441915,-129.531935,-78.86248,4.773271,39.292683,90.033602,71.644169,-71.693077,-141.106436,-125.773607,29.652067,70.098126,29.539921,3.594295,9.931289,22.443997,45.558329,33.959786,16.31478,40.584791,65.779873,69.282356,58.716303,30.815065,9.33163,-29.406041,-27.138875,-12.934834,13.196344,27.087273,84.312889,111.106211,108.26462,93.475739,93.779336,64.049456,29.453324,16.762893,58.354389,119.718897,108.379566,4.235189,-140.769767,-156.376579,-32.281369,53.849714,108.606567,68.459862,32.637292,103.363004,100.549439,34.233388,22.522169,78.547008,108.991627,82.898162,37.021103,-67.62745,-73.593058,-8.314336,95.663143,80.384765,21.568836,34.04613,131.317407,199.357764,199.610283,157.149271,137.41246,149.346345,161.419012,113.387023,82.062584,90.372427,78.193989,29.648626,-78.916594,-88.998124,-45.906754,-34.155,-32.226488,-39.811548,-17.563172,85.441518,108.504105,137.482136,199.962494,295.361434,258.393095,78.377447,27.627816,92.246111,238.90119,253.319472,183.126808,153.401207,179.58521,197.990789,168.752273,163.554572,218.434797,313.640126,300.497789,177.474683,114.603267,47.819766,-15.917324,-65.885709,-90.66214,-40.073999,67.858194,89.854858,114.019161,94.860285,98.053957,215.592521,287.901995,362.392164,352.446487,250.390715,194.0721,122.44827,105.502007,117.414891,145.635525,182.127721,326.895832,367.528187,290.366219,141.154834,117.202187,175.170406,199.654162,162.682257,96.229841,-56.583955,-88.112594,-91.966537,-96.113058,-55.841714,87.521763,132.003564,125.446526,99.294582,31.809776,-71.382789,-117.283702,-92.859967,-17.673123,163.860657,227.340917,225.765485,179.237295,97.320657,54.053729,51.997663,80.157535,109.140537,154.096449,137.26905,67.445491,24.340517,5.247352,-21.297655,-40.256824,-98.254005,-115.469501,-133.475838,-148.127469,-178.99206,-244.175648,-269.244126,-205.514007,-140.475042,-120.272105,-182.853866,-302.909276,-284.307745,-251.661554,-179.007521,-117.612073,53.078288,109.397847,63.442357,8.749929,-6.673854,70.306449,106.613772,111.764243,83.552449,60.332774,69.422239,85.389448,119.338367,135.183277,194.831705,239.246093,252.642435,221.853089,197.037598,204.86467,142.77633,48.548549,68.483124,212.556465,300.2008,411.551864,390.224713,214.246528,-0.603929,-69.835907,-52.880277,7.998813,111.336357,116.635229,22.566806,-12.543052,7.518432,-90.222903,-169.156402,-180.761281,-118.039062,-2.454325,9.160139,-59.270358,-122.033705,-96.351384,5.075017,33.858697,58.049706,62.169121,17.644716,-22.63594,-67.382358,-21.201476,3.058879,-36.575535,-64.417704,-43.295152,-22.360968,-32.771901,-68.068192,-63.483832,-16.288568,-19.519956,-60.47344,-38.342206,49.457533,40.769788,-98.235912,-131.313018,-78.9656,30.618689,58.92343,49.621067,21.999316,-12.294397,-4.622451,-8.394096,-11.809665,17.057394,167.539156,243.242385,192.763632,67.29181,-135.450093,-84.790361,-21.177343,8.000546,-12.941312,-18.934063,-0.613974,-2.808907,-97.899472,-118.889854,-57.12606,-24.758131,28.70284,55.477273,-14.153705,-113.61335,-271.095393,-268.875699,-242.640946,-219.113046,-203.237277,-144.428401,-125.571371,-179.146561,-291.134736,-300.766333,-209.063006,-134.817302,45.857656,128.219439,196.580544,181.801803,75.056611,-20.52447,-11.7693,71.256074,99.634951,76.76098,43.845764,24.075104,8.179256,-30.635678,-86.555981,-71.124638,41.228289,86.609396,51.628919,25.812507:forward
-211.669153,-213.521546,-147.61064,36.933397,62.576619,-71.864953,-157.607524,-246.389945,-254.07244,-218.033776,-52.788505,18.522013,13.52112,-28.190082,-36.98825,0.833386,48.12918,93.26195,160.111205,301.148881,321.990841,224.629423,135.060843,41.24007,143.915995,200.973208,275.817341,320.522084,357.92739,294.564534,55.254987,-34.812845,-93.304251,-149.427624,-169.27705,-133.718054,-151.624789,-368.259047,-488.937699,-548.062002,-408.326615,-343.296697,-231.867578,-166.471182,-101.528191,-124.647484,-224.649417,-258.710464,-202.944605,-64.69557,-7.913864,87.115322,100.316263,10.438125,-59.009466,-136.008786,-66.69508,17.217436,162.56676,158.895785,25.70649,-28.96072,-108.16496,-172.052354,-288.52527,-305.130668,-265.781185,-117.802955,-73.789131,-135.611906,-203.465689,-283.091104,-162.788086,-47.187253,147.997001,209.719999,262.284661,252.336258,204.051183,186.146397,143.356423,32.153681,-20.092636,-116.379449,-151.33695,-101.199117,-57.889183,-80.396513,-152.222263,-154.07616,-67.543613,-1.534231,72.765913,76.91137,25.507591,-33.194025,-61.964299,98.712323,166.98427,216.97175,235.872772,299.270663,305.139984,247.69366,232.082703,248.243055,308.300091,338.622445,326.103078,275.031546,114.037896,36.636408,5.385415,130.626252,185.443646,145.095615,50.981756,-100.361095,-109.262621,-74.834403,-63.68484,-60.727957,19.840366,98.27273,213.38032,211.752444,78.829413,-5.227823,-61.99706,46.756838,120.940116,197.64724,173.747913,84.341207,53.905812,7.763864,54.731237,121.685852,232.981543,242.817261,177.74972,113.49447,-68.68949,-154.066084,-206.662092,-100.143763,-24.602308,99.557368,138.332123,104.071393,12.79502,-181.206568,-197.089945,-144.368772,24.207638,97.456919,72.58689,-8.069748,-140.562259,-177.320504,-172.251298,-14.751957,86.627356,199.328748,182.03327,110.932794,102.306646,20.751816,-146.652502,-149.982865,31.58128,115.246499,83.796385,1.536557,-130.303186,-150.497319,-70.630191,62.804256,85.637378,73.822159,51.323321,-62.197631,-152.495181,-334.879354,-406.204796,-394.515171,-326.330288,-285.247625,-235.933303,-237.346109,-298.08402,-335.873307,-297.816771,-109.271931,-11.377966,136.307739,198.702589,286.577374,264.873491,116.494612,116.077653,176.456999,266.023185,301.607479,369.995704,359.054236,239.340014,196.024172,200.249983,164.529249,148.991891,219.044938,237.921225,117.966807,18.480742,-132.187439,-150.681886,-104.025544,47.425201,94.793676,82.51122,75.529683,99.694572,78.40454,-3.064897,81.644109,187.707752,344.036616,325.902461,153.334062,75.291319,-11.889212,-114.969107,-172.316952,-176.523987,-118.505745,-33.943359,-45.562352,-132.278352,-186.57827,-232.017286,-58.931499,69.04977,191.743089,159.269122,2.105958,-107.001748,-338.708824,-399.333012,-347.747433,-195.875224,-153.252134,-178.142458,-224.025091,-352.023841,-418.627296,-476.507251,-423.680542,-365.700779,-235.900813,-192.785393,-169.660764,-195.007929,-310.351118,-359.711362,-328.910609,-197.688229,-101.94551,72.835318,97.308497,-14.907696,-102.764978,-184.006455,-107.135829,-40.571175,73.472398,96.092164,78.027808,47.190469,-30.140911,-52.707802,-41.954548,-13.135197,-5.219693,12.688126,31.525836,24.824938,-16.172914,-84.799617,-100.305623,-87.760367,-6.230084,28.091776,33.49302,1.842849,-165.765418,-295.465902,-252.672944,-0.526357,120.20176,162.953157,80.618885,-164.497687,-266.763423,-302.984869,-151.923727,-80.215945,9.480629,45.214937,85.597108,50.765824,-95.185175,-93.070344,-42.807745,2.490156,6.43326,-2.724914,-34.677842,-85.836122,-61.199879,56.701617,95.975317,94.460761,168.665492,222.592087,194.748699,104.663856,-71.5024,-119.59348,-99.230872,25.536145,90.479039,101.260497,63.293284,-38.666562,-94.811802,-145.316175,-91.291128,-36.494137,80.950509,98.843314,10.838431,-58.807392,-137.390386,-137.967356,-142.977579,-175.682171,-194.194447,-264.026531,-333.366805,-528.043229,-599.368863,-516.947942,-287.149347,-228.70059,-236.408774,-252.249058,-253.967507,-257.749064,-274.890724,-258.655399,-233.053316,-114.027643,-33.456906,25.738415,1.410304,-95.678573,-204.594715,-433.582557,-330.282377,-203.387067,-85.918225,-105.180633,-142.135847,-138.223561,-167.137471,-199.225122,-170.1476,-40.778174,11.316925,-43.361923,-114.894958,-171.269069,-155.791527,-107.68524,-107.39903,-105.190215,-50.695204,-24.635635,-32.004327,-67.102309,-144.005424,-90.135903,-22.360812,52.560418,41.264746,5.684123,11.196813,57.398811,88.920528:-179.387061,-48.308554,43.883259,58.778416,-5.834454,-128.212728,-165.981355,-220.972281,-268.33156,-240.973936,-45.969914,44.695524,71.900911,41.759516,10.571095,17.647967,41.501769,96.683828,167.129428,355.628382,401.986688,267.489461,137.392936,36.189251,221.414648,304.725934,339.179787,340.76364,344.474416,291.572382,88.931962,40.978201,74.865017,-21.926461,-63.481251,5.673919,-8.033249,-304.196045,-470.816333,-545.371353,-363.482301,-291.108931,-209.521795,-178.137436,-178.085127,-205.467276,-261.589493,-279.079889,-247.572778,-143.830612,-90.897347,0.100764,33.390253,5.824277,-63.750259,-166.667449,-75.529172,9.794905,108.072873,109.735729,107.801763,94.889651,-63.854614,-184.500192,-309.128814,-184.59532,-87.670248,0.962571,-13.988469,-113.381902,-181.741758,-204.920088,-37.767609,29.824651,106.309916,158.004797,231.366917,192.96014,37.710407,6.701732,43.91129,26.878751,0.061711,-64.074946,-91.641329,-59.977357,-28.283333,-10.340364,8.119481,6.492485,-14.039756,5.131226,117.298189,154.32462,41.534666,-81.111963,-180.204611,-20.923725,50.040444,115.109485,141.380316,178.205419,173.969492,160.21095,205.936773,246.845997,326.427862,344.021089,306.849482,246.368497,54.655355,-8.903745,64.217601,163.600857,156.907744,114.817221,76.554683,-69.979034,-127.497538,-87.117681,29.668504,45.166122,39.629239,52.03406,121.565171,150.614391,62.541577,-30.091766,-73.56829,123.863724,217.850765,254.105859,215.698545,146.432783,130.823675,115.036494,105.633885,117.832132,223.991296,269.907454,171.552452,47.892518,-176.588613,-233.080974,-194.012033,-82.770398,-55.114101,-9.783856,24.366361,-5.064899,-95.093727,-229.048964,-171.238389,-103.418419,57.80561,93.88373,-15.356528,-99.739776,-164.471833,-149.668133,-99.494808,3.018658,104.677731,241.949238,208.774447,76.278596,32.658028,-56.925845,-103.623521,-45.308713,163.596396,207.483536,74.866894,-17.861067,-88.36586,-86.843707,-50.972096,43.074343,87.330178,77.075393,13.149266,-150.455029,-208.727072,-231.261498,-169.37314,-162.181955,-210.394887,-194.95998,-54.691538,-23.83867,-188.384509,-301.10025,-261.259118,31.025846,130.427584,164.747648,147.143832,129.42538,97.829225,24.356362,184.689509,276.45847,292.694064,294.785684,344.713449,311.239414,118.728808,44.301819,52.045621,112.632407,137.727232,255.769693,301.241455,200.561756,74.750283,-125.771905,-96.956625,-9.334337,193.024757,223.068491,117.797744,76.707787,58.879562,18.85648,-81.890634,43.150276,185.007646,348.758206,298.58331,83.418829,7.548133,-33.647193,-24.222253,-18.221029,71.042282,122.281202,73.342819,3.726399,-101.702552,-158.166613,-254.650152,-129.411504,-4.26671,126.665979,91.330295,-66.264609,-153.698355,-326.167282,-324.188057,-239.20555,-89.427957,-88.070973,-192.922903,-239.851951,-262.402366,-257.738955,-276.34821,-261.267666,-197.773335,-91.231834,-109.487049,-247.173293,-317.094891,-381.191542,-330.330133,-264.608513,-77.350087,20.88177,142.476232,140.130575,-12.817338,-121.591598,-211.533912,-112.147605,-56.447308,-33.699053,-69.477754,-134.881883,-127.143568,-107.560815,-197.427073,-247.539818,-229.930913,-168.336449,-84.344267,-95.224781,-205.295478,-254.18001,-202.233111,-81.647101,-63.829508,-90.116075,-111.821143,-166.402527,-209.971763,-320.202574,-344.248214,-297.006896,-124.161931,-24.165018,74.670755,20.601668,-212.382712,-298.570486,-307.408423,-210.571262,-158.667381,-26.402497,28.053767,-42.500865,-143.75126,-232.400749,-150.509277,-107.848063,-44.444641,-21.98629,-4.389305,-25.926576,-137.810647,-164.511924,-72.367254,38.11124,67.336797,67.102841,26.234028,-90.394316,-138.199474,-188.223944,-183.227246,-152.393112,-28.05095,23.708558,24.997888,-14.737492,-132.828749,-182.542344,-202.233184,-125.415864,-53.384624,82.117446,86.909147,-41.889134,-120.169284,-187.00143,-160.034681,-145.153281,-115.387729,-113.717494,-219.722468,-310.310528,-441.184,-456.276074,-355.058164,-172.084592,-123.827351,-141.367758,-165.316476,-209.970837,-248.686314,-281.808439,-171.797488,-121.848213,-45.264164,10.580771,67.730358,46.825724,-39.257574,-119.333553,-318.696186,-268.04447,-166.9055,-89.757022,-114.991361,-134.499903,-129.813599,-200.694761,-269.249099,-235.695642,-99.684894,-51.824698,-82.491553,-139.339546,-271.674204,-335.355288,-326.606261,-127.296271,-60.357779,-69.473575,-83.570228,-46.09489,-40.179679,-167.396597,-250.429068,-169.481197,53.889131,68.815121,-55.647129,-91.426017,-73.450461,-52.613259:-211.592399,-104.049506,25.748893,90.109873,0.948369,-173.875174,-198.141961,-175.210656,-126.329234,-84.802006,35.505225,86.871909,112.256255,100.404034,100.165129,129.729176,227.185762,332.749258,390.58597,458.152337,444.853363,363.488364,318.586228,293.240044,364.892805,385.884506,424.338973,456.159496,445.299786,375.280452,173.980264,110.411472,93.226388,1.491711,-66.000567,-110.718351,-118.285695,-194.328758,-235.132986,-229.196901,-128.478458,-89.85844,-64.423691,-70.244624,-101.250018,-132.353043,-220.285827,-235.718416,-156.336673,-55.197436,-41.989705,-87.104451,-109.462926,-81.019553,-54.415426,-55.386314,-60.731139,-25.881623,102.255333,146.846892,131.324035,89.874878,-53.90856,-148.275444,-243.449941,-174.681069,-121.137649,-51.558381,-67.298024,-193.859528,-245.522159,-192.235609,5.310846,89.515099,155.521139,153.603948,98.266151,39.836027,-27.973596,-0.846542,65.612625,63.806997,61.320646,49.458476,52.336974,50.279163,11.766081,-52.460022,0.622961,27.28582,60.385535,78.849166,121.565722,135.489741,33.059668,-85.970125,-225.340176,-136.8691,-69.214031,40.675621,73.672339,85.287436,67.160139,49.817561,118.828307,164.43617,235.047673,261.381725,262.424647,207.241797,15.968324,-44.750516,29.465488,185.944343,203.07202,88.621076,8.953217,-120.920509,-180.640796,-208.885205,-121.307824,-94.785445,-53.369512,-15.397783,49.379661,34.448364,-105.435116,-166.536752,-133.629944,62.893388,163.91396,228.172696,192.00956,86.917264,41.400839,16.38839,46.979,59.846657,117.311277,138.628898,62.024376,-25.064178,-186.586103,-217.22139,-142.120777,-70.306156,-86.774933,-103.551432,-76.433459,-95.576393,-173.971101,-283.738873,-215.609743,-161.365218,-51.632587,-18.17791,-95.845798,-182.606327,-252.334159,-208.008972,-105.240351,-91.37286,-52.439878,128.773988,201.960343,183.668857,99.05579,-75.814162,-73.668639,-23.098898,60.069267,78.606747,68.016822,28.129422,-93.379235,-117.883325,-8.618267,137.850158,148.022588,67.392795,21.816976,-51.585802,-100.70515,-119.114851,48.784532,62.838632,-74.842939,-84.646607,64.975897,94.56036,-87.497066,-207.759726,-231.250141,-3.084962,106.044678,187.300329,179.504887,200.80511,216.48382,165.240794,105.08728,106.982911,144.821778,169.569392,211.000291,189.541951,61.448449,34.015916,135.248554,191.422789,170.210293,178.699581,184.890268,7.227083,-138.632248,-253.489644,-170.429209,-124.345179,13.349823,78.550492,58.378576,-5.498215,-79.677671,-91.958258,-156.700952,-106.605781,30.678652,263.602673,248.617794,86.201975,26.546972,-22.043184,-12.547021,30.011179,153.113044,175.677679,102.464547,48.281773,-44.285572,-97.391537,-175.956131,-82.146788,15.196037,158.772183,162.755883,50.80885,-29.996849,-125.761723,-75.009761,-23.277618,65.002017,61.899651,-69.318925,-137.632517,-207.035827,-230.10693,-216.508972,-117.584189,-82.973709,-102.030102,-140.135497,-205.925319,-229.687175,-248.535753,-188.088693,-128.053453,54.02833,148.767814,184.985805,108.843217,-93.175921,-162.068364,-191.14814,-106.627693,-44.873528,26.762931,7.847486,-98.408386,-132.748242,-102.136963,-84.444662,-95.946209,-97.184191,-110.498474,-153.40214,-137.140807,-100.081117,-128.682156,-183.968099,-140.844515,-101.374619,-76.131651,-120.896753,-271.312818,-334.795214,-397.277803,-346.365697,-271.32249,-75.106418,4.700418,24.324946,-44.869824,-216.603949,-251.286535,-234.512296,-182.551447,-127.271076,-5.299007,25.603626,-29.861172,-108.580556,-209.137711,-146.790667,-96.375957,-34.479217,-34.285463,-48.007327,-54.816564,-93.339409,-93.866917,-27.666157,-5.156105,0.039708,43.760643,37.341783,-103.640422,-185.107212,-205.497411,-113.507722,-64.75656,42.018702,70.937528,30.499189,-15.326491,-84.355821,-96.538114,-114.389928,-114.047144,-66.831597,76.76122,97.741155,-19.713102,-93.079385,-130.64316,-81.683015,-66.902137,-58.868886,-65.479466,-158.445705,-227.679019,-338.852545,-383.126522,-398.187386,-258.680626,-167.306904,-80.117218,-90.765877,-164.557393,-222.914914,-266.482433,-133.477855,-77.969697,-37.042116,-27.683647,-48.811364,-66.910619,-86.246793,-141.846878,-359.775856,-330.148044,-204.176113,-65.985502,-114.405668,-274.608645,-297.758682,-224.575839,-169.610228,-168.753367,-124.337603,-82.145352,-104.848961,-170.379867,-278.797497,-307.335074,-296.908589,-163.572974,-91.795112,-76.716292,-121.291873,-121.877795,-55.713769,12.845191,-73.799181,-94.2115,-60.101389,-60.348682,-100.806953,-101.956834,-78.689192,-73.410252:-176.837854,-190.704634,-110.148854,75.115464,84.119697,-61.167197,-148.081437,-254.654366,-261.1453,-215.097497,-42.090796,24.846917,27.732305,-6.197403,-33.522175,-16.086777,28.224876,133.176491,245.54871,437.093912,432.579245,300.294743,260.67421,271.066911,242.355297,215.426642,296.614035,381.317374,385.419218,281.387276,37.711236,-28.213541,-48.97225,-106.728982,-144.172388,-142.854377,-152.58872,-266.61485,-309.134329,-286.967691,-252.583298,-250.596143,-174.557658,-124.915553,-166.053016,-238.053539,-325.903801,-316.762442,-242.113512,-137.680439,-62.808127,72.103362,90.78874,4.505136,-73.794531,-140.98263,-21.279814,46.860718,102.756917,83.321832,-22.900485,-77.335643,-187.662504,-260.17615,-318.538975,-162.851616,-79.130337,-40.829942,-78.728997,-178.556439,-224.117264,-272.098471,-163.137187,-70.141442,87.732374,140.534585,162.771359,122.385893,21.901618,27.509757,154.64702,165.459388,100.740522,-25.995402,-44.913112,-23.501819,-29.141491,-71.085856,-40.564679,-19.875341,-30.08096,-42.797723,-33.220558,-16.02112,-52.919083,-122.962916,-200.454105,-117.395962,-66.715889,42.363053,98.605187,127.284051,88.870464,44.557996,142.848849,199.775074,267.918136,285.058059,265.093276,196.179998,-29.152989,-103.075718,-18.622688,214.635606,282.784302,249.04104,158.632291,-52.413066,-132.058036,-200.125456,-159.972978,-132.480765,-77.65965,-49.907967,-23.121122,-40.315584,-126.766051,-152.527742,-100.194477,40.820485,117.491428,173.77736,125.508285,-11.752801,-44.315575,-30.022123,16.789805,41.107108,103.072141,131.081385,109.53935,34.839523,-189.173883,-262.276424,-220.937525,-101.937143,-59.542525,36.495738,68.965886,-0.369083,-94.876813,-242.96323,-218.555346,-178.306799,-83.503488,-40.501651,-69.642727,-151.460425,-331.778723,-371.235571,-288.539254,-124.375856,-53.951644,57.100265,83.526321,63.61188,5.215609,-185.928242,-226.800192,-162.853541,-15.667004,26.088115,12.540583,-35.777675,-140.026468,-157.7449,-61.939745,95.025832,125.53887,84.538702,40.709053,-69.322309,-140.158234,-226.050173,-175.470479,-163.030519,-156.363499,-120.98192,-74.575095,-104.002303,-235.259456,-294.408842,-266.047909,-54.322834,47.081281,166.714878,196.564248,223.535913,220.053268,188.356158,209.654389,235.329477,247.723393,261.665106,341.44436,361.542393,299.687271,255.601885,227.272149,172.99194,152.319424,240.027138,287.446095,190.220338,75.019118,-99.045251,-135.835875,-107.244043,35.296363,91.729966,86.043024,78.821528,116.898627,109.24276,8.373079,21.807697,121.656577,327.957156,341.174978,218.5235,153.279613,76.263228,33.191055,27.00505,109.955335,184.773292,246.110036,196.390492,24.258681,-36.87864,-36.012916,111.269025,183.694975,202.598561,155.794527,25.565447,-51.192224,-195.086618,-215.44385,-162.712587,8.704944,64.344704,14.270888,-63.28566,-242.975829,-317.551983,-337.486353,-200.093063,-134.967634,-115.99293,-137.327673,-151.008613,-165.537368,-231.718555,-211.895942,-159.18031,13.72463,117.802098,210.695658,176.361795,19.277302,-62.966153,-100.654794,6.936167,54.147663,64.03927,31.648486,6.069622,31.654087,55.209617,1.941758,-16.209223,-15.16837,-1.080486,32.757168,40.697676,32.829637,22.611409,15.061524,11.432769,3.144063,-5.850036,-6.939947,-34.511675,-66.611101,-143.518525,-151.424919,-114.111013,25.133318,110.240497,189.978543,151.397647,-28.166831,-111.707279,-153.079139,-66.462435,-2.868422,103.99486,108.10433,24.331043,-30.09701,-109.487921,-92.891462,-51.463087,23.913124,42.506769,9.06946,-35.9417,-88.61151,-81.137402,-37.84958,-23.999523,-15.420419,36.699984,57.0203,10.685803,-60.655871,-171.031306,-114.604187,-65.800912,-5.201525,8.225587,7.972441,-6.716964,-54.667006,-74.297563,-85.913727,-73.278272,-57.605186,-21.468686,-25.44149,-130.902285,-195.610057,-185.184632,-94.048527,-118.506816,-235.575383,-252.739193,-266.523477,-321.878432,-491.801755,-540.548779,-450.663416,-251.163656,-190.57716,-158.285131,-174.668353,-260.078856,-313.619086,-346.398241,-226.551358,-161.79131,-56.434507,-11.162372,-14.259358,-50.801784,-125.383526,-201.773353,-407.42658,-375.383112,-262.681816,-82.657275,-73.539379,-138.994008,-151.617024,-116.945557,-98.363407,-92.496226,-19.298007,24.125881,-10.631062,-68.111607,-147.201923,-173.038054,-233.393117,-276.772474,-269.652305,-203.857499,-166.882423,-123.524155,-119.982588,-153.822684,-145.61252,-78.776268,50.02775,37.812155,-64.946914,-84.392518,-55.300962,-43.448791:-126.190217,1.394539,58.17417,64.831369,20.679254,-101.656154,-158.763727,-215.300088,-171.484892,-125.219513,-20.823314,0.623746,-22.027258,-23.359823,-4.87059,10.880341,116.235631,301.549503,395.397363,483.089792,448.029764,288.552142,227.333695,222.302953,286.117103,314.352875,382.853579,395.590331,269.006117,157.170916,-4.784743,-14.900591,16.797548,-75.510269,-108.633271,-61.049233,-60.187384,-148.015212,-172.979615,-151.282622,-100.597714,-70.252224,7.856284,24.569836,-60.673123,-140.762342,-259.026687,-259.510172,-147.930855,33.370122,122.147032,209.876618,196.374968,117.022184,63.780455,-22.205175,-18.586829,4.404966,64.377417,74.392744,13.104266,-43.923445,-211.06757,-291.396959,-296.893073,-142.512194,-57.424805,39.43502,5.161475,-192.580951,-276.549386,-298.193567,-168.703179,-73.214489,113.09352,160.023004,107.817601,33.284334,-74.545693,-54.879166,88.483267,161.510925,163.377094,169.251402,173.067552,119.733447,58.983799,-38.814125,-30.115256,5.301434,66.150599,56.256852,-19.292377,-55.191429,-145.658798,-199.634316,-218.468016,-95.175203,-28.582577,47.346583,60.095743,34.480314,-1.858507,-0.829544,127.094486,179.856302,229.31558,241.307945,247.876745,209.627693,23.734071,-52.484447,4.951923,258.043175,340.261038,240.960626,112.886016,-85.362031,-154.034256,-249.595798,-197.356446,-113.36301,32.595934,31.105175,-98.841964,-184.659649,-331.279091,-353.8484,-231.683479,18.994858,125.436989,158.795701,87.121506,-90.043555,-154.427504,-184.556566,-60.00841,28.693309,147.998695,137.894225,-18.144783,-111.62202,-241.751641,-268.591569,-230.319053,-139.302746,-86.34743,47.583667,71.039637,-107.779622,-247.77929,-346.232492,-182.509469,-84.519085,31.228996,28.675428,-114.499808,-229.902974,-408.495614,-426.674608,-321.233131,-156.707156,-75.999991,69.150294,91.33027,-33.522878,-143.228108,-275.326338,-186.551262,-109.218575,2.856732,20.788334,-40.347686,-105.192655,-195.455752,-181.08705,-32.068347,133.519224,160.584312,81.82209,13.385899,-90.585818,-136.060727,-196.925986,-110.310981,-56.248225,-44.371249,-53.337364,-26.163641,-26.744756,-133.329243,-196.007644,-170.420075,48.146146,158.826252,245.763573,217.116153,118.635964,72.021282,14.061354,82.838398,144.462681,222.170478,229.856527,229.679256,222.46977,154.247824,127.632307,168.598604,192.990632,187.438424,220.410921,222.812742,47.570737,-88.140878,-202.158273,-106.554095,-47.880918,47.369615,65.886913,14.621325,-32.909891,-105.555694,-114.675491,-76.657134,81.353359,212.075972,378.387791,349.806135,170.634436,84.970091,23.37224,110.023284,155.532964,245.213877,299.857634,318.187176,243.929669,51.881262,9.884656,55.346491,151.285506,178.229533,175.531003,152.051615,63.314978,6.242078,-79.073251,-86.654827,-54.445605,77.389573,131.583675,82.64284,-17.39697,-234.528456,-277.64342,-180.547178,-74.114125,-61.192586,-25.581389,-3.888801,-73.607835,-169.97483,-273.661344,-119.621278,-16.875125,175.326943,250.939891,239.363135,159.419105,-27.14152,-101.702143,-161.508866,-92.730122,-29.254579,61.328723,50.743375,-64.35563,-119.027724,-145.548536,-72.409333,-8.22061,100.348276,114.347809,63.346235,18.349678,-66.862395,-78.383311,2.625737,63.886914,46.765899,-16.175403,-48.560417,-169.320298,-246.011242,-286.251422,-164.800189,-103.964528,-11.85291,25.236767,44.105348,0.935686,-172.162712,-234.063605,-209.472916,-80.446858,2.773069,113.688353,89.599881,-98.045476,-205.682049,-265.304142,-89.873811,-1.004899,60.425073,46.030697,-35.412288,-110.702866,-293.667576,-341.545091,-280.10873,-95.575341,2.902618,90.343294,48.068616,-135.125794,-221.219954,-291.698896,-185.086363,-86.079538,82.398279,107.170075,11.217672,-79.241842,-198.817122,-185.668106,-92.966225,-57.058356,-21.517754,72.356635,65.184676,-64.573153,-130.856627,-152.439191,-81.843956,-84.575161,-136.554989,-127.350368,-119.119569,-183.275251,-400.365108,-479.32621,-457.484217,-280.032615,-202.50289,-138.056749,-143.162581,-202.294251,-255.018671,-324.071522,-227.002529,-139.017169,0.807663,1.779173,-128.420416,-189.150796,-260.414441,-314.778147,-428.537812,-350.239643,-242.367996,-133.687619,-179.188944,-281.876073,-271.612105,-171.947659,-83.393263,-63.840767,-22.401025,13.88896,5.060137,-72.595178,-276.689162,-325.922382,-264.328837,-210.14953,-209.100126,-149.530109,-107.182509,-138.944773,-207.26959,-284.457144,-179.264304,-80.46571,72.432984,66.515612,-67.455471,-125.049307,-185.179189,-212.310516:-200.022369,-117.606786,-38.227065,61.237852,52.810448,-3.423074,-41.367131,-152.367238,-179.001789,-141.690562,-30.389614,7.757246,-11.793547,-38.403019,-38.208217,-24.2186,22.879316,156.867443,248.268156,399.143943,414.259008,298.08703,204.356472,107.445598,184.799197,228.974107,280.400458,282.808693,210.183457,149.155789,8.515279,-61.544445,-142.865616,-162.191397,-151.121959,-94.460587,-117.399218,-304.363377,-368.915345,-294.454879,-152.118433,-120.82757,-64.525778,-23.390137,-3.205118,-41.369721,-170.671254,-216.06613,-119.063889,99.130576,164.08838,227.265095,239.13063,178.160751,100.506598,-56.411783,-35.402352,36.697994,127.47591,94.077507,-49.306011,-96.613062,-182.140979,-249.05451,-337.14891,-310.280085,-291.260705,-270.573938,-265.715948,-253.438628,-251.406442,-276.210444,-219.23213,-134.013428,60.729568,136.761251,214.318293,214.327124,158.451119,124.267316,110.004123,173.981841,187.415205,115.901406,68.95797,43.540204,40.223031,-12.079552,-65.219556,-73.125402,-17.590009,29.721633,58.029026,30.635423,-34.954101,-39.681544,14.611257,63.585031,88.07125,193.109525,254.531131,285.067009,243.350778,138.171991,154.711467,208.283944,310.184708,330.926543,249.806658,165.030645,17.089301,-18.425924,61.515951,263.597308,327.589036,338.22516,289.195229,115.373173,19.24441,-87.892995,-42.065054,-20.123801,-1.27203,31.254955,99.985599,89.351696,-9.94475,-43.145776,-11.964371,60.785856,84.171343,116.941629,112.547199,22.39407,-26.380013,-17.046142,92.86155,142.178745,212.690196,223.443303,146.337794,75.500709,-46.640702,-88.930706,-117.645962,-12.581508,64.913429,132.63919,112.709069,24.990651,-26.670578,-117.001155,-141.800549,-114.081875,-21.00973,-9.869538,-122.857801,-212.223965,-330.969569,-355.541242,-349.351131,-210.108067,-97.310437,90.553081,111.011763,12.74449,-63.93441,-201.27567,-247.789237,-212.369702,-68.474972,-23.106869,-85.496728,-139.241773,-140.336372,-109.229153,-69.009561,-14.533172,28.647142,37.164384,-21.112348,-161.142448,-214.275334,-305.608471,-368.683357,-381.858385,-351.950468,-316.473198,-306.394221,-340.762417,-400.13762,-400.509787,-325.678843,-176.804834,-77.818338,127.332828,189.925998,168.872686,120.815788,138.066689,311.696463,366.9837,373.368696,364.636484,348.475745,333.173552,273.856667,225.401818,120.372965,34.066758,18.711548,64.128306,73.983364,0.421835,-43.70634,-94.701927,-144.033304,-150.984453,-84.103468,-30.668831,40.913665,51.626309,16.131154,-23.125254,-72.551401,0.873266,94.263862,308.441232,352.967181,258.303048,184.485628,88.032816,-5.06837,-49.033051,-12.795372,76.717778,229.48965,218.594533,53.801774,-7.697731,46.310991,195.526859,235.683171,222.514836,186.730664,90.075848,7.125908,-221.89534,-311.699709,-260.085087,-59.44213,17.309189,-15.43584,-106.153786,-323.470094,-414.018609,-411.228791,-206.940799,-138.814388,-142.586218,-160.746762,-172.283794,-205.083476,-305.370645,-261.782179,-197.600404,-87.725666,-54.467509,-66.745874,-106.099918,-143.048796,-114.464155,-9.896158,62.775593,81.840499,105.514887,99.340762,30.01912,-6.269614,-2.817641,66.847173,78.604638,42.991768,30.766561,54.297174,66.854799,29.925933,-10.953182,-45.022271,19.727871,81.777474,195.322581,194.291842,71.163823,-6.357511,-122.866603,-166.983154,-146.109608,43.045622,170.108701,246.067129,172.535242,-37.300313,-116.726321,-152.616198,-9.916647,85.029396,207.016837,197.666043,58.296782,-18.708871,-111.241822,-57.197212,21.330654,120.88532,104.376205,-18.404349,-87.58753,-168.481072,-167.945966,-93.806801,-52.298585,-60.954903,-28.009763,28.483882,95.483075,52.093247,-125.938112,-202.762195,-165.029823,-1.620046,66.13373,68.227165,19.186789,-89.626547,-123.07373,-90.26755,-29.335448,-29.39647,-19.826577,-10.985601,-84.706281,-162.286,-225.852876,-99.743291,-45.692275,-32.981812,-48.767284,-138.185083,-225.953102,-443.561094,-534.814405,-537.261255,-344.30986,-274.655733,-224.950555,-208.549362,-216.264957,-263.513575,-358.418663,-293.60823,-206.559204,13.847563,116.270479,167.85966,103.66186,-104.874814,-218.839104,-350.694399,-234.031122,-134.780598,-41.642936,-68.929046,-135.823259,-133.913621,-135.729123,-175.924298,-166.086484,-62.105158,-16.48025,-18.877645,-36.556223,-70.633877,-95.026144,-132.047954,-184.561796,-231.222388,-266.725045,-224.004405,-153.53654,-182.339266,-268.07708,-216.513869,-138.243069,14.015054,31.128908,-48.053749,-97.621097,-176.90871,-200.355512:-202.483795,-147.292657,-40.598957,129.79985,108.12438,-63.79399,-138.526201,-223.35566,-220.603224,-171.689036,-20.631426,26.225082,13.884307,-27.143938,-113.480215,-108.408125,48.610469,294.190738,416.084996,530.667067,483.428971,291.934747,213.682333,159.953652,216.557809,264.483085,402.995779,467.787127,387.950426,214.97477,-147.575597,-215.196839,-116.89008,9.781209,32.67091,20.715043,-11.624622,-140.79624,-221.306663,-316.416049,-198.609153,-79.478806,76.770428,68.423548,-67.16476,-170.898795,-382.514673,-413.372204,-217.121196,87.102566,197.87022,291.026123,248.772972,57.687625,-19.427876,-67.281894,-0.405444,50.507754,132.080943,142.790694,73.250817,2.564457,-195.720037,-294.650669,-332.830198,-162.225632,-69.340569,18.985881,-24.864997,-265.486276,-386.799682,-454.013267,-244.948309,-96.018115,108.299476,131.073907,84.411247,60.625714,30.610813,42.586895,192.510997,325.1166,330.214855,270.477674,213.422595,55.052605,-24.589943,-107.452822,-68.584567,-26.235639,68.968994,102.155109,60.483108,-10.601991,-145.24358,-167.483441,-79.506483,83.709729,155.076695,239.471082,229.792036,122.939819,74.172146,84.515742,195.96006,266.255872,423.025878,469.053384,373.614101,239.866657,-22.328013,-66.084125,99.862212,413.50708,531.58026,556.235542,453.211138,145.767033,-12.701926,-199.350346,-114.203653,-41.749819,95.49281,150.825204,116.549796,9.472608,-288.19783,-370.74497,-194.105766,156.953951,252.870697,224.254483,148.367585,5.648018,-54.376128,-123.208093,-26.378582,66.454589,219.030251,234.363442,114.216407,6.429196,-211.982168,-268.456776,-204.680804,-3.690216,91.89613,124.660809,50.839241,-153.602816,-246.889628,-330.780041,-243.044782,-166.202599,1.414049,33.464477,-155.075462,-329.813818,-573.25771,-590.796493,-453.654682,-240.292744,-149.801215,-9.783274,4.545577,-149.243718,-268.194031,-408.428122,-365.969084,-307.097864,-159.089409,-85.789808,-44.834396,-95.900872,-227.468488,-255.892487,-161.369515,77.824595,138.299901,45.181166,-33.888602,-167.83714,-254.809486,-411.171738,-394.407907,-339.335056,-203.239167,-141.263822,-114.843613,-174.20337,-363.480029,-423.328962,-364.08166,-127.510352,-0.385605,168.79729,197.142889,145.015528,86.448072,38.755802,137.369522,196.812597,291.766771,315.970937,258.525706,192.987039,126.60287,142.107353,162.310783,121.143628,127.051941,190.565778,175.055061,-21.662348,-127.112809,-195.99636,-144.555394,-83.538085,119.473968,199.957033,188.213004,131.415972,46.97662,22.727589,-0.300458,108.455056,224.358299,419.526087,431.784172,292.274563,192.736967,58.27761,56.761461,89.126563,231.1849,326.516967,406.977361,340.774336,102.992776,42.956131,129.537192,293.628287,350.277081,393.162912,355.857932,156.955233,43.493949,-112.90769,-125.621127,-63.943322,125.799112,179.263074,116.271148,22.918646,-228.212972,-325.32375,-302.801207,-128.360318,-51.521312,12.175959,-11.390712,-130.161696,-218.573302,-332.112431,-183.668105,-61.707998,131.748417,185.920595,157.128795,68.460379,-159.996895,-233.150153,-199.819411,-32.372551,40.579594,92.882247,67.572076,-40.881271,-92.569768,-120.235505,-15.256902,60.233758,168.904325,179.861724,87.383857,4.199961,-106.315582,-106.504098,-55.902536,11.100543,79.145457,200.325646,173.744782,-44.22497,-161.361647,-265.137558,-156.144341,-58.082366,131.570742,191.615568,161.166386,75.583089,-138.709566,-226.046208,-242.847714,-5.918065,154.86319,337.116509,302.139382,89.820388,-8.465823,-108.812155,-51.007297,14.624802,77.351261,58.239177,-63.39037,-159.588101,-329.414047,-350.041656,-256.238195,-142.700965,-88.288863,5.796278,8.021246,-126.657901,-227.364779,-307.037287,-181.56006,-95.632553,49.994862,89.737916,36.502726,-60.698924,-256.877664,-278.052956,-164.32298,-48.327457,-24.200731,-33.078208,-78.110042,-253.929926,-346.94082,-397.707177,-242.672217,-153.998346,-45.757897,-31.966475,-147.584095,-279.171758,-566.060684,-658.40227,-639.228182,-420.434721,-307.024997,-179.048096,-177.745384,-285.884353,-364.387816,-408.746782,-230.793458,-122.646229,24.766478,45.004952,-72.831537,-174.857289,-328.722804,-381.146336,-407.383042,-223.632465,-101.070492,-6.498986,-41.265026,-143.348648,-184.514301,-195.018137,-109.418511,-77.859444,-31.656047,-13.461085,-75.784483,-144.53457,-242.378869,-267.593317,-278.123931,-208.193185,-168.512787,-155.376295,-176.377612,-231.991316,-260.149233,-283.462063,-200.875784,-134.930096,-57.518559,-71.999245,-178.37086,-239.821531,-329.198968,-349.049527:-58.016443,-33.393505,-66.816889,-99.865063,-53.675956,94.844521,117.724258,14.805455,-89.058003,-107.002887,-128.77302,-134.092619,-58.587968,10.818724,16.422406,-54.58677,-112.396511,25.359303,104.806741,201.79547,220.159298,201.064184,137.843979,-65.35498,-102.680508,-50.149707,44.833795,70.872033,86.326553,61.746332,-69.974187,-143.232834,-211.042531,-234.568931,-220.40664,-91.283539,-54.645427,-165.135349,-238.613565,-231.101192,-83.983833,-21.750197,79.97231,139.038013,174.863474,124.616898,35.044605,42.270372,158.722084,318.939008,361.272441,387.544842,386.755172,288.186221,189.705527,53.201816,71.878493,106.842072,159.567242,151.980974,85.26699,50.668539,-31.056696,-97.415071,-264.124902,-396.24603,-409.586182,-306.476982,-251.580864,-258.023346,-292.515679,-319.682971,-274.875907,-230.498448,-69.175992,31.416694,176.063291,202.155261,153.827541,103.943878,102.002102,250.759935,303.143295,253.013811,179.488853,38.197469,-30.807895,-129.130898,-57.3773,-22.121161,-2.208315,50.79113,171.935271,154.990199,-7.071465,-66.614148,-4.129582,109.938279,108.513704,70.193584,76.74251,143.749403,158.49831,70.159512,0.429991,31.714433,178.92568,247.07002,226.380179,136.955984,-43.787823,-87.790402,19.731532,320.435174,420.817809,461.860527,445.716462,361.268725,275.512603,66.260312,-12.863219,29.233796,174.494814,215.691381,175.784695,127.301572,73.85198,66.653,50.182175,27.841341,28.401133,57.133467,35.537341,-113.96699,-164.75526,-63.140386,181.823532,246.060689,201.062673,160.938176,172.860971,201.847319,163.917109,84.061202,-47.599882,-3.496227,58.272618,162.445897,159.444707,52.835714,18.544181,5.460059,-29.177826,-12.188224,98.139765,113.88385,-57.634036,-195.949157,-355.600512,-348.864913,-257.191655,-186.074337,-146.317916,-11.262697,44.774773,9.438647,-66.8357,-197.597762,-191.194591,-130.942869,22.857719,58.859382,-16.194999,-76.370552,-100.822511,-85.70356,-67.974,-27.472895,-4.483318,9.790078,-11.929818,-88.978352,-110.53889,-121.112107,-179.065823,-211.564134,-237.963806,-244.009291,-289.34052,-325.449331,-386.799111,-399.121702,-365.058256,-254.34732,-176.016083,-10.325727,45.53066,60.818656,34.444162,-26.775541,27.806924,105.474744,267.650837,330.897337,384.945611,366.578347,248.134431,161.30881,24.714332,-6.896449,-23.097412,-66.482273,-72.408777,-96.143071,-143.270805,-287.570436,-401.955489,-404.82495,-234.220334,-122.075574,-87.904904,-146.72409,-213.114289,-204.051226,-170.222721,-127.868049,-89.923832,-3.718188,15.820366,29.38572,52.244816,48.58618,-117.39212,-178.831199,-95.706217,11.060974,171.49504,184.733556,83.06914,20.445806,11.679938,137.283217,176.893413,93.42157,19.588479,1.697486,33.437787,-46.122152,-277.354221,-331.71773,-221.139815,-126.293046,-87.162465,-149.233442,-322.670461,-395.112089,-407.166068,-276.203718,-230.499674,-241.453314,-268.61484,-305.658335,-324.932754,-366.354702,-358.223347,-339.98584,-258.19256,-188.073827,-110.52852,-126.670853,-195.84216,-228.712468,-210.196618,-123.893989,-139.21601,-224.595841,-221.693357,-146.714754,-118.963885,-56.134127,55.367037,86.15133,84.730957,87.904507,146.946895,189.121596,209.896472,160.593388,8.926008,-26.287363,15.43388,117.418729,132.163813,80.817821,49.777225,-7.162649,-40.646936,-5.211234,127.83877,170.45947,136.275773,77.535126,-7.042923,-12.710287,6.90205,46.634078,99.994617,279.852259,338.260622,297.517786,244.819927,159.613784,113.593513,103.00093,66.785279,45.145933,-11.573761,-50.551905,-125.487408,-158.324408,-180.526987,-181.482972,-191.254573,-117.994611,-43.484839,36.005297,12.192386,-133.918429,-221.600187,-201.973636,-59.807447,28.21922,73.588628,16.614413,-112.782592,-132.980616,-91.208417,-70.600103,-66.635014,15.846709,68.057693,68.062106,15.243114,-96.224336,-100.967723,-66.367301,19.816204,51.357756,22.458456,-33.319249,-155.359191,-210.386337,-245.434705,-141.990673,-66.993035,30.789521,34.589673,31.81745,30.943835,-38.269279,-84.868554,-56.99427,49.72067,110.188285,175.290368,145.893623,-21.180184,-121.357454,-242.318374,-180.321099,-103.939843,-10.12031,-30.829829,-109.98666,-130.905511,-194.587973,-202.082396,-139.109376,19.521385,57.33913,-2.084498,-56.065477,-135.342428,-163.894204,-159.761625,-86.422813,-66.574628,-98.264228,-132.743093,-151.109561,-124.031405,-60.27777,6.082796,40.488929,45.859992,20.796365,-32.46652,-56.975985,-103.940111,-116.745846:-132.770673,8.068978,44.754043,57.483895,61.402708,36.864379,-20.688278,-153.244751,-112.479305,-48.173615,8.591308,-7.370258,-3.474267,43.415115,89.063139,45.330436,-48.75907,35.142446,121.784507,209.238321,188.029385,105.075786,58.690633,-59.776832,-111.240652,-72.381545,74.176664,124.893257,119.019348,90.075031,6.254238,-44.687679,-106.508357,-163.98666,-177.315065,-120.133028,-143.390743,-414.432311,-535.310669,-489.419565,-276.291381,-213.295698,-142.208934,-96.505189,-17.455135,-7.515331,-38.898416,-70.591853,-62.864123,123.42973,202.146603,215.431679,195.332585,164.744937,123.624282,28.748309,85.929619,139.513224,162.076291,128.77735,35.608045,11.412198,-28.830756,-93.205919,-257.079944,-283.388814,-239.796572,-143.728172,-125.015726,-164.114175,-211.910972,-262.611961,-173.560869,-117.317871,8.923145,113.13973,330.610436,368.752174,253.89492,165.847382,62.137497,6.563669,-6.496284,-8.135998,-12.878299,-6.6285,7.600578,9.807233,-17.647015,-10.452352,95.215496,174.535311,263.773308,247.290026,142.21749,104.208676,166.494018,286.126522,303.429638,303.4497,307.663006,292.548278,253.532551,157.788955,144.751321,172.739549,281.671746,324.141373,257.139669,168.940838,39.212018,20.147088,51.529853,156.182216,223.185524,292.721957,273.968992,204.466296,164.76231,55.998599,8.604733,17.345737,79.570338,137.272447,241.637696,265.283333,237.641502,191.332869,119.409999,139.373578,140.993847,93.501989,64.628439,11.922743,7.212601,93.074883,211.96957,229.372008,222.031221,235.431686,258.202086,231.886354,101.111008,19.562877,-79.623923,-19.191569,39.024345,112.570401,121.765608,91.13304,50.058866,-67.065496,-100.38009,-59.844128,57.428542,98.400154,39.832103,-53.766078,-198.28788,-195.766543,-93.561723,-46.490149,-19.934774,108.628032,143.668087,75.786243,21.608448,-58.518213,-90.291426,-70.195497,49.485592,112.047157,108.172012,41.11003,-76.033431,-73.26622,34.283261,111.245191,120.221377,92.350314,46.013546,-61.368013,-105.070114,-226.152961,-335.130914,-340.197526,-291.543115,-273.744448,-319.804574,-365.493263,-408.610187,-411.31328,-392.991682,-279.742147,-192.819865,-36.350798,13.049344,76.662412,89.30983,36.652365,-5.690951,32.32776,198.219428,286.946749,376.232277,348.96572,218.262504,162.894847,82.500037,13.697501,8.9629,35.128895,11.87628,-101.28888,-147.464968,-194.601197,-244.08416,-271.305989,-248.310557,-197.065009,-107.062735,-91.636564,-143.663985,-191.71239,-214.874759,-82.854874,26.829604,215.222308,220.329652,90.108485,44.432511,-2.321179,-134.905228,-202.451216,-192.154207,-109.638619,45.97192,55.1614,-38.235007,-89.690446,-104.251659,39.175684,119.933826,128.513103,59.767842,-69.79016,-117.690005,-259.227274,-407.094604,-421.966748,-310.546569,-236.242749,-179.992981,-220.54322,-422.468765,-523.825636,-555.560019,-439.884312,-382.543006,-277.343156,-245.559611,-246.698944,-273.635158,-340.482464,-349.371049,-342.509834,-315.036301,-269.057959,-124.860755,-68.443064,-66.09305,-108.72239,-150.259954,-50.625394,7.814315,39.234929,33.843017,61.434691,64.25701,2.258839,-7.768425,3.495745,-1.20706,12.907299,103.403154,144.740489,145.459272,109.066529,23.623548,-0.701891,23.828272,105.334595,139.344592,149.12601,100.293772,-20.475411,6.300111,58.926593,171.823551,218.598453,234.548417,186.118662,14.390298,-51.706418,-47.865507,33.201189,86.587906,242.100522,292.573548,221.919316,130.699953,1.358112,54.934081,100.605645,109.876104,108.47779,107.827972,72.387008,-29.205388,-69.969053,-98.469076,-84.422404,-71.575363,69.817892,186.835235,274.292839,193.832114,-49.933328,-134.721159,-109.562174,0.093489,48.949803,62.62862,37.22695,-44.000974,-90.269603,-110.811179,-40.627076,-7.361033,64.226724,86.77639,29.0574,-32.965096,-72.989445,25.490881,59.728518,28.633834,-23.370195,-154.198995,-214.468203,-316.591623,-364.653045,-396.247708,-268.603128,-175.346149,-67.82669,-61.979422,-89.84102,-113.253856,-151.29162,-163.526551,-161.078724,-100.129394,-29.132379,123.328415,143.060057,-19.889153,-159.891343,-302.108651,-165.390029,-75.91415,1.360563,-3.894645,-26.7514,-39.003796,-82.299623,-93.419182,-76.531399,-48.406476,-43.477603,-36.198013,-34.532518,-76.39836,-124.910003,-176.898066,-132.897421,-107.616507,-69.811427,-55.671687,-24.673497,-29.048039,-142.692927,-221.48731,-181.269901,-47.849392,-18.456403,-19.819723,-15.516482,10.669563,31.017313:-205.017179,-173.772071,-111.109979,-58.787589,-111.147759,-202.693393,-186.978627,-185.701187,-253.165512,-233.917625,-80.111403,-6.752098,25.712329,-3.975099,-79.584963,-92.681563,4.397639,197.183162,262.754371,330.496934,336.970162,240.438772,154.921722,35.971599,44.738154,74.114937,148.040473,176.583009,153.647884,82.153925,-129.171818,-195.281344,-182.016683,-198.329142,-239.157107,-228.412913,-174.539039,-117.328286,-147.804905,-239.95688,-168.659023,-69.690559,97.362144,135.523307,115.582742,57.053574,-101.896623,-146.263587,-42.229187,136.621757,165.688219,196.524087,206.762513,115.673878,32.171437,-52.612278,12.954433,48.516038,54.29018,43.959382,18.263306,-18.125795,-155.599985,-220.441445,-239.305907,-186.218893,-176.493486,-141.910197,-124.228414,-196.254173,-272.356851,-333.286628,-215.298978,-148.051254,-54.594507,-5.314711,83.494419,84.951002,36.267401,38.105072,134.003962,246.810679,261.558483,201.054257,153.229619,64.630018,1.595243,-154.419761,-65.220918,75.072164,206.459296,141.525236,-44.604041,-88.818606,-129.500041,-152.39921,-123.533634,34.940261,126.769205,233.229997,232.140064,179.555656,144.626501,61.600029,65.961555,132.09743,286.985245,317.64938,206.776087,90.657878,-47.996281,-17.037488,181.385932,336.957553,362.988432,375.025865,359.903705,255.654181,179.739014,37.888872,-6.176907,15.932568,117.61409,163.03868,162.581698,121.461006,-57.147469,-162.126014,-149.835845,73.442841,112.679301,60.345911,43.763667,36.254338,5.012988,-88.818953,-16.676295,61.847477,150.668285,169.62116,161.519171,114.969528,-8.544434,-51.161788,-56.247498,42.061801,103.351769,168.720438,133.953994,-40.740377,-126.560823,-216.7294,-145.017801,-75.103268,37.161224,42.997309,-128.440457,-275.824144,-497.926951,-515.058007,-385.465889,-232.851728,-157.712798,23.081139,61.790823,-62.745187,-152.206196,-234.28735,-206.060819,-156.811927,-35.43796,4.87234,-11.781042,-50.062329,-90.465083,-79.579556,-14.514854,19.852307,4.63794,-19.221032,-17.083776,-31.153103,-67.583037,-197.676925,-290.565836,-282.976841,-195.487445,-158.139422,-165.824762,-205.506491,-330.058806,-387.463477,-358.78366,-144.316354,-23.269474,143.045445,176.177693,151.935073,106.614121,54.245126,160.655133,226.185527,273.624849,278.740653,279.471397,266.058066,225.478629,204.689732,163.608735,74.209058,38.162581,38.580304,29.875691,-48.198354,-83.572951,-89.03213,-31.383382,7.232345,95.995638,117.974226,54.562463,10.252709,-9.46297,-10.448971,0.202596,98.1537,167.524051,267.276555,276.88746,234.455744,186.592605,63.84772,14.068572,34.221812,151.674573,221.901478,267.653948,230.852189,148.816895,152.694532,259.961417,321.676524,303.120517,243.876246,201.273549,84.640405,33.084369,-73.185962,-154.354366,-137.289045,-6.099435,40.727011,-9.194847,-84.326143,-240.776971,-287.594114,-235.381846,-127.675746,-116.577447,-87.99219,-53.466932,-73.75314,-150.513633,-274.022858,-207.651787,-158.678068,-88.062649,-43.552899,32.606795,37.306232,-54.547849,-126.890863,-160.438037,-25.591151,31.142862,80.403181,82.614712,31.17502,-12.065963,-36.455936,72.307901,110.596815,132.829149,152.35232,167.939859,133.326013,58.526886,61.048883,88.455243,73.334638,73.408604,75.046443,57.923168,8.271235,-16.858161,-28.830405,102.631466,167.309022,196.697886,193.738804,134.999631,65.679897,-39.973332,-49.605766,-30.624078,62.032917,151.633804,286.246698,289.962684,222.702989,174.023197,94.220605,102.013011,119.506513,112.034925,89.822853,43.304827,1.136975,-158.700237,-229.410311,-213.246686,-94.380305,-58.270628,-52.620014,-82.58717,-142.760806,-155.219643,-181.968908,-183.33077,-153.270718,-13.876494,67.120217,102.287959,46.543378,-94.249401,-123.021423,-55.523493,-0.678208,-10.085275,3.236403,22.564024,-21.129962,-81.320012,-138.66287,-31.553667,29.334886,52.109283,11.569579,-115.24439,-158.201135,-220.467387,-266.742687,-285.484265,-194.424257,-147.771631,-99.957175,-117.359529,-144.550207,-118.452422,-55.417978,-56.344967,-72.275807,-57.134931,-14.532371,66.68223,67.381717,-47.621813,-149.228606,-287.655938,-165.429919,-50.344927,61.271105,23.09482,-128.317932,-190.883985,-242.23329,-158.560043,-94.098301,-0.128441,26.590306,26.399976,3.68231,-78.791706,-151.271343,-259.22332,-199.241996,-150.333121,-92.888644,-101.760593,-181.997355,-213.890164,-219.87556,-154.881598,-101.602885,-0.678123,28.723946,-31.713397,-126.928339,-297.4813,-299.456902:forward
248.706945,534.773611,562.965308,440.455012,372.896132,294.293542,263.797278,230.162352,292.556993,348.736522,386.554328,348.43674,249.826144,205.357739,118.781366,96.835874,126.919927,178.47875,177.612472,153.204829,158.622458,200.155877,219.737596,246.833368,258.378366,270.581528,344.445793,379.0847,349.568572,281.456143,147.230929,142.965757,230.807617,273.743841,267.776598,212.42052,152.668289,15.011312,-12.347748,44.803176,115.531794,123.593733,96.233321,64.674157,-18.559204,-54.03642,-44.981043,-11.643906,5.097887,-14.568471,-29.407311,-97.991147,-125.508233,-112.863642,-85.358466,13.071567,176.513346,230.375599,186.968837,143.257522,197.639347,260.048064,268.614472,208.120096,58.165261,42.338832,85.386446,152.233695,168.420743,164.722696,116.8657,-54.280941,-136.442795,-82.387034,116.304164,155.130481,67.185565,6.96557,-83.389372,-117.630656,-174.119953,-164.845228,-105.354443,58.002137,101.489448,23.210221,-60.908724,-116.980818,40.050788,142.490634,241.053345,216.285732,116.199333,73.741081,-7.024307,-43.362441,-58.866967,29.639436,68.605967,44.321421,-1.849872,-99.141211,-121.875908,-36.88773,88.078275,91.937468,30.581624,29.632007,116.384257,135.561557,74.806926,73.959748,203.375029,323.764329,335.742034,281.034372,244.122964,192.272692,178.73043,189.852092,255.693657,290.030188,241.614648,144.083098,-55.320983,-105.415508,-109.777348,-75.58098,13.233968,79.6078,101.299114,108.397622,94.461632,1.373354,-60.054878,-102.190446,-93.111969,-91.451243,-70.64617,-70.855577,-113.499518,-135.839856,-156.553617,-162.07905,-119.115169,112.572173,238.167529,290.72704,212.455388,-38.806401,-141.123462,-194.172836,-169.964226,-139.684617,57.90083,195.373988,297.589526,211.836649,-30.073478,-86.188171,-54.577531,-28.556849,-93.461913,-277.093301,-304.551753,-244.969184,-207.028593,-115.467133,-40.917997,-32.219739,-20.563871,-14.30791,-44.903493,-67.81923,-55.323169,-4.704893,150.775712,246.208837,254.928636,255.772463,267.873743,246.103575,200.151357,148.760777,241.066803,337.726489,473.978185,442.157832,260.889535,204.79754,231.972177,268.584945,294.701845,345.411676,395.126877,437.898342,409.319855,241.918556,129.63924,34.063499,150.653979,197.631509,160.441252,129.648908,186.052352,220.69267,166.929283,141.133672,205.073436,206.662815,131.846367,26.296306,51.591991,90.143248,59.396921,66.666538,190.23621,217.291966,204.220634,183.196978,131.283511,102.100277,-2.587727,-59.476863,-89.516101,-73.36092,-67.879169,-41.249068,-30.697275,-37.994475,-36.505131,-26.053711,-55.343571,-33.651981,72.309974,83.696419,0.756158,-56.484133,-143.033019,-173.609834,-243.537061,-215.747684,-162.287649,-168.417538,-224.964694,-241.777228,-209.078829,-225.438871,-275.659355,-245.411895,-117.288237,-69.144217,-55.66148,-90.564213,-200.719986,-243.219638,-246.750292,-70.38142,45.927975,149.728681,155.909603,183.458231,178.49161,112.134655,61.564086,51.879415,45.796041,42.829637,15.601095,-32.030968,-147.156884,-151.370881,-36.80336,46.992181,20.942193,-56.017301,-40.521501,5.672382,-9.534939,-9.469508,85.594573,125.414128,119.799821,87.571811,33.571767,-0.477155,-104.644828,-139.750675,-140.577921,-129.327372,-139.626026,-214.263653,-282.466659,-425.040079,-446.750845,-339.861497,-211.524691,-161.527883,-71.361175,-56.390175,-98.70313,-149.40949,-254.591588,-263.037268,-192.256163,-214.860751,-292.973873,-427.089153,-429.349471,-368.427751,-346.077864,-297.068339,-198.253884,-136.763819,-90.892835,-133.294064,-236.611791,-256.604643,-249.719128,-233.947883,-173.242414,-70.22144,-37.38924,-36.759218,-39.059465,-69.280992,-119.722922,-203.22502,-128.559603,-45.045091,65.490141,46.825397,-75.47587,-118.249063,-56.981532,32.200977,116.946504,55.44148,31.852619,-1.657815,-17.598494,-50.970362,-63.564254,-31.672633,59.974806,90.285518,22.707567,-57.62888,-116.2713,-71.629764,33.29767,56.219456,52.127717,96.660531,124.011095,45.4772,-41.441625,-189.400209,-227.532175,-217.158902,-169.250839,-131.464605,-25.563584,-2.939172,-85.888401,-171.147338,-329.024396,-374.291846,-381.888346,-297.461679,-259.920575,-250.793442,-250.809486,-235.485225,-252.378588,-318.133819,-282.579455,-199.514561,-28.166999,-15.722626,-140.52305,-214.593079,-256.057925,-210.817412,-57.026825,24.426972,-6.632001,-149.300407,-194.808067,-236.146023,-269.259709,-317.439664,-258.565489,-200.915432,-133.553168,-128.684341,-82.260665,-51.971211,-78.709162,-122.347268:310.218609,449.203769,437.738296,348.357252,299.972383,217.323682,200.913252,239.042239,307.815321,342.505928,348.633142,289.113118,122.654781,73.735896,98.407056,140.842849,161.226512,167.361888,205.159768,244.054783,216.556546,166.640028,198.568171,346.155552,397.765954,369.21249,302.803576,274.473603,163.28379,96.569101,59.703412,93.068741,181.010225,228.117966,231.091103,203.601004,171.143966,84.697981,70.603659,174.616726,309.738885,326.602607,287.42497,264.875199,190.245481,126.686965,63.513832,74.047154,52.37587,-9.950275,-24.303616,-78.432197,-126.203669,-158.393972,-107.930032,60.528219,186.057697,228.485325,261.863696,263.615889,289.731198,301.973847,273.749291,229.717967,115.183966,61.042592,76.332772,132.1898,129.405359,20.11601,-55.241144,-165.776635,-146.360802,-76.425888,98.078544,150.379353,96.565521,0.017011,-154.268492,-152.674575,-79.853185,-61.737592,-56.845984,3.217908,31.773,-13.25485,-59.286306,-77.923191,14.50079,70.608154,105.152392,69.910611,-51.691491,-97.7116,-136.974638,-143.614745,-78.080952,77.928924,120.210556,75.68405,19.654304,-90.272071,-103.861397,31.925371,184.211947,197.528786,146.535481,120.209716,104.516047,107.637376,136.050977,164.247591,214.969214,238.783292,232.21455,137.201303,71.313032,23.132618,52.83642,114.719415,145.743866,179.96151,181.868184,110.276144,-66.904296,-107.665904,-77.044459,-41.73107,20.940964,91.178318,120.344704,129.839963,104.973574,-20.9204,-101.576647,-179.471198,-133.899544,-91.349143,-25.915822,-26.588534,-114.677843,-170.049096,-191.773752,-175.488073,-135.673517,-5.371243,50.990839,67.283817,46.614185,-34.057645,-85.607264,-146.532213,-128.459927,-97.785219,36.497497,136.45799,265.492691,254.832159,146.350036,80.650519,2.447332,30.50657,27.97639,-82.936192,-153.92466,-189.705994,-138.539527,44.21464,174.951454,175.61232,147.05625,165.944567,191.065468,152.370698,51.712047,51.418796,145.302464,207.496612,211.014739,188.102591,163.170423,118.545097,116.755592,158.926785,236.310313,296.395169,392.852508,363.361898,177.534053,106.789563,99.476687,130.062963,198.317464,270.288877,273.492057,175.083742,92.046468,-48.248983,-57.206078,47.675032,165.701546,175.227869,86.034751,44.596469,56.810695,71.603766,69.965138,85.541294,139.675896,122.878248,74.767021,-10.093406,-25.509004,-64.257128,-73.281526,15.699608,160.051663,197.141919,179.147175,149.833195,156.245337,182.519233,164.444574,121.346638,71.015501,101.711913,120.094273,123.265149,108.912722,68.588834,53.498668,47.599617,45.702234,65.276149,113.61618,103.765956,29.033675,-11.30687,-62.637428,-81.348958,-111.49384,-82.592322,-63.205535,-77.485434,-112.798451,-187.544046,-210.641612,-217.910874,-128.768374,-67.669328,-56.750982,-84.977402,-75.381351,-68.362231,-85.95642,-90.62774,-74.65524,104.570486,201.493647,176.90914,106.552477,64.016122,91.706021,171.362902,209.974512,192.290904,116.570791,88.288041,54.182069,19.900242,-79.734689,-101.002627,-15.754836,97.072177,77.520703,-53.062926,-75.528088,-52.91857,-53.646678,-17.432889,86.279255,124.064849,104.077196,48.843855,-97.132965,-162.436804,-192.575996,-157.663955,-90.214242,-123.472012,-160.747499,-234.487715,-281.154326,-360.253944,-343.739764,-228.871442,-162.959883,-143.75578,-164.799749,-218.302734,-254.558278,-189.120012,-48.084059,-47.998294,-115.109228,-82.558565,-77.328498,-209.014827,-288.125722,-304.746606,-242.682023,-87.107537,-14.157504,14.218671,53.782009,24.144674,-135.444265,-208.027859,-194.307026,-122.215022,19.804619,111.155847,123.073131,91.087891,82.798137,64.517741,34.977513,21.032869,119.89722,164.17805,149.192567,115.527493,69.311652,21.772047,-92.05499,-69.588884,107.860425,116.386622,32.370055,-113.878776,-115.88914,-24.630626,13.925426,18.191757,40.895304,81.493181,58.93324,-21.392876,-129.514226,-106.749142,3.922325,35.082211,34.371378,46.610554,48.571191,-18.271466,-78.94437,-214.053226,-256.136652,-275.357089,-218.856251,-126.206419,74.734357,100.389029,-30.14237,-144.708252,-328.062559,-354.841356,-257.550753,-129.282155,-139.202782,-206.499576,-193.140196,-158.883642,-191.921872,-268.888423,-169.59345,-81.396718,-39.687984,-105.97931,-255.04194,-278.49085,-234.32665,-200.353699,-121.028118,-19.528583,-28.312333,-195.155564,-265.934367,-289.839643,-282.363054,-274.52986,-226.715745,-176.860112,-91.128403,-80.196393,-97.025651,-104.775934,-87.230795,-74.527679:67.313054,253.191548,257.44643,164.070705,120.02129,73.734198,63.823686,99.616237,238.517566,297.966918,304.790325,261.210105,88.078465,-17.019513,-44.028581,53.503901,199.048383,163.717073,146.058268,144.061192,135.626955,115.1148,135.018407,224.062882,202.824681,122.669911,-9.792869,1.513883,95.700291,106.170673,41.004648,23.811928,121.997624,224.449231,202.738666,113.761607,98.929636,139.999769,164.203432,183.956023,244.862597,280.176288,292.820162,264.953793,137.603739,51.547112,-31.899652,-1.77808,128.778457,184.209928,141.256575,13.908365,-31.863267,-78.471255,-65.052671,43.641254,202.700287,262.428802,280.440344,263.67482,266.529536,270.482729,212.792648,165.521143,101.647474,99.081315,103.21623,53.683858,4.914516,-105.429204,-155.557133,-178.572135,-131.250684,-129.674593,-129.776028,-84.85784,-2.045874,-35.434287,-141.058461,-125.52185,-24.838066,-30.493134,-61.48621,-74.329107,-63.658629,-80.009716,-88.627765,-29.958787,93.355104,131.19037,115.3395,69.90431,-41.344895,-69.374463,-39.237745,-3.435576,76.898918,86.79371,44.604205,-25.085904,-29.734025,-66.882667,-94.245474,-39.023879,109.734874,158.927094,149.392207,105.053746,45.190531,53.907946,162.215966,242.101615,297.705023,225.544277,200.489497,130.024979,60.408915,-61.00801,-72.142244,-56.821621,-59.565122,-31.907539,58.129381,75.261283,-13.090068,-88.470556,-139.29811,-92.777277,34.035671,65.151889,55.602908,50.935745,37.930664,-61.869957,-112.913254,-119.16301,-36.91401,15.356673,35.384252,-32.707695,-220.060897,-256.124988,-174.309061,-126.490549,-112.855309,-99.330278,-72.107323,-12.199183,-2.164141,-44.357913,-89.228544,-187.505738,-167.363179,-100.386684,80.021967,171.658503,243.254327,206.126002,131.73947,125.082813,90.691164,45.655344,18.416297,-119.845166,-195.782813,-201.527427,-124.512658,58.445283,142.649683,153.0775,178.280026,196.576504,173.913096,110.070495,-29.671673,-30.151501,116.146546,207.135617,194.536095,147.146948,134.536202,94.798422,72.682927,127.491904,271.16541,316.435469,299.66148,251.860386,119.608542,46.736266,4.363191,57.405427,187.244625,226.443118,207.911055,57.739655,-63.195647,-212.204275,-179.129217,29.675005,183.788553,174.459668,40.851683,-21.903085,-97.745527,-110.656079,-18.840694,65.61505,139.529005,61.280587,8.000754,-56.719884,-64.909694,-62.536129,-38.550087,96.795582,230.404582,237.923451,118.046339,39.907695,41.594646,139.423121,317.95534,318.348843,250.821626,277.852257,287.743218,243.292647,221.519201,216.17034,215.432382,219.778547,268.135224,294.029914,271.098856,229.933907,157.575074,121.817609,64.401757,47.054948,-13.354974,-64.487518,-69.005961,-58.704995,-51.623383,-60.080603,-73.984638,-53.867254,78.864222,138.337901,135.199199,91.606775,38.788146,71.047531,188.34932,184.374413,84.879512,170.179233,248.83877,237.80674,160.096425,90.136566,120.526048,184.607503,213.742776,205.849233,118.192228,75.633594,55.844892,42.498749,-31.400439,-45.280644,48.685463,147.538599,119.905509,0.893911,-18.226529,-11.395773,-12.725051,49.39539,162.368917,193.837627,188.223872,140.734555,-58.348766,-175.575037,-273.813122,-220.591661,-74.284624,-99.810861,-134.596564,-143.297814,-164.65471,-264.031702,-282.04467,-260.627719,-167.896436,-76.817034,11.667513,-38.544289,-182.29873,-183.778441,-57.521166,-16.687141,6.731334,8.039218,-30.271759,-129.176029,-179.034714,-224.520313,-172.958173,-14.762947,33.215698,38.041924,21.335891,-14.773588,-124.054987,-168.121177,-142.971654,-88.22018,10.220038,114.268694,152.454761,140.558154,105.969843,63.361878,78.352719,142.035846,207.967359,235.69369,192.681778,125.399728,1.084631,-42.206835,-78.653518,-54.35727,78.107669,150.393539,106.60515,-30.871409,-59.681441,-2.923829,49.013038,69.474805,71.848185,131.662106,201.115944,162.678364,63.878966,34.72766,-13.416907,-26.974159,-3.212768,59.759787,81.398754,45.343336,-3.059364,-84.281446,-111.190892,-141.370427,-101.489887,-51.828702,68.347767,88.814333,-25.206572,-111.963994,-186.332541,-169.949651,-98.047653,-31.173428,-27.678551,-39.030156,-28.217814,-23.951328,-48.9186,-92.502484,4.869376,85.826753,114.058776,53.415583,-58.536604,-77.042481,-38.569107,7.521652,53.653752,20.651684,-19.122964,-190.382282,-259.836225,-242.848342,-212.176328,-176.207038,-82.495803,-44.000129,-63.41519,-96.214384,-143.774098,-155.663731,-115.583731,-57.924957:146.406422,358.80834,371.182324,293.929955,251.956956,180.912627,152.88822,121.702917,156.56624,208.045222,247.288421,202.057446,55.679964,-12.802238,-47.277946,-6.842395,63.960963,88.50676,114.380158,176.958525,177.575642,117.150737,112.850933,214.255927,264.075229,223.062401,147.585869,163.998803,257.783974,268.030969,151.219389,85.468673,78.513998,149.768908,166.31855,140.363701,104.639104,27.306286,21.771022,128.960755,246.213248,270.655681,256.662317,207.252652,64.116883,1.919502,-66.905135,-62.320216,14.612236,87.687551,83.158756,2.704007,-38.375634,-104.52368,-130.377917,-77.686428,112.670712,189.391834,222.232981,205.18671,218.232319,238.273458,202.670257,126.859782,-69.693773,-72.401653,0.317549,73.005701,53.460995,-14.691292,-60.76941,-163.537352,-181.401967,-140.426083,-14.78742,32.427261,39.342269,-9.851898,-138.568226,-156.762742,-94.393045,-6.777683,34.139234,84.243722,70.395014,-29.877061,-73.283449,-58.675918,57.132095,130.78239,256.170687,262.786263,130.889429,45.872448,-45.066916,-46.394404,24.571623,90.363963,75.458717,-25.974562,-72.171915,-109.532454,-107.455906,-66.560718,3.908,41.824044,71.679418,60.208823,89.208871,137.498874,204.360975,211.900317,188.264836,155.413238,156.960706,161.925735,134.681376,8.299578,-34.004356,31.918005,161.423551,196.815017,174.325806,119.877035,-19.385854,-89.416963,-199.160263,-204.298283,-76.879575,89.301473,114.958051,37.918608,-23.100577,-103.054832,-107.629641,-62.28269,-28.642395,-19.059734,8.036527,10.533183,-22.451164,-48.776181,-86.556594,-94.745064,-84.580568,49.917189,132.183198,161.077529,92.74163,-93.082967,-145.450765,-149.605261,-161.997976,-160.088142,-10.538867,122.517394,260.369973,195.762061,-19.544381,-60.598697,-5.496177,37.874254,7.101193,-138.53655,-215.469882,-270.011282,-228.222353,-80.897467,40.666607,96.451745,157.482116,135.614356,18.093953,-41.401939,-72.708167,-22.175261,167.223338,306.46178,312.209641,258.823732,238.849031,198.132896,181.593127,208.35574,271.051694,312.05612,394.833659,389.286653,222.965179,115.785123,75.337804,145.455657,243.158403,250.444124,274.486686,305.520009,281.383426,171.124272,116.58962,109.228881,222.665661,255.134767,173.649948,113.063495,100.06711,114.328849,93.484272,99.2703,205.422597,267.011038,227.489978,107.328819,72.201583,36.425629,51.018546,183.582872,280.937613,272.030418,167.291529,100.804953,58.361307,91.968267,157.416755,154.707959,107.720951,97.188877,112.583984,131.277503,122.399114,100.952741,110.805514,155.002564,171.754661,196.961634,252.728189,235.12986,107.643122,45.689349,14.427575,15.519785,-45.608476,-91.330513,-61.609502,19.331263,22.318537,-0.050388,10.20488,43.102546,107.067723,149.413217,129.127771,69.562703,0.455338,12.295021,54.667011,55.533621,69.962456,264.594286,370.421142,378.699048,316.81011,217.436365,183.791579,132.152433,84.715393,72.967066,81.795432,79.57427,7.606523,-63.975155,-169.321198,-166.732321,-112.300425,-34.341031,-15.330142,-64.854299,-76.250509,-35.816348,-30.015579,-18.545567,88.283447,158.943359,180.671044,102.565866,-92.808464,-149.752514,-145.477912,-103.15619,-51.789806,-86.445805,-121.871829,-224.884281,-270.432457,-333.587102,-354.855357,-346.559071,-248.176292,-170.831296,-69.118856,-64.597176,-89.005861,-106.035003,-135.262324,-150.117751,-199.041703,-203.122776,-204.196444,-297.281653,-369.084154,-446.895156,-412.210432,-216.694732,-89.530323,-89.906214,-143.458806,-178.486538,-241.622647,-267.345154,-279.868846,-236.971823,-65.258269,45.778051,37.729305,-56.096949,-105.797468,-186.522749,-222.599136,-240.13386,-113.807339,-29.35206,28.312271,-9.299311,-107.218432,-149.757593,-187.752578,-133.415187,71.96942,106.288855,25.096866,-173.433098,-215.483093,-157.972437,-101.272653,-27.749182,-4.762355,12.757158,7.721172,-28.057764,-89.245575,-97.319655,-89.105601,-73.768766,-12.569008,53.9458,59.365539,-53.955493,-136.062627,-205.305104,-186.653996,-119.646027,-112.410716,-96.039246,-9.316869,6.607969,-25.305021,-48.639617,-125.041206,-176.414886,-219.789764,-112.119992,-57.97276,-41.391453,-65.418324,-141.02514,-176.177392,-157.033726,-16.754015,59.361667,137.898742,114.587584,-3.504111,-59.41318,-113.737065,-87.26824,44.061064,75.213786,2.385659,-212.371462,-260.479716,-218.576891,-203.510504,-241.888461,-256.447617,-227.550501,-127.943877,-85.926142,-77.686767,-109.787941,-137.649596,-110.666493:-25.341433,112.654405,106.560692,39.94686,11.928555,-53.155756,-79.405673,-54.612978,97.807297,193.707918,276.081941,223.761517,-24.242285,-137.149211,-136.259052,-59.363748,38.231235,113.695427,165.214255,177.90813,117.428049,-6.526197,8.115916,172.164167,240.740249,197.519928,38.688328,-31.341384,-62.826099,-42.228011,-16.640084,1.806311,92.492423,177.320273,161.587164,29.431491,-16.325955,10.073397,54.999015,120.804819,167.150878,191.047624,198.256569,183.043518,86.703887,7.135885,-71.293059,-42.701607,60.404091,119.361675,125.667604,80.940215,20.658916,-118.366789,-140.568778,0.114148,224.966739,267.766481,220.388952,188.726913,172.572117,172.588365,163.943649,158.890784,133.752074,97.960747,79.458236,5.747054,-64.135422,-230.394209,-279.65502,-267.536697,-218.315833,-197.121659,-120.525651,-65.042919,22.521384,32.640993,7.118949,1.241577,72.410891,203.188578,210.749149,110.190191,52.767282,-32.209162,-50.495278,-8.972982,105.443124,162.321924,190.864254,152.513259,34.54843,-11.124587,-3.57006,46.412566,135.68305,132.701673,98.544412,-6.52983,-67.80856,-214.182344,-258.007358,-164.035505,3.232223,39.153324,22.942519,8.185583,15.808773,34.584642,152.256342,235.61285,285.370786,238.274734,225.311919,128.785849,45.453414,-73.166181,-74.907694,-4.856423,45.295512,81.666292,161.873887,153.815877,-5.883294,-118.091371,-246.145423,-236.311719,-152.958928,-49.770877,4.248466,52.424097,8.603597,-189.876175,-255.727033,-193.090302,-72.313602,-56.668853,-113.737471,-156.895596,-224.823731,-240.300145,-150.931346,-68.661683,-13.189636,-49.910932,-60.525864,-96.319229,-130.87644,-172.941497,-158.069544,-161.356278,-223.449742,-195.231596,-19.363778,67.357987,126.860068,90.95953,-20.896954,-46.203722,-23.328455,15.65851,6.720507,-140.424841,-262.041021,-400.752387,-342.449493,-83.498202,65.790009,82.950284,30.836924,-17.648054,-102.479968,-127.243772,-106.219857,-71.847529,24.315748,175.076821,226.209543,246.145477,216.572055,41.388583,-33.622771,88.452805,357.780254,402.326334,286.89716,184.97866,24.778741,-15.490662,-13.554521,11.778142,34.07634,62.100202,101.555391,103.805835,38.560195,-89.195616,-99.412515,-14.092369,164.051744,233.508124,176.120464,78.635108,-66.118264,-86.507003,-59.004519,-28.102325,85.135389,226.916961,240.394581,131.093747,76.877035,63.098684,85.971054,195.717249,314.145574,305.278465,135.035269,35.503823,-2.132332,60.622738,191.17663,232.056985,280.668214,251.393734,213.708755,154.434294,153.407439,213.204849,245.010412,230.537367,205.604674,256.472678,323.761868,261.262758,60.888801,10.780631,90.755548,162.528615,176.420729,76.420661,48.238832,70.000938,90.328004,72.19093,45.900377,55.461065,210.56026,286.767562,276.634125,223.082851,166.842654,168.721939,190.707223,197.328675,194.796149,270.995468,349.875502,423.780035,373.914271,232.409654,226.41415,315.354249,272.373675,205.778188,143.817828,133.377625,12.83432,-75.445891,-88.586181,-6.86298,100.162205,82.709802,69.098297,27.508212,19.033303,47.385713,65.163446,116.632523,228.416236,271.957655,202.757051,92.996422,-123.300748,-172.748133,-106.737466,-32.901353,-5.081864,-121.890647,-155.489083,-174.820295,-214.809207,-371.958549,-409.065119,-308.946989,-135.349019,-55.173771,7.97455,-26.073528,-140.18427,-163.193302,-106.693434,-80.669399,-100.289359,-124.499586,-145.140165,-231.837548,-280.434966,-311.665949,-265.732522,-152.821453,-100.529478,-53.094484,7.015498,-34.357317,-188.766771,-245.599831,-228.211217,-139.923917,116.886225,246.152507,221.357137,100.144134,23.950637,-135.057872,-164.250836,-60.523019,128.093746,172.891628,75.694602,-11.063322,-99.644546,-100.394088,-62.633274,-30.771451,69.503613,149.524313,120.371885,-64.583115,-144.651227,-139.658119,-64.483039,69.672613,123.12296,162.658443,159.155916,80.116939,-90.681528,-124.220223,-85.866663,-48.105306,29.865105,121.175645,123.905257,-16.672722,-107.008527,-179.098493,-162.646125,-136.209005,-155.646465,-137.961763,-30.102417,13.254699,-26.611881,-84.517029,-106.47321,-66.918054,-3.582452,27.424009,33.308335,30.920091,24.332531,12.530472,34.583174,88.378298,59.979907,71.41472,189.530421,230.646993,142.064185,63.565096,51.033439,91.48248,124.742507,143.150028,117.21099,-87.869488,-199.858079,-243.368004,-193.544005,-142.513445,-136.919594,-90.121483,32.399835,59.423512,4.409574,-48.863401,-74.974913,-45.959201:51.319904,340.815191,426.241797,404.625377,363.866883,301.754132,221.807217,28.067382,113.573667,223.169201,259.294279,164.598779,13.269325,10.947421,14.374085,-1.046785,9.978129,77.531427,90.555346,49.779087,21.605084,7.643802,30.318426,104.579048,164.210156,187.609743,217.369122,226.944742,268.767293,283.523909,269.925372,252.076693,173.71575,86.565441,99.423653,217.438195,233.162784,82.510707,-6.90613,-22.523391,85.870378,105.1128,24.251296,-52.141818,-183.564405,-212.973568,-190.686037,-160.395951,-139.703215,-165.635839,-179.421198,-183.14839,-165.744979,-113.399367,-97.594643,-101.066095,-77.630816,-47.175915,-33.948678,-45.193131,40.75014,127.857235,173.6578,91.664085,-122.994157,-102.985112,-28.586139,37.65496,33.191159,31.191614,16.480477,-100.376748,-190.553731,-139.834866,43.259738,72.203517,-14.232227,-76.125393,-160.572887,-176.070323,-179.182871,-125.050859,-61.543099,90.661934,126.217608,21.978219,-68.641497,-113.355165,30.903455,126.662221,276.441334,288.805419,176.780684,87.867596,-50.349792,-69.168389,-13.798154,61.578359,71.989156,11.459871,-56.125741,-226.801608,-289.71535,-251.868735,-63.419691,-1.90383,23.954195,47.277585,177.202313,229.885057,224.839477,209.688062,218.35029,212.969782,195.743556,166.644295,184.980244,250.393964,243.104872,190.833737,272.108764,333.618488,290.329987,173.144506,-57.127918,-125.098174,-232.082794,-249.406829,-117.806516,58.787546,94.31059,84.552013,72.069288,41.501525,3.701862,-74.647145,-58.045164,-16.10281,65.178428,77.52172,48.291366,18.462438,-20.17625,-17.511928,14.179316,137.738454,200.972602,190.561819,120.615305,-55.120128,-122.401059,-188.887392,-191.120624,-141.923368,53.127311,147.756647,202.10749,144.988866,-23.146931,-72.410803,-87.765323,-95.968877,-135.18473,-316.905901,-418.836894,-452.587088,-365.950556,-179.599685,-178.242419,-183.303313,-79.735807,-35.556956,-70.308602,-102.925647,-80.684853,-11.045581,196.215078,344.049242,359.745774,321.97623,297.822286,233.48356,187.43255,152.850271,310.654319,423.783894,489.029432,402.577928,173.951779,127.330434,217.700112,289.442423,307.524016,279.760594,323.906074,415.955129,406.253761,274.349462,203.392,197.610924,306.830613,336.002944,273.541716,218.900696,202.971489,219.101901,220.207958,230.113314,300.624502,336.483461,301.458086,176.429305,137.589549,102.699826,87.58192,120.005234,230.306673,282.225533,265.817245,182.365053,29.055788,1.68737,-74.401897,-141.269262,-177.71655,-67.984383,-32.328314,-61.405555,-89.773206,-92.330715,-67.063559,-8.33863,29.313683,79.562815,213.862701,236.228337,131.662481,35.823463,-80.43864,-83.522344,-107.648659,-129.373999,-112.113412,-77.975614,-53.382148,26.026559,46.272213,16.647635,1.938537,9.112673,-20.748614,-51.072026,-88.549257,-107.15639,-150.481739,-166.208685,-189.348385,-91.128949,19.028828,190.58435,221.992455,225.699816,190.418942,57.38357,2.203043,17.982786,22.889331,-13.241391,-131.802327,-196.669851,-241.866694,-180.813474,32.090857,102.323595,36.608633,-103.4063,-82.676742,48.065229,82.640716,108.776385,161.449182,204.736437,221.467775,159.212953,35.864207,37.783408,67.069792,26.309353,-117.998041,-125.208697,-95.253475,-139.847147,-207.279419,-314.119246,-310.476028,-189.815814,-111.02902,-100.474031,-47.98625,-11.19465,35.669399,22.793861,-103.614263,-181.106639,-244.784638,-185.741545,-192.251089,-356.58212,-452.797671,-532.50933,-505.372866,-397.458475,-310.298857,-273.246309,-284.055371,-341.209782,-448.223753,-483.043303,-503.268309,-454.209009,-254.867344,-101.478906,-99.947308,-225.224945,-296.986275,-379.654185,-401.39098,-417.414306,-290.954008,-163.190498,30.372698,32.99857,-54.586528,-85.92351,-72.367933,-20.040726,84.069608,46.516791,1.713074,-55.212249,-72.395138,-110.564147,-101.466706,29.395337,183.374386,213.447613,136.302985,68.534795,21.063491,34.328268,64.358609,89.102229,164.436861,234.592632,251.329442,183.027821,98.553154,-50.926238,-74.732254,-83.974794,-87.427789,-48.191071,28.817583,38.672138,51.931376,39.35572,-94.532177,-182.068692,-261.766343,-202.885135,-162.031961,-120.170786,-105.58533,-87.396355,-110.812459,-185.788866,-71.852766,78.738694,297.679339,275.433211,104.054545,36.184843,-22.303876,-13.381795,62.492238,124.331204,105.418215,-15.304217,-58.936616,-101.228828,-152.529793,-301.205292,-330.458452,-275.067037,-110.884028,-49.242841,-11.594034,-27.348539,-69.615598,-76.00783:-88.656575,102.610677,151.541929,134.350949,69.655429,-106.360334,-166.473415,-154.386317,24.166193,109.820504,82.386879,-6.865831,-119.811384,-126.83188,-104.067548,-66.310973,59.423034,148.557818,150.766972,80.841699,37.458695,19.530553,60.799396,176.472527,213.420653,183.674092,89.19784,66.760298,40.69928,11.429447,-4.486427,29.73473,118.726927,160.089412,144.48583,61.665787,10.982043,-75.309721,-84.716563,-3.588654,118.328573,142.99772,80.706972,16.556148,-92.119761,-127.690077,-162.917152,-157.208269,-79.193159,43.159893,63.536748,-27.020422,-101.6779,-216.618475,-231.951539,-144.374516,-7.02229,32.97999,39.696593,11.898862,-35.756831,-24.324984,31.082729,34.831937,-16.356143,-21.517179,-7.453202,-24.907564,-47.241413,-78.393812,-100.88568,-160.089547,-121.722662,-51.746395,73.133723,93.531044,49.928339,-0.348893,-76.978026,-73.148483,28.885142,193.336988,234.478037,175.563174,113.949967,18.847136,3.752292,23.063771,74.889158,127.791482,231.498763,243.739455,176.129822,101.903861,-52.344389,-72.187905,34.708896,146.590109,129.15981,-14.507822,-82.289429,-181.668324,-203.329677,-128.940122,0.168957,44.418345,58.730749,44.0497,84.484644,142.699096,230.967626,239.075677,202.340326,165.979628,165.433087,157.486799,129.205124,21.796624,-30.90149,-28.516121,134.639896,221.564499,237.323627,147.734468,-102.577827,-212.167253,-319.923037,-290.189888,-94.286936,105.9556,133.881558,2.810635,-107.546683,-268.615913,-289.138118,-211.120001,-75.702125,-26.359098,-22.700783,-68.350034,-166.862311,-204.24832,-214.060071,-165.207571,-21.920666,109.370643,137.895831,82.103307,14.928372,-153.504793,-216.436609,-226.354785,-155.048404,-105.236709,27.537562,90.635167,97.632196,39.179625,-38.934603,-31.936019,-1.05793,14.706538,-11.298728,-186.913527,-301.509536,-416.836042,-378.535434,-219.351684,-121.824648,-71.618665,-8.206482,-41.727793,-184.796702,-246.202663,-288.353775,-242.432636,5.904207,251.251535,302.160368,286.251211,223.4772,30.011046,-33.629438,23.472911,228.488155,313.349162,335.798874,261.791457,33.866433,-51.785463,-6.729393,109.509741,268.118548,238.096697,235.180769,261.696378,242.61647,140.44329,103.652228,145.689049,281.721636,311.558036,214.798524,137.60618,53.567446,31.090041,-1.66816,36.520465,241.294685,342.734353,301.812955,184.966467,146.69704,74.544853,56.907732,127.007828,216.459479,210.914508,94.853791,22.492597,-31.688848,-22.460889,-26.649486,-23.035954,63.385559,146.075141,158.631451,180.776783,191.395736,136.513826,92.050365,91.714022,174.914538,222.513196,259.81938,227.331746,91.981899,32.566378,32.954992,63.278031,51.035317,33.674792,63.457066,141.756514,163.176383,159.467958,149.328347,148.001658,235.366173,292.787839,283.470854,223.216008,111.754119,82.057415,85.761861,117.761363,237.011088,405.923801,454.701468,433.245802,395.066768,308.079876,259.118757,173.062599,148.073501,154.662364,128.933874,74.541587,-105.545591,-200.632296,-242.069917,-166.014913,34.613651,96.292401,55.720369,-41.989595,-42.110788,22.453124,50.987507,117.74373,214.4405,257.9409,244.468304,156.845867,-65.574581,-115.489377,-59.757481,-15.15685,-9.468651,-47.407024,-64.417308,-171.473433,-257.734832,-385.091747,-375.927104,-239.400582,-122.049768,-52.300321,94.103257,93.865277,-53.92627,-111.175797,-115.521653,-115.444712,-148.564691,-141.954052,-166.733836,-342.502656,-446.967134,-563.723495,-549.78373,-405.842194,-186.56919,-98.848045,-130.475969,-236.208783,-413.453376,-436.228121,-339.057777,-228.524531,3.762342,115.678715,107.638548,-21.937837,-115.764823,-280.400376,-314.248668,-250.376668,-85.911422,11.888902,141.339828,131.442354,-22.749351,-112.865798,-135.273897,-60.29725,66.873036,60.296519,29.682627,-83.690713,-161.17395,-250.421293,-211.675886,-42.754219,55.224135,76.854758,22.143009,-55.648135,-175.984101,-191.918111,-134.887167,-68.351356,93.102059,251.771911,282.926874,104.06367,-71.139285,-301.598579,-297.423053,-176.577102,-129.518645,-122.326372,-65.537004,-33.139273,-47.847527,-89.352367,-132.372269,-124.112648,-61.934492,37.993486,48.714293,-32.64336,-71.946598,-90.562744,-81.000548,-14.230162,99.762033,159.745677,227.186793,199.202365,31.777698,-47.318164,-40.772667,38.82525,192.498115,245.401898,209.831642,-1.593341,-109.673863,-202.377286,-221.605713,-289.292933,-205.938709,-69.837546,120.626035,89.375222,-82.35422,-136.00961,-139.872111,-100.164442:-6.031733,231.972336,301.72378,309.65831,287.724866,227.475936,152.020478,-36.699138,-32.256579,37.806139,52.049891,-43.329743,-190.704682,-181.519625,-171.774926,-229.275384,-357.821839,-328.083419,-281.679544,-243.491857,-229.28453,-145.582018,-117.868883,-115.664581,5.793207,102.979928,193.07177,189.581646,190.050927,185.875193,162.174713,163.670399,156.51598,97.872442,87.134756,129.498129,133.139137,46.338657,5.47319,4.198495,-8.517039,-30.086729,-20.900147,-12.153484,-87.081047,-154.847554,-252.344616,-254.591456,-189.955822,-210.094314,-279.451029,-345.119126,-278.536968,-111.154106,-103.616582,-205.677036,-253.211755,-235.060856,-189.739341,-161.132847,-14.220494,68.557343,94.030337,43.784284,-56.635238,-41.486794,2.754809,73.962769,76.607596,5.969106,-43.840623,-108.580052,-140.865397,-128.105814,-39.163469,7.986343,56.0023,35.268599,-47.378693,-48.252215,22.470861,32.651737,19.15943,41.500024,87.337878,147.002145,126.964458,88.463378,92.87489,101.515215,162.668389,182.280096,101.480431,17.948471,-127.702173,-153.069675,-84.120541,26.39283,38.934077,-27.437839,-78.574939,-196.530583,-247.070331,-252.679292,-178.471245,-140.415423,-75.010895,-53.53451,-16.76934,6.228903,87.657462,135.377434,165.55479,148.441163,129.47256,81.769989,102.882269,220.62382,258.598099,268.525105,259.224871,248.882282,216.539268,191.370776,124.958325,83.917347,-23.83762,-54.17225,-1.243857,54.639773,30.859359,-64.714582,-87.487236,-112.873681,-148.085364,-193.654708,-147.364563,-115.063388,-83.069886,-77.288599,-61.236706,-67.215445,-95.547664,-92.514576,-50.628512,58.912127,106.798356,67.788695,-3.733658,-173.042051,-245.323216,-290.703364,-206.683922,-151.183626,-71.7463,-43.098392,-4.178633,-17.91739,-103.442036,-139.429268,-185.851365,-240.717283,-278.167414,-372.796456,-405.046628,-407.15883,-396.070215,-375.825515,-365.464426,-363.279121,-299.576511,-215.953466,-59.169319,-64.733776,-136.411036,-82.509356,194.791856,380.357908,391.652634,325.292439,275.323876,168.997999,121.459428,68.151102,107.569127,160.458186,193.165445,128.152871,-39.955646,-58.57982,89.366604,177.343876,142.922122,9.453075,42.309525,194.794788,217.78054,145.251734,89.211093,7.942447,17.763471,57.778813,147.85736,175.671167,179.654258,157.320163,112.434808,130.015221,256.957286,295.735641,239.373651,107.691189,78.882786,19.746281,-26.040992,-12.461653,101.301607,134.972562,124.549848,89.267952,67.664897,72.777905,-37.80045,-119.01353,-125.601272,-5.757886,18.924856,4.324728,-13.957147,-86.008528,-121.745087,-95.778653,33.555444,106.321132,173.379998,122.70869,-20.188695,-22.666943,62.440711,71.273733,8.877063,31.548469,49.974659,-9.437724,-37.273442,-9.571904,7.595268,-14.701609,-64.905952,-74.43066,-85.248005,-116.787698,-200.201168,-233.19659,-311.716458,-337.032967,-304.696244,-240.848106,-212.704479,-93.726652,1.2375,78.359048,9.657717,-179.048223,-174.642911,-124.07995,-66.839611,-66.124713,-83.216507,-98.8636,-91.542567,-41.076761,110.630505,212.092627,213.225942,173.627689,194.450048,300.406088,318.398847,302.729562,369.639606,407.319927,403.554983,360.278667,243.192624,207.004608,199.373513,208.037303,231.780926,282.966215,304.951241,250.120037,165.524383,-4.195068,-27.865666,73.136485,150.244788,129.59341,87.112196,112.139715,205.343331,219.261759,153.670464,106.217148,72.20629,97.078508,67.847623,-99.445875,-199.428629,-366.932144,-406.188902,-348.320118,-254.048664,-254.847764,-360.82123,-420.661966,-470.426252,-476.994696,-426.641809,-328.911505,-98.923377,-94.909333,-159.421833,-228.540574,-208.65864,-203.532686,-258.370875,-319.255363,-150.337749,-37.138336,20.319023,-30.335591,-51.466537,-0.917514,92.70298,114.127508,82.54033,-12.429621,-33.477142,15.949338,42.077363,-33.338543,-95.122643,-44.205205,119.446914,154.35232,168.49818,165.713173,186.860725,210.614814,188.506617,181.336596,337.055959,526.136096,541.232426,454.896861,410.133883,349.690419,313.518983,214.886759,142.647673,147.793204,200.372192,227.776516,264.379953,249.883181,160.039873,112.425805,27.41504,2.376733,15.123003,30.193104,34.5749,25.445155,-6.959306,-85.049215,12.570237,133.304298,284.860858,276.181184,221.440743,208.875408,189.154954,181.227846,194.160416,215.921518,198.087803,112.647592,78.418555,37.40383,5.893968,-88.422585,-146.074537,-127.560928,-49.387416,-23.048467,55.472944,112.49083,174.354886,171.593608:158.494884,428.194624,454.327851,367.792963,309.633216,177.665278,97.632244,2.981588,99.508618,200.793916,304.04521,257.770614,126.683304,90.796292,-10.780707,-99.039678,-223.070303,-120.544038,-44.428313,15.70292,26.280271,57.127938,69.549498,111.183349,185.890929,228.534557,290.037193,297.141963,284.952232,267.142595,208.65011,194.450911,209.068599,182.318371,143.2293,68.830045,41.854471,-28.247169,-61.625239,-73.892731,-91.956307,-106.012692,-82.805454,-73.373194,-103.114423,-111.726515,-92.539275,-77.945448,-74.357019,-153.175133,-212.898269,-266.935611,-230.146653,-112.11175,-90.057836,-112.750169,-68.984814,-17.330644,3.614057,-24.242445,54.090771,168.106822,264.314261,189.659144,-19.962102,-25.382344,28.139571,96.023183,113.175272,120.74855,97.766289,16.752423,-56.130765,-43.001411,85.672127,121.854019,29.995533,-36.673927,-69.030977,-67.343019,-138.583308,-189.147944,-135.101567,54.492548,104.421623,21.378414,-62.166632,-123.24332,-58.784471,-18.868514,56.924626,83.550646,104.313504,84.424466,-36.835331,-93.14925,-98.899606,19.266585,69.992659,24.945468,-58.477829,-230.32003,-282.905465,-278.909546,-200.614653,-180.233375,-181.230891,-164.322856,-23.0042,60.665708,91.16725,53.916163,52.038063,169.335521,209.485273,196.045554,173.700982,144.888513,143.222184,224.027022,345.964807,337.217409,145.819783,42.86802,-23.569379,-23.862602,-66.561844,-86.228331,-56.688703,-4.498926,-11.957588,-50.668939,-48.852779,-88.641362,-144.528973,-202.830258,-193.834561,-188.414852,-144.102188,-106.784517,-83.950064,-133.696113,-255.427731,-255.978809,-113.412109,123.793035,210.3929,207.280658,129.028914,-66.58147,-150.45682,-246.634105,-233.398945,-201.111457,-101.672184,-41.346986,25.811117,11.830876,-49.709892,-82.560571,-159.05632,-193.892816,-223.604856,-312.286139,-314.722124,-243.754316,-228.753516,-250.057792,-232.579244,-202.989871,-156.3655,-153.905212,-144.369027,-116.890428,-31.828598,24.343754,193.347274,327.177037,323.728877,224.348171,180.15502,150.602916,156.560029,181.892165,178.070634,187.349908,239.276355,235.462993,149.912694,115.67804,151.330283,199.79591,255.449286,292.423851,326.824582,400.819861,413.527526,315.228733,216.505111,43.044536,43.877921,103.044564,143.818678,117.249052,156.278438,216.527575,280.728731,294.609745,343.088168,338.026685,288.428845,192.691927,169.42377,48.832803,-42.594944,-8.470542,264.813376,330.848136,284.261896,247.769473,261.963967,267.862793,129.954171,35.051874,-20.824453,5.586534,-1.878994,-33.328154,-51.609535,-91.816116,-84.447495,-4.710385,40.376145,70.765838,153.158483,149.672996,49.986827,3.380841,-19.671333,-21.663646,-65.700343,-43.739327,-32.299946,-133.67169,-179.89506,-132.311377,-100.50509,-165.523204,-282.278965,-263.387977,-88.325774,-22.81145,-51.354782,-117.302133,-228.303263,-245.925674,-228.3612,-139.432377,-96.511245,-38.031031,39.023178,232.612629,255.166701,168.281977,94.817851,98.521085,133.056105,129.14985,78.15669,33.586976,11.678489,73.26094,220.106114,246.262415,204.016686,118.272403,142.821319,241.927815,248.259507,253.302249,335.316591,366.080208,358.501826,322.354567,248.778291,231.729943,187.820025,138.460969,53.50625,79.043476,79.896319,-45.630031,-128.79877,-217.675346,-196.260718,-49.638425,11.75555,10.875907,60.231221,88.815181,83.589703,62.098021,21.13651,0.450518,-52.835191,-98.733814,-131.83576,-271.123093,-343.215452,-393.496414,-382.601724,-337.621298,-258.422157,-204.010755,-168.621491,-220.476388,-364.690307,-407.135823,-413.868946,-363.589534,-194.974057,-98.129257,-86.938799,-75.335044,-61.188442,-81.631632,-145.020354,-288.096298,-234.93707,-116.838563,116.341405,149.810752,51.385455,-15.11323,-16.431694,58.3458,158.809349,80.028129,44.185193,30.372495,7.12901,-97.708508,-115.255557,-28.220579,6.808577,-11.634325,-43.215614,-40.986844,38.073145,88.860838,105.730756,93.888347,123.255638,228.405766,283.007111,260.156799,173.946589,10.526898,-13.547856,17.543287,45.768395,63.763792,91.882613,86.724679,62.499991,62.594996,39.940385,-25.993112,-189.149015,-163.260818,-109.123792,-98.789148,-120.388574,-129.046382,-140.743459,-159.147926,-75.303013,-19.748599,34.179156,20.118903,-44.795313,-65.18061,-41.96325,-5.44331,53.804903,66.50065,50.018048,18.044211,33.354532,33.510909,-20.502171,-155.38372,-198.272487,-164.20541,-70.506817,-39.277548,19.396761,30.063364,-10.375723,-17.972139:-84.651796,93.03523,163.539695,238.542556,220.827778,96.115262,33.570229,-26.493496,25.325422,84.18637,82.660517,-14.363053,-162.240234,-151.358833,-108.753887,-109.85385,-65.686152,1.685532,-17.462364,-90.462903,-90.074956,-36.191936,6.217345,98.442778,125.476532,133.798008,160.10178,151.091634,108.672905,101.614443,135.692964,170.323176,204.516232,151.123981,144.571065,224.52683,234.761724,90.534855,18.882391,28.203097,69.533816,78.976957,108.008349,94.092619,-18.761754,-83.750607,-154.532549,-164.577444,-185.23989,-181.128341,-175.886769,-214.594277,-243.517937,-275.025351,-282.686545,-281.727012,-271.601043,-265.005216,-225.82577,-201.440327,-154.481859,-120.256182,-18.337106,-1.549801,-120.640062,-157.834925,-96.75718,-32.582558,-49.194954,-55.181067,-52.327456,-100.114799,-124.780307,-65.92022,104.9832,124.345674,38.301852,-0.115329,-39.253302,-47.570091,-7.710703,93.67747,128.713676,135.568296,112.773271,54.728121,35.737218,17.44496,15.053987,24.071524,90.636753,133.105514,162.193161,130.604271,2.035804,-37.627582,-11.90961,2.539289,-20.446292,-109.061164,-164.021571,-248.497226,-249.495027,-154.364718,-58.92317,-23.231857,52.460217,78.270184,107.444769,124.357082,223.711287,304.331339,373.21875,295.524431,269.486082,239.490961,207.994818,136.522783,119.594332,151.063553,207.876968,206.502239,154.643479,133.496932,92.399372,43.525671,-99.260808,-152.140265,-172.976045,-75.839592,-10.325265,2.540062,-60.120892,-148.330446,-141.190174,-163.205318,-237.534779,-212.002876,-65.637005,-10.199792,2.647717,-30.081306,-91.53484,-96.725972,-46.672912,92.118385,136.926639,90.62403,21.92688,-159.064847,-241.555672,-310.84019,-290.275846,-223.174095,3.111927,71.834178,62.641916,29.575723,-37.574486,-65.852731,-114.98519,-140.068706,-150.748102,-224.636841,-289.061159,-396.711531,-406.43944,-388.781125,-343.348546,-255.661744,-90.565282,-120.936168,-320.505252,-355.777469,-204.781234,-94.278465,82.446864,251.763124,311.507435,290.840427,220.397912,64.344853,26.820515,54.330702,128.965969,169.835011,176.316846,116.757435,4.716016,9.0417,109.03973,165.805284,227.121606,229.220206,214.747943,201.346666,231.368983,259.591516,202.231524,67.876623,100.3152,170.245441,284.218586,273.410435,152.684582,95.7852,85.465876,137.637726,277.141576,351.481632,330.187989,171.428887,85.049203,1.735075,0.819107,52.86975,125.840137,144.150624,104.461337,50.461234,-54.134352,-89.189238,-141.070386,-164.275479,-145.798627,-4.500364,60.306559,116.65991,112.999734,31.086318,-18.766977,-47.50296,-40.010492,-3.472582,128.458912,146.298151,-14.368381,-128.6142,-156.885283,-76.562434,-2.049171,-34.12087,-4.71693,84.330719,98.993183,78.487612,62.015823,70.635522,86.737317,63.96264,9.541218,-13.10943,-83.621912,-128.354932,-164.097498,-137.288114,-24.517012,89.052236,104.297507,65.694886,70.08132,104.048162,83.177857,30.098056,58.204639,62.660769,0.498703,-31.780064,-86.319015,-133.902273,-168.775085,-105.572273,36.645961,28.69139,23.655083,61.990279,74.057747,28.805159,0.922608,83.305653,266.961523,310.800186,260.461082,199.022712,107.908061,83.683249,21.538016,-8.930974,0.416035,27.31921,1.361279,-96.579306,-143.155986,-220.022524,-229.340746,-137.002849,-14.858173,20.577237,73.32952,103.06289,129.484959,99.387196,-41.447762,-106.525047,-134.41777,-103.397039,-119.012603,-248.269279,-340.74336,-500.65809,-517.084053,-405.377817,-249.811248,-191.41919,-227.209626,-309.920814,-401.813014,-404.770115,-409.003699,-365.353234,-128.95962,37.786435,22.779288,-94.764166,-131.725781,-149.668468,-155.072759,-167.719754,-119.950105,-28.001564,133.634696,102.682591,-37.122879,-29.216436,94.250807,125.864535,93.200955,71.705182,71.403752,23.988149,-19.257846,-104.488271,-125.384208,-65.137396,90.063168,166.468074,190.242074,122.452269,-14.540587,-21.40754,65.371449,120.076207,279.351671,442.447081,409.39255,144.712401,34.744869,-32.836168,-24.970767,24.94795,41.9059,14.760212,-17.273829,16.834349,140.093204,169.924188,111.762051,54.427843,-25.264208,6.368839,23.183885,-40.481271,-91.480023,-139.029155,-143.206819,-130.502764,-11.177296,101.42708,298.309552,321.924931,256.378214,223.955934,197.149264,191.430483,189.690616,196.340967,182.548527,79.569485,23.575834,-46.647618,-92.503094,-211.525328,-229.123065,-168.815651,-32.564757,-14.032457,-27.654927,-36.52181,-73.546604,-61.384578:forward
-11.332733,-77.328606,-140.126349,-213.578817,-239.286105,-284.926895,-248.123512,-55.290824,93.591541,108.94944,38.616116,-3.799887,-40.123408,-41.424761,-11.60571,10.475941,45.736376,83.649597,94.716528,76.343896,46.495739,13.816428,48.909137,199.244,298.407741,290.123756,185.505632,108.946222,-43.235699,-87.78149,-137.988255,-171.317805,-182.306401,-56.516532,19.377739,115.816519,120.286084,83.68611,80.590017,132.820963,282.846429,362.958754,395.118664,351.052915,205.293865,136.648265,73.692343,61.666779,98.749195,215.069713,230.995026,149.210658,81.426026,-65.581487,-130.944094,-203.550732,-165.239517,-128.190717,-115.854155,-142.039513,-184.317341,-178.961383,-143.371508,-132.090447,-112.978797,-124.097887,-153.738748,-199.053459,-212.53264,-251.68498,-258.906589,-206.283681,-37.527179,53.388849,87.693619,48.865787,-39.125321,-97.851914,-212.263908,-216.629859,-78.634509,62.922208,86.633226,148.050777,211.702124,357.479616,398.052052,348.180736,270.783722,250.737328,142.726221,72.151569,36.494528,82.793302,195.817017,216.199539,230.220308,228.744609,178.291616,12.833077,-53.884471,-75.452191,-47.540382,-2.773893,86.400742,161.05405,237.681053,218.371366,133.530583,97.345807,58.017498,43.632105,14.076506,-8.648945,-13.605312,-7.566475,-25.900505,-135.768183,-171.674284,-96.644674,19.249954,20.242043,-18.583738,-19.485937,-76.061461,-153.583504,-251.698817,-232.039131,-163.599607,-162.520662,-161.193543,-143.009051,-168.616134,-289.672941,-312.825191,-203.285566,-56.488716,-39.033691,-77.434343,-93.440159,-156.226152,-175.565772,-86.688729,-35.662285,-34.117983,-89.084376,-118.908638,-107.325294,-63.932715,43.742182,116.960885,267.343186,298.007592,267.781901,178.947403,119.635058,-24.270678,-60.615648,-38.96415,-39.426548,-61.451875,5.590484,42.254242,64.83041,51.549348,32.652453,52.290657,29.31333,-95.510277,-97.701659,24.566944,76.914157,72.852347,67.639318,166.001575,197.784275,104.921079,125.72448,224.261038,340.500328,303.671005,158.326225,111.141066,111.811502,109.857043,50.265221,-98.593194,-110.046123,-19.047857,26.954686,76.911136,83.895505,107.974867,169.315357,182.658394,176.074444,155.852555,66.447585,33.493217,101.32022,256.326032,295.180603,277.548285,257.901121,234.86981,203.901016,92.281056,52.428236,80.013407,151.386736,163.540731,125.933226,48.106414,-200.739681,-294.099444,-323.160673,-218.562529,-176.093521,-212.708557,-263.936608,-337.700418,-355.571715,-366.97621,-350.978737,-198.173981,-69.958524,-137.081287,-388.683332,-451.544848,-416.413198,-374.879118,-316.359465,-286.184884,-298.120577,-353.761302,-357.820138,-318.317725,-304.794163,-276.327212,-232.033358,-77.799828,79.355635,114.877935,45.911036,-43.790559,-202.97538,-219.599191,-124.053096,-76.955189,-139.952347,-317.549408,-365.217633,-392.673873,-369.223739,-153.571317,15.469278,302.698213,389.426071,357.768197,212.360204,139.180269,132.36146,189.558271,233.20417,173.835385,161.831468,166.395416,147.716776,0.011894,-86.185068,-83.554959,11.250474,255.702697,330.07807,283.645006,192.92284,163.5638,119.968953,147.838536,272.583868,271.029698,215.3454,113.237735,110.242295,160.484915,173.293277,186.528036,195.593936,273.318166,394.101317,378.923698,188.854916,104.426776,128.789669,209.788616,341.564174,358.943315,335.972622,280.765463,275.319557,284.992567,278.550449,230.94576,188.56746,145.72618,167.692993,141.113771,53.584474,33.471373,58.727544,102.618672,209.299121,293.376484,329.306703,360.612237,332.280717,176.078779,98.42022,45.092988,56.945498,130.434087,252.444765,299.276565,284.119923,213.601104,48.470387,12.185814,38.034985,114.188785,164.966647,263.81743,280.100772,185.967572,134.91688,223.212607,313.819184,326.006455,160.132753,122.525766,201.176857,237.968905,201.143681,176.849412,175.333782,159.972897,111.131679,-41.888866,-91.961165,-114.213206,-90.883142,32.932051,94.187149,129.430036,83.219758,45.421126,-36.512825,-81.708412,-177.230792,-221.50336,-275.376803,-184.31049,-114.800499,-68.913962,-84.792239,-151.363823,-181.19108,-167.505706,-145.405081,-137.917838,-136.884851,-142.251133,-217.733336,-277.608617,-348.312576,-340.363761,-264.654342,-157.797145,-133.511426,-154.243209,-167.342834,-198.12984,-228.098193,-257.143765,-233.200033,-134.818584,-10.355694,29.495676,10.727917,-17.365836,19.774956,73.029383,46.247975,-117.806205,-150.048005,-117.357374,-114.220578,-184.297471,-206.465827,-177.032991,-163.179302:98.083812,112.146499,44.051009,-140.641358,-212.935255,-229.26244,-159.510188,9.124407,53.967647,33.805541,-30.750026,-60.575953,-83.156059,-66.035623,-29.30447,-21.704126,79.100594,217.23959,194.957719,12.061268,-39.320881,33.786806,80.466713,78.170911,93.424518,122.390514,87.502376,7.76033,-100.318348,-86.315188,-64.263271,-80.032266,-35.803065,32.477064,18.355626,-61.615069,-101.644321,-106.318052,-51.808672,96.63273,221.645649,248.907564,205.115473,165.700087,133.229195,150.580074,189.310968,173.798063,135.415571,171.932814,162.130871,35.411066,-39.257872,-173.957595,-240.247278,-309.635292,-274.906019,-258.725813,-217.02703,-157.903561,-79.488535,-84.804468,-44.125652,11.735367,73.929307,-30.259158,-99.841299,-99.549653,-65.030352,-128.402193,-187.461586,-146.8125,-7.97178,1.092641,-50.749779,-51.748094,-20.213915,-37.8854,-147.401009,-183.058378,-130.617662,-55.82184,-63.736505,-63.896106,-15.47672,108.13121,131.918968,84.787446,57.222091,57.031918,10.898295,-28.665741,-50.718861,-13.948163,61.932356,64.654516,55.325498,82.421052,73.936779,-50.45929,-131.904965,-190.17838,-159.07881,-28.506862,105.02776,128.466343,42.208127,-24.360155,-68.815928,-36.882498,53.234183,66.986684,54.737582,32.131859,-17.73093,-131.379711,-141.497969,-129.050546,-133.014091,-86.714347,-64.58001,-108.081814,-184.505198,-199.442526,-257.75177,-289.743756,-289.376254,-265.770035,-194.559725,-118.700395,-103.034837,-115.882979,-154.96492,-283.332151,-323.946755,-278.975285,-126.973643,-61.556693,-4.235968,-19.348011,-134.73988,-171.810823,-60.612955,33.019922,77.819593,-44.386786,-103.891392,-155.235828,-146.377831,-24.174476,76.784053,195.576369,148.164304,100.669303,18.159354,-35.473237,-162.016265,-170.587211,-71.874665,-41.106223,-58.299755,-14.170712,34.992477,54.530608,20.753107,61.801773,142.968533,131.052767,-38.511603,-36.485641,84.194625,105.743152,66.924455,89.591825,240.588738,282.127325,202.536393,99.648632,109.696272,191.923151,180.844929,32.156156,-25.25411,10.475444,104.487346,95.329125,14.189014,-13.616809,-41.960908,-20.642473,117.202123,184.550849,235.754673,137.611807,57.995322,-28.72805,-46.076353,-88.146622,-93.764627,-21.169874,72.895875,79.963498,18.023309,-17.346045,-63.31329,-80.562723,-68.803227,-25.50663,102.89813,147.31244,104.840628,-65.915945,-165.209761,-322.53396,-368.438213,-387.173695,-234.53821,-134.328231,-122.894383,-210.620219,-368.258145,-402.097615,-389.429734,-340.287587,-179.273575,-122.004019,-184.445699,-346.012964,-374.812054,-359.928158,-346.054541,-299.64768,-244.01693,-238.786421,-284.211809,-322.562,-335.640422,-274.176101,-115.728979,-61.709103,31.168459,105.396898,86.225038,-63.081115,-118.326062,-111.489115,-99.991572,-114.75725,-112.108964,-131.896622,-267.511946,-355.477504,-452.323236,-415.084409,-166.55557,-23.987517,158.500027,199.981343,169.927179,22.653895,-60.292917,-93.725104,-18.835395,119.223718,7.047037,-68.28955,-50.175418,5.213898,-35.764942,-113.897316,-111.58316,-21.168959,129.15897,114.193924,75.125941,-3.605982,-41.762382,-75.903024,-58.550179,-7.738032,6.173877,13.24775,15.577145,-8.402145,-51.530268,-37.103568,1.898409,-16.025434,-43.764389,42.253228,62.647025,-46.204589,-115.992062,-65.892681,32.622157,122.936693,125.444521,164.287805,187.670757,137.629831,70.055112,112.774952,211.111512,174.555804,40.799301,51.1279,56.424131,-48.283079,-108.021747,-56.640622,39.891602,172.71763,165.317242,167.852178,210.879401,189.109918,-17.792407,-107.668437,-48.16893,45.279595,122.322162,98.971542,117.01133,159.062784,127.337171,-5.552718,-45.077241,-15.023172,78.478211,106.779592,149.027154,175.212612,160.584302,136.467912,198.03383,275.818273,349.782039,230.130638,177.747329,191.191252,191.083238,137.98461,145.313032,192.736077,182.47895,160.534155,91.858312,77.31235,128.96754,173.552488,277.503266,331.177869,359.026902,237.128151,170.299672,106.960953,109.328246,159.424917,161.160553,57.145298,7.569176,44.419175,124.382172,108.285249,-12.635291,-28.775743,77.036662,115.126983,70.891512,32.306638,40.093522,-30.244757,-121.217485,-247.187973,-242.042863,-134.502873,-31.608351,-37.719864,-105.029219,-129.361973,-208.541051,-240.47614,-138.555909,-52.30306,-6.432226,29.01269,82.440334,134.345312,115.736755,90.6015,109.286491,122.157476,30.670822,-11.884193,-22.429839,-32.571351,-140.015937,-181.938992,-115.21537,-49.010344:76.715129,-37.698375,-114.093827,-218.153166,-242.824504,-228.895354,-179.936172,-11.158798,82.629446,62.06169,-17.116505,-50.834424,-115.897586,-121.13957,-43.293316,-1.783822,74.163698,147.191353,132.755093,33.232057,11.362824,65.259352,94.575757,117.302073,113.359008,69.999521,-20.326379,-23.525055,-32.426883,-72.012109,-136.666465,-103.705943,62.90787,84.585199,23.413779,-145.37867,-225.219872,-240.806068,-156.369763,54.133831,155.151218,174.523469,168.408852,121.760193,-0.562919,-12.260604,94.01631,158.263229,200.008189,138.458248,88.287509,-17.330745,-60.816778,-143.185985,-191.928259,-240.526925,-187.680152,-159.856088,-131.970791,-130.303927,-147.66318,-126.202126,14.033008,86.2712,111.321741,-25.085639,-87.532621,-115.757988,-121.28427,-200.57768,-222.795706,-123.811826,-18.385705,-25.054173,-30.858566,-12.273871,-83.352095,-162.357722,-222.513141,-191.040741,-77.734788,-52.680522,-115.98173,-235.607961,-220.361987,-95.554393,-39.575415,-13.835869,-66.551277,-100.457273,-193.332777,-243.928694,-289.412429,-274.79326,-198.485189,-130.703313,25.796105,5.005783,-70.602884,-226.211813,-285.004976,-286.038439,-219.925107,-56.290876,37.287395,37.691998,-41.02156,-103.09384,-184.704676,-158.73089,-9.415272,48.722061,90.028591,77.744212,48.715681,-9.543413,-19.098894,-7.88332,5.479155,50.303322,96.760115,74.319199,-156.165085,-313.377833,-427.284164,-352.932123,-191.484904,-175.95017,-173.416213,-101.810332,-76.63917,-141.050942,-220.926961,-334.423521,-324.872243,-190.722641,-59.71457,-57.57219,-154.594973,-210.912676,-262.566098,-218.032064,-40.940753,-9.027833,-112.357139,-193.224263,-175.576033,-118.293591,-121.814145,-138.239901,-110.77019,12.308132,103.220446,97.143124,-4.930372,-85.610316,-204.629555,-195.869222,-93.418217,-47.811091,-36.167914,-90.504223,-93.42048,-66.448733,-59.268661,8.181321,68.320004,90.413116,45.686204,48.422576,74.150794,88.538372,134.556566,193.683083,389.474396,454.918102,375.466847,196.587867,172.856754,204.258946,171.11428,-11.373942,-53.192038,107.393837,265.244438,218.647112,23.190053,-26.885627,-15.980785,28.604352,141.798566,173.505509,204.677878,154.207625,101.963938,65.008181,63.738114,11.245301,-10.397072,81.198087,223.385737,225.687807,118.491101,45.321769,-55.708512,-47.956788,33.014251,67.430408,154.191346,223.538889,199.717134,23.150938,-93.894759,-252.057597,-282.800323,-292.645337,-141.192111,-32.39288,-31.46875,-140.086323,-262.98882,-230.504738,-167.205693,-189.987254,-189.98131,-65.082221,-64.243766,-195.355901,-235.926702,-208.046669,-184.504848,-157.036834,-107.596366,-82.331051,-80.536229,-124.083622,-220.08321,-199.815638,-40.47527,46.022881,186.802678,222.010641,174.340366,35.120042,18.928518,84.498886,109.970014,151.896125,198.733696,202.830263,91.456041,-50.56649,-291.12385,-257.620161,23.014426,134.527936,232.5917,323.435306,361.201298,290.555661,190.771927,97.504746,145.827091,286.814822,309.354723,266.961715,133.542448,66.415343,-3.864616,1.843056,49.312399,104.668646,257.883545,207.084872,116.829269,40.818638,53.310679,48.228139,24.774543,34.831772,121.105556,146.261706,132.586142,89.418974,-5.825865,8.164392,123.620147,142.69795,126.546996,140.933871,111.942071,-17.401836,-60.166372,-3.294115,75.96077,216.284715,343.356768,393.986707,350.267972,260.719449,130.331632,154.118968,283.938711,311.184921,278.581482,218.683022,189.64933,98.8036,31.435389,-1.088873,64.295342,212.742045,274.751825,281.230009,301.472608,311.573172,215.484916,143.445954,73.890912,62.547035,106.809996,186.711387,187.318866,149.191165,121.266762,20.279492,-26.474864,-15.072355,55.395972,66.870977,108.885207,150.179794,193.444957,202.628937,286.326573,351.436378,383.582639,249.316851,192.486215,148.828033,113.479778,23.536524,36.533777,173.61229,224.966007,191.006857,45.009505,-20.135717,15.850137,108.997049,313.427146,383.905117,401.456401,276.109489,189.537685,17.035355,-31.62301,7.919262,38.024209,65.919746,178.859939,196.930571,17.802725,-120.836576,-247.546926,-197.336984,-37.345879,-22.331693,-127.214969,-136.992095,-79.066319,-134.707901,-266.917887,-380.898203,-321.181069,-176.226099,-133.4553,-163.393115,-254.180667,-278.921986,-315.205004,-328.644686,-249.832369,-174.136482,-139.000881,-173.706434,-157.987569,-169.731654,-186.841335,-112.140917,-49.363661,-31.360401,-89.996742,-91.017324,-109.033174,-157.232076,-247.661005,-278.49786,-336.562388,-300.61908:-135.43467,-94.032171,-81.192013,-156.272663,-239.900336,-329.982067,-287.051235,-95.135187,31.978831,33.556793,-50.10015,-109.589062,-181.533122,-155.949592,-21.856461,23.226898,67.160482,151.202788,174.327267,131.520538,85.49015,29.247522,44.787961,145.226455,231.761611,223.256158,122.600105,62.392279,-38.458899,-65.680721,-101.064575,-114.063393,-61.727152,14.488669,17.675042,-27.561943,-47.775178,5.772941,77.587364,190.17638,224.404978,260.175067,309.070755,264.536792,117.62327,97.023081,177.764183,221.996227,281.873861,346.535643,349.135939,259.219211,203.053686,143.356886,125.883806,77.740295,59.610807,72.86901,114.896444,102.924834,-10.880361,-40.473163,26.254087,66.826277,92.641813,38.069961,-26.120149,-140.34948,-179.07423,-262.324898,-281.527336,-209.527476,-86.511753,-61.22566,-86.547084,-104.908774,-115.11333,-121.762194,-152.830606,-162.288305,-119.472988,-33.557818,-5.903507,56.528108,111.811702,236.090742,275.449647,275.126108,190.552273,121.801072,0.044683,-22.010155,-31.132723,-47.970819,-60.657512,-15.652193,157.477229,215.048145,160.461295,-28.268681,-126.428844,-211.264336,-165.64551,30.651563,206.022411,239.636839,156.454483,70.516059,-58.643049,-53.570707,114.656605,197.202753,212.595832,168.294701,160.937932,91.497713,13.062372,-74.678978,-26.341965,141.561651,188.075479,163.725452,83.729421,20.761376,-171.989811,-248.876954,-263.496434,-225.638651,-99.402336,4.224317,-13.182769,-179.420254,-271.384394,-335.391919,-304.473299,-214.697411,-158.717199,-140.121832,-132.440325,-156.845445,-231.361668,-219.230841,-72.707485,-20.89448,-43.470211,-118.770736,-150.970283,-192.857019,-200.051058,-106.418641,6.617381,213.713655,228.092283,181.269972,78.013378,22.697794,-86.530391,-105.706081,-95.479582,-105.189662,-132.535918,-77.776386,-40.36704,-45.526303,-81.530758,-69.135379,-4.805468,55.033503,-11.576926,-15.275148,75.023703,131.828955,192.859835,217.530239,310.734315,353.36009,374.846444,373.71985,382.040525,372.393508,328.354323,199.827548,165.663062,185.113259,179.411534,123.790185,19.454391,26.602929,119.545743,155.870136,162.856691,155.799844,203.157079,257.802753,258.24462,231.489507,182.469137,40.031604,20.514045,149.511964,311.382567,332.701889,242.201444,176.139407,101.647708,94.450846,87.959218,88.843774,190.383414,335.675946,326.823196,107.228711,-47.244028,-248.408419,-278.859881,-286.021686,-201.088136,-161.097562,-230.530622,-293.070363,-304.132038,-269.748293,-242.674546,-246.72248,-141.616764,24.41898,-1.239258,-213.477958,-287.301568,-306.139993,-282.832761,-206.511517,-172.522757,-195.963797,-244.141775,-251.553865,-262.429594,-265.107122,-241.282042,-179.372463,103.141448,312.436017,282.101859,64.050143,-38.51272,-118.713405,-96.476427,-4.619745,54.010388,47.365021,-55.459665,-138.163889,-274.785331,-257.099821,-10.712422,122.10531,245.517089,313.918936,345.085461,302.844511,237.716879,174.545429,205.883189,282.392744,257.151177,225.141947,189.375967,170.933371,51.95885,1.008635,99.751347,215.295235,365.80725,293.602043,224.730337,169.818929,164.528827,140.657338,139.485476,149.178575,157.859673,169.266486,189.696526,194.292937,215.800357,254.828192,332.690591,308.805079,198.979864,218.817049,234.629066,151.954197,91.866412,100.24025,157.306903,248.250928,349.46244,398.758469,438.266848,433.633301,379.479955,356.797375,360.078059,354.953468,323.130852,296.365078,262.723715,155.913653,102.808103,64.172631,100.85752,249.648321,357.387689,370.645582,361.67135,340.769777,224.253161,166.074156,178.383862,230.397077,307.049244,308.286069,293.342106,272.735016,247.022254,121.112607,49.505027,-32.594119,23.819065,82.218596,146.716862,136.98876,73.606654,80.353068,256.487727,362.324162,388.115593,174.550523,85.131474,33.095345,30.851445,53.913838,73.223459,64.260519,70.794975,94.432592,56.501786,-13.605352,-103.31266,-78.389427,78.298318,158.289324,225.737199,158.883548,86.856413,-78.4868,-141.073424,-156.371025,-144.492111,-180.434953,-169.3314,-146.67726,-169.985142,-223.208361,-346.050912,-348.723598,-200.00552,-143.959135,-192.218415,-248.78364,-240.29295,-268.142758,-324.791936,-403.767194,-399.960069,-342.709453,-226.862881,-200.735662,-289.410856,-364.441314,-490.459061,-509.933774,-415.947301,-349.346164,-277.567198,-209.347641,-176.852632,-175.835046,-188.332937,-153.528907,-117.776177,-124.15205,-170.464211,-155.671219,-142.859527,-179.081298,-281.036888,-318.410281,-350.881801,-324.65812:57.166768,-27.097407,-86.320602,-201.061767,-256.466894,-292.572313,-250.019456,-57.198323,98.712184,78.69186,-83.345372,-160.842835,-211.538263,-155.992008,18.908395,57.555438,73.717189,148.075345,177.300606,164.193797,123.117961,65.220879,83.369969,159.721441,194.373924,174.775079,99.716088,62.941841,-5.923842,-14.096462,23.774528,43.364924,93.745236,85.056019,38.371704,-69.178449,-106.221218,-52.244633,47.237312,236.218219,301.960516,303.609343,256.954723,204.354633,79.76172,62.180321,160.709955,224.863136,302.680719,296.891036,269.607505,226.249824,226.358136,241.332195,231.452563,197.0588,238.218902,269.0088,240.584226,178.373978,72.414602,63.373427,77.338786,77.624076,93.11474,39.233004,-44.042476,-174.156303,-183.253073,-183.802116,-195.526949,-201.768622,-190.175648,-179.34904,-137.932536,-129.905053,-148.113256,-128.72811,-44.42782,-34.005487,-45.92195,-62.08412,-98.164844,-132.195594,-77.797778,105.962642,157.837889,129.590518,72.395461,39.215039,-68.37306,-119.076897,-156.900112,-140.263515,-49.077094,14.261485,132.543812,127.798904,80.5684,-26.91117,-80.849731,-141.682704,-129.346778,-6.409343,210.506408,268.697712,174.304124,73.835857,-69.6891,-74.135551,55.879296,140.045605,225.785409,190.367974,161.427879,114.828605,93.2167,83.629662,111.010462,211.746831,253.981882,208.841659,13.314281,-109.516372,-306.008139,-318.184813,-187.814978,-111.391289,-0.371625,39.159267,13.706754,-123.234786,-212.883856,-311.220036,-280.063116,-92.247353,29.262831,7.09918,-125.220973,-196.414053,-260.455746,-223.771254,-88.006004,-34.319579,15.806218,-24.360788,-62.739315,-119.395268,-117.319228,-34.951568,18.286531,107.171031,173.185277,176.932596,82.350242,-20.397695,-208.190801,-215.5973,-130.062798,-114.507822,-125.485566,-125.565426,-120.216964,-78.802525,-56.360636,-18.857673,0.951428,25.831599,85.596638,123.325896,187.135285,214.555877,233.851194,255.48567,395.335283,468.673963,475.48288,375.505329,350.728824,369.5867,368.389551,260.936778,200.387394,202.661046,261.63317,233.969296,103.431221,68.383756,103.939963,130.234683,134.253888,139.33695,207.323982,231.010504,209.414182,186.086897,187.544238,164.413421,146.80325,205.20018,300.844069,275.750899,134.992928,85.571731,60.158051,65.059436,74.218812,94.123031,228.020687,328.710589,285.056292,30.20731,-109.873865,-231.791539,-225.725733,-213.950014,-170.670781,-138.266578,-149.791386,-195.958956,-279.292886,-279.084211,-205.506325,-166.233135,-74.485811,21.49991,3.701406,-169.732205,-252.331712,-280.94503,-237.437426,-110.152218,-24.52272,-28.718633,-109.82754,-167.044922,-282.523161,-311.472137,-262.337948,-193.074613,-38.215884,-3.548695,-58.218171,-219.030683,-256.999842,-184.808401,-115.688906,-3.380908,42.116804,24.094481,-122.626745,-244.111896,-411.684392,-373.048473,-131.631202,-39.993749,-8.346551,-43.782662,-44.178763,-36.471657,-54.006098,-110.900684,-122.83746,-85.850849,-30.672952,-42.389914,-172.850845,-264.983682,-380.719273,-382.869758,-351.838453,-305.467085,-139.281567,-175.474136,-270.746173,-338.982027,-315.786425,-337.272482,-370.138116,-345.75575,-199.978113,-140.318068,-186.605977,-288.122719,-461.573851,-453.270417,-298.496642,-241.110445,-201.392722,-185.953032,-219.004328,-364.108935,-412.435007,-328.621738,-234.225157,-108.287315,-16.207781,23.368749,23.05282,-4.977383,-77.981609,-104.52592,-106.781987,-89.881417,-24.991606,-36.538302,-103.100152,-280.456513,-354.465544,-380.829355,-328.182217,-165.376698,-6.733428,33.211646,6.992493,-36.13685,-117.74502,-133.110346,-120.058778,-102.136268,-10.838218,94.951957,112.276659,30.212964,-67.302933,-221.075599,-223.646278,-144.482067,-97.627485,-81.378976,22.645391,74.305297,70.135054,70.813877,190.276792,263.926175,272.745769,72.863802,-18.202744,-48.041422,-20.869616,92.015351,176.285287,271.105034,260.663703,255.857074,218.708167,178.586309,138.607696,167.025221,305.168102,389.827671,496.459297,396.787939,292.464809,107.618517,49.701835,34.105571,65.902429,173.485951,266.385949,243.183474,76.736186,-28.289634,-158.010652,-113.472518,106.740515,149.084125,33.561775,-43.012612,-33.364347,-95.113678,-186.634325,-286.500353,-251.234009,-115.943132,-33.454327,-58.869055,-171.805766,-199.762181,-239.982358,-273.727312,-260.067055,-193.129666,-84.140403,-86.864737,-96.057442,-99.394765,-103.701039,-88.179078,-50.158228,24.754247,52.762649,46.869188,-28.75434,-80.766565,-122.995257,-104.190272,-28.190046,25.947978:-149.108457,-180.91734,-218.786512,-270.340568,-292.515389,-328.859665,-296.357624,-100.9671,79.848171,108.487809,19.270856,-73.787991,-194.817431,-179.064771,-68.882007,-38.091507,-16.062804,72.117249,122.831022,170.508943,173.683105,188.149781,214.983855,299.627965,360.304586,345.130418,168.335573,57.338029,-60.341516,-79.776415,-134.445904,-164.532829,-116.192176,45.977138,90.910064,57.794916,11.099511,2.204602,72.436531,232.09155,284.849601,328.255029,426.043814,399.301128,211.403511,120.794894,21.84031,24.133028,186.610049,372.533329,375.556344,284.332492,248.174218,202.484819,166.617025,78.343643,108.031009,145.412733,96.977225,14.068479,-152.075952,-182.454278,-110.965541,-74.173312,-66.113985,-79.093073,-100.428515,-160.487601,-194.462163,-285.517843,-318.668556,-304.18989,-163.360494,-71.308811,22.92112,7.433975,-76.809517,-107.227983,-85.720613,-41.902151,35.646112,56.472499,61.981292,142.569261,215.976849,368.91956,420.621774,376.960648,228.145827,192.582043,157.275978,129.111784,103.411454,114.858793,139.974975,150.071903,199.551733,191.803741,145.080932,56.553671,25.598868,-21.072229,-18.250697,64.085533,210.224958,277.559703,307.110849,268.126399,182.533527,168.521189,203.266726,234.941547,285.863153,226.946083,155.726524,67.985907,71.237729,79.304257,75.025889,145.688342,278.112332,285.48276,166.688556,80.822128,-73.3748,-98.868938,-20.762198,27.042158,72.793827,40.453845,-9.748389,-109.197819,-147.779482,-196.774919,-199.112329,-157.494957,-106.548301,-123.045453,-192.547073,-202.448677,-237.269207,-260.188735,-174.198625,-90.178979,-57.972453,-209.664593,-259.309078,-201.21034,-135.872245,-18.972287,63.75471,271.16999,290.337221,217.162925,57.28935,-19.13989,-163.475935,-202.053175,-223.718548,-231.93417,-215.476001,-156.128212,-133.326182,-59.742936,-16.760635,28.731282,28.837584,-69.406581,-169.036944,-138.468377,-4.760432,47.344552,83.180335,79.062733,91.540155,108.339678,164.844587,275.53145,298.380976,234.195533,196.618426,189.682027,208.507736,197.531381,78.792105,15.362948,-54.685943,-60.732097,-38.481472,-13.274484,49.839085,67.383876,87.900103,126.313643,140.16914,174.702023,170.312497,110.695594,112.215164,180.610369,237.611945,257.875956,233.492865,191.691796,139.197084,142.322074,149.874838,137.294628,144.543119,193.071825,189.746138,40.375413,-96.444407,-293.40574,-312.834091,-301.89485,-306.945219,-316.371628,-357.134641,-370.765619,-404.138304,-449.135851,-504.634292,-444.809065,-166.447279,-65.741895,-165.403385,-437.563077,-488.772183,-385.664335,-316.71063,-325.810225,-447.284339,-481.530297,-477.509718,-452.561904,-403.385748,-407.772867,-459.214239,-440.317769,-211.296457,26.026494,43.872211,-87.77653,-157.932666,-186.648462,-179.231829,-191.89231,-235.379792,-281.542498,-408.610692,-471.999478,-566.000886,-553.23366,-335.094449,-190.904667,-26.512927,-11.433446,-9.531499,-29.479963,-77.335428,-153.376177,-141.890503,-136.199499,-258.888092,-342.10443,-493.720082,-533.724122,-568.043114,-584.025479,-516.897957,-413.233295,-210.799493,-208.03818,-262.045343,-334.992895,-351.33361,-376.156204,-356.83057,-252.987666,-244.667997,-304.28965,-416.337111,-414.732536,-348.334782,-329.240713,-334.389048,-349.279808,-319.333254,-222.805194,-236.015225,-377.190297,-423.829398,-344.23448,-256.735401,-158.385166,-147.936766,-144.482493,-140.057653,-145.869391,-201.974541,-242.647744,-328.947259,-378.501731,-411.868744,-366.05326,-366.445788,-388.52339,-397.952299,-412.887025,-384.277384,-215.292106,-28.780056,7.947737,-29.963978,-80.89662,-206.404809,-222.849231,-99.401279,-22.261295,73.351846,116.292579,113.231579,88.68524,53.729973,-51.846785,-60.464219,48.065627,134.750201,130.379903,93.446904,102.151611,173.054616,217.666705,332.012541,380.418024,367.018382,235.925989,189.166035,225.759294,276.994657,333.976113,334.948588,331.171464,351.77128,339.837008,246.444319,198.371466,191.695336,250.012521,419.547052,461.307568,444.819369,469.304868,459.518776,292.004637,194.176029,116.533623,96.951916,54.349221,196.470377,280.595552,247.314829,169.208902,70.523478,66.492742,130.994366,166.725651,156.770598,98.814834,69.224186,28.765791,34.122999,103.814084,159.516653,232.334421,187.885679,145.216897,78.596565,41.666189,-53.204884,-69.972096,-16.514376,15.633018,47.472144,75.091563,101.427071,168.880737,205.55668,285.314757,304.740078,255.436396,186.366007,163.990598,128.361984,133.828063,160.251543,154.86689,156.054966,171.016849:33.655318,-22.372995,-82.803464,-177.334856,-204.182418,-213.949482,-187.411872,-69.254799,45.664171,44.219441,-72.191766,-134.066272,-179.428573,-162.365743,-81.062874,-31.515006,122.025993,257.475899,246.817528,168.639201,156.702435,171.617479,197.037482,290.257989,328.015785,294.229884,180.308766,134.011025,57.033262,13.663503,-24.393359,14.53048,152.488247,155.781346,101.364064,13.751743,-8.526613,4.017903,53.851581,201.002219,317.828144,323.137252,217.460219,150.852147,97.121295,111.29935,155.514153,180.883376,284.565701,371.533654,370.499716,317.524723,284.125823,244.610544,236.887311,226.144726,285.610008,319.501007,232.074665,110.724251,-78.437308,-80.907544,41.459314,117.398289,202.191098,77.304489,-28.536025,-151.662186,-160.333686,-188.790292,-224.319911,-252.823263,-151.50002,-89.053342,-53.54695,-82.550439,-139.432462,-135.028233,-87.974181,-73.37861,-60.340518,-17.314253,10.76127,76.949382,125.284603,234.276419,258.420641,219.74058,221.538152,230.968257,140.909717,54.626922,-69.117309,-65.88404,60.0608,151.874765,336.77777,334.260332,227.641688,-4.968148,-57.969162,-35.921872,17.245276,172.094498,329.422362,368.924358,280.856878,166.946634,2.256493,30.502142,244.113821,333.027,395.068553,360.208675,303.440658,134.865547,62.017038,49.445107,107.836387,268.709523,375.719263,351.45945,164.969748,56.318874,-119.65085,-158.49207,-99.018607,-32.823245,98.11612,136.940959,98.873941,-51.992259,-127.819712,-148.680826,-105.503208,-60.050057,-70.868445,-83.218351,-152.207791,-205.563336,-300.103982,-303.978423,-201.390005,-140.034016,-116.393863,-217.107824,-255.923404,-266.19073,-261.874889,-218.277395,-156.754676,11.117526,130.093042,130.075082,-3.713789,-98.661144,-242.136869,-268.291439,-240.665483,-211.833145,-146.044642,-90.901774,-93.558707,-155.980572,-184.086134,-138.575526,-70.792354,14.356886,20.768397,26.637816,72.784387,118.259288,185.760908,199.102837,261.949292,310.477092,389.332603,441.843752,446.002149,383.697128,315.84465,152.663801,103.695931,148.176456,254.953104,231.099797,23.299457,-55.14139,-21.227294,35.029104,74.443493,73.328338,154.180874,247.091276,240.661425,182.295159,141.939165,51.818879,42.294833,141.7421,255.58382,254.176739,168.482939,130.975214,86.217029,77.20275,144.669774,210.089787,284.236721,207.349155,143.518728,-25.848024,-143.116123,-321.064791,-345.617279,-316.553634,-230.120578,-204.565066,-260.239501,-307.272523,-343.308746,-327.941559,-238.113542,-168.37963,-11.447358,43.928951,-10.180221,-198.24779,-265.658359,-255.479574,-197.215499,-130.255168,-235.029234,-293.232552,-296.896929,-290.992618,-378.194495,-431.354707,-426.392641,-359.350284,-125.760353,38.916946,-0.840522,-252.033186,-339.847299,-269.554888,-178.621564,-90.92973,-136.812636,-195.144556,-365.276343,-457.443152,-576.095218,-551.497191,-328.837603,-213.793122,-93.116085,-61.61108,-83.654317,-182.541359,-223.116413,-234.845214,-220.276092,-220.720142,-250.431358,-256.130055,-297.051237,-352.712696,-469.038828,-482.580607,-404.031066,-346.42026,-259.848414,-271.538351,-323.144686,-414.639527,-430.407826,-442.851899,-430.792095,-333.464628,-260.65129,-284.37579,-421.131476,-495.533315,-589.072201,-579.791038,-442.502664,-363.165989,-245.692683,-216.788471,-279.250881,-491.589162,-556.019072,-465.760623,-351.435112,-180.276891,-110.700131,-105.237399,-152.197993,-187.209781,-276.957589,-309.598742,-298.720631,-283.714358,-261.732363,-226.719253,-233.675961,-360.614802,-457.178163,-540.050821,-475.099804,-212.586774,-1.59352,37.496728,-24.417199,-97.676595,-227.127947,-245.260975,-151.712724,-57.046567,132.618046,153.67281,103.673924,4.618955,-34.948227,-74.307524,-51.617659,22.93232,57.881386,69.835941,80.855863,64.858074,-6.258793,-2.577024,168.710475,277.033359,347.675257,195.665548,131.845672,148.930415,172.974162,230.235539,287.214144,377.737727,430.873365,438.625035,316.939203,213.957512,121.891548,168.422716,365.727964,459.496655,540.155041,446.981261,363.956553,201.868512,132.324792,52.710158,55.454316,143.00671,252.958404,253.514218,110.826279,6.986309,-105.446434,-58.443254,167.667036,249.30589,265.465763,158.563132,97.392058,9.690199,-31.066158,-53.155587,-7.521247,125.642266,174.746703,130.683688,-21.979439,-87.171996,-214.969707,-265.100997,-224.246868,-137.537286,11.359249,12.049313,-12.948245,-40.955167,-33.342698,17.216442,36.291796,50.153452,79.115725,73.29872,29.098706,9.795122,-73.689453,-117.21658,-44.509448,68.034267:-175.52375,-203.029449,-214.739879,-230.59851,-265.509882,-387.110441,-414.785563,-325.231088,-135.487602,-70.527356,-103.883732,-170.843941,-244.513709,-230.174513,-197.622063,-211.109699,-187.67815,-64.609023,-17.176355,38.203456,69.573649,153.095876,191.061759,234.419601,234.118206,213.468204,89.255019,-4.201571,-150.090021,-196.779483,-250.529009,-237.500545,-154.573147,-115.904459,-115.996115,-89.785065,-49.42073,63.186898,107.889416,126.593957,125.511688,138.060601,128.401589,113.163538,91.667407,64.617276,-0.955964,0.823235,117.361492,208.930871,181.93281,92.608517,78.776826,59.353122,22.915045,-79.042922,-102.052538,-86.315772,-134.511029,-204.106396,-339.043386,-365.185862,-298.8388,-255.169021,-252.466012,-301.535479,-335.495082,-375.298455,-361.808607,-354.813419,-377.84468,-364.071256,-205.772821,-129.06942,-47.992283,-13.417525,47.580456,51.648592,26.865891,7.120309,-0.353886,86.957833,134.107614,194.404187,217.249405,258.832589,269.805176,241.82962,233.530253,265.869644,278.813534,222.874824,94.741915,64.622708,34.439335,16.426297,11.760962,69.658996,88.629944,73.005052,35.090817,-78.23852,-96.249448,42.494119,286.976582,364.864414,400.511012,417.613216,459.639017,426.383812,302.99047,279.56403,300.447701,250.319424,182.326091,86.025277,87.116282,94.090455,87.59403,140.897274,232.455963,235.928091,161.351158,118.204096,75.263814,87.242597,131.987266,132.576656,135.821482,147.758979,121.156271,45.973308,25.98902,44.712742,81.95379,166.583851,192.472244,172.422876,93.759217,69.525892,84.341334,109.765364,184.46921,211.030914,181.88198,152.881424,168.63848,209.881539,222.49276,256.367989,294.51521,389.900419,374.339927,313.125749,192.213697,157.659991,77.459028,26.714283,19.522569,53.350693,37.970725,-15.212681,6.985746,98.650535,130.145333,160.806634,170.376938,160.858742,133.064841,133.923689,146.314285,151.004349,176.970861,189.113269,144.855735,94.369564,116.549625,315.905136,360.658452,289.712028,244.195473,213.682475,198.809675,79.028391,-73.551834,-104.178425,-113.205838,-125.228137,-191.596567,-237.264856,-256.119426,-203.577518,-72.133729,-56.49554,-75.010213,-72.320198,-50.927028,-13.321426,1.119706,28.680274,79.449671,125.763473,226.119836,265.465792,264.959204,204.018369,48.316204,13.3244,44.3475,110.621946,125.481095,-3.185751,-161.546894,-405.941979,-394.84264,-247.533759,-239.398575,-288.842865,-311.701905,-260.623605,-187.468037,-210.761211,-295.910823,-301.221972,-181.042263,-35.196145,-49.502547,-244.199173,-322.683959,-255.18213,-164.981196,-139.022067,-208.712427,-193.924043,-126.718914,-106.347214,-132.173911,-186.338741,-306.619343,-317.546519,-179.888555,12.187964,33.396292,-44.612346,-44.204471,85.074345,134.523793,124.632497,76.48307,52.241378,-6.786878,-41.36493,-84.1226,-76.79157,-30.059083,5.422555,134.378883,220.111153,188.72659,93.043674,65.62609,-16.693028,-72.611323,-140.253922,-193.807948,-235.847315,-291.976422,-300.197539,-380.219325,-449.044992,-457.157388,-388.304559,-238.868472,-142.660626,-138.682897,-209.047409,-236.595239,-190.690725,-132.418615,-71.907476,-119.255101,-151.212222,-221.902076,-224.983449,-154.440594,-147.625481,-218.549542,-233.63708,-117.072083,3.022633,-34.569207,-218.374218,-267.958412,-176.607305,-80.671702,19.591115,-17.54622,-16.4813,75.601739,112.382763,9.792816,-93.990219,-191.513147,-165.16424,-71.67371,-63.686343,-113.914827,-226.176961,-235.303028,-184.116235,-140.190571,9.857985,161.761626,205.196003,194.115882,139.423355,23.82627,11.864251,86.900394,132.430322,204.528499,247.689867,254.069769,222.390582,154.346767,-7.471561,-17.147165,111.009028,229.351896,243.055364,202.15552,158.258007,49.379978,36.959029,134.827797,160.675995,54.147076,-38.207507,-1.015438,180.593312,237.251686,191.413125,152.706346,162.902375,220.805349,214.815398,96.853547,39.371808,40.244765,96.997049,230.258587,238.682805,150.67679,127.968065,136.383927,90.747449,31.31591,-55.714285,-62.470349,-76.385226,-36.290809,27.842913,88.089796,44.96706,-68.892035,-81.976784,-32.872939,-17.961007,-25.922692,-13.592655,-13.232824,-21.227972,-18.703509,-36.157353,-60.0039,-52.785699,47.986636,79.08779,17.157239,-60.481221,-182.481023,-194.032086,-161.182273,-163.33703,-215.131201,-204.248872,-165.246227,-29.232582,54.079081,145.356495,129.232532,31.666272,14.859501,52.250764,99.032621,87.557828,57.600021,57.526503,102.285066,141.542746:-165.152186,-279.446543,-316.177324,-297.912011,-307.887023,-377.16632,-354.462056,-167.891987,19.486588,69.851436,76.053067,46.185114,-76.268352,-155.159269,-236.401574,-226.533042,-174.54044,-97.781012,-40.254934,32.810909,28.752934,23.196061,43.378495,112.606908,209.361193,239.515854,168.123191,71.555497,-132.274144,-205.893697,-308.766656,-327.074924,-236.746852,-97.748199,-45.340346,44.076865,69.483904,77.821505,82.546831,118.820951,222.799705,285.791032,303.369433,244.159916,70.067961,-2.801821,-52.055694,-44.093442,33.862522,159.041308,164.017573,38.265677,-39.797305,-120.584381,-138.092003,-234.503776,-287.382923,-249.516086,-210.063272,-253.360869,-399.504615,-454.210351,-488.364783,-471.42893,-346.046369,-266.732151,-302.192751,-390.88501,-413.012344,-451.260203,-450.464206,-349.971123,-135.013503,-47.16062,-33.919263,-55.632112,-51.999825,-71.442736,-152.718656,-156.870973,-52.172505,118.224738,198.681753,286.448247,288.072874,278.700697,285.678252,273.762811,221.579885,219.721062,243.67925,238.517641,202.650683,190.330884,154.39587,123.587683,117.127164,200.668019,225.723413,204.527764,166.556521,61.889343,12.67271,-33.962352,64.892174,141.028392,223.621089,240.991849,255.194193,246.214222,220.25137,204.949646,164.104208,150.459302,147.686377,113.769217,74.115255,-30.149647,-48.38132,30.135944,100.585572,108.716434,160.362637,186.800601,87.52149,-14.683032,-91.817866,-50.619366,39.945355,42.424054,36.405166,31.087867,-1.90972,-97.974381,-87.028869,66.4037,155.79327,142.210128,66.631876,32.809438,-0.583426,11.99552,81.193611,96.712965,59.486562,39.153703,59.906468,128.518661,128.940327,77.517856,112.571093,338.953713,414.939506,323.765249,109.408721,70.038499,47.949285,31.08421,40.001231,61.500054,79.849634,88.151358,108.896361,161.985312,177.785641,199.808551,188.95978,51.1701,-72.274299,-60.27497,46.330457,104.176472,155.803604,133.400739,56.598964,37.080525,65.675901,166.053988,220.820392,250.24359,213.65999,132.893141,132.520693,137.453338,12.740532,-51.169939,-89.444201,-88.334084,-123.763622,-146.257297,-112.38235,-54.773455,50.382612,78.023084,78.47589,83.452399,85.808698,68.782779,49.336282,42.251757,119.983867,158.081142,184.382991,205.756806,277.727445,267.431083,113.154292,35.309578,22.948281,142.211306,180.429156,101.834421,-13.325302,-229.52079,-260.656899,-202.319766,-164.150205,-189.304229,-265.409902,-278.667688,-297.853492,-341.991693,-441.776561,-425.378485,-206.190125,-47.809429,-94.113102,-335.989412,-428.677175,-387.319209,-287.886783,-178.61045,-275.427754,-337.926621,-344.586253,-282.440848,-200.714736,-226.119241,-299.495958,-286.34142,-138.467029,43.561006,102.338512,94.526887,52.915428,22.879838,47.681873,122.986357,100.848629,36.762899,-41.185145,-12.63341,40.378395,38.242268,116.095979,214.620732,462.148616,616.845579,598.126341,458.305003,410.977732,433.237317,469.097447,444.733732,341.171396,318.903594,312.327229,302.681884,196.117692,119.936154,116.297114,189.112296,340.665977,404.149503,404.390099,373.947487,331.070387,260.044477,292.180501,395.491095,378.255628,340.069388,274.591854,290.653306,344.843073,318.030707,253.765003,280.597666,430.588271,526.470176,495.26662,352.191599,312.492039,344.867203,380.654919,405.429224,389.61952,379.809193,355.330951,356.227444,384.846278,378.549814,260.432845,182.05511,177.118596,289.836814,267.905659,120.122971,91.10192,190.956968,261.418303,326.712982,421.075173,486.935898,483.13317,406.969238,264.434669,249.28149,287.259493,289.051674,287.635585,355.727712,390.215479,406.276608,360.670947,177.291063,99.135399,62.071405,162.456425,237.360402,323.691661,292.763824,129.027386,89.470073,154.117066,173.861566,104.362356,30.659038,32.338555,100.919593,123.178143,87.917721,62.032212,-0.451243,-111.557817,-161.12219,-200.067731,-194.705542,-178.209074,-157.218977,-118.46791,-153.511185,-235.45645,-133.427075,-82.079435,-130.192594,-214.830814,-390.217681,-440.389914,-430.744312,-359.761621,-324.375629,-220.62337,-169.519567,-188.831629,-239.832275,-272.559241,-256.231435,-206.488128,-149.962293,-157.183723,-242.802201,-284.210194,-309.314621,-278.659123,-163.133626,-92.070559,-80.52407,-84.819831,-121.211071,-304.351146,-391.399427,-378.833312,-319.418568,-240.048666,-132.19364,-53.759134,56.2867,64.936425,47.455874,45.092274,10.238389,-104.610966,-162.54259,-201.395706,-179.226621,-135.168532,-117.2556,-54.005724,-49.784169:-144.640284,-161.327948,-137.946576,-118.077311,-152.13189,-251.677124,-251.687267,-147.556054,-54.434182,-31.867752,-51.007554,-96.057425,-206.451461,-236.434082,-201.734267,-143.566232,19.020429,103.122633,80.694642,32.788546,59.556036,153.233048,168.837143,146.414408,168.38075,185.525024,137.408196,86.800879,33.991177,20.055291,-49.353792,-74.017785,-30.712682,37.652655,22.37358,-82.440723,-94.874382,26.104711,93.244435,122.675345,111.987636,142.339587,183.62471,136.506579,-18.984632,-54.035013,-5.636461,38.458328,143.303172,251.176944,261.683932,184.074094,131.830443,96.021728,128.862216,188.549524,130.404029,104.893769,48.774135,-4.98871,-110.531053,-131.119951,-101.336073,-87.407851,-97.732121,-153.847643,-209.597506,-300.674329,-312.602359,-307.571511,-291.808438,-216.329423,-169.302154,-168.510403,-129.246265,-78.933827,-25.895837,-41.879913,-46.410719,-19.943209,5.392582,-87.556293,-134.086561,-63.795688,31.75783,180.192648,202.226179,143.658544,106.352381,134.046837,154.198741,113.774685,-11.886772,-49.054214,-4.192516,43.883171,111.484196,103.166024,67.907104,18.031135,12.590298,-2.524779,3.682227,103.565328,212.845451,244.427803,303.034672,311.580976,211.122493,144.819512,170.783849,248.3658,339.888906,294.198284,241.279994,101.466689,42.972514,25.084535,68.530858,182.993195,268.740356,292.803971,272.653493,230.395445,93.048956,30.060348,33.514252,88.612802,188.220047,152.230873,83.210061,-42.629382,-68.424144,-41.153207,-4.483094,21.53958,-11.246696,-11.167917,28.712032,41.526156,-36.788217,-102.745137,-125.129076,-85.657764,-33.739513,-59.616897,-65.456697,-31.869643,-25.233322,-39.308306,-9.191885,129.395691,191.023536,178.460979,93.839678,32.880306,-43.477861,-44.350977,-51.972722,-75.758468,-87.547308,-56.654141,-52.063324,-59.731761,-80.190622,-100.301118,-53.093558,105.604935,163.984044,142.926492,107.737677,130.658882,204.192689,227.93643,276.882971,311.631015,386.835693,426.76355,416.076114,375.844326,361.460165,303.605884,262.847001,220.482032,164.79549,93.251171,-28.809208,-26.557038,29.317271,33.422817,11.229331,7.94318,59.806695,140.46471,119.06598,0.717886,-32.330123,-27.341132,5.296967,123.73915,191.608998,173.841451,129.229816,145.575404,178.129719,145.491075,81.18209,108.876436,170.853392,103.54986,63.440927,-47.349471,-145.338563,-325.475943,-344.813434,-263.970303,-191.179987,-190.989991,-214.829993,-200.265227,-163.97161,-195.848966,-267.133321,-241.287804,-94.489017,-15.699426,-90.185703,-334.979591,-365.034011,-184.327903,-86.181841,-111.723751,-289.260691,-322.737926,-215.851613,-124.270656,-91.893203,-184.86409,-374.30735,-370.866936,-149.548036,67.375284,61.873984,-56.519346,-63.309262,21.268338,52.390792,52.362033,29.5893,7.951586,-107.61563,-187.513643,-279.559174,-248.844094,-101.539102,-49.516715,27.204049,102.26488,87.482154,-13.100939,-64.01643,-128.531713,-133.992708,-106.256441,-109.61062,-151.320984,-269.59811,-322.773975,-435.709146,-486.072878,-433.928641,-325.39679,-123.961775,-109.030257,-140.281323,-128.603014,-109.069722,-152.322806,-167.653545,-84.450443,-6.736831,-46.137156,-230.174017,-283.203525,-246.741415,-197.329976,-109.415762,-90.451167,-53.253722,21.128529,0.903429,-130.26505,-172.39699,-163.858309,-128.409464,-70.35662,-12.038213,17.851216,17.168769,-14.939713,-129.151661,-186.458079,-215.521079,-197.064062,-151.683974,-111.486465,-122.030886,-210.095064,-258.726556,-289.828138,-253.069163,-96.132666,34.625613,58.332133,53.071258,24.624666,-78.837855,-98.830361,20.953599,109.780515,228.129028,268.671042,261.009207,212.115254,150.537521,-5.242639,-23.386816,54.079735,67.654147,42.796325,7.667704,4.49571,22.895486,54.117585,119.222124,127.911073,95.915313,46.235813,64.431364,160.117585,162.220202,96.754669,101.678198,178.735422,202.260634,187.763085,106.03973,55.268268,30.920662,73.978801,218.643077,266.089984,254.634249,193.892032,148.75074,34.241876,-9.721635,-22.703332,-9.395554,-43.871351,-70.088123,-30.904627,7.695913,-42.957855,-179.042943,-199.606366,-86.207574,-6.309513,17.713254,-97.831103,-132.881012,-96.390542,-41.473039,89.237558,121.901218,56.127308,-57.683831,-87.170927,-73.755842,-47.5817,-52.016114,-70.993774,-63.104525,-57.451088,-67.588681,-63.848452,-55.324934,-7.867137,33.014496,92.572937,89.593389,46.312539,30.539838,44.969548,66.703986,36.786446,-63.901606,-73.238832,38.744181,118.775992:forward
13.466227,41.146178,9.005711,-76.38357,-72.180069,5.553604,32.056477,40.910824,22.459331,-25.351539,-159.803262,-204.059132,-277.023316,-307.359799,-236.502746,-134.214125,69.939587,152.158392,140.134379,52.068454,-24.991893,-216.736961,-270.556178,-187.311318,-5.341735,36.591467,52.85553,58.628036,-7.830044,-81.59927,-133.954547,-82.836893,48.666402,50.341332,15.848478,-8.988706,-9.80662,-84.107566,-140.872684,-156.892016,-17.723916,48.544676,50.763123,9.931596,-65.910184,-98.048561,-138.785914,-142.789278,-113.700295,-59.713009,-56.455074,-75.423801,-78.217144,-76.498093,-76.92479,-115.141654,-111.613444,-65.037085,5.103482,-5.251209,-76.558565,-97.705749,-70.433511,-52.306931,-37.580255,15.028473,39.270443,-7.532741,-74.991796,-160.740519,-142.801049,-47.77425,59.964763,107.648679,110.708759,66.881429,-48.743763,-97.568491,-90.797604,-43.746636,41.022066,118.213637,138.92274,63.130365,-24.060588,-156.859902,-155.509245,-67.833402,-23.54059,-45.948023,-128.943211,-160.847574,-213.685,-217.796034,-100.919501,-10.433266,101.357836,121.749264,123.275356,89.158913,24.439033,-139.618829,-177.600659,-120.696251,-0.459256,14.918958,-93.881208,-172.769982,-224.90868,-160.84695,67.649293,146.960908,182.616548,153.190047,121.195203,17.677391,-45.465635,-125.781933,-131.948277,-115.740002,-81.281291,-69.053058,-55.36303,-49.011193,-84.757016,-127.686666,-165.960563,-154.768136,-121.72798,-129.685782,-152.199068,-167.344905,-173.929109,-244.786217,-271.52214,-255.386083,-279.606373,-302.900993,-275.603806,-239.746894,-253.414146,-300.274912,-310.501969,-239.48468,-9.618605,146.079142,144.457534,35.291713,-22.542304,-79.862153,-88.894082,-95.993349,-95.402215,-107.582988,-175.254227,-221.44445,-292.141474,-281.349003,-145.962362,-82.556331,-58.135025,-84.770261,-106.444967,-171.700045,-196.524781,-188.392856,-163.378337,-117.528335,-22.539394,48.29962,73.074797,-2.35054,-187.773213,-221.681505,-129.515909,-50.408942,44.711873,4.622932,-48.370985,-145.398398,-180.195504,-202.883774,-183.939601,-120.104741,-44.974062,-1.780297,76.033738,87.259471,48.755942,49.928559,128.23816,138.614389,56.135794,48.265222,80.715482,154.213639,184.932894,169.691166,118.707992,51.036407,179.334123,261.933111,283.156634,241.281967,164.092059,148.809213,178.196795,199.662591,227.41136,205.02498,131.648483,-81.137964,-154.418194,-125.866879,-47.003635,81.504917,140.712022,162.182071,142.482008,95.770849,-34.872796,-98.229574,-155.209549,-150.740744,-94.725636,9.74805,28.148936,-24.78258,-50.947965,-60.636168,-80.681523,-228.191676,-351.163549,-333.464448,-208.875988,-169.183032,-203.209877,-232.247195,-229.860576,-231.601083,-243.462082,-173.171316,-147.083646,-182.954138,-207.361266,-147.899658,-94.860847,-134.032561,-228.435189,-200.649812,-90.05652,-60.199103,-72.626533,-95.098815,-114.3771,-103.168073,5.275785,159.020335,166.877092,40.17407,-37.626678,-79.081016,-15.900226,107.067611,63.181158,56.170188,116.552943,117.686377,0.971972,-57.120489,-40.196426,7.190246,95.455889,167.285033,183.706844,182.375447,153.331567,26.698785,-28.517774,-38.815366,13.906969,1.263481,-138.977588,-212.478353,-279.536577,-290.377264,-290.921848,-264.659855,-149.355045,-87.606962,-102.510878,-125.045168,-139.897713,-220.420739,-235.608988,-128.357188,62.541853,117.444198,106.978414,83.993827,36.858386,5.031899,-32.668785,-41.190621,-76.867836,-85.547494,-61.117755,-9.546991,-11.808833,-20.514246,7.080717,69.362005,71.163609,64.376771,65.230688,65.571876,18.371,-6.654782,41.262281,86.762329,94.426948,35.272258,31.645376,57.377834,41.24949,-4.04491,33.581371,213.492013,336.789012,350.298256,330.730633,313.193441,273.607594,266.936719,311.03661,332.263154,255.612436,109.343263,96.256305,191.507869,223.329777,174.950782,142.528096,141.549929,194.832396,212.952614,205.227663,188.676176,143.524192,120.674175,91.104966,74.806503,62.44353,123.911077,147.325352,144.029382,135.685351,129.916834,129.491853,139.830079,191.59639,206.055958,152.594677,119.737309,113.760704,145.204018,209.755789,184.437306,44.812937,13.324825,38.47817,29.894138,0.062502,54.698828,142.417364,270.178842,298.000587,261.153092,90.418079,29.753755,22.661526,49.71769,168.275092,259.525631,396.036297,396.53645,351.904172,228.986515,187.016193,169.798204,195.363427,291.084082,359.601249,354.483867,219.981511,115.369662,9.147433,42.550326,157.866907,182.964094:67.973955,-16.79596,-60.137827,-145.753264,-183.343157,-129.131719,-64.691451,-21.940329,-14.328179,7.642703,1.628934,-58.14797,-226.524628,-248.513332,-90.401313,15.038162,130.215788,115.380001,64.679388,-109.790529,-211.078339,-327.477225,-302.49219,-122.881671,39.393198,73.597587,55.692665,9.883606,-115.852255,-160.693128,-178.157377,-158.915883,-83.863736,-15.115823,-13.837566,-105.369157,-186.16578,-333.960359,-341.571526,-183.520617,-31.529627,-23.421011,-80.882146,-125.563294,-249.844155,-298.656828,-278.919669,-218.594543,-111.44114,-119.333103,-130.849738,-123.03199,-142.813805,-218.346782,-211.013095,-110.174598,-59.806392,-68.765966,-89.367642,-87.299867,-127.793059,-167.562261,-157.543853,-105.496987,16.152171,103.714626,106.28249,4.778423,-69.256512,-127.70505,-107.306511,-44.88174,55.242069,109.466099,123.193576,75.979043,-35.455814,-67.195209,-85.644276,-86.622213,-66.403312,25.657483,76.034026,54.538346,-27.060441,-180.609719,-200.770827,-141.998496,-82.532315,-93.507599,-137.333355,-165.744957,-281.215814,-310.621433,-195.940408,-104.388061,-9.59897,-51.716802,-88.834426,-114.424864,-117.005506,-159.632048,-182.713597,-152.558445,-52.31963,-29.688253,-64.283889,-107.513332,-179.036901,-164.709512,-51.381978,-1.50662,97.348775,181.137859,150.627397,-51.655991,-170.975097,-294.97254,-255.491799,-47.047104,26.790506,-40.99776,-186.289573,-192.648715,-165.368085,-168.127373,-172.873648,-170.234033,-160.726187,-221.367681,-293.290685,-388.140544,-366.565173,-263.895511,-247.374853,-293.8959,-302.809897,-294.723794,-292.038397,-293.98778,-364.184806,-418.312471,-393.562764,-300.242978,-105.673382,-58.550781,-68.726806,-110.080518,-139.497609,-184.015742,-180.219526,-103.184862,-29.261738,-55.638503,-162.84186,-170.477372,-123.335596,-101.749334,-43.915453,-11.911216,16.09357,-12.981411,-33.245344,-86.236784,-145.423566,-230.617905,-192.423605,-52.301567,-40.930509,-61.130396,-90.397751,-116.383915,-184.419179,-199.635819,-178.938545,-162.061547,-124.683695,-135.278566,-171.086732,-236.626205,-253.301366,-219.437887,-166.704467,-72.300735,-6.573007,30.192091,53.652061,10.199389,-112.71287,-127.831224,-49.564501,-4.784573,23.552361,-1.241016,-24.34124,-87.322815,-109.672024,-85.678153,-51.77917,25.872448,160.816631,235.285347,300.518369,274.682039,163.400043,133.071848,184.814371,226.87373,247.672793,194.13431,152.903496,58.747905,9.682556,-34.824011,-0.081512,127.945891,175.88497,160.240794,66.480669,-1.9441,-124.350566,-158.314823,-167.581418,-151.781825,-80.845051,-45.61163,-71.437162,-122.950874,-136.259466,-216.612676,-277.055468,-287.890305,-165.412106,-135.022892,-170.532257,-203.218707,-245.908958,-248.837733,-188.440099,-136.528081,-48.329726,-60.041489,-113.951376,-225.789146,-250.663766,-207.835894,-159.498572,-114.32028,-73.674704,-21.638971,43.689197,35.786898,-12.990058,-34.477306,-35.602334,-3.006851,99.724637,130.143915,111.80664,65.041133,51.354863,70.176411,109.413495,185.35504,187.804315,198.865542,223.821198,186.518022,39.790771,2.226454,55.514996,94.995743,155.046121,229.691786,239.523662,198.717341,168.170994,104.577646,86.953331,121.134049,173.042493,128.074885,-106.463137,-206.953783,-255.161335,-227.574647,-111.230506,-19.868778,169.689359,155.777513,62.639599,-145.420345,-221.330794,-219.512049,-137.896839,20.255695,76.963502,92.812964,104.205264,108.90442,101.620279,71.693043,-4.236284,-24.075956,-11.151679,-9.076417,-33.916919,-78.056236,-71.432409,1.367361,33.778542,55.806485,92.150717,107.845388,92.087636,69.064646,14.280272,0.071518,58.782737,107.969848,142.52165,94.79187,66.439637,30.591426,27.01414,72.347457,126.72043,239.436814,287.770422,289.386602,274.066072,275.040343,285.768029,276.231462,251.736112,259.808129,266.002522,189.263183,169.551278,213.832452,230.584085,202.809341,177.304194,148.219153,153.363606,128.877863,29.988299,0.856592,14.000866,46.882464,96.715413,87.3367,90.923352,152.601185,144.269359,46.910191,8.096322,8.760906,34.948108,143.880507,284.836707,301.704562,226.954702,180.470236,97.296667,66.637343,48.779109,47.378845,8.957017,-43.334026,-34.055477,2.109448,7.703078,86.50536,164.544858,306.66891,333.281463,250.382249,23.475963,-9.150932,22.40305,38.865394,191.62285,310.586944,417.864034,358.684391,317.688971,224.384433,154.974859,55.884418,95.014826,297.392463,445.111731,456.402096,295.523602,148.443218,-15.844058,17.174453,88.76045,80.282084:189.763766,18.255485,-97.304804,-179.772123,-159.421129,-100.797441,-79.40337,-27.975072,52.281585,58.203389,-52.457769,-134.604782,-232.500942,-226.517965,-131.578605,-58.68296,69.826269,16.014541,-74.63283,-224.638142,-251.257199,-197.179451,-135.774066,-18.056608,95.928174,134.866241,95.074338,14.387825,-184.513116,-238.299475,-212.156334,-172.141292,-85.913295,-52.081509,-78.995188,-180.87749,-228.839364,-247.512855,-201.169348,-48.931258,35.971027,27.516602,-96.300505,-194.845238,-318.667411,-292.64233,-166.961901,-136.964017,-110.592688,-103.505153,-140.287022,-236.941465,-255.665915,-219.054595,-190.71852,-149.353726,-123.942899,-132.646318,-191.845292,-232.989002,-307.857229,-313.230719,-217.247628,-134.099215,7.454766,43.060141,19.049696,-95.36163,-155.128679,-177.783999,-132.796481,-14.155323,24.71034,3.261182,-76.859538,-98.511771,-77.820925,-68.779746,-97.924909,-105.622803,-30.916783,74.024858,80.289912,-21.271168,-101.881205,-201.392281,-170.691182,7.976663,45.055159,-23.646996,-157.34987,-194.701893,-247.085238,-245.459914,-170.560917,-119.482485,-40.328195,-64.712023,-117.15358,-212.94828,-245.032319,-285.599178,-279.904377,-163.532036,-8.00907,3.218635,-68.860873,-100.957723,-117.030769,-98.14706,-27.263957,14.608092,102.733945,99.923306,30.158048,-189.883075,-271.252955,-208.264235,-98.978064,46.398805,73.68651,66.177432,-34.745025,-114.196331,-220.234544,-219.932923,-154.775156,-138.367976,-171.219417,-240.803814,-288.458659,-379.593843,-400.546116,-393.761315,-379.762204,-345.141711,-326.411755,-339.305668,-386.481165,-420.767251,-504.894094,-510.885016,-430.107806,-377.481036,-283.50955,-240.099499,-228.506096,-215.678931,-231.679999,-288.220157,-300.990727,-237.57997,-143.410574,-152.526537,-219.003586,-229.311261,-216.855505,-192.945931,-113.751737,-77.298741,-17.06426,-1.941919,-31.301789,-135.53483,-182.078663,-195.205786,-159.99103,-88.234402,-82.66964,-114.320245,-209.421709,-235.888226,-242.720542,-231.573667,-177.397511,-160.52153,-170.52272,-170.223496,-166.870919,-175.472362,-186.25898,-166.458821,-133.035187,-59.43565,5.927821,16.046151,-20.394465,-62.371544,-139.360796,-135.291999,-53.620599,-28.325976,-61.76683,-115.343155,-118.920714,-89.436123,-80.898979,-83.563768,-83.051199,-37.415518,123.733919,185.921798,150.572292,82.513714,-13.078805,-12.061207,41.042317,63.756045,122.86058,152.390701,100.17959,-112.466143,-210.79613,-246.759603,-190.54187,-43.233743,33.38187,1.963147,-168.409649,-230.338599,-212.422944,-179.308609,-186.559343,-200.444914,-148.387508,-94.423354,-111.269281,-211.615664,-255.146832,-269.09605,-266.467214,-270.114936,-208.809248,-178.77296,-214.19623,-255.493813,-293.482336,-298.048429,-303.151121,-283.191364,-177.332012,-139.421815,-171.754376,-212.167203,-202.485198,-156.92719,-139.593034,-146.826442,-112.810457,-59.139804,46.826672,65.470456,23.282199,15.298029,114.333198,175.476886,198.452215,138.348937,120.353865,115.57439,113.678183,129.909476,159.562332,215.372098,225.123969,217.654314,147.392712,79.491645,-40.269993,-42.729613,63.253335,117.318465,175.693405,243.508353,274.000662,268.815866,242.079566,226.973149,258.652573,340.756201,348.926658,292.452636,81.036993,-8.951972,-55.743368,-27.366919,61.236555,109.816732,201.486692,240.36705,218.850982,54.315507,-43.4942,-34.648637,72.918288,254.509647,280.240569,273.526135,259.926049,242.62455,193.756503,186.597074,230.148486,256.038773,258.852397,192.09962,137.323857,32.465157,17.501374,95.761261,151.050341,239.478005,318.623268,324.063772,256.309469,217.329859,127.997988,90.939811,112.592824,146.938169,168.057226,153.020574,157.793851,168.915353,163.098793,174.61092,206.580055,333.241312,452.271794,427.031254,253.439838,199.135262,239.635876,289.895498,364.203289,390.317298,393.069684,315.205071,302.549861,370.713467,394.300999,350.304902,317.137556,316.427569,356.605865,346.206395,268.391367,218.954268,142.286283,144.526189,188.222137,182.405756,140.247225,147.277234,162.610748,156.480495,133.520223,135.747044,170.943863,233.476424,292.50952,321.847839,292.271514,214.343627,15.490293,-39.520006,-4.602497,47.662228,43.238442,-96.567452,-110.585508,-4.044331,61.764785,160.542658,197.382133,317.509454,437.95099,377.598897,108.905559,34.451537,40.689348,104.740599,354.957259,460.625122,479.333001,374.882776,313.359057,158.655959,69.24898,-18.04477,49.476631,361.032538,623.683411,648.863081,449.476408,290.157199,90.22018,95.147084,213.356566,266.893383:-56.32417,28.29348,11.991123,-143.834269,-224.787768,-225.75758,-149.953179,9.051849,72.323427,38.529299,-131.337831,-215.772761,-318.336903,-318.321364,-196.08876,-104.468606,84.784536,128.999107,74.191541,-54.065173,-124.873919,-287.490695,-307.96914,-140.823168,90.810056,145.099896,90.520811,9.896309,-161.217824,-202.450078,-151.343308,-95.6663,5.512104,74.587914,78.058701,-17.797789,-112.912497,-262.709974,-261.680942,-161.335644,11.966268,92.389268,30.531871,-104.98799,-312.754799,-318.354342,-239.644099,-221.613898,-223.044575,-216.410794,-225.187981,-239.517623,-238.046417,-238.90106,-238.298055,-211.609199,-104.052232,-52.23973,-67.795094,-125.575399,-214.399734,-205.81063,-103.170899,-64.911372,-53.756374,-19.374227,-17.170474,-108.846835,-176.350881,-234.165352,-196.900031,-61.055641,15.318772,11.12459,-72.262082,-111.572703,-152.780017,-181.200252,-204.949649,-169.970165,-33.515266,47.654251,40.108775,5.288431,-23.158517,-128.685544,-146.08243,-14.047702,98.398951,65.626528,-113.761331,-209.736466,-326.718355,-311.348518,-147.239279,-55.621447,45.491911,19.119195,-4.928131,-24.166681,-64.782081,-193.695648,-207.644302,-107.750103,13.890633,30.700518,-81.752383,-179.206247,-274.026548,-219.610729,5.861572,82.614769,82.56627,26.636944,6.598703,-68.731952,-120.001437,-141.644732,-104.037009,-12.09204,49.329267,58.182582,57.764772,53.514896,-32.142196,-104.368238,-168.045743,-152.323458,-121.752246,-176.333037,-219.899481,-248.236337,-239.883167,-248.441874,-256.445113,-238.776163,-218.765651,-229.012294,-266.36045,-278.663676,-337.911782,-384.266389,-416.440531,-377.317439,-219.467878,-121.488115,-123.466358,-142.198634,-134.003351,-132.297806,-166.319644,-221.607338,-116.388989,-74.432726,-152.47457,-216.827766,-262.70427,-231.744709,-85.424664,-24.062643,16.595673,5.271301,-31.870939,-144.858819,-193.583564,-236.911338,-225.50926,-178.03812,-155.877685,-162.579468,-244.320221,-304.552024,-356.070149,-331.065682,-263.534946,-249.342184,-205.71097,-160.495869,-175.649008,-243.502405,-262.838729,-191.309464,-105.621859,13.705118,20.105672,34.826196,51.677995,9.108508,-113.662819,-127.784569,-44.727544,-12.984836,-58.516576,-108.249157,-96.17367,-20.811732,22.184318,56.562996,38.440948,7.991583,95.770415,148.204302,174.535318,154.265576,86.534522,70.132004,103.105581,122.195598,143.145044,101.364515,30.771331,-146.29424,-210.341959,-219.743769,-164.50613,15.685458,125.060818,92.447718,-89.959209,-161.152279,-190.949799,-192.065564,-214.169362,-212.553159,-156.972095,-58.783596,-16.24612,-19.930001,-81.45342,-249.296178,-315.001018,-378.410502,-357.967005,-326.685153,-239.679371,-202.162481,-239.373868,-315.509312,-413.963985,-388.810191,-244.218989,-137.1227,-146.980649,-242.834154,-273.814824,-220.042393,-159.478247,-115.424578,-126.335013,-91.949174,30.873425,79.209466,89.121638,66.757519,43.879515,57.800858,119.874816,118.924885,76.114604,-24.377242,-43.053962,-4.002109,14.211975,16.125436,81.775906,124.493876,89.93821,8.295646,-125.032247,-99.235919,105.601718,178.505628,199.089106,267.719497,333.825696,425.315325,411.545098,278.194745,223.745068,258.887334,339.206112,303.697368,105.156895,29.112545,26.093259,59.888525,94.022126,105.50716,195.784536,265.036721,217.01391,32.166657,-23.413714,20.472083,94.288095,266.584378,430.059945,446.377371,306.566812,247.396488,267.533262,283.18588,253.796832,241.868281,267.589659,293.223168,285.65346,262.646606,257.398794,284.577957,314.501015,307.841684,244.789128,247.40979,278.041898,269.420504,198.141092,164.108979,178.380573,213.880001,243.540482,236.81597,237.166604,203.989125,177.741187,173.234137,196.800574,279.929991,416.595803,470.683519,465.159095,421.133217,323.866203,306.413022,407.59052,482.56508,525.124945,406.715792,336.880372,290.2705,294.574646,286.138899,281.839238,311.534797,367.479991,366.378356,321.14528,308.611808,304.846226,298.489718,247.880268,209.324372,211.645691,282.504692,263.453903,162.262726,142.34446,160.512254,162.910916,203.411821,306.963089,305.084317,198.357285,160.919113,136.140548,131.270295,144.580272,139.7965,64.478164,34.222098,58.07122,96.522274,113.20888,204.182141,277.291227,394.171398,381.356949,322.666765,204.334688,194.580254,211.797229,218.208929,312.783993,390.750708,500.798777,486.945342,414.063312,227.651165,171.471861,163.115208,214.855026,396.409974,541.353046,555.533864,412.171833,284.040739,120.302057,126.582443,215.157936,258.793371:-53.148223,-105.371358,-130.574528,-176.289303,-195.72119,-154.929898,-86.623023,68.662695,144.24884,116.93617,-71.20132,-204.208617,-398.887603,-392.66058,-205.237135,-100.999403,46.613666,97.764123,68.85007,-104.717859,-209.277761,-254.889515,-178.723272,-4.944137,98.481065,109.820091,-0.248938,-85.140731,-207.391558,-232.063014,-195.189875,-130.483455,49.22311,128.551535,95.261833,-52.814578,-134.252526,-212.717322,-171.097811,26.262709,182.510308,180.773775,-13.194401,-148.926222,-321.842968,-329.650619,-232.838874,-163.699164,-59.958522,-64.47403,-106.132383,-240.785485,-294.200507,-261.292386,-195.529057,-59.688241,40.665579,27.207905,-136.135053,-217.43794,-256.461699,-220.668867,-104.414168,-47.182287,29.413962,6.714263,-41.250187,-151.696753,-192.018854,-177.537426,-120.074437,5.813319,49.224344,19.171153,-87.639911,-126.12729,-173.161644,-183.923471,-136.892534,-80.016354,41.180678,72.613272,50.120632,-57.428684,-137.697189,-196.071564,-125.438687,112.909362,218.995978,179.247598,30.000861,-31.915802,-121.972601,-138.588786,-91.054602,-43.763426,52.587514,31.682982,-52.948914,-220.214526,-234.669069,-128.342934,-57.425637,31.17199,67.40361,68.089544,-11.202517,-93.280485,-207.37843,-170.308557,67.18681,179.760805,248.207613,147.629911,81.289409,-53.181316,-119.311671,-150.762192,-99.348048,45.739501,159.866127,185.423445,148.004618,87.55546,-62.197017,-96.56911,-49.669414,-26.858704,-60.537621,-119.090401,-129.923373,-182.978828,-248.416742,-353.38408,-351.548688,-265.2802,-173.360927,-175.466057,-255.657065,-298.723767,-370.62004,-391.138564,-366.659616,-301.122079,-101.583565,-27.17517,-54.782887,-137.81368,-169.483831,-201.847344,-204.844464,-142.337245,9.102797,51.032171,-7.50221,-60.618637,-85.127666,-36.261702,122.407035,174.318488,192.231616,157.507395,109.373198,-69.246173,-160.308938,-195.70637,-143.935613,-52.197077,-49.204053,-68.702591,-132.849367,-176.034957,-240.761362,-232.143653,-169.837867,-150.970241,-126.77738,-63.878355,-20.63561,14.732088,-2.378583,-10.647131,18.949769,105.313015,153.012129,136.847037,58.850935,25.478778,6.142481,12.81686,14.629597,16.937225,71.182389,146.636402,170.965809,158.643451,113.653857,48.913163,60.966299,144.964045,239.656266,248.122145,179.213592,122.311829,15.82633,-0.360871,77.430103,147.735488,268.356514,231.626289,135.105315,-80.476807,-155.923005,-198.648346,-153.121376,31.772933,174.987815,172.551914,49.357163,-13.827712,-79.687322,-86.704107,-47.024276,-1.70559,95.848618,96.915483,66.387829,-3.19074,-51.271979,-134.688606,-145.931681,-158.496511,-183.400604,-185.914111,-181.723257,-181.060804,-201.407758,-242.032011,-371.546606,-396.122332,-266.0985,-116.685827,-106.331251,-177.112053,-222.967965,-231.286175,-185.792136,-105.220643,-52.094901,0.622403,118.532546,135.647697,56.619614,6.986372,-17.942319,-1.65377,29.570873,3.453229,-32.888821,-118.540468,-152.261058,-178.888719,-170.92111,-106.383855,3.993303,37.399071,-19.387902,-92.55654,-215.24686,-227.946072,-112.2316,-3.987842,167.624888,174.788672,168.150881,201.285455,187.079434,109.043245,120.128585,240.676355,308.956652,278.971632,120.736832,37.096537,-80.731419,-90.167827,3.579774,64.331587,177.149799,239.753486,203.803052,35.593673,-36.123095,-53.919159,-5.730326,142.108131,277.477742,291.147136,202.102919,149.1186,118.172911,136.931582,202.867595,221.638818,205.772668,157.939484,130.098287,112.974325,113.195232,91.714529,85.418784,115.156197,172.661961,186.777288,144.786385,88.922203,-34.429286,-68.004126,-42.952809,8.731281,103.237551,58.779615,12.65986,-38.756636,-33.378085,51.918467,108.859116,208.508209,341.141608,390.590922,339.580328,252.728948,103.83907,97.621462,229.821439,316.055689,406.154609,348.583827,294.43263,199.485087,152.711743,97.94521,117.871401,224.24113,313.812436,311.3091,231.86278,193.513949,128.339564,116.646278,182.402013,211.608468,201.619034,197.099698,184.403092,95.450809,42.071274,-7.05249,2.574499,102.3824,245.145463,246.234539,92.583894,3.771854,-84.1233,-70.478294,50.281792,118.175257,119.57478,-10.018799,-41.447951,-13.197381,10.812857,31.528831,60.668606,238.869668,367.194747,307.414546,76.121696,11.541517,31.951733,90.396853,256.441957,347.10055,476.428036,395.803024,278.157649,19.791201,-64.864715,-19.785517,96.215024,330.413006,480.106447,509.152333,403.292567,274.019983,35.028905,15.463536,193.01504,310.923901:-70.688754,-53.004951,-66.104688,-121.078606,-131.768018,-93.288768,-53.679829,44.144026,98.10062,53.846157,-158.284894,-249.318447,-313.191617,-309.676887,-226.125496,-119.363844,155.283892,218.104663,141.966539,-21.283889,-72.051035,-191.111494,-261.736756,-274.421111,-57.032498,51.168877,115.004146,83.554914,5.273415,-14.077284,5.715366,42.927576,138.774652,195.008328,191.070955,126.729553,67.480373,-58.537745,-84.829566,-29.885477,60.650235,81.550894,86.210649,71.791856,-55.80997,-139.355772,-195.202313,-177.691031,-133.968065,-113.271091,-145.8805,-240.070035,-244.228243,-180.343611,-136.176178,-47.615001,35.310217,53.457277,13.43471,-0.365049,51.489753,92.247487,142.902023,119.893942,4.55544,-18.807638,-8.350789,-35.615148,-50.523269,-18.852479,9.957718,40.473006,57.024884,55.080121,-15.912114,-61.590109,-104.087656,-104.823038,-42.410656,21.061234,128.898906,154.436773,135.784501,61.930727,26.479901,-13.002577,-3.00468,52.33518,74.904847,68.104503,14.264785,-17.688057,-44.339671,-42.0715,-5.373228,30.406575,141.628305,205.055164,166.909829,40.600814,6.459401,-30.84393,-53.997502,-53.55162,3.086156,2.273971,-132.425247,-231.432808,-281.184629,-173.704652,170.841045,283.268771,289.091769,178.123137,140.058306,108.737248,89.623236,57.209434,77.515031,139.293988,70.500924,29.449411,57.919147,89.690695,75.244659,42.952507,14.643825,28.405027,88.580887,70.051495,12.476396,-67.905381,-75.562696,-87.568806,-80.266824,-9.869663,32.620144,9.40879,-68.429567,-80.892644,-87.594855,-116.249902,-138.633358,-91.134558,81.993763,217.947953,231.655382,163.88428,105.390687,36.261124,37.677161,7.888571,-17.930913,4.743466,8.772853,-36.366819,-130.46103,-118.943581,32.96113,107.651032,167.881308,139.69829,91.493587,-27.140672,-68.753779,-110.937697,-116.779914,-72.621076,32.982597,63.942552,11.086704,-59.62666,-163.493715,-160.535583,-130.736372,-122.839673,-15.599618,117.287674,107.688585,-33.70671,-112.790955,-169.488427,-119.700026,52.909823,160.560164,187.737732,191.729386,162.714063,82.72068,54.932756,43.667613,54.660999,86.800389,106.707566,112.486362,140.728139,149.984184,116.592185,94.376725,92.381145,147.136261,169.91523,170.648983,166.504044,127.833264,96.303571,130.114432,194.202253,250.157903,78.108731,-33.373403,-107.52795,-81.981418,-52.643709,-49.263607,30.749047,151.572949,163.220815,84.410415,48.044485,1.14347,-39.473773,-44.263231,27.182203,145.945155,101.372809,59.747458,-3.026822,-30.13359,-97.96678,-146.627535,-261.661434,-280.705253,-236.56873,-140.387627,-139.734597,-273.251321,-353.377545,-364.400226,-304.085414,-170.223281,-145.119151,-211.847593,-344.644179,-328.038386,-141.383963,-42.100104,-34.026273,-200.277823,-198.630045,0.951522,78.882596,42.308896,-28.408978,-135.566493,-139.56816,-40.63207,65.078792,56.293692,-32.429655,-64.315027,-95.693677,-106.901679,-134.179334,-119.673723,-78.477054,-25.002767,-53.268315,-200.747238,-260.201945,-221.044959,-158.973578,-80.492033,14.91905,94.823975,192.300976,147.175584,-48.932673,-102.10215,-59.582543,-12.456501,-49.059364,-192.945506,-237.89927,-248.038954,-227.177008,-161.556422,-136.592937,-79.065782,-34.655291,-35.646003,-52.56869,-77.569072,-161.111496,-172.050065,-45.920419,175.36181,238.42167,180.126947,112.886249,55.730108,57.366548,66.409556,65.329579,54.703595,20.041688,-5.465039,7.409808,36.606406,50.666532,44.887913,67.485404,96.604311,89.069424,82.516601,94.638352,65.343658,25.969791,7.694223,28.902883,32.271418,-37.01469,-56.861655,-17.361876,3.68424,-15.571282,-13.823512,95.909123,263.070062,305.819766,260.310751,201.003863,106.469314,115.436391,260.464663,323.298542,279.892744,118.191418,60.16902,26.48944,35.87985,70.393352,101.050512,179.434716,201.023726,196.847987,246.457194,287.848684,261.40587,187.517866,82.780863,94.903194,166.095989,131.050378,84.629283,54.815154,55.466633,5.093101,-25.997452,-27.263562,41.723496,62.72728,25.22466,1.136959,-1.810811,8.183491,32.203327,11.235043,-122.865973,-171.891893,-134.60602,-19.56415,20.874848,25.439188,32.620518,129.920461,135.226966,55.367323,-111.826354,-130.702792,-54.152606,-5.138948,47.968208,69.97442,171.829197,213.177342,140.449709,-54.597302,-81.232329,34.356457,123.262659,222.764822,249.418116,256.180034,162.240041,67.709851,-66.880174,-68.882123,25.144448,102.012664:17.051836,62.088414,17.226161,-147.571508,-222.930592,-211.531346,-105.377617,130.873706,182.710984,124.716782,-78.402895,-176.369741,-307.202117,-322.46352,-215.005951,-123.89024,57.801171,151.503217,128.646033,0.69771,-67.737808,-183.895845,-219.323946,-175.767328,-13.836203,38.389565,20.967178,-27.958264,-175.697485,-229.045677,-126.539979,16.512126,272.051279,272.532698,174.162469,-48.735853,-107.607034,-94.73004,-55.677285,44.718173,160.252853,162.57957,21.889648,-78.825611,-289.924257,-355.995812,-267.373816,-152.406072,-11.716722,-87.673639,-176.856987,-319.469798,-342.745188,-285.60805,-207.869553,-18.484732,89.416487,78.798361,-21.839947,-64.397027,-93.415817,-77.066242,52.962952,134.359469,168.111587,24.712463,-71.782504,-234.643761,-271.820353,-210.113451,-125.370967,19.820966,61.127508,50.17671,-49.802263,-120.199803,-231.882451,-257.101581,-169.387422,-56.270893,154.772294,162.885399,117.159072,41.488225,-0.911918,-57.432301,-19.088869,153.42093,267.713712,266.636696,138.540637,30.745744,-161.353016,-173.674554,-6.346494,91.942327,188.157947,172.059197,140.915238,38.882362,-34.724973,-127.261487,-92.530605,52.928859,94.03444,71.622685,-51.428642,-146.870719,-242.675637,-173.517944,118.283192,241.254813,331.313848,279.054803,213.765208,15.723334,-72.761577,-57.052585,41.938767,206.830785,227.674987,230.524723,232.186263,191.809441,34.933041,-7.059198,78.060078,149.42787,210.118541,97.881884,-0.063141,-119.253442,-134.368818,-156.517384,-145.333685,-44.950539,28.364187,8.678498,-92.464318,-123.122256,-130.448058,-129.125882,-102.828681,-63.039187,50.054369,76.272336,31.737238,-59.639135,-53.297389,58.468226,90.524103,36.436562,59.653805,97.907588,92.548664,68.051082,42.108953,58.052514,213.040528,325.039218,433.654404,336.140485,255.158166,83.789844,1.857369,-90.835713,-78.57903,5.605789,45.599884,34.590414,-51.6739,-120.952873,-231.570597,-234.917071,-139.910328,-64.401996,107.145803,165.283019,114.348761,-32.797233,-85.42336,-89.683921,-24.995078,171.332175,276.963611,280.457682,224.098181,159.527825,34.879046,19.13936,28.48069,30.484687,71.504639,115.043155,111.049616,93.766312,90.602716,93.932682,117.483388,247.08351,377.462899,376.319714,269.822546,218.729783,149.676211,145.660923,231.609828,282.768941,365.152495,350.892063,257.506565,15.384999,-44.792472,34.638569,122.975614,283.181696,407.552698,398.676186,193.843595,78.159028,-41.730025,-51.96582,23.490275,105.187518,298.153318,378.024648,324.586794,110.252406,13.330106,-69.472726,-69.901878,-111.007207,-139.439053,-109.664779,-62.270425,-86.661044,-247.364449,-348.05357,-433.30412,-375.341112,-122.765761,1.882369,-62.451838,-263.592988,-296.52835,-180.838054,-85.417018,29.138757,39.53984,44.216851,73.185098,81.190501,38.099296,-12.720645,-83.382304,-54.149062,108.656077,140.721725,51.444074,-187.862728,-257.806184,-262.557386,-234.555013,-163.299889,-84.180107,-87.406015,-185.637389,-240.103329,-322.209041,-335.608873,-240.248986,-144.707293,12.705345,68.11638,100.85914,148.108946,100.80626,-59.839845,-74.183416,41.839426,102.416992,65.598851,-98.611253,-191.053023,-324.616249,-335.87013,-233.952685,-152.352214,-14.017174,-2.291778,-57.328861,-210.055976,-270.040212,-272.488964,-201.608101,16.248705,189.151578,205.553995,94.241933,6.004614,-126.137705,-139.849476,-94.174044,-82.728321,-91.070664,-71.99603,-64.324658,-93.462011,-124.213066,-126.2408,-85.028334,-22.754681,-14.792796,-10.326092,-50.248284,-112.820924,-243.179179,-263.638513,-217.465975,-174.769469,-85.925047,-84.546102,-135.639507,-230.7657,-229.872056,-161.561492,-114.17306,23.627955,176.446363,196.797684,89.671265,8.072838,-96.746327,-100.095462,-0.563577,80.371836,201.014914,148.972101,66.959693,-83.619871,-131.553922,-159.396913,-107.009179,95.295589,186.453145,145.629042,8.289714,-30.517421,-44.653812,-43.779424,-23.986282,10.306531,118.742645,140.762985,91.440721,-17.139151,-47.362825,-60.631133,-42.6637,26.887647,84.160793,68.614555,-44.084681,-106.863919,-176.70264,-161.58677,-50.213663,1.760436,7.143795,-69.97555,-109.40625,-148.082482,-136.875988,-75.098361,-25.745112,89.294578,120.897386,83.116151,-51.97903,-108.849828,-128.729697,-78.416174,75.264248,130.857297,220.411645,234.364624,154.859158,-53.791489,-108.435645,-92.923128,-31.491608,162.633739,329.837689,339.401951,165.058286,29.828295,-152.236714,-154.813903,-17.255572,81.849239:37.555113,64.014617,55.894342,46.601467,63.366275,124.18764,148.497272,162.174613,138.755127,101.886926,-24.661203,-70.2698,-43.3535,4.670151,107.344179,162.609539,260.703632,256.927215,213.508692,96.833787,28.48786,-103.005241,-151.527687,-214.578136,-192.578637,-126.734425,14.341949,26.931326,-18.205217,-15.504303,67.698267,120.822836,212.174769,275.996532,261.680827,95.004214,-3.015927,-44.583574,18.118632,154.609007,191.536762,177.470909,122.860727,96.372944,-24.278457,-115.924259,-217.056009,-208.89623,-133.036798,-115.662352,-163.60483,-235.368949,-207.715245,-100.031484,-66.061251,-34.115957,40.207274,84.754883,137.817199,162.715703,198.399803,180.729651,119.847481,113.047439,145.378216,155.449116,122.701091,23.137722,0.09953,34.679049,81.266254,167.155016,184.702179,167.354572,62.376732,-9.457796,-103.402836,-102.475093,-45.566756,-19.943412,42.799106,120.755461,134.033763,105.911226,87.09919,117.968442,163.555489,215.512284,211.848338,198.681338,187.22869,213.364909,250.452288,235.817376,249.20876,298.951766,423.961069,498.752116,492.764361,415.782128,364.939331,271.117008,242.528773,206.043425,169.781157,158.88316,112.214469,61.480248,-20.625992,1.572647,201.857217,320.048646,407.656862,306.293074,251.343309,225.701623,256.173165,329.289009,347.427909,314.999559,207.402203,165.055016,163.435036,200.886907,253.122197,230.432777,154.809698,150.15778,205.115686,216.750205,193.629249,183.908685,199.33915,222.640058,235.586493,230.302565,173.348664,166.406603,168.925727,144.002386,62.615966,53.090026,138.050808,182.910905,232.835759,291.341772,300.699739,296.204187,300.218295,275.254801,228.889866,125.229487,141.146114,166.801892,147.642122,117.320378,56.671027,43.759134,125.705241,190.261668,246.145457,221.137024,199.824613,171.695335,159.889792,127.979872,131.49107,174.103849,129.823301,72.7529,-18.095576,-34.417972,-74.859676,-99.484568,-28.458634,72.586825,278.663636,352.216405,323.887614,250.931517,249.426054,264.91846,265.112095,283.297419,336.290307,360.968399,331.43496,305.201143,335.844485,351.549832,283.494432,240.196021,243.518872,279.811558,275.602178,231.770148,198.371661,147.237177,133.246916,59.090182,-43.640591,-53.39304,19.486226,66.341154,52.997573,11.575778,36.876025,97.990504,183.550967,125.765696,71.756314,43.005197,52.304117,41.898998,61.086744,203.968255,319.147866,337.768051,337.563671,332.025448,281.596452,222.021614,141.618347,172.147947,316.627006,383.827515,382.05839,367.228997,350.060016,273.77783,203.009005,2.67934,-122.72254,-122.987209,-72.149533,-61.639255,-127.055201,-180.822626,-200.852988,-165.185095,-127.707805,-187.074226,-233.236947,-300.519662,-285.555265,-141.817331,-84.394224,-166.705197,-282.390705,-248.198359,-69.436269,3.934734,-35.041693,-135.293036,-264.978391,-236.999096,-70.270842,-26.961835,-108.659472,-285.466168,-304.52868,-271.309968,-258.242177,-224.574713,-133.393285,-83.558946,-104.413891,-190.214284,-358.22828,-361.230689,-228.636102,-188.79767,-207.115215,-165.122599,-113.581003,-45.310532,-76.376467,-240.398618,-290.576218,-269.817938,-271.019492,-306.734601,-378.617647,-384.460403,-328.036122,-293.752302,-275.579378,-277.852876,-226.880994,-164.508845,-178.212954,-258.062104,-298.260248,-358.949303,-367.697262,-343.416513,-260.749201,-219.581176,-255.813061,-323.062721,-409.564045,-400.928181,-348.711387,-363.158049,-469.573276,-478.715393,-438.984555,-373.424557,-370.55715,-414.464425,-432.677115,-413.47739,-367.924801,-358.270983,-359.051774,-362.310331,-410.432248,-450.71962,-485.077485,-466.247263,-378.98161,-287.527518,-249.377603,-199.919091,-200.162656,-210.287703,-191.851626,-89.512321,40.541695,71.670185,18.366793,-31.64748,-86.117568,-78.807958,-1.11826,45.677619,94.135127,50.677483,-0.675976,-113.91405,-172.786174,-239.89625,-217.107225,-125.406789,-123.238436,-148.804599,-137.956137,-90.148653,-25.082499,-38.783537,-85.105845,-95.772515,-109.695473,-105.695136,-96.904811,-98.803019,-132.096123,-286.616635,-367.933543,-416.276281,-360.132771,-327.341261,-268.864527,-238.878107,-150.548546,-97.295031,-53.020622,-93.641122,-271.355217,-399.575644,-427.960313,-457.563965,-455.390451,-410.651943,-369.089205,-313.511804,-363.224005,-413.191969,-526.078597,-559.572053,-542.287576,-515.989888,-490.694525,-489.717322,-438.875645,-356.678432,-358.463391,-392.974516,-398.334155,-404.346152,-384.71674,-284.172245,-197.018299,-182.078606,-217.27312,-252.897972,-286.983468,-258.789824,-135.292764,-81.159537:-125.781089,-23.991856,32.465601,88.980794,99.024931,138.000743,159.054543,141.693511,54.425391,-7.82827,-123.891122,-143.702685,-134.753384,-125.828188,-21.064777,74.69334,251.421315,311.254341,278.250124,119.997962,13.709949,-167.84185,-210.489356,-222.54053,-136.606702,-58.475053,84.243969,114.925321,50.206109,-8.170711,-18.376716,37.993481,165.718977,208.318425,191.739107,93.671229,28.291523,-61.12823,-69.506098,-35.830364,40.947781,86.489394,119.444227,97.903215,10.671271,-41.615394,-117.407276,-132.681048,-128.352082,-150.691141,-186.999397,-194.231929,-160.007084,-148.88643,-170.778144,-158.932461,-42.168297,5.122554,-6.473159,-36.308027,-44.545017,-27.481653,-21.428235,-42.528807,-91.205894,-81.961986,-62.900664,-30.425785,-25.445207,-51.089828,-52.530364,-2.285736,30.927837,31.281329,-23.361064,-72.020133,-139.936178,-159.478472,-177.816979,-159.36822,-63.69411,55.297104,100.838496,99.97226,60.855156,43.928977,84.654363,135.934333,45.666289,-43.625354,-175.520866,-163.283773,-65.80296,-27.25048,48.012305,86.54524,155.990002,216.339873,232.719397,203.744768,158.56495,82.794788,68.548946,48.328792,26.072864,18.648369,-11.11648,-55.726058,-161.906042,-150.699734,70.846793,208.695471,346.27133,269.96385,175.172712,14.731566,4.718772,60.176087,66.580731,2.779614,-68.563687,-74.247502,-44.165854,-22.058085,-21.608039,-60.786282,-146.303206,-162.693437,-119.58675,-12.423956,20.250931,45.863594,41.437768,-28.539585,-63.425179,-87.032515,-106.823984,-111.34683,-85.91482,-69.274047,-107.595562,-155.372601,-151.88473,-84.465583,77.614005,164.524522,168.830791,168.3512,166.952526,86.327744,5.774883,-123.952833,-102.438096,-74.438734,-107.2882,-154.564517,-231.53284,-253.307636,-223.687754,-188.799046,-162.019542,-179.172469,-187.223351,-205.026188,-223.327596,-236.606268,-207.028516,-107.190182,-14.085539,25.293195,45.439274,26.836612,-31.522535,-53.940929,-23.249157,35.90005,202.982798,244.116345,167.813416,-7.453948,-56.025893,-120.814593,-135.440257,-114.31357,-37.068874,31.408144,146.786238,156.196181,126.454702,116.095835,102.424687,100.466687,140.521628,168.757414,144.220481,96.404655,102.572751,93.895827,47.900977,-34.817181,29.200324,71.282145,59.46697,32.217656,4.403209,-6.147005,-30.178005,-43.796568,-26.959983,52.330551,38.956469,-119.885165,-194.219097,-187.001573,-112.274013,15.047528,36.922279,52.143459,81.639465,59.35986,-72.130922,-139.978994,-168.829609,-134.418082,-21.667786,109.109205,139.492767,106.920004,85.964072,96.737733,95.716798,-24.736145,-194.448979,-220.232207,-148.143461,-106.199298,-140.444741,-202.541851,-263.409581,-244.234647,-134.937125,-33.646184,-70.01791,-264.346778,-322.579147,-260.70197,-195.705522,-204.543381,-333.217093,-332.748753,-181.529949,-95.674523,-83.645178,-159.560989,-274.457383,-251.73855,-53.916535,136.510612,134.567263,-43.856931,-133.814656,-149.36435,-84.381372,30.661246,19.628175,8.176991,14.232672,-1.944883,-109.998095,-148.26088,-80.811904,-23.853065,28.713309,66.845936,79.077478,41.071564,-13.556959,-118.244954,-122.504541,-90.008882,-139.32947,-175.058399,-215.812969,-213.262865,-201.188879,-217.856168,-251.877649,-239.882006,-156.991733,-49.113633,-5.267956,-4.501594,-59.621116,-157.077796,-153.586205,-67.50746,4.275493,-6.32173,-93.396671,-138.204619,-168.435774,-122.929854,12.723352,6.702905,-139.99959,-138.079554,-78.259331,-3.920759,-4.71422,-6.935158,12.484642,31.261286,5.567769,23.703158,74.449505,52.327391,-40.076534,-51.354793,22.991925,72.112088,99.812257,62.321748,69.289569,133.845758,140.75686,94.237756,121.21538,318.538678,429.46207,416.934768,350.767184,329.149721,321.021816,328.652942,362.969588,364.493671,294.052741,230.612889,224.16906,222.201037,202.003163,115.338647,85.175868,111.029388,209.716361,244.204174,228.667592,196.336406,123.141042,88.659387,86.674798,116.286049,145.473919,150.706221,171.787131,216.479305,190.471991,31.435942,-30.99746,-47.515899,-18.352439,-13.383169,-39.544494,-31.780659,59.474422,102.936354,102.28219,50.500496,-80.211479,-128.579395,-120.125816,-97.072206,-112.654547,-160.374593,-124.651832,31.026142,1.390279,-87.517507,-187.876038,-158.857947,-89.351979,-90.092721,-71.25119,-23.342703,109.683797,153.95308,108.251998,-15.656454,-32.960331,16.718163,35.724051,49.900227,99.760648,118.319356,83.924555,30.712283,-25.159492,24.429553,177.124205,208.71519:78.71222,77.590617,69.061442,-16.877966,-65.904566,-45.65007,24.118409,118.086125,102.554706,84.883918,-17.191706,-108.337643,-274.110783,-289.067398,-105.303692,43.606968,230.052526,166.080004,82.071281,-62.009719,-114.652303,-199.255614,-206.785446,-152.59377,-116.472181,-114.254721,-111.680965,-101.54603,-62.85657,-31.032375,82.380318,144.267188,215.188103,222.78747,195.239449,79.163926,14.470234,-55.78721,-34.105585,88.036445,142.77573,124.461662,57.045256,12.228357,-143.172482,-222.031278,-250.591664,-229.888156,-237.016751,-253.436614,-241.995582,-212.647452,-208.726247,-214.364356,-209.470476,-125.144719,41.807479,100.993209,129.615514,118.428028,58.062343,25.106181,35.612495,72.222674,94.043895,-24.611607,-85.111274,-116.533674,-107.106461,-76.932352,-24.476602,120.807143,114.587933,58.396511,-65.922801,-112.278197,-169.713785,-193.970717,-180.470104,-130.150995,-53.440403,-57.911311,-40.146466,71.386533,117.868157,132.745097,136.393295,206.567883,286.677018,273.585983,138.867134,76.417576,35.340038,41.659555,103.373778,171.475954,329.115749,331.392501,267.171625,118.303275,52.862985,28.460875,92.325641,194.264207,123.044023,60.782586,-101.997031,-198.104827,-266.770567,-182.893881,109.674958,204.907791,253.98576,274.642156,248.693544,147.60995,122.238089,126.475672,131.694385,134.221856,183.366566,209.264295,196.805428,184.138706,137.049908,77.887788,6.567005,42.402611,221.658009,311.543025,273.24608,145.965456,85.8056,29.326992,60.683523,154.471337,137.273275,90.450347,-14.708491,-40.664222,-18.943542,-0.017676,23.457718,44.677235,137.157284,242.359723,241.095698,182.803595,179.679797,211.410053,219.737963,197.919414,145.395792,104.090667,14.830577,10.626424,88.879729,118.44844,170.151447,224.475962,357.554464,358.752337,278.859906,131.64748,105.524879,70.638146,45.61492,15.654754,40.657401,48.401959,6.438312,-47.05387,-220.879724,-284.566092,-213.230422,-113.929793,52.210774,127.73679,115.913418,15.313895,-24.125098,-14.578525,20.982817,87.560294,165.374712,207.391029,214.185433,185.021015,131.088442,116.160935,121.32799,138.115041,169.126058,198.712518,203.746127,186.078306,178.401463,158.05342,131.840351,51.009977,-6.813594,-21.26786,10.985205,72.253959,168.027998,152.942921,88.503526,101.820094,219.052914,261.3346,200.550815,45.305127,9.581721,29.304144,80.161476,252.007406,379.747385,362.401707,208.809389,147.058214,104.049017,91.92103,114.624732,153.905644,228.789647,293.905258,299.326721,248.802192,222.27783,174.852927,116.313278,-100.37879,-217.362851,-194.773649,-113.113007,-102.974129,-211.372358,-299.519304,-389.613721,-376.152078,-237.508306,-40.221318,-34.510946,-198.01165,-252.347762,-191.463753,-123.823103,-69.704057,-68.15337,-52.858889,-57.828852,-50.963583,-13.213925,-37.336239,-125.694979,-115.90614,51.119053,128.454414,55.520638,-155.606736,-225.707632,-265.00729,-240.906948,-157.121472,-113.875156,-109.335514,-119.996889,-142.13999,-252.394493,-311.032116,-289.526834,-216.834,-88.085853,1.687766,58.746771,129.497954,86.903791,-106.174295,-158.00223,-66.726142,63.728149,52.317533,-82.190574,-138.629676,-177.27411,-189.221357,-222.759446,-205.739374,-83.351109,-76.565967,-115.473621,-76.950178,-38.506492,-113.18957,-167.846556,-122.588999,28.587109,73.465749,10.250339,-78.394451,-211.396881,-222.938871,-153.679922,-104.078827,-101.11839,-187.072888,-195.622238,-116.944157,-78.606569,-122.848409,-172.382243,-166.855897,-76.82125,-47.739631,-47.355114,-76.985547,-229.323347,-333.081942,-385.2617,-309.820815,-156.111746,-116.436677,-118.502413,-141.374472,-163.86116,-228.010329,-245.11542,-192.590468,-20.063139,47.512118,4.277289,-45.031756,-41.444154,-9.002268,60.649041,86.12124,74.060593,-9.672777,-37.662981,-52.84718,-66.634994,-64.33438,-26.743615,28.714612,20.600558,31.879545,106.099757,154.120349,150.297283,74.628943,-57.411433,-48.027008,53.043674,71.155241,51.788139,70.206025,84.724895,-9.548136,-87.085831,-138.804205,-81.791588,-69.146892,-75.355675,-56.317467,14.895095,45.572615,81.386463,59.901558,-66.487676,-172.864601,-191.445112,-153.023358,-134.101341,-198.585779,-232.548558,-161.338746,-84.29947,-120.309613,-237.930261,-239.789596,-139.408254,-99.262095,-84.741118,-90.69017,-58.750593,-30.406976,-69.902512,-190.284193,-240.807364,-295.495096,-268.104981,-104.770149,110.398806,180.662659,120.686272,23.813618,-121.842167,-146.674663,-127.617288,-86.489836:forward
280.102412,274.272652,304.748081,406.498391,409.591752,277.83964,195.414173,121.810628,135.566676,140.594012,186.40916,217.851889,217.513963,207.800278,191.382174,148.908781,80.545376,204.084549,286.650288,291.556994,205.168871,32.115169,-3.200816,-29.631713,-33.587973,-10.189058,60.206965,84.58814,94.665145,85.691092,37.247921,26.397129,114.008287,189.891414,201.315513,246.116901,246.667136,158.347887,105.927873,84.051543,207.210993,271.30903,355.844796,403.535919,450.713084,412.057195,290.961916,251.463698,222.974253,262.111205,292.575997,307.368469,292.891337,299.730607,325.184952,334.365509,258.796907,198.780836,89.794456,48.281186,-66.500037,-127.36018,-159.78516,-136.406713,-72.778992,-15.893262,23.873343,111.599995,114.811911,25.422259,-26.351693,-89.733041,-94.555865,-54.912982,102.978306,150.678271,66.429563,-4.069129,-55.975038,-48.934363,-48.676988,-88.6393,-87.760767,-28.606462,-5.70082,-45.59882,-107.55758,-229.489104,-215.248239,-167.960123,-107.212023,-115.07723,-159.107348,-162.803392,-179.741796,-239.065809,-377.178354,-292.870023,-167.603918,52.248661,88.45566,61.422084,28.223684,-66.207015,-77.742016,-35.215979,28.857741,26.351625,-0.164466,-10.288276,-45.739404,-58.141522,-5.622242,21.329898,-18.679228,-77.609134,-59.263029,1.753124,-6.103836,-127.926534,-227.852863,-222.662029,-123.494256,-60.985451,-9.89575,-36.123439,-178.706706,-269.832017,-386.388103,-344.913794,-271.696605,-142.076658,-146.020844,-263.974405,-313.692068,-338.801517,-330.089236,-313.878615,-210.041351,-143.071212,-85.190249,-101.188635,-206.869412,-270.368553,-285.151435,-145.789556,-86.686091,-84.904801,-118.30671,-190.75298,-233.499525,-293.721523,-225.581744,-157.093093,-50.131841,-30.259624,-40.179607,-52.963987,-81.839036,-94.045231,-80.777343,-25.289609,14.988118,100.955549,120.095531,84.822227,35.013447,-62.721909,-27.163305,32.041787,127.938727,134.371767,35.933078,-36.345537,-103.766732,-82.694748,22.996548,59.954643,20.014876,-85.976152,-119.719424,-155.953101,-190.024004,-307.966051,-319.170142,-262.671133,-162.801044,-162.049247,-249.21164,-305.359433,-403.97518,-438.92361,-433.631351,-328.332223,-245.93197,-94.644237,-73.211952,-121.651037,-147.126371,-115.700823,9.607571,56.028143,76.810692,61.964859,27.02041,24.107379,-41.962555,-122.342093,-177.569879,-27.124674,25.867955,30.878032,33.403251,69.429529,53.473492,-74.838298,-176.72139,-203.575455,-222.358888,-197.2503,-90.901961,-40.498908,-6.33638,-14.012948,-2.577985,5.987574,-9.500928,1.169878,33.784038,67.496618,41.180727,-13.959852,52.078131,74.18243,34.708213,-4.501761,-115.365041,-167.581239,-226.42828,-232.21462,-164.406428,-115.259762,-138.825125,-226.048862,-293.864464,-438.408813,-470.062016,-450.825298,-400.02792,-381.859058,-345.856427,-326.526916,-337.692132,-363.539997,-419.105818,-451.400299,-464.507583,-398.0302,-370.346215,-343.911274,-334.441262,-268.606602,-208.347126,-89.213053,-6.922286,14.466455,13.985916,18.169501,98.078579,135.865127,75.483701,-1.736037,-76.034794,-25.285088,-15.326087,-34.990927,-25.417544,19.143082,-1.967376,-104.469858,-56.028622,5.583954,58.481507,37.244153,-68.207767,-112.998329,-107.325101,-81.189112,-24.062324,69.541829,95.231151,67.915834,50.755337,66.656797,66.415537,45.625668,97.118097,111.410589,71.872378,55.289388,76.354578,90.36187,69.282705,62.797673,184.991975,300.338371,254.216485,57.378869,-10.560969,-1.633348,38.72296,91.791355,125.884745,128.840388,152.585325,194.190217,248.199839,230.565977,111.492302,33.54691,-86.556746,-160.909584,-179.314387,-149.325371,-126.727281,-151.211816,-181.349774,-168.692146,-58.359833,-0.028511,108.923242,147.321986,118.935264,50.035924,-108.585211,-157.678532,-169.938044,-104.555792,-30.826897,147.510499,178.585545,69.529901,-29.6174,-173.423532,-72.014499,26.705053,127.842421,123.774895,62.532435,26.599359,-10.397298,-21.015419,-62.022825,-73.748135,-46.12183,-11.798944,-36.832053,-92.361511,-96.275221,-69.75101,26.082259,101.126388,257.311095,310.363462,280.600497,200.99036,51.829601,40.461117,150.390398,201.206793,158.168858,101.107818,131.792525,224.944382,230.149857,164.510936,193.606029,260.551184,358.069809,368.691816,373.30383,365.716431,288.857217,234.630929,188.593763,224.522052,239.067409,198.011959,136.927058,43.057224,48.089293,112.173582,184.393839,206.312419,215.084101,216.226257,209.380031,193.626987,144.041149,123.090763:139.647668,207.806009,234.354054,240.101291,204.221644,63.450228,-5.934821,-69.467889,-8.699802,67.083593,210.931946,224.556104,152.26353,115.988853,58.894206,32.113876,77.877823,235.370086,278.641317,231.501616,155.619176,-8.354932,-53.346216,-67.845556,-23.26453,17.818777,97.942842,123.034561,160.031106,157.765272,61.42491,16.692488,72.782169,163.045189,171.175446,189.155422,188.845744,125.058614,85.780582,90.210651,216.186581,272.084597,306.701854,302.704805,320.569667,323.528247,198.849405,94.503001,44.376056,212.709888,275.500858,290.080212,269.737895,249.459384,254.715419,265.628665,214.753708,154.578598,84.770704,111.575271,146.41972,88.265436,-70.108356,-92.087126,-22.565963,88.614891,131.460619,154.831253,140.215624,73.086229,22.363343,-51.951187,7.842253,86.908205,252.08209,273.529329,152.487134,79.273919,8.016002,-2.046789,10.568014,54.546137,85.797816,135.602612,136.941996,46.985847,-49.241734,-190.887506,-114.841658,-53.509564,0.332396,-11.567452,-92.237929,-135.776037,-202.974794,-238.855699,-271.294368,-206.910327,-153.747574,-44.119216,-14.542512,-55.584123,-113.655799,-176.385343,-77.742756,-7.959671,79.90132,88.229687,50.398302,27.640099,28.662046,54.93176,141.411664,158.297607,109.46,9.173169,8.820639,68.078564,64.445981,-66.932874,-195.986903,-199.629795,-109.240121,-58.284571,-15.325322,-35.139951,-230.018981,-374.441334,-471.008894,-276.978122,-190.893523,-138.151205,-147.493822,-219.389508,-291.046921,-438.436497,-407.569945,-343.485926,-239.129414,-218.495316,-292.401966,-374.906127,-523.77435,-559.841749,-499.501047,-342.351816,-285.334039,-234.495045,-230.91928,-304.091987,-385.116643,-453.494086,-288.171382,-213.692965,-173.896207,-185.691865,-267.846067,-317.682673,-345.28517,-327.802933,-277.486106,-165.350971,-83.296899,35.59473,60.935774,82.19415,63.770801,-47.404159,-121.335451,-99.591628,21.044307,67.625785,36.336933,-14.366477,-70.91611,-69.993561,-25.487599,-7.901764,-20.71273,-72.792584,-122.221683,-276.826829,-356.079333,-343.177114,-173.650948,-132.926429,-105.384949,-110.310396,-210.593476,-270.544038,-345.423347,-366.75425,-349.361937,-244.777773,-171.031531,-37.934342,-14.96812,-62.189457,-96.048352,-93.013889,3.322739,45.261548,75.673586,63.028894,-18.991417,-48.69041,-53.537942,-70.679021,-129.260142,-102.927188,-55.205512,57.751586,98.58322,78.708336,17.392023,-81.49458,-46.330327,-17.697422,-41.359106,-88.608799,-152.359865,-138.990028,-94.801747,-106.720368,-131.476307,-66.186622,-9.601697,91.98681,98.616124,51.549578,32.309617,-2.980583,30.62754,75.49146,83.553698,29.109054,-88.277919,-105.295498,-81.342259,-73.532523,-51.097289,-19.925501,-27.599643,-111.283479,-177.658345,-288.895673,-321.154093,-344.195186,-309.060932,-278.124236,-257.461265,-289.229787,-371.151197,-392.802947,-467.024744,-523.030017,-522.087924,-376.578439,-327.484011,-322.702679,-328.47055,-276.892459,-230.689567,-122.230235,-16.190505,0.840847,-15.855693,-15.790309,12.540629,11.071631,-60.344525,-112.392629,-140.91227,-25.332602,27.722673,17.918279,-21.142629,-26.869193,-1.549075,-40.937337,-147.021234,-149.238555,-83.713548,-80.904179,-168.188577,-216.395079,-246.825622,-222.199816,-131.896018,-56.074244,-18.872614,40.30791,51.413835,55.943169,47.873955,34.793018,87.544961,133.383448,230.037087,247.543203,178.04629,143.406052,163.846686,185.3711,200.950205,223.328283,229.289333,165.042937,118.579888,114.462317,123.330217,98.592715,123.494701,148.450288,203.562565,225.641848,192.850924,124.750397,-46.404004,-84.202985,-5.607082,102.814521,121.972595,96.356118,69.278287,11.783421,-37.194688,-117.334173,17.457887,115.878403,208.197433,223.41462,220.538895,163.86736,-54.233167,-148.136865,-189.72813,-87.499122,-14.683633,92.620498,87.222862,-43.683302,-125.34857,-163.240323,-8.092511,47.314935,59.024074,66.368532,64.823143,27.295008,-66.191412,-88.929399,-35.422137,84.725552,119.175648,87.324327,37.466264,-58.039672,-77.713611,-28.494909,85.537357,157.475624,280.354236,290.628817,243.969702,233.701555,228.3681,214.965873,177.040477,134.07392,118.764034,111.652498,94.818465,23.326185,6.557135,55.540911,173.363473,237.590628,306.014525,296.402849,256.255218,255.583,229.055707,183.537147,139.767985,159.269239,128.250646,-1.349025,-44.156294,-46.49759,-38.503174,-12.388721,95.226564,159.914585,248.684066,251.33165,174.46235,130.323347,64.388015,30.066059:104.6167,137.162887,134.290557,111.823313,76.909549,-55.642672,-99.272152,-41.357323,89.656873,131.201685,167.592323,156.428879,64.341556,-1.202319,-108.858144,-108.200216,45.097942,226.628585,257.445712,177.090413,92.544824,-46.415022,-68.631517,-24.564094,54.397087,85.145835,158.975848,201.426774,211.5232,153.47636,12.01254,-6.323369,50.604156,83.672073,86.63189,111.144253,130.046727,129.16944,99.698701,69.390255,202.144539,281.902241,311.151776,273.875241,201.781262,168.048315,89.819113,73.42744,104.085743,154.709896,196.554314,310.691044,334.443914,254.660451,187.013136,130.220219,166.831709,163.444191,138.916596,133.337027,63.480323,-4.550385,-71.273058,-41.291845,17.477663,-30.160323,-51.281508,-2.137026,41.35968,38.573571,-11.498792,-101.387572,-82.530151,-42.409974,90.953437,161.352096,198.334677,150.977297,16.824421,-9.013663,58.819607,184.249145,232.041629,227.254839,172.280159,42.227865,-12.572516,-86.221996,-89.145934,-67.557607,-2.066808,26.136099,49.848123,52.941547,24.199058,-31.112623,-144.832348,-108.232762,-55.868712,-3.648952,-8.395375,-25.06692,-40.618295,-112.787275,-150.760266,-121.332029,3.230504,58.23931,103.637468,109.043795,127.022826,150.458059,224.549373,251.025448,218.620623,98.748703,48.841551,12.88094,0.598354,-69.661645,-123.190994,-109.143906,-48.294823,-38.419547,-81.506048,-132.606148,-294.653658,-366.130059,-379.929877,-265.862096,-188.005486,-73.645904,-83.618657,-209.892616,-294.929415,-433.787236,-346.298826,-245.634492,-110.058514,-95.445672,-172.977812,-257.296953,-436.761034,-483.899352,-430.893543,-259.70343,-205.181003,-243.807279,-296.477735,-375.100519,-403.050337,-390.155141,-276.121734,-226.415005,-205.635328,-252.261774,-390.374931,-412.20005,-358.162641,-326.745955,-258.544432,-190.462564,-162.976504,-69.267742,-2.475998,63.998443,33.459792,-13.278305,92.942186,157.225019,254.702172,275.423044,201.62865,141.005251,84.13075,71.806421,53.461178,59.370147,52.631853,7.760429,-14.633871,-51.581696,-87.229109,-149.846352,-54.360955,2.661191,-38.969244,-110.718015,-179.922443,-164.151247,-156.606636,-181.087278,-181.116925,-73.740185,-10.271337,28.88289,-18.943143,-144.853073,-180.265906,-183.606391,-133.904118,-101.286293,-37.664602,-21.875423,-32.526807,-45.079876,-67.871415,-78.048244,-85.069609,-42.467236,-7.098615,36.242051,45.2775,35.355357,-14.000448,-119.260536,-36.451864,14.374156,-36.547457,-102.463941,-129.046728,-86.376012,-84.607308,-145.727189,-196.679615,-53.046978,24.768268,51.321267,17.0464,-16.254496,-13.926168,-0.098415,105.384921,155.287734,121.073035,45.976943,-51.650812,-29.162307,18.892482,-5.316361,-47.965577,-23.378943,-22.830106,-82.415979,-147.156639,-304.031225,-367.295338,-404.448335,-307.213877,-255.580029,-230.673578,-236.938952,-236.897951,-249.11866,-334.320656,-384.767887,-387.281802,-249.403474,-194.985806,-193.44246,-213.326773,-205.563639,-187.459534,-125.050211,9.257329,77.865121,127.143446,89.82085,4.359918,6.430335,3.26373,-32.017459,-36.561233,92.71765,142.589289,130.380862,103.884674,90.916029,78.821867,8.053985,-32.943004,-23.13184,37.565414,51.271982,-47.398077,-137.753063,-236.841954,-210.669648,-102.799801,-52.432518,-30.859048,34.750799,58.646698,56.963776,41.037061,54.984549,116.604242,139.544296,175.360159,170.674266,86.491805,40.390904,39.355571,98.944944,234.523228,228.674544,203.948779,228.900605,263.410834,247.093086,179.993019,73.938083,118.230135,144.900019,146.836853,138.596699,151.827532,155.473696,58.608944,-5.60412,27.95995,146.698668,150.910202,125.371232,144.344557,168.758393,112.514183,-22.513084,52.200842,119.345299,206.336585,224.914626,153.238905,73.562244,-64.362443,-104.368536,-80.747721,75.426554,141.318502,159.882538,120.926071,-10.467488,-82.603013,-125.232992,19.713774,108.090619,188.299729,154.583268,6.90742,-48.660182,-81.578505,-75.162867,-36.153271,11.750565,26.616019,21.349959,15.514063,-0.737593,-31.206679,-66.101274,49.326016,139.44404,293.110107,332.935379,341.536185,323.285593,248.135447,224.029465,252.362417,243.028512,211.844405,156.936726,130.216393,82.01232,73.916231,87.443373,146.529559,205.705328,311.032787,308.958307,244.121372,224.929891,150.637399,79.017348,-4.372357,50.473843,70.325688,18.055786,-28.600894,-67.814907,-64.845373,-53.514698,57.875695,143.135945,216.062574,197.356544,182.705157,192.065014,132.861341,78.731405:35.218298,149.299247,203.267437,279.688552,281.619178,182.551026,84.104272,-72.406688,-8.584263,50.013973,66.994067,26.024829,-57.040959,-65.650728,-67.496481,-83.922269,-61.330639,80.575428,156.395311,219.199419,175.345329,-4.943341,-84.424334,-163.487372,-155.22962,-122.145677,-10.930936,38.984867,78.39636,71.965936,5.922886,-28.762812,-6.54035,82.899003,127.7712,195.977057,196.328751,112.724418,51.251864,6.676366,135.313485,214.651415,300.246623,301.381585,237.083192,190.375283,140.241029,135.821661,125.757157,157.383463,199.923627,239.888122,212.434454,151.493103,133.759072,100.049178,90.730877,86.130576,32.370617,-20.570762,-95.385144,-99.6383,-122.189947,-152.071235,-143.186398,-2.187436,46.722483,3.842355,-55.96873,-139.524441,-155.942697,-173.400944,-184.568459,-165.463386,-78.658905,-58.143461,-84.983587,-88.991025,-75.812464,-84.716657,-91.048801,-4.069992,62.525521,107.18956,62.012299,-51.450635,-90.035566,-124.123599,-124.373889,-101.459159,-30.445588,-27.458412,-57.929,-55.367242,-75.635595,-138.2905,-280.440258,-172.210493,-30.765028,126.490052,88.221986,-47.257291,-97.073072,-198.799263,-215.059185,-144.122206,56.854171,111.261969,89.796581,61.094769,42.050646,49.228992,58.002162,11.689867,-5.874992,6.861049,11.514998,-16.143883,-45.679738,-133.54108,-214.125069,-227.223385,-169.3688,-128.464847,-129.017347,-183.027785,-363.908851,-441.370677,-448.013111,-326.221846,-275.725049,-233.07937,-239.456477,-288.189271,-329.718179,-422.350803,-402.281652,-345.620775,-218.570998,-164.736381,-116.904913,-144.071282,-278.351017,-334.161626,-330.038954,-219.208667,-169.445837,-155.897436,-182.877869,-269.873452,-334.955198,-422.130229,-303.268511,-212.380085,-122.09479,-139.883192,-215.964437,-211.595822,-138.299542,-126.754933,-121.855051,-40.369518,13.44344,76.783171,72.298773,31.038207,9.078091,8.663787,112.576274,187.519814,305.269085,311.617086,206.104785,149.964149,132.546207,142.479296,151.683805,140.949727,125.423152,85.613273,50.28057,-27.626872,-62.143247,-124.79674,-107.832188,-81.782672,-60.198489,-65.602695,-117.642755,-169.553738,-255.529164,-251.331645,-202.099822,-181.775414,-135.41919,-4.217526,7.701893,-53.465943,-80.812937,-94.96832,-23.266553,20.839648,66.139545,78.706643,105.654538,97.0265,-30.97647,-107.916776,-100.540882,72.4894,146.032522,188.712347,170.828147,116.747604,72.61542,-34.793006,-56.562595,-45.088545,-64.749484,-82.221657,-42.565807,-9.357713,-31.742521,-71.72553,-56.374128,106.271732,157.745138,111.015168,53.868167,-2.677154,-3.686898,28.244825,172.646912,244.949153,223.419365,137.026807,-27.015045,-61.444299,-90.722974,-113.370422,-129.518064,-110.209232,-117.235584,-177.361515,-238.465457,-373.122028,-390.628351,-314.709575,-246.381404,-241.212949,-232.060609,-205.344837,-167.9533,-193.101468,-296.714749,-317.976392,-228.37275,-131.126679,-119.134794,-96.792398,-81.966646,-74.268839,-74.21098,9.872466,211.083703,277.308514,278.001667,256.362522,284.009604,320.107931,264.735984,162.409053,29.57522,75.367012,86.781765,54.412478,59.90783,122.533021,114.779244,-3.197792,8.6883,79.154614,170.441591,150.555712,26.087729,-28.88386,-68.392434,-55.131082,43.617763,143.284338,149.9315,119.427577,109.067007,125.6109,138.85904,130.177893,145.203235,185.862601,270.572871,279.701723,245.019006,216.793571,128.892995,105.986624,217.212722,362.958736,353.480527,207.501387,152.410112,150.14338,144.474093,65.786729,73.166302,123.162409,224.261133,250.745805,225.87818,187.804942,93.622985,49.665997,34.578281,60.332477,53.103832,34.043175,43.129246,81.799209,81.81725,54.584723,106.520244,148.790404,221.827619,246.58797,207.296326,142.57266,-3.565132,-54.055855,-66.738966,3.216965,65.488079,200.033266,220.6123,157.438067,112.687543,51.464339,58.30035,87.265127,149.107394,148.200638,59.208034,-0.096689,-89.466022,-114.287723,-134.857075,-105.626189,-64.288106,-37.221292,-70.763319,-111.080361,-97.137736,-54.85729,20.993321,95.236797,305.033375,376.389411,309.855212,222.464816,140.880596,152.313548,178.834779,156.134704,156.738809,189.287395,186.100367,137.800325,114.00912,91.595265,145.010712,206.885895,322.709929,341.111168,282.789835,242.653461,205.526357,190.70739,161.499321,149.064723,141.367461,94.391782,63.178784,38.929341,35.308966,45.87922,175.630094,245.159764,296.16362,312.463689,356.096903,335.45656,223.061892,191.241666:111.542557,224.429673,251.164224,240.176923,212.375298,118.542478,41.111775,-82.047163,-33.574064,15.90959,79.458143,81.238118,17.11047,-36.911763,-127.442822,-126.671679,11.233229,250.316271,326.587238,286.783292,218.696361,103.71121,40.808786,-64.832756,-0.424346,50.582313,64.608995,59.405299,73.654727,56.180148,-27.26959,-38.968309,17.145383,64.534496,93.729577,171.738993,190.384573,139.734579,73.213482,-34.491069,39.250179,127.157709,312.28539,360.700577,262.102461,137.394181,-36.453309,-7.701529,156.250323,161.495723,138.503958,181.449776,226.739472,256.373591,213.03305,89.394068,88.116437,126.221852,168.399574,138.796378,-16.84465,-116.207044,-249.070058,-228.703493,-53.953095,27.926843,14.41274,-29.940175,-58.826997,-145.036299,-186.249995,-189.140025,-128.149563,-109.882216,-83.094259,-67.066353,-48.226119,-57.134834,-124.967628,-150.391174,-63.309265,111.152051,165.626888,165.974878,125.341562,12.096201,-55.269288,-141.810986,-66.386451,4.497643,84.716687,84.506001,76.046301,68.461081,-44.250326,-133.7774,-194.910783,-49.648112,45.063628,119.556267,69.711995,-86.65713,-137.502069,-160.462524,-125.791194,-80.826636,71.746973,140.636636,168.561684,136.104027,78.168703,93.217265,173.139228,156.291375,127.509879,104.069026,85.654696,-36.985941,-114.767572,-183.857911,-172.932079,-163.427581,-122.539707,-108.057967,-151.510268,-213.685763,-376.601094,-426.325292,-381.26138,-227.517798,-147.636341,-76.871263,-114.263402,-246.814292,-297.840967,-357.091778,-319.450676,-247.923398,-88.964561,-57.029336,-103.868113,-148.259441,-223.821091,-238.031304,-215.87079,-179.10746,-147.308602,-94.111299,-116.044352,-289.090478,-388.232355,-433.909156,-295.634354,-215.283061,-106.745393,-103.778111,-191.645798,-254.308458,-350.950873,-343.072661,-172.865329,1.70464,28.069678,0.274771,-13.775448,-17.650483,-35.336678,-56.462235,105.99003,213.860591,298.425752,269.923537,186.646948,162.08428,93.555182,39.53638,-6.954454,80.160843,123.120103,78.85129,11.824387,-56.515797,-67.159089,-123.902477,-125.854019,-89.616011,-16.261965,-12.503724,-92.911411,-147.35773,-202.340416,-190.743403,-145.49793,-152.830655,-152.161981,-123.526035,-122.062781,-188.103207,-240.961323,-257.152888,-127.359541,-59.056975,68.169147,112.175601,69.687083,3.206366,-124.916436,-171.819888,-148.220537,69.318683,177.335403,232.927873,202.579338,139.781193,93.074657,-75.054179,-177.801507,-148.065366,-15.602721,20.861391,-12.490242,-63.958572,-173.806372,-203.365004,-153.931036,-6.420613,51.169418,103.500267,124.614549,112.138846,41.714984,-74.345275,71.116713,172.845151,209.613303,137.613754,-23.075385,-56.928981,-73.790352,-93.022182,-161.149724,-191.895569,-176.046675,-149.097823,-179.039683,-325.433289,-387.088102,-378.630965,-233.373555,-148.998977,-42.477887,-32.119266,-40.796783,-56.093739,-153.32237,-212.536942,-227.775088,-110.658861,-68.088657,-60.880127,-50.034514,13.395821,14.354014,-26.570611,91.08319,192.265396,302.597225,299.030936,256.878267,231.707437,145.503486,95.728923,28.117049,40.294139,73.257966,87.456519,67.241628,36.046083,-0.180335,-100.02867,-47.169168,37.99227,162.824611,149.609693,-6.342611,-98.877212,-177.927528,-136.049721,26.236367,119.366566,145.749195,208.379463,217.037389,157.196584,116.219641,77.869883,108.917206,125.479886,150.857954,167.84051,180.381556,147.130602,26.93309,30.700452,225.078957,345.59357,317.408984,192.223322,154.191331,122.332203,79.170693,-13.075821,54.33278,135.352525,267.373178,290.038744,223.207901,142.262906,5.542837,4.526139,135.088661,276.418771,306.316883,279.213831,237.29335,157.555446,132.000852,131.168605,198.594019,222.154331,225.195909,216.287491,157.098119,107.964317,14.691881,-6.637878,21.572585,86.546928,132.571039,222.932554,219.0145,122.749275,85.979074,90.898233,149.223606,184.194616,252.637162,251.97518,116.272564,10.035572,-162.650061,-185.985993,-98.979693,22.541494,56.718628,52.91655,17.582427,-63.328417,-86.668288,-41.683664,113.502773,179.664197,275.171562,306.826032,320.808841,309.239957,223.517627,173.729094,184.68276,272.67792,301.925001,250.075446,164.899061,49.42336,56.970498,115.836078,138.025391,155.794876,275.82648,310.122352,175.364831,78.904875,5.86994,12.172194,11.206324,-19.453028,-27.236396,-52.961565,-78.891692,-133.151867,-161.773409,-161.267456,9.961654,105.34977,215.291767,247.541509,257.16785,205.98603,51.094851,18.977524:115.812158,282.744773,334.9502,387.794315,391.919956,329.908387,269.875773,142.148366,59.71765,33.057859,15.510962,13.804905,-9.450022,-13.067847,-20.183504,-43.064891,-28.209302,101.097299,152.343687,171.699056,128.81557,-54.74091,-147.998081,-254.737625,-272.23946,-237.945293,-97.406563,-37.898053,-33.108189,-66.503632,-125.2485,-134.098688,-60.192245,50.811529,62.596265,58.737894,73.426492,72.374272,25.73045,-86.818532,1.09222,95.32559,218.61636,240.71168,214.737834,177.991898,112.46008,92.899104,102.185998,180.983351,240.741424,275.987365,214.463849,82.169192,48.994839,-16.714527,-67.52775,-85.673038,-143.795591,-183.392844,-261.600349,-277.825723,-262.065205,-258.646746,-219.526405,-85.509002,-33.67482,-17.991682,-42.724786,-98.352429,-113.511115,-154.922743,-188.512684,-164.348263,-63.426994,-26.020237,-9.339919,-21.618795,-64.55982,-79.298918,-100.569838,-157.492837,-155.959495,-57.267917,-38.911468,-150.592295,-208.404111,-178.861576,-78.861817,-60.349022,-49.906482,-37.643825,-19.227602,-28.065643,-121.933309,-197.119779,-250.988268,-110.124785,-22.280532,73.185467,77.794059,52.057007,11.482041,-138.595047,-137.488104,-18.093403,239.360033,262.641586,82.110949,-27.911179,-90.488509,-48.767606,38.303259,0.58068,-31.896507,-40.05443,-44.966533,-68.175454,-77.719139,-159.134136,-276.322779,-285.539638,-133.296344,-24.759065,10.268886,-77.387136,-282.790639,-344.349854,-335.659075,-215.103586,-161.907077,-102.512847,-103.773112,-167.136571,-200.388692,-199.464898,-140.462437,-93.540536,75.973439,172.432854,243.080909,195.89329,41.809717,-16.259608,-36.080354,50.545293,77.624866,21.864561,-29.720629,-121.253449,-161.874901,-143.694162,-6.777037,32.761619,35.951206,25.347102,3.511466,5.077697,53.127305,79.329777,90.248233,79.697344,102.695153,198.277005,222.351848,178.465517,128.583956,62.723456,120.09676,141.363692,129.3127,128.911081,99.487298,58.906393,21.664677,45.727714,130.145091,149.638733,118.944508,21.085391,-12.989837,7.978058,0.856304,-154.235613,-221.776341,-195.694883,-174.162986,-185.59043,-208.165699,-218.223444,-239.258397,-242.961998,-216.134442,-132.723984,-72.440425,22.748869,45.403796,88.609569,95.939042,34.555071,-0.245723,30.185208,118.573612,144.854131,134.103858,111.781663,59.422397,33.706479,82.924235,226.284393,258.974206,259.32131,247.442488,143.12157,31.598559,-191.348488,-189.961288,-133.489323,-37.300349,-0.474199,43.350577,48.15575,53.934559,58.823757,84.939362,181.290379,236.568769,254.247955,209.675139,117.057477,101.368075,130.997874,198.843871,210.500851,115.970856,24.376669,-121.899263,-146.881097,-172.30082,-202.463393,-207.217118,-104.491342,-90.769207,-239.074544,-357.900299,-475.950936,-433.867073,-248.466656,-178.612146,-222.175261,-312.017619,-300.330956,-215.11611,-192.959566,-218.447696,-232.02576,-193.640473,-201.139806,-229.714469,-213.749148,-186.672825,-156.047149,-134.40403,-17.872658,171.249085,239.951057,304.272207,326.399818,365.387038,367.845858,261.075591,147.023785,-10.930912,79.990491,148.25898,164.823134,131.255253,80.012843,51.203096,-15.529589,37.111577,106.333649,201.810799,193.168005,120.291148,98.820061,94.139687,95.559988,114.898213,137.677877,136.657368,126.437914,114.812392,129.58009,175.021064,203.312227,141.874698,161.088377,235.066958,221.052595,125.196948,100.742539,86.561198,84.528177,185.446861,299.124515,265.793631,79.254241,-3.312986,-63.793576,-43.376662,27.713068,28.74102,15.457154,59.855113,114.308287,189.102825,173.237183,-26.054003,-162.483774,-265.493568,-165.243756,-134.039366,-153.789912,-161.815413,-111.135019,-84.969539,-85.779376,-39.2619,10.966948,124.538274,176.325663,186.446972,137.898107,40.207962,24.389031,50.10087,78.043966,84.135926,105.080331,126.947524,149.342495,115.063493,24.836801,49.401805,68.451832,87.036785,89.380836,23.094562,-28.43527,-76.435111,-78.704723,-64.971454,-28.15072,-20.937969,-77.416133,-118.52464,-105.358651,-60.336291,-22.022446,-17.471074,26.164353,153.682771,186.43431,156.34354,110.147398,0.711921,-24.819743,64.636261,167.725664,152.157335,60.841213,37.457709,72.315169,91.027486,78.538161,135.448017,192.750431,253.370237,249.422547,213.507851,190.249654,145.725781,124.734015,96.046647,91.022846,99.750268,136.376071,146.440273,91.377402,29.877269,-31.251947,71.729509,122.041352,184.399214,228.526628,284.429561,243.503426,80.571247,42.807679:65.850473,259.182739,311.835996,339.757105,323.679709,241.007293,161.846131,29.544681,67.345942,90.793553,64.396761,32.087729,-44.268444,-79.716337,-108.581417,-75.663005,115.88249,274.600998,280.51911,188.945909,116.458016,-29.260465,-97.49239,-200.118894,-183.629227,-130.610371,17.20167,69.817519,47.548452,-6.156902,-85.924838,-84.502044,-13.13409,55.632202,93.536787,172.964609,163.068873,-10.748294,-110.388987,-110.606992,119.02307,208.977475,246.282336,217.391822,100.052216,23.306741,-63.666921,-34.543708,120.222854,182.164507,181.793528,201.854442,173.857452,19.29017,-47.92256,-85.561811,-29.646218,6.619159,23.439821,-23.13283,-174.351706,-226.419737,-246.223333,-216.643026,-86.75992,25.862354,38.653665,-41.614598,-120.028703,-233.139427,-236.923425,-180.092626,-149.962313,-161.104019,-155.742278,-131.300551,-97.201205,-103.214528,-167.923781,-192.565679,-116.923449,26.014065,69.555087,87.117138,47.402286,-110.870464,-192.931055,-243.131583,-79.883187,31.560502,145.130596,115.31325,-7.024122,-40.375177,-82.531985,-116.48517,-119.632404,2.740475,53.650313,71.838606,49.092462,-13.016478,-48.826094,-159.087588,-195.089346,-126.515479,79.351623,129.673514,85.089046,50.044978,8.412266,-15.224028,-4.401542,78.772817,92.250653,43.788562,-0.423825,-85.652575,-123.502241,-187.948719,-198.523334,-177.307469,-73.971907,-21.899996,-56.872671,-156.645607,-388.853819,-434.98316,-299.042368,-74.841526,-6.823126,-13.891097,-83.654363,-223.301619,-254.673526,-265.998738,-204.274974,-136.09773,14.825986,68.017864,98.208144,61.919667,-105.127749,-183.479471,-208.102128,-129.97124,-94.438027,-95.738328,-155.081527,-329.126213,-396.657046,-410.937854,-246.964936,-165.614156,-117.355369,-134.399662,-191.828831,-210.127354,-185.635034,-145.416325,-23.45897,113.677948,163.468908,164.517304,106.583678,-48.548373,-106.755552,-132.06304,-20.423247,56.626763,176.325011,190.547448,120.141221,79.848516,67.268621,84.818529,118.613478,127.518726,117.324193,38.211202,-22.18582,-139.550588,-202.931755,-308.515335,-246.275629,-177.188991,-86.449818,-77.335632,-147.628187,-221.840116,-340.260586,-338.601881,-239.292787,-150.21522,-120.276761,-66.686845,-56.649577,-85.218304,-107.653455,-121.934054,-78.714179,-46.196573,25.261533,63.861338,101.657276,66.439728,-84.324047,-118.289502,-1.454047,159.414725,197.009831,188.53396,146.976654,23.077255,-47.924114,-180.71277,-188.612532,-123.594717,47.611564,90.10136,28.5155,-34.957366,-103.02067,-92.848115,-11.388219,60.152331,85.043672,129.088028,127.927898,81.717594,76.524191,161.774317,314.568936,351.631081,252.911346,153.460679,-11.672601,-67.039308,-179.520129,-228.398971,-208.154662,-92.449551,-64.72479,-119.518128,-196.399648,-354.513149,-380.732658,-305.064399,-198.755854,-158.59269,-55.561564,-10.974118,-56.398303,-128.860728,-245.566198,-250.186176,-103.346289,14.099413,-1.712328,-56.646929,-65.198143,-88.298562,-108.541549,-62.933246,146.365838,248.894034,359.352195,381.397364,397.689869,381.464221,280.95113,206.78721,67.904974,40.624126,82.061523,177.262051,180.554779,64.896291,-27.924838,-120.788035,-9.064783,65.725514,150.94439,132.201163,12.480852,-26.567298,-29.178701,-9.11919,67.116828,157.956034,195.227746,222.1525,202.084615,113.221451,65.968578,44.510193,133.84753,167.037371,149.599613,127.252667,110.803065,89.291778,1.733193,0.920063,155.004784,273.351005,266.118184,159.520996,80.803775,-60.962894,-110.783256,-122.006697,-13.858141,39.235132,131.57549,168.883659,141.747715,80.780768,-39.917521,-68.803175,-14.188395,112.990444,152.549558,163.149708,135.976359,46.241975,11.391837,51.213747,216.746707,277.640926,316.680506,303.911357,206.559738,138.818314,48.834201,49.476324,135.031684,243.965794,295.691965,356.034333,341.441907,272.862176,237.485308,166.128824,187.171294,225.775108,247.594477,219.037456,83.718147,-9.230161,-154.409561,-169.575142,-67.563726,52.400494,72.559622,65.609641,44.347581,-35.583721,-75.413677,-55.158636,98.848925,186.584224,327.498954,344.011919,229.532775,148.467413,60.926603,59.755178,104.982611,129.634201,125.404795,97.803117,71.412416,26.046812,11.451544,-35.203628,-13.036946,61.046863,228.87259,242.175566,103.896923,27.582024,-32.46114,-27.148323,19.956934,48.796971,50.172906,39.376506,14.180381,-76.509585,-115.975083,-116.148243,18.746547,102.604061,217.510344,236.235281,194.45754,136.314889,2.050378,-22.366525:265.882918,389.209599,402.225723,390.115466,386.222893,392.210279,385.910729,308.676307,228.23594,215.017378,187.10857,152.705604,67.721081,50.447033,52.49539,42.927299,81.105032,217.698395,265.008084,266.279704,216.75776,20.072699,-108.269263,-316.90307,-345.393243,-308.017983,-222.663479,-192.841478,-162.140223,-142.226827,-90.745648,-107.144084,-203.966451,-134.059348,-42.517914,66.057513,64.393122,36.452801,24.0065,-14.99175,-19.095547,3.507715,70.803081,93.714356,98.084717,104.484988,141.355231,150.274869,163.666817,181.035311,172.787647,140.029421,116.562757,37.200913,-22.101052,-168.533914,-250.587421,-250.730525,-250.861479,-279.143225,-377.04055,-401.135247,-315.128448,-231.05971,-82.768499,5.095437,28.414468,17.901705,-9.689398,-25.070458,-10.582325,-32.437144,-56.347032,-37.736508,-35.067817,-52.986792,-29.042868,12.29002,25.575978,-26.949935,-109.903884,-69.302305,-36.882584,-8.008378,-38.019753,-142.412825,-155.762321,-101.807681,-39.56231,-18.281462,-60.844102,-117.006714,-154.927816,-108.718603,-13.643339,-30.217832,-108.376537,-80.212755,-41.3193,53.24352,98.857325,136.008083,117.166598,10.053802,-80.89181,-68.529275,37.502321,77.657341,69.923104,55.111488,68.975124,70.210056,45.859739,30.509137,31.143841,32.93437,16.642412,-22.129047,-54.408498,-212.479107,-340.442773,-327.583412,-140.210879,-5.915744,123.532035,74.767453,-90.73822,-119.178635,-19.909919,120.334669,168.308099,227.504223,227.858371,186.156162,168.579935,151.892708,154.258937,166.380378,253.147452,342.642862,493.088156,479.406633,326.141872,267.361108,288.125598,427.413615,463.083599,346.451253,224.123461,28.21342,-24.419841,-97.274049,-62.881314,16.595944,149.077229,153.873181,100.006219,90.478723,134.29725,163.815142,225.547832,250.410685,232.111521,162.023659,120.219592,57.859546,32.954811,-10.203978,-21.277977,-28.574786,-41.036474,-43.463353,-67.562713,-61.367534,22.111466,53.019706,80.795947,102.979812,86.858859,-22.782588,-95.894078,-166.744872,-175.95593,-294.015998,-437.589417,-446.989183,-384.644766,-348.309424,-301.668661,-278.125367,-232.752306,-224.402639,-199.049986,-157.808006,-132.141963,-57.971803,-23.551523,23.970113,36.772633,45.434628,91.386385,135.216863,205.910987,218.819093,223.720506,218.494696,202.035225,208.235608,265.644832,336.123749,341.580995,260.216294,189.880555,62.445311,9.576416,-117.28699,-263.666238,-311.68175,-267.787084,-192.455007,-80.954744,-45.370289,87.793022,175.719515,266.261681,213.402959,183.112436,184.523962,198.069588,185.663185,150.057818,103.78671,175.082883,172.104129,6.592203,-77.334785,-153.374087,-172.866121,-187.785049,-177.764217,-143.864783,-139.894186,-181.349823,-323.94709,-383.72886,-422.320922,-391.02016,-284.128825,-255.383084,-275.347273,-285.317875,-251.353357,-201.941578,-203.192772,-108.466168,-7.88041,52.253292,-114.431147,-167.274516,-140.328371,-107.387812,-51.911957,-20.313491,37.424642,77.055871,98.576101,174.489821,228.469973,314.831906,332.040586,275.388403,205.429914,89.81227,70.74409,89.082603,110.245608,87.828151,-20.576363,-85.036921,-122.491122,-35.858077,4.351658,71.367779,102.715177,117.071786,100.354713,64.865598,48.404184,37.55498,79.501945,98.234233,79.452709,58.540617,72.082544,89.552216,68.151053,24.615973,29.67625,93.43204,127.228623,114.856763,69.083475,24.18702,50.613529,131.036004,129.533081,74.636249,-51.152211,-72.304566,-24.706069,31.16565,111.672274,5.950421,-71.853665,-115.971175,-93.248476,-22.81775,23.61714,35.113767,-39.845775,-216.420204,-265.627759,-262.02248,-231.546303,-205.694596,-156.010571,-145.581177,-130.787381,-41.271728,2.006824,3.819638,-2.854423,77.196775,158.067606,287.487519,293.727535,206.302017,122.37346,116.115291,179.879429,216.94274,215.759248,185.851332,133.551643,84.745695,52.414989,-30.700792,-66.255122,-29.62239,39.415126,126.233554,110.558186,27.997573,-3.021439,4.447616,-16.642813,-58.525717,-111.045706,-83.708275,-15.536327,-78.113404,-135.405259,-171.275629,-130.876867,-52.401342,-55.946309,-122.935005,-151.356164,-130.324194,-82.569999,-98.135092,-158.081139,-135.919262,4.720455,20.937579,-140.923058,-174.165885,-67.959446,144.842765,178.964128,147.270155,119.83394,96.279835,105.376803,106.059464,62.822722,66.291292,143.42418,194.668783,264.683825,252.642884,128.867682,65.948595,90.251472,151.417054,156.412127,97.984553,40.460391,-81.019399,-116.930211:294.351963,322.105214,359.759423,446.871305,455.023526,375.818693,312.217601,178.591647,104.846825,120.262608,233.62134,269.286472,215.165251,182.299372,187.122999,187.455842,145.953682,99.061865,110.974144,174.259254,149.863155,-42.061283,-134.793533,-186.165676,-107.994235,-65.942599,0.504971,34.069801,75.309321,66.247154,6.904911,-17.979574,-9.599159,70.936097,123.188813,172.052471,148.749085,80.900391,44.393153,-73.960155,-66.252739,14.023026,159.333343,200.062195,259.467699,259.941399,175.546792,133.349826,125.129719,122.059163,109.311055,131.854159,162.146045,176.89258,154.526941,111.63754,100.115387,78.838337,-5.446188,-49.950528,-141.321422,-182.857154,-213.91951,-201.933529,-94.063845,56.596059,89.405971,61.995344,24.379485,-29.166076,-47.170754,-114.795359,-119.515872,-64.059018,46.131991,53.758666,2.463307,-23.276106,-85.078189,-125.378434,-153.926238,-150.714479,-153.307309,-124.498506,-108.42832,-110.540678,-119.672746,-132.306154,-111.980817,-101.780697,-153.690398,-210.011357,-268.68711,-254.310247,-270.150333,-325.089574,-379.653839,-240.105566,-114.482067,109.993813,149.554831,91.768937,21.052301,-147.567617,-163.687068,-95.245322,-3.672088,-30.628858,-134.305935,-158.727256,-167.590894,-178.682558,-172.394501,-99.093551,-93.44852,-140.554058,-141.528277,-52.784327,-12.392607,-108.351794,-313.183545,-331.132561,-132.027552,15.018574,180.276684,165.231261,-21.180362,-149.236216,-270.214338,-136.264162,-61.081279,-35.599972,-76.949549,-126.749255,-110.96436,-110.983813,-163.750923,-155.193029,-32.993263,52.275769,174.701794,184.648746,91.105068,19.370288,-3.447211,163.153909,213.033587,157.023034,99.464823,19.694963,-6.643823,-41.671167,35.303453,116.678279,245.802516,253.480009,159.100536,107.798491,81.873565,92.3717,111.038854,69.814305,50.739401,86.581557,102.568058,41.195094,-28.144335,-154.324639,-144.107696,-95.138742,-29.436979,-61.609518,-241.053177,-297.31375,-229.887894,-164.360001,-41.449668,17.604381,-29.721129,-156.852819,-149.429501,-42.251488,-50.09137,-232.572521,-352.821035,-362.273807,-365.222391,-364.776564,-331.840831,-303.031838,-278.76114,-297.374125,-315.293114,-244.045257,-195.996128,-76.711054,-17.181847,33.289533,19.919753,-8.111021,37.855676,83.210788,164.335232,161.879319,65.646288,29.349429,21.173923,15.890674,51.290492,147.260486,165.868636,167.266131,160.520254,106.585047,56.563027,-69.091512,-169.984213,-199.731216,-214.835727,-186.292362,-63.113445,-4.843471,35.820161,46.322286,141.295307,208.478435,191.717373,142.865542,127.546282,103.256254,90.925358,79.531345,153.436647,188.601825,122.082722,42.441518,-92.139401,-145.25103,-246.335201,-257.959023,-127.418945,-42.175432,-100.887358,-274.230551,-328.1759,-360.259627,-335.677457,-220.123273,-159.754642,-181.341682,-243.324867,-263.389594,-299.4699,-298.550574,-239.081668,-218.445325,-248.138338,-256.520312,-229.639235,-174.867672,-160.193062,-108.336788,-61.387354,34.066361,124.694531,155.852303,178.552883,186.492348,224.447583,238.601582,147.29039,53.391105,-34.400683,56.953054,79.811077,4.243327,-45.182434,-79.912855,-89.556407,-108.843502,-73.74317,-50.958421,9.299733,45.812404,74.894397,72.561396,62.930028,46.492425,56.666029,167.490159,189.695143,117.889515,96.863907,192.776763,235.33417,177.399654,130.393838,156.457697,224.374882,218.361928,125.3468,97.378773,127.020067,153.426347,216.384893,278.569801,264.29466,98.023383,3.957439,-42.46373,-17.323668,19.417147,65.497449,93.214935,143.840357,143.737328,76.744403,55.026898,30.80005,-23.657864,-197.567705,-262.139521,-225.349113,-126.46074,-122.494955,-168.74721,-165.136153,-101.468745,-55.10356,-56.304415,-37.024182,18.074988,134.165354,144.272703,82.75518,40.049136,-19.534711,3.849829,50.454091,146.872474,153.781355,105.363646,83.98789,29.112405,-21.815713,-24.502561,12.272827,59.201203,172.947528,183.207202,86.395679,37.423063,20.602904,13.542377,-9.52653,-41.27186,-36.634081,-12.045151,-7.913615,-9.539137,-9.253603,-18.987969,-1.191698,40.310666,99.225047,85.209643,0.217572,-32.406697,-32.788293,-16.442293,-9.268234,51.348262,93.437117,128.572698,106.322521,51.982437,148.061718,215.97436,253.806691,249.035456,251.481225,256.644798,258.819375,224.249272,107.181905,108.580315,156.946339,195.870176,156.252126,124.620779,166.882639,185.570513,134.569483,166.871438,288.178286,300.159914,178.963261,100.08628,5.842842,-23.878832:96.532217,284.994323,339.084174,390.355459,385.054849,329.774407,293.74964,208.887089,118.740977,84.528858,60.709556,57.526554,35.893707,25.503634,23.061448,30.495021,104.753603,230.481334,260.704155,205.042524,124.079691,-35.779693,-72.186616,-117.563363,-182.964953,-197.343422,-151.099707,-125.282149,-144.921663,-159.307306,-141.694141,-126.653024,-104.663016,-50.513602,-11.0577,54.812404,61.248426,6.917551,-24.300919,-13.923226,72.408724,103.856846,131.388699,137.227119,135.362454,134.153616,136.72331,132.342007,120.577974,89.834469,84.27665,140.8576,150.550019,13.01606,-102.503172,-255.311987,-229.150145,-197.486866,-193.210791,-216.814656,-278.982186,-302.607147,-302.262153,-285.259996,-222.231166,-48.13248,47.988215,54.467316,-31.352087,-120.257936,-87.111582,-46.655793,-118.295032,-135.95544,-65.330691,-16.005295,-12.651287,-35.505236,-49.11516,-55.880323,-73.283552,-66.042654,-41.728681,47.384277,52.129535,-100.89287,-205.769446,-258.866036,-96.445792,-42.149646,-53.504138,-54.457327,31.028807,74.661449,58.456705,16.26502,10.552954,93.62107,91.33852,-3.121918,-37.105128,-6.111399,17.102704,-54.013111,-101.038655,-23.085786,233.497989,314.726396,294.667657,242.510155,139.391922,96.367815,114.501826,150.903393,81.740842,-102.981472,-104.921358,24.682921,29.699957,-138.586718,-222.919914,-185.625455,-47.225007,8.699079,18.139997,-11.577817,-43.798294,-37.397847,-21.176609,-2.692935,23.616536,67.664373,63.900175,31.130287,9.497859,-11.458057,70.600456,129.304316,230.39587,275.789124,289.61916,244.472141,149.583392,123.468847,80.975779,69.715929,62.279046,-9.242211,-51.053202,-116.458362,-166.228977,-294.385332,-246.276675,-130.697196,93.078994,123.369919,-6.540053,-78.100855,-36.628174,39.491297,129.553985,163.224957,203.129804,264.587083,238.003363,104.854089,45.557654,-4.484963,66.738133,121.693667,165.571229,148.04146,79.923142,55.091102,56.823488,72.972098,100.499257,99.160165,76.750793,-11.014148,-55.070102,-99.367771,-136.098973,-312.253274,-442.19392,-426.403875,-290.686654,-223.613482,-164.384074,-152.664594,-109.241674,-104.08608,-155.144943,-136.43621,-75.639987,27.97402,25.78759,-26.62719,-33.641682,18.973226,73.044869,67.613423,46.249223,67.218507,147.342553,154.241031,66.201743,23.698448,71.939186,178.576024,189.963982,155.29486,123.315391,42.490153,-4.779132,-117.840666,-202.761854,-213.139921,-120.905564,-39.75444,39.652409,26.880083,8.164632,30.957127,140.747404,220.570061,220.012589,189.405673,155.223632,69.897939,62.461311,113.48172,151.134903,152.062173,83.341241,9.677768,-128.330375,-141.465454,-115.896102,-139.258098,-187.853054,-109.580979,-85.344684,-170.767243,-258.937122,-363.647836,-338.642549,-241.390473,-202.489457,-211.886967,-224.746617,-184.875047,-74.999886,-57.542183,-85.360482,-97.616506,-97.143938,-109.966237,-108.450028,-66.605824,-64.840149,-119.154526,-117.958872,12.442757,157.873613,181.695681,215.834332,274.040651,381.693405,367.227105,201.853404,104.730327,2.446221,54.530516,110.333983,180.750631,183.8905,166.161816,134.182407,22.380679,15.123977,61.038495,153.168618,164.148733,90.754853,44.86087,-2.472093,-10.450335,20.355858,93.083245,110.203499,87.309959,83.14056,157.672473,192.757361,144.9639,63.27423,43.898395,42.544403,75.930521,131.628317,99.395153,-19.317841,-18.620675,130.04242,194.045372,157.132895,36.056927,-25.299181,-69.65682,-51.469252,-37.206562,-29.705634,1.054049,62.405803,64.367577,9.33888,-23.319909,-69.453256,-87.316588,-74.230159,-41.273008,-39.120268,-15.732557,-3.792999,-8.771223,-10.324723,34.298204,132.554215,155.892475,144.976356,160.301384,252.913645,284.145794,264.234752,247.076811,255.725566,219.160793,191.084028,204.84074,222.415255,212.486072,194.648357,156.028366,85.877437,32.470742,-37.318173,-32.462007,-19.955714,-33.124808,-41.641593,-27.629278,-9.417442,-0.13845,15.157042,9.831693,-8.002523,-11.812308,-11.836595,-30.194695,3.959199,48.260877,159.168727,197.990367,154.58579,90.150017,2.221569,-0.924743,37.93411,1.839949,-46.474012,-100.226587,-100.187837,-80.079005,-75.944395,-80.372221,-16.602818,21.199731,70.822388,95.942952,72.051061,4.35631,-85.91534,-69.10357,-39.708715,-90.433716,-72.295237,92.385951,152.591701,107.003156,44.748567,-13.882179,61.822248,108.941639,159.364919,166.191965,139.989432,106.102284,26.829569,-6.825883:forward
-198.450332,-204.986145,-228.98153,-167.584862,-96.057414,-24.671224,-43.855386,-117.013537,-199.615375,-237.060231,-209.283107,-152.793113,-89.181398,-100.947568,-157.204263,-184.725325,-231.419134,-257.982025,-258.162958,-244.108168,-251.027387,-283.230921,-279.996623,-230.901391,-225.393901,-240.039197,-216.530422,-163.287332,-4.510978,77.006563,129.141331,81.048912,-53.613416,-102.199165,-50.546787,135.984997,201.998777,235.296139,210.326129,131.804453,97.502053,76.163498,69.670661,125.681459,240.548559,222.028853,53.944932,-18.759974,-58.746337,-45.828762,-28.974556,2.009067,7.755408,5.972834,-14.035015,-105.37052,-228.003461,-266.733418,-246.71529,-236.039395,-275.774504,-275.279613,-254.885081,-275.621435,-290.395679,-238.435631,-219.951591,-146.73644,-66.794713,59.269367,40.711335,-80.251258,-202.449452,-261.643896,-326.564363,-315.270651,-209.830701,-139.623535,-44.462708,-31.999966,-66.883686,-212.989949,-292.121477,-278.771831,-173.572355,31.372624,34.948349,-123.425918,-225.500763,-227.767455,-244.891339,-283.868661,-323.53727,-292.22883,-195.034996,-163.681729,-207.610636,-353.087238,-367.047034,-206.22379,-84.600219,69.833876,71.463469,-16.827176,-49.870875,-11.402131,38.234997,18.061265,38.52936,111.380683,224.248299,219.142571,137.662586,78.945182,101.83663,234.065848,292.853674,304.049392,250.278075,94.799799,-20.864406,-51.961225,-31.222162,18.563681,157.644318,224.944697,253.540922,211.458446,103.743668,-8.645728,-62.09667,-116.354151,-116.72059,-64.425842,-20.846982,-17.933915,-177.943189,-246.116514,-171.510989,-55.922981,107.834394,119.946203,74.247077,60.769675,73.105444,65.911573,64.423052,98.671028,137.080946,216.390612,212.495892,103.879675,-35.443801,-101.672069,-204.50886,-238.361936,-241.974372,-213.055484,-161.309916,-136.023097,-70.242433,-46.667264,-55.101221,-64.894298,-42.617905,53.638889,100.448113,158.249457,114.063244,53.25616,-30.823363,-42.472887,-52.970281,-43.40259,27.834163,59.293667,48.733498,3.277256,-5.176396,-4.111694,4.097568,63.118457,77.716207,-11.949538,-123.755376,-152.978461,-170.885402,-167.558101,-133.25396,-96.209013,-50.531297,-89.491071,-270.806046,-311.110544,-256.049104,-154.038613,-118.786592,-46.879497,-6.600753,92.448761,51.238754,-41.932912,-134.894994,-99.024745,42.517132,111.29185,118.762989,37.407158,-165.113932,-246.05779,-224.069061,-156.561034,-148.553935,-103.368901,-52.134279,-19.85616,-98.130472,-118.092323,-65.228529,-12.514393,49.323609,23.653461,-99.714947,-149.544614,-218.141951,-241.63897,-208.864995,-122.269966,-85.855817,29.223858,91.883346,135.838359,43.212871,-23.551646,-43.398475,12.424759,80.744175,66.193048,57.331447,62.495201,-3.640145,-26.39681,30.627186,133.532242,132.954672,81.44015,50.247746,4.784135,-43.230389,-87.378796,-144.299269,-137.42802,-101.054904,-85.689694,-46.106769,-18.193718,4.268552,-82.044847,-124.707507,-113.087966,-68.92707,18.184342,41.98024,87.576203,86.506029,24.334428,-140.165463,-176.408371,-103.196257,-8.272077,171.738089,184.59379,61.040345,-25.530874,-19.833341,21.032978,44.53602,142.121158,197.307741,201.105591,111.795455,79.410183,108.920381,165.965419,250.705293,263.820414,248.988952,216.256304,114.756975,-10.888638,-57.973755,-76.547577,-38.482341,110.513037,179.133878,269.06563,346.557692,376.631592,356.067667,307.092783,237.795714,217.555953,112.899388,45.79166,7.087844,69.710992,77.642372,32.034168,46.79406,213.239746,269.29625,182.419977,110.749019,131.399855,135.27177,119.756839,180.170954,224.84698,216.496329,193.056974,187.663577,229.819954,270.350885,284.523997,244.416452,218.56699,226.958928,151.295962,47.96027,34.93588,86.099337,125.728656,113.676521,51.955722,-83.675087,-126.358237,-187.080536,-272.7103,-292.618522,-193.354876,-86.053471,72.204542,73.561522,7.202917,-25.47834,-15.754749,71.183518,118.444111,205.416762,248.68637,201.266228,126.875195,111.231914,165.996341,131.642719,23.773948,-2.001943,-19.852035,-27.489762,-14.746003,-32.594928,-52.969563,2.346524,61.127883,99.587545,70.710817,-3.997036,-39.313279,-100.874856,-73.035307,-37.772825,-7.894769,4.948263,93.696118,140.062656,140.472606,44.451807,1.63343,2.406596,18.916969,-12.80718,-37.084227,-6.095108,26.09586,-46.528949,-223.771244,-232.590815,-94.341113,-7.387604,103.41354,108.260431,41.437134,-81.603534,-130.869703,-121.226177,-73.921542,44.956155,93.961862,90.864101,32.413359:-338.067308,-335.75198,-312.113138,-195.886716,-104.19011,5.031356,-13.039456,-74.492147,-132.724215,-179.866292,-167.98943,-100.900551,-47.265772,-77.70494,-125.459563,-149.958838,-256.896174,-319.517715,-281.539639,-144.850317,-121.779773,-206.370242,-253.460309,-277.4347,-318.901645,-332.463731,-243.476667,-140.256612,63.393058,96.443174,18.049247,-33.165768,-99.355301,-144.46199,-129.424348,-37.54481,4.17505,43.898778,50.240846,58.965094,28.344975,-10.003507,-29.137534,39.227212,212.590708,211.758488,5.231568,-106.415533,-184.071427,-119.696317,-63.818841,23.725455,31.903711,2.661132,-28.811081,-164.935421,-311.754956,-325.731276,-257.329456,-235.570189,-287.412891,-319.214444,-326.34124,-324.972387,-336.019614,-331.764666,-283.063402,-51.434929,67.824733,127.614294,79.921003,-27.939919,-216.799189,-316.011445,-356.949708,-305.866667,-153.203562,-96.024731,-101.300783,-156.054681,-280.087711,-333.995982,-323.950741,-226.552249,-149.390392,-90.28854,-143.060619,-254.198754,-215.584552,-183.641317,-227.664745,-281.338006,-280.679191,-223.941344,-166.486948,-190.433567,-296.639931,-396.320455,-380.357549,-227.285006,-139.166928,-28.248339,-17.289086,-52.829704,-66.217463,-63.05918,-97.967912,-113.503249,-29.252361,55.956018,194.989526,220.719621,157.433929,63.57348,78.101193,215.006389,276.788165,282.892346,229.320071,82.437052,-11.003369,-5.83012,77.587476,106.676977,146.017596,174.135112,107.400336,10.131564,-110.899703,-142.193337,-164.283699,-184.115427,-172.286915,-83.943718,-25.666777,-36.549198,-181.800036,-214.068892,-114.956526,-14.23396,98.914531,82.69469,4.23481,-31.479814,-75.174534,-48.579384,-32.051699,-13.410511,9.069817,53.031416,47.61522,-46.324618,-208.58154,-268.508291,-320.160619,-326.665788,-269.230875,-221.691507,-180.731372,-173.456632,-146.582719,-119.712068,-104.074903,-61.322107,-29.59133,44.479896,74.816933,105.076021,1.618499,-75.880593,-84.227705,-35.380329,1.109728,-1.144669,14.955348,29.807308,66.418149,96.194024,110.675787,102.843482,73.754843,48.487029,35.813008,-75.492199,-153.256891,-174.16966,-225.592633,-217.273056,-136.349221,-111.531867,-114.270263,-140.384258,-266.822573,-328.896543,-289.580578,-166.53139,-110.467885,-36.440445,-21.08634,3.147716,-0.790659,-3.590696,34.517791,53.777648,100.605181,151.905965,204.565979,140.611432,-86.001974,-143.539398,-83.153107,11.588194,-10.891827,-69.4093,-46.718438,36.288718,21.444784,-16.552455,-26.774239,14.52237,90.197878,82.10673,-35.656572,-98.272727,-172.960993,-201.998156,-165.209767,-20.440154,42.456954,106.812411,106.358736,40.254115,-96.19853,-143.457964,-91.151553,-16.328942,38.458913,10.703752,36.568494,97.265704,126.755949,45.082117,44.204611,146.731179,208.120117,227.136243,190.532822,140.421497,57.564593,-8.766553,-77.070387,-71.628944,-23.726531,5.14234,46.389796,66.081343,78.558848,-9.47907,-53.186729,-62.536667,-52.349052,-56.431082,-53.880118,-11.189448,-21.08059,-66.885153,-134.958498,-103.165502,68.105365,144.81092,178.74651,132.693463,-3.569987,-18.969995,28.645887,112.198473,131.643365,150.16156,134.203045,79.281887,66.944414,66.582001,137.738675,222.842904,284.112114,213.086249,109.600332,130.079189,105.451844,-26.739264,-42.112954,15.208681,46.89183,127.650945,189.286473,308.91064,347.205463,341.101112,298.564588,271.236335,291.923757,309.922661,184.171243,80.510106,53.760394,201.140608,216.619588,132.135765,129.415424,267.026855,313.138252,218.361408,132.413559,162.814267,280.660282,341.765861,411.502896,388.451855,298.487677,297.862412,318.930731,284.279159,305.379341,351.545537,338.467113,332.457626,356.065979,334.915354,157.193259,76.041526,59.433007,115.356529,203.446527,172.610063,25.06414,-20.78958,-78.769292,-161.291682,-158.733578,-37.870135,53.54502,184.152157,172.940667,53.56288,27.740346,62.4139,131.557062,150.345612,234.678826,297.361,280.54866,201.049512,122.647957,185.366687,206.590951,171.898577,116.024279,-52.954316,-113.664619,-65.11181,-30.20351,-78.865602,-91.122761,-17.597764,102.823045,85.4326,-59.386752,-146.403807,-265.25797,-228.972257,-180.283544,-69.526751,7.379985,140.715648,140.638972,66.166314,24.761029,-10.261435,-53.442992,-31.558128,37.004764,54.458699,19.753533,-28.637796,-146.534337,-163.907994,-110.746132,-26.283976,-20.476083,-12.016496,-11.665524,-87.791147,-255.205867,-316.160647,-224.148174,-80.096757,112.858625,84.653473,-36.594021,-45.728866:-332.208111,-302.285305,-240.177794,-117.209967,-66.320592,-11.898614,-48.316014,-184.88105,-219.324754,-190.626759,-51.681258,28.142636,32.091046,-54.152955,-199.186555,-212.615907,-237.330555,-301.875056,-298.51611,-161.632225,-63.580717,-37.626625,-134.912868,-324.369236,-326.622353,-273.738278,-143.618965,-88.705423,6.671499,33.85824,8.24143,-38.035427,-187.839375,-277.326692,-233.311145,-57.143592,-14.023563,-108.913606,-193.777716,-231.939998,-121.718216,-113.201784,-144.149653,-82.080289,70.815592,25.676295,-194.540839,-242.705929,-224.305091,-177.392792,-123.377235,-6.820395,20.172886,21.331056,-24.199292,-226.05999,-328.397057,-289.676213,-171.230135,-144.151355,-173.012425,-203.499028,-281.845189,-347.006233,-462.081276,-405.880341,-297.778511,-61.361026,6.19027,18.529838,-19.372025,-93.303762,-180.737555,-271.250257,-414.292097,-372.074892,-145.756562,-86.521328,-143.923135,-200.576928,-309.192293,-349.018461,-313.918128,-171.264128,-97.31707,-62.583409,-93.164319,-144.481468,-194.76718,-220.045957,-239.986094,-224.988069,-123.148036,-63.548057,-59.632831,-133.901716,-384.560531,-517.112725,-445.629279,-177.194149,-80.561058,-32.842089,-43.082751,-6.142606,19.88301,-20.319712,-106.161605,-111.116835,-26.53147,34.784919,122.506055,146.906736,107.961664,-4.343899,0.431079,181.918919,286.00439,353.260839,320.269476,160.128869,-45.875648,-108.209118,-88.675211,-11.25273,143.698351,126.551038,-114.049739,-209.895633,-202.786449,-229.641188,-297.944377,-335.339637,-256.437574,-53.803156,-28.815595,-179.727361,-335.64125,-338.67088,-221.692149,-142.522376,-56.483049,-68.506889,-126.128098,-147.127364,-180.691313,-167.618612,-148.880158,-108.470366,-78.006313,-48.207921,-68.003505,-132.379019,-284.417853,-387.730275,-414.943039,-320.603237,-160.084334,-163.389912,-251.592532,-265.261261,-199.179735,-140.960608,-126.325157,-81.269779,-61.759095,-43.030471,-32.782199,19.840668,24.955334,-26.215185,-114.273747,-86.920867,51.522501,91.00786,91.421701,82.06687,70.462209,171.144791,261.383957,305.496229,240.505308,126.626253,96.489188,-4.112622,-65.723266,-61.543284,-56.352327,-49.333228,-4.55685,9.3258,6.175131,-0.735182,-82.292939,-173.591232,-154.533505,-76.377062,-69.807637,-89.196639,-97.032526,-99.630093,-60.306487,-21.937319,26.460038,9.421245,25.713718,101.483449,181.25792,97.283897,-146.767757,-144.234312,-60.675384,70.675794,67.607131,-8.445584,-14.996126,20.67971,-66.854192,-103.85309,-31.528611,16.193533,41.77965,29.545345,-63.524563,-112.681458,-129.486827,-101.202097,-85.763199,-10.5062,57.012116,116.000386,53.287547,-136.531363,-200.432537,-193.680984,-135.253212,-68.148611,45.520827,38.672468,-4.844248,5.109807,26.046865,51.804397,111.963641,268.236878,303.341669,268.445996,239.397291,155.697644,-8.030687,-60.225313,-10.465878,56.236467,155.827929,191.167098,252.253652,259.46021,192.858415,69.781956,47.297605,104.094003,119.474048,82.331286,92.893721,164.654345,98.391223,29.274962,-27.683022,17.008956,206.577163,293.369608,312.076558,227.913695,23.437029,56.812095,148.656576,237.29572,209.246561,124.587229,88.784464,82.763133,133.873887,124.147654,82.869678,86.470251,118.530478,124.36505,137.479513,151.378129,108.299449,-10.839036,-37.070293,-4.855324,49.571368,177.67715,194.081109,123.861364,122.336543,172.179272,262.804102,282.566757,267.870437,219.645899,99.561409,79.779931,109.662667,124.583406,122.865896,140.130922,157.671105,192.603234,227.493087,288.967098,226.099755,201.850025,263.032545,316.612244,380.502456,376.717503,340.044883,322.218241,229.326895,198.985799,295.00998,463.181949,420.730775,257.908417,250.875656,285.973139,142.034196,61.099152,41.344757,63.645805,40.68669,24.302032,71.735289,94.043852,19.015941,-117.110128,-138.257556,-29.192807,70.453854,160.647719,131.881253,109.355118,155.154753,146.856936,118.173133,124.856279,196.20493,245.436385,231.795189,165.797087,96.3997,150.45978,166.830117,122.999332,72.510234,-44.181963,-88.292676,-54.128872,34.888545,15.43402,-45.26334,-14.305362,135.97706,179.579552,128.257233,53.870772,-149.350689,-256.820822,-230.544142,-53.106418,57.748527,156.406387,117.677041,26.36641,30.272141,36.719253,41.122429,22.456761,-32.48856,-5.266056,139.800436,182.682107,100.443105,-68.106204,-79.014695,7.143192,28.163012,-21.37977,-49.268254,-30.273279,-45.954152,-101.167593,-120.79362,-43.881532,111.848029,139.21785,137.506844,108.632665:-270.664325,-237.750286,-225.216852,-165.561575,-102.880565,0.817434,-3.189996,-48.472937,-96.791391,-130.370025,-86.891879,-11.467205,69.211631,34.463314,-91.723722,-131.609216,-179.687172,-235.064543,-232.567742,-157.124102,-132.336912,-187.080174,-236.6398,-255.237134,-235.619053,-249.210475,-218.071497,-139.046911,44.914629,75.461579,-9.844799,-66.869291,-123.211216,-156.333893,-148.544759,-45.916527,4.734158,17.775341,-11.496727,-58.115776,-34.711577,-32.526521,-47.88216,-9.324426,127.278521,131.434712,-46.432598,-146.136291,-244.704528,-257.642022,-218.317578,-67.742118,-6.763682,-13.309709,-82.165404,-254.284851,-340.853715,-334.424406,-265.380791,-238.082751,-255.229368,-287.515949,-334.429128,-347.869701,-362.045969,-297.363571,-222.889385,-57.546827,2.44663,38.764526,23.470105,-6.174083,-99.762633,-170.023477,-211.914899,-165.668859,-42.605634,-25.200024,-112.913195,-159.255342,-159.258246,-222.47307,-285.078939,-259.014465,-162.748116,-27.526436,-43.037687,-163.727102,-247.034031,-254.825268,-249.113005,-254.361155,-238.741991,-203.037254,-168.249832,-208.308046,-362.902584,-398.950451,-317.75224,-71.981174,32.777353,135.140386,140.818055,159.353995,142.98105,79.288601,-51.07796,-53.074909,87.509502,171.588239,227.428479,205.538498,123.493713,51.253852,50.39808,110.412018,151.979965,216.942717,212.626483,119.676507,-29.561122,-108.779814,-173.23494,-129.432641,46.701733,87.496662,-63.689527,-150.750481,-139.026206,-135.714385,-178.370108,-214.640331,-182.772833,-94.905942,-88.817526,-152.82007,-243.75167,-289.054771,-260.655663,-165.297755,11.029749,21.879354,-56.646297,-86.300157,-90.256358,-85.768964,-75.272755,-8.930164,32.23971,62.521844,44.601258,-57.096706,-251.320263,-328.961377,-345.293078,-313.633645,-266.846067,-250.710532,-183.680163,-121.455681,-29.024605,-91.582728,-140.383601,-176.284687,-141.212794,28.724443,93.472648,58.219362,-68.689568,-96.253783,-40.523232,10.304507,88.349777,111.756841,104.963556,78.906827,40.647101,72.986428,132.921324,230.702298,204.432451,92.822076,67.53741,46.407185,-29.306802,-90.500873,-168.594776,-159.861055,-97.809494,-76.290004,-68.928042,-67.111094,-76.204608,-134.366503,-148.842186,-100.424052,-55.05664,6.512372,10.779651,-30.753662,-126.02443,-167.307525,-176.803824,-165.36234,-113.184894,-47.089372,77.790623,61.821448,-118.283517,-186.084265,-142.477302,-69.691503,-55.859138,26.03411,80.657394,101.999666,-6.866743,-44.826511,5.824006,53.14173,59.867844,14.32049,-97.419631,-129.344967,-110.405981,-71.477626,-62.717827,0.964744,69.413008,209.291419,222.469444,82.116188,-84.354522,-114.515864,-100.909462,-73.251018,0.279462,32.773942,68.585481,77.223552,78.268443,51.431022,56.561748,128.96305,189.992698,323.026965,346.079407,233.57254,60.469657,10.455739,-6.769771,0.538873,39.538616,74.199284,111.104116,114.524601,114.252812,43.865108,8.01704,21.857241,55.393083,99.779226,107.572276,125.211195,108.471018,58.201256,-42.534617,-24.270542,124.303946,188.767913,259.268656,269.113404,208.104311,151.818106,186.647615,288.104384,302.988896,271.990813,234.682398,155.314428,158.84472,168.018987,193.310512,232.585685,279.496344,245.671759,156.374444,154.042624,154.389399,46.716577,-15.650233,-100.336197,-96.229467,55.091583,161.90885,297.573973,282.401673,261.811639,253.02381,248.226223,234.166988,219.879185,172.690824,159.345496,135.873299,69.998846,41.850331,67.593245,122.30083,225.045306,246.507429,226.279284,143.176558,98.352648,75.442134,112.423806,239.720107,281.13709,196.186299,107.088736,57.777051,177.867587,231.504738,235.804177,198.144754,155.359853,163.730726,131.016826,-26.224207,-105.475695,-157.334358,-137.151526,-59.098842,-22.471344,-24.317452,-64.965227,-167.68528,-223.120795,-221.089561,-134.596106,-47.200788,88.300795,87.459608,52.548818,66.126847,65.011803,60.901935,67.842335,130.130155,184.509853,233.727763,212.366544,159.345786,169.333015,180.6217,85.81651,-15.663096,-127.587013,-89.736948,71.343024,102.147871,54.164225,-31.944112,-33.04866,28.280323,66.961972,128.479493,123.369635,-23.567779,-193.972914,-212.142776,-90.298364,15.377266,148.137027,141.684513,98.179796,89.401624,68.609047,11.0234,-12.150138,-26.359418,-9.347377,68.13373,104.267724,52.899562,-61.039937,-64.717678,-36.383793,-28.999243,10.611232,33.716421,71.791044,85.91718,59.848445,36.877014,80.567628,198.76738,224.744185,194.301267,161.37011:-277.744548,-303.498995,-296.633361,-231.803424,-147.252174,23.005961,34.448313,-48.895236,-112.365792,-118.155319,-4.759137,110.537582,265.227258,234.295403,31.745428,-49.129883,-103.132756,-127.761037,-113.950924,0.803356,45.405861,-49.155586,-159.694958,-274.827818,-237.34053,-212.859349,-135.131236,-71.167648,61.340364,102.845377,62.545865,-22.274002,-186.656112,-215.068564,-178.508004,-55.687872,-9.284247,-14.469908,-53.574077,-134.696982,-154.953484,-132.430539,-25.564862,52.394595,111.749461,53.285941,-112.339566,-181.447178,-348.469794,-430.867442,-369.907759,-156.308718,-82.880141,-57.919664,-93.781858,-227.610555,-337.842648,-352.56844,-295.855454,-225.25188,-75.866818,-49.59953,-136.283035,-226.388289,-385.295006,-350.586332,-243.932834,-6.020871,65.788041,68.8267,0.419015,-173.618879,-244.678452,-247.800307,-242.217734,-216.264704,-109.675919,-90.740937,-179.902256,-221.037034,-239.884942,-312.729127,-354.42221,-303.04782,-196.216192,-14.91449,-12.51591,-139.892943,-290.423036,-332.799784,-351.068548,-345.211236,-278.232759,-221.17972,-160.24526,-187.692759,-356.322385,-461.253101,-402.527271,-153.381853,-40.814056,65.972745,59.655736,20.452452,0.622425,-22.305632,-50.574416,-25.424694,117.774803,191.901252,240.737416,232.548293,168.928056,57.416127,28.924973,61.432974,99.390348,119.392255,90.527495,15.485682,-118.730906,-196.566488,-221.523581,-162.478857,-39.243987,-35.309648,-135.731834,-171.382203,-189.116569,-254.333504,-279.028929,-218.118474,-141.341137,-17.09455,-23.699602,-170.614558,-356.429111,-411.912742,-359.281353,-255.533751,-47.878517,-27.22174,-171.002045,-250.089053,-274.297759,-213.156591,-196.515097,-182.282372,-158.135202,-84.564643,-60.584464,-86.386683,-275.248621,-375.078459,-394.565131,-344.482661,-299.807856,-304.113483,-243.329645,-173.991212,-91.36213,-110.484136,-112.730457,-71.017884,-27.956577,55.500085,63.278314,24.368549,-43.793302,-81.642954,-125.031825,-111.534116,52.475349,168.048609,236.334574,169.561303,8.007418,29.179465,117.093086,247.769529,234.175361,156.675921,137.792844,78.362022,-53.630379,-95.58886,-96.197497,-95.137172,-106.248939,-96.085192,-76.682105,-89.855625,-140.217611,-115.921642,-79.977918,-54.634904,-38.859186,53.725265,71.744748,-18.973721,-120.507752,-139.128404,-132.830082,-119.245136,-44.606354,3.732183,6.528381,-63.984534,-235.44626,-196.10421,-111.120004,20.548689,54.52752,96.064876,105.356837,61.929831,-70.046139,-95.142768,-10.506676,35.390208,84.101203,101.745116,51.539076,-16.927736,-104.559269,-44.906593,12.997318,101.307722,131.265802,138.592113,92.31908,-74.035638,-166.633277,-131.536731,1.93957,42.779059,45.297491,33.505465,66.99334,109.908704,108.17616,42.712469,82.099639,267.966584,359.039843,453.884161,436.880556,283.226698,48.372625,-24.190916,47.07162,138.303558,203.8947,171.34699,123.229034,129.68189,108.530725,25.070888,21.079469,81.244803,88.524897,63.112162,68.327098,75.74696,-5.945422,-57.09963,-91.149731,-70.959311,37.910313,122.613286,250.014204,241.138115,76.177819,-11.57598,45.249996,222.716494,279.041128,270.476936,225.871839,157.069171,97.330511,63.800057,56.486077,92.13737,173.329699,186.040125,192.542428,197.364226,78.103047,-147.667546,-175.477144,-62.040333,0.962314,71.40618,85.515343,70.285139,38.74991,47.751195,142.449506,211.503169,267.952014,216.033827,68.088814,35.917206,7.643338,-8.599027,17.937538,140.309277,215.408105,298.576024,290.456682,181.909678,23.980135,18.066479,158.321696,226.434596,304.205404,321.790689,242.937987,147.885166,12.208644,87.404912,167.093563,275.977411,307.73469,343.333707,312.083608,117.068302,-85.256142,-108.973693,-69.343808,-67.609812,-7.924762,77.385004,181.509334,157.995727,11.756302,-84.781235,-47.389554,105.46106,154.011185,168.787062,156.726176,83.393286,-20.333029,0.129497,183.846329,237.891247,208.751273,198.153482,223.343041,224.463583,149.626461,90.265588,107.225716,122.938798,97.300931,53.781111,69.813306,146.762258,113.388309,41.053491,-95.641436,-117.563931,-23.459879,65.721738,172.741751,140.329725,-69.637535,-219.170903,-215.373017,-80.118288,17.631118,105.275955,74.017877,-19.935774,-65.155919,-53.411024,-11.266777,-11.221176,22.348206,79.281739,162.336848,142.755443,-5.993291,-87.063183,-41.026567,91.614591,106.161457,57.295316,51.872128,79.73293,40.962587,4.636908,25.569303,105.892183,293.319582,330.094428,255.724445,175.605459:-178.314205,-232.547943,-244.231503,-163.074768,-110.406692,-51.289357,-53.013191,-101.190531,-149.861304,-160.73057,-84.134746,-17.706034,25.395846,-9.487848,-123.536483,-171.401922,-205.896543,-183.10213,-176.120006,-192.592021,-202.685036,-213.571913,-235.191307,-266.385704,-227.154511,-220.435015,-200.239275,-146.441883,12.087817,68.503266,62.979022,10.616102,-93.717086,-63.416459,-3.499448,83.359988,117.325104,204.426431,203.278135,53.611746,-41.4501,-17.438202,57.79562,79.990859,115.369876,121.794945,41.721863,-21.019936,-66.970547,-100.467153,-142.045544,-162.722927,-138.475882,-144.852159,-179.568364,-238.048048,-288.990053,-318.778026,-305.207702,-268.515199,-262.811477,-289.813116,-327.611278,-334.631252,-323.957625,-292.009265,-260.200618,-147.752048,-90.539519,-23.296239,-16.268125,-38.04422,-117.665153,-169.563727,-209.361422,-187.554061,-92.639154,-59.166648,-97.399665,-115.227076,-46.059462,-49.679261,-104.571238,-185.595921,-173.483719,-46.39988,-0.318521,-90.539053,-304.219824,-380.259792,-386.575879,-323.027476,-172.048193,-143.835084,-193.063485,-206.595508,-172.385368,-199.750786,-216.013562,-105.379717,-3.101546,119.18769,131.304418,125.047759,71.507552,40.163755,49.017315,95.131096,192.958937,220.848061,230.663461,209.419387,100.24194,-32.809212,-41.863851,76.728397,140.644086,124.981001,30.211243,-185.874014,-263.81302,-279.009822,-292.816156,-274.452675,-186.402537,-123.443764,21.2846,83.810731,100.375701,-16.739077,-52.175949,-5.531309,41.514667,53.493797,-4.159741,-134.417559,-206.852006,-249.163109,-205.530651,-91.670261,100.952964,112.424117,41.032544,16.803077,33.488576,67.374945,82.320593,102.423468,111.466676,170.621076,193.59888,133.336118,-63.506201,-175.53615,-270.719332,-253.138555,-206.387,-191.635468,-140.528647,-87.029436,34.753728,63.132449,41.81771,0.780359,18.88993,142.700629,192.375326,157.854283,7.803365,-58.090327,-74.851337,-34.541808,40.74992,68.674745,152.809094,181.632499,100.935882,-3.952124,-2.885337,21.419253,36.994931,133.621681,164.26848,63.897006,-66.728255,-88.412652,-114.804591,-141.422598,-140.873948,-86.758905,-3.244367,-29.279249,-181.030281,-235.224535,-179.75553,-46.688777,-14.478556,15.16403,32.63462,39.172876,-85.845678,-159.685261,-176.500567,-143.070601,-84.599245,-39.581804,23.109577,-19.965335,-188.842688,-238.001068,-200.168356,-130.641517,-135.770478,-153.390556,-128.634109,-45.156506,-41.242261,-52.144512,3.050713,46.638471,44.337136,-15.919489,-171.844665,-209.7619,-148.870921,-48.217085,-34.194992,-29.134413,10.736278,166.291596,219.023883,181.379435,53.993181,8.012096,-6.807717,21.056407,78.805092,90.920565,117.415852,123.42908,68.463942,24.762105,57.777113,134.383123,131.011216,117.022132,112.424351,-2.509188,-153.035558,-169.947354,-98.721413,-54.320685,9.458828,30.712161,-5.393743,-53.735456,-103.264296,-89.461458,-92.646458,-125.486244,-115.231949,4.067779,52.800899,45.578012,20.791982,7.39447,-38.805972,-68.691433,-106.440143,-73.042853,69.584553,106.063861,53.072392,31.041021,94.393238,222.460161,215.015362,131.519056,101.300287,62.258631,24.345607,14.133068,50.691573,87.586319,136.862134,137.878076,83.945836,42.94138,-9.818835,-96.999206,-157.060186,-202.675808,-177.467908,-75.842934,-6.725805,137.348501,153.806551,109.087975,38.783615,53.329551,152.436722,157.252381,-22.85458,-131.566305,-140.999164,8.307756,20.366106,-23.92465,9.119473,163.14497,198.409168,130.951276,11.737933,-28.101028,-4.289289,64.143758,194.365074,196.415738,115.550695,103.713543,158.770539,182.173619,186.551921,229.673846,257.727105,276.409497,240.530389,71.240582,-27.426778,-12.009455,49.033832,75.603947,122.272486,131.369318,87.822876,36.467695,-126.132035,-274.817693,-254.544615,-32.502109,64.846323,71.043472,32.945159,35.157896,58.702226,54.164267,87.073556,117.276624,181.169271,233.179091,292.433877,262.970859,206.255634,224.842585,206.924257,79.059849,22.375313,20.362177,47.983946,92.288713,88.604686,58.819237,2.507821,4.690274,56.005254,90.569761,143.370093,138.248491,65.652314,-15.122734,-22.227696,93.083932,174.963207,226.953522,205.976811,198.322848,214.853551,191.310318,96.681869,50.104273,30.683908,72.313269,162.646978,160.205142,32.078869,-117.193336,-135.735358,-84.969229,-34.894226,73.063411,100.930275,112.956687,70.694417,29.062006,43.143424,101.351557,167.05065,147.099248,48.053328,3.659311:-240.324266,-327.987103,-326.007324,-200.658354,-101.14652,30.756529,23.453529,-69.898416,-146.496386,-156.431378,-61.377226,29.71753,149.986684,127.058831,-32.815868,-90.324851,-105.25423,-88.227999,-84.839732,-81.149296,-70.979826,-77.663583,-118.336771,-212.464011,-258.925569,-270.165215,-226.658733,-160.508189,-6.469326,41.910626,32.366099,-28.632151,-215.78185,-310.130036,-274.152129,-87.289593,6.468796,74.465761,39.313211,-86.395087,-159.023916,-145.633891,-12.549124,71.491296,159.944867,146.95088,2.939206,-108.11682,-313.492418,-400.11233,-376.224447,-243.927214,-171.470675,-77.343255,-87.971565,-227.583089,-380.427132,-429.566019,-404.123136,-322.930383,-161.352669,-130.949033,-160.291841,-197.112991,-268.671925,-272.927573,-216.639904,-20.505149,52.799224,45.848729,-16.665779,-103.821696,-102.140644,-127.495018,-190.947561,-166.665885,-12.753502,29.873338,-95.157515,-188.519214,-225.842896,-194.658281,-194.719828,-143.675437,-80.352385,18.12984,8.082606,-120.74,-292.344081,-351.773958,-355.598338,-305.518857,-168.001203,-128.866561,-180.179825,-224.051041,-250.849803,-233.913234,-191.744588,-16.210394,87.784192,203.017871,190.817082,137.753422,80.781637,28.18167,-22.035288,26.486432,210.095487,270.592268,250.528329,200.895781,70.389597,-62.968559,-80.049811,4.163449,64.139743,131.972174,112.78069,-33.933812,-221.539428,-295.456724,-348.084283,-318.019789,-135.401102,-37.112892,-1.440121,-35.682848,-89.14298,-114.994541,-119.497055,-109.060494,-77.865025,4.096953,-3.614246,-173.113447,-366.916886,-395.396063,-273.187389,-143.326776,87.01293,110.636081,1.496072,-48.942171,-59.46131,-50.990207,-49.108994,-19.718799,22.856557,129.828806,133.272669,-31.853761,-253.607279,-310.6683,-302.04656,-257.045237,-135.015859,-82.628527,-64.706284,-96.066693,-152.223537,-116.179714,-68.059213,17.010638,53.470767,128.048434,137.348512,81.302256,-50.984423,-126.230633,-147.892638,-70.599326,104.618925,137.26469,112.079057,80.751211,2.470047,-61.678135,-58.148464,72.551327,156.633252,213.25154,176.2133,28.207993,-118.428924,-179.011251,-239.935595,-207.834847,-68.349061,-23.540842,-45.59254,-84.520225,-114.670502,-76.537978,-59.061491,-43.697878,-36.454733,14.43893,32.270921,-40.406108,-211.186554,-267.936044,-216.145494,-144.165486,-38.647801,-9.328239,-15.726778,-70.235206,-196.611078,-182.878853,-142.10405,-62.367068,-5.506031,121.150497,138.138018,35.992795,-111.657743,-123.30777,11.671588,90.891701,146.523866,127.36826,23.052757,-31.608186,-73.911731,-88.78273,-86.100487,13.516325,114.846937,277.56442,257.243826,29.303556,-128.947853,-121.783642,-50.003312,-17.92246,38.993486,58.969819,91.835342,114.067884,154.76799,175.261298,174.089443,174.74582,208.554044,309.240294,311.249597,156.426193,-37.928842,-76.751746,-22.216396,25.562555,100.588179,134.007425,131.709815,81.33038,-47.755081,-145.963478,-168.214422,-116.243548,-42.071887,73.849161,59.829419,-33.313253,-68.440634,-86.481781,-111.044705,-83.709173,39.568734,86.745061,85.790703,68.334375,50.968379,54.181519,82.996616,173.035449,202.406531,216.488538,206.259366,138.967089,34.118138,-7.577456,-12.056553,41.51786,200.978117,230.018854,116.533213,43.116642,-47.831949,-163.215279,-210.026133,-198.176762,-135.017671,51.573793,121.959178,137.209458,59.354796,40.130063,88.19104,133.607935,187.709375,172.549714,101.880725,72.30127,-33.903856,-141.761673,-114.890797,83.674231,201.737627,354.326755,343.422296,140.939897,-80.639585,-97.023553,73.505528,181.457199,277.489816,258.938031,155.171914,97.192791,24.614238,61.013751,102.149307,181.452646,229.558122,306.784656,286.396057,140.251437,10.234309,-41.320797,-94.157582,-64.386694,106.137414,186.143501,174.953659,93.836965,-81.943668,-169.299399,-149.633619,13.590872,108.316965,196.803463,189.369058,156.456361,90.229357,47.858297,66.304056,123.164675,244.617627,285.849585,269.205026,229.474258,167.682822,135.357055,147.171477,182.784292,169.037583,105.779457,95.612872,142.997479,142.42973,97.084779,36.011837,55.04132,139.29932,168.218297,144.34652,92.395558,-41.0598,-144.444218,-158.489369,-48.984228,59.749082,187.377225,154.380083,23.520404,-24.547382,-28.183197,-24.047295,-18.814796,9.965002,49.939967,165.531601,184.513999,41.754264,-103.31005,-77.696986,59.261426,111.712358,163.391832,172.635975,162.168115,57.150214,-16.20603,-15.140409,85.896935,274.928119,271.923338,137.877284,75.466092:-231.657673,-366.746915,-410.528032,-315.362049,-220.308291,-124.575482,-146.792638,-207.366183,-219.010575,-228.451493,-184.778254,-131.46891,-111.595131,-146.450058,-182.509759,-175.217318,-145.419892,-98.795811,-94.595486,-177.583105,-230.428312,-246.231996,-234.351484,-268.358989,-296.433134,-271.480106,-161.508272,-110.183004,-78.785033,-82.823102,-72.108709,-51.077591,-28.79263,-73.661477,-73.611678,21.43891,92.241745,205.026776,211.620872,176.222536,202.38422,198.35038,138.683425,131.547642,186.521325,207.4683,136.604202,76.284055,28.950018,-45.534603,-117.576516,-213.282452,-210.002488,-128.276904,-88.063361,-99.960095,-223.145548,-264.128684,-221.580546,-173.724548,-136.600475,-152.775007,-185.494439,-162.668701,-68.602383,-56.099862,-93.560303,-218.201177,-270.735663,-302.534756,-285.834192,-171.851844,-36.183719,-39.911502,-160.364178,-182.031252,-39.846076,53.192724,79.272528,37.905159,7.791352,18.595784,11.526876,-22.801937,-33.429518,10.665266,31.558903,-15.268752,-128.14711,-180.729895,-214.192676,-208.459909,-213.47224,-205.446172,-82.458179,19.889357,123.276722,52.492207,33.726155,77.795687,120.580587,208.047174,232.964299,250.431616,268.850884,266.171163,194.911366,148.139567,122.759018,135.812309,111.985687,59.543005,-63.062396,-107.68581,-69.416151,57.821504,79.700557,-2.116988,-81.872589,-241.52022,-309.864965,-319.715788,-342.249224,-340.526952,-261.3526,-184.248115,11.682403,98.106655,166.050584,188.849635,230.676221,255.796887,209.917675,185.887815,241.408564,274.981947,74.17383,-32.288767,-50.31664,54.459884,320.165996,385.131381,318.935084,260.858507,249.399148,268.672737,247.740831,199.059723,208.751321,297.777671,319.287139,250.291077,135.521799,86.679144,45.150462,53.785477,72.636114,81.030033,130.971775,151.675871,143.739639,117.763719,113.383101,136.716361,166.829563,276.130131,332.344392,343.384426,251.203972,226.234984,220.122283,203.828344,159.555344,164.726015,243.27454,273.816467,214.848432,59.460921,9.926606,11.155285,43.911211,127.644578,140.582385,74.920115,-18.567891,-69.670371,-159.988138,-173.926074,-103.239265,-22.649149,90.246547,65.658006,-52.639272,-9.065378,62.334336,148.453356,150.610552,159.302658,184.494518,226.535969,173.05408,107.38853,19.622607,22.396721,50.335069,56.450964,19.313902,-44.41184,-191.33259,-229.027253,-212.748291,-173.873687,-167.202341,-151.482284,-146.6396,-176.177396,-192.34086,-190.391975,-196.19314,-199.786487,-209.020325,-206.218931,-185.81892,-174.259073,-112.070512,-21.383146,10.487915,63.840179,111.447819,243.274103,286.208227,297.952174,243.131101,202.663465,147.384837,133.938226,137.308706,153.200341,192.909515,212.143746,179.188272,3.759266,-85.698713,-186.91815,-192.873148,-125.692174,-107.831566,-204.003138,-313.374134,-328.559382,-301.287157,-260.95747,-160.985483,-138.26739,-193.746574,-238.11583,-271.378072,-308.312151,-331.610592,-290.008553,-222.939061,-50.574873,20.323236,39.749286,-36.48507,-59.887844,-46.371056,-49.572163,-156.585532,-203.507955,-150.682916,-95.590081,-88.088874,-175.354951,-165.583577,26.414751,116.663191,68.609164,-29.324932,-96.784342,-10.668407,-17.951311,-65.54521,-43.641436,8.882905,-3.364715,-51.170175,-61.655083,-126.978406,-267.138178,-306.881459,-261.202199,-200.895414,-108.553669,-79.826197,-47.46413,-148.03245,-216.567437,-188.351892,-99.282568,37.473166,37.198973,-88.383994,-167.045267,-226.490022,-188.774852,-188.288373,-213.469068,-199.081492,-109.090192,-72.865782,-53.830174,-58.967985,-53.198298,-3.639836,15.193107,31.035808,69.975027,180.199123,197.51037,162.035003,186.96083,235.003686,266.764229,226.113696,137.245506,110.958715,30.892874,-63.508572,-59.548995,45.096763,89.46083,115.778229,123.518854,83.362753,6.482326,-147.339629,-160.138057,-137.16841,-108.326762,-96.298206,-55.06049,-30.963683,12.746944,16.938072,-2.131172,-14.810546,-5.765491,-2.200048,2.033455,37.245292,62.865854,90.850195,26.36965,-21.883296,-87.437831,-97.586482,-55.953228,-35.011635,-59.068964,-87.935415,-84.421875,-71.804652,-64.902593,1.973799,60.102298,133.775898,130.573621,84.298536,66.240134,87.067956,187.266299,245.087547,297.634999,285.220563,265.512872,280.053473,271.017675,234.963033,221.919969,190.068618,179.106122,187.695637,178.384264,60.117104,-35.081149,-4.451894,87.845805,110.09901,158.48573,176.614686,190.464103,205.602041,188.599057,163.118186,197.94529,272.855722,260.481763,154.355809,89.068084:-250.056405,-167.705494,-133.267539,-88.601254,-72.761372,-60.338606,-72.229968,-138.569308,-197.483376,-207.439806,-210.84957,-202.547605,-149.503184,-124.591968,-144.579987,-175.865923,-189.927588,-189.628722,-207.081088,-242.454781,-260.818175,-265.228245,-245.585187,-215.516044,-235.622222,-252.917351,-221.635547,-166.540066,-51.046475,-14.769769,0.412402,-9.99869,-40.544607,-88.239476,-85.5961,18.260184,91.606446,210.169949,237.02523,201.279863,108.439881,70.553204,64.419507,110.467813,224.487037,237.116191,120.7103,39.007028,-13.17497,-36.962606,-74.951927,-94.734747,-65.155898,-26.103241,-52.183548,-145.550037,-192.744341,-203.085856,-180.671896,-165.778483,-182.52269,-187.107093,-176.295204,-177.019702,-165.457775,-187.735414,-215.219454,-182.948905,-118.570933,-17.483807,-5.057651,-21.721288,-67.300724,-90.506404,-145.943838,-176.812243,-129.345264,-33.581901,132.232174,153.782802,113.165948,-26.16511,-99.462671,-123.789743,-74.028183,35.09939,51.011231,35.391946,0.906305,-55.816575,-218.263398,-272.749888,-279.011175,-253.533938,-178.039961,-114.719166,-15.152423,-118.770707,-163.264887,13.172822,159.2361,230.961004,157.802417,53.075644,147.171511,188.721012,114.15797,44.041391,12.577398,48.134565,93.01726,96.45752,86.454994,42.177456,47.305807,136.419366,167.584984,101.99147,24.598715,-88.469688,-117.697496,-124.179062,-102.463817,-78.688106,13.33575,103.139463,289.907829,337.989724,290.791023,146.590341,123.428561,133.077511,103.348055,39.626517,32.734157,0.158312,-46.40517,-62.132482,-41.637822,13.938199,178.984319,234.758701,196.061786,140.849898,118.200788,169.535025,182.086447,190.26235,221.011785,363.108975,417.289254,398.440418,242.7728,136.803889,-35.011322,-88.820409,-139.451721,-118.420614,-3.004799,47.331943,78.41289,116.314262,149.227451,161.948392,157.530792,223.439788,280.612308,308.865306,152.082288,64.254999,20.72176,36.070428,37.954901,64.156142,192.896621,226.177843,149.225764,0.180022,-50.061825,-44.020752,-5.922612,73.182709,104.798241,115.309207,28.096349,-35.717135,-151.991834,-192.39265,-200.829985,-169.243123,-111.146927,-110.741882,-143.065212,-170.306745,-176.087871,-98.933754,-11.771182,136.013212,170.460029,209.88507,169.618797,96.486367,-67.669618,-97.953578,21.634042,121.67209,145.254501,41.342214,-220.972034,-359.806287,-349.88541,-254.541769,-232.840707,-221.169005,-196.427787,-162.713372,-203.710757,-214.904204,-191.831279,-187.725231,-201.454666,-208.010919,-245.676526,-263.791117,-241.958627,-194.77451,-170.370352,-107.262991,-62.792978,53.210298,106.836155,185.21029,142.488317,52.496855,-81.782393,-54.412423,88.219951,131.441162,157.849591,161.753659,106.505309,24.533921,39.962408,83.494118,44.190027,-83.455045,-113.676427,-105.396135,-134.235491,-173.370523,-191.893932,-146.394638,-26.56661,-8.347441,-67.915445,-78.55814,-27.85535,-73.888278,-102.131475,-52.147502,-7.971359,30.449337,28.145369,78.393788,171.956258,147.475696,-37.823198,-135.564108,-213.635676,-165.426652,2.814863,40.327159,-0.696134,-46.605917,-31.760035,85.387739,159.989798,242.079985,206.580599,24.066972,-25.46602,37.357772,204.541711,244.215926,228.096897,226.624242,233.531585,201.866147,83.175565,-59.462093,-117.747245,-135.646898,-106.019303,-47.671354,-28.837702,13.212964,39.06913,27.422138,15.454741,37.390148,81.280117,60.107459,-112.384249,-208.924532,-220.848619,-109.626053,-115.369359,-213.258094,-218.797106,-118.338054,-91.936484,-114.340837,-89.855368,-89.702499,-125.307553,-110.829626,3.743591,76.377348,188.971513,210.018696,182.946014,169.131964,186.354043,175.798463,151.493955,139.493568,114.446834,5.375125,60.682988,136.660935,182.322616,153.017711,73.475047,28.927176,-43.646488,-67.577272,-141.66704,-224.266348,-232.214668,-186.710907,-144.221314,-76.778069,-74.424365,-65.937875,-14.007785,-7.147457,-37.210594,-55.512302,-19.386851,41.969677,133.539891,133.880761,98.935787,54.953934,7.977022,-137.070978,-193.726766,-188.557254,-155.333514,-95.726918,-57.773358,-62.847184,-66.741631,-32.108845,71.838049,103.41599,88.716886,51.550839,-14.524137,2.108346,37.48367,152.14232,224.859603,319.189704,325.408157,312.790006,276.528979,235.685068,168.635532,155.240701,131.570863,114.492008,117.136853,137.93094,98.660837,-9.697108,-17.225248,43.187315,87.959439,175.870735,189.107691,129.774093,6.709474,-36.859111,-6.361872,42.510106,108.540346,130.865771,133.931424,84.781102:-261.775536,-364.428125,-366.528428,-241.147277,-175.001396,-128.972094,-139.741549,-182.671361,-156.920374,-110.445314,-19.075365,8.031541,30.690763,15.683912,-69.713012,-105.009292,-92.969634,-71.827129,-94.739822,-171.268163,-208.166098,-225.622841,-224.877537,-284.332266,-317.59323,-290.087574,-162.075717,-91.88943,-60.781358,-97.31919,-134.975516,-114.874314,-62.820347,-91.331727,-108.656413,-9.386705,84.758526,183.770329,163.091171,83.066274,52.268893,48.354959,81.358946,117.670218,166.04066,164.031609,98.795639,40.375918,-102.186588,-228.230382,-250.400118,-224.726196,-188.024845,-74.044533,-48.561644,-117.99699,-198.109645,-221.1653,-231.038955,-217.205062,-168.337627,-133.287201,-81.177567,-75.310807,-69.196361,-86.031332,-109.061575,-114.90477,-80.687748,-50.709763,-82.274716,-61.690305,48.223381,21.674138,-121.832239,-147.822118,-93.925597,-58.538584,-17.802649,-10.888629,-10.203602,-4.294959,-2.24189,13.114629,41.520546,93.606106,81.882968,-0.884756,-82.944516,-125.892029,-189.46297,-192.837475,-163.087231,-132.858274,-30.591663,16.993366,8.440902,-89.63364,-112.460504,11.444695,144.861605,310.590631,274.60099,139.752069,165.820475,198.792551,210.667832,192.186638,167.754812,195.704402,274.938999,259.332997,90.72146,-50.484574,-51.216182,-15.340811,-30.240203,-56.784741,-39.394096,-24.45065,-183.946316,-313.710381,-429.564667,-370.783114,-181.086033,-129.801839,-90.580461,-36.422385,82.573155,5.823188,-47.443026,-30.73624,19.461946,111.247846,120.388665,63.595378,-16.682273,-51.927198,-51.237846,16.539517,225.223097,290.419903,254.972332,199.68754,143.596401,150.983105,155.913816,178.017295,204.912769,261.19649,266.045997,188.761196,26.223409,-60.596016,-147.085501,-117.984113,13.209504,60.793383,77.953522,70.459934,41.518972,-9.692252,-13.766766,52.998045,124.466025,281.540703,312.536049,262.052589,147.405571,77.332616,-7.842618,15.870245,150.570749,214.545592,243.738387,214.240041,152.513535,88.927776,66.249602,90.933702,127.814413,149.201144,105.596528,14.927666,-35.02152,-95.359936,-171.693979,-134.655295,-9.070852,23.747717,-6.656075,-41.71571,-51.530855,-24.824142,-34.094448,-26.116614,17.526833,100.009247,103.416324,61.3064,-22.433184,-67.375188,-104.198109,-95.122272,-55.416229,-48.183558,-105.558549,-137.403522,-109.93727,-133.11342,-188.279942,-158.392132,-57.482997,70.209579,35.017731,-101.985862,-139.32548,-134.464703,-110.915894,-94.8093,-97.517542,-105.610649,-66.213912,-33.713099,-39.808668,-99.379306,-69.497351,84.422214,147.279721,240.114326,279.214124,262.67756,128.913239,83.213582,118.263668,172.116109,223.828245,222.359955,255.233923,273.956985,224.582657,102.289211,62.51913,59.148273,75.650304,108.454124,114.419379,53.81575,-44.120852,-64.840578,-73.74163,-73.778986,-40.153559,-30.486236,-110.40719,-160.680395,-212.896662,-315.190686,-352.613518,-264.956004,-173.179036,-93.581779,-114.347499,-92.398043,39.021068,61.18383,-40.978992,-121.475995,-181.341048,-138.013745,-22.552998,-0.879072,-36.411448,-50.250458,6.630372,151.885336,169.773088,113.588826,83.799485,84.891247,130.916316,129.888928,98.921271,92.607302,78.288533,60.806472,3.937442,-23.553299,-84.678662,-254.084647,-335.690301,-299.342477,-185.456326,8.310062,26.746616,-16.098145,-84.596575,-120.520953,-128.397413,-85.427232,42.447689,86.846427,76.249,23.430517,-105.223686,-159.689309,-147.755397,-101.405932,-88.328989,-15.062104,48.126598,70.805799,-78.896587,-142.933297,-112.794201,-34.551944,47.784852,0.134337,-107.630468,-74.295327,62.69286,19.176882,-10.382743,53.028097,87.762855,77.354253,70.976746,58.446871,-29.549044,-56.129322,-14.39288,15.655424,24.01037,26.623351,25.733694,-10.078124,-119.96156,-129.653345,-87.645189,-10.325426,8.030212,17.494958,3.839453,-58.018027,-111.850884,-107.474316,9.868991,86.493348,131.708831,118.334896,110.113208,110.580348,117.372639,127.063775,121.921173,106.734804,116.117044,161.686707,176.044796,187.31885,134.72358,66.908577,-32.537279,-35.603544,39.990844,105.666168,211.872672,215.798918,107.248511,12.750433,32.747757,178.101201,249.253647,256.785653,210.084112,191.560884,216.678109,177.857664,98.244788,113.640368,216.557977,259.850074,243.74109,177.428335,45.535734,51.775981,87.078095,118.841919,124.932022,176.731555,201.329504,195.691857,123.753938,87.153666,130.904174,208.591916,338.928956,340.237678,199.217143,105.332719:forward
172.615798,35.757093,-33.720595,-137.496298,-159.970484,-117.577591,-83.562953,-69.140571,-118.065655,-152.699032,-155.066386,-111.386208,-9.425646,3.06862,-135.006549,-251.307387,-394.033397,-396.626316,-373.487516,-302.609434,-281.502565,-316.479901,-355.598051,-377.617123,-289.705374,-250.404745,-237.797563,-244.350143,-171.401245,-63.579851,131.974142,135.59893,26.775313,-8.847658,20.378148,95.000817,120.340611,185.55602,216.90331,176.690606,20.236351,-63.381817,-142.074692,-131.771193,-89.2256,-65.944913,-43.932484,-65.390327,-161.226621,-238.720415,-236.245315,-155.470483,-106.61891,-46.563023,-34.290948,-10.123644,5.54097,-21.386394,-122.031447,-137.277028,-64.947371,-27.634811,-31.842688,-68.085725,-188.927376,-347.528566,-377.823336,-253.106804,-135.714615,66.06901,101.981631,25.166023,-105.654901,-145.150914,-143.587199,-116.177998,-50.204203,-21.245897,-38.418369,-100.503224,-243.783531,-303.671787,-278.40983,-118.340914,-28.883807,49.356893,33.835917,-37.672481,-134.560742,-181.470447,-204.463367,-163.226404,38.593449,161.933493,253.369469,202.116773,87.920529,106.783822,148.766957,215.054003,206.932442,125.708956,71.369893,-55.194931,-134.777639,-144.693406,-100.1852,-42.012885,45.90354,35.997147,-31.708901,-47.646342,-43.07539,-76.802632,-106.005857,-117.525351,-83.927282,46.305569,91.329071,42.637312,-70.568973,-107.600537,-98.695066,-42.060621,128.577318,226.541322,397.012382,433.611707,423.939753,349.148491,292.708516,242.940168,252.32799,208.84692,149.846479,93.919047,73.626533,21.75599,-45.394038,1.954163,168.39957,216.990207,255.89104,264.381405,201.108116,117.863939,116.59297,92.716041,46.95144,20.907602,67.42424,122.563671,2.190084,-74.446064,-166.363919,-180.281132,-166.991508,-150.598627,-118.473063,-94.123485,-53.100312,-158.344883,-225.678377,-237.515833,-201.141991,-108.065865,-53.945546,22.291953,-71.867191,-181.083506,-334.896983,-337.044227,-258.659424,-205.470051,-147.586206,-180.269929,-298.985252,-313.526646,-281.11237,-214.823736,-214.682199,-265.729978,-275.852022,-260.742398,-323.049452,-369.599988,-344.239165,-277.231698,-168.949012,-124.99017,-13.337171,6.556785,-67.286738,-121.957511,-99.874687,42.534173,121.750622,177.384524,156.610882,137.0764,174.694562,151.470427,46.755038,27.633155,60.64507,93.92435,147.748588,132.772091,-2.260021,-178.376497,-232.083418,-211.853208,-149.816965,-27.486731,-0.562822,-19.690411,-161.748453,-268.109752,-384.637624,-373.317996,-284.291669,-207.182007,-46.103729,-19.272561,-93.766106,-196.796957,-248.252494,-361.02013,-359.9334,-160.378602,-40.078591,31.346693,-54.050765,-99.536191,-178.358545,-212.859419,-248.406039,-242.298076,-253.397984,-273.654991,-271.409476,-322.046639,-360.207147,-308.832004,-223.113878,-2.007815,102.852366,227.010299,207.427658,143.089499,-6.074571,-42.86527,-27.288971,4.103806,10.798562,-31.168666,-106.476467,-121.385904,-133.615629,-179.22431,-178.770802,-96.344579,-48.493374,0.637408,-19.712135,-64.926012,-138.693656,-121.564126,-31.767352,-3.267331,19.925776,25.578262,7.726849,-19.761768,-22.180236,-0.060167,30.960281,84.753579,74.122445,22.490766,40.873812,35.069639,-38.096188,-32.735098,122.981808,223.948199,357.138516,384.27585,390.662716,285.019608,224.888364,258.43456,339.365004,440.956543,416.299491,256.52153,100.164495,64.183735,24.480627,-27.955615,-124.179255,-103.061421,10.835712,49.908025,22.927496,-131.706498,-164.050425,-91.9394,-69.106702,-108.741228,-124.366384,-94.182807,-45.515114,-54.078432,-89.756611,-80.725586,-24.89582,-0.87464,12.20636,19.081716,86.276222,152.848907,152.422055,104.936553,98.025253,179.887845,227.232289,200.673195,104.311305,80.121856,38.243178,-9.877857,-155.763004,-203.241187,-179.084566,-144.804134,-99.145272,-24.898852,37.400368,93.236509,62.069187,34.153138,73.141134,139.82641,150.91598,155.62325,167.697963,198.230105,296.837055,310.949559,232.741982,189.778473,135.563637,33.744529,4.830998,47.983066,70.869609,99.967487,118.802199,120.173676,102.08973,104.508241,144.179133,181.828789,263.583532,295.422823,300.572767,257.705124,116.004064,50.865697,81.552091,197.292071,236.940337,248.627426,224.875444,109.704314,-56.215799,-112.768719,-113.19461,-71.409442,59.530356,132.557257,207.606448,194.736158,71.195765,-91.423859,-75.13112,164.306986,268.225744,318.325577,306.437842,274.927397,212.256827,183.789399,213.105555,272.206428,390.200429,412.354026,382.811094,355.437714:136.599996,-28.480446,-44.751425,11.114352,16.988623,-6.628068,-0.258109,8.536853,-40.959446,-78.484966,-104.753145,-52.624512,112.137349,117.932512,-100.360911,-223.765919,-311.791254,-262.53853,-214.229507,-133.102311,-126.687847,-148.488564,-168.820256,-266.966187,-326.520651,-308.638135,-288.582136,-315.865792,-322.367344,-250.872812,-91.725029,-74.832389,-122.861777,-98.789734,-40.515235,62.694337,91.406999,143.83894,145.596862,46.032652,-67.326474,-94.070149,-82.201072,-61.153095,-57.304198,-60.944262,-38.701026,-33.285342,-86.387465,-183.331503,-206.11162,-181.610919,-154.219634,-69.89545,-4.280809,89.594507,-9.957244,-113.674114,-227.565424,-184.592493,-32.815318,-0.274237,-13.423038,-41.552287,-188.49168,-350.745492,-348.541006,-189.049493,-94.617494,67.988763,122.902545,84.813254,-97.215549,-152.60853,-110.439887,-49.925922,62.175404,72.130246,-56.62768,-134.837704,-196.123869,-237.5239,-250.698994,-155.056463,-55.196701,78.423665,74.706119,-19.382171,-133.406661,-155.230127,-136.753494,-110.109908,51.047491,170.834244,267.074119,211.395327,50.409061,31.443779,80.783669,199.609357,232.840298,172.191097,80.831337,-90.263582,-123.23309,-104.567521,23.191045,129.271871,290.359133,292.002158,177.621796,136.688758,127.58199,41.233725,-15.591183,9.631724,83.642372,162.740689,132.372536,31.55815,-47.096632,-49.271205,74.146139,157.441284,281.01007,326.665544,383.819053,381.67929,271.410045,88.76744,49.160021,82.468786,111.438986,142.096681,120.59602,-16.45008,-175.772449,-239.220559,-271.690887,-224.130332,-95.612666,-44.551367,7.032337,-15.997574,-121.119746,-174.895448,-199.912511,-259.659381,-250.527207,-150.327009,-115.643472,-131.160872,-195.046894,-247.849481,-403.884159,-456.501039,-326.023616,-175.531577,-26.904118,-68.501192,-185.810342,-227.578766,-224.201338,-167.267077,-127.754603,-64.36563,-50.28542,-70.599449,-123.164756,-152.197267,-207.982704,-215.760804,-164.136074,-120.063123,-57.887996,-74.013253,-246.023252,-379.421669,-337.532947,-143.22609,-84.4511,-139.072724,-198.96722,-213.984274,-220.135958,-270.589635,-315.235367,-279.842921,-186.433546,-134.803848,-11.171304,-5.503838,-159.394216,-242.361349,-204.699235,-68.370148,-10.846237,40.535392,44.441194,69.079118,97.488059,85.175297,-5.574769,-69.760357,-116.04672,-82.451952,-45.845159,-83.520032,-227.530393,-348.37131,-368.877722,-300.440106,-219.398411,-72.740519,-40.458946,-38.046186,-135.984496,-208.698947,-274.58656,-272.725642,-261.977233,-231.993876,-105.152259,-63.65736,-135.829943,-248.977357,-247.983699,-178.341653,-117.727233,43.955174,83.578899,40.38748,-16.323872,-57.951737,-152.706217,-174.137735,-208.275986,-239.435558,-275.443588,-271.552832,-322.515814,-414.625714,-368.336308,-156.654681,-96.549472,-20.58712,52.009989,174.263421,182.217093,158.043006,61.684216,6.801762,-42.724801,-12.234253,63.588072,33.590666,-121.13404,-200.394879,-198.286973,-129.990398,-54.852121,90.174994,85.529268,-12.694721,-22.594524,-34.026225,-76.482551,-59.11458,38.488361,72.62077,99.39788,112.520891,100.305057,39.247249,30.80946,114.231423,209.172307,387.673264,396.646784,284.001021,215.550545,182.529869,68.489269,55.027212,225.678794,347.859657,457.060773,447.295549,401.257652,327.402982,302.637728,316.1946,354.122785,441.012634,434.566491,276.897258,77.300217,21.596464,24.422063,48.067851,92.316492,120.781172,152.930329,150.142888,81.755817,-97.300482,-135.921729,-49.739328,-4.559943,45.318221,80.452083,133.419682,66.025197,-3.328509,-55.933826,-15.87212,80.699624,99.24482,79.07888,63.407455,56.815565,80.055036,87.661175,62.750192,61.968129,134.803725,162.125324,127.851925,98.538047,105.851771,91.206882,47.579326,-49.769462,-63.912403,-15.45689,29.280409,95.14416,135.148644,184.7739,307.533578,331.741803,299.374269,271.70201,203.419991,158.79692,169.843113,226.526741,266.253203,351.000775,336.759613,186.616049,138.8137,112.258611,13.448031,-7.286284,88.809232,151.104584,214.242402,196.213639,70.335969,16.374187,65.51744,218.881872,245.294875,213.556562,221.994342,260.059643,236.932536,122.806359,65.388919,100.98086,253.941585,312.24086,310.681954,261.997667,126.623512,-1.411977,-20.337869,38.126122,62.357195,94.860863,132.617785,163.940101,115.906281,-40.491241,-92.861243,-36.327735,156.296621,232.815884,308.988343,315.778274,282.457508,184.36757,115.918326,77.625268,144.07411,334.413141,390.165282,343.29723,258.952308:129.764276,-0.726284,-17.422307,24.233782,40.958811,32.28545,15.754503,-86.023515,-244.607999,-263.577921,-128.330842,-24.170223,68.580383,10.986601,-182.494657,-229.17615,-216.264994,-194.985411,-184.835413,-165.568243,-166.621299,-192.24108,-205.116784,-226.249782,-272.322346,-296.0318,-338.107873,-359.214543,-337.309077,-277.579835,-155.6772,-129.768621,-167.114091,-166.556263,-107.209754,29.753266,81.079931,110.527126,75.829226,-31.20759,-64.191557,-63.560899,-88.621314,-103.149313,-89.80242,-52.154301,34.820486,57.267654,35.001995,-100.628128,-181.600126,-214.009472,-148.61144,19.467913,68.182248,65.198901,16.80517,-6.407045,-46.47987,-50.084484,-7.930749,22.168636,7.47494,-39.855485,-139.582766,-208.559702,-221.091115,-182.069207,-127.307837,19.091401,69.161231,11.39453,-177.834023,-217.350769,-136.439486,-88.277404,-41.275353,-20.884736,-46.766939,-111.514868,-267.996569,-332.831556,-305.365027,-155.703579,-72.534236,-2.20236,-20.101434,-71.042467,-112.162243,-134.911985,-140.552728,-111.283995,26.344091,106.783572,131.412366,61.650482,-67.666005,-9.026247,46.977483,116.71597,144.99727,145.609095,76.362762,-100.450283,-65.179438,8.007074,137.166346,199.910782,311.292433,315.660382,206.524386,152.413561,104.11845,65.225985,46.755878,68.019378,120.677723,157.625136,85.823894,-98.600014,-121.125115,-56.887421,139.602437,208.940293,226.228656,210.364319,234.799556,273.347065,266.399293,58.771701,-33.747198,-19.506128,45.5691,98.855862,49.879099,-139.090957,-281.09531,-328.129421,-375.682461,-362.597737,-268.855324,-210.748432,-159.434915,-187.746909,-304.131694,-373.961218,-388.293115,-419.602263,-422.109259,-358.950255,-332.895279,-368.400006,-417.771806,-425.001836,-424.793624,-412.249868,-325.737155,-254.932035,-136.743001,-112.571294,-128.406786,-194.183375,-222.492945,-226.524382,-185.798629,-24.704344,38.283846,-13.454176,-195.141537,-242.715133,-183.482428,-118.947166,-12.553924,22.625217,20.068154,-13.824851,-92.115407,-120.948375,-101.200329,-37.152487,-24.244672,-74.606012,-114.833207,-135.122355,-135.305718,-180.603332,-272.739115,-264.357356,-200.835749,-190.84764,-157.606351,-115.540493,-121.4723,-216.22119,-199.507161,-65.862821,-7.504225,56.403743,66.724944,47.323461,-29.611045,-66.491198,-69.537488,-59.772155,-97.676308,-132.292122,-173.322341,-188.908207,-280.878447,-366.044921,-345.499114,-210.792236,-139.591729,-79.131617,-89.47346,-89.338986,-112.503724,-170.641746,-237.093059,-227.334549,-248.498077,-258.805661,-150.026415,-88.250708,-135.160405,-199.539306,-155.837734,-17.565843,35.928642,88.347011,84.409915,62.933336,1.60248,-65.336117,-130.164472,-79.380971,54.045429,47.002052,-116.851756,-201.637598,-270.354997,-263.015245,-258.970246,-212.535269,-141.047285,28.863182,49.620334,-36.075304,-7.43237,46.961098,32.864538,-20.560562,-41.761012,3.043714,47.601667,-2.572844,-161.597639,-199.510766,-169.692512,-99.22601,-49.916034,80.074135,102.400894,44.096012,3.673132,12.365906,114.63781,183.82664,222.458028,182.403808,119.29189,138.688764,174.545278,92.828969,74.314313,207.047921,315.515506,407.878659,363.83562,217.244525,133.070449,112.11244,116.593056,140.490446,192.018272,228.960227,342.434665,381.920998,335.227573,196.383825,160.797933,185.161822,232.762696,338.065304,332.249454,161.392805,-5.99992,-28.345236,-4.015632,11.158955,56.034267,91.286711,98.673532,34.724724,-169.01289,-233.997545,-163.627697,37.887624,86.35674,76.223125,59.601792,14.754102,-58.468452,-69.700299,-8.441784,22.676823,23.742032,21.392881,55.960611,84.060896,147.86365,173.378485,185.30233,229.342374,237.683079,245.822932,255.729142,231.565189,209.804787,229.09978,283.41966,293.34852,235.288106,187.161917,144.545203,140.070669,122.18574,177.963516,244.678602,357.76592,374.749507,330.997008,288.089841,203.161327,155.595578,163.543958,271.863692,350.798816,415.752761,371.203422,216.180403,155.779564,97.120072,80.290016,75.892223,95.693817,129.057769,194.852909,177.383524,54.311778,10.428691,33.410219,130.003287,170.819132,183.962637,182.643804,191.829655,186.224051,142.417248,100.024816,127.287653,274.12934,331.851308,325.496589,280.981631,175.158302,39.146359,-5.740058,38.802492,75.053847,105.568871,135.607649,199.859414,189.762338,46.070395,-80.132869,-39.763027,166.511681,216.489612,163.766801,147.331067,192.697151,143.020366,77.621632,40.594672,80.972433,174.045276,204.094643,208.016023,169.664419:110.02129,-57.927679,-109.657501,-86.89894,-56.294181,-52.658056,-73.956295,-139.895422,-249.954235,-319.580473,-381.496332,-328.874084,-103.757933,-25.61106,-127.055388,-258.623874,-414.291832,-402.835804,-387.875974,-355.43702,-341.557652,-339.856171,-352.404691,-363.644298,-292.147868,-257.612635,-252.708358,-252.538785,-154.615786,-59.924082,55.56747,39.26918,-34.970185,-61.16351,-59.177801,-19.547507,26.183873,107.481292,95.526069,-27.306214,-113.989006,-134.430473,-164.86673,-158.88981,-78.073646,-26.475497,-8.431892,-49.759942,-179.015747,-326.310839,-358.961086,-274.890597,-197.319285,-72.778158,-30.970613,3.226778,-57.798511,-105.607116,-99.102219,-20.192464,156.34174,187.216385,99.933885,12.066061,-142.950783,-230.978663,-248.1904,-232.674012,-201.906432,-77.574855,-15.559284,-24.750621,-190.053646,-260.73161,-262.960285,-203.458732,-59.110646,-13.452898,-20.044131,-55.194122,-137.360728,-230.663894,-247.193778,-134.189652,-36.772602,81.465032,82.07535,6.534073,-135.301817,-184.59444,-109.292227,-4.972185,193.322385,254.185243,224.431322,143.328644,21.955005,58.060501,101.253236,179.188045,207.453286,195.442143,147.837737,15.661863,-106.723189,-138.607554,-71.667968,17.381653,167.635788,200.189051,186.172562,153.90369,106.780631,70.874803,28.355772,-41.771374,-20.633102,81.100141,93.224445,7.366214,-109.941978,-143.856723,-76.267969,26.807101,220.119512,273.814482,338.507418,359.137204,337.027149,201.17626,147.163216,164.970681,201.857273,248.593577,248.924684,175.184098,32.793853,-45.781294,-131.633796,-96.860668,88.300419,181.45013,265.162914,237.103348,82.661466,-63.68892,-113.512413,-162.236455,-155.822889,-141.528329,-169.210921,-223.041433,-188.236636,-183.234769,-249.915556,-282.645543,-238.848386,-167.88821,-49.250239,-40.285986,-146.282749,-359.290044,-414.221369,-306.828606,-209.058167,-121.20414,-136.915696,-203.148445,-304.672484,-378.482042,-436.794347,-380.412118,-206.232727,-147.839862,-149.643879,-202.776282,-338.799823,-367.437579,-320.088091,-226.573934,-225.206631,-256.488038,-246.65983,-203.229317,-241.870919,-298.214516,-380.205514,-364.319181,-236.174622,-148.84784,-26.35959,-32.162868,-99.286587,-62.202544,-11.36726,85.706947,145.188287,273.527388,288.607455,203.445619,114.355619,87.576133,46.551528,29.342048,35.749097,60.852703,48.470598,-12.660704,-197.745396,-395.239795,-455.223974,-400.653638,-284.649113,-43.849717,-5.523996,-91.982022,-200.472726,-249.106812,-319.146248,-321.189,-282.338128,-254.794719,-161.698873,-109.996596,-124.936596,-224.955307,-241.969754,-228.495059,-192.919119,-24.077296,63.070949,116.687753,-38.151349,-150.271928,-216.516444,-173.861566,-119.935777,-119.553767,-137.790472,-152.091378,-178.53252,-236.513377,-256.881669,-232.417915,-199.380988,-78.545613,-13.713089,26.680984,5.243272,-23.728905,-126.888851,-158.936876,-113.824563,-55.114949,27.678439,23.697893,-64.109711,-179.880611,-202.082559,-145.020605,-86.477669,38.473872,73.552178,94.309912,88.092405,54.765769,32.828621,76.348382,158.158088,156.395548,109.60618,109.423461,167.852776,157.396249,134.221776,164.203399,210.426241,283.024775,281.852307,191.940951,81.076213,35.138541,-15.072824,3.74785,149.468394,250.748629,367.266722,349.298395,259.166729,248.946868,274.26625,316.057957,325.46282,371.169364,385.537119,284.794527,72.275857,-2.595374,-22.380434,-13.764489,-31.768099,-21.004343,12.857331,-12.882183,-127.69716,-218.380937,-212.438076,-104.528851,-45.763203,-2.034339,-33.783509,-151.338488,-211.636229,-202.023897,-101.834199,-54.240981,-39.066246,-17.956604,90.793157,134.259612,188.90984,214.321852,208.85852,192.136652,202.446845,274.421361,305.653615,323.417912,321.318164,304.272901,285.071013,284.790787,169.536953,72.040943,19.45345,60.293188,95.626404,90.759866,133.940713,217.058252,193.713112,149.409623,190.81722,240.015003,135.3024,106.544865,175.114046,240.440815,324.069501,312.923522,204.904651,146.899609,52.94953,-30.543059,-25.979912,76.454574,129.083351,165.853379,122.73503,8.13883,58.373927,87.450621,68.996807,80.360157,199.806416,255.001784,235.727367,176.345663,70.913984,59.257173,123.623492,333.807391,387.784356,289.241136,192.898779,64.751628,-17.040182,-55.671635,-42.952304,-6.685144,87.543864,167.757384,311.474116,304.455188,133.186104,19.691528,58.446028,224.525721,285.321939,327.715126,322.140826,289.572016,204.117418,138.713572,98.503094,149.588796,293.403404,352.589998,400.436054,373.69222:3.579548,-109.111284,-105.788173,-48.812694,-45.213395,-86.321599,-93.968171,-117.915724,-276.013166,-354.539581,-336.997321,-247.978275,-99.482508,-103.631267,-245.27289,-320.190048,-398.594825,-423.661289,-406.864429,-306.924728,-242.896848,-167.581936,-181.823465,-277.420319,-336.02252,-329.741942,-305.834218,-285.458998,-141.762228,-52.290338,-20.622877,-60.999626,-109.589048,-129.046752,-121.963405,-25.668849,57.591669,187.987138,179.839063,-1.62158,-207.850025,-246.975457,-237.796571,-228.955667,-162.39935,-97.193433,-57.572331,-115.24814,-255.088565,-283.510669,-260.409045,-160.535912,-95.081851,-2.906983,18.779046,21.735707,-41.308904,-54.079261,18.841258,80.991058,216.362388,256.284888,149.166697,28.260662,-179.313491,-310.01992,-331.605367,-217.787032,-116.899817,8.772487,10.765347,-55.917552,-180.15416,-243.929469,-266.981822,-204.898532,13.270916,103.949565,101.603959,14.71243,-181.026003,-230.192892,-198.208627,-112.098567,-71.741968,0.912038,15.590473,-26.66248,-92.963565,-77.538637,26.358043,70.609006,169.671385,226.001521,226.123314,162.514898,32.444435,14.929126,56.389496,163.993697,185.660925,163.918857,141.986364,45.653412,-79.008917,-88.277868,-11.969014,37.609639,174.210083,244.315181,247.647176,194.300847,124.612282,83.591635,48.391985,18.241299,48.840974,106.274381,74.187741,-93.474324,-166.403987,-113.687364,81.800523,157.303514,212.12471,227.370732,263.390942,267.28119,206.811709,45.552804,-12.082308,27.299476,98.346892,208.575333,209.901878,109.682813,-34.688549,-91.41333,-133.662505,-124.625053,-52.342578,-1.981088,30.268924,-14.455722,-185.947694,-280.865576,-275.47087,-263.530151,-256.844038,-188.32965,-166.145546,-207.376784,-285.385124,-302.209702,-227.348963,-162.902852,-54.676524,-18.312829,12.167855,8.513989,-102.478261,-274.959347,-285.753094,-173.735287,-111.868691,-31.014004,-27.436212,-138.34317,-346.163413,-428.103819,-407.684571,-317.169836,-129.280774,-79.741528,-108.897482,-158.049031,-251.882178,-283.857576,-235.108675,-93.513631,-75.057525,-119.196758,-135.955787,-155.451124,-197.222364,-218.388957,-259.286009,-273.245641,-184.59233,-81.434192,41.916207,19.179477,-81.015699,-79.457245,-24.89322,139.938297,237.876926,381.572796,368.753275,207.68788,78.220181,60.977191,79.007607,75.806714,47.553841,44.343449,26.182123,-8.20992,-155.484884,-341.336262,-388.623804,-299.343688,-166.952586,71.307623,80.981984,-73.644489,-196.636708,-228.005021,-237.660087,-199.406763,-105.430215,-91.56678,-84.328136,-73.459211,-138.492927,-219.387091,-182.603361,-26.896151,48.615529,136.343856,129.022118,55.898618,-71.311093,-146.355724,-223.86123,-208.919226,-103.491532,-55.657357,-83.851619,-157.827282,-289.861975,-282.6094,-239.182784,-136.916584,-82.141688,17.482298,17.298319,-80.534022,-151.048945,-171.452084,-190.712237,-174.943322,-84.845841,-18.407537,30.445689,-21.176561,-138.054688,-125.345298,-99.673327,-51.786286,0.107093,146.145512,178.354374,127.125757,60.288234,50.433444,111.04172,165.922701,216.301467,203.246769,155.563388,141.820989,148.356254,142.339912,148.258423,266.018085,341.52487,351.012591,280.175686,128.385443,38.397509,1.346854,-5.856867,34.785955,170.585049,255.286169,348.637104,305.003357,111.501982,57.667981,126.873926,294.739749,324.793164,279.091936,221.456208,65.04283,-51.79855,-61.508226,24.736316,75.431997,118.774679,129.095651,94.303608,21.991711,-169.988714,-253.278952,-234.888068,-177.172577,-146.693632,-37.656999,6.570708,-31.775885,-180.161375,-224.600417,-182.02119,-128.555534,-41.199087,-5.41653,72.292945,105.550604,108.975269,98.700973,130.13536,193.618505,210.248959,291.261284,335.344665,305.74544,168.348442,118.54799,148.4597,192.793616,171.957223,117.63322,51.601096,36.967676,-45.121313,-71.140922,-7.040398,133.260507,159.65031,172.66023,175.464983,115.397498,-13.206342,-35.781804,106.777327,232.265091,383.240523,353.435048,133.918028,25.538373,-63.150753,-31.47663,-6.325327,6.179773,22.799186,121.297568,124.586058,-7.609929,-31.6693,11.902096,65.692276,64.004549,88.78211,128.336782,159.592293,119.518302,-5.098536,-2.257942,86.159896,305.547955,352.694679,277.662602,200.545642,74.914536,-12.739342,-41.103277,-27.059845,3.162587,138.475135,232.994479,284.910857,225.308584,72.487601,7.973424,40.380555,224.358673,323.705965,389.67982,344.747942,215.401083,118.445072,86.704634,121.792517,174.946688,272.781565,319.937499,355.30174,296.468381:128.111954,-107.966129,-187.924272,-222.244511,-200.767223,-125.123685,-90.246514,-71.48229,-93.900423,-124.103775,-196.613089,-188.49268,-59.442381,-20.396518,-145.096936,-249.212604,-352.239575,-395.529941,-421.330741,-416.963347,-401.099834,-406.791427,-417.960853,-404.7729,-336.469059,-307.61122,-252.433404,-196.097493,-31.707854,40.741405,86.434504,70.339207,12.580993,-52.333808,-57.776851,-23.095309,4.92272,70.582984,86.422038,37.810702,-120.329787,-207.404377,-262.465717,-238.941956,-218.374316,-215.687205,-173.184521,-160.598896,-234.328858,-353.545631,-373.654859,-330.045124,-293.277849,-216.832309,-175.027496,-86.715163,-57.094781,-80.296573,-93.693584,-41.454059,113.094334,158.307794,135.723714,81.389457,-68.754603,-205.642005,-233.101997,-200.37661,-159.595399,-56.355812,-31.714487,-129.097921,-278.473588,-302.987865,-245.604882,-200.690311,-118.724071,-77.510643,-40.032022,-61.44882,-167.417578,-274.668743,-257.827044,-88.499585,-28.227306,-36.440501,-73.830886,-146.285703,-161.465045,-166.772094,-138.528122,-78.422933,68.957508,123.132936,161.583307,153.933536,129.432644,93.918179,100.053534,183.728742,192.366077,55.786627,-33.549709,-125.057905,-148.285391,-175.642854,-224.815491,-214.239248,-129.814055,-84.595017,-52.475776,-61.699452,-75.953351,-107.760755,-133.762621,-189.848984,-221.408254,-230.572526,-193.512613,-91.97324,-71.854207,-96.146228,-66.128471,25.727688,290.848808,418.387226,542.644014,514.605338,401.716612,396.679126,433.836665,484.269603,460.853252,358.487603,325.146114,341.096994,390.142933,378.198473,308.904832,303.399992,375.386094,413.243446,424.084105,393.297581,279.023535,191.485315,188.505927,180.802416,133.682632,64.039469,85.952692,93.435613,-56.44622,-121.747119,-171.06456,-180.810012,-156.067982,-110.808244,-52.819785,-67.749124,-129.511551,-228.389547,-277.82481,-286.140529,-264.767499,-211.680984,-166.554999,-154.342484,-369.510166,-476.712345,-471.894854,-400.107783,-355.537002,-369.142505,-335.116744,-323.636916,-394.092232,-454.224323,-433.174525,-311.153846,-245.932019,-168.758941,-167.640194,-238.748778,-366.964421,-412.613751,-346.469362,-249.898627,-98.414481,-47.314458,58.962811,72.287793,-11.826347,-25.745842,10.345867,117.632457,194.608221,328.16416,335.683509,264.152771,255.138334,260.486279,240.915671,234.265024,213.919273,203.604059,200.669593,197.019894,115.466815,-156.426844,-287.580299,-293.977279,-180.567506,22.888992,38.343676,-71.723999,-239.871378,-314.113152,-349.659467,-292.486519,-147.273269,-120.408731,-139.347953,-141.457312,-108.571254,-141.845347,-225.032186,-383.800172,-355.885689,-60.957592,101.441448,208.592855,30.300346,-97.355484,-291.662616,-333.200471,-316.421603,-271.503319,-191.351928,-180.469089,-191.755962,-244.629813,-265.054016,-208.679265,-141.410724,11.804421,73.23176,94.88575,18.147915,-36.546356,-100.826677,-72.111222,19.687941,44.840152,80.609773,80.125819,-1.001548,-75.586638,-78.090592,-83.163628,-92.742762,-61.02664,-9.493674,139.101894,220.636076,193.38903,99.867196,88.073422,99.338749,88.022825,39.023873,21.646719,39.460043,52.641681,27.923315,-22.744843,-26.541121,14.33888,30.469038,-37.081641,-122.177679,-128.442684,-130.115721,-117.827804,28.724962,150.542589,284.256033,259.759916,194.090908,185.27423,187.669359,245.215281,287.529709,319.882814,303.326249,206.572785,80.620857,34.286383,-42.910255,-79.704956,-79.261459,-26.213327,72.66713,75.183761,11.18485,-79.840392,-111.068192,-157.825385,-186.147326,-169.513293,-114.544762,-39.261057,-51.175208,-40.722776,52.069913,95.747329,85.002617,59.919239,114.819002,184.089286,247.546584,187.101033,164.223233,180.487413,215.744889,323.34263,365.585073,329.706004,159.456549,96.181101,78.471293,75.556861,-18.48203,-90.255155,-206.246009,-225.827496,-142.316477,-27.716022,3.460769,20.589887,-5.550154,-60.755062,-48.760676,5.614696,3.637447,-1.776819,79.030429,159.438966,271.743223,277.5518,200.222779,129.787999,-12.842912,-90.872747,-74.62484,38.023985,74.791769,70.625114,41.740596,-15.46293,0.950922,7.009696,33.833619,110.204842,349.213263,426.314949,348.757574,230.505105,78.523375,89.732274,114.855584,211.110354,264.649225,258.900517,187.90221,32.537026,-73.809476,-129.468516,-161.46343,-117.287369,30.232287,100.541624,148.731378,125.719544,21.656809,-87.615663,-51.957043,207.49048,304.640396,221.078108,96.200453,-37.83381,19.772698,34.209796,47.706712,104.194595,276.827912,342.115368,406.110267,402.273641:-79.206555,-290.027193,-296.026696,-153.934889,-90.734099,-26.788974,-6.248937,-39.722113,-239.040813,-341.825432,-355.0688,-263.649839,-49.747778,1.70402,-101.837307,-216.798701,-403.002756,-507.839354,-509.197997,-358.250411,-261.787022,-181.677337,-201.500677,-299.657056,-383.747874,-389.812492,-293.459458,-194.834172,32.988163,114.287279,143.321435,115.124726,28.950902,-98.677244,-146.162764,-108.191539,-14.166843,168.225507,163.793368,-55.597079,-314.101771,-389.681065,-369.863993,-304.261656,-200.983545,-164.69839,-130.909515,-159.931522,-300.067737,-409.887798,-401.040321,-276.790295,-186.72036,-27.173613,-2.944496,-40.685815,-49.746107,-46.610692,-44.499934,-6.665768,199.122036,301.328542,273.631791,143.767429,-152.410931,-321.031228,-339.535979,-270.627848,-190.953112,-18.571677,4.11824,-107.294768,-246.568628,-288.812286,-264.624417,-195.653071,-20.274024,60.158359,100.109325,37.619652,-126.965505,-229.658153,-245.960849,-156.310921,-65.106908,71.710919,65.869801,-82.815827,-215.062319,-215.876046,-88.502507,11.860638,227.230667,296.797265,252.470626,168.182158,42.771933,51.81508,98.561775,188.505735,192.477637,156.824534,140.670222,60.642436,-134.715378,-227.814403,-221.263595,-122.224988,89.130853,168.261635,241.144656,212.817205,93.153645,-14.901199,-71.104531,-131.743496,-98.707686,30.23339,59.330763,-11.545437,-156.507452,-195.025903,-98.823948,29.844386,315.389636,418.195395,477.620528,434.610891,257.918393,88.681475,68.517833,182.415545,272.804404,409.60688,431.247984,356.178165,177.755036,107.9163,89.670457,136.656796,307.093831,395.632351,436.603043,351.902369,51.096062,-112.061283,-83.924231,2.123172,1.374369,9.845781,27.595472,-12.624308,-131.841312,-190.248768,-219.472627,-175.710967,-46.999438,-4.52062,-11.967754,-59.647082,-235.502908,-414.130221,-440.093907,-341.992472,-256.191587,-120.795687,-100.855798,-207.102146,-472.496174,-580.926532,-554.590082,-452.822762,-272.170006,-213.662208,-166.303436,-192.670315,-328.56627,-425.629903,-407.150597,-289.201581,-221.922085,-116.817494,-122.07972,-259.924836,-431.049698,-486.541732,-409.383691,-271.843989,8.362656,92.379414,118.620274,59.646841,-128.880299,-157.848686,-68.794914,186.824046,302.168608,434.325455,435.325756,361.195256,233.266729,154.088395,86.618081,111.117104,172.328757,176.268241,97.816886,29.615735,-117.08752,-304.278962,-387.134406,-386.309736,-287.192765,-63.993666,-34.64977,-168.014118,-341.871574,-393.107927,-413.466274,-377.500632,-229.539576,-149.306814,-64.228718,-81.481788,-229.556451,-326.455468,-303.998309,-218.252979,-159.838927,19.47971,89.220573,69.443207,-119.663613,-217.484676,-244.642151,-178.51624,-70.188068,-52.364927,-85.315051,-135.240854,-237.548433,-332.541376,-348.549957,-248.361338,-148.541517,82.993897,152.480384,76.756311,-107.623032,-177.652892,-224.581825,-171.987789,28.894866,114.537977,184.067805,167.126022,25.429716,-76.397469,-54.510257,-8.801647,0.150151,89.388183,145.477275,180.960075,92.002095,15.689981,0.492694,96.673375,235.939405,194.941122,44.171113,24.422241,67.715728,29.892634,2.709297,63.416669,140.594108,250.96084,234.68326,66.576505,-141.980911,-226.201856,-273.027203,-215.277512,14.085456,140.309653,241.910346,194.780265,92.126078,127.127052,152.250604,179.701406,202.637892,252.301383,240.958174,96.850518,-89.452517,-139.07186,-110.613074,-68.286303,0.72062,37.271148,74.202611,49.314252,-62.716827,-156.891448,-167.812766,-137.874713,-110.302575,-45.261819,-33.830719,-94.292332,-185.041054,-198.233114,-104.006594,-22.834437,93.701813,129.236883,189.492094,202.888559,155.416709,70.525005,71.839651,177.146883,255.517622,382.129056,400.647908,347.488317,205.284657,132.782208,108.746347,140.597248,106.606324,30.198746,-73.30501,-60.083631,2.996874,11.453669,11.366659,11.473296,13.331442,73.340864,106.052237,55.52208,-53.265612,-82.699421,-55.485217,17.677533,210.861246,254.355083,153.713516,59.85178,-93.457977,-179.78911,-178.93774,-89.825969,-29.365642,43.342078,21.621832,-65.311484,-54.441466,-55.334249,-73.738626,-24.530221,186.502623,267.405186,247.232305,175.444259,23.872432,-75.282984,-59.697768,123.678844,239.010232,350.952896,315.341135,111.23501,-104.892986,-152.859033,-80.208191,-5.777081,126.818379,182.036212,223.931576,195.240695,37.076235,-104.102605,-64.987397,190.346049,293.056027,334.006255,299.215642,185.178593,88.056881,57.335605,59.84372,103.321533,257.284882,336.035587,411.345553,403.571256:178.58558,121.068819,128.820023,167.21703,140.925741,40.547691,23.99036,-4.938374,-85.080184,-110.45481,-110.319713,-71.4873,22.349727,7.090501,-125.415091,-147.730224,-60.948904,-79.820299,-163.900916,-351.89959,-404.855619,-402.191309,-385.246989,-344.956622,-242.145474,-204.901297,-176.222857,-152.180982,-68.527524,-1.459397,166.43176,215.897112,160.086148,1.104395,-26.661696,60.693194,96.441212,60.07629,37.39144,32.697078,-2.508284,-49.34645,-169.225335,-198.395359,-144.662301,-102.624059,-103.653221,-136.531206,-178.024232,-215.803637,-241.096979,-227.471727,-177.860654,-46.870243,-1.429311,-4.39745,-40.814448,-41.772889,11.340908,79.645336,231.593514,262.961932,198.259813,119.453119,-25.658519,-101.133019,-137.188855,-139.269271,-65.437604,122.379271,140.948454,-35.770415,-223.264142,-246.392616,-214.510141,-188.499744,-157.655676,-171.289537,-254.2043,-289.427484,-306.248673,-339.730603,-363.040394,-351.766067,-329.735219,-287.161903,-259.250658,-209.705302,-227.424742,-266.441419,-312.35799,-276.11173,-108.095131,-24.898827,26.08905,-5.965839,-66.183917,-48.023177,-19.971369,12.587897,-21.718384,-174.702184,-228.537548,-205.649002,-185.25099,-242.046876,-346.450003,-316.031124,-173.925583,-135.571943,-112.829704,-96.631859,-42.818782,-32.477888,-85.779363,-216.514531,-204.505098,-79.103821,-59.494945,-73.091152,-13.178807,23.523178,136.212184,230.080656,377.274638,382.787296,316.025018,291.876045,311.454227,352.860511,357.297594,355.517543,335.166183,246.99106,220.294144,288.063461,396.380261,399.15056,378.156069,404.322704,489.664402,491.142807,374.272023,310.752779,281.358977,263.282713,231.554945,188.652239,156.383723,77.179216,72.465279,70.894476,-20.004712,-79.288884,-167.572661,-188.720285,-185.875978,-152.84242,-64.220407,-49.442667,-96.785139,-147.511382,-123.412033,-15.806204,-6.827394,-49.378341,-37.753054,4.769082,-83.460426,-159.701262,-237.185138,-230.84814,-205.727248,-212.005771,-264.819935,-299.978196,-354.058918,-329.963683,-285.48541,-215.622339,-211.93279,-184.769963,-140.655384,-101.809634,-197.138848,-250.790424,-282.56102,-250.73831,-112.493636,-20.295007,110.062501,93.505694,-36.287951,-55.32241,-16.408531,72.827285,129.160085,280.372746,324.48065,270.276852,141.505233,98.008301,111.909362,137.720766,114.13687,90.724078,128.891812,171.71708,142.1237,-108.024755,-223.602031,-234.806254,-150.047513,26.081769,81.439355,121.597389,-28.366512,-175.691057,-331.629834,-265.547974,-56.646801,-9.674621,1.910017,4.554658,23.322767,-16.478452,-98.279608,-254.364848,-240.62544,-45.839368,72.353844,263.31806,240.592857,114.822652,-152.673641,-202.878038,-151.633626,-91.075482,14.971606,31.215224,30.909261,58.255623,43.350441,-11.588431,16.41091,187.524357,246.242854,174.011041,44.340847,41.365071,126.147075,154.391633,160.35566,190.977871,317.089363,357.614091,344.627176,283.352996,248.770141,156.816724,124.862718,161.036432,215.948898,339.683216,356.001769,297.446003,169.038023,144.639417,153.464921,153.915919,89.012065,42.400584,22.775036,1.183738,-51.44298,-151.790504,-177.752693,-177.206167,-151.5065,-76.878063,-66.083572,-139.006521,-310.715636,-302.312158,-113.44038,-29.85279,25.257339,39.811519,102.487341,122.400623,92.708849,25.676529,20.835752,68.907915,86.436879,44.756276,-31.537131,-78.783459,-204.350465,-243.259508,-195.264594,-131.166435,-51.7092,-38.644959,-8.087513,-48.709351,-92.129956,-171.533251,-198.702051,-156.496438,-93.537058,-5.038766,52.712532,99.439057,174.922737,183.740532,171.725716,178.860019,241.003561,258.271873,176.633208,48.20727,46.907847,161.07785,203.497963,256.03696,313.489601,386.462771,211.580937,86.307864,-24.38035,-10.236591,-4.104358,-34.225436,-95.028678,-109.68171,-104.623146,-71.208165,-45.132641,-21.259851,-37.367098,-16.959444,45.693022,141.994918,131.248865,126.527645,126.250546,108.70669,67.527168,73.784498,69.506793,12.822715,-168.097131,-269.324811,-247.628618,-133.232256,-108.500038,-116.729967,-95.719146,-29.03275,-85.871473,-145.776805,-129.829845,-23.77571,184.102941,213.366699,159.421018,117.080727,31.167223,-81.608615,-111.004461,-31.187021,44.339126,127.626919,104.329277,-45.385382,-186.757867,-248.326591,-333.405936,-305.283165,-109.016359,3.726149,131.140676,124.940095,-5.570545,-173.364149,-197.611324,-116.337354,-70.327813,-58.973423,-68.899862,-8.283306,64.712246,37.962938,-56.842142,-64.318607,22.518757,86.157542,148.897406,131.108766:332.527124,172.442984,100.176982,2.259811,-14.182901,-10.69473,-21.296142,-38.999878,34.616685,66.860726,65.877573,51.663443,17.433969,-9.252435,-77.383317,-106.525616,-186.09081,-314.217134,-343.250205,-319.193559,-305.734717,-297.853046,-298.598142,-280.712082,-200.713723,-165.791593,-140.776619,-151.329023,-187.246866,-147.462461,53.3912,126.996419,125.748335,20.445058,-23.760529,-57.914589,-49.206836,24.89422,83.1918,172.544459,120.476563,35.134797,-155.417853,-216.490738,-261.614967,-262.911717,-211.786049,-169.567694,-143.319965,-216.238541,-254.754855,-233.60546,-170.719233,-48.884937,-36.435557,-58.171668,12.119138,26.442373,-77.178405,-119.067104,-44.010861,36.245641,103.201392,59.709723,-97.267406,-248.476687,-297.041239,-243.230803,-142.372367,75.126259,123.081641,35.456175,-100.082551,-117.559798,-103.923424,-103.467843,-103.047686,-103.773584,-177.561059,-255.675682,-406.30037,-439.712584,-392.065789,-243.513492,-198.457942,-190.173277,-186.275973,-123.793268,-134.187849,-207.484815,-332.984351,-297.334786,-56.640208,51.566084,98.343958,62.600061,14.504467,45.113668,62.957914,38.551794,-8.569309,-95.571822,-116.88029,-171.573884,-270.16937,-302.442732,-310.601723,-280.484501,-156.23038,-113.089876,-135.599387,-160.647562,-142.30074,-122.152898,-156.999821,-246.455145,-258.526872,-182.370352,-120.832185,-78.032732,-185.833486,-230.616143,-118.999937,-8.055983,97.389135,124.096633,252.918899,309.23044,338.562706,333.346148,320.525406,271.429548,235.729061,194.880047,205.082967,229.980967,203.197318,172.468544,178.174091,236.834548,317.881789,307.475083,300.321782,316.823098,302.676792,254.73726,249.700179,247.957756,226.005735,193.585644,208.689666,201.970662,91.555487,27.78502,-106.005638,-156.694513,-170.995592,-126.203843,31.941707,84.070384,39.676564,-38.204795,-25.68344,29.172452,26.394241,15.324876,51.918844,114.561787,-45.009785,-177.40773,-353.478154,-375.617455,-349.761637,-320.964117,-270.526146,-269.469983,-314.573636,-379.379515,-381.168108,-269.852752,-211.321834,-199.630543,-214.386371,-225.025257,-310.486481,-382.511637,-406.810706,-329.764627,-115.611381,-15.769744,116.892229,126.157348,74.501435,6.906643,-12.084487,48.229234,129.154123,250.807439,237.597518,169.399743,172.837885,155.948267,93.1702,77.510603,76.025707,100.49564,182.01735,197.653538,99.689209,-125.962605,-211.332648,-248.27968,-224.568676,-122.429206,-41.99773,58.488694,-49.59684,-141.639832,-233.180676,-209.728118,-106.90083,-61.571678,-8.602919,-1.06742,-6.965158,-60.68366,-151.793436,-387.506731,-405.989679,-148.353907,12.735109,134.813393,45.377089,-8.758282,-114.01878,-174.630117,-247.378358,-241.047798,-229.365809,-236.905133,-205.54092,-184.394486,-197.554633,-185.244547,-158.152649,-74.749297,-5.563712,123.038726,107.350174,46.666571,-27.939679,-7.242631,54.164758,64.036529,56.429281,57.264489,48.308383,-42.486027,-77.484394,-58.37571,-38.517088,-35.075271,-52.58531,-82.581883,-55.62413,-54.009879,-72.302791,-58.013879,2.46791,13.928321,-39.655417,-83.185328,-96.232564,-74.674047,-102.449654,-162.555873,-176.647839,-204.239885,-206.010904,-129.685078,-52.892142,-82.672895,-190.860005,-196.347808,-107.937968,-37.754977,113.950233,165.123805,191.201344,148.312425,110.214015,67.965561,94.826937,203.320485,218.802251,108.422534,9.661785,-17.392773,-136.519409,-222.091892,-287.89257,-222.735417,-39.916108,13.347875,40.030135,-60.262703,-129.404796,-216.295915,-231.097775,-178.240221,-129.920854,-85.643464,-68.625069,-70.90467,-109.201521,-114.137948,-66.463677,-29.081097,-6.727275,-28.628878,-37.695473,21.039482,44.944434,64.54369,71.843535,119.276285,154.505779,200.233446,185.718991,136.70615,-34.908207,-110.997467,-164.696801,-168.314236,-184.888462,-180.255259,-127.667154,-100.387446,-108.015379,-120.592925,-104.107174,-12.928194,40.778228,98.945447,79.987034,68.157371,91.996185,110.431097,109.302823,110.99633,122.98183,101.990036,33.318165,-16.05276,-34.060999,-50.670984,-72.092049,-75.304691,-15.955662,89.973357,77.554621,84.340661,185.468537,241.495839,304.941555,333.045688,330.608385,272.172431,137.951469,75.465435,65.308316,101.659347,147.414224,191.267994,132.543439,-96.265229,-224.644367,-221.980525,-134.312675,-82.894697,-20.182548,-4.482607,23.359066,39.647372,28.74936,-113.495324,-178.611823,-163.843773,-99.85765,44.10218,80.991478,70.138014,63.461562,75.226918,124.101376,157.280012,227.439885,258.770031,289.617025,297.015485:-48.706388,-114.78727,-84.124748,30.989933,61.792611,29.166138,-3.166688,-34.261869,-59.794161,-67.059953,-35.262473,-20.910011,-5.836474,21.829144,38.482305,-4.469268,-121.661194,-211.478304,-224.798727,-235.611262,-268.552831,-338.102682,-337.692394,-267.988843,-209.898459,-199.847844,-152.173932,-101.396496,26.058117,91.897422,178.190954,180.59945,124.516802,12.641687,-35.360332,1.021854,78.004097,191.480119,176.793268,-8.088967,-245.885557,-311.476205,-273.981009,-215.388708,-160.415662,-152.320523,-111.702949,-102.596477,-184.279875,-337.201649,-348.922981,-175.091881,-81.655266,-55.139753,-71.626373,-38.437416,-14.05773,-39.401545,-62.013423,5.38076,244.290393,326.410136,285.829421,173.621567,-109.552261,-276.94238,-277.008314,-160.681384,-83.784324,12.484138,-12.917417,-188.95564,-282.370324,-265.785522,-192.940629,-166.211438,-103.547875,-38.32792,68.442299,49.053937,-119.019232,-278.994202,-286.318125,-201.627947,-177.102062,-170.898452,-164.197397,-167.611086,-209.428417,-219.335457,-211.560645,-193.094631,-82.627904,-19.156242,27.704516,31.985806,79.88562,130.135408,137.211321,161.120739,174.673416,122.061644,62.526361,-26.551119,-81.298188,-120.40862,-152.962482,-131.058739,-64.016459,-15.974075,106.797414,134.24553,58.577806,-24.893124,-39.137089,-128.488878,-202.44996,-239.633826,-183.124498,-88.095124,-150.718078,-171.351835,-44.194741,68.858406,263.517916,339.848499,425.318423,419.22465,325.51839,135.651692,94.066151,243.584127,326.487678,346.113675,330.123126,323.741565,319.526783,291.275428,255.963606,313.530069,507.819681,545.095849,398.257044,285.768939,205.737726,222.417543,202.963079,117.082788,68.106177,62.843786,106.427236,114.573854,-19.311606,-82.702631,-147.022583,-172.916589,-213.617648,-192.381078,-84.000671,-40.888696,-47.889053,-149.455401,-172.628199,-122.45398,-88.698643,-14.102261,16.349064,-46.70974,-225.779111,-301.354031,-345.932604,-311.534855,-224.043242,-212.866577,-262.748646,-311.777213,-400.891806,-359.76238,-301.051511,-227.114458,-227.537723,-203.623054,-155.674743,-73.735621,-164.121858,-251.731282,-308.437385,-257.694605,-81.799573,27.80945,162.257119,126.162282,-37.433098,-66.244189,5.490608,282.690637,407.755776,438.370994,372.038532,288.545924,310.205695,296.16127,206.408079,164.730061,107.920643,113.495776,199.002232,211.328152,62.027675,-162.926662,-214.538148,-171.046345,-111.189264,-23.592816,-29.209658,-119.05186,-263.115434,-361.374614,-479.875027,-431.605996,-201.121762,-124.49225,-145.637835,-173.28657,-116.731337,-106.77173,-192.180581,-334.450605,-305.544404,-132.709628,-33.994798,127.627708,62.048829,-53.19365,-242.845401,-274.963191,-215.32281,-125.044258,12.799123,-6.801911,-86.749662,-83.050218,-76.897816,-38.44291,-0.431741,138.233101,219.608227,216.641818,24.257242,-47.127667,-38.970045,26.386379,167.835487,225.317787,286.009886,257.824787,142.725956,135.428558,155.691282,148.153865,137.614426,166.423047,203.611664,273.122316,234.519286,154.10379,8.111673,17.039953,147.032313,169.336684,49.66106,-6.07419,43.532721,68.146946,19.201812,-26.775313,-4.753877,17.599348,-16.583598,-144.271592,-207.999679,-217.381702,-254.130114,-275.424454,-205.409541,-92.082913,114.440615,136.162222,47.014996,-27.5841,-28.720612,-10.873211,19.687935,112.871967,109.60735,-30.766022,-139.891889,-155.4359,-178.312014,-204.761444,-242.487644,-210.521273,-89.59773,-49.337306,-26.474234,-92.235317,-156.483684,-256.072758,-252.084676,-162.694113,-143.704168,-196.795155,-138.437191,-52.165954,103.310179,145.674651,138.714175,114.197224,93.18891,90.08611,72.432378,36.397059,32.079587,69.772534,81.219023,89.690993,114.121266,161.44296,123.98824,89.207214,15.946535,-28.617957,-111.559884,-123.189602,-91.182075,-82.35975,-66.962607,-31.509522,-36.131197,-81.651443,-84.420751,-15.094249,17.982027,6.347189,-3.709212,36.197598,156.016281,183.921858,140.777431,107.208502,26.821818,-31.308931,-105.17522,-85.556379,-61.926864,2.267537,31.283474,23.140437,-17.320788,-57.07092,-2.199619,-8.257618,-36.725219,13.433487,211.362125,291.489784,305.581706,250.520911,119.641402,2.295285,-22.324722,58.873049,119.631439,141.801573,92.82089,-60.287747,-177.219161,-208.765995,-195.069496,-137.600889,40.625091,115.517324,151.2125,121.944254,21.1588,-93.490094,-87.84835,94.383778,168.439441,123.069802,58.59068,38.183143,104.055816,70.27752,-48.868471,-43.777831,99.064057,177.182866,233.767238,214.928506:forward
179.461895,73.968187,58.340345,85.29385,88.59437,38.712609,10.817381,22.227516,25.189939,-16.162973,-137.314898,-175.234872,-141.088945,-102.98722,-102.90419,-141.136634,-203.296479,-190.236342,-174.383176,-93.777189,-23.856086,4.649884,-66.121839,-183.220791,-195.533866,-208.905544,-221.724989,-216.662509,-213.62645,-205.15228,-94.732302,12.288167,186.206442,206.33336,194.383553,189.144296,176.451531,76.315926,16.230229,-37.746393,-32.110341,-16.992832,7.491478,13.709781,95.147178,167.257196,245.015823,231.708029,124.891421,27.225413,27.479363,43.682661,34.564161,18.963226,17.310326,43.606247,30.083159,-27.563165,-117.122042,-94.17224,38.858235,77.615709,-1.480088,-70.379428,-89.149192,29.225268,73.964984,64.84216,40.199459,74.588924,147.570471,278.587036,228.439584,174.382235,149.702981,170.901534,194.03647,182.009555,158.359138,176.108575,235.761676,220.562701,170.229107,21.750918,-20.001974,14.74934,50.075619,109.7116,166.961721,196.477482,206.839633,153.537982,8.908429,-15.561912,35.631771,83.409661,146.621553,88.659808,40.347016,-36.538758,-46.816918,21.79808,79.31374,170.999645,223.962201,254.698112,309.644151,316.129847,356.929067,420.046033,517.822127,490.827086,318.173546,184.250857,160.212862,141.70672,133.902749,125.378205,126.180664,142.283596,153.438827,146.345879,144.548573,165.533895,171.265329,127.176064,36.577188,33.895604,52.482341,-17.549821,-52.914127,-44.881728,-9.855772,95.512713,146.880677,213.372054,258.474694,262.174043,208.465798,157.521355,79.543459,85.513252,183.606911,240.400631,265.923079,179.291963,123.128613,20.446426,10.065662,94.175199,144.093305,197.385061,142.625894,74.394896,-46.024543,-71.329835,-22.104256,51.091369,192.851325,219.331391,209.033474,196.169303,161.083607,30.498602,-5.474243,-8.205956,-29.250709,-119.555815,-176.289236,-176.338165,-148.223846,-159.428756,-189.012033,-137.886376,54.885589,112.026536,75.375854,12.705943,19.824428,35.980528,23.365762,45.828743,113.636217,310.871721,419.62938,400.026951,242.656547,143.773529,62.713348,101.548249,213.034835,246.348839,269.907543,209.476948,130.596052,11.879539,36.05883,122.826577,114.892338,67.18211,26.167989,-19.492282,-134.627994,-179.117709,-191.659122,-159.78986,-69.388383,-23.377023,33.128576,16.315515,2.902807,-31.946746,-63.4576,-97.059686,-73.979249,17.87,-11.776628,-85.975778,-226.122205,-267.812164,-256.657004,-212.814182,-112.651565,-44.300212,108.741872,128.622731,77.391353,-85.640509,-155.401099,-197.361106,-194.367103,-218.663856,-249.125671,-250.834382,-247.649547,-232.247057,-69.602209,59.95604,181.089466,145.161586,19.305864,-98.672435,-157.074671,-207.116659,-186.920119,-131.148284,-101.231712,-18.791214,-14.351186,-48.383667,-80.657692,-83.52004,-127.350746,-137.212706,-36.902924,40.122167,107.854036,20.697142,-63.847011,-166.601471,-130.474869,26.372451,57.548702,-5.977427,-20.680525,24.168241,61.95306,4.900628,-94.538585,-61.598068,98.390253,163.284544,144.48696,-48.57144,-115.978643,-100.602187,-53.543596,31.60348,46.303196,-18.48856,-82.143332,-68.244564,-85.375657,-159.708964,-258.689151,-201.774818,21.234637,81.412189,12.434848,-153.558284,-233.225284,-310.134781,-264.478976,-79.339281,-9.009458,58.243867,86.209809,81.560308,3.069128,-54.767693,-84.271443,-40.878015,58.696927,87.071163,68.603603,-18.639309,-41.426054,-70.771291,-98.875974,-112.304409,-53.96385,158.062103,237.449549,188.405053,3.432551,-90.886307,-173.748595,-143.863974,-7.135716,58.437558,106.572371,53.695737,28.367891,16.404713,21.378232,15.183224,-8.357818,-34.38861,48.308936,82.264234,15.781187,-60.284537,-159.777181,-167.757989,-144.270986,-117.219052,-80.253435,-145.368807,-197.932296,-238.992408,-192.244867,-16.657802,59.669852,97.699043,-7.487174,-67.399011,-159.986634,-193.045234,-212.240297,-216.718468,-227.603411,-187.780131,-58.101381,-102.630334,-154.729178,-124.886376,-43.274536,106.44813,131.500706,89.407314,-41.215096,-103.763413,-129.607566,-108.159555,-70.676851,-75.754811,-145.120278,-148.950203,0.622425,111.374439,63.703496,-127.456049,-174.838602,-118.195815,-61.044071,-0.490159,-24.131944,-45.973289,-112.568482,-157.394776,-207.842956,-184.301789,-29.606595,52.36662,28.072535,-202.301972,-288.168449,-329.669258,-318.321486,-253.299803,-179.620249,-13.774091,-6.29819,-45.188489,-64.633013,-42.553655,0.207558,4.213022,2.696779,28.471809:84.28584,26.839158,-1.817497,-66.446872,-72.074679,13.059633,54.042743,38.085482,-64.444757,-117.904597,-164.941712,-139.637841,-62.981418,-52.618888,-55.330556,-49.200144,-52.585482,-77.926009,-97.82417,-131.25922,-118.245811,-49.997209,-38.683846,-116.96835,-211.787426,-240.34787,-322.291477,-355.261255,-275.298939,-189.42274,-87.505931,-60.105641,76.38709,269.132863,306.307117,238.47655,184.411365,126.030727,127.483544,130.177505,65.009858,47.09246,79.763457,80.84551,56.311027,94.968216,245.468278,268.063815,145.651975,1.241769,-42.802418,-71.260809,-55.085547,-23.192807,-11.111624,13.12585,-57.175035,-115.325918,-181.178977,-189.041541,-164.302223,-136.248539,-84.972909,-59.887988,0.791825,58.59344,72.724134,80.973237,98.658403,154.153863,183.090822,242.718028,228.350033,180.716942,104.158001,108.678349,157.742736,158.573281,105.989399,83.234166,60.49321,67.985492,66.16185,-22.68154,-89.655623,-127.930387,-85.326541,3.442017,19.007174,37.092792,77.828662,58.855986,0.428444,-4.729888,-8.577247,-3.529761,51.431633,81.003252,44.399636,-85.223671,-100.266177,-3.297096,54.526781,158.26666,243.234517,251.92474,215.319991,209.699067,281.908378,334.06868,352.466494,310.630586,189.8857,144.365367,167.457221,196.057752,164.121877,55.247374,35.088333,144.423537,270.953661,263.166883,157.684464,106.645683,52.354936,48.50802,77.219633,78.748208,-21.108288,-179.145497,-218.730403,-178.193767,-123.9344,-26.194118,7.587116,45.543917,21.598127,-7.396889,-32.905703,-13.928538,52.684879,86.165538,121.178286,101.693473,38.457398,60.244011,62.372749,4.854551,-0.054368,68.593845,110.613429,169.719041,135.300354,85.173247,20.490763,18.136349,57.126391,104.733343,203.602221,210.012803,131.173835,73.954288,63.07919,25.332374,17.798464,77.259566,128.459759,163.964161,35.624583,-28.342119,-69.961158,-83.534964,-93.919494,-47.632144,115.279745,168.973356,157.960358,99.497895,67.760333,-14.160131,-23.151089,53.96395,109.836802,255.906234,337.646379,301.435611,167.756623,120.367388,108.239003,136.734489,217.945548,246.300779,232.849549,131.609083,44.921779,-131.072092,-148.101466,-30.988208,16.779905,-10.567616,-77.492205,-99.391263,-195.354324,-263.277781,-315.878667,-287.410415,-170.224177,-116.641015,-108.84352,-147.516183,-144.509124,-157.934418,-170.572529,-113.852524,-39.583404,54.959003,-93.312375,-195.032618,-280.982905,-280.333717,-262.714277,-246.713072,-145.444687,-47.58883,98.843236,37.637911,-33.295883,-184.205234,-230.564805,-205.256685,-176.971011,-220.160971,-296.681823,-278.767052,-153.033234,-89.460516,-22.482232,-19.199515,7.159588,55.259982,102.616956,-57.176661,-179.266997,-339.997472,-326.307652,-184.301866,-131.273552,-112.004646,-104.98355,-79.185793,-53.52989,-79.87906,-135.69213,-119.877552,4.883833,64.565948,109.008799,71.378648,16.437873,-52.324729,-17.722212,94.861873,114.012705,103.683921,129.874812,137.727585,24.686339,-60.074078,-64.269485,17.021027,183.93817,220.105651,144.569811,-20.562781,-70.01292,-31.718562,38.925057,136.553986,139.042753,111.18901,74.652031,49.580102,-21.489572,-57.013509,-45.793914,25.039927,218.388794,264.890008,180.80259,-6.124123,-110.846583,-249.905699,-219.772626,-22.076969,56.26129,134.328419,203.396269,201.051566,72.406582,11.40327,78.910544,182.513084,335.474986,343.256295,200.858369,21.804078,-15.630593,-48.649041,-62.041495,-28.327336,19.789391,128.461836,160.477776,129.553006,-2.687209,-66.654736,-73.138823,-39.451885,5.983244,33.439368,83.489571,9.681384,-62.881883,-166.197562,-158.205906,-53.655812,-14.260723,18.810408,70.772222,71.698263,-25.527256,-80.432905,-114.518053,-90.054367,21.053287,67.811453,39.271899,-126.334881,-213.120847,-234.073287,-134.651619,105.124199,139.453729,52.43745,1.720134,-13.987098,-128.595691,-193.428428,-225.963112,-196.293123,-76.191872,-14.250825,0.606055,-91.388891,-108.743497,-40.107738,33.877137,171.508598,195.857708,142.284879,32.750152,-8.031259,-69.506774,-97.05323,-128.547767,-132.154569,-98.009286,-68.07566,-65.130374,-108.676439,-114.093856,-120.846887,-117.840738,-65.452719,-40.453982,-24.580198,-37.797876,-55.634161,-69.916272,-68.4097,-70.639797,-64.615584,-25.827145,-2.821194,-41.380311,-197.876849,-263.390923,-289.804426,-252.21354,-157.088096,-127.053481,-95.657584,-60.177533,-33.766933,-10.636553,-20.350233,-37.914808,-32.35013,57.521204,139.394034:38.612481,-57.213482,-71.746397,-50.402037,-46.185913,-72.562797,-83.688765,-64.452782,-83.877844,-129.235183,-208.304092,-203.287461,-135.3307,-111.870134,-78.095548,-60.155868,-97.486505,-214.696476,-256.157725,-228.051946,-158.166933,-38.314547,-36.603913,-123.084008,-192.174291,-198.773035,-197.648038,-188.517771,-146.9121,-133.605763,-115.574966,-94.393213,-28.962913,64.376506,84.119222,61.581368,77.960337,156.489836,165.223724,120.587344,71.682754,45.676628,-2.830532,-15.104628,4.353671,40.342003,101.501707,93.138435,48.793464,49.849839,21.062953,-85.981751,-98.415121,-39.837995,-21.998828,-52.176464,-154.855937,-217.932015,-285.427396,-261.839172,-170.219995,-162.348101,-190.343387,-182.305525,-139.691859,-115.005184,-111.529261,-72.002743,-8.519913,115.90883,130.751692,126.229814,131.729865,118.9315,45.925882,2.456239,27.389969,100.621122,191.343711,178.893915,98.418299,6.806989,-20.170772,-24.489207,-23.573502,-67.459853,-80.24035,-9.737996,48.962728,34.640167,-46.164388,-91.065783,-142.08783,-151.764206,-123.436545,-70.581661,1.606896,-105.338591,-166.413487,-163.16271,-120.735981,-48.469685,-13.694683,45.539761,44.125513,52.971994,97.101082,105.940252,141.205289,192.986968,294.32411,295.749296,177.95425,82.500128,81.309419,80.240055,69.675925,95.664932,141.170193,202.995076,140.23801,88.814302,-17.206934,-58.324716,-76.852127,-73.441251,-73.506328,-67.352554,-92.636565,-184.102375,-217.512262,-205.273412,-161.586541,-64.712307,-34.868907,-32.760855,-93.318246,-116.254938,-120.253971,-106.493374,-14.408799,49.516608,98.06422,85.216026,96.166022,124.599651,86.267693,-17.531054,-22.7323,7.216289,15.104343,74.389514,149.339756,143.818925,116.386364,143.378801,205.974103,190.148382,132.347573,125.058826,99.521998,62.317674,54.908564,33.101836,32.759925,98.529896,141.82187,169.468544,83.625142,13.655075,-93.550008,-103.46309,-46.705797,-7.800955,76.26142,136.536176,222.678463,136.120657,53.561763,-43.125227,-20.290227,120.930352,177.212197,201.559181,206.207052,219.540662,209.881107,173.120126,135.794865,171.784418,295.75809,330.818055,276.53328,86.65596,-22.543369,-138.121709,-126.202744,-25.110675,25.527422,26.435927,-107.276179,-168.824171,-237.68163,-255.56117,-239.003063,-195.606173,-38.734727,37.615239,88.790911,71.082801,35.609587,-68.439101,-90.444059,-25.431981,48.044615,116.444703,-34.467836,-122.224178,-213.178739,-234.843893,-246.468569,-223.288785,-103.920339,-19.596842,92.139627,31.683979,-35.399241,-115.166336,-109.207264,-96.24615,-116.98103,-158.627001,-145.231174,-129.033952,-125.927408,-115.393092,37.647668,153.853835,278.392102,260.21731,110.429346,-69.503007,-110.73207,-107.93813,-109.913934,-130.080673,-107.293462,4.385146,36.669032,7.668801,-112.497371,-183.096064,-203.024016,-132.043349,44.33572,89.78023,80.536253,54.489794,63.753189,133.885818,169.496551,178.400644,164.851211,163.120198,176.191596,160.047087,65.208402,31.074064,72.175925,118.443039,191.786828,211.735189,165.497182,26.667072,-11.970062,62.003212,139.082684,279.97466,336.067136,333.972611,209.618999,173.352032,159.406993,160.227916,193.94911,227.676819,311.508604,356.042412,374.329513,195.237838,57.091617,-77.492023,-19.926646,163.897098,221.330155,304.703987,358.660941,331.695034,183.819321,135.861958,190.707743,263.09339,399.468662,418.75371,340.598087,269.452268,234.798448,119.766635,80.763506,77.491627,85.672966,104.360063,116.957915,82.195135,-93.27028,-160.047148,-136.774714,-95.299283,-17.050827,28.233551,45.470887,-92.022525,-172.278302,-231.963255,-197.777978,-111.930133,-93.733939,-37.459901,35.252323,18.688899,-68.137996,-77.066848,-7.160163,35.978096,91.605845,104.254744,71.187947,-86.828894,-195.539487,-276.547475,-180.847483,119.072554,181.891298,103.721511,47.448798,21.874137,-141.647875,-237.25662,-277.470889,-219.02288,-86.048495,-59.418094,-85.148916,-137.701043,-166.40109,-173.28276,-115.754547,81.797586,156.66986,139.585449,-0.728354,-45.392508,-99.265471,-141.339378,-186.985439,-153.421451,-8.793762,56.217774,84.563261,20.993297,-9.486041,-28.035554,-10.878484,61.406032,85.234748,62.974034,41.519507,44.817831,38.931772,34.591846,53.415566,67.942736,90.030658,85.929007,18.745562,-74.82935,-140.863822,-258.739839,-248.315535,-88.4339,-5.574873,65.303318,54.838409,31.425884,-15.696393,-15.976217,20.77765,56.26345,187.72602,241.668539:169.828363,16.080453,-17.828467,10.244163,45.677719,64.304595,34.636831,-14.994047,-23.517498,-43.237379,-118.473252,-141.560158,-102.898443,-74.049183,-91.187672,-127.970835,-190.473737,-232.230774,-240.732205,-177.469818,-108.750309,-15.512434,-31.345478,-149.93065,-256.04828,-259.625599,-211.065261,-219.978961,-294.64076,-299.873056,-174.423791,-72.58282,71.320886,123.11701,151.310707,183.703335,165.422515,90.685958,60.387768,45.190152,97.934905,125.959495,120.097232,102.652954,148.668272,217.503323,318.893181,305.446846,157.978985,10.757684,-10.894506,-4.762977,0.767431,21.310429,26.651127,-3.501747,-64.478007,-81.14702,-112.601373,-149.676488,-218.799064,-219.48938,-179.734266,-173.579327,-202.12177,-203.00279,-177.463112,-99.073244,-60.883776,11.776837,63.567295,162.781611,125.873711,82.827924,84.735163,116.494597,131.264847,121.763312,188.434573,259.698178,314.371073,192.187014,102.723302,-5.396204,27.0144,140.160318,122.707621,-3.477363,-21.437687,2.917374,7.409466,-20.491108,-63.282821,-68.772539,-45.609414,11.491717,153.639358,104.516282,24.607359,-76.173659,-64.933209,48.10138,113.375177,206.947478,222.0288,199.734315,173.557321,191.842385,275.373515,323.232782,365.837607,347.598973,287.224622,269.798192,249.234366,140.562618,101.162058,136.291031,166.801625,152.908982,106.745066,97.966906,56.309114,13.35872,-15.924053,15.876432,60.618776,40.061488,-61.136542,-158.138439,-194.219085,-235.979704,-211.266688,-59.090962,9.717259,49.634829,83.700338,109.062947,94.005412,60.681707,26.698628,36.407529,101.168146,159.326158,271.928472,236.119231,160.442709,31.458222,22.942635,90.80725,133.505426,215.883709,227.090613,195.454407,116.780089,86.611992,90.089511,127.935532,210.750727,222.794413,216.769252,245.960958,233.745612,150.027256,123.842802,80.313056,53.362862,37.165775,-16.104399,-69.529907,-159.462887,-190.412388,-193.564405,-143.782459,33.148482,108.661302,121.381685,19.804418,-25.058585,-44.727827,3.533273,185.605546,265.812243,362.677925,371.11501,334.694013,216.595272,158.225495,162.300502,227.842645,331.527476,334.150728,281.868349,200.742741,135.900635,16.157672,5.302845,59.652521,91.386962,112.335593,31.510583,-17.154555,-66.364413,-79.368909,-106.002648,-106.739405,-34.25235,35.459641,119.876165,65.626723,41.443405,36.087275,27.09679,0.403627,19.158371,118.179519,96.172013,36.540472,-87.550521,-142.030473,-146.799801,-93.100475,23.343293,77.383703,159.492343,147.883946,101.614587,-46.382018,-106.286716,-141.025314,-125.245177,-64.884044,-44.954276,-64.370737,-106.971508,-87.294939,99.345296,223.22734,297.166077,228.704103,78.044703,44.268377,48.468695,40.443146,26.972502,11.85035,23.012603,69.973528,102.011987,107.384545,57.318474,-10.138184,-108.590318,-84.333084,4.343897,5.105105,-15.736469,42.41897,78.943263,92.97758,69.899333,32.729935,29.27124,41.131682,77.425619,93.598566,90.14755,62.667001,8.34856,17.452181,93.029083,118.097073,56.549202,-76.110399,-101.2488,-66.628224,-27.9545,64.028165,84.166686,25.551059,-24.317106,4.48425,91.302973,91.626554,38.470702,42.438759,131.902192,185.121369,191.916975,-3.859729,-128.094041,-254.959813,-214.782538,-6.076872,82.025896,154.376601,177.476006,157.341464,23.249415,-29.865989,1.498957,48.428977,107.83507,124.285598,122.111712,67.318298,24.468082,-88.82735,-136.716149,-161.683394,-133.55492,-18.334885,19.451442,-36.904906,-216.082556,-278.18439,-292.049087,-259.943207,-136.484315,-67.72015,-54.190679,-183.798708,-238.329257,-264.772277,-233.73028,-157.501128,-145.394168,-140.816997,-117.128063,-116.143491,-161.853483,-191.417321,-185.336038,-153.304201,-98.340537,-74.176019,-53.603022,-104.408906,-146.421015,-193.509307,-162.647841,-57.72229,-34.792418,-38.82214,-76.670552,-120.528093,-247.856828,-304.595695,-353.805799,-342.07278,-229.762613,-145.463085,-70.756471,-192.474045,-259.735807,-238.530728,-149.998668,44.042534,92.643281,26.107686,-158.628808,-207.43265,-172.31902,-149.116065,-147.163234,-139.58972,-93.65757,-65.856754,-23.882,15.408136,21.187513,-41.299563,-62.464174,-7.03497,36.675615,88.347042,64.024022,25.376115,-31.683364,-32.255467,-10.176891,-6.602869,-4.885008,7.92459,4.128457,-114.574034,-191.794723,-235.173963,-176.005699,-34.665714,-3.90867,22.721764,42.657359,44.722142,15.63334,-20.821372,-52.553293,-22.540126,72.623118,114.149533:159.019389,34.15057,-27.169365,-67.47701,-54.789607,-35.707797,-14.247805,46.717836,4.084711,-41.41216,-117.985243,-141.001851,-142.88105,-132.330101,-97.830017,-85.917806,-121.625722,-215.449658,-271.651313,-295.811583,-219.679622,-33.051003,-17.510877,-159.647208,-272.380545,-255.032896,-216.407675,-228.673295,-239.943718,-234.193645,-165.077442,-88.228862,47.465242,92.15534,96.040371,108.310302,121.409328,141.891448,157.088361,217.041319,223.14495,178.283871,74.184575,72.68667,215.627753,296.940734,309.706565,236.992343,37.751625,-79.576085,-96.337876,-93.669652,-85.536032,-65.482174,-36.949299,32.793508,-71.409781,-176.462815,-322.466721,-336.156805,-308.122981,-299.366542,-293.999583,-276.12496,-199.764889,-195.262265,-232.06274,-204.44392,-111.085999,42.309591,63.415737,96.669907,114.93333,86.403096,-4.781834,-19.458578,72.429861,142.997455,223.680577,224.018649,181.390168,134.571739,96.632243,-8.912742,-39.402031,-23.213613,-2.861147,13.188718,17.534132,17.125473,-9.726701,-38.648855,-105.179743,-110.736411,2.058684,82.289412,107.403522,-16.381905,-55.827826,-59.156484,-53.429737,-36.690673,6.673067,160.39375,212.867666,170.449063,42.974168,15.326049,90.596483,157.749376,284.611661,337.465713,346.982185,219.627566,142.207519,23.453529,6.708902,46.013034,70.240565,79.602206,35.041433,-2.077336,-72.997592,-79.005797,-38.055189,-21.109018,17.310459,43.189274,17.909653,-113.994161,-184.534612,-270.086549,-246.30255,-69.429939,31.902784,142.624864,92.598328,35.503616,-62.143167,-81.623311,-41.191809,18.603687,161.434077,207.934269,231.60947,191.251253,150.897374,61.853863,34.959478,51.654861,93.45229,188.376086,211.906726,191.037829,115.880501,93.321573,132.47112,177.612874,268.078518,291.002827,237.156465,128.736458,85.62623,71.988689,116.36397,176.146663,154.805478,74.130879,-28.540091,-88.438185,-186.879914,-200.278898,-119.347268,-34.713299,141.793974,189.170803,160.306395,48.555799,-20.331644,-90.794818,-30.616314,190.914669,250.413177,276.449538,316.27797,302.465225,168.041455,102.767281,117.90857,177.058153,287.287516,321.924062,306.403551,176.235063,97.254371,-14.697028,-40.49964,-45.730254,-11.152995,82.768653,29.783366,-31.486653,-128.940678,-157.787437,-174.13118,-161.233062,-4.221719,124.483813,227.684708,92.769473,21.42422,-59.566012,-66.991241,-15.892501,42.219508,156.993307,105.510208,18.168038,-163.085082,-216.165921,-170.629402,-84.088044,109.517863,182.03024,190.558087,40.74411,-40.891912,-114.82194,-88.730864,-9.357868,0.258207,-29.456108,-55.334963,-65.13447,-107.813692,-100.981032,86.375961,217.034248,328.467729,295.852307,173.696742,90.195477,68.689813,41.174383,32.414119,49.643593,84.251156,147.24783,124.198893,97.009456,14.65523,-46.121361,-105.179258,-53.042907,114.150701,131.297877,44.632444,29.524613,27.695144,-12.68792,-7.02323,71.779937,110.500574,144.183918,111.787597,81.552282,21.9023,14.707268,74.98699,124.34517,224.199214,252.588592,190.815466,18.153335,-49.952673,-63.424092,-18.385042,90.757927,145.031407,218.570764,169.847118,129.678996,97.826162,96.42809,127.228959,184.318991,368.92014,444.103114,421.237794,211.194958,97.327717,-24.928314,-7.514677,141.586745,245.54589,419.450335,420.735755,360.336455,195.82107,152.518339,246.356005,345.003166,450.908689,417.23366,289.050906,239.635089,205.261666,65.255925,-4.930752,-86.018799,-70.59609,76.740199,101.503963,5.512853,-233.862862,-291.420979,-255.098876,-209.774305,-114.671686,-70.004477,-63.979531,-189.558357,-273.98995,-358.038263,-316.974939,-144.704269,-68.004267,6.294242,-32.444857,-78.87037,-163.285898,-171.657911,-72.588901,21.190134,187.250628,214.838605,138.647454,-7.891099,-74.361139,-128.205268,-95.738595,43.49938,114.017337,170.51677,85.66264,-6.967598,-230.501919,-294.355786,-248.282042,-184.956392,-95.724195,-72.692972,-73.856692,-140.031856,-166.912201,-127.991384,-65.045491,49.938737,70.745061,13.447814,-113.178326,-147.911631,-154.500512,-153.622003,-130.419435,-95.980128,5.353773,64.401286,166.678264,169.37567,131.730248,50.133311,32.649834,54.202703,85.181475,166.16006,185.17739,142.165589,8.829722,-40.402194,-46.282393,-15.237619,67.810109,100.552837,46.329906,-116.910689,-161.821964,-144.656919,-110.25695,-46.932821,-19.300389,36.216366,42.19813,17.170677,-77.637136,-118.401118,-104.76476,-56.179435,81.226026,151.585236:185.366666,80.160612,25.389091,12.189103,48.550862,73.594419,38.228963,-30.571279,-70.451448,-109.278656,-190.851211,-201.474169,-139.897566,-104.406785,-122.414097,-169.041011,-239.935757,-182.771224,-128.233595,-43.713903,-9.03834,-9.605695,-78.683137,-234.910779,-228.861618,-192.058816,-149.800325,-144.501187,-134.194785,-136.873943,-132.880577,-88.928226,84.13213,230.144685,239.034028,144.728539,98.186357,55.019403,30.162873,0.515786,38.791337,48.017613,22.92419,9.63739,73.575524,154.718096,285.657829,280.233928,134.236543,7.956221,-15.362817,-31.168811,-23.86692,34.166868,62.229847,73.180942,7.880723,-50.658409,-145.735035,-144.072818,-60.575052,-50.288123,-148.387525,-184.887091,-158.121246,-118.362237,-116.61851,-117.82496,-98.142489,20.090049,101.52705,180.213271,93.800744,32.681503,-16.510612,17.25608,209.087203,315.712066,385.469042,372.120251,370.152823,349.196119,307.851582,186.892063,135.589271,105.111166,121.004841,176.869852,207.694423,194.667006,105.293275,47.566002,16.249675,54.701056,117.147417,123.04554,108.51899,58.808324,54.354677,60.017143,37.188226,39.471758,94.002001,179.007241,133.132057,104.962524,100.128558,115.564576,224.592539,312.434797,392.586614,359.368023,264.63209,221.720582,195.293272,78.055784,21.01487,21.488241,57.02397,98.316661,92.53866,82.420379,76.079911,89.103674,107.290975,104.44757,125.536763,149.755514,148.319111,8.360182,-100.372827,-211.144219,-130.626739,167.650235,242.20284,209.577065,198.008779,200.213359,148.974437,116.159502,100.492401,118.393104,168.922121,198.90086,270.584996,267.828311,215.083619,91.590746,67.359414,68.919013,72.701946,106.539354,116.341442,102.50702,72.918946,51.023786,34.843958,81.767794,236.065452,270.133068,238.215442,230.69618,215.618473,79.533126,-15.087105,-140.198131,-142.493039,-112.448703,-201.514144,-263.197455,-307.133949,-298.889998,-253.530697,-200.671798,-57.851353,-3.751436,23.609543,-24.101834,-54.632094,-66.661533,-18.046332,148.503939,232.494347,397.967454,461.660734,408.719728,233.089703,173.481997,156.161599,169.362038,199.233639,239.023808,320.839394,258.950065,187.027693,85.081263,83.950454,141.300972,172.948232,200.206808,115.812379,58.521971,10.116136,7.255013,-9.75193,-30.769167,-32.017596,26.105498,143.991701,93.433785,60.363236,43.70568,41.331057,36.116539,24.180985,45.09919,136.711401,119.993059,-68.950818,-159.988535,-147.816483,-47.077988,162.723612,214.570209,185.278999,85.749128,69.40338,68.813762,49.596275,-8.680072,-21.523535,-0.840257,-26.586929,-86.194248,-175.420538,-150.482615,33.154419,139.523995,202.334009,154.236372,64.81155,69.445446,57.690047,-19.28518,-40.015036,-12.386613,34.507036,171.457846,171.795454,119.126311,40.975639,5.193491,-85.674173,-108.19775,-51.900443,-4.784662,12.347436,-42.419895,-67.079922,-96.689987,-89.330728,-6.336358,47.164475,102.835348,94.438416,103.579451,121.566293,95.319587,20.081072,-1.605281,13.726215,46.544905,65.426927,-11.494887,-39.763871,-39.761099,-10.841339,56.303112,49.554389,-56.222434,-149.513766,-142.586088,-81.281456,-83.286504,-89.610272,-42.382889,70.091264,92.39292,64.688065,-85.443809,-167.464672,-208.107557,-168.702222,-52.328973,10.9626,120.586959,101.466636,26.594119,-143.713154,-164.55921,-6.608756,105.90536,137.359991,56.089389,-48.144816,-6.694195,-6.469032,-98.473103,-132.579619,-85.014188,-32.442634,54.478628,74.380202,50.916314,-71.61201,-151.781616,-227.468562,-185.886261,-22.09453,26.231494,9.541143,15.834643,46.032554,3.489067,-63.981569,-89.130155,-28.673403,83.678496,41.75794,-28.771926,-192.779394,-247.38099,-226.529605,-172.865245,-97.169659,-76.037483,-51.146724,-83.648976,-111.738342,-148.132106,-135.412088,-61.064977,-18.189991,59.035568,41.255219,-15.920868,-134.242968,-174.194998,-258.635072,-289.527645,-210.890656,-117.59857,-29.514886,-107.287269,-136.363116,-114.985402,-72.189327,24.494586,48.665341,16.577692,-89.914599,-114.174005,-52.78356,-25.844751,-31.847259,-31.552466,-28.979496,-26.084981,34.332755,117.213032,106.148369,-42.780356,-91.20015,-30.763173,12.535988,34.288851,22.612538,8.211782,-52.21715,-95.106341,-150.774316,-129.290719,8.426395,67.383534,34.530197,-139.491338,-216.81786,-267.137458,-236.85524,-127.136712,-74.704042,-5.054674,-0.284877,-20.802332,-67.60214,-75.782925,-67.897696,-57.650157,50.613316,143.280245:180.087215,31.219995,-46.74468,-136.355224,-132.500567,-59.872188,-15.914435,3.057788,-114.95924,-186.974141,-294.957913,-316.923006,-275.769893,-249.486897,-227.612638,-217.310706,-239.190391,-329.552903,-358.626196,-306.748319,-231.982824,-104.772004,-95.603438,-148.525693,-198.412681,-202.999388,-191.606601,-185.776249,-165.917633,-145.383212,-26.011949,64.075424,176.705002,195.462292,201.850199,206.087111,201.402138,184.105216,175.374276,170.486301,179.450304,184.115501,180.570897,188.010738,269.157609,315.366935,345.365065,331.552189,205.120538,15.128826,-27.127697,-42.961486,-39.498073,33.289191,85.846658,110.130107,-38.162658,-133.390523,-240.133123,-238.411735,-185.856043,-165.713087,-141.129401,-142.564366,-193.279978,-215.044392,-209.971647,-177.920045,-108.49217,111.551867,178.871624,140.041472,-11.323616,-74.020271,-78.678805,-23.631443,137.364288,222.364465,339.018753,356.443729,312.816215,207.415267,144.41858,40.234948,31.529023,107.869759,156.549495,178.148301,80.377897,16.152219,-52.463843,-41.357442,46.139582,98.264024,169.450212,184.142402,174.575599,124.125823,76.308207,-9.748382,11.066891,173.937974,238.931573,226.597926,128.745474,94.373401,68.761163,81.255282,183.418906,247.362482,301.637124,295.946091,245.202658,141.990189,97.176706,45.957457,43.243983,79.139505,93.659889,95.864074,103.861335,98.738518,13.936192,-40.820509,-35.341375,24.415117,136.370898,149.786328,39.153869,-170.738451,-245.052645,-235.6139,-145.024455,75.824598,148.93753,213.639688,145.507571,75.832893,6.222328,1.611116,-4.799331,23.307962,178.423404,261.192684,311.586337,226.395454,173.084265,89.168677,67.092626,85.857841,122.865024,203.721973,217.507561,187.672286,112.37079,108.311538,189.556615,229.046424,262.230123,287.260659,353.035568,297.558647,215.770067,98.771601,82.949923,30.525855,4.144606,12.593715,-58.014314,-152.580034,-331.869161,-361.57141,-250.03154,-149.714148,-10.888322,18.582867,8.657263,-124.994908,-195.776444,-185.569224,-96.526646,113.483527,194.943906,329.983786,346.891055,281.912838,139.428836,105.109939,134.380303,186.15992,295.340849,346.024283,365.25966,167.060073,55.073046,-2.873936,32.803331,104.56865,133.87722,165.062465,85.494952,14.947258,-122.273981,-165.48691,-130.043198,-60.57292,88.436282,133.125323,86.500608,-54.263472,-89.676419,-86.893886,-69.945609,-27.412156,1.625443,86.518123,63.269785,-16.766056,-170.810266,-185.148564,-81.298311,-10.761518,111.989354,166.641854,186.304725,101.96751,59.095399,-23.996874,-52.862412,-31.621382,12.198644,67.014989,5.767963,-52.538088,-153.426916,-154.316528,36.595507,184.4308,309.429831,264.717657,164.827244,124.065772,82.267829,0.966908,4.972398,73.575518,105.915369,176.258668,204.271518,156.312513,-13.151937,-76.425677,-80.16684,-43.557363,3.689101,7.29049,2.909724,-8.438262,-27.49131,-78.130554,-69.202776,66.678194,153.824842,221.251177,119.016528,65.521558,42.146038,51.289605,60.797094,72.356313,150.386666,198.163509,163.104703,-51.080027,-132.039089,-138.364492,-88.938583,19.164006,39.489698,-3.491528,-13.604817,23.985783,90.79955,86.786127,81.72232,123.621939,270.705977,321.814448,225.157021,-58.317086,-146.88112,-128.032487,-52.521629,122.618956,190.151221,267.755579,279.775626,254.744407,117.73356,48.649987,88.809132,192.736048,346.428646,326.372021,165.776764,101.826911,107.483194,80.29627,58.699958,62.058752,88.528389,171.498921,157.873386,85.210181,-78.222319,-120.777261,-90.11743,-27.138981,127.710776,183.542433,182.665334,71.070717,5.083272,-72.81205,-48.711858,73.460891,120.121312,146.103522,67.890768,7.594012,-70.993447,-61.565421,61.227335,138.909954,236.119436,257.943933,261.20762,153.020005,73.118576,34.83474,103.251995,226.620287,233.252569,215.791764,144.15857,56.180475,-148.016131,-203.52291,-181.275431,-130.451723,5.824719,68.957473,71.928369,-60.26395,-108.996089,-112.13453,-70.986459,38.765528,83.602045,120.332458,0.84054,-75.945154,-156.275391,-175.700602,-104.966201,-1.677267,161.740913,186.972887,196.619829,167.492014,128.014451,79.693048,104.072653,149.244419,129.572666,77.342707,52.321149,27.796644,-46.434033,-81.552798,-73.951929,-25.102354,64.452597,74.589886,22.768507,-70.125849,-112.809855,-164.755059,-154.259403,-44.418953,30.494412,118.423771,90.752826,61.861495,-17.571959,-62.819322,-62.848802,-12.217481,88.499271,122.710028:-64.999625,-49.372162,-26.60571,-61.313645,-123.222702,-201.551843,-192.19074,-184.390744,-259.176027,-272.76504,-247.491019,-265.862075,-328.807519,-312.13533,-187.327225,-126.702633,-70.762398,-23.383787,5.314953,28.106974,39.332861,8.209789,-57.444469,-108.372595,67.278929,165.91422,247.205722,232.015727,161.843594,109.522922,-19.769505,-48.293955,43.97562,191.821021,196.239728,38.576298,-41.245807,-42.90702,-7.029623,31.148945,57.422118,72.729122,126.451637,145.557395,136.562968,144.173471,214.843811,240.223869,213.841748,188.85298,178.291401,56.714012,-7.240104,12.103325,69.665553,149.487118,101.378344,66.609969,67.130009,81.658331,62.795117,14.510241,-101.954917,-122.102887,-82.971892,-58.012721,-64.835896,-52.542492,-18.188245,37.705356,33.585571,-10.879948,-28.755182,-22.29933,0.272731,24.214101,128.709994,206.735396,370.84829,436.227125,490.722472,414.067488,345.056381,170.703769,85.195464,44.061342,82.239807,148.217272,214.970712,230.191486,163.685127,127.026519,161.77037,212.767006,243.867709,221.070014,199.171132,155.818042,103.52778,-8.969291,-37.553366,30.607211,93.785153,114.21636,41.335093,44.57334,116.690837,138.482512,182.64043,227.011996,265.51926,239.587864,167.095643,133.216457,114.547412,17.711613,-29.874542,-16.077288,26.33679,83.028608,138.627928,187.26731,253.706407,235.047925,197.259781,230.937041,309.032945,305.031971,220.965565,156.075649,162.67422,195.596837,211.11464,283.924564,334.789348,402.807183,370.519276,326.085099,209.348783,158.243458,141.261592,147.489083,113.372445,115.119657,178.711518,117.091452,37.818454,-28.561431,9.501272,80.088168,91.963639,139.331316,181.920713,158.719741,25.264681,-39.570508,-62.915892,-18.620514,75.623209,85.190202,63.946401,92.462473,107.85373,35.832008,-43.041305,-196.186979,-248.741234,-265.485175,-213.404035,-203.119446,-230.067296,-249.678485,-245.965713,-217.139634,-153.249226,-139.266467,-164.39333,-226.906523,-252.875089,-289.323673,-288.651787,-175.208108,-71.022483,121.840906,138.751425,59.814112,-110.704164,-152.865825,-178.83627,-176.460657,-134.407907,-100.026711,-69.955423,-101.84839,-103.128998,-64.803412,-45.012953,-10.426638,10.906647,56.342266,34.086304,-3.049969,-47.373154,-54.17254,-60.15846,-66.639444,-102.093307,-99.096695,-24.249743,22.346885,50.534219,142.501259,165.953067,132.793681,108.799064,102.815105,141.86616,157.529051,87.925929,9.590022,-31.181252,34.922914,182.079257,203.48815,152.215927,185.494544,239.73855,221.907813,147.616942,-19.922955,-99.938592,-184.740787,-185.28999,-206.363735,-261.668578,-261.265791,-187.250614,-132.014025,-55.320994,-45.994216,-33.813861,32.446382,52.564242,23.906093,-8.39371,-56.346263,-57.0962,-5.096581,48.933118,55.949655,20.15537,-31.678842,-153.816445,-179.479587,-133.841492,-103.47839,-114.292915,-165.131634,-176.954191,-208.328363,-220.066849,-172.022097,-121.17067,-47.140991,-106.787123,-161.581671,-193.198799,-178.236588,-189.439157,-222.661707,-249.339722,-223.358329,-178.100475,-183.735236,-165.07207,-54.200928,14.382375,45.425226,-10.962229,-121.225035,-159.022719,-168.22626,-133.342058,-110.170413,-99.945226,-88.25028,-20.318843,36.9028,167.316394,146.830004,66.266856,-43.926293,-10.669628,158.651692,227.792821,274.407891,203.355281,151.547896,90.231298,102.091501,227.704103,298.972449,317.627858,260.058773,148.8991,154.401886,149.804105,60.135368,45.044109,160.883445,219.774966,252.181457,270.42349,260.388193,130.47397,48.783697,43.433221,140.279586,382.494511,451.896452,422.067822,354.210575,360.679797,336.606334,297.942418,247.646161,229.710818,207.264798,162.565713,105.156156,-20.41632,-58.952668,-46.782152,-5.004399,44.978413,39.022188,39.187234,41.222876,17.645631,-27.403043,-7.165082,119.08395,193.438479,303.359972,314.525078,296.596936,241.622733,190.456992,58.974377,10.127692,-8.809007,28.128706,126.45402,85.240437,29.175439,-11.416592,10.932355,83.408707,108.521753,111.330578,116.437346,148.560317,223.757479,220.295304,156.788856,125.313456,37.47788,3.395057,56.414205,137.077631,110.642768,-24.370277,-53.811184,14.560995,51.131332,23.886457,-58.01155,-76.510869,-89.908821,-112.561865,-145.577893,-120.188787,-37.298358,-8.959615,-10.249895,-166.819457,-269.360639,-334.473041,-285.903228,-149.266749,-106.449262,-82.415568,-69.687372,-62.835168,-88.351782,-103.997593,-14.77154,84.441859,220.239405,218.428384:137.204454,30.875578,19.571979,41.2167,51.862823,17.369963,-25.12911,-58.024211,-52.832837,-87.084615,-184.131322,-202.842265,-159.348898,-122.415995,-82.726373,-85.23423,-80.659968,-30.209978,-30.236818,-84.131488,-83.232731,-41.991256,-42.253174,-55.251453,-79.628496,-102.184937,-76.157882,-11.520113,100.326864,89.945537,26.61307,67.217958,257.207065,329.460912,292.826299,130.64465,46.299388,-19.672142,6.150377,57.897214,16.270261,-6.199916,12.382758,46.514216,134.119593,184.427686,267.385325,281.653735,236.352589,140.658419,84.248446,-46.667608,-65.377789,28.655003,72.632961,67.014189,-5.670656,-23.92237,21.19109,46.301968,13.887864,-16.934142,-7.235068,23.737941,40.287128,36.740771,52.912356,36.953255,6.718651,16.089186,66.48143,132.867389,43.450284,0.464231,32.193152,75.774626,149.534932,180.396062,230.071242,269.353833,364.552314,346.160117,286.200606,136.087944,87.186333,97.050967,127.120184,185.732086,221.256535,208.97295,200.899186,214.028083,208.140077,183.981408,98.299675,68.994479,68.325885,-33.575195,-110.945733,-171.059265,-148.908195,-66.142346,-16.648292,57.337514,49.721141,64.76927,178.252227,234.972154,294.951796,310.847169,330.679832,311.789772,158.836112,9.442184,8.088451,62.526227,58.240319,7.960148,-1.25947,33.582683,159.476311,233.975946,276.770186,240.268754,149.856743,124.599804,102.878691,102.031156,117.726761,94.310596,77.996392,84.674836,118.448266,249.679382,308.434036,375.575437,445.050039,459.260911,359.292007,244.771801,51.986996,41.881909,121.969212,146.633922,110.757284,13.225737,-37.509255,-92.698229,-67.532635,54.378734,100.260859,102.18127,25.415899,-34.201579,-169.176111,-200.306953,-79.782534,35.691635,161.629459,163.83474,180.959642,198.936468,149.937241,-45.64722,-124.252348,-183.944749,-207.227245,-281.199475,-320.387697,-322.134815,-337.227681,-349.776525,-314.552129,-259.259183,-150.060817,-107.610972,-3.920465,71.793525,40.299866,-97.486671,-105.45698,47.977528,128.295266,200.375414,240.704401,246.633255,160.683064,83.885063,-3.695377,-9.026653,-47.210648,-59.994466,18.83403,50.260906,5.310623,-66.280006,-53.464237,27.989896,66.927912,101.831093,6.241654,-63.090689,-97.161144,-87.17523,-123.874707,-146.052936,-87.968398,-10.494851,86.013139,50.278737,48.817207,98.518882,100.985743,12.824816,-44.886103,-71.982723,-9.590187,9.131741,-50.853853,-113.105026,-125.056461,-53.875691,101.149562,145.354643,160.411828,150.92738,146.538993,68.234062,0.017745,-101.316901,-127.70898,-186.130342,-207.280712,-172.130047,-121.294098,-146.924498,-142.228224,-60.72091,78.775007,66.325182,-23.424029,-69.350424,-106.056003,-155.032383,-136.469326,-97.873959,-87.493797,-28.021351,3.933149,-12.509761,-33.567491,-34.375771,-50.246885,-56.169836,-13.679561,34.389603,83.883093,-11.242174,-89.442035,-190.245125,-188.16928,-125.501653,-79.877423,43.860343,118.172775,114.864049,74.46058,41.767126,-18.215305,-25.678873,19.949229,62.107223,68.368911,-42.073974,-65.151538,-9.26655,29.676664,74.110141,75.911567,32.800978,-11.792101,-5.256141,3.192461,-32.660717,-110.38554,-105.995458,-2.424887,66.218516,104.350358,-28.860595,-109.825052,-178.527264,-136.400238,84.883012,197.106919,263.081371,173.424384,116.757667,16.591848,-7.944185,53.283754,117.132157,170.500307,146.827856,79.90822,90.522196,94.320357,14.85175,-20.45204,8.947933,53.818431,168.449106,231.063792,200.671405,48.454909,-38.669888,-126.535402,-93.381664,85.814671,175.358596,219.234343,136.91944,122.2615,157.380178,170.92824,124.021446,66.120778,-0.82454,54.08429,59.180603,-75.804074,-180.478483,-289.05002,-279.284378,-242.660836,-226.680892,-205.888618,-254.926289,-255.850839,-148.501153,-82.371188,14.796261,60.300497,160.578182,184.994537,152.118907,31.26728,-34.228378,-101.208386,-106.47015,-104.995952,-84.600129,-11.556894,32.740072,33.623868,-3.613245,-17.453857,45.77065,100.743236,122.766468,35.063798,18.338938,83.724053,109.031859,96.798177,90.93986,59.621082,24.690817,8.682497,45.140311,40.360791,4.507529,-6.171461,-22.615862,-27.843618,-17.688372,-28.45268,-56.698497,-149.69851,-206.240939,-254.311907,-209.336401,-39.680578,24.804092,0.791176,-201.281083,-285.118345,-322.894257,-307.807087,-262.087542,-220.508283,-114.762825,-44.447031,-36.485218,-66.896628,-65.954262,73.606958,164.938001,210.902672,193.294851:59.638863,-18.143553,-51.463019,-124.633316,-156.50074,-208.39096,-223.570924,-190.733873,-197.427014,-234.212728,-240.448883,-198.850194,-128.981295,-127.555936,-133.554908,-121.749423,-156.016993,-210.821606,-184.286049,-98.521824,-80.374685,-72.582063,-79.659095,-122.139283,-74.465397,-6.307477,56.852582,29.829229,12.916202,40.705746,51.260252,46.192454,71.828779,70.753558,73.962709,106.869712,115.701031,110.247801,109.436289,136.311526,187.584487,212.811237,257.981004,269.201787,261.410334,251.457739,268.284553,281.348749,208.032335,71.306453,35.510358,33.127124,43.289597,28.428469,17.53114,36.781503,-24.655188,-85.950652,-131.203732,-116.620009,-64.741908,-57.25529,-121.656336,-156.88972,-190.137714,-186.43822,-147.025962,-19.531515,30.367664,78.496701,95.611064,111.196537,0.991319,-83.796251,-113.114206,-46.463428,121.144368,197.284149,312.830441,351.211638,355.778097,215.525147,139.777527,91.232545,105.942417,118.713842,113.070318,117.374402,130.136177,140.702535,166.541479,163.10167,136.102861,120.861798,99.701282,122.499816,202.834992,168.00295,109.428365,31.333885,54.813901,173.577046,197.098533,120.795281,43.897329,41.933394,69.233056,86.094817,114.19303,109.915934,87.186476,99.434135,146.670459,159.285141,148.963409,74.327242,46.695082,91.251876,115.658791,60.38989,19.079108,50.407935,108.209356,111.342516,99.609316,90.086162,108.786279,144.499285,169.490644,73.567293,27.259412,25.755681,66.37707,174.855851,224.903453,300.969942,257.156518,198.294019,122.935075,95.686425,61.947785,87.441478,174.046982,185.37306,148.172132,117.661193,90.420707,25.079322,32.651636,119.654166,143.938468,139.751606,132.7176,121.123031,91.064918,91.432534,158.234339,214.2767,249.496115,217.530427,172.002017,179.327241,184.070472,156.343594,105.988611,-26.236467,-63.943339,-30.227551,-8.14914,-61.961551,-195.629179,-218.965143,-170.733198,-127.8124,-89.329108,-86.490013,-82.15546,-204.440103,-270.102923,-233.078759,-147.149656,50.175715,139.900803,243.685349,171.637742,103.842827,44.590276,47.749648,69.731226,88.81835,124.280772,149.096073,215.034551,192.357342,133.809235,28.293565,32.862573,107.842963,128.828137,142.35172,100.10588,46.724276,-12.341283,-2.039122,15.00429,5.440901,1.88024,31.62462,80.830865,-36.535182,-97.674806,-63.11874,-6.88347,58.737738,75.759463,97.263571,47.90516,6.785076,-48.024418,-52.880357,5.477447,55.121501,166.094977,221.567881,245.037059,162.137557,120.463696,65.798501,53.614652,42.458739,26.129259,-11.4492,-13.182228,-30.199683,-114.116418,-132.188498,-14.581233,81.290028,161.510706,139.96682,111.20597,152.904389,139.631179,26.765158,10.915342,120.901954,154.289441,78.611963,21.402007,31.398501,28.504092,-1.510496,-45.425243,-37.039789,-17.278681,-32.302262,-83.5466,-83.363536,-77.567911,-66.220608,-50.311849,-7.508937,18.885586,48.794444,13.319784,14.162113,71.666978,55.566419,-111.233396,-170.676156,-110.901264,-48.992528,-30.972606,-127.085011,-154.826159,-115.335713,-68.261393,-8.77821,-35.670642,-154.48164,-167.01462,-130.4657,-81.908819,-80.232953,-86.975359,-82.618068,-11.508267,61.913853,173.987384,66.841833,-35.333642,-146.004939,-123.825006,-1.824794,53.320145,133.567242,158.594153,128.655275,48.106875,29.772498,86.148908,151.648407,224.305793,195.810235,49.832993,-39.508076,-39.437775,-38.817395,-17.697865,95.502046,133.781046,159.461293,148.35761,105.7492,-7.719224,-48.328329,-43.787221,11.981589,174.433824,239.791723,247.271265,154.687224,119.729485,65.867679,59.107056,129.213199,171.517779,172.67132,88.506234,42.055744,9.936517,18.035541,-7.949968,-15.590108,83.930996,150.076631,148.252565,25.717451,-16.817875,-42.641376,-26.387765,60.166053,123.581207,247.247421,218.52136,144.052554,-23.294833,-80.911077,-98.689535,-81.817502,-48.584445,-15.024482,49.999056,20.599505,11.058857,5.147513,0.951767,43.783181,76.583096,87.359026,9.38151,-26.965399,-106.647626,-164.775458,-157.518573,-75.559137,44.747707,49.007282,45.191935,121.819825,155.93638,129.129208,97.169738,61.366831,53.458575,72.397936,91.572527,46.326505,-123.024682,-175.912929,-123.37358,-56.213762,26.829754,29.427395,-36.60452,-124.08363,-136.641308,-167.42525,-196.453528,-134.255808,-51.861288,9.482006,-46.582748,-66.308651,-98.074141,-113.630735,-88.911966,-40.792236,83.089983,141.682602:forward
-101.777153,-70.412937,-58.852024,0.123352,79.327226,178.225324,135.160876,-20.462691,-64.818334,-30.242694,73.504887,122.396555,215.281936,237.735096,206.242459,175.730897,147.819175,187.378717,200.633536,199.361193,226.222014,318.281251,327.253591,285.588285,319.926839,353.673267,360.666293,343.365033,325.896416,317.664875,271.11615,234.774608,176.107329,229.789982,281.690545,336.623837,346.176249,316.47709,235.625898,1.439564,-28.826711,22.012219,21.244786,-26.159936,-69.713453,-67.262819,-76.524478,-104.476338,-188.946444,-125.199428,-20.455145,171.864861,216.474277,175.366845,109.151731,30.235193,53.180564,54.88738,49.794413,82.895655,231.261407,295.512421,290.578829,230.738825,118.1515,126.357635,137.37862,114.802958,95.704591,41.623896,18.585302,-10.451427,-91.479401,-152.003853,-204.995819,-165.29717,-23.917645,11.089487,-33.895542,-60.763453,-27.264929,43.638136,60.871054,158.137424,244.681276,285.753672,218.654027,78.206816,-29.132122,-54.144026,40.96253,111.279167,91.253893,-1.35931,-148.8463,-150.008769,-97.675843,-108.807201,-119.513615,-81.708665,-41.62305,-22.102032,-36.853766,-14.04077,44.993727,53.475547,10.260443,1.211336,94.82144,145.08346,72.002292,-43.88937,-241.352455,-243.480718,-207.885216,-132.448138,-99.529504,-102.053829,-135.41912,-192.209976,-119.057316,-25.574693,130.888387,176.696261,231.388258,206.874922,49.054267,-43.44716,-225.505919,-336.224437,-319.926845,-149.610859,-52.695041,-5.37281,-57.348144,-154.20415,-128.838279,-85.432737,-29.052624,-22.971963,11.394485,23.108404,-30.67355,-72.624121,-115.304438,-105.568307,-87.30728,10.008275,82.958676,167.31495,152.073202,-2.668287,-145.043149,-100.707467,135.44666,221.182963,291.337447,320.964588,306.74773,217.178355,-1.849079,-49.693889,-28.031542,9.677398,-0.415253,-121.920311,-202.825792,-295.673747,-313.321135,-306.405214,-257.080709,-223.755459,-180.630049,-181.350366,-204.66934,-214.848443,-211.831174,-176.737356,-136.886302,87.130852,243.462655,343.474067,241.919252,-16.159091,-64.776677,-34.695308,15.774351,45.720592,155.023286,201.806064,197.439193,156.858952,70.907401,86.250165,137.630267,231.702435,238.961586,161.732236,102.560404,-41.568897,-122.188232,-83.391004,11.658574,28.48028,112.817994,151.88175,40.016522,-62.818873,-105.354325,52.873139,123.588437,211.923119,243.697604,257.342767,230.317624,95.731494,-40.232897,-51.494656,-13.271861,2.43253,33.028685,40.3841,2.700427,-31.544547,-96.442576,-118.534453,-91.691252,-17.48425,-18.718324,-124.941499,-185.464573,-253.190143,-251.740804,-197.366122,-45.566084,-16.002191,-69.438447,-111.884807,-172.200108,-188.034759,-196.291771,-136.827046,-91.801463,-47.094441,-48.790338,-103.415617,-150.11217,-215.837261,-282.753962,-316.11257,-327.458381,-301.038569,-213.948631,-178.377676,-126.758317,-124.166361,-200.271526,-177.903961,-95.602482,83.285391,141.812646,149.184008,109.573271,8.790686,-57.075088,-39.992753,64.683283,129.217178,285.817644,337.17973,278.588913,188.00911,-10.776388,-92.59244,-78.136781,-11.948457,19.435212,-27.16252,-114.816216,-237.038202,-150.192361,-48.485249,134.693789,186.605843,253.161527,260.862491,183.635903,118.092056,-4.293801,-112.344915,-153.539881,-133.611398,-81.460229,-58.995827,-100.077612,-152.327138,-135.820096,-120.627783,-72.987407,-20.667046,135.733139,193.669343,235.69011,236.788165,181.847962,130.65493,141.271122,200.964767,219.290996,166.399271,117.806479,76.482318,74.404667,53.132204,7.956899,20.608195,87.36283,96.642716,42.569968,-12.371298,-174.206132,-265.867906,-237.164848,-86.597909,-9.193455,69.317016,61.922181,-53.751451,-217.151913,-243.758194,-202.495169,-179.437615,-136.156311,-109.492125,-109.822469,-155.688604,-251.525462,-202.391269,-139.200498,-33.051094,0.96564,27.809901,27.813823,18.870907,-45.218501,-69.53386,-30.708749,20.268095,82.031256,38.922573,-127.531325,-155.803323,-80.07683,-43.489309,-43.315683,0.400989,23.49212,7.888714,-29.788758,-134.033409,-158.884686,-125.521479,-52.710938,-19.85051,60.991175,88.276382,72.493624,20.444436,-118.299215,-133.397406,-96.039629,-46.434466,-55.331782,-147.739922,-217.475035,-334.298546,-384.58323,-370.591341,-300.846657,-268.690282,-205.392024,-177.223778,-156.282659,-172.555929,-228.289453,-221.303214,-199.903941,-186.337078,-207.607391,-292.721491,-316.187344,-332.246451,-419.224964,-440.145018,-389.731825,-357.893274,-317.361076,-312.592508,-334.921693,-341.926389:-192.903553,-106.119989,-38.028601,91.109769,125.364685,119.14521,95.246633,30.894848,-27.175869,-39.547069,0.320336,67.103163,207.031317,225.314139,159.648151,110.222105,66.249143,151.568171,205.275734,256.758466,258.373218,248.784815,252.787557,280.706017,282.377303,264.845457,224.738704,216.394548,260.17318,296.23151,237.616656,135.911873,20.394739,184.511134,303.08955,428.767754,411.943083,280.407198,186.553319,-19.289098,-82.233256,-72.264878,-102.096913,-106.054961,-48.451339,-42.490813,-70.326042,-64.534406,-23.812461,71.481858,141.44941,253.403444,285.727321,264.803399,194.309151,32.804251,8.988098,24.454156,63.005089,112.774369,232.725543,271.64938,285.762673,253.082625,176.045368,170.862008,147.734115,65.040703,44.375736,18.314465,-0.113628,-50.93676,-102.9852,-108.542046,-96.257062,-86.296121,-58.178912,-71.913308,-148.592928,-145.997919,-23.995631,84.637008,103.204236,155.102873,216.774121,318.015614,316.924889,195.860313,-7.511956,-58.477515,14.891359,102.424236,200.949421,164.187479,-4.464621,-84.429447,-166.699444,-101.059672,-26.30831,110.358553,151.519276,176.96438,153.44561,33.799019,-11.412459,40.679501,151.4096,158.823172,101.811852,65.430675,12.031253,-7.42196,-61.163759,-115.173212,-106.989117,7.495772,51.767907,-26.840257,-100.689366,-141.157817,-35.745504,45.192108,226.313513,308.091191,320.303632,232.348506,4.779337,-108.267396,-285.760627,-292.261404,-223.934946,-26.494152,29.619515,-31.4498,-98.108211,-201.710973,-233.915085,-177.273759,45.793876,120.922518,37.600899,-72.970548,-224.396139,-251.927763,-239.677434,-161.332784,-116.915168,17.38673,88.103881,91.93948,39.644706,-81.361106,-147.911951,-110.353038,30.497411,108.89302,328.981299,410.982238,330.197076,212.436375,61.040269,45.55943,49.726572,120.874989,149.326836,5.535522,-124.595982,-276.998834,-274.467612,-244.142605,-170.636511,-145.318871,-132.71577,-137.751393,-109.558352,-80.036262,-71.890563,-104.218016,-91.05473,78.7471,209.720615,314.250494,238.070361,29.545402,27.572695,80.14932,157.067551,190.631395,245.948973,244.506707,193.542176,145.564436,29.878497,56.838884,124.759962,202.65887,187.674832,133.055123,118.014398,28.14523,-95.494762,-92.025022,-17.611455,4.941008,34.135989,38.017497,-39.134171,-99.831744,-107.950569,14.83568,54.155167,77.603157,86.886378,100.209306,76.544538,-78.527199,-214.149572,-217.419814,-166.467689,-125.436287,-9.553554,17.553211,-91.58273,-201.862301,-323.858438,-205.70698,-121.697713,-41.533495,-69.917578,-250.403275,-344.103727,-413.83424,-322.296532,-247.530779,-183.881668,-205.553526,-248.583943,-230.071726,-146.435095,-142.59292,-237.270416,-292.28465,-275.755937,-223.545719,-200.88835,-183.171936,-206.118089,-300.537522,-357.305267,-330.576537,-270.687652,-275.702979,-224.146472,-141.3872,-36.960624,-72.389715,-165.801796,-70.693086,0.869132,74.923076,92.918223,137.847918,137.839927,20.911613,-67.074174,1.386441,280.8896,386.831167,431.549293,411.456993,348.333418,281.615222,129.568484,127.662036,155.554347,160.352411,140.656734,53.390287,6.463884,16.465676,118.486539,163.936995,269.278745,331.465228,383.431128,356.744827,253.669947,179.203949,7.400343,-41.546068,-18.857283,27.678625,35.356349,27.363533,17.429457,-52.809688,-138.954949,-112.100317,13.944137,58.741729,141.790432,182.8197,229.260414,223.142542,132.084599,81.527445,121.107198,277.702148,334.557323,274.127711,184.780107,69.388056,47.396467,34.172305,42.117856,86.849579,157.862419,127.504503,9.084128,-18.111695,4.176898,65.03049,86.613257,112.150765,129.340473,167.732217,181.794798,133.853112,-14.20528,-41.296579,24.843748,67.092463,137.865058,139.153663,15.851295,-63.387966,-134.016104,-65.462982,-17.580857,61.130994,103.114752,138.385264,109.725316,20.464878,0.511669,18.640813,50.956824,72.128833,104.0908,61.39091,-134.352554,-210.173165,-223.466724,-147.631433,-87.036731,84.143539,129.384495,19.743917,-80.028262,-205.683562,-182.70398,-114.07607,50.615375,99.242878,119.71906,125.839935,130.720437,74.569017,-134.315815,-198.514631,-148.076253,-8.609542,23.15463,-106.04535,-233.314554,-354.219486,-190.974601,-88.80625,-44.511142,-93.187651,-181.276017,-187.051683,-161.546833,-152.586341,-157.194213,-201.039762,-216.650993,-183.212132,-164.563165,-226.276137,-284.990786,-406.549168,-468.915581,-441.082545,-331.157109,-275.14321,-171.728439,-150.99212,-229.839593,-298.576261:-65.962435,47.492755,149.953129,267.468711,265.075782,157.476926,58.58999,-126.605519,-87.40225,2.790378,124.066499,144.725022,156.853169,128.095545,20.218844,-19.930425,-30.150701,69.050929,137.902823,196.317834,164.694917,55.117624,19.609337,34.245505,130.272873,118.931785,10.459563,41.581419,250.478299,289.19654,110.325945,-22.288639,-126.031919,17.175725,114.938516,236.144474,254.477845,181.585403,55.111018,-299.280921,-387.699404,-300.036599,-141.275896,-126.495154,-132.08378,-133.346641,-177.032611,-196.140637,-101.863857,71.87443,109.964456,129.753947,156.050121,209.87054,172.382515,-51.362887,-103.60405,-7.851673,188.773918,229.828873,252.708622,272.133234,294.118718,259.615101,166.666007,96.518281,59.456667,24.752567,1.663821,-86.510947,-110.088016,-129.013927,-170.782148,-164.829633,-85.549689,-45.744576,-35.603339,-58.68789,-112.689833,-130.419093,-80.955614,64.112639,109.079073,80.705724,46.486158,85.028946,155.323891,141.957097,-55.120013,-66.134661,82.664054,148.690994,196.760086,200.63273,140.92091,50.893627,-126.567468,-66.204005,15.013459,105.52156,113.843663,123.675453,113.343511,-4.849278,-151.156154,-142.556786,36.097338,117.281397,116.823488,65.89735,-30.501708,-76.32449,-168.246461,-161.751908,-109.129207,-13.9959,-27.285936,-116.12985,-105.789835,-17.291517,-8.464656,18.677787,159.427386,232.917791,246.732653,143.417893,-147.81222,-234.069075,-199.541877,-73.264303,-36.880155,33.249152,72.803255,85.849825,45.840445,-95.319043,-174.200019,-126.667934,10.722404,17.531052,-26.08733,-38.12878,-129.613818,-201.819579,-227.396103,-99.973315,-45.646367,44.062868,81.206154,80.719911,51.860069,-27.908904,-98.017658,-91.203622,-20.134432,45.226025,244.306448,315.353506,306.604533,255.977188,127.475378,9.119317,-13.458039,24.301372,40.493316,-10.150236,-75.062312,-218.305888,-203.6695,-129.809628,-17.447949,-1.108641,17.132632,23.988202,12.997087,-7.062908,-96.467743,-152.740636,-113.441662,52.854186,125.437811,156.387619,98.52845,-69.432932,5.556704,101.078851,163.61185,175.59413,253.976533,258.825891,181.60169,149.857821,88.003634,6.892334,26.021013,166.642517,205.925407,148.295997,85.480088,-27.910507,-32.987975,12.480435,86.550056,109.915245,135.494176,101.500873,-36.81071,-87.844366,-81.908877,50.937671,121.981806,174.660726,162.649381,126.704404,90.180253,-65.571989,-212.168318,-239.513464,-193.522462,-120.201722,-4.57331,-20.985694,-130.798588,-171.848909,-218.465416,-203.701927,-150.512732,-19.115544,-23.135041,-261.195744,-394.847714,-463.2914,-354.074459,-276.471844,-166.520668,-170.318126,-233.949182,-246.882249,-238.241466,-250.143233,-328.36597,-323.026062,-268.366373,-157.912194,-138.412722,-200.963942,-243.398094,-282.450259,-296.602859,-268.961394,-170.79343,-153.1096,-150.547108,-125.880605,-93.261458,-121.861975,-161.509741,-37.132292,54.540872,202.657113,219.467853,101.431608,34.386663,38.020757,93.955994,105.746429,190.999457,267.976345,361.744756,339.54348,233.381911,202.665348,174.295778,122.490633,108.637374,164.407147,180.13512,72.938244,27.968405,97.886199,189.747386,189.732584,235.132932,308.68418,349.272339,275.585313,124.974764,87.749857,23.739698,-34.323357,-25.937189,81.222003,121.72358,71.650122,18.216805,-95.837782,-219.177365,-215.157724,-40.664875,65.947186,149.534868,114.83108,43.132249,51.386889,101.755026,163.135192,209.171341,328.37353,368.021977,304.454485,230.748974,114.701793,66.456092,90.67075,200.39556,234.544993,193.456224,139.000336,68.102426,51.083127,23.911938,54.193403,79.079009,111.275711,130.559253,207.890108,243.17089,147.701556,-13.360736,13.713704,144.15822,162.753556,137.328033,117.93285,71.076512,33.793351,-81.334274,-88.268756,-17.73193,122.099187,128.91271,26.281732,-34.596304,-119.968832,-135.206355,-108.794336,-22.441757,40.726308,148.085247,130.091796,-69.689397,-189.351472,-270.647046,-138.932674,-76.797696,-25.594546,-27.616286,-88.915376,-134.95497,-212.955245,-185.756176,-102.239106,103.282983,155.007008,175.260284,195.960702,174.982256,85.054111,-66.764717,-1.68875,53.413752,114.270147,109.747519,-2.937928,-71.614533,-74.99309,5.070445,10.791496,-33.643899,-54.788332,-75.388009,-74.512702,-60.703058,-64.420106,-61.272246,6.415496,52.720397,142.05041,116.092921,-132.430054,-248.255263,-327.26085,-280.235944,-223.264741,-66.865648,10.465728,91.295586,87.316498,7.399196,-53.469648:-12.102517,86.752413,140.635084,219.807273,245.356814,220.07444,160.401236,19.39383,-56.506534,-59.052525,-13.441387,18.701431,26.821761,-16.381345,-96.913793,-87.489748,-32.863396,-1.34762,36.09482,122.679301,147.116531,142.844087,100.192184,-4.283808,42.662974,97.200727,151.593795,168.950387,207.591847,196.654975,110.940672,55.692889,-58.176636,-40.920316,37.538546,195.000929,230.509038,171.82307,75.199958,-140.869015,-189.075729,-167.730767,-178.692646,-191.619301,-135.834495,-112.879471,-132.935775,-125.938346,-61.539761,20.493509,69.346531,147.540287,159.517846,127.162819,97.502659,11.096215,-86.597157,-92.293721,11.700664,86.425058,189.065827,208.131626,178.25926,126.819283,46.244305,113.494214,133.527218,22.024653,-53.321745,-110.287859,-114.501651,-178.814166,-272.809359,-274.204072,-196.283461,-149.749352,-57.880341,-27.468417,-79.325319,-152.026512,-212.688736,-79.997827,-14.688205,71.37219,114.546004,167.541579,163.302511,65.421477,-118.09228,-148.011698,16.387,132.135683,194.813123,139.214485,14.486528,-30.018088,-104.582062,-109.517315,-81.738292,-4.91824,26.191982,32.845748,14.844515,-35.534023,-78.182341,-69.333498,17.139541,60.286162,85.805741,81.620663,16.303987,-74.582279,-278.607056,-283.678995,-232.541757,-125.049558,-74.363749,-36.594731,-58.990775,-122.541313,-113.711851,-60.974639,86.297704,149.296197,180.771335,126.871611,-25.387779,-78.151249,-130.981598,-176.15997,-187.737349,-93.047766,-23.333746,5.928804,-14.073401,-56.609,-125.330777,-142.466691,-126.698718,-101.321249,-8.795655,26.56437,-28.655477,-102.771438,-202.313232,-144.177341,-71.9679,79.026449,124.936717,106.762493,68.793355,-9.179457,-49.119426,-15.924393,75.90682,113.051708,245.913733,320.144031,333.104086,265.159088,123.019902,112.569792,127.647172,105.031526,58.015866,-119.251146,-218.990808,-301.758732,-263.601327,-249.430909,-210.58656,-167.470106,-97.588705,-111.80524,-192.788601,-211.635997,-213.267806,-178.65378,-133.686655,-0.508315,75.602897,126.243305,63.607723,-84.850269,-15.034118,71.409033,182.413531,208.506946,240.918107,232.220104,199.136304,203.309622,207.868506,160.506628,144.967023,190.779392,234.812808,249.682971,203.542098,34.197859,-115.568599,-112.66168,9.788218,77.028299,162.931576,155.528073,51.787435,0.738826,-8.369049,128.851109,198.606533,237.488014,226.124126,198.444234,172.570091,46.309052,-116.159185,-141.431349,-35.639216,60.056439,180.695334,162.103488,22.021548,-49.271545,-129.994485,-136.885304,-113.804427,-15.084517,22.46462,-77.161842,-202.309625,-390.145602,-315.381327,-201.89378,-30.184514,-12.046435,-27.917683,-34.674973,-61.930808,-105.755683,-226.55541,-229.556888,-202.409252,-171.000718,-166.471564,-203.292374,-241.936982,-315.316978,-346.569392,-342.329223,-364.425262,-383.915126,-285.670659,-184.078553,-84.54249,-114.060128,-211.690895,-152.281503,-64.042051,103.902527,138.841214,81.260424,48.340337,91.574593,123.549865,116.069212,163.657068,214.619077,262.667942,244.132413,165.199987,99.908395,-50.586881,-40.870777,13.229661,100.696581,128.086242,132.141969,111.282855,31.888908,-7.846122,44.070117,240.553147,341.262746,439.029048,409.141683,271.314795,200.316087,72.385848,26.169806,26.297962,12.20527,9.682712,22.454355,9.394996,-105.078207,-242.838169,-245.250732,-90.821609,16.233085,147.244337,148.854116,118.848981,131.525847,164.483491,156.401742,152.013961,175.712255,205.78022,232.346055,207.160924,109.391863,39.420232,37.401192,53.106998,56.082071,50.831065,34.303424,-14.586024,-47.696194,-153.439244,-194.985633,-157.851683,-49.396315,-0.268617,53.654331,34.688764,-105.369772,-225.394008,-213.552137,-124.562239,-96.100419,-88.438779,-97.891807,-124.388093,-150.51392,-214.729275,-214.955772,-185.937895,-86.696647,-32.384517,1.699413,-27.236964,-99.870579,-124.822409,-115.515182,-46.604123,23.833116,162.372903,152.106377,-40.761105,-135.412886,-170.939839,-79.486785,-51.819675,-32.296046,-30.356915,-87.156689,-122.807769,-131.123374,-119.635122,-99.93147,-3.964468,53.387184,157.185022,193.588354,173.296604,103.321297,-43.676986,-21.435311,38.811792,119.948702,106.927908,10.909083,-22.756297,-16.290695,-13.534121,-11.49189,7.442476,2.157179,-19.176767,-2.380215,96.378433,135.696419,108.429765,35.085492,37.037236,118.260637,142.067292,43.922946,-35.293545,-150.849349,-255.046012,-260.563004,-121.189762,-32.254948,54.199249,39.989649,-62.731842,-113.946645:-86.724822,-40.458483,74.719357,271.18126,302.970429,268.659684,210.204122,9.097047,-98.236446,-67.403847,58.966899,114.579189,137.568842,77.656518,-117.435322,-183.114872,-137.624462,30.234664,75.845174,82.583116,66.121624,23.878492,10.405135,-35.191409,-59.141159,-35.871759,57.430925,124.688466,201.977331,166.56838,8.815514,-62.156129,-120.599929,-33.793787,50.777427,175.174421,165.51965,26.586371,-72.277963,-278.560602,-302.752924,-245.264179,-178.88443,-185.111335,-165.304821,-131.48941,-146.219639,-194.228388,-191.431879,-38.532272,24.889212,115.261952,152.441865,142.691998,92.131151,-26.898432,-70.792733,-23.503378,148.347138,198.817903,200.130285,201.522883,192.461236,146.144782,63.588977,70.177213,65.951898,30.726194,2.27669,-72.094379,-107.755776,-187.16862,-215.64867,-173.14531,-49.580728,-7.965902,4.881561,-24.557911,-127.545782,-177.332143,-155.321933,1.652451,43.221557,56.355344,60.71384,47.911895,27.74343,-45.679439,-126.631842,-117.081144,12.391628,79.68169,143.143127,149.694381,85.024877,-6.710047,-146.253599,-62.713884,4.735695,78.469118,75.991507,34.228514,1.634236,-133.769337,-253.825337,-236.809058,-74.384262,14.480734,91.992478,74.483275,-49.664138,-140.179257,-257.76162,-197.218855,-123.523265,-4.672742,1.997389,-66.028447,-100.87339,-128.154981,-88.5951,-47.307666,51.849477,110.875841,171.135959,122.852085,-65.543864,-136.119923,-146.502986,-55.074785,-22.1933,28.333506,60.152676,81.132209,35.938282,-139.767725,-207.648704,-156.450631,18.888481,93.468473,127.711262,65.854953,-150.060494,-239.121176,-253.251917,-64.545582,36.875772,174.948881,214.154348,202.420278,150.538184,-15.836651,-127.61196,-109.930429,27.476983,139.214784,365.584033,394.256653,276.483242,207.954901,152.362595,157.835261,167.204068,205.646226,201.662475,60.33128,-51.970113,-218.802141,-215.275314,-167.874539,-51.541268,-4.17624,34.852044,25.595663,-45.364684,-97.443861,-177.83848,-146.737812,-91.996708,57.649677,135.379811,197.563136,143.831305,-40.903784,-8.630717,91.795698,231.348665,249.586454,261.084635,258.139869,208.587116,161.675986,62.635714,29.006476,46.280777,170.538725,250.39963,265.8267,184.255527,-5.865525,-49.444151,-6.652899,92.261628,114.594979,134.923622,148.729297,168.66141,156.951248,97.536961,112.932375,184.013615,370.614416,405.100938,294.992072,187.800888,-42.417457,-149.239035,-123.301042,33.392073,121.964006,201.938126,167.807598,-19.294031,-131.25862,-241.474696,-151.604133,-85.008427,16.46882,30.862282,-95.202658,-208.349527,-389.660329,-394.37868,-302.973183,-77.933002,-19.044432,-5.001745,-16.749456,-76.630213,-144.646291,-311.598076,-329.422388,-272.117642,-139.170743,-101.610721,-131.132777,-195.083962,-331.522468,-318.972675,-266.05431,-217.002275,-236.006566,-226.117549,-177.033677,-149.648038,-205.425496,-290.053614,-150.868865,-29.776161,147.38289,146.940822,-20.809674,-91.731497,-30.219102,116.669899,140.689542,135.628737,150.253167,217.00659,216.731103,92.613157,14.492155,-59.615574,-44.670484,-23.857143,62.546176,97.320308,80.830197,65.343009,73.975414,125.440285,179.229892,321.878302,379.268715,399.626413,352.375364,174.287665,85.868243,29.524561,76.471146,88.707605,150.590024,195.884108,198.652652,154.49155,4.777015,-132.979558,-142.149035,-28.782434,84.863489,250.477201,222.637511,81.726441,69.104788,125.607369,120.209621,117.953631,200.344898,258.47511,284.291061,231.059343,50.334325,-39.294587,-14.078527,97.176982,143.115944,139.946653,98.800462,16.766075,-20.185323,-91.158803,-96.887648,-63.80614,-15.585158,-23.100567,-26.399258,-20.795648,-113.181899,-232.233472,-213.445889,-57.929982,16.778054,50.91178,21.067372,-56.550219,-98.320393,-176.325657,-183.55022,-130.124885,44.71789,82.371954,-30.119924,-105.978423,-158.755043,-152.325304,-153.273988,-84.691719,23.049664,187.505106,137.483516,-137.200036,-240.074327,-231.95946,-112.297639,-86.867416,-80.732631,-74.373195,-74.360776,-101.76148,-207.818947,-217.72411,-141.661289,61.362118,123.902028,140.582132,136.218624,140.11716,105.964129,-14.376349,7.476611,69.72437,162.686592,169.938539,96.235558,30.503977,-52.034769,6.434093,55.548284,60.82944,32.464577,20.776565,22.784375,-9.633278,-25.197393,0.572143,40.49741,36.138097,38.818033,46.167337,-24.674714,-97.253256,-234.965259,-275.958775,-231.334909,-48.37221,51.713042,149.477427,115.700243,-35.571104,-98.211877:-82.388244,0.701745,58.087183,119.482917,143.98486,175.189098,135.12251,-28.077002,-56.755417,-4.870352,31.368603,1.148673,28.516272,95.150042,152.947959,120.138387,0.110735,-58.772479,-17.719108,113.785689,138.884502,118.61005,108.371273,116.327545,182.029402,215.154184,232.108353,232.524637,257.004724,270.134287,249.079243,199.826871,73.245282,76.395745,129.865939,265.084642,321.493405,301.590889,211.294711,12.616188,-50.425479,-40.583001,-66.476001,-100.942365,-88.487766,-62.342678,-82.889812,-107.686266,-108.795581,-27.336419,35.589107,132.150216,152.301272,189.344366,224.324603,260.411488,153.804018,86.692735,55.083733,103.215477,250.83085,293.933028,255.852827,200.188673,119.251947,172.142524,213.431258,188.77917,130.097252,33.29298,16.687974,-3.094915,-93.840997,-156.296243,-186.302618,-124.024864,23.92832,37.837857,-25.060929,-35.476073,25.318594,42.471213,9.769916,0.228447,66.475741,205.48114,207.587932,65.913498,-89.708029,-102.33946,-35.940488,6.6246,79.414416,95.589943,65.628868,16.089164,-96.907823,-79.048339,-38.937081,1.766628,-3.517343,-61.548022,-77.113145,-57.228145,-75.26082,-66.070796,23.610775,69.227692,145.748118,175.562706,126.017182,33.574547,-181.309195,-267.330869,-248.070482,-174.210652,-135.919009,-65.469379,-56.549774,-121.681033,-136.040573,-68.415173,108.688849,172.017327,242.633626,230.926598,85.185642,-13.872466,-155.205868,-166.040243,-142.974018,-80.196373,-29.110628,74.982435,94.688447,69.307659,48.52033,61.088646,71.716441,61.744503,92.192514,126.708421,97.339527,28.561974,-15.504739,148.198106,196.605522,205.262099,249.972051,350.80896,321.508795,106.250709,-14.842028,59.32447,303.439156,356.19783,311.457504,292.079677,290.443916,254.25569,121.753702,67.331036,77.78362,135.742357,142.428503,13.694261,-90.388708,-220.24652,-229.118064,-219.273641,-163.459905,-118.633256,-84.900366,-108.14759,-138.683639,-126.178335,-120.29494,-132.766448,-106.035078,19.911869,104.705634,208.442749,180.572575,59.143508,46.221701,75.477152,126.713905,157.480814,264.427178,305.161284,315.942355,303.810969,272.772072,300.301589,332.945777,375.147651,380.105559,348.186256,302.08694,100.956556,-106.207305,-100.216824,90.258672,183.92688,232.581451,190.469703,84.387408,50.119834,38.619452,171.418924,250.084039,303.536908,306.491282,308.466365,274.810893,108.408761,-52.852593,-60.024685,67.231991,128.024351,159.931427,159.839243,132.325047,71.931277,-91.231488,-90.728095,-42.936272,5.561085,5.604754,-34.683798,-88.882979,-230.659432,-215.933207,-108.239113,104.60719,133.57491,57.308529,-9.099991,-104.424136,-124.369419,-135.957497,-100.82991,-89.303591,-131.162701,-163.661744,-200.684028,-206.841631,-216.858346,-280.523254,-314.793873,-352.66567,-359.590642,-304.592372,-251.389052,-185.980004,-189.426836,-229.334559,-173.967222,-100.751003,9.891286,21.184417,-12.37069,-30.905097,-58.870273,-149.904588,-190.191257,-131.985493,-32.466415,187.499044,248.001643,186.78316,73.055621,-170.680966,-236.440847,-192.951034,-27.115143,39.420489,-13.898419,-109.354303,-207.838648,-97.230815,-4.167944,173.903275,236.026477,242.266902,179.020751,49.572228,26.691076,-14.130178,-116.58819,-157.875135,-152.136208,-109.814313,-41.568758,-36.288803,-60.613678,-134.336619,-157.424476,-62.49454,51.387016,243.350307,246.026707,155.392838,144.726998,204.684257,264.573364,254.119367,190.436314,171.900811,132.891115,91.366235,0.525439,-11.789807,-3.946096,-15.901974,-12.164457,26.732867,16.937179,-69.819187,-112.14273,-216.000411,-324.597741,-325.887403,-195.733359,-114.235016,-102.691246,-163.413868,-246.874049,-284.006084,-303.392343,-291.557306,-254.99981,-169.373918,-146.342769,-184.921124,-231.200037,-269.84736,-208.032726,-184.527837,-149.527603,-103.084246,-43.027729,-72.896185,-118.16573,-40.981553,10.728578,119.469923,165.261698,151.555754,63.234811,-175.916069,-227.041047,-117.899203,11.253201,12.178402,-57.680636,-90.328011,-108.513141,-94.974031,-68.420998,-97.937051,-99.70253,-17.026223,33.21798,56.019687,33.043967,-14.362848,-36.003465,-86.277245,-109.361349,-103.90669,-59.573485,-40.063267,-75.447959,-115.10521,-176.225735,-249.423715,-268.7444,-213.756134,-166.085014,-91.34571,-55.731596,32.666278,47.361231,-47.400818,-99.61309,-62.219085,3.115703,-11.794213,-72.344064,-71.859498,-51.364098,-152.407284,-208.500626,-186.341096,-134.873879,-109.652807,-136.387672,-163.986173,-171.557764:-111.219709,-1.506609,73.583735,195.241297,247.525166,263.096019,204.782763,15.004373,-117.521125,-127.974108,-39.016301,41.965469,114.888399,58.349812,-87.146324,-104.738126,-68.721834,-9.118751,44.162781,171.996663,195.79319,88.68431,-5.61124,-115.844015,-16.418785,60.556076,142.651855,171.230198,226.26164,215.152525,118.099412,55.931292,-75.388367,-90.18167,-10.634086,215.173459,270.540883,139.870678,14.950911,-146.18211,-165.127831,-149.000673,-147.404305,-151.261161,-76.798862,-34.972115,-79.827724,-140.527176,-128.230135,91.173775,176.005965,216.253608,203.499362,173.387871,169.694578,130.837201,33.179183,26.160484,118.563069,177.498095,238.543738,223.331925,99.946698,30.660919,7.207691,70.018993,73.67966,56.564117,50.831237,-15.704196,-77.629767,-178.490063,-226.36224,-238.176976,-181.155955,-95.093666,63.203755,59.763439,-82.404764,-148.11988,-182.691425,-112.816416,-69.483409,-12.754427,9.068068,38.824928,25.825671,-82.477302,-164.121826,-135.799444,-5.103989,53.590856,144.642757,159.050803,58.411649,-25.074901,-118.234666,-54.229747,21.049767,102.824903,63.176355,-86.803937,-136.216471,-175.596843,-221.465678,-223.402594,-84.127554,26.946921,144.81499,125.294682,-11.872404,-102.144501,-261.128956,-305.431415,-275.976667,-128.199691,-37.71026,35.649678,-0.853679,-136.291959,-152.598033,-72.870358,143.600068,215.617648,221.355243,154.200573,-59.725639,-154.288277,-196.173342,-78.386556,-22.270395,43.24261,61.864576,62.111463,29.981989,-84.710622,-120.930026,-80.358073,4.31412,17.224379,41.483199,47.176164,-28.098999,-86.137367,-115.777549,43.329177,155.579048,347.367836,412.922228,401.223131,307.641441,54.679948,-30.807071,45.882894,262.37025,343.066973,469.637522,486.941467,351.746675,237.835202,77.93598,110.647985,169.518638,229.577118,205.364133,80.103695,0.864725,-150.2533,-249.364137,-234.092745,-36.745309,71.762002,125.759834,80.163251,-35.351854,-92.503532,-196.844968,-139.561158,-58.320284,113.589016,198.992554,240.153433,159.251973,-28.016768,-30.776666,15.576715,114.968872,173.461904,264.682887,263.855712,224.901044,219.340819,222.628881,259.862752,305.896158,378.076798,365.432397,277.611001,235.792339,93.35575,-128.44721,-150.161691,35.66349,154.515837,278.966923,273.035862,163.808357,80.980969,-43.187284,34.779721,145.868329,366.417096,407.448948,295.148785,202.01751,64.169619,-34.08307,-44.636014,68.875305,162.904134,253.365805,213.071779,74.445827,27.251973,-23.124702,-65.074668,-69.011588,4.880189,45.386987,-45.345998,-161.386733,-310.949605,-258.747146,-181.362215,-20.114322,30.310962,65.536528,50.668337,-37.0455,-88.479981,-185.910631,-231.747117,-210.174607,-135.38888,-128.675938,-199.958993,-261.379816,-390.103275,-417.840873,-385.029586,-303.595299,-269.132872,-193.505917,-167.34538,-198.513123,-246.338915,-299.481828,-197.589041,-101.716938,96.439399,138.338319,38.699479,-30.877775,-64.079611,-64.219621,-52.753576,56.033392,131.121882,254.77882,279.917147,180.213879,56.927335,-185.739217,-198.89987,-120.448956,69.696066,141.231437,158.012853,94.174282,-66.028272,-59.041577,30.331033,266.264595,362.488994,390.574816,294.000379,14.883344,-77.937159,-100.185673,-46.225169,-24.650345,29.132282,56.391556,51.685378,9.037787,-105.610253,-218.537425,-239.657305,-109.277863,18.0476,185.412926,183.591024,130.124058,108.730686,71.204383,136.592551,210.473521,319.685083,306.657016,147.418714,55.867528,-52.866797,-70.44304,-50.023294,18.08225,56.694358,102.718001,78.613952,-34.538983,-94.410542,-203.274369,-236.463781,-198.360567,-62.752805,-21.627474,-61.061185,-112.478902,-222.411165,-311.30805,-310.259417,-198.128677,-116.433992,-17.184237,-35.839254,-149.410617,-191.469499,-229.565688,-188.687721,-112.38145,47.714186,69.887843,-16.502138,-82.508536,-144.775076,-121.29003,-89.264792,39.335358,114.070981,163.356821,98.325477,-153.618654,-252.527837,-243.893904,-77.616134,-28.062806,-44.939218,-61.572001,-44.845947,-50.676561,-185.287569,-274.154232,-211.60964,-24.634627,23.407374,78.864589,119.824095,114.687349,21.280773,-187.172479,-164.311316,-92.521129,29.678738,46.655923,-10.188986,-50.790791,-117.553585,-169.258393,-177.709831,-129.290517,-80.061597,-13.497647,-17.158903,-49.283779,-54.294176,-54.366967,-31.984994,3.68791,92.463269,106.088913,17.93742,-56.002546,-173.091262,-204.515399,-193.298258,-120.498322,-52.156746,61.553905,50.492122,-74.397989,-141.560686:95.180175,115.765,84.430009,34.357404,49.930426,60.26577,17.028497,-105.546829,-142.202663,-101.31565,24.937252,74.671214,143.55951,162.419741,141.275427,91.946168,-45.757032,-49.021727,-2.520685,50.76346,72.431572,146.043817,169.005201,169.536538,205.538752,258.71606,327.95213,298.691671,242.385439,279.73243,355.778061,306.668363,106.954563,117.282892,216.912885,420.062765,445.987848,288.285319,181.444126,90.304817,84.62488,84.612515,65.516182,43.609306,34.219981,56.735349,74.703396,24.55403,-156.90878,-201.842405,-125.343664,80.949844,135.540453,143.936848,155.893906,232.720337,215.144435,154.697312,85.487546,125.995838,276.49498,298.094321,175.062082,102.573904,85.024257,163.498118,180.206273,157.693017,141.444415,117.840806,99.272299,35.904748,-59.661377,-117.454214,-170.057913,-122.171183,47.677556,92.473689,92.753266,88.852947,84.967858,94.981225,109.047458,134.78548,150.768282,174.089612,168.401002,143.738535,95.851115,73.338281,65.628124,70.912593,60.636597,49.165138,62.866145,69.072862,-6.110021,-106.920428,-136.381323,-143.755573,-109.685923,-69.378724,-106.606711,-180.24163,-117.585558,-64.655202,23.021214,55.612239,101.243872,119.784577,143.778674,115.541653,-89.616459,-293.967123,-308.189868,-223.263558,-173.197169,-87.671915,-47.750837,-44.823111,-189.156223,-221.640558,-72.827222,59.978359,266.430883,294.952928,201.562698,123.302912,-2.116268,-43.159497,-32.301799,19.56381,55.636317,132.374519,150.675839,85.939235,-18.598984,-12.658384,83.643743,124.37562,186.094027,199.898042,150.59291,117.291292,88.939598,87.921704,105.805641,194.088372,244.371083,282.530753,262.079341,128.219378,27.373862,89.611658,289.176627,310.321898,262.265083,262.753739,240.338111,173.745658,5.429364,-46.84673,-24.962085,29.118952,31.365925,-9.216595,-37.714839,-114.587102,-188.799751,-164.127844,-13.880223,26.608453,-11.510946,-39.418975,-34.172446,-10.220003,28.640977,51.196336,42.560646,28.606292,72.856093,182.926283,185.932355,154.409174,174.605374,187.921519,211.276356,224.035184,224.315518,227.83404,316.30457,360.070814,330.571239,291.937017,299.757147,297.770068,281.364168,254.904521,252.465553,207.221272,65.860266,18.190517,69.046305,119.763992,131.215951,118.807686,152.374706,168.706655,145.263039,138.643153,156.022436,231.037607,280.330005,320.023345,284.806947,140.760473,15.313471,-16.891262,-34.425897,-19.707882,68.59047,136.532985,237.928198,219.587798,53.810083,-43.520841,-18.59832,89.366381,121.779411,67.625697,-9.031998,-138.234783,-100.570566,-25.902431,84.530858,80.16169,23.455009,9.141921,30.990212,60.974268,109.076418,96.669956,88.788872,89.32352,73.302,-6.591752,-56.455097,-137.387645,-185.104253,-188.766285,-208.698962,-247.031923,-272.617288,-231.760065,-172.642853,-204.012332,-283.453707,-197.444617,-125.725897,-28.253904,-14.375736,-57.579628,-97.630311,-171.283962,-233.31662,-245.177237,-196.473029,-145.651403,-35.794698,-10.480114,-65.284293,-128.786361,-243.142583,-253.903321,-236.600972,-184.978288,-152.215804,-154.541085,-201.406304,-245.862527,-100.953974,-6.742411,89.965484,86.843102,33.239179,-11.160829,-123.744144,-150.883724,-109.876952,-98.449004,-139.665408,-209.216259,-189.842615,-75.710706,-32.680647,-35.077603,-74.296931,-50.755399,71.374362,131.657324,232.001927,271.166841,309.269144,308.56449,225.521223,68.372389,23.31042,45.882686,95.672961,149.591667,114.332178,-0.578469,-6.680679,2.003498,-45.983681,-52.966745,-13.749376,-47.052414,-203.508498,-229.190029,-218.29003,-369.342995,-420.826774,-257.81178,-117.474736,-20.191666,-75.055936,-249.356998,-379.746251,-384.708076,-320.47078,-295.179777,-231.014083,-175.637865,-99.671306,-115.871256,-200.108792,-160.163175,-97.420676,-15.368287,-2.105401,-8.778777,-34.105998,-98.744557,-91.869392,-53.65316,29.110644,46.444962,29.803793,-0.03471,-94.662392,-129.095573,-101.329001,-35.631899,-23.134013,0.531965,9.004655,-23.927392,-51.537533,-88.762621,-101.714545,-76.973645,40.229636,88.74138,71.159844,27.205108,-1.705081,4.186881,-35.994824,-72.591528,-69.952123,-94.818385,-123.286334,-167.378054,-177.590383,-212.687826,-301.812987,-323.843129,-257.32246,-189.682353,-41.766423,15.181584,15.645538,-37.657158,-125.490831,-78.697003,-36.591158,-25.873347,-55.615483,-74.208012,-37.61193,-36.386561,-241.205865,-293.964993,-150.599692,-59.613044,-74.661203,-127.753009,-127.722361,-117.882138:-67.969404,-34.844169,-43.77818,-34.275597,30.310377,146.972676,136.476444,29.402575,-39.776654,-8.447771,135.141667,194.495462,261.690242,257.918923,162.886843,100.244699,17.037284,-6.569927,-26.573464,0.274645,87.788024,255.207455,282.45834,265.639378,222.156662,250.584932,387.39441,411.405837,353.13448,326.618429,300.24183,274.726798,181.80797,140.668752,184.500903,348.20393,396.03983,319.73956,235.181999,102.083726,12.947598,-22.377047,-84.820486,-107.865043,-101.862486,-102.195988,-155.474313,-186.58828,-233.074202,-202.363694,-148.300056,-24.240654,39.149372,154.981073,191.95073,214.953029,159.154105,101.700287,38.636927,70.624601,181.517362,214.222489,202.423411,167.154244,101.444351,123.886156,143.377337,126.431133,95.647891,30.254209,2.269124,-69.525374,-152.507825,-182.869652,-209.655382,-192.65364,-82.244624,-18.481025,68.471942,91.064282,58.165718,-37.817237,-38.946956,124.596696,237.072354,307.916864,264.464508,171.5954,113.686172,104.78639,94.220357,72.368015,-0.708216,-50.385687,-127.397265,-147.273332,-187.799279,-187.103662,-173.835682,-156.73142,-129.879363,-58.335953,-50.708741,-86.780166,-88.50781,-43.673921,47.19047,53.496349,67.508528,98.440044,114.143554,59.694773,-150.109712,-297.280687,-301.897392,-203.983667,-119.319975,-5.128791,-20.941151,-117.835962,-139.895152,-107.670768,-13.027825,33.48822,147.385246,193.946103,184.191734,116.751148,-133.536952,-344.691367,-357.848602,-227.061155,-139.634458,-51.397441,-43.617914,-34.403866,-50.988599,-45.279346,16.909061,47.779842,111.470828,139.553904,102.752877,38.736548,-73.002389,-46.146423,9.13296,117.119866,151.555513,155.366169,129.144495,6.197132,-137.530664,-119.117251,75.948792,158.719501,222.827507,225.600149,160.171775,84.55747,-106.083258,-188.459127,-158.974007,-55.840957,-41.847963,-150.386396,-217.973938,-227.663018,-172.776761,-174.162057,-198.375124,-192.378496,-144.688349,-132.774912,-147.362568,-154.605881,-137.50776,-106.359754,-107.964148,-42.753707,66.047044,235.889867,187.818005,-45.760008,-64.874453,-8.661537,51.764754,46.709646,48.059285,68.898236,77.952152,54.785387,34.256625,112.319019,153.145653,195.933124,217.953041,229.799087,187.335887,-10.919064,-172.143547,-157.450007,-56.722226,-32.006025,32.751335,78.097645,76.89528,39.373659,55.630073,184.936069,212.706737,215.652713,238.622235,271.597448,238.059715,97.987286,9.540456,9.666199,39.936719,44.626298,74.638801,108.499143,123.822952,90.652874,-9.013394,-23.927217,12.465016,37.46311,15.587209,-39.010013,-84.304897,-197.31243,-169.360246,-94.348934,14.209185,0.572517,-119.668306,-165.935434,-132.232545,-77.797668,0.493377,25.246464,38.585043,96.004107,130.079709,111.379525,34.040074,-137.939592,-212.489429,-208.848307,-143.333667,-108.944877,-69.618773,-62.352563,-82.223042,-113.823134,-163.35491,-87.285073,-23.196629,67.804818,91.27863,111.740331,99.435243,-45.245542,-256.80008,-284.260105,-157.655836,-54.753106,127.489329,178.018228,147.766539,62.984058,-143.586854,-178.341825,-140.329315,-105.152207,-122.77219,-215.98422,-269.931288,-300.029132,-202.496668,-116.538076,27.955736,61.146311,148.644486,203.765068,186.902691,108.655083,-47.214109,-148.532418,-206.754351,-273.49883,-239.926871,-133.821894,-116.355214,-133.545234,-138.240977,-120.104991,-32.602061,24.023213,147.902095,205.478943,237.902421,215.172332,148.362882,79.117881,39.643889,12.927879,41.674895,65.061022,38.667332,17.140693,35.761555,26.002107,28.169674,67.400801,124.193905,78.554031,-126.246111,-211.626314,-277.027068,-293.311255,-294.661416,-202.579646,-119.425467,-35.233113,-62.302374,-189.044642,-304.057103,-334.472504,-383.377641,-406.98211,-361.38352,-282.43103,-161.001924,-177.489706,-272.7774,-219.841628,-146.624698,-49.968901,-38.994572,-12.995863,13.148124,16.929225,-51.103286,-54.56998,-9.519299,2.926508,-2.547691,-30.889677,-101.164954,-92.660857,4.052056,48.892449,29.743451,-8.095467,-21.303352,-105.164771,-143.68517,-126.278091,-77.883608,-30.432665,100.564041,128.459841,90.772123,66.301783,49.581221,26.187032,-48.458128,-18.811832,9.602093,-34.323379,-94.123876,-201.090971,-222.698092,-211.494343,-238.355038,-252.190676,-220.591649,-177.352765,-34.998453,29.506791,-3.657618,-88.573546,-192.924576,-102.95826,-44.484343,-41.390775,-85.519193,-160.072277,-167.745882,-174.994957,-265.599896,-306.024905,-286.865138,-251.838841,-227.846261,-247.980271,-253.041322,-220.582448:-19.177974,52.463296,101.630565,146.574403,154.118718,108.453665,33.543369,-147.841634,-186.982667,-134.952727,-8.009584,18.713382,9.748773,4.202004,-18.136088,-56.231362,-121.133804,-27.407363,44.936986,132.867649,157.00777,162.594491,144.206855,108.058269,102.808277,130.827816,193.526584,188.72536,178.015504,206.420917,212.587781,150.235881,23.186229,72.01087,147.289239,247.930579,247.189181,207.285087,174.924025,67.422999,1.071011,-2.221958,-22.028429,-20.426032,59.490939,84.926699,26.951842,-16.19622,-52.774735,12.637595,77.111733,146.549505,138.468912,124.734308,133.326874,152.164407,110.74863,86.730683,73.666239,81.113987,144.225384,158.631165,69.228247,17.933608,22.192962,113.501304,144.724407,137.468814,96.839487,-17.38565,-50.150616,-43.06336,-28.439604,-46.671926,-115.329577,-116.345099,-25.532823,8.856749,-11.554563,-31.790153,-33.002864,-39.466212,-55.820357,-70.338913,-48.504336,25.47717,48.291899,9.914033,-64.936451,-59.022541,-1.726697,38.459511,138.058974,130.198912,-21.817185,-83.084922,-125.194261,-111.551965,-82.810295,-23.851715,6.742643,42.667102,20.433259,-106.451381,-219.041024,-191.472541,21.780976,118.715869,177.583609,155.878591,71.652358,23.587824,-116.340893,-232.682145,-224.916543,-126.082888,-76.574484,5.346788,31.508879,-24.907048,-138.365243,-134.619876,-9.55711,64.153558,134.349659,104.703156,-14.060155,-57.685459,-104.024428,-79.834531,-40.381957,69.071691,123.063321,137.284897,88.502919,-1.760503,22.53009,39.94508,25.276149,31.593686,135.098391,174.215445,115.173373,61.927032,21.696492,106.405784,166.334835,202.712891,208.951635,297.690563,320.072131,167.305873,3.270719,39.735424,242.310764,315.951044,350.15955,334.057842,307.234933,277.758612,107.645929,-7.814401,26.290946,160.039659,183.680634,72.948524,-10.223318,-109.016375,-159.487258,-138.718835,3.125908,62.169702,111.805008,126.088574,98.130684,34.260349,-129.984625,-196.698055,-160.76724,19.946054,119.203834,188.820464,147.513608,34.629678,21.089188,70.368085,172.276293,177.107526,155.820298,165.354645,222.054006,245.479748,230.011952,228.19611,275.313884,371.561756,358.52491,251.67107,216.874475,152.676735,9.46147,-36.525858,-0.774849,56.352875,147.153607,132.902217,15.042617,-22.876907,6.665727,131.569277,188.587146,258.032259,290.126359,260.487083,180.170865,37.751722,-46.686298,-81.3642,-64.999063,-0.240064,135.358724,158.34161,137.504444,103.368733,7.316022,-1.723844,22.136425,85.844045,123.130916,117.987838,46.988238,-129.039498,-165.876556,-138.453008,-82.998611,-50.434827,25.661005,32.326223,-29.037939,-51.428238,-93.592127,-192.716618,-195.81977,-77.484174,-32.05534,-117.372881,-219.454893,-352.759202,-339.817245,-306.994015,-242.207849,-213.373173,-202.476745,-242.427769,-307.431701,-296.6344,-231.877753,-120.876871,-68.157243,-44.614391,-66.717953,-94.684608,-70.572726,-14.54183,-58.310979,-57.804511,19.289894,64.775246,171.563483,207.033931,147.05059,52.479964,-114.145829,-71.228794,-22.978772,40.169347,67.467236,64.449745,3.421901,-151.510634,-101.625531,-27.915596,14.787311,14.530365,90.508703,96.977661,-70.898715,-162.585726,-186.096192,-108.574126,-93.052005,-76.914565,-43.935762,39.534791,49.393101,-55.482538,-201.63656,-214.608845,-99.04532,-5.871351,135.495676,146.052566,107.36554,106.382174,126.50191,162.157284,179.660501,174.065413,159.174029,83.912903,21.242535,-77.474301,-134.836163,-152.89173,-139.116011,-104.730461,-27.342721,-30.457947,-114.130302,-141.325801,-169.165328,-238.560904,-269.038439,-240.864136,-173.824994,-88.938957,-127.386661,-274.464135,-346.308758,-337.857702,-227.092614,-147.980846,-65.899236,-60.322646,-38.506984,-33.455856,-77.419012,-64.192684,-11.319748,57.616038,44.51082,-34.660637,-79.699691,-148.60892,-120.326139,-39.113552,132.428764,147.432016,116.097889,87.02155,-72.150823,-137.568586,-65.620361,91.60747,91.909672,-34.449295,-72.041268,-79.729257,-95.895981,-139.862171,-150.102754,-127.131046,-35.913588,11.793243,87.138305,101.44673,43.67504,-16.787058,-112.308264,-89.999877,-44.178339,9.636107,12.603987,10.280561,-17.540721,-123.993627,-187.713517,-195.080536,-161.103527,-112.442984,22.762196,72.943712,44.935265,-12.795657,-37.656509,47.946868,66.956703,69.164985,66.928855,27.660508,-4.371671,-88.106181,-195.4849,-198.486711,-68.505813,12.683429,113.883388,116.453417,31.896169,-26.52139:left
16.094439,117.406646,118.696195,89.847708,71.362367,-4.940935,-71.800413,-218.285865,-295.578498,-330.194155,-431.120829,-450.292883,-358.291694,-303.275558,-272.936706,-266.592935,-252.130509,-294.570541,-290.921392,-185.056594,-135.605229,-122.439996,-129.989209,-81.209096,-9.792783,-16.30847,-126.066438,-198.059675,-243.538967,-211.812447,-172.622992,-177.78174,-172.740281,-134.555552,-124.501352,-188.354078,-235.78881,-215.654268,-158.328603,-74.317342,-84.548069,-110.08142,-144.364782,-156.092702,-146.753794,-122.720075,-93.329323,-75.325989,-18.18874,-63.033815,-140.034498,-364.707928,-458.411792,-423.232852,-313.721873,-143.276968,-184.525377,-256.29803,-350.348563,-362.514399,-359.492007,-329.830683,-208.751504,-146.371512,-41.42364,53.74705,79.194734,-10.71153,-119.382216,-284.045478,-283.592745,-93.648273,109.818441,97.427716,-84.99554,-174.068636,-263.043011,-273.777022,-284.707582,-274.577514,-202.524786,-119.651669,-105.977402,-182.563489,-233.900922,-223.647378,-175.793389,-58.025662,51.844686,62.459351,-3.402409,-61.140843,-178.811651,-205.279202,-162.973868,-140.228351,-242.771294,-405.947037,-418.583759,-357.361485,-321.623453,-225.995537,-168.448835,-105.196613,-129.099673,-132.015459,-74.055568,-69.178704,-168.000023,-203.780504,-164.987573,-116.885742,-45.997565,-101.321028,-147.982561,-195.157424,-189.055494,-126.74299,-83.950953,-1.300352,-2.445503,-43.765333,-114.038858,-123.058485,-105.204359,-92.684857,-71.662987,-36.856566,50.679282,12.169567,-21.318016,-99.757434,-161.331813,-241.30502,-235.554061,-162.303025,-118.326344,-121.571707,-103.718454,-96.383557,-165.204407,-213.387033,-188.670294,-110.396747,-0.59435,-69.620537,-82.912023,52.620614,134.522351,191.36839,178.266978,140.648863,111.670218,79.174164,38.076602,44.399754,34.586375,4.382362,-90.727228,-126.876507,-134.967858,-138.382583,-141.698117,-119.007581,-92.005383,3.861516,70.519793,217.380868,307.158698,295.009987,177.424476,91.163394,-59.285828,-76.405279,-41.66158,-33.565667,-9.127125,21.428592,19.093031,-4.151671,-12.730664,-18.019167,-17.773676,18.292055,119.004315,157.612489,103.893622,22.045808,-85.376504,-80.373348,-40.14942,-25.865933,-24.714468,-126.461099,-191.830486,-195.259594,-115.965702,30.227885,40.576521,19.399397,44.713542,57.447962,46.924611,19.252066,-45.690688,-64.610639,-74.082949,-44.813289,80.179432,99.033096,52.374699,-64.823552,-108.409745,-84.389802,-10.576466,160.862188,164.126098,98.153174,9.338532,3.580236,-11.36081,-16.85357,30.248215,79.565433,167.322605,151.39838,118.940871,85.721859,107.785148,233.547487,296.589842,296.005208,159.795618,112.838494,135.804665,158.125483,74.441244,-8.833443,-89.634303,-65.12524,-9.228999,-71.819343,-112.862052,-141.926661,-109.837871,34.48193,92.182131,95.127826,4.288234,-60.95383,-180.997814,-203.152445,-131.836397,-64.840513,53.882679,114.12995,220.724728,184.496871,134.156896,84.042225,76.456139,54.169232,44.132869,48.757321,84.787459,83.482032,24.028453,-0.433424,44.051788,111.346145,251.357041,288.878983,238.296214,81.612989,30.732758,-49.373226,-101.304639,-129.554522,-99.864703,-11.195852,29.407393,-6.045913,-113.11345,-164.693459,-255.220363,-240.080032,-78.513404,2.920358,64.8413,-26.225476,-101.970146,-193.15327,-186.874845,-148.956215,-142.467418,-82.467086,15.026087,24.181381,0.83762,-7.825545,-23.887878,-30.087618,6.591466,55.676242,104.569398,60.188026,58.519946,58.11093,44.917936,83.026663,135.352891,197.003566,126.956319,80.043269,77.037349,87.900215,43.449238,30.39999,76.109055,84.759226,-3.289069,-64.790772,-13.93731,129.145003,148.574001,148.031878,175.357461,285.199334,376.153376,377.781731,293.659921,227.179679,139.641459,131.486146,72.985205,7.149301,-96.883089,-129.214405,-158.459576,-296.725424,-362.355291,-378.466942,-353.791456,-284.661809,-200.52042,-196.259446,-253.03326,-274.640605,-253.435256,-211.324034,-135.730792,-116.130332,-53.083117,-25.893507,-80.984721,-266.509846,-311.6703,-192.526016,-86.411428,12.100165,-83.472725,-151.589665,-222.003953,-244.284993,-256.731332,-196.571474,3.883697,76.355765,87.486286,-19.882302,-55.642985,-104.4554,-125.262696,-29.41026,100.371632,384.695113,450.607761,380.325411,231.66383,192.669548,129.912198,106.105788,99.691996,123.57258,209.188471,198.651575,155.894177,51.713699,-15.259081,-117.047208,-119.687937,-27.979158,53.741215,33.556034,-71.128279,-108.81585,-100.936794,-54.907509,76.837026,132.24676:-14.555044,43.787732,13.552825,-33.653719,-38.40624,-54.393008,-63.526998,-116.607558,-235.302633,-281.715817,-344.525504,-355.702306,-284.612347,-218.761455,-84.929262,-27.01673,-29.192997,-179.957455,-204.346181,-86.300743,-24.371575,-50.215491,-101.150472,-91.161862,18.21379,13.780513,-137.422713,-214.501458,-212.447894,-144.211163,-42.976928,-37.954543,-59.546825,-67.176677,-86.389561,-191.880632,-231.961224,-171.315836,-98.243593,13.884456,39.103814,22.955895,-40.868137,-70.259813,-102.108013,-108.161309,-73.810392,-37.503895,-40.750317,-163.762682,-217.841054,-290.698823,-301.86443,-207.108413,-129.439001,-38.090778,-64.129896,-101.797458,-181.658587,-234.852326,-289.07836,-232.41162,-33.459634,35.915485,65.720948,33.917483,14.756955,-54.446851,-90.913429,-118.520963,-109.101375,-39.393618,-8.877343,-48.979985,-189.699037,-258.799799,-272.267012,-201.323299,-55.748455,-41.999006,-110.07342,-91.481802,-53.495804,-101.087209,-153.024547,-161.65139,-138.940524,-74.00688,26.333982,53.984135,-8.800911,-97.425664,-237.783979,-216.722221,-42.248329,3.244061,-155.525728,-385.231442,-415.436956,-348.98456,-303.946184,-227.837979,-168.906744,-35.757713,7.074086,-8.12098,-86.878212,-129.446051,-159.17761,-143.087854,-97.739979,-72.755885,-4.832889,-20.014438,-92.061896,-237.969711,-235.905265,-104.477665,-61.079658,-86.876205,-125.559553,-131.685121,-199.16264,-257.128998,-298.725183,-263.84279,-101.772031,5.097167,72.937503,-88.314838,-139.255434,-158.785109,-175.170348,-222.827288,-242.336124,-251.303461,-210.23916,-163.973973,-105.333751,-147.129577,-260.89153,-263.178318,-212.550534,-189.947321,-139.404372,-115.798719,-123.475962,-150.223671,-147.785826,-105.367901,-98.189629,-99.344394,-61.490894,-53.349728,-50.074918,-69.908571,-154.645285,-160.326495,-66.014226,-16.790217,-32.577411,-174.323356,-229.403628,-200.478857,-122.615422,51.546744,125.006224,287.633977,377.033148,342.576134,194.497489,129.140578,43.228473,6.663242,-64.511516,-69.447981,29.312999,105.708506,63.008152,-140.035818,-212.661954,-133.139383,-12.153917,185.330241,189.928115,122.694941,-37.578292,-92.741514,-102.53158,-61.463978,1.396173,6.579874,-22.256012,-95.005866,-139.095132,-217.841494,-210.507731,-84.76053,-35.997478,-54.64302,-98.485253,-93.975969,-43.436969,-34.450086,-77.629586,-91.068699,-69.929582,-53.413547,-32.431724,-50.590172,-71.207057,-112.435519,-125.574637,-96.277873,-43.84277,53.458095,-35.12632,-100.697087,-162.625407,-199.473976,-267.728667,-251.92938,-134.798165,-70.594282,-26.65146,-110.04223,-122.549933,-101.736932,-102.001043,-15.68491,75.869788,203.223182,169.385304,123.489375,96.682492,120.039494,109.825428,71.381752,66.629593,99.743241,117.014141,59.020457,17.691553,-45.67164,-30.251668,84.716145,151.938382,258.487664,207.737987,112.550612,-102.765074,-171.365664,-120.654922,-17.77528,143.350778,152.028532,76.155377,30.68709,37.575096,50.211985,46.184465,58.053126,79.488889,89.516566,13.509232,-23.949305,-50.678593,-58.911823,-54.017253,-1.798439,177.01872,239.358262,201.585756,14.698826,-62.735557,-114.647156,-97.768269,-30.102704,-0.654354,40.478448,44.440086,28.377517,0.782084,-33.761503,-136.950397,-130.235848,37.758089,109.436538,95.074463,12.611684,-13.582054,-62.681817,-65.266591,2.989973,34.586637,67.770064,78.001264,79.970144,93.82923,86.534825,35.428536,14.004018,31.447521,70.169918,111.446262,116.520134,154.605394,160.166216,96.181366,61.218006,146.912566,341.315694,291.559842,210.704014,96.242452,48.467637,-47.525185,-42.165194,102.654707,167.366169,106.951311,-24.163468,8.651388,151.511357,156.490992,85.87888,100.94885,308.839209,445.878879,398.092975,251.915093,232.619686,285.824349,313.225322,313.564037,287.553011,225.100402,139.786295,68.096092,-93.747984,-135.813429,-73.74777,-12.28821,28.362202,-19.154209,-31.05333,-57.160325,-84.444274,-90.446698,-45.37424,88.855955,116.081708,32.230098,-61.397152,-101.235829,-222.480433,-251.628916,-175.070343,-104.835134,31.718203,52.686922,0.143913,-121.603029,-158.493452,-160.829271,-98.570052,82.604328,122.782218,28.71169,-126.324217,-138.984944,-67.229062,-35.591004,9.743111,49.772986,177.701369,264.386745,253.022113,127.872644,38.676427,-64.644836,-51.093287,19.847612,55.478771,162.720961,211.793781,184.684268,76.802022,13.392138,-74.692728,-71.399324,31.011339,93.453688,57.362603,-75.926861,-104.360033,-3.237576,77.643052,167.65989,183.473446:-147.797642,-16.990769,24.764313,0.004525,-42.142945,-122.280509,-144.876587,-138.042141,-158.995491,-204.581185,-301.535454,-318.701048,-226.778697,-130.079243,26.514318,57.11119,20.954968,-153.265815,-223.505619,-180.558327,-96.398603,35.483172,55.984387,49.476812,21.223777,-17.601345,-165.758594,-250.88631,-312.889658,-263.061328,-100.895401,-45.738866,-66.530367,-199.498999,-244.993323,-249.739291,-218.500358,-82.880936,15.552495,190.943749,190.05194,110.898171,-64.435653,-91.828607,-20.395147,12.106931,14.726335,1.762389,-98.841756,-193.147401,-176.264174,-143.767175,-146.905511,-87.058018,-37.538117,30.928087,43.202196,12.168554,-119.07726,-188.57164,-188.108095,-103.546379,60.336694,86.324059,44.571995,-41.542515,-65.180116,-103.420289,-137.322272,-172.891656,-153.224045,-83.814024,-93.120393,-126.451728,-175.936093,-195.845869,-219.76513,-196.168131,-81.07204,-35.959412,-37.575111,-22.812164,5.177693,2.589213,-41.266997,-158.961861,-185.818708,-110.33843,-22.596958,-36.129994,-123.231327,-160.558665,-193.273349,-190.967346,-152.244104,-135.232917,-187.792879,-296.0921,-322.388909,-271.563379,-203.921493,-36.528816,49.09526,154.2051,110.385579,49.424225,-44.900236,-58.199628,-57.143001,-54.211971,-51.79037,-52.938425,-53.103458,-88.285721,-137.288621,-215.493897,-194.406405,-63.37036,1.480798,32.975554,-88.844915,-147.223427,-219.631966,-245.234836,-209.630194,-159.202545,-68.308296,-11.056547,77.462362,17.762667,-43.323366,-174.452692,-219.802195,-224.431795,-211.536046,-213.702435,-222.639068,-206.074343,-206.481493,-258.788187,-326.065491,-306.65009,-245.577327,-198.62173,-87.61735,-146.566915,-234.557418,-345.180739,-326.575907,-198.143194,-153.104277,-126.572403,-80.622496,-76.442642,-148.846099,-197.020619,-219.832431,-194.57936,-123.214018,-86.738192,-96.891415,-249.464652,-308.904915,-272.411684,-184.461514,44.477204,153.561264,327.569452,369.635742,312.445118,151.709303,114.223834,129.6256,131.086944,67.639417,44.446258,119.547187,153.261803,58.089838,-213.906956,-272.02378,-146.401827,-27.809892,166.085771,192.517358,136.435485,59.792793,84.412022,149.335328,144.033299,96.357334,93.775764,118.664897,79.766057,19.089321,-130.253182,-152.690388,-32.052784,51.464188,102.539954,-9.888567,-67.686274,-83.622769,-76.627183,-94.735414,-78.42493,-1.417232,5.545293,-30.187926,-15.693237,-11.485918,-31.971836,-40.924118,-26.931997,5.383731,61.470983,-33.52485,-96.961318,-106.283227,-99.412488,-181.046949,-221.319718,-173.851669,-96.745309,23.560897,-22.839653,-67.889348,-105.95559,-87.537523,30.515875,109.650532,211.264531,193.197406,172.993193,207.88919,254.62823,288.534251,272.14944,223.748278,180.088161,90.690938,112.635953,128.400127,115.78716,125.60896,172.884891,190.068496,223.299245,180.41707,114.564667,-62.956999,-138.113458,-120.736567,-22.950994,158.767644,167.065867,48.471957,-7.538222,3.058667,-17.651918,-30.657056,37.038782,87.195595,71.689248,-69.755845,-115.457091,-87.006513,-54.444904,-25.240164,10.411563,187.65879,287.444142,311.425216,88.611729,-22.294027,-134.965443,-109.768193,85.885256,172.689302,186.972502,107.607858,89.125206,103.689254,91.42013,-13.322988,-41.038045,62.867223,137.729531,154.572944,100.902507,118.825175,170.370863,180.41891,225.105792,239.814618,158.146606,19.197642,3.117552,62.097068,77.305642,66.570299,68.859278,24.56898,-34.459296,-101.910637,-38.133325,-0.783777,-3.61883,-20.885682,-16.447073,13.829105,148.015006,236.570193,232.831921,140.307212,26.493036,-212.28719,-221.328912,-50.576655,4.848643,-64.653837,-129.695278,-90.864304,34.440266,74.207865,95.779478,110.701619,223.657918,294.413998,260.871501,170.625997,167.505701,237.523257,272.568194,313.011203,321.869865,281.739552,219.747763,201.820621,103.893008,24.050451,-67.995479,-49.484514,39.994659,68.058744,82.853647,102.13538,79.040243,56.229208,88.467862,175.995994,181.603246,79.068241,6.44144,-29.060161,-217.61904,-292.365907,-214.024159,-90.132317,119.792077,114.572396,65.134735,-49.608062,-101.544271,-92.807297,-15.939284,146.085976,178.960761,147.998306,68.766986,28.472291,-46.705258,-56.966319,24.882797,105.739896,238.885832,191.110176,138.319525,76.954326,45.296616,-11.338637,8.363729,110.513932,128.326362,94.363881,107.114355,136.170474,159.997793,137.844447,41.020467,-13.531057,-41.444808,4.587579,-5.201201,-60.773852,-58.024034,21.236649,52.573064,75.422744,124.123422:-53.922512,22.914058,-15.30345,-170.205841,-218.307607,-203.360196,-178.806469,-135.354673,-150.144941,-216.404722,-423.707879,-492.955502,-399.11332,-265.227269,-90.069886,-96.252423,-195.608207,-280.477946,-287.255063,-213.386721,-158.964511,-90.493834,-70.740759,-5.227441,57.464006,43.800656,-90.569722,-177.737193,-255.022354,-209.573594,-44.973616,3.294182,-25.77494,-52.956733,-41.573969,-99.488309,-156.54773,-160.155836,-92.210943,74.512818,118.083083,97.842667,66.077907,47.191551,2.961658,3.632831,36.041007,42.199482,-8.255026,-104.353226,-137.965308,-256.819223,-342.370846,-343.675706,-236.296312,-35.570354,-95.122532,-195.547693,-342.385079,-377.91931,-378.051985,-322.155928,-180.634975,-129.928399,-39.580414,9.637191,-13.000778,-144.892476,-207.691221,-236.317824,-222.748233,-134.205213,6.959023,1.587434,-166.456656,-244.790118,-274.010937,-243.686128,-189.533209,-176.487682,-126.286211,-14.228767,17.159308,-41.169241,-81.123706,-113.800911,-139.485644,-159.163035,-117.140771,-114.894052,-110.049219,-134.171154,-263.932385,-291.974101,-214.027958,-177.589984,-254.607473,-453.638509,-509.61663,-450.576337,-359.615479,-186.439316,-128.344395,-8.583438,67.254832,60.172648,25.072246,3.920037,-56.761694,-76.414477,-62.128784,-34.745958,7.121012,-18.655046,-56.014956,-164.413931,-197.394976,-116.196081,-28.272327,76.065432,0.676234,-60.96742,-139.296506,-160.449748,-171.504561,-149.83938,-47.602157,21.819419,99.633544,48.783788,12.835284,-95.412842,-170.153405,-274.305557,-285.082625,-220.606518,-106.77377,-68.132133,-39.203076,-45.179621,-92.196678,-132.71102,-178.142039,-137.783606,10.221261,25.282224,-18.699386,-55.736173,-16.354305,84.70559,86.227594,48.017166,100.929115,119.569655,49.358208,-27.725488,-161.082441,-175.486058,-87.16934,-23.175029,3.284447,-131.554981,-205.683799,-251.874886,-196.53461,2.701479,89.880171,241.154214,346.190779,318.8913,145.938803,65.789857,20.681043,42.10693,38.03656,14.470044,62.46168,119.276381,76.816189,-74.345014,-117.877404,-93.293818,-69.623728,-26.884114,78.771244,121.007723,118.518862,84.461383,32.447419,32.754657,52.979116,73.962233,139.794859,119.042414,43.423063,-127.214249,-137.656337,6.766023,66.387048,53.80902,49.937641,82.885793,139.718368,129.656898,47.656026,10.242175,-15.518165,-2.315158,71.547872,78.329174,38.7724,-18.217582,-23.483759,-3.765157,40.772492,174.041628,127.829671,62.536727,16.766227,-18.654085,-152.2026,-161.31859,-14.023858,79.005731,161.032631,105.134803,83.809742,64.147925,71.935334,172.001213,228.158852,287.033008,274.899685,238.430883,179.301897,180.652296,202.831453,203.205359,183.822541,154.518531,41.986841,-36.18714,-54.481046,-94.975441,-77.515291,45.650894,80.000076,56.626855,49.392354,35.753882,-72.221761,-131.802976,-120.02576,-36.814227,167.063039,242.538932,291.014274,180.155738,95.090111,-11.350302,-18.662591,-2.866065,-1.932485,-21.995979,-51.245797,-57.966403,-5.498909,35.81205,67.599942,78.511167,202.965576,308.267261,401.60997,233.151955,140.131332,32.573437,8.434207,43.691852,83.268209,135.674887,152.381549,146.763929,113.415917,61.983574,-134.571075,-207.024571,-139.3601,-33.762244,106.358238,102.538456,92.091479,36.196082,11.650938,85.447635,141.174274,119.394337,-9.84514,-45.114657,-71.524728,-96.35948,-106.295347,-73.992517,-56.08303,-81.523233,-127.017636,-132.47408,-103.014044,-41.115372,-32.383338,-11.946795,19.661303,95.988049,89.243428,53.382746,-50.406581,-126.84715,-266.66878,-282.759515,-223.598563,-185.768257,-181.204581,-245.056238,-232.80346,-141.196202,-99.828993,-19.908426,28.502438,193.990718,312.436088,264.303591,106.873807,80.496207,97.894729,98.013863,60.914174,50.42048,67.323463,33.91091,-31.883742,-205.377218,-250.092669,-220.501614,-187.57183,-140.430996,-96.131658,-64.538312,-55.343782,-98.972905,-172.352195,-163.704979,-87.639132,-43.002101,48.808568,101.912175,57.438971,-150.630024,-228.361756,-242.189994,-200.450964,-25.889932,136.451472,128.070971,-62.998097,-182.278791,-217.039271,-90.496281,172.221591,211.51637,185.538123,70.182619,5.478805,-30.562687,-4.142578,92.377241,148.387268,257.740196,300.204912,281.360827,174.342945,94.924235,-11.638961,-2.150652,51.689595,47.039423,28.709025,45.859853,38.637953,-6.919987,-25.247984,-74.163399,-114.392022,-95.124641,84.088575,127.728506,18.632482,-70.628831,-115.803868,-62.825896,84.20369,160.785381:-69.85846,-9.84338,-46.543695,-215.355222,-293.749576,-279.097746,-195.998944,-68.312025,-123.904823,-191.667421,-354.410602,-405.651421,-257.903583,-90.014026,125.89013,121.820664,0.179151,-141.089037,-188.708272,-186.363506,-141.7994,-22.078281,21.867176,41.920175,17.269933,-7.120398,-95.467955,-154.772796,-227.7799,-195.714298,-3.728234,81.483047,63.583777,-95.687913,-144.81509,-153.132383,-136.384074,-76.810092,-18.794399,145.149013,192.981501,127.303064,-50.300596,-76.288069,6.675983,41.823194,72.716995,101.603054,90.409344,-68.265607,-148.512979,-264.759304,-275.879474,-156.939496,-76.829869,10.741722,-3.182248,-43.972299,-158.338015,-214.338737,-243.436123,-191.694551,-47.146847,-7.915952,-23.639505,-130.642756,-197.852828,-276.60702,-264.841495,-210.019371,-200.57693,-161.298602,-143.965201,-206.767027,-360.849729,-371.682016,-290.666296,-255.150393,-204.05801,-178.199688,-131.530524,-56.162892,-46.578388,-122.597096,-145.373712,-134.483805,-145.074538,-158.014979,-101.469716,-92.780336,-171.451181,-240.56954,-317.912214,-294.972338,-191.876855,-138.996479,-109.59636,-309.137341,-427.841007,-447.218313,-345.128575,-113.682039,-37.842335,80.066459,140.3431,108.943803,2.800569,-35.812549,-70.088091,-56.532263,17.434386,37.93539,-2.269212,-66.996531,-108.637402,-217.891525,-232.443951,-108.537737,-12.63823,110.013285,84.83431,40.185643,-93.760717,-169.707525,-219.253542,-175.186635,-14.954225,67.247509,121.634544,43.863983,-3.998551,-128.489157,-186.60782,-211.509071,-186.053666,-84.240767,12.123895,12.835817,-102.341397,-172.184887,-176.992726,-133.820558,-59.324934,-15.628107,33.548204,-83.10767,-166.961233,-244.257908,-206.728447,-6.634133,93.997415,156.900681,103.11683,67.194601,-54.038304,-118.878474,-147.371038,-116.030327,-34.41361,-2.55706,-15.152568,-137.895944,-203.305039,-219.855813,-139.42672,76.141079,149.199341,284.406352,356.530746,299.182845,118.801585,79.332975,128.316338,159.168591,117.800287,75.972283,86.056554,91.029662,19.289901,-145.470255,-155.528021,-52.289399,0.485647,82.67286,107.654501,87.896926,38.665572,24.671095,26.339229,34.835381,80.041056,141.344903,251.405107,112.13561,-29.359463,-200.916765,-168.929386,-6.163023,49.01322,98.004444,97.798464,81.128821,19.454473,-27.589837,-58.436302,-6.093661,129.697827,152.903077,91.032269,2.523841,-12.78647,-8.145603,3.166033,91.523364,157.805782,199.199054,35.429014,-27.53888,18.546438,30.500168,-79.025666,-109.163556,-35.691012,14.194901,68.411558,57.036986,37.354607,4.643171,13.03849,115.688858,183.493976,239.388507,199.578372,196.712723,252.115851,274.140797,233.479861,206.942383,254.999867,289.366373,193.715155,3.458433,-56.566366,-111.04502,-90.414773,43.34196,113.170176,165.477296,67.205363,-19.477385,-146.426824,-149.702501,-57.193979,6.550343,146.329999,213.553313,219.306531,54.781322,-26.211719,-92.271283,-61.289211,32.109436,51.471416,58.015062,56.225709,35.968516,-43.881896,-76.605763,-30.427114,48.190095,241.450805,339.883017,400.75351,208.958466,102.006313,-21.614079,-14.115127,156.115595,254.219974,320.721975,248.923994,190.46486,69.177777,21.361806,-38.309258,-55.679579,-43.059194,-0.082049,103.562116,117.832342,93.332187,33.17156,38.488772,172.273757,250.243197,256.242215,48.992312,-39.016228,-74.703882,-65.976552,-59.833658,-56.821365,-38.173351,-37.908065,-132.001464,-217.938654,-204.465151,-153.026448,-140.732593,-100.350462,-40.109901,103.40743,41.680493,-47.256524,-184.408914,-253.782208,-397.608439,-403.732844,-259.315309,-199.152357,-259.027155,-367.414245,-359.195034,-285.709811,-247.988318,-129.231614,-36.557592,167.17147,195.236762,116.091197,-75.747308,-133.945356,-129.754876,-86.042378,20.130255,71.23829,110.302058,16.530746,-58.405093,-166.373611,-178.714411,-163.115815,-131.206146,6.293534,85.848167,70.892264,-43.974614,-106.270761,-91.025707,-17.085199,106.650123,113.167815,64.805366,49.872374,22.450143,-149.640491,-241.677088,-260.324213,-177.967651,24.408472,52.200921,-7.200135,-168.130633,-213.503407,-100.915385,42.660821,267.053123,298.954325,276.432544,144.81885,55.108608,-21.711245,33.696178,235.231337,294.040121,250.937485,105.579053,49.163485,-18.624867,-45.694305,-54.226103,-26.148533,34.311976,34.191219,-18.433995,-59.806824,-84.08683,-156.399758,-167.697213,-111.162668,-85.768739,-44.671012,-0.764377,-20.910717,-126.521358,-155.356641,-57.081253,22.508806,87.483455,111.629223:75.957517,199.978651,192.894379,85.852752,23.325352,-19.12465,-13.430162,-47.020616,-146.060041,-215.699054,-380.14826,-430.432225,-354.4707,-257.648952,-135.170724,-138.957631,-214.463506,-290.794237,-294.026294,-228.126607,-189.575062,-139.798616,-109.939995,-8.641255,51.648218,24.169018,-141.006143,-234.056682,-286.335224,-234.42522,-149.274225,-158.885828,-177.425144,-127.675994,-106.560836,-125.203356,-154.706448,-158.945624,-130.529107,-90.922221,-90.582673,-82.159471,-78.176161,-106.364136,-134.276797,-107.366877,-51.922372,-25.691607,16.472983,-77.540828,-150.642765,-308.329627,-406.04099,-473.938879,-391.545244,-174.504958,-163.136208,-230.567283,-343.417946,-371.939199,-388.819951,-349.486666,-186.372169,-111.54742,-48.330564,-53.413105,-70.941356,-180.179901,-257.88546,-311.678936,-256.588867,-73.162242,4.471155,-16.912388,-94.556098,-141.696626,-236.261174,-263.416691,-285.385507,-283.007318,-206.551402,-79.080916,-55.264933,-138.875577,-181.314696,-135.189598,-92.287313,-41.720904,20.293898,32.225475,-18.793391,-75.617138,-220.031944,-259.458477,-205.571391,-165.146506,-229.057437,-395.440768,-411.357792,-307.93544,-265.711817,-262.557126,-265.893392,-237.32861,-163.992565,-115.033308,-12.409647,14.964691,1.837392,-14.801341,-19.792999,0.421821,19.794264,-69.729462,-102.348687,-78.467503,-46.278811,49.893243,128.463656,275.988755,242.154627,175.58772,71.145071,39.397248,22.473852,32.133386,20.225239,22.781999,105.125646,121.34006,80.187144,-65.913831,-145.967776,-217.696198,-201.195242,-128.180361,-81.085249,-72.089999,-96.059044,-136.209177,-194.76226,-175.102265,-61.755344,-9.4098,-7.464317,-86.06256,-79.456747,64.373627,148.32768,229.372664,232.645733,230.683114,231.475437,207.80601,116.906995,65.678509,1.426669,6.822595,18.712665,8.367537,-11.020822,-105.743346,-159.671143,-133.350205,-56.192809,103.228371,164.950411,300.725071,362.756471,307.906057,121.954372,41.345684,-50.167173,-47.927401,-7.669874,6.755676,61.9611,123.475596,136.899558,120.270193,80.774652,-9.028422,-14.988288,42.012497,95.394816,127.08142,179.298317,160.083867,51.409239,20.557386,66.191005,123.823859,185.924078,43.819134,-68.901695,-155.575749,-71.671524,179.544407,209.63547,91.82452,69.987946,93.504528,91.837046,61.528125,-10.692612,-28.077746,-23.156535,-5.370754,55.935805,96.135738,82.679316,-70.415731,-175.782986,-192.23973,-71.367703,203.567982,204.150846,123.887995,49.930686,61.193297,71.873595,81.918553,158.565986,208.446579,267.375176,225.56648,161.350948,29.731457,22.737712,140.906385,211.226748,299.589878,305.380591,259.781451,112.505025,42.883411,-61.537629,-93.637031,-112.718261,-107.994349,-129.238048,-218.566441,-267.904272,-316.502757,-278.703518,-90.260631,-8.68011,29.755601,-54.746147,-124.032382,-211.027161,-214.811422,-186.473707,-144.066148,33.613642,152.995351,311.227483,254.189185,189.467502,76.215213,26.972342,-27.440975,-17.637527,44.905813,75.206317,77.83545,115.060306,125.65809,99.5748,123.856089,319.09215,420.72046,417.616368,221.138116,150.818316,58.830412,6.851548,-48.949871,-47.504307,-43.9568,-63.883636,-90.16001,-123.35135,-141.135269,-252.847526,-312.501991,-321.654431,-260.234897,-85.814309,-42.74981,-79.645322,-165.525288,-185.494249,-181.135144,-167.886333,-105.03777,-6.809565,11.846914,-30.365236,-47.183063,11.048114,63.159027,101.340785,101.877236,110.337878,14.71551,-59.021635,-138.948029,-128.701587,-48.485887,-7.633734,16.564404,-51.525529,-81.305842,-42.176913,-13.033822,-66.522287,-116.319253,-169.918461,-200.949382,-279.663446,-241.599819,-170.281684,-69.63229,-65.287998,-22.10586,55.504332,259.005072,310.457419,251.055728,104.679646,41.578733,-67.511588,-88.139491,-91.887025,-113.866748,-206.729,-304.71667,-336.789686,-405.536974,-445.580154,-452.04715,-413.552404,-281.132635,-115.985073,-82.045714,-147.452397,-196.039459,-189.476233,-145.119626,-78.757862,-51.251464,7.662112,-25.113157,-79.901657,-186.723917,-204.842776,-166.724246,-133.874653,-63.140528,4.873414,20.647873,-32.379056,-94.854417,-138.935769,-73.179428,140.593498,236.787509,323.29117,244.447164,186.751384,101.406212,104.620042,248.093484,329.052593,375.226588,340.093801,312.223901,237.837304,205.515871,193.88896,210.838684,179.416068,101.214557,-48.477089,-37.045765,-12.938214,-75.73757,-144.81252,-159.317284,-83.741113,126.402806,265.857222,251.763732,19.664938,-124.394946,-206.905858,-124.87973,80.590346,137.321508:21.62817,136.517411,107.997156,-87.501631,-186.257155,-203.54572,-138.115384,-20.252255,-87.050151,-207.295687,-455.463116,-505.729905,-396.721092,-250.786921,53.887372,111.972451,-38.909702,-254.898006,-279.630185,-214.352588,-163.418703,-34.77902,26.066285,92.43924,72.353021,23.304224,-125.8406,-203.93371,-275.583919,-232.521305,-39.816073,39.210486,11.229888,-155.198644,-200.980787,-241.158731,-245.197075,-138.43952,-47.775845,109.753234,131.300884,63.533414,-115.904826,-174.824148,-166.955094,-110.392958,-1.409459,29.730027,21.108651,-120.788916,-213.804971,-372.583892,-409.104379,-305.757665,-185.616424,-7.555544,-88.936419,-183.168398,-312.121465,-345.237102,-366.782821,-344.806276,-216.868938,-115.003451,29.076195,-37.676025,-112.563316,-239.194334,-266.231842,-252.026893,-228.461984,-153.972015,-101.864129,-116.956384,-222.320206,-273.54149,-268.271172,-219.160213,-127.806624,-110.34136,-90.626099,-20.603009,-13.115251,-98.213252,-123.679435,-84.25143,-69.19422,-50.3229,-34.440563,-68.097082,-194.317141,-253.168799,-294.599005,-266.003105,-189.036479,-169.83321,-185.484197,-306.196481,-373.968461,-418.988868,-380.880829,-225.439313,-147.550055,-28.085728,30.676247,31.226903,13.486864,1.344498,2.401976,31.969048,104.110271,121.838054,93.576579,-24.286821,-98.740673,-216.986937,-222.69186,-54.730071,76.210348,206.720552,81.640425,-17.890639,-150.330044,-154.25859,-37.439971,42.659274,127.019498,139.964526,176.44785,117.426723,39.794958,-114.733113,-166.796887,-202.717512,-191.281478,-122.330582,-49.225269,-25.024324,-41.344058,-103.355303,-237.759699,-236.522527,-82.509581,14.53773,98.855368,-20.608023,-108.965164,-145.792063,-44.042138,238.074208,304.422217,295.795895,256.433364,202.467358,43.307818,-15.269197,-55.192692,-38.074185,53.41145,86.859907,17.759082,-172.735035,-247.886735,-284.185626,-216.366355,53.140949,172.746051,272.260596,234.388081,182.900816,65.648694,2.268366,-73.10893,-46.040133,51.030002,66.413379,54.595008,48.934516,32.251927,-35.884316,-59.92477,-40.717075,7.761708,153.910575,245.980889,251.896209,195.618257,140.054708,70.394665,88.251238,147.736526,152.557184,143.138447,45.296066,-62.122607,-214.48347,-193.621118,-21.466841,62.781683,156.0731,174.049087,155.592119,75.054353,17.920471,-71.124563,-63.919119,19.1052,60.763274,116.044987,29.388582,-61.746251,-124.476942,-59.394988,83.077471,116.449626,197.350527,221.995968,172.686565,76.481528,52.761919,19.467514,28.067466,121.542924,176.725227,241.896079,219.011573,159.919238,-15.879136,-54.888669,70.985174,177.261295,307.687474,310.619485,277.957189,127.855583,28.187582,-67.283316,-35.2809,103.743493,144.066875,47.730192,-137.222127,-195.468458,-241.217763,-214.594434,-72.487335,-12.388832,33.0934,-8.423651,-69.638948,-187.128204,-206.583668,-168.699187,-118.705081,33.776549,128.468481,271.55147,194.761107,84.177301,-144.453853,-204.643054,-146.826371,-62.623375,81.726114,89.236047,37.792006,-83.766802,-97.876534,29.976499,137.871757,349.063133,428.523947,429.175247,254.671079,177.627101,54.578306,13.316826,51.183251,102.998576,157.388753,155.257458,120.553361,-23.276706,-90.012435,-142.365916,-143.083491,-131.102798,-95.779951,32.14218,61.219419,9.333321,-136.417247,-164.824215,-55.800416,37.637202,113.69542,-11.482871,-79.040966,-135.677572,-148.186588,-145.484153,-113.121131,-45.878779,-44.136462,-80.261023,-108.915568,-138.91061,-210.730144,-203.557364,-114.839113,-63.004545,53.632259,15.402014,-81.088879,-245.390625,-292.039593,-371.813311,-396.494031,-366.749646,-338.733456,-363.388862,-398.781169,-365.944662,-285.45378,-260.682347,-134.103063,-12.949897,239.990173,296.560914,211.760649,-24.284029,-91.299206,-80.215443,-33.342333,73.752703,112.977095,80.927344,-73.503817,-143.312324,-257.123684,-297.995743,-284.715706,-226.241139,-46.00078,75.541334,78.570952,7.330474,-42.364552,-77.072197,-49.323188,17.157682,48.637929,113.317377,48.95985,-36.784054,-204.076611,-249.057418,-217.909473,-151.427532,-13.614716,17.151475,0.784279,-72.476615,-128.369954,-134.016951,-33.337712,223.536063,296.722093,327.874685,272.654257,218.38336,102.494122,84.353605,163.1716,220.796402,296.771335,292.113612,250.638472,110.325098,52.620616,60.575733,106.903652,164.435397,163.681649,115.650148,-0.002451,-64.657029,-146.625204,-142.312191,-30.444813,45.561666,150.8722,140.605397,98.232732,-35.496161,-109.980695,-124.719003,-52.23049,92.887663,147.624034:340.401165,516.82281,537.251626,419.567496,323.923561,200.845705,187.174008,202.320788,140.365233,36.742777,-194.87197,-250.793069,-236.657298,-208.046333,-182.080715,-180.896359,-196.777813,-271.623308,-293.522149,-216.248819,-132.213429,-5.014326,-3.927233,-58.441341,-38.931145,-21.743778,-82.011735,-154.010008,-259.333433,-272.156551,-305.848841,-332.821236,-311.770472,-187.830164,-133.68336,-153.427322,-221.516691,-315.0721,-303.807637,-216.433992,-192.737717,-219.49355,-269.194794,-271.333611,-216.885841,-179.169913,-162.062932,-156.097843,-80.4385,-90.841642,-149.899311,-274.366136,-310.08668,-275.256744,-219.726625,-112.843247,20.716764,91.850294,107.687137,39.05222,-71.798686,-62.963821,-40.328044,-69.25179,-112.593072,-37.573272,8.059967,-30.210678,-107.785196,-168.707249,-124.153581,18.204626,129.244487,123.029327,24.199155,-1.844614,21.36651,17.765628,-109.710938,-184.467915,-182.819962,-56.087051,4.961267,84.183878,78.413345,2.291047,-20.751152,22.246729,60.379629,32.627541,-68.583437,-117.254058,-211.377709,-254.708973,-297.719051,-291.959939,-289.13209,-353.284201,-371.80175,-358.521005,-356.888527,-368.810771,-367.269461,-326.788866,-249.109396,-205.277183,-129.398328,-111.460825,-89.572851,-63.740573,-3.209844,15.416513,15.932998,19.420509,56.291326,92.757735,66.762656,65.521132,124.057684,267.32025,249.746382,171.532157,42.368799,37.398458,124.443518,162.447196,125.504956,90.423085,91.957476,81.223188,23.577946,-181.497826,-280.940656,-313.972626,-240.460285,-126.310893,-205.394012,-259.505871,-320.123386,-343.899186,-402.360555,-423.960123,-381.575697,-318.473613,-235.748741,-215.779356,-160.776074,6.668785,81.046427,230.634146,307.963509,410.369044,367.393503,279.85771,95.972156,50.644618,60.358112,101.246166,143.064853,114.896757,57.583064,64.782692,67.745066,66.464449,90.942899,222.632039,302.342792,409.858365,394.223024,353.268191,248.00515,175.905132,71.689138,90.241486,198.078834,222.846231,182.197022,117.933815,123.251013,177.08548,165.678946,44.921917,-16.029761,-21.730833,71.607715,105.041514,142.899315,135.488405,66.641736,34.831862,-17.828963,-47.946957,-93.556903,-90.818351,-74.606899,-48.941624,-35.989613,15.077429,36.574279,19.298994,-76.190974,-117.126343,-85.134853,-38.991504,-34.244348,-66.766621,-107.866595,-100.368893,-43.140976,-46.552381,-73.980122,-127.372829,-153.77077,-148.796496,-96.483568,50.766484,139.326385,137.644257,89.76621,75.379102,90.037599,119.885775,172.387998,172.107454,187.75734,225.428153,180.539629,-28.781524,-109.097332,-85.529908,-13.180189,71.505334,-36.915791,-111.751986,-187.033969,-224.163959,-373.596622,-438.992554,-453.73344,-415.693613,-317.90931,-276.943324,-286.038813,-296.765663,-275.86047,-199.140261,-171.962085,-161.845099,-163.535405,-183.091032,-240.012396,-236.653419,-112.357077,-10.29425,144.046852,172.22369,200.810159,223.119458,222.865104,208.712853,184.032819,111.936437,93.754238,150.101166,244.902283,247.954879,200.323,174.024006,127.64885,139.764928,268.463639,342.971649,400.56463,344.367147,293.735449,126.073293,44.242241,15.12965,45.14295,130.183238,210.46555,185.538027,49.956613,8.552324,-50.274635,-98.412809,-162.235003,-148.340286,-73.670825,-75.336288,-101.170603,-211.687064,-312.22868,-421.746745,-374.610858,-233.547499,-199.753959,-194.277378,-161.406436,-162.5769,-201.758928,-197.966341,-126.701473,-94.651527,-66.085892,-29.732913,-11.60856,-43.330721,-84.39462,-145.935727,-158.006465,-124.853061,-83.418157,-94.553157,-100.894879,-83.846275,-58.806374,-43.542952,-22.954468,-45.189625,-97.276674,-38.823051,20.302754,78.797792,58.196104,51.929172,98.969433,209.888473,262.109778,252.296081,159.343531,59.312881,-186.536953,-249.521523,-242.672437,-226.441974,-179.90099,-110.399954,-97.270193,-134.378291,-162.979118,-210.011874,-237.821924,-239.927348,-151.617152,-131.790854,-162.609323,-189.255336,-177.918285,-116.309204,27.73057,73.000476,57.911839,-103.966755,-162.687404,-143.10932,-116.926507,-111.275408,-103.198361,-47.015774,-10.119369,4.944184,48.660853,44.68247,-19.884655,-10.552518,165.554406,278.253954,397.900325,369.335661,342.688659,306.445185,307.971825,389.160629,444.791597,479.202002,432.584806,416.96127,417.627557,412.212104,371.529475,348.589673,294.111569,262.819377,214.047716,154.824432,115.298769,25.98786,-1.278565,23.668464,51.138982,135.327607,271.03607,282.689292,119.169939,0.136064,-114.148671,-76.44592,72.539578,123.298067:266.86891,369.181408,365.612967,238.831543,159.042919,98.721525,109.167079,85.407695,-70.595443,-172.480361,-297.71061,-298.692156,-245.618162,-207.272447,-125.711745,-106.766824,-113.832992,-174.695698,-218.098833,-261.397449,-242.013499,-150.28115,-113.624926,-70.607164,-35.154258,-55.134728,-164.987702,-219.118896,-259.464858,-243.768141,-241.077236,-278.879752,-351.830695,-297.474731,-236.810622,-181.43672,-187.236019,-132.652426,-98.522334,-169.56228,-302.760175,-320.912312,-294.213305,-301.106865,-309.798315,-265.793444,-147.517263,-104.91216,-63.196013,-115.093102,-159.2334,-254.033266,-300.855016,-312.521206,-265.47225,-158.228238,-124.681344,-135.096483,-173.301463,-192.607361,-231.174128,-229.636909,-175.86209,-149.295964,-110.524692,-25.83331,46.499723,81.856039,-4.375137,-174.561861,-160.052282,52.292549,212.219627,183.458322,-8.56261,-98.593675,-175.965034,-186.908643,-262.43911,-303.484629,-264.086042,-161.202067,-134.61271,-137.092367,-143.104122,-89.208239,-46.372642,1.792486,40.326446,53.448288,5.660356,-61.512941,-207.006754,-234.044523,-176.839904,-144.069439,-187.363024,-274.461674,-276.200158,-255.992397,-272.444681,-306.458825,-294.114048,-249.586617,-175.603102,-123.101319,-81.091796,-113.690335,-205.615436,-210.715953,-118.44895,-71.35847,-85.62935,-144.570884,-117.008186,-40.793257,-52.591344,-75.801786,-32.948317,81.673056,63.595212,10.880596,-94.916516,-121.465766,-89.327081,-58.199175,-47.041543,-35.53754,45.710727,62.190102,40.984453,-51.704931,-138.028812,-282.324403,-284.526922,-197.611554,-203.296132,-259.168844,-343.320414,-348.788996,-383.317161,-422.081531,-404.211092,-312.160163,-99.184687,-74.391468,-100.360722,-76.336735,-12.535207,148.212073,196.306277,225.510004,214.281665,181.478563,139.847428,139.30308,104.163602,82.07484,59.47868,48.795305,37.236883,14.979345,2.791652,-0.218504,9.897248,83.588919,149.129576,278.826417,281.785262,236.296754,102.87093,-5.092004,-206.796809,-206.124286,-63.825488,-26.733273,-67.637298,-84.99108,-46.310861,5.235897,-15.148439,-62.552632,-74.640874,-73.566172,-28.768661,-2.71943,17.808321,-11.263399,-104.056926,-132.077928,-151.385928,-145.695954,-124.640872,-190.531456,-242.897989,-243.309398,-183.236959,-81.53424,-74.840123,-66.972225,-72.310737,-113.592823,-121.633668,-59.068692,-12.630978,-73.23767,-176.358914,-154.822053,-32.23014,-1.590468,-45.334745,-197.430865,-260.411599,-184.769954,-45.123572,213.825786,246.084864,199.353016,105.171704,68.435441,24.014444,46.725225,156.925394,191.142241,173.970716,135.89938,140.190571,123.157521,96.003521,114.847677,151.421172,152.310304,84.735556,56.762224,13.091957,-9.39674,-99.390348,-168.871022,-263.867735,-240.316455,-97.062646,-71.006539,-111.243909,-172.221489,-150.566084,-20.670362,22.934618,6.777443,-43.563758,-73.497972,-74.479336,-27.151353,34.339194,31.561143,76.920873,146.927842,316.011588,418.313073,412.164058,255.406574,168.599345,153.393658,186.242848,206.274162,200.99406,197.791291,190.515313,179.803155,143.77288,143.060447,218.608104,270.728869,238.785147,67.283609,49.775857,122.667322,102.917887,-58.88925,-104.568964,-22.555984,58.680101,25.646867,-107.985298,-173.464255,-284.943345,-305.104934,-234.922562,-165.414521,-66.828371,-106.812981,-136.496528,-173.415548,-205.847628,-301.77665,-322.625998,-191.335289,-19.389552,-17.393417,-65.212621,-66.009496,-73.748077,-79.468117,-13.859442,58.371962,148.806253,76.520714,45.534307,55.465645,66.697756,85.748219,99.71624,133.806808,118.280746,84.981621,57.78604,59.014169,58.334134,86.816954,158.370948,148.161073,33.36532,-52.870489,-26.378983,89.430751,118.312978,146.99438,173.660519,228.004604,253.440294,254.5139,211.93052,138.760356,-61.414895,-113.237143,-85.318311,-58.376619,-90.652705,-188.274963,-223.34985,-317.837888,-374.015675,-419.07783,-428.006985,-445.718403,-373.793317,-331.630243,-318.036563,-336.722069,-317.972648,-257.789295,-112.669676,-49.1154,40.443091,-19.74071,-84.450868,-153.615245,-148.283559,-83.036656,-35.816503,30.235768,24.936878,0.590747,-56.891755,-83.227358,-107.664292,-85.791011,3.056026,63.91954,197.503666,207.257395,171.54156,92.749671,86.578355,223.69548,337.614175,534.414021,552.482768,487.84438,381.451484,358.866077,303.743614,281.211877,249.025436,227.785882,205.821577,153.048192,104.979206,16.393307,-3.221751,29.46349,48.288579,75.62535,182.284853,203.055175,39.434728,-86.852992,-163.585287,-92.669726,59.662427,98.273291:150.35466,276.508673,212.838548,44.991069,13.432723,-3.71422,-38.879743,-96.373454,-65.73563,-88.355598,-235.208834,-291.208223,-265.319118,-200.085833,-82.051641,-68.487691,-146.186256,-228.668344,-220.166476,-164.172969,-145.387612,-88.976145,-47.961987,48.575351,135.548272,116.712517,-83.204373,-209.691992,-338.04861,-317.197235,-237.218156,-217.145027,-189.743564,-150.262266,-117.676915,-82.879979,-106.101372,-158.620146,-147.246704,-75.804706,-79.673886,-115.52925,-138.009936,-126.074373,-127.59839,-129.877376,-96.863766,-60.33187,-30.559392,-185.414762,-281.063641,-392.820442,-399.958,-295.971653,-208.03212,-63.622909,-66.322787,-126.339553,-199.411603,-179.104277,-141.495617,-159.474435,-186.941494,-153.884308,-35.748726,-8.797877,-33.864967,-119.277428,-163.419321,-172.289331,-147.570514,-97.702406,-25.005423,12.096156,53.712359,32.878459,-72.516206,-117.393599,-195.498727,-230.258067,-205.971625,-66.687415,-10.397611,6.069624,-1.90573,18.627963,11.78789,-34.418188,-11.364076,1.035932,-36.99162,-88.50995,-225.956573,-269.139167,-239.100141,-199.423618,-232.131194,-363.481648,-369.548567,-287.188982,-277.276947,-322.954052,-315.41459,-196.136261,-82.62692,-62.18637,-51.124937,-53.588935,-39.096695,-3.539846,70.982896,78.487838,56.085735,18.108248,-5.131042,-19.990276,-4.401352,74.24439,113.544441,135.011704,82.891215,39.283763,20.21425,54.028892,120.314421,124.156191,70.502344,50.033575,67.607517,63.616102,13.260974,-140.570777,-171.531016,-94.100969,-50.156724,-64.957875,-139.960838,-153.108195,-128.635753,-135.480707,-204.480827,-214.643822,-141.170102,-91.312012,-63.753446,-164.354271,-193.848714,-74.690258,61.250386,316.93258,365.473661,312.453573,232.208705,207.516871,158.075755,103.787693,-11.55761,-10.956933,79.939235,119.466284,108.254511,17.11648,-5.45585,18.282776,62.193971,197.331639,260.750223,331.589074,263.146607,195.047469,132.741914,136.135118,116.349664,82.932697,28.2951,48.488351,152.366487,152.199082,128.741956,121.098527,102.387322,-6.528443,-33.55324,35.043384,82.193332,90.212799,147.225274,177.855547,165.281737,131.936927,91.356719,97.541041,97.527805,11.419375,-38.85896,-124.660494,-131.326701,6.834662,88.7894,102.037428,61.337927,46.80091,-6.189358,-10.184829,-0.364982,-30.050592,-104.658956,-88.13638,46.543454,71.200721,38.362627,7.295262,1.811641,-29.619573,-26.356075,89.904144,181.183728,164.810464,111.789637,99.587265,43.873067,13.585718,69.914221,149.756062,256.023576,220.106206,166.682466,38.190881,0.451322,51.951418,106.386198,173.982537,153.455976,76.638933,-121.692002,-179.885899,-219.381044,-228.565296,-249.734097,-250.125765,-240.075318,-289.227459,-318.457887,-350.527092,-347.197152,-271.389358,-204.680316,-77.434041,-85.242563,-145.397294,-227.968553,-206.750831,-90.396333,-47.734542,12.512325,74.135649,174.120657,88.971176,20.650097,-96.792445,-134.844722,-134.269411,-110.119238,-30.225337,54.296746,60.489446,39.035982,43.29145,112.582278,176.022347,322.748107,385.230365,420.352575,330.338361,289.268109,207.572501,147.882032,101.061909,132.307256,178.57093,104.292376,47.548612,-34.953851,-70.452466,-180.568123,-249.220502,-274.140503,-193.007033,-23.161876,-57.82343,-97.096541,-178.251792,-255.66757,-362.230229,-326.769492,-180.560884,-170.52757,-193.425215,-172.168817,-157.825294,-188.94194,-195.61013,-145.010938,-125.541495,-148.471874,-158.861891,-145.644145,-165.302671,-192.574788,-194.687657,-159.101559,-58.5408,-88.284095,-151.764227,-171.908224,-143.691125,-155.373468,-170.781944,-213.159084,-254.03401,-263.127086,-133.59073,-80.172065,-109.163086,-143.690232,-42.928979,65.224653,199.486974,203.7023,169.156347,60.39175,-1.705286,-115.017334,-143.196286,-129.199903,-99.459192,-59.82161,-135.506641,-200.592423,-276.556537,-244.741281,-86.654083,-22.563865,28.480902,40.890981,50.083042,64.750802,50.274514,15.394728,28.624757,67.007971,69.944938,76.05329,42.717194,-17.18158,-172.391287,-211.505615,-177.281653,-148.433307,-82.084805,31.273622,48.822526,-44.975964,-109.036453,-117.101048,-48.173427,97.980728,146.900307,278.782938,363.995426,327.220469,232.900679,230.338215,268.656005,281.045863,309.040203,295.160893,259.478292,205.979655,187.661407,194.643002,240.804654,296.185955,263.171263,153.2315,59.314177,16.019681,-50.454902,-61.112311,3.480557,58.766061,123.547361,146.636321,157.923116,94.750598,1.199006,-155.287617,-147.416962,-27.15441,23.234178:left
-414.20586,-202.361542,-178.961084,-247.71483,-240.687398,-108.393413,-38.612231,9.404725,-45.788625,-55.86823,-72.377897,-122.690616,-212.57136,-217.324937,-209.887717,-214.615422,-185.129527,-14.208856,87.922923,187.682919,189.138094,124.15305,57.825117,-47.965287,-18.238271,16.036958,40.553978,37.918342,39.235102,37.805584,37.881869,38.202168,53.576193,160.396766,207.7468,205.5174,194.055839,205.504731,203.653152,124.720088,12.445794,1.329262,5.901448,-22.909472,-108.51352,-141.53234,-156.460627,-136.441293,-97.017202,-127.503477,-149.475433,-80.345914,19.419265,166.507438,140.318513,-25.534301,-0.70545,81.807253,162.084334,150.682418,141.460572,139.871072,73.313803,22.001487,-23.565697,11.967906,23.32646,5.627856,-17.129121,-90.222157,-129.550912,-202.529782,-185.862528,-102.603875,89.326214,121.799321,58.314957,28.344515,5.574882,-45.835236,-186.785896,-151.336744,-119.132193,-171.12161,-192.055108,-73.035851,8.893792,3.589056,-98.50467,-98.307025,-80.080629,-97.32373,-114.683322,-127.263433,-237.144789,-314.080751,-437.612974,-465.428716,-423.493145,-211.699521,-101.077742,-45.281451,-83.946827,-203.291187,-343.734688,-371.911556,-273.539485,-175.051252,-66.08955,-85.996325,-110.655458,-104.209305,-190.378721,-281.305234,-240.373787,11.760089,160.226331,271.234669,208.575006,57.739694,76.853092,96.115702,-10.105448,-77.583701,-39.215566,26.158904,61.756494,11.38797,-164.817133,-263.287298,-258.142605,-234.383349,-238.693904,-261.008855,-255.197815,-216.850511,-226.339525,-241.122988,-272.897405,-279.56201,-271.840667,-290.891919,-330.988307,-308.193626,-199.247189,-83.953693,-84.805055,-174.8926,-174.433169,-92.186858,-69.296337,-67.919767,-121.353269,-176.676219,-284.572114,-296.146657,-260.273917,-262.395722,-297.683712,-314.666124,-349.66207,-314.990436,-282.003958,-221.676431,-189.560295,-188.473405,-223.764018,-269.495074,-244.959332,-214.236799,-125.541327,-78.615472,-8.39292,24.66625,102.157185,107.63493,14.906599,3.307445,65.462808,227.297047,287.272399,302.750437,259.04605,133.99518,35.056873,14.569072,12.206319,26.004712,73.814531,73.157568,29.510334,22.30131,-17.94052,-151.05096,-189.371855,-135.047978,-108.827761,-177.020054,-231.848659,-317.425077,-378.901773,-377.909397,-315.990015,-278.821987,-219.03559,-203.133481,-212.411101,-231.04057,-290.663486,-384.153847,-421.373773,-407.283435,-355.040024,-227.370219,-168.76036,-21.810268,175.547321,274.349652,445.714982,497.826851,487.938532,428.621785,256.585665,150.539347,-77.876452,-139.762128,-90.85177,33.003248,69.576944,49.869548,-2.839768,-150.306173,-250.681298,-238.991308,-107.626799,-27.269665,97.185607,137.388498,167.958973,156.486516,108.586009,121.695237,149.112106,133.26032,74.451985,-107.203635,-207.392848,-333.259164,-254.828648,-140.170419,63.140577,91.710338,71.148097,64.994885,83.584642,111.937327,163.391233,137.349114,115.280221,121.071241,111.369493,-69.961862,-212.215395,-420.757435,-440.554289,-373.813338,-203.547392,-154.182236,-111.835087,-83.994198,23.290994,65.848243,62.097735,88.758247,121.767751,133.00778,128.950969,111.791035,77.680906,27.362057,71.289384,98.118976,63.9602,31.777182,115.44886,217.307129,332.7445,295.469112,116.573269,86.773617,142.600989,267.367539,295.657399,233.55482,170.598229,77.365254,19.753258,6.682552,2.496067,-19.022179,-90.055302,-111.952301,-106.208993,-92.487664,-40.37216,67.11347,97.756107,110.938442,120.696135,74.006405,11.917886,-76.615612,-48.471704,-15.88393,13.953761,31.013021,118.215088,147.919448,71.715231,-2.248003,-22.005809,104.445959,120.712248,60.316548,65.660697,138.590654,110.328442,-129.939758,-282.496264,-222.60479,85.383888,247.122691,441.325239,457.78725,363.296949,266.339803,107.533431,238.10708,353.599191,439.934564,404.650711,282.145171,219.139725,104.258706,69.306895,85.309174,102.02102,101.063783,167.097849,225.034258,263.265997,225.295239,143.375394,229.623123,326.51498,457.461207,465.070805,436.974466,414.262801,302.87033,153.235472,116.226395,124.15022,145.554588,230.32708,278.980711,289.722807,248.229676,168.524281,246.150709,310.420843,303.629154,238.543926,87.010873,39.738262,64.162347,135.067455,151.004776,172.095719,211.821261,349.111768,401.545801,341.823666,211.591446,45.017472,241.868253,302.403484,217.138095,179.786952,139.263396,105.297856,109.360595,218.029463,256.7576,236.063474,205.789824,191.499239,187.545104,119.674787,46.239478:-442.460438,-304.372052,-246.353262,-188.961991,-170.240026,-183.132128,-204.722754,-215.404061,-207.748339,-184.004306,-115.569926,-121.28416,-215.177468,-263.548003,-293.336593,-271.12701,-174.576464,-1.796222,56.327024,32.683135,6.037175,-12.006509,-30.134556,-112.452772,-156.688484,-120.340325,-23.166169,-18.624117,-33.797273,-25.095566,-14.564421,-16.41387,40.438551,194.266619,233.146094,208.178275,196.344393,191.511874,168.599779,31.853192,-74.238146,-39.159123,97.727299,122.520189,65.202313,14.072081,-32.896197,-8.382319,32.537682,-62.797437,-104.07167,-0.735219,113.574012,244.592729,208.354815,17.8678,-25.656785,25.610179,96.810768,120.958241,214.762009,227.412672,109.879807,34.681167,2.353364,139.701723,184.618042,146.102789,96.138515,-18.863892,-51.003135,-54.080813,-31.85089,20.467927,172.109553,214.394495,158.804144,84.128514,-71.955771,-149.185085,-252.31008,-136.130685,-51.413024,-78.297452,-140.056043,-97.166881,-38.456073,-98.26405,-192.883794,-134.581804,33.138387,49.166995,-61.745702,-152.262429,-319.835557,-393.758796,-511.660208,-453.171231,-361.285723,-164.721043,-96.575031,-51.848832,-57.371499,-148.514253,-306.31911,-303.300761,-153.130231,-92.524785,-59.536511,-62.525385,-67.341136,-94.674018,-210.059404,-212.464056,-127.039211,137.026038,236.358697,187.627463,56.680387,-131.976765,-32.373853,23.233563,-55.428683,-121.091128,-112.850382,-61.246724,-16.081054,-73.015545,-265.570034,-254.999961,-169.259232,-70.892812,-95.096575,-213.295952,-263.899744,-319.894986,-356.97619,-352.377544,-346.240743,-352.663343,-322.083037,-308.415784,-360.254299,-404.894141,-411.368223,-268.345736,-206.769899,-182.347412,-175.979555,-142.300819,-155.671633,-220.302998,-194.206058,-181.051415,-258.04575,-287.307821,-253.094689,-261.345452,-393.958555,-461.442023,-456.805353,-310.265095,-249.910536,-151.732522,-100.942503,-97.578058,-146.501196,-247.155016,-256.721933,-209.266321,-72.202687,-5.526387,72.23138,74.416615,83.257898,76.328692,-29.12839,-59.780966,-3.306276,186.686862,272.35847,288.868227,212.542843,6.354537,-107.525302,-115.740147,-97.701024,-79.391766,-67.201632,-102.407447,-197.085965,-231.770976,-250.197467,-156.734548,-86.740959,-12.013584,-48.299429,-181.022273,-227.611938,-331.485093,-393.294044,-355.311088,-219.710075,-171.689433,-149.083797,-160.729135,-181.019436,-183.297662,-215.614704,-326.725537,-366.357013,-274.500534,-173.02899,-74.433341,-88.189151,-50.771835,141.160695,236.883254,355.825377,382.72343,382.052065,335.574749,141.519056,21.304602,-162.885989,-158.120861,-115.991542,-27.51994,12.248833,11.732565,-34.533374,-178.499004,-274.750316,-247.746046,-88.592556,-16.980375,39.066086,40.972355,57.696307,82.186655,116.220341,103.562711,117.091493,148.308545,114.660907,-19.039666,-78.214653,-152.723468,-159.729293,-107.822409,60.571283,113.228606,106.635795,81.283502,60.871341,66.234852,93.108609,125.877446,124.95062,118.976981,115.764574,11.215339,-103.751652,-328.120973,-347.842686,-293.552413,-211.437203,-189.910817,-107.13993,-53.636425,10.147566,7.170305,-10.707931,83.81779,142.442377,175.987715,176.895779,176.727548,125.421529,-31.612871,53.478021,145.332123,164.191099,132.529639,179.47285,235.806824,265.928332,221.007062,125.259637,199.971427,267.581566,323.762505,313.731721,245.285444,174.45151,15.44693,8.055729,40.880071,20.482142,-16.592253,-33.16006,-41.337412,-107.880134,-134.574031,-138.21882,-67.679637,-3.42088,90.833543,92.288218,59.109973,36.971485,-56.730583,-88.532623,-36.710416,111.899995,165.233577,181.421559,140.932227,1.547966,-64.550176,-32.305393,179.905911,225.382703,172.290357,169.774013,242.860805,208.084994,-24.567782,-75.100575,-7.584045,147.378834,206.788022,306.383146,367.287426,413.759249,333.085458,155.34648,275.983429,377.970413,470.813132,470.478634,425.42307,349.044791,133.419094,128.355862,177.618397,232.703994,274.720659,375.240433,360.896093,202.984918,139.624105,171.379319,325.074553,425.251916,590.674428,584.013891,439.931024,391.462714,320.213934,164.5047,112.660678,113.168188,136.819882,232.195249,294.780574,322.079264,262.213631,109.255416,158.729701,251.399922,381.169064,368.103611,177.08467,88.535707,103.905385,145.555089,112.872004,112.458551,190.813777,414.409395,502.146401,426.599087,223.702224,-89.04675,126.62293,233.429917,196.970553,132.932326,12.147041,-22.569868,-15.311339,16.426924,56.177023,150.583447,167.252313,140.791695,118.999709,98.678409,66.493433:-344.948366,-241.96618,-183.404971,-103.715795,-95.190517,-108.043908,-99.781639,-84.330574,-204.981686,-273.616223,-247.167091,-198.856319,-232.59546,-284.574276,-300.671456,-273.099544,-184.195702,-61.139289,-44.261294,-78.962311,-70.693186,-14.6159,-5.312983,-47.54627,-103.316045,-108.696064,-65.333523,-20.577591,65.090018,75.240365,33.111816,5.882163,7.981031,97.179929,112.346127,83.628802,90.199019,106.040028,95.296187,42.415367,-65.574265,-90.338713,-10.319856,54.72013,93.780316,53.633164,-43.408742,-54.474925,-9.868205,-18.913447,-21.464022,74.520172,134.541655,162.597581,115.516082,-34.329702,38.738285,160.350265,220.068498,151.10888,90.72158,98.577475,27.435818,-35.932259,-13.825541,131.87208,114.678146,-33.599037,-51.254302,18.981069,26.309249,-70.400556,-112.430138,-41.795088,171.017565,234.825564,217.65656,166.769323,54.936415,-12.258475,-146.739588,-108.009654,-42.440294,-7.20121,-39.724053,-87.466283,-97.881117,-129.154408,-111.613698,-65.041863,29.202257,43.537735,-52.034032,-153.424727,-322.189029,-360.161082,-362.269199,-269.064946,-205.373854,-91.430659,-74.340025,-159.373993,-202.939312,-223.61191,-274.17702,-296.792108,-270.528388,-218.916959,-86.530766,-56.283472,-105.618936,-156.724518,-226.580867,-164.787429,-95.589403,66.638499,133.514565,123.880501,39.339045,-130.832488,-55.343397,36.735231,72.813116,24.015585,-59.228592,-63.186231,-49.812695,-91.441406,-214.064471,-216.903005,-195.849406,-138.300252,-125.661069,-232.011842,-320.519645,-442.839745,-465.93794,-453.398553,-424.94218,-389.774899,-282.403151,-264.755634,-357.136412,-434.35567,-487.873174,-382.298076,-322.86876,-193.872446,-134.076003,-114.213983,-149.221735,-178.116773,-106.349219,-123.697321,-293.147595,-307.63175,-145.02039,-110.514855,-260.873702,-379.891269,-540.307948,-421.224085,-262.605413,-19.132713,-8.5278,-121.618332,-189.504545,-299.631834,-266.375201,-193.487309,-94.390477,-81.387307,-19.002754,18.835651,-21.745897,-94.280949,-171.437476,-82.275608,-13.567476,135.562448,194.99269,179.514788,93.974402,-106.600256,-223.337015,-251.610713,-255.538027,-223.282194,-133.729004,-114.736259,-193.134035,-275.512659,-344.95889,-197.242552,-102.890716,-12.994672,-44.113448,-161.505259,-192.677841,-250.616483,-332.157156,-328.790253,-237.278254,-192.722425,-184.794455,-199.740313,-162.368296,-127.14187,-103.207557,-187.284314,-253.242605,-247.927674,-166.19453,-18.798941,2.873554,-6.542046,100.78302,200.089406,349.757312,387.890235,388.338573,337.02065,189.650035,112.43238,-30.665549,-80.235267,-77.537034,5.75547,74.689608,70.087998,-10.698151,-140.415383,-102.18533,-29.97951,107.491203,142.250162,169.810533,167.897186,105.929812,65.231808,58.439799,166.221206,237.11142,297.534533,246.574978,93.642818,52.124775,5.883303,-34.196566,-11.540489,126.001156,174.043875,96.008837,16.593952,-21.758795,10.320311,31.082852,-16.928117,-16.611763,84.3114,125.451109,34.694554,-72.150867,-271.388244,-299.322314,-243.392239,-130.963149,-96.658944,-51.595834,-32.034543,34.126689,65.730081,107.164311,194.993466,219.122256,183.942307,185.675679,240.253055,219.524857,95.592173,132.993468,202.049028,251.75554,239.030816,231.709235,233.19473,191.290402,140.801219,89.853958,206.505936,260.213605,263.407764,243.459565,175.781506,107.382802,-14.252672,-13.456926,-33.972554,-104.805167,-69.524624,68.72528,64.909267,-68.749572,-112.896948,-70.605103,20.439465,43.477375,50.870881,42.222473,-5.400025,-44.230013,-85.368706,-4.992686,56.254515,155.786414,180.05222,158.543154,123.901479,65.907414,43.852864,46.639808,205.421776,287.082622,291.527091,261.979862,252.251024,208.733284,10.947143,-18.30208,33.524895,65.39461,63.961474,162.761038,229.506772,258.817851,221.170881,137.297211,182.290949,247.136628,354.800259,370.974396,311.932993,241.728447,113.062073,151.024728,192.254276,179.999099,148.482145,164.709751,212.269573,212.196574,138.18259,75.507787,235.953176,309.386315,351.341946,325.980852,280.866369,292.381374,259.107456,185.215473,214.075307,247.835347,195.469022,93.93406,93.160595,137.042638,153.27518,137.593942,133.063832,177.726482,305.195033,309.260455,147.945595,83.943698,120.908904,186.765573,186.138635,204.231225,223.016514,261.671443,329.468247,373.040484,227.588313,-96.735283,-12.914318,113.592944,271.267633,252.06808,123.443992,79.572328,26.776488,18.806968,47.923269,108.690089,121.757556,73.375167,21.008099,53.633082,119.341797:-357.443874,-212.296322,-147.228591,-139.724691,-173.839615,-197.434937,-157.120411,-90.38694,-176.952786,-214.399952,-182.234978,-164.556852,-207.707692,-248.012413,-301.25435,-296.759497,-200.973794,-40.519459,5.077373,25.42364,32.803629,47.133653,51.51229,41.168347,11.328698,23.510684,73.676669,85.28321,68.263453,32.172627,-38.839874,-51.517614,-45.668787,76.363017,144.643035,152.036784,133.949832,170.388582,192.601503,101.962162,-76.852694,-105.167956,-60.434364,-39.329367,-49.768572,-89.462303,-215.224683,-253.571052,-234.325591,-184.205494,-144.273192,6.04385,78.85685,83.860293,28.121799,-25.750009,62.493862,116.480463,154.54491,146.873943,148.401597,134.07962,2.728075,-81.924393,-152.808795,-96.99347,-79.621781,-75.41128,-75.796533,-122.904996,-151.451814,-178.760337,-186.655153,-142.468147,-1.555504,41.351921,61.42595,46.232854,-32.908247,-85.980099,-185.678664,-204.781857,-177.461057,-113.570888,-87.389753,4.841974,61.602599,53.795098,-100.134256,-124.255863,-20.013968,25.795239,-19.977645,-111.036739,-364.675336,-470.411152,-532.118936,-479.812533,-444.306788,-285.790764,-190.498302,-134.09661,-161.394245,-241.021117,-347.628117,-372.929463,-343.345831,-300.392125,-190.728544,-166.189051,-205.147157,-226.355579,-228.481879,-174.129737,-90.640019,192.368714,312.496062,310.533963,218.932807,81.512654,72.887376,88.453747,92.87085,71.581959,8.852867,-19.172134,-55.712664,-94.684149,-262.803709,-343.757111,-303.66655,-214.96746,-218.406117,-286.284599,-310.038568,-326.107877,-364.546118,-386.710948,-414.107613,-400.555954,-296.844356,-247.882722,-239.700367,-263.573615,-275.817416,-155.706007,-88.547997,-71.908117,-96.288845,-101.461279,-89.478206,-83.16084,-127.410984,-175.266594,-258.600493,-245.307719,-145.000468,-123.682457,-202.760109,-274.012847,-376.628465,-333.339187,-266.053825,-119.554257,-74.997119,-118.355045,-176.761069,-231.124399,-152.865708,-100.084936,-63.731475,-54.273721,15.51015,38.216902,34.277726,31.228209,-1.398378,-51.511518,-37.965407,90.241234,162.503761,202.665866,162.543785,16.017314,-115.846732,-116.448801,-16.676115,23.608825,40.962642,15.248435,-96.579052,-154.396262,-196.67055,-123.692143,-77.777318,-66.28751,-126.128145,-303.669456,-359.293192,-417.727259,-493.996891,-485.832611,-375.564949,-331.981978,-332.329971,-358.205134,-335.849788,-270.253617,-140.531667,-152.236536,-199.953062,-196.202781,-120.936495,5.99992,22.282786,96.148813,259.910624,321.792539,423.843332,464.56707,452.827088,392.177975,232.182322,162.698764,56.584473,1.308353,-16.044421,-0.693785,54.151581,139.429168,108.72681,-59.95953,-133.943221,-77.605842,89.916862,151.822045,265.829147,319.990512,354.797361,324.06232,237.051167,244.853695,284.360673,317.687727,285.099114,177.786422,135.634748,71.56547,13.53435,29.201935,118.117267,134.894586,114.260075,99.11592,51.449175,19.316169,-1.987563,76.472332,86.912192,17.463559,5.214451,-7.537745,-77.003781,-269.045455,-287.232554,-240.795361,-181.828815,-168.323161,-54.83334,46.129862,161.653977,141.569328,102.347465,159.509531,162.309609,122.048335,134.124414,196.245611,187.975328,98.140471,133.152297,196.248404,240.152527,245.451712,337.985468,366.907469,279.285336,215.097256,168.300385,220.553092,253.597635,292.488162,286.364444,182.062829,110.085623,33.403893,1.231553,-30.769951,-72.715572,-47.497988,44.661777,48.962696,-13.234654,-33.403039,-38.222298,-13.011587,4.064953,35.383213,44.33111,22.590882,-22.47316,-161.911678,-159.915051,-106.288512,-51.947222,-28.040725,67.20741,85.581887,41.30372,15.603394,5.343944,87.599551,128.684649,128.910232,125.519375,121.411812,62.03382,-125.297826,-170.414248,-137.883795,-45.12238,19.914507,185.517982,238.898333,214.785599,157.540246,52.175728,141.655026,248.576208,366.738435,347.214431,233.370124,169.834986,68.552607,49.851901,67.932305,98.061056,105.909658,160.929502,199.670101,207.445893,177.417871,124.177967,146.001578,195.933928,310.538517,326.319801,261.762167,224.536665,169.421987,132.495812,143.810472,183.849827,178.635943,153.642749,155.177414,159.5429,157.375461,162.079885,224.552724,277.045788,325.806578,270.467252,54.782869,5.542519,103.053587,163.374813,148.895554,173.413742,214.922033,284.802692,305.280193,248.467616,150.308304,10.360286,160.933792,249.307743,289.447983,280.729192,259.511225,229.798863,136.761339,96.022718,129.818127,229.607773,250.233601,209.447081,173.271998,205.1998,255.134842:-236.245509,-221.291601,-163.596492,-44.051645,-47.947777,-179.678357,-237.711561,-277.240697,-314.038197,-325.543957,-257.798973,-202.738357,-198.735352,-253.424231,-345.730529,-352.435922,-314.024927,-254.227684,-224.800667,-111.809757,-24.212663,98.05735,93.530235,-9.070914,-63.072216,-48.350974,27.969608,83.212962,136.392319,104.784749,34.423914,17.153843,-24.075293,14.447549,61.741416,129.021847,155.457193,179.377832,145.626433,-35.485964,-173.387651,-139.703272,12.092899,44.63876,-18.686641,-98.674748,-245.232645,-256.781635,-181.868713,-139.055003,-114.734939,16.926831,93.667503,157.159857,128.274889,34.676465,107.575389,196.500674,264.089218,224.427015,117.544861,73.489291,-13.320671,-64.742075,-130.233748,-97.491524,-81.692729,-77.654304,-79.847806,-101.499353,-120.650456,-144.310753,-93.845862,-46.401132,9.125585,31.019929,79.85948,61.130954,-54.150293,-103.137876,-136.779693,-71.374005,-14.596957,85.591111,104.360267,68.773373,35.125447,-50.219917,-62.79511,1.64334,167.478095,199.28813,92.470106,-21.895652,-266.583822,-362.984222,-413.179058,-295.367999,-223.700572,-99.863172,-77.113384,-139.97475,-185.284867,-268.746136,-339.681137,-327.63638,-238.499892,-190.594902,-112.921771,-104.815489,-176.471154,-230.582762,-253.538709,-105.291004,-20.64798,150.733172,241.605976,293.123623,229.060969,50.366867,45.533102,112.864818,190.972024,190.613356,144.776614,72.190786,-115.891825,-177.128414,-222.99663,-249.210319,-260.290754,-237.148054,-215.820719,-238.153078,-279.398806,-367.618153,-393.713617,-352.922477,-227.466859,-191.28466,-193.798617,-205.496585,-221.003931,-247.386704,-306.76533,-236.382388,-162.845956,17.729526,87.972491,81.426719,29.643472,-40.730241,-45.537954,-58.929237,-106.620213,-96.04206,-38.538373,-57.304566,-206.968497,-292.36163,-374.839875,-292.799689,-217.175822,-56.876187,-7.854905,-70.914263,-158.191886,-269.709675,-201.118183,-133.653827,-35.631299,9.504238,151.446585,198.198602,123.176318,40.996235,-8.705635,46.950494,45.312095,84.37248,140.539999,164.136402,89.028088,-113.851341,-137.831274,-95.915226,-7.532354,34.164393,100.046103,112.992312,27.950343,-86.404187,-274.119733,-217.557856,-146.416915,-47.94179,-53.030755,-177.215635,-246.62351,-341.665323,-428.330278,-441.908603,-345.001188,-256.068757,-145.874253,-152.537706,-182.748258,-185.28674,-225.442766,-247.267737,-205.586356,-35.008863,42.545652,101.323834,102.887069,85.435861,101.464648,147.036095,317.722725,428.771888,552.432607,511.049607,295.179404,191.995035,78.531747,64.752254,69.522602,111.89869,147.62629,130.626237,62.82566,-77.081448,-78.446811,-24.739775,122.847987,200.25821,325.920054,350.192914,311.1028,280.012802,279.78295,343.204547,374.998058,422.258459,413.710472,284.919531,186.372471,67.515702,161.763274,231.142341,272.635357,267.635087,261.998284,234.014013,122.101135,62.577985,-21.493313,-3.748982,25.982073,80.037132,84.090258,-22.267038,-114.55108,-284.297183,-311.936456,-262.121725,-130.806961,-57.116067,61.264963,74.345209,45.545585,25.396238,26.69511,128.806069,160.500392,146.887001,132.758201,94.657427,67.625227,29.744206,99.330346,168.862068,219.672936,214.325442,298.932769,342.899575,252.096286,150.467634,26.824123,82.665823,146.505515,256.864269,266.274829,137.58083,34.19959,-86.271471,-40.281374,-35.258958,-85.956578,-44.423134,142.799026,161.726605,24.397771,-51.158885,-128.45965,-76.420409,-21.795961,48.496638,56.765623,13.819552,-48.965176,-195.266228,-217.782351,-169.415719,4.642212,105.697253,190.420331,139.277041,26.115396,39.087439,138.228606,196.194714,216.07446,275.968654,308.197405,273.840179,182.622329,-41.427755,-151.299386,-143.38947,-67.982179,-39.014793,20.951946,70.141799,119.295806,76.104063,-42.707652,44.422972,152.291031,308.626527,301.274392,124.893204,12.045281,-120.915299,-29.299845,58.181624,160.961596,177.703834,214.890239,226.252271,161.302275,106.520437,74.056674,97.96639,107.623958,180.750442,221.404753,218.580956,183.895814,76.087415,48.344187,100.499936,162.42355,135.147281,66.775255,53.978913,51.919312,46.595552,25.496919,45.943115,65.792086,113.534775,142.664475,151.899871,125.435072,62.531203,37.146754,42.68418,105.036702,136.339907,136.987117,122.483826,36.050072,-55.740825,-206.356708,-134.396799,-23.442041,169.600649,186.408596,111.500113,62.931745,-8.354891,-27.045237,-46.130595,-70.57248,-34.845853,57.999873,62.197733,75.006381,101.920346:-283.762854,-120.742012,-75.844,-96.516132,-113.451521,-38.222303,37.243059,68.134218,-112.608351,-158.026512,-97.324693,-85.800407,-156.310305,-187.427355,-199.121014,-199.736549,-214.735432,-132.828762,-32.030219,164.025685,211.028193,184.607291,133.594969,63.477545,88.281459,99.138431,79.767367,67.831865,67.180005,62.843117,7.739494,-21.690886,29.902465,196.200542,234.687058,149.275494,101.993031,154.104109,208.705035,193.414245,36.720702,-14.129,-8.99546,17.229761,28.694959,-19.105519,-152.455155,-170.796992,-125.363677,-136.435895,-147.848329,-11.938386,116.519871,218.270197,145.582409,-18.821256,56.113644,143.954761,239.493397,231.552622,167.133309,120.431112,2.441858,-54.177637,-80.315388,-31.914451,-34.320285,-20.20657,12.339269,-13.128543,-82.3153,-193.500932,-146.29336,-84.320513,3.28737,24.789661,41.817452,16.429974,-83.614216,-118.058718,-127.564771,-103.508441,-109.710254,-150.564484,-149.384784,-57.663193,9.833397,53.521593,-19.47613,-38.949593,-56.664887,-75.119967,-121.903485,-170.454508,-338.717697,-403.6839,-413.830945,-376.488424,-362.680102,-249.996772,-169.616187,-141.086293,-180.155247,-208.392212,-205.149741,-225.625478,-293.737622,-301.542593,-212.857918,-153.849592,-89.226036,-86.988298,-117.146168,-62.319002,14.175664,226.143772,334.018809,386.079148,300.722539,95.310507,79.154066,113.454753,125.973636,105.473293,71.133099,60.140525,14.643513,-37.548616,-178.05468,-260.008292,-262.135356,-221.089128,-193.818569,-170.670387,-174.00146,-182.394444,-189.620949,-190.6933,-180.569186,-164.699798,-120.910981,-119.451397,-138.846356,-119.114995,-11.821823,54.318776,29.712295,-64.362157,-77.96035,-21.631611,18.032946,49.827363,-46.117469,-110.03085,-126.602457,-67.087695,13.225286,-32.885193,-195.649162,-243.56499,-234.544281,-134.591534,-100.922114,-99.611752,-97.338789,-90.552308,-103.082995,-116.882954,-60.830005,-24.146891,-37.948255,-76.536385,-33.22971,69.470775,236.589575,228.471127,100.440725,68.482966,109.65159,249.02638,315.780319,309.180048,250.388371,219.588343,219.6215,169.461439,92.055992,119.924095,236.769614,238.698254,81.866757,-15.758338,-160.087705,-224.575823,-213.919106,-154.472059,-171.4351,-325.914891,-389.186557,-410.008739,-381.256743,-372.780075,-395.565307,-400.077063,-355.368083,-344.717554,-365.986758,-349.223981,-222.647071,-149.853235,-156.988785,-151.28709,-119.946545,11.46446,112.818167,300.19096,378.188308,404.963591,533.218057,622.588181,680.203201,614.798499,421.931488,337.684192,209.531961,200.315276,224.20609,249.503831,270.882715,317.510953,273.375655,44.938914,-84.175142,-58.854931,105.265647,203.511468,349.934421,380.117519,373.507227,354.64718,282.220372,236.528541,249.039466,252.660824,222.21645,135.629819,83.100151,-41.934139,-131.719603,-119.290884,51.374226,152.470023,220.246118,180.509242,67.030973,27.283166,-28.940928,-5.221418,26.311372,-4.826029,-66.790575,-220.311909,-302.938058,-423.885365,-375.277992,-284.974643,-120.40122,-95.466794,-71.263481,-26.653051,69.431408,68.102219,-35.450824,-25.150693,33.723762,72.375327,58.221391,64.146735,71.089547,40.187482,17.661525,37.858123,82.254532,90.279636,116.297808,137.828768,162.55093,146.670781,75.528168,109.98932,169.686555,228.719986,199.366582,73.521491,19.433398,-60.410462,-203.881264,-272.587587,-247.422407,-152.970135,20.226858,35.302511,-47.129248,-101.649189,-164.702917,-66.89009,19.836345,113.745615,99.076884,-12.451557,-75.210994,-122.814545,-74.957961,-61.364055,-76.150724,-75.883576,-7.143412,24.444353,-13.163512,-51.19599,-43.03346,68.172941,100.480598,98.877909,104.028606,88.035579,24.626592,-144.57398,-235.771065,-227.975317,-49.01411,85.429115,269.521635,282.112437,181.462557,117.423427,65.733847,168.865787,246.553646,301.178602,266.883067,157.155234,82.576677,-78.283283,-80.330245,-31.091467,23.819504,28.70685,68.839936,86.710255,43.195921,-4.521086,-88.474127,-91.146414,-44.869288,66.132497,84.807031,54.001535,38.691511,-6.410931,-68.193615,-66.096737,-21.200802,-5.384139,-16.455813,-36.815569,-21.600958,30.513144,130.897143,173.391657,195.428917,215.323966,185.80869,45.568005,-36.030379,-139.273023,-78.486737,2.565472,157.67417,208.683044,273.880864,272.958482,109.229036,-25.062628,-142.272758,20.405364,100.373747,161.548701,177.797011,181.027874,149.647001,51.053387,5.880526,37.484072,142.245186,165.211844,96.415194,18.881059,-53.432704,-19.452493:-225.398941,-105.219469,-28.117624,35.172234,-11.30252,-167.51797,-210.370386,-230.993475,-223.726593,-191.469651,-96.559956,-71.712637,-106.773243,-167.528769,-358.650938,-429.064881,-351.199215,-99.34204,10.7092,162.391565,192.612623,150.898027,99.770534,-10.522939,-49.695711,-24.307536,74.105116,136.226483,197.838161,142.256282,-72.134785,-144.821367,-105.909429,72.846858,129.813011,153.583823,154.002469,125.641692,93.478676,-7.227959,-132.14378,-131.395208,-2.31717,52.764126,34.661732,-36.329013,-193.789383,-232.155917,-195.656073,-64.228361,11.872424,163.082175,209.449604,161.031565,84.996625,-24.009105,42.016682,123.919468,244.617984,254.380088,202.75491,142.681771,-13.175184,-74.647122,-122.712937,-85.386306,-73.514999,-62.064233,-34.427537,-42.385045,-124.649809,-289.745862,-195.490811,-71.845467,91.014203,87.136902,12.473787,-18.641312,-52.322173,-66.110874,-105.564832,-69.862193,-2.991492,149.031615,184.775391,120.723399,48.861951,-74.150499,-94.042132,-47.898149,94.836585,134.07512,71.165206,-20.467767,-236.135528,-313.761232,-354.35297,-313.008239,-277.144029,-141.306512,-82.969053,-122.427197,-186.606311,-261.542325,-271.781652,-244.924711,-173.963504,-165.993077,-170.077354,-171.67585,-217.17164,-255.266265,-267.258934,-116.070677,-2.353544,239.951031,339.080824,374.307675,296.81251,80.230701,24.270264,88.87572,243.714897,265.188735,167.275174,67.339234,-121.561667,-177.358855,-256.852237,-269.027988,-213.477293,-72.033317,-57.349628,-160.977956,-222.89186,-274.011215,-233.14143,-190.698615,-117.175129,-96.182038,-64.969272,-63.032468,-105.80376,-134.486111,-134.462649,-14.63395,50.036965,98.470282,79.042523,-13.560637,-45.377066,-13.230719,29.737736,20.441703,-15.711874,3.788533,71.983019,38.040044,-153.157373,-222.465819,-205.978344,-116.444319,-89.020266,-31.81043,-3.06968,-14.562808,-50.690474,-109.04123,-81.642844,-33.09426,57.915655,89.493893,155.098871,180.395782,193.806943,166.308064,61.13849,67.48478,124.452016,257.970278,287.78694,167.101281,53.562493,-83.376669,-76.460349,-15.836393,188.296978,260.027505,255.738123,207.468551,58.592863,-34.962068,-163.021708,-130.917749,-84.551404,-45.60653,-88.881604,-265.322455,-337.861411,-402.885564,-432.079666,-421.033485,-349.515915,-326.527858,-343.947228,-367.010298,-391.805707,-376.773314,-279.247477,-159.215596,-114.910759,-17.960802,33.224354,84.277171,95.98593,125.820964,201.531962,265.10831,437.395587,534.17046,576.243624,474.499754,239.223919,191.348453,151.325059,138.385504,168.885281,251.830917,275.379878,232.576073,173.637564,36.305738,-44.717094,-15.361415,179.912674,300.741827,448.545379,449.895609,358.454193,302.966305,262.15368,321.379896,366.945324,454.557678,449.425302,288.372372,174.80079,27.512677,60.844672,128.078609,275.324695,322.998149,323.089045,266.275816,84.586221,5.307358,-59.796672,-50.554928,-48.549381,-43.439101,-45.840276,-139.884541,-224.392404,-341.303201,-324.655036,-286.08345,-205.781278,-160.634978,-55.716072,-23.379755,-38.415069,-72.883608,-120.466473,-39.475516,32.17287,101.83471,71.969611,-36.709173,-64.75919,-39.98049,34.060386,85.198695,198.888787,229.598854,231.664278,215.990889,114.961293,29.110111,-72.323932,33.030982,88.885885,118.843324,114.8981,63.934217,16.994684,-98.741102,-252.665471,-301.168476,-205.771573,-89.413303,80.385359,95.763723,21.141095,-41.564762,-127.925563,-72.348148,-9.814509,63.866598,49.665326,-31.368546,-71.754467,-186.418908,-262.91187,-212.358892,-1.970023,98.00611,197.217878,181.244063,81.606729,36.632644,22.393506,119.711739,165.249565,199.505792,202.14403,147.333973,63.759938,-150.599194,-221.167471,-183.203553,-46.448272,26.516957,126.747691,132.789398,71.746233,34.043536,7.975366,63.891991,104.227141,168.661295,173.627736,80.017796,-7.742127,-147.327068,-95.759684,-15.516653,89.042478,96.894884,114.32973,130.940724,88.743653,23.32311,-85.087026,-70.537303,-21.747421,88.98187,104.297446,18.560287,-26.345605,-33.766421,0.293764,38.068079,120.450589,120.436854,45.25425,5.269196,-46.667545,-63.766506,-48.005591,69.149394,127.812248,189.182188,188.706419,83.298556,-8.204892,-125.40465,-41.999247,48.654719,182.734077,201.817891,189.780291,169.539948,41.803455,-75.551693,-252.182739,-126.599264,7.822896,202.247089,221.966768,145.447306,82.991868,-40.901688,-72.802022,-30.384327,80.954601,109.593689,69.362988,3.386573,-73.817734,-49.664853:-182.756643,-75.659452,-48.95612,-0.081389,53.382907,141.695476,150.885178,188.329308,233.461244,230.910505,143.887832,75.301434,-12.12973,-35.745386,-62.743258,-59.073086,-43.670136,62.881845,158.960751,260.082668,239.14031,171.52881,155.119845,132.72831,103.133855,72.984322,-3.131762,-8.297544,15.004217,-14.778936,-96.247487,-95.202192,-39.820327,47.358663,91.605907,112.780779,101.200543,131.378361,177.895828,204.648746,89.814698,71.695372,176.583878,217.951283,158.279029,88.332088,-46.746803,-87.927011,-62.971472,47.303859,64.156209,4.949789,-25.739412,-42.668134,-39.188722,11.876612,113.706143,153.772422,209.117314,229.886899,196.578695,122.116059,-39.34097,-62.180082,6.913717,26.421672,0.617044,2.865293,31.500872,54.74135,62.026408,66.09281,-33.409599,-58.226753,36.688596,118.193177,241.887043,254.635985,177.474557,126.407646,62.466295,17.401162,3.629623,-16.487455,-26.589697,10.243883,56.187902,100.192573,100.516127,129.28025,169.701628,147.049478,48.680711,-25.115932,-174.745214,-192.082758,-91.624161,-0.093821,-4.103671,-39.053662,-29.696386,16.39462,13.29467,-47.517939,-124.05476,-144.161127,-147.457476,-143.064279,-95.377441,-61.648075,-0.317776,22.717973,5.281003,11.554704,67.434205,228.638997,295.156425,312.048341,263.299107,165.174572,158.033577,168.557431,196.351478,208.474286,169.546501,124.427581,54.691612,20.56486,-108.072041,-219.529004,-217.141842,-128.197229,-101.957382,-189.950862,-248.156816,-183.125676,-16.331205,6.002442,-28.875217,-29.394411,-10.025085,-26.734316,-69.312549,-50.403536,67.967036,136.983006,126.490939,79.688877,55.144209,1.603166,-4.123822,36.647165,67.711018,91.880801,169.104144,194.696396,194.245814,177.871451,144.758153,146.377284,185.638568,200.834472,179.798085,108.71291,80.196759,33.196696,14.552845,32.553553,64.742823,56.839929,38.925949,47.42783,123.183744,180.401077,267.926507,277.080502,226.50136,222.644665,261.84769,347.570064,373.98109,363.383423,332.666538,296.234869,259.506837,214.908268,193.264047,249.224474,345.045836,305.097772,93.007757,-3.236571,-105.214712,-181.689956,-228.333647,-260.794367,-240.766433,-238.486576,-270.244675,-326.157019,-344.114102,-350.317678,-399.96081,-434.944812,-425.513242,-391.153534,-402.516574,-435.237389,-379.286046,-215.475506,-185.203549,-208.926335,-200.439816,-78.656125,31.382812,272.299996,390.833708,415.575613,540.514573,642.547955,758.601166,728.573223,588.432394,528.394802,425.684843,333.125811,299.682481,311.512057,362.72395,405.95641,344.156825,119.70572,-39.802643,-38.232461,87.257378,143.58888,194.823657,213.5123,208.096494,175.999964,132.831445,162.003697,184.35716,208.716847,203.162274,113.129357,27.760007,-114.611562,-84.528955,-26.978164,47.768751,56.372922,87.361111,109.410945,85.530255,36.575728,-79.675103,-154.643943,-168.160449,-180.390053,-191.39046,-273.170269,-335.767225,-401.69898,-358.547998,-307.150309,-188.494529,-143.016422,-79.547374,-55.005594,-24.843154,-35.966894,-139.470538,-198.621487,-162.872713,-36.45028,12.138963,55.168006,57.510335,21.023467,-42.314954,-40.341391,7.1587,4.837426,-24.127721,-16.960156,-12.15947,-53.771503,-150.485827,-84.560033,-22.240852,59.16133,65.346816,-35.238243,-115.838119,-213.743278,-284.353065,-331.135135,-366.80664,-328.216281,-147.906261,-59.219726,-30.118371,-75.549473,-151.644623,-119.985634,-91.443961,-102.384768,-119.668538,-99.188805,-81.268776,-88.630947,-144.936197,-175.189967,-190.650464,-185.147825,-205.096402,-224.738484,-217.095921,-174.972476,-91.598333,-95.065389,-98.418009,-71.76517,-54.829034,-54.872877,-75.758123,-114.564659,-125.593078,-112.746033,-38.971238,16.173941,132.954764,155.118404,84.163845,34.389215,-9.226816,-3.421515,6.221482,4.544483,-17.398051,-85.848807,-112.123066,-152.433135,-203.91923,-203.633721,-145.846656,-117.434485,-78.537448,-58.8428,-30.399105,-41.527384,-129.216586,-208.648513,-200.950315,-144.091373,-140.568551,-167.323226,-168.661831,-173.488041,-231.366573,-241.558516,-145.453003,-79.210999,-43.031725,-61.959922,-88.428339,-85.191875,-44.968555,77.17661,146.077823,169.724136,111.036051,-39.275155,-69.232819,-62.989641,-124.679038,-130.958007,-9.868265,56.676651,62.322687,8.549005,-113.66503,-146.54726,-109.802103,-21.012896,-24.211888,-114.80562,-149.984127,-164.77851,-163.924439,-184.690641,-205.568169,-185.321942,-130.012309,-141.71162,-257.242255,-334.531726,-418.522972,-390.695388:-215.46374,-84.073865,-76.945458,-135.012367,-124.009222,-27.949996,12.002388,61.525471,66.355468,77.35908,54.783376,-22.30558,-148.481453,-130.411608,-49.418843,-58.710413,-149.760186,-58.044833,90.652684,349.509867,370.622682,216.257151,120.522656,33.531111,12.868049,-7.395121,-4.512399,44.096762,106.062152,59.606007,-43.524894,-24.307034,79.190486,174.912525,209.914371,206.562426,179.586086,146.683067,167.709894,233.600663,130.116123,58.250075,65.890549,104.263229,48.468138,-48.272649,-190.203883,-173.095081,-49.3478,-58.85705,-112.62191,-152.653438,-120.628119,-53.330954,-48.87079,-57.197856,-8.241279,37.395,119.961991,148.022825,181.471273,152.126306,-7.61232,-71.082789,-63.875095,-29.388367,-60.553952,-108.807766,-75.056543,-7.601326,-29.290058,-136.790038,-140.925117,-64.907062,83.027713,90.53212,38.283039,37.396072,47.604336,9.772615,-104.248965,-138.404843,-135.012225,-147.977058,-152.420294,-61.008963,29.232728,100.323159,-22.344872,-40.843658,38.410642,52.201224,-30.610432,-97.281938,-184.378881,-175.284005,-133.612514,-140.239275,-139.410231,-71.250624,-8.263539,72.371462,64.289277,-10.817702,-93.130257,-130.846702,-157.08984,-116.951922,-15.354744,-7.602111,-6.497892,-11.224562,-175.092052,-263.203543,-166.874973,87.817431,164.196979,197.498852,169.619177,110.65939,113.251531,114.725037,65.18865,46.673502,117.118579,163.003992,133.272,73.116985,-62.845784,-147.545026,-145.091856,-116.519358,-123.349133,-158.165125,-150.98705,-61.966315,23.149057,26.525965,-54.055391,-99.70392,-150.614117,-191.4339,-278.726523,-250.803349,-39.428551,77.799792,32.631353,-90.533034,-91.06909,-30.231999,-20.522069,-70.506722,-132.902361,-139.994232,-156.022815,-167.500051,-133.587331,-101.759909,-89.133947,-113.340629,-148.266625,-100.612117,-88.323827,-114.255941,-125.704417,-143.371435,-155.526556,-168.346915,-146.031248,-104.798703,-32.872716,-37.32056,-51.99877,-16.917462,154.999676,219.898848,139.107725,33.650241,63.16501,199.611281,268.059829,350.988394,357.369795,304.503237,152.069104,74.367067,24.649488,62.623508,166.274564,168.866361,89.743893,58.147895,-22.862285,-171.66124,-213.4992,-195.552647,-216.034821,-368.012216,-401.187645,-329.659787,-301.719609,-317.965583,-329.466644,-300.555418,-197.701766,-164.571301,-155.238755,-153.535976,-164.625761,-248.12044,-302.522775,-363.641427,-358.731176,-234.41753,-104.05938,169.389577,315.97301,363.417508,452.108335,490.963762,560.123849,574.437893,506.369619,426.738697,259.084039,178.636833,170.773214,180.159275,185.388288,172.820589,147.889982,32.729024,-119.711624,-137.678866,6.967301,112.216855,231.751955,230.348654,156.267564,128.02898,117.156931,120.987041,117.345628,49.452707,6.595223,-59.413789,-105.894469,-205.032047,-176.739504,-94.903437,59.208781,87.317555,118.159623,140.617944,149.733313,136.885358,115.553417,31.14598,-29.110582,-68.104804,-59.62008,-145.170563,-236.97148,-353.003575,-319.953282,-264.73953,-157.668737,-127.132384,-47.287071,26.843764,180.881117,198.76699,86.973944,12.600467,30.04271,106.120217,138.807386,134.727345,103.293037,61.719443,63.85133,56.441907,5.738104,-17.749179,-1.928618,26.407032,55.35334,48.886131,18.708896,27.748082,49.52548,143.212041,206.503114,189.623695,103.918953,-21.250178,-90.989166,-142.682523,-208.016978,-204.027439,-151.767234,-126.311128,-111.489712,-110.44481,-73.165981,-18.480787,-13.98485,-39.659097,-37.718959,-12.839535,-16.406469,-72.901752,-136.37668,-149.980637,-154.509171,-146.844073,-118.090112,-110.311389,-117.70923,-122.464749,-130.014221,-119.485962,-89.349399,-13.847652,11.052468,35.183588,19.252035,-96.999248,-175.472478,-127.117142,76.518449,148.329943,198.039406,212.953201,198.507471,134.027082,-33.21613,-9.450085,78.011481,234.429176,259.926879,211.552876,146.946364,-22.192405,-104.881218,-94.711394,-46.579589,-11.407868,108.454077,158.070726,134.773655,69.920095,-36.264636,10.892109,74.306961,145.242034,137.979785,106.351188,105.643377,80.993069,-56.459318,-92.477573,-12.433722,42.323029,120.806341,163.56107,208.933023,199.555165,189.839375,275.596703,324.410034,260.407255,168.895767,60.567259,59.67008,98.083857,110.72097,108.251333,124.307444,169.824092,320.146835,361.202406,257.200672,142.682925,78.489557,262.394639,266.798609,69.253132,-0.921346,-7.577298,0.58853,-31.360303,-77.718972,-86.044134,-86.30396,-66.982518,-4.99503,-25.893336,-194.896561,-264.921297:-92.151317,-51.288911,17.477288,81.83783,62.857996,10.380385,-3.41035,16.538314,50.392865,68.445209,81.074837,37.679698,-92.804683,-130.908476,-160.647563,-177.446406,-183.129509,-28.887927,64.113629,135.972182,121.032998,39.656795,13.819434,62.14997,112.736523,115.760672,127.953798,132.522368,99.672367,58.567143,-35.476094,-56.050439,-29.199103,36.011426,71.117643,104.740445,105.545695,134.643008,148.128012,66.352738,-50.284654,-31.480807,89.11526,118.651473,100.457119,58.114817,-87.53714,-135.933673,-122.463554,-75.704776,-55.963515,-14.197116,-0.453397,-39.362585,-80.768898,-82.931251,37.130703,108.715532,226.618211,261.491786,234.684027,152.689681,-43.137929,-93.231102,-88.144448,-71.809193,-83.084382,-28.048352,41.918398,52.928769,-15.683186,-106.608642,-106.060358,-89.571588,-33.959049,-13.165638,9.246391,13.726278,4.550582,-14.113845,-74.875014,-26.723773,52.936852,143.168764,124.68445,84.44083,80.514784,23.357129,-8.201288,39.470035,106.489306,83.083433,17.453761,-38.526314,-230.467535,-284.007548,-225.181355,-186.589838,-196.814491,-163.271335,-136.945593,-136.260867,-128.5102,-86.830573,-168.54346,-236.123019,-301.643956,-282.364001,-159.826059,-110.511461,-97.052051,-100.800518,-85.939207,15.263851,108.975902,266.71704,303.354753,314.971842,295.834715,216.102282,145.056331,137.285072,125.489271,110.886527,79.369175,56.041953,14.575948,-7.823415,-109.057637,-218.546872,-235.957954,-187.527818,-156.225331,-166.631545,-189.263812,-204.792791,-164.076378,-105.938167,-15.051682,-28.408152,-106.309151,-113.762416,-52.327456,-20.209383,37.604322,118.451105,122.79797,47.410918,30.46747,103.961174,151.212648,140.260359,46.216638,41.292129,128.72122,181.81193,200.749234,143.220989,24.64109,14.859898,41.3449,97.810822,127.7034,117.011246,88.536228,47.358377,40.514472,56.331482,40.859136,34.178228,83.790558,116.5673,140.37033,126.198492,101.696824,112.012072,117.206683,114.637929,143.659445,178.156016,153.688254,101.381466,100.592989,103.018764,59.334403,62.97281,189.025318,278.69823,372.261178,332.053936,152.618213,71.991516,-71.49938,-156.15324,-147.366049,-134.347349,-180.821624,-312.029618,-333.981593,-309.774902,-360.112598,-424.514773,-558.670218,-578.416142,-490.418047,-448.003918,-481.573435,-513.27216,-413.033674,-174.029418,-123.271307,-149.732992,-143.650772,-29.161558,51.502819,215.376423,293.80322,287.504726,342.127743,439.889328,578.748808,540.407897,361.251144,285.726391,176.399677,142.406346,152.072369,186.823375,209.648589,203.761405,146.291363,16.788392,39.490757,87.116584,130.100985,126.595997,184.501023,252.762175,326.987269,297.486301,203.142646,178.296108,169.975012,182.429022,215.790791,217.613572,154.149077,-3.572012,-36.421961,4.800762,121.022491,173.832547,229.220916,198.912325,40.642301,-30.364376,-117.556011,-169.955628,-173.95212,-166.208776,-175.91364,-227.97497,-259.86858,-332.823495,-410.35802,-399.90682,-254.984304,-183.290172,-128.242929,-122.686153,-98.900025,-92.197221,-104.07329,-54.187227,-9.970067,40.956351,42.523143,35.890021,47.208924,74.837745,24.206361,-12.332872,-10.471599,34.679171,129.51149,122.285587,-39.871471,-123.700406,-107.334652,29.915942,37.478255,-18.579248,-27.072993,-65.600632,-116.252293,-226.191545,-323.085642,-333.952165,-242.283581,-172.091365,-23.076117,44.001441,92.762722,70.425873,-16.546051,-85.037119,-97.135477,-86.432406,-68.274352,-59.093825,-78.261962,-106.910083,-118.556645,-101.034505,-14.485489,1.21712,-20.889448,-9.469059,40.391917,26.045023,-72.752218,-53.611499,-3.32906,50.193504,73.316534,111.780305,71.566112,-118.891735,-192.776735,-116.866067,112.124556,160.813939,106.146162,67.005203,41.29798,28.285004,-42.687748,-40.424268,10.447924,120.617637,142.270559,65.34808,-20.646994,-191.720202,-235.902516,-186.282336,-71.360646,-36.640547,59.397762,112.601973,122.824859,67.448469,-95.857519,-170.629775,-141.07579,-82.69761,-107.18637,-152.963114,-118.748593,-25.111048,-14.654246,-23.459932,-21.470602,1.514123,31.220507,1.269346,-92.237131,-108.206708,-46.063671,63.185907,107.390636,146.923143,118.678795,-26.767614,-89.776001,-101.559096,-4.928486,36.792564,56.563136,49.557402,41.01153,20.920145,-94.811106,-155.778961,-168.653364,-69.147434,-9.643405,88.786483,100.489986,54.954315,32.993958,-7.523991,-122.318001,-157.347208,-60.295515,15.981921,21.862595,-51.251491,-174.019341,-181.091468:left
91.636415,-23.748606,-74.032642,-181.18249,-219.528118,-140.64256,-17.177492,207.295742,223.852388,204.142869,213.286071,242.681798,307.835672,298.296574,195.992234,161.441802,151.190622,85.577245,18.52784,-97.969888,-97.675945,38.387735,111.566066,140.579262,73.963845,37.178552,-31.114324,-61.369692,-89.490647,-61.718606,57.392138,100.070943,75.87824,-53.423083,-116.095844,-141.510059,-92.037906,33.112267,79.826699,185.22545,274.179656,258.383805,94.219566,14.363497,-3.262761,50.060245,223.24026,304.137734,303.897621,139.433457,61.17124,-0.821256,40.192794,213.9498,303.337354,363.051029,194.427805,99.635497,58.136449,95.851564,118.433866,66.636029,-48.127686,-65.263741,-88.268404,-161.873003,-210.330945,-274.926506,-254.483821,-145.410491,-106.419341,-62.560539,2.597768,43.363074,105.180491,118.03218,93.770366,65.234817,83.079891,124.425294,101.708542,-49.566622,-105.037695,-104.151628,-86.265352,-91.795706,-75.452656,10.125699,12.399247,-0.962415,8.113945,5.746877,-51.013878,-83.569479,-110.634559,-124.057389,-180.720145,-236.853336,-276.439962,-336.742044,-312.267478,-186.76345,-123.504884,-27.947203,-33.652965,-63.507158,-85.113134,-68.087739,-65.655032,-99.827976,-152.810171,-147.07668,-102.935413,-42.947807,-30.32922,-55.376104,-70.909878,-98.938035,-94.475446,-19.914396,4.982632,-14.69697,-64.813561,-95.084568,-178.290733,-216.476655,-174.944644,-86.118281,71.621043,46.663568,-28.192505,-147.049559,-149.704103,-104.292297,-62.888452,69.719471,173.541575,205.490392,238.351544,256.237503,344.621005,384.785466,376.742352,344.439838,297.699209,273.511531,240.362543,190.714414,220.105203,320.067218,347.032705,374.716345,350.873416,287.08827,111.478846,68.899911,138.116936,192.602373,238.611833,239.66253,195.447754,89.793666,22.614188,-94.721016,-131.740638,-191.37618,-202.077976,-136.797033,-109.197446,-166.953481,-300.367124,-302.263591,-251.65903,-274.565888,-352.557493,-350.21242,-287.099254,-241.263026,-253.398839,-307.64914,-300.852405,-185.970564,-95.746563,63.785629,104.160352,110.97013,159.922183,191.188008,248.189933,266.237727,234.890001,181.792539,74.808486,33.122281,10.219165,-62.298482,-81.225555,-36.314313,12.402854,109.328752,235.903779,314.864142,380.722245,371.777832,422.908985,472.515484,465.164399,404.453257,300.143811,337.49506,380.785719,419.850092,401.366643,302.133858,258.668402,263.954114,316.038993,300.039222,164.655143,114.766235,177.073647,238.068262,281.696982,269.970306,223.822942,184.238787,170.994472,166.669206,183.610037,251.213605,292.75494,333.652622,238.36756,165.946423,63.525889,50.065381,100.762854,137.31387,154.248886,123.583519,-6.209506,-133.026782,-174.38906,-223.02594,-218.395173,-180.007112,-181.250224,-207.342215,-183.09946,-168.325564,-182.453065,-180.249535,-98.596855,-65.381807,-109.607212,-156.188027,-204.794367,-187.03563,-184.00161,-238.113158,-273.94442,-274.762468,-223.043965,-133.40566,-139.804845,-111.397002,-31.458345,-31.846209,-43.516701,-22.882724,26.182053,32.401141,-8.642912,-63.490176,-54.948179,41.138823,80.45881,40.287218,-1.454312,11.083253,81.63087,86.231461,20.560603,-22.530259,-42.355242,-15.530295,30.554688,14.700687,-100.572877,-182.076374,-219.335388,-372.169774,-415.785531,-286.49145,-177.678885,-88.889813,-172.08826,-206.431541,-180.064438,-124.861008,12.862592,54.171585,98.666468,131.951074,137.93113,36.858974,-10.859042,-65.061553,-75.77642,-82.091914,-69.085871,4.397447,78.295616,98.878439,59.213684,10.846101,-53.175569,-64.53631,-29.182371,5.083714,-19.737401,-138.202603,-175.515856,-138.570557,-71.417298,35.382753,51.576446,64.722776,-18.301077,-112.231324,-207.877242,-149.490597,31.463018,75.123213,100.245052,104.648045,77.18966,-24.141351,-100.707345,-154.511654,-89.240173,57.617984,73.406808,15.675706,-57.407937,-53.181143,16.388151,36.398256,62.062833,92.572875,151.781587,132.69446,-38.724627,-168.237872,-152.644578,-35.069674,21.865008,107.939046,140.700149,162.5506,109.73914,88.139567,93.573555,90.681432,13.104463,-30.177413,23.066141,93.17151,85.093266,-78.569411,-122.161705,-106.224324,-87.169645,-86.470842,-86.685388,-92.179118,-158.079221,-178.889787,-166.325336,-153.659586,-156.152031,-145.795708,-27.852568,16.021358,-77.498698,-258.287563,-310.744013,-274.717286,-219.346108,-194.805677,-210.900364,-194.947595,-194.16088,-229.706135,-324.259268,-336.613681,-265.459391,-217.218827,-128.107709,-101.15958:86.008403,-61.401051,-118.358129,-188.629899,-217.738443,-173.864583,-84.561318,98.389963,195.954824,208.8345,140.391853,99.010363,120.969208,154.427234,138.385333,107.844689,84.535307,23.025961,-52.752758,-182.6532,-162.871817,32.513002,110.635824,68.789418,-47.642928,-63.266369,-86.181607,-99.334682,-69.783832,-41.459798,7.1866,22.315079,-13.475032,-127.084393,-168.856363,-103.318982,-4.67832,178.323072,230.725805,290.258441,311.314263,254.718306,3.933612,-84.469225,-65.399721,-24.267688,50.607261,101.844698,150.290064,-3.809467,-105.861765,-122.610188,-25.66455,180.354203,231.907053,226.126687,111.494168,55.755916,41.446746,65.185367,79.871086,71.610716,50.379843,6.877843,-162.024749,-288.803237,-311.130539,-276.301248,-234.080112,-177.359579,-167.708735,-169.44011,-186.052278,-162.463624,-72.070472,-44.144321,-34.998298,-25.067617,20.466409,12.536155,-99.660421,-190.132661,-184.293774,-114.049944,-109.56707,-132.620156,-76.082543,122.105895,116.68969,49.041992,-3.154751,18.918432,25.24216,-0.225561,-44.309479,-69.047739,-163.373333,-282.418513,-315.051305,-259.034795,-193.857653,-73.813072,-22.905006,37.424379,53.353419,57.289671,-8.25334,-56.943401,-61.340624,-25.243265,45.927442,75.574824,87.413012,1.209235,-50.427044,-107.715655,-110.600739,-103.553041,-82.672805,-6.650763,-14.500952,-59.368082,-168.804109,-214.720098,-276.556132,-286.221677,-208.876056,-131.128553,-15.130654,-24.574435,-61.610407,-93.746913,-80.113718,-58.594169,-25.377048,96.125814,82.713646,42.386054,42.915138,89.321083,217.685,277.395208,391.058853,428.006742,397.038863,316.385092,290.428698,279.318224,304.132492,407.955181,465.079109,531.32732,416.1471,297.229314,162.837254,179.598123,215.241751,195.652444,152.630792,147.635784,130.793167,34.826723,-49.300828,-189.866966,-211.846815,-180.565759,-141.026959,-57.003131,-43.559972,-85.593515,-216.569158,-255.878433,-277.520884,-274.519218,-217.921414,-191.260921,-199.923103,-263.614457,-308.240634,-274.756202,-168.141216,20.540085,49.330308,79.692428,177.656608,222.24179,237.040967,225.526919,220.585248,217.264818,179.457901,158.639226,107.514613,-0.284999,-32.092917,18.624128,73.868329,150.499667,166.189552,212.130249,282.180765,290.022849,240.788612,236.176132,328.88142,374.808231,379.675752,359.853234,336.466853,340.512842,339.563479,358.914672,376.963322,374.212082,367.313457,339.658136,206.209919,128.930444,92.126949,138.350626,242.244431,262.318439,245.104345,209.872413,93.532355,54.62633,86.32022,162.211792,176.688262,198.715982,244.342233,329.71096,261.37718,198.287433,125.932457,130.867651,136.114629,123.668204,150.602429,177.019605,138.904773,-1.23953,-70.546932,-144.898033,-150.231809,-120.010399,-81.565018,3.959119,-5.643994,-51.602284,-154.57406,-190.890302,-207.630501,-180.624015,-55.024315,5.992173,11.114359,-100.918729,-158.351614,-234.851261,-254.552565,-244.425487,-197.513404,-93.259149,-101.32486,-124.978075,-118.161032,-77.721088,-9.994857,-5.529706,25.954523,48.225685,5.212344,-89.679899,-116.061204,-62.747956,17.654678,152.976455,157.68479,69.805403,-1.78636,-5.631661,1.521088,-13.098058,-66.012475,-68.153787,8.793404,35.624037,-28.531091,-112.591199,-134.840817,-191.271939,-224.704107,-265.141277,-248.921414,-145.088761,-68.974006,-88.3058,-239.997179,-279.589961,-131.518933,-22.365033,86.201525,96.032838,67.001018,-30.027428,-83.994508,-135.97003,-128.372911,-37.833587,24.201387,66.766737,38.432033,28.03827,10.954519,16.694891,57.012339,74.286353,144.049622,179.731521,78.100347,-159.843213,-213.795913,-105.642745,-1.260737,123.295483,145.542667,138.81434,29.866114,-37.410617,-130.277258,-118.924775,45.066556,139.577925,246.053085,263.047367,215.775971,19.662399,-97.106419,-164.556299,-95.306542,17.341511,4.836494,-79.603471,-113.344193,-94.357963,-40.758185,-10.522649,78.64644,127.204463,172.556297,141.844117,-15.80162,-154.367207,-161.449025,-32.204683,33.956821,29.670874,14.729886,57.271471,1.923717,-80.419984,-170.396121,-166.24815,-149.391647,-118.831417,15.306808,62.797226,8.806208,-111.643152,-133.881632,-102.598646,-84.736464,-104.815027,-130.260786,-201.732772,-280.636283,-279.722884,-226.85817,-218.149793,-204.395382,-145.785501,91.79783,184.898486,113.599026,-136.325385,-206.87153,-170.228672,-122.023682,-95.26155,-93.948594,-74.397378,-105.170671,-145.700892,-204.754411,-188.544754,-137.840134,-141.964686,-148.990676,-141.562232:62.655756,-72.067701,-94.946341,-124.664253,-143.151375,-78.759847,8.797256,122.960235,93.024973,54.869648,-10.395666,-7.358253,43.963392,66.345078,114.746959,127.348438,78.679994,-25.101906,-77.997844,-117.71957,-79.722947,71.069392,130.793749,83.111892,-70.739269,-103.244112,-100.94255,-92.202654,-74.809679,-73.834834,-47.451885,-11.219768,8.422449,-110.148445,-169.224554,-189.015197,-143.438739,15.832285,80.863182,133.452437,142.879943,105.68284,-32.437124,-67.113083,-54.805238,-49.412525,11.747624,81.808945,149.551115,47.004369,-31.7008,-110.601364,-68.661809,81.8056,119.750905,101.530746,69.92543,62.956382,81.234339,112.111235,147.498531,142.813746,115.458028,58.32987,-162.460127,-300.022856,-295.470123,-214.570151,-185.221433,-180.26614,-179.230875,-184.5144,-201.480584,-186.254495,-146.450123,-151.871073,-196.582449,-198.752349,-132.538838,-105.01051,-141.73476,-261.301978,-297.147146,-231.73585,-173.641114,-106.789511,-72.545251,-10.282573,-36.040425,-57.037037,-58.720947,-38.81657,-7.085059,-12.333609,-60.02908,-95.999874,-175.127858,-237.831633,-237.68795,-143.434172,-75.505981,33.42587,59.969599,42.904074,-1.870719,-11.451146,-29.147716,-35.770028,15.887138,70.794751,120.361239,94.329441,47.508618,61.965232,53.812701,-6.376948,-27.60011,-25.208325,-13.232938,-25.207303,-126.854144,-176.516639,-220.046792,-228.705731,-253.865397,-268.323893,-227.554409,-163.431207,-66.890169,-84.666189,-103.83208,-104.302843,-98.630376,-99.766798,-79.670631,-17.485222,-38.008266,-47.21636,-3.784116,27.500914,77.661318,104.62416,222.433687,306.443137,389.377234,298.85149,235.192472,189.145069,218.472222,331.916836,378.913869,360.584359,235.468408,183.304605,145.478349,138.460728,65.989251,23.109428,26.059249,34.405357,-34.270113,-97.548422,-111.198737,-141.496719,-148.004396,-115.294246,-82.026599,1.064127,58.241182,35.544805,-114.382201,-195.700291,-267.770666,-246.381111,-134.15463,-92.240444,-105.158519,-192.613621,-222.443174,-175.101051,-97.474732,65.875039,102.909428,118.831729,189.85481,206.879131,167.614215,170.494955,242.370328,272.244446,274.630003,253.363909,190.046691,102.816434,57.417437,37.877852,88.086311,235.595612,279.646045,274.56478,243.372905,237.564812,206.346302,194.315353,250.407384,296.00348,313.370847,278.958731,231.594908,295.299458,324.583498,335.786503,327.580905,303.304127,294.265206,273.571468,223.382466,185.360764,102.235861,82.561773,96.985107,107.749762,132.610943,153.910995,174.833701,112.31621,74.598249,103.117616,174.135028,302.471373,314.863676,239.43448,136.879697,104.994212,105.901078,148.01262,229.748734,229.347049,179.969807,141.576425,40.510969,-60.764468,-110.2669,-141.000921,-108.094583,-32.744392,-24.137166,-33.5978,-21.793063,-31.270302,-83.563233,-94.703791,-51.217627,-6.862361,57.982785,45.249229,-37.862239,-87.93683,-108.878728,-164.00105,-180.715296,-148.623606,-108.708691,-72.138413,-126.129656,-152.463832,-124.379661,-79.611373,-11.177724,12.561084,61.243097,52.954207,-53.648068,-62.408812,-6.347529,59.518714,46.195686,34.751124,49.231082,34.954808,19.822868,48.204688,42.950712,-16.568148,-102.758057,-93.23905,-42.815457,-38.77196,-83.960611,-150.27357,-174.871142,-197.781755,-211.896572,-230.558154,-204.004929,-113.000825,-127.438698,-173.674316,-207.182405,-179.026049,-121.13746,-77.933583,92.41083,146.991321,65.708964,-67.576439,-76.131047,-9.240341,17.116327,21.933622,18.283147,25.368,83.728642,121.589377,130.416631,101.592098,86.520282,119.381547,179.306672,163.961884,35.807297,-87.963401,-116.930686,-136.844845,-126.292889,-20.144176,74.518433,196.71726,70.113686,-31.870603,-115.384546,-71.373273,67.720274,120.591529,207.351584,218.158694,133.46166,18.441913,-29.816535,-52.487865,-5.83798,101.732503,104.7942,6.582396,-76.411301,-89.214247,-56.375526,-9.333578,54.810604,49.659365,29.61512,22.944912,-45.505253,-200.585383,-248.969697,-164.271976,-81.077771,10.290606,31.192602,36.803881,-51.24422,-98.194598,-118.367768,-99.340498,-63.471124,-34.587112,66.700048,85.706082,1.805548,-90.552712,-99.57344,-58.322251,-43.198795,-36.913946,-20.78404,-6.041007,-111.398427,-174.93166,-219.083343,-207.113959,-137.113777,-60.287742,136.930947,184.033613,95.824291,-45.158595,-79.181861,-42.602154,7.989599,28.944178,-11.844863,-65.199934,-60.04772,-85.974969,-161.889603,-167.566127,-125.289857,-96.553943,-27.249974,-10.054811:91.69634,-48.570675,-106.373207,-156.161752,-149.313683,-43.962108,43.533951,163.281874,169.691766,160.819401,132.054184,131.192149,171.530971,174.192001,146.495234,152.197161,173.109002,88.451466,11.066758,-119.772129,-113.533325,76.254643,165.502838,136.412687,1.572453,-23.111711,-40.716605,-57.58787,-37.03473,0.561356,54.900496,53.012244,-37.371823,-185.536319,-237.896024,-269.36446,-243.225434,-114.123659,-30.942381,94.958793,98.605581,59.549198,-49.933965,-78.602181,-54.852572,-36.167424,33.613124,89.551548,115.713231,18.295877,-28.479684,-74.268042,-56.648586,92.094527,183.282154,198.284223,21.65757,-14.63134,63.635364,104.801652,96.52125,61.868118,-19.34931,-58.392516,-113.969846,-135.862228,-163.676819,-224.944485,-216.076323,-132.194134,-101.994062,-117.969512,-143.568461,-119.080578,-61.480628,-50.028964,-28.292147,-10.564146,29.619388,33.099456,-38.782104,-105.357774,-92.990202,-36.703881,-22.832678,6.823894,46.523927,150.907109,150.026115,103.992965,38.178954,36.563415,37.172685,16.798758,-31.349481,-44.547305,-93.257917,-182.585011,-208.265634,-194.382507,-160.17853,-68.380386,-14.767589,68.390144,5.571441,-52.677705,-105.954926,-93.483324,-33.262687,-6.91167,30.40056,40.669864,12.301272,-27.002186,-23.42368,9.551944,9.965691,-56.553946,-77.755776,-12.361975,22.787882,-14.024818,-111.206749,-131.585423,-119.981167,-120.268193,-109.007281,-68.999152,17.699423,-10.988744,-52.555299,-55.508046,-14.234526,33.601085,46.969005,95.038262,73.144044,45.64771,63.921318,122.982692,245.529308,275.364033,322.153812,353.642808,371.595475,290.61216,227.292652,173.644644,206.165169,293.297887,322.11214,317.760863,219.058079,173.599813,137.084807,123.75081,79.483153,74.136096,113.492632,110.669217,-28.510857,-189.119548,-226.190323,-236.12614,-228.246701,-210.167472,-173.327784,-43.350274,-40.726344,-104.169747,-228.70869,-257.603401,-273.011831,-266.360084,-192.097287,-152.320541,-153.951314,-187.48346,-206.886509,-251.850189,-241.671853,-133.34098,-61.030469,98.931623,258.695907,299.194695,230.29101,157.117685,117.415507,163.335207,249.349939,244.795147,172.795924,116.009571,63.987477,-69.948075,-77.497125,37.464119,102.575876,204.299337,304.044175,343.633328,365.826947,367.498203,407.855899,434.060076,429.717899,392.80769,310.323473,307.270437,334.031427,375.513738,357.414497,255.303322,229.496097,291.340758,321.278349,273.743578,150.794513,133.049022,218.358856,289.807641,359.626219,326.761259,207.113111,167.89652,163.169127,161.42825,185.006346,241.595231,261.129892,288.010473,241.593052,180.924578,74.063457,71.37664,122.544412,130.666924,137.858413,145.168092,54.454538,-137.520571,-191.909089,-195.296673,-175.293408,-121.704566,-81.740677,-17.724587,-34.409855,-67.599268,-134.775857,-145.7562,-107.596032,-70.5899,-14.590391,-14.520083,-61.597236,-110.811799,-153.891619,-260.192072,-266.91115,-195.320121,-156.950914,-87.522609,-62.603053,-65.737668,-50.160594,-32.628435,-6.574901,13.78112,89.931121,99.764407,3.800403,-46.445249,-15.098901,75.092883,98.38854,59.649547,24.077853,14.170543,56.941215,76.149081,89.270125,68.627403,-24.730584,-54.352436,-10.479193,16.529665,-17.542639,-68.400061,-102.716246,-237.530322,-295.913143,-295.765682,-233.898249,-72.272981,-39.254658,-64.644566,-101.168543,-111.990808,-110.355188,-66.839707,112.452817,194.980025,175.747434,0.956461,-37.605575,-1.104757,18.991886,34.717807,55.015868,117.287599,151.150757,144.696443,93.054005,78.743778,95.852594,96.577818,78.995725,69.798853,-16.416238,-229.823623,-313.039209,-263.621937,-167.857868,-67.233818,-68.135408,-23.08092,30.489657,-6.85901,-141.177307,-138.533293,19.139503,71.176814,60.628134,54.791483,86.562287,60.129317,-5.747422,-91.697847,-52.216298,83.130299,101.813104,17.844547,-40.677782,-26.099044,22.35784,38.267728,78.000865,113.138363,137.156667,89.785467,-59.760468,-170.257503,-191.642685,-155.283899,-116.34773,-16.415578,48.945242,127.960308,2.346132,-82.143238,-119.481447,-74.095239,53.162307,94.946354,100.141934,78.231151,40.197765,33.113713,18.345784,-24.905963,-33.374203,-24.567239,-15.313834,-20.352114,-94.249779,-134.995846,-182.234798,-182.218428,-111.815326,-53.068965,69.904468,103.252791,20.070876,-187.722518,-267.68746,-296.243138,-251.270433,-155.03389,-136.871337,-125.53365,-129.471517,-159.217211,-252.746075,-278.451602,-280.880336,-271.117382,-165.842268,-94.671483:64.982313,-126.652814,-211.378336,-256.546398,-210.838469,-55.177276,18.176206,60.389096,37.656913,41.490252,4.015637,-20.420467,33.317872,91.22174,155.433175,137.431821,36.871609,-40.850436,-78.545532,-143.638803,-126.914899,46.09449,160.643717,266.155986,133.16452,40.343193,-69.26943,-82.091971,-48.065772,-7.351077,99.555125,123.917449,-5.569804,-242.637311,-324.505249,-386.186141,-360.197386,-176.777739,-40.325452,135.427032,64.532698,-1.836218,-107.669065,-139.957452,-129.361554,-81.74284,47.306603,84.879667,60.033185,-34.986596,-87.35278,-121.298237,-92.748042,-8.919437,31.188262,101.21341,94.811666,61.281289,16.448994,25.21999,77.799078,102.320701,90.263854,31.311734,-124.609995,-255.800472,-322.006419,-364.801454,-330.956721,-248.162825,-208.830998,-130.139221,-145.915417,-192.928514,-250.487642,-233.930769,-162.852847,-122.255733,-26.96742,-6.522759,-80.305127,-196.866773,-220.676677,-151.161571,-91.203862,0.686273,52.588328,146.343143,99.867519,41.102244,-27.360734,-18.210846,34.635232,54.685441,66.415635,58.930503,24.298612,-97.416702,-174.892296,-223.964469,-188.443233,-40.881277,48.769453,121.946489,-3.98319,-79.408808,-114.645499,-69.120674,21.993638,33.989032,38.19176,51.377515,67.930713,26.868264,-0.866983,-17.817696,-14.232014,-19.169163,-12.13493,13.996165,-45.221595,-106.47157,-249.48374,-301.887243,-282.602569,-216.483897,-51.31783,23.502677,89.493236,-16.428962,-94.828379,-149.390681,-116.826842,-39.686491,-13.297439,24.621752,-13.953088,-57.811835,-103.273727,-70.728481,49.62587,94.00868,194.631377,246.249182,233.169329,89.447206,28.267627,53.829043,131.716913,238.259147,241.267663,201.447906,94.761107,42.150235,-11.435503,-29.26368,-68.132699,-69.044555,-18.61014,-10.234371,-117.409648,-304.526104,-366.638132,-358.00604,-309.849114,-217.41925,-169.217582,-37.753915,5.017671,-56.638382,-227.650833,-267.705237,-251.148931,-221.684133,-169.164866,-167.764994,-196.154259,-215.158223,-234.104698,-256.573569,-219.591663,-40.133128,56.296322,127.391129,94.17514,90.728203,102.962343,102.26394,103.611765,128.512589,204.784754,217.421066,177.657131,92.316025,27.560764,-55.545955,-27.61914,135.631458,218.527492,263.54413,235.165827,240.09371,268.289727,299.711448,390.833572,426.401807,437.068894,397.961058,273.64011,204.998421,195.167784,175.13975,169.509739,234.52404,290.736302,329.965907,287.716189,252.174124,129.73051,95.471568,199.359621,282.409529,333.435101,296.718794,177.232002,113.274377,116.29917,149.14917,178.660887,285.515193,337.513297,308.642484,105.828496,14.847082,-52.170179,-33.761277,53.394689,91.521107,94.503759,55.938923,-66.258538,-182.644767,-212.797637,-168.577988,-113.420979,-52.501694,-43.018399,-17.564102,-37.352387,-72.542509,-121.898544,-104.733286,-18.897171,10.256396,24.014611,18.284416,-28.293561,-90.064035,-117.599799,-170.884163,-190.850606,-168.755212,-121.066455,-43.628828,-23.740459,-24.852594,-32.81912,-24.240649,1.492196,27.742474,115.871847,118.945354,-21.225385,-152.760073,-148.81533,-69.623515,-39.621418,19.295233,61.842361,70.668158,-44.260104,-55.082917,25.786882,37.691724,-48.339084,-83.673804,-15.336218,50.890735,75.048162,-53.150056,-128.243746,-235.043141,-255.102003,-188.367194,-106.311363,5.849169,-56.734105,-97.668572,-110.97434,-96.179781,-48.168085,-7.86616,126.219701,181.225604,135.421178,-28.979213,-78.465193,-74.29356,-32.073395,138.11745,238.610285,297.826746,165.449713,108.842633,57.314686,41.73919,56.468265,104.054993,187.945966,167.539756,18.994402,-179.684152,-267.234315,-317.429844,-267.564725,-67.397295,26.735162,38.617695,-100.466448,-145.753648,-163.890171,-140.679968,-23.834106,49.772996,132.88306,117.71001,12.060563,-102.786375,-144.386208,-104.625994,-23.74417,94.026441,98.587365,24.946985,-90.320184,-114.208786,-95.766284,-82.288944,-41.69243,2.597705,73.52835,44.438073,-112.296882,-240.799866,-264.425575,-194.655868,-119.639223,20.818764,53.784982,0.142158,-102.600506,-113.049003,-79.391622,-64.099259,-53.221029,-46.498755,30.173353,73.465467,31.981161,-69.084672,-72.079603,-19.212216,2.476928,49.937106,78.148192,57.534097,-40.820262,-86.752736,-153.5632,-157.175798,-111.313249,-55.486186,146.48074,219.85622,122.005862,-161.873611,-247.37199,-166.348886,-67.90208,7.125229,-8.152174,-20.849303,-41.853872,-97.448346,-223.139965,-219.702502,-141.669761,-131.518748,-65.73671,7.381573:129.301661,-73.714961,-154.883641,-156.083797,-126.802988,-77.230069,-9.38957,196.402692,249.685597,226.786036,201.85338,202.820073,222.37294,235.046211,236.86527,222.545912,172.308542,98.630987,54.672626,14.347987,46.23786,149.954094,167.284043,106.007204,54.716799,56.819103,24.587711,-24.927384,-110.649233,-115.776938,-32.95371,36.279692,82.85763,-101.813649,-215.425341,-313.587772,-294.375516,-176.119474,-103.853768,-41.649828,-32.430834,-1.188153,20.768897,2.570553,11.847665,49.115432,160.484964,212.385614,234.009338,176.523153,143.443332,93.270102,101.276052,167.981864,203.467619,236.41362,162.819018,115.18832,92.234418,116.567783,133.750044,106.992731,67.117032,59.665341,-18.756096,-113.390617,-132.850063,-186.781879,-206.929872,-133.6325,-62.151406,26.229685,93.658973,157.610491,238.356876,212.821658,119.459502,112.537113,189.216745,223.280554,218.039216,170.212694,126.327117,31.91786,13.830247,23.305839,46.086626,141.873079,211.563313,200.989626,121.591591,92.900987,86.799767,86.371879,33.471396,-24.901868,-140.640868,-153.395647,-147.26881,-174.395467,-182.926282,-127.024709,-69.210013,19.819459,-8.48998,-45.256576,-74.062838,-42.652933,48.207998,57.972476,2.013729,-29.79328,-30.40043,50.667201,61.950064,-7.402478,-36.049891,-49.681295,-42.474333,36.200843,148.492051,171.755956,137.30097,115.316178,60.323856,-6.736652,-107.389149,-76.421915,16.453862,-38.359657,-95.613838,-160.342994,-150.253233,-104.535993,-74.280848,10.469526,63.722138,83.171735,115.746311,150.819003,278.825591,304.866126,212.601754,160.517675,158.897195,145.725908,87.248794,22.509862,64.201994,172.39902,210.979621,256.731089,181.503357,126.032727,35.456232,1.144092,8.642214,48.654129,106.971569,99.561364,-18.339552,-209.133107,-263.002243,-267.199184,-244.558079,-178.52933,-131.960838,-3.765103,28.286689,-43.620511,-237.56736,-273.510122,-208.577305,-164.184418,-131.942863,-141.286491,-159.097164,-204.748375,-248.382376,-269.307701,-235.822212,-173.51134,-130.336719,35.128477,148.629082,144.706944,82.301696,69.71575,146.211195,194.516288,175.149024,108.905468,-42.553253,-84.607409,-76.853589,-123.256171,-153.04215,-109.785827,-52.301706,47.083767,160.194345,238.594413,367.042956,413.93524,495.306182,489.561358,346.85521,255.442343,138.601774,156.569052,191.633339,252.981382,259.916435,175.383689,124.78709,130.995629,158.765427,154.913366,172.320964,193.406649,237.658439,266.571544,318.093603,298.349493,164.120488,91.682879,80.501276,65.881444,89.887307,165.353484,186.834758,220.396869,182.541869,114.567243,-11.967807,-11.799597,82.63871,110.282593,111.316535,93.520509,-28.680149,-136.449801,-159.908653,-177.604625,-149.030353,-90.329328,-107.089946,-143.378078,-83.281966,-48.23959,-13.002673,-14.35927,-28.480903,-9.104662,89.568817,117.00928,38.302563,-136.653321,-224.128959,-298.71118,-263.994518,-151.807634,-115.988459,-74.411708,-34.595587,-28.441361,-60.196719,-67.612126,-24.464687,4.804674,56.500197,62.618585,-17.05081,-64.410463,-26.503977,45.707898,41.222367,30.325281,48.887791,106.045874,113.053294,96.771165,78.730306,58.874051,-38.364702,-77.823182,-48.25878,-20.696194,-88.406096,-208.528123,-263.546074,-374.896892,-380.853679,-292.555615,-248.771966,-155.515428,-51.376896,-27.853192,-37.705322,-39.889165,12.703071,55.626189,154.603299,210.08744,277.385154,185.979284,93.457667,-21.02935,-16.67478,-11.537155,-31.731289,21.439144,229.802906,306.062305,231.396922,115.310902,-29.689753,-35.39241,-6.820723,-6.993494,-94.613099,-239.712906,-278.544479,-237.369913,-171.805073,-48.285621,-19.418741,-34.124464,-123.467883,-151.657339,-102.746235,-40.050333,83.925987,101.883791,19.501446,-36.536261,-64.398388,-1.685327,11.480064,-28.154066,-37.332648,25.73735,79.308125,147.912543,105.580142,70.227235,42.867272,44.846443,44.267913,42.508434,38.674394,10.730864,-150.048819,-306.475233,-316.12215,-218.024704,-144.236758,15.451913,79.144149,120.011369,43.494067,0.789699,4.776814,29.268396,18.060674,9.154705,99.903612,163.492019,167.870996,47.10944,-13.698775,-50.030242,-14.875897,47.929916,47.40554,0.189585,-121.734533,-174.020693,-184.599028,-158.708944,-138.823813,-154.566488,-134.991445,-95.320378,-95.852615,-260.13757,-346.74742,-382.121136,-342.959007,-293.49415,-286.685644,-243.594688,-227.662122,-272.391578,-412.285641,-433.086863,-328.237853,-269.808323,-223.055114,-213.427641:51.326828,-114.262881,-202.533552,-249.238219,-189.339253,17.017003,109.271685,149.043395,63.656937,23.487967,-48.024802,-51.201137,65.024459,141.286844,203.926522,177.128176,50.305506,-30.999982,-44.289343,-79.503295,-77.235695,65.833897,173.564047,254.004036,132.550575,55.66612,-87.17232,-120.557591,-26.15923,60.254523,149.997771,137.428863,61.28217,-71.135423,-189.018342,-418.95031,-436.760241,-253.206576,-135.185376,-36.794707,-101.507569,-126.280164,-132.553755,-134.328384,-114.334801,-66.532325,85.428883,140.597638,152.55312,77.89104,32.460463,31.488699,83.998052,191.825683,231.201592,262.735236,143.498056,54.921588,2.277109,55.713455,152.44869,144.811226,99.948495,85.737339,27.081943,-78.600982,-150.86905,-235.237797,-204.285161,-91.782463,-62.878928,-38.706788,19.537724,29.846468,-53.50817,-94.802716,-45.989747,19.893433,109.244283,109.488179,55.092637,13.849892,-7.981033,-59.647076,-58.224853,24.399253,86.202855,183.061804,221.481291,221.684077,146.782681,92.301401,41.48051,41.951705,72.462564,81.275867,17.717032,-87.10773,-127.770288,-158.120471,-122.093301,9.356207,59.932633,99.379,61.93493,28.67546,-66.809185,-108.734465,-87.415027,-33.118221,71.585293,93.568994,64.60912,10.15301,-7.90489,-22.899904,-28.630436,-55.474268,-44.802888,66.154921,82.21045,12.905056,-124.146129,-127.439893,-28.859191,16.801069,80.033824,105.972779,71.111441,-74.210072,-141.953004,-156.620641,-97.685074,44.411925,103.023745,147.169432,36.586434,-33.069624,-82.371993,-52.691347,79.89851,152.419137,233.204557,229.404183,160.09605,70.963841,37.594877,27.554644,47.384773,103.904504,149.397804,226.585573,140.071944,68.654546,-16.301993,-29.109544,-11.444603,-6.255221,-49.618614,-80.468811,-149.515856,-266.830635,-318.184847,-339.115328,-315.265421,-232.394207,-168.007093,-32.942015,2.94855,-37.242048,-186.839087,-218.921366,-142.344529,-107.277503,-132.563053,-162.013497,-193.280483,-231.306011,-264.210486,-274.886549,-235.389116,-118.70466,-50.982264,84.031579,148.58591,142.862612,87.076029,71.462326,104.090888,124.478192,123.082893,106.518208,55.410528,-63.45712,-147.69197,-214.91702,-164.409996,-1.083513,65.243922,120.864091,85.931943,73.632677,109.000201,163.388043,306.662233,360.801387,403.604613,391.455594,301.172821,209.961948,206.23046,229.861467,205.883868,122.750389,129.592096,233.118791,211.194194,126.966279,4.939959,32.04967,198.776965,278.582237,360.365461,335.414349,178.324015,69.128232,26.460434,-46.443014,-25.923446,122.170927,191.5615,225.635518,106.714503,12.330633,-114.598134,-91.996321,46.896992,87.283632,103.516053,88.122211,-33.35209,-148.592322,-166.206268,-143.630555,-112.292884,-61.693671,-52.512554,-38.8794,-47.307884,-86.351467,-167.178244,-154.368852,-55.628067,-13.711718,48.570777,59.43999,-22.997756,-149.256376,-194.155274,-244.228544,-243.882453,-176.015975,-110.843944,-16.074487,-77.870199,-122.326557,-145.112669,-126.467288,-47.611356,-16.060098,1.797566,3.262984,2.970311,-13.219387,-49.280962,-127.45747,-119.261173,-1.556897,63.185414,80.865963,-36.172,-70.879131,-50.850293,-45.891092,-95.400435,-106.427355,-17.00461,34.261714,20.520374,-110.523485,-198.192355,-308.819921,-295.942468,-175.935978,-100.368034,17.115521,16.772726,-20.395747,-75.908638,-71.233447,3.414432,50.534454,128.712913,152.17717,105.264386,-17.560979,-42.898983,1.772018,40.938015,135.662888,196.29631,291.458112,255.800648,174.772197,-24.205881,-65.613361,8.421146,72.768296,164.38087,154.755189,-29.579665,-254.382116,-310.697733,-303.675943,-248.322799,-92.172809,-33.556004,-1.303649,-72.14018,-125.521416,-160.764535,-127.072701,-29.859749,12.051859,74.014484,79.34423,17.789075,-91.153373,-141.161625,-127.817986,-36.50012,197.465151,258.037085,190.491383,20.444315,-40.158704,-103.517237,-94.657454,31.130831,106.39636,120.765618,37.58361,-203.765764,-347.120369,-354.938736,-287.561935,-227.858017,-69.254485,27.170587,155.106569,26.463294,-78.852229,-169.912677,-152.933549,-47.904224,27.596351,139.641625,136.005917,46.555335,-8.694616,-19.409331,-11.080442,20.615477,87.334469,98.961551,42.496076,-92.488324,-152.251512,-251.653491,-272.721423,-187.447836,-107.013562,23.915142,53.198247,-28.223361,-265.773983,-377.922633,-437.971319,-376.517979,-217.05938,-160.799918,-107.194344,-174.80079,-250.683591,-377.953717,-390.916474,-317.788472,-244.434843,-50.1697,13.31954:-82.252405,-93.68371,-132.081291,-191.874234,-181.622064,-74.119909,-11.512485,77.002672,164.88589,210.013188,187.248069,128.227131,127.459545,192.730453,252.916833,212.119692,55.961827,-18.961392,-2.387429,31.393926,49.21783,122.927431,144.92818,105.396644,56.294384,52.13129,20.576938,-16.216698,-85.677019,-95.417935,-42.794749,-12.756522,-55.968631,-189.026733,-248.792833,-342.982019,-351.664848,-251.732767,-178.347685,-75.714032,-27.181253,-12.691255,17.312978,48.817797,120.925157,130.417611,104.582994,100.31451,134.273651,164.254614,161.11488,163.12217,192.862797,244.515197,235.532184,231.620777,271.055396,264.968715,215.688898,190.095872,131.305983,85.795956,-2.421008,-9.130947,48.579059,68.556001,41.026052,-60.354706,-109.557905,-123.596793,-73.643172,63.50281,119.323499,116.716189,110.975764,113.616524,72.201503,35.216448,59.606366,131.254752,200.508394,62.315717,-1.207348,1.550057,27.916313,18.155357,8.213531,86.469335,195.362757,206.728538,126.079759,44.330268,-75.939265,-73.296392,-30.187772,-47.164934,-162.230456,-253.608223,-267.422164,-262.95509,-240.841457,-125.692923,-50.19652,73.243721,106.666007,83.150867,0.298765,-26.622198,-34.650206,-42.969039,-52.726373,-30.005916,38.910548,114.759185,137.340986,71.199089,11.434083,-35.257444,-8.026131,98.944584,180.413888,204.081319,207.810933,170.353742,1.611419,-96.487055,-167.429329,-122.413498,-11.296647,-27.156047,-94.399422,-232.26558,-234.923442,-153.837648,-132.948277,-104.913521,17.416989,77.247219,92.14803,71.286316,47.93407,46.328508,57.355995,53.304089,33.048291,9.47725,-51.282644,-163.747566,-123.365598,69.400224,132.280321,161.90195,112.512424,77.297886,52.715021,73.315111,135.497314,138.275139,78.546688,47.437614,-6.321535,-83.161983,-120.836046,-178.467736,-200.65554,-201.388298,-154.801428,0.502377,60.040016,38.912286,-9.765718,-7.121088,11.482181,-10.473368,-77.866351,-81.185627,-47.494483,-106.475671,-173.103257,-246.787795,-222.648803,-113.947767,-58.064399,40.320548,70.960904,60.362563,12.92686,11.721441,85.408585,97.084506,-2.890134,-75.06204,-232.428999,-340.311726,-332.39618,-285.760393,-275.668065,-245.247642,-230.019216,-223.023194,-152.958725,-76.712147,105.776798,180.727842,223.592268,188.826291,65.878575,3.277763,-60.116986,24.723337,80.093781,113.080996,109.420021,74.827,45.282,45.218786,84.484451,93.479046,105.142088,113.943047,158.154685,179.999529,181.418547,153.161482,62.297091,21.239632,7.168023,-6.71338,35.219482,131.640508,135.306801,112.353671,61.172599,9.38879,-84.153175,-85.704639,6.513601,49.1263,72.429187,57.549561,-37.234988,-105.940602,-98.164486,-74.127894,-68.563029,-38.699135,-30.79219,-58.81232,-12.711415,57.741472,145.8861,132.204028,96.256516,120.06005,205.270484,207.890568,66.880962,-85.67882,-121.840498,-167.063179,-162.660611,-88.485216,-48.749389,5.043205,54.130023,61.72103,-17.263138,-69.469109,-69.596164,-22.93786,87.122845,107.917283,50.261084,56.929689,99.402198,112.178802,75.356415,-3.650832,-12.179198,59.367969,96.36245,78.733863,102.702412,143.927826,147.66153,76.786016,-97.042729,-127.298219,-98.368001,-112.366579,-169.318037,-296.86073,-303.51469,-258.420795,-256.483742,-227.819952,-99.572328,-35.917115,15.031233,8.092599,10.994361,30.840159,79.050995,101.147486,96.512025,35.276013,5.52373,-57.337426,-79.386671,-100.551558,-106.9406,-67.529864,52.249269,84.641761,-33.227143,-156.507012,-319.111928,-319.749721,-248.340103,-220.642301,-221.32654,-294.198916,-336.679743,-345.062069,-306.032335,-214.296533,-175.915916,-108.409225,-111.252254,-143.18369,-188.347164,-163.09512,-32.409624,12.551797,-24.777747,-64.928271,-29.615084,75.677884,67.989773,-40.85103,-80.458159,-73.859212,-43.152991,13.341511,22.673786,18.417899,-29.123103,-83.410242,-167.358356,-159.784307,-135.435115,-178.197481,-319.94158,-377.477579,-375.573921,-331.714473,-285.54125,-163.501441,-85.625453,99.175404,135.912959,70.496855,-78.750425,-104.946868,-98.30183,-109.58496,-84.937029,-18.881305,85.426063,43.604122,-18.614841,-132.640733,-132.983896,-66.776571,-54.030485,-98.723887,-192.026102,-207.227893,-139.278152,-117.922676,-173.340867,-199.966457,-193.096404,-191.164937,-238.623941,-357.948206,-433.217469,-515.845621,-485.913692,-333.199349,-262.625851,-180.317581,-176.756791,-211.87141,-298.144989,-305.370108,-240.557765,-196.166804,-116.021782,-85.937845:123.469966,53.427678,2.527692,-77.084251,-109.62958,-117.783246,-58.905888,135.867872,267.686618,282.578232,208.610323,163.288258,199.23866,263.042918,310.050763,258.949255,90.922216,-3.955734,-28.975965,-31.908908,7.077444,65.877689,44.062379,-14.898778,29.824135,32.084781,-106.505009,-182.126952,-205.791117,-169.949591,-45.351828,16.905041,21.595855,-86.982628,-136.309874,-173.834207,-139.377607,-3.63468,52.680118,98.736632,126.27638,156.757498,210.919238,224.485947,230.578915,230.734918,275.04076,316.758202,377.287607,348.285036,286.883796,140.236087,113.946823,188.830597,249.285768,317.933514,301.8887,280.864372,255.349737,248.174026,199.379286,152.883478,79.063316,71.325164,46.007475,-24.539139,-47.304472,-61.98663,-74.240212,-110.654771,-108.326389,-37.496805,68.756601,141.057157,269.51006,264.019539,139.08052,97.061571,120.986307,141.388615,96.270473,-25.764442,-79.185134,-131.568937,-114.772478,-53.975427,-58.535675,-107.260704,-73.606907,-38.326295,-27.184328,-48.528106,-120.915418,-175.294387,-234.665061,-221.959457,-226.780696,-281.889981,-279.130307,-238.866706,-245.224608,-286.448354,-261.977558,-113.024025,-44.783815,-72.128662,-139.588161,-135.774561,-92.489421,-111.048008,-224.862619,-255.480452,-202.523584,-76.586219,-36.389937,-68.151136,-94.642175,-74.706082,-32.411981,106.44818,205.750938,221.567582,235.67394,210.38354,68.511501,-7.353292,-53.473261,-21.623645,41.529909,31.250364,-14.471966,-150.254931,-168.222646,-33.459851,56.822376,120.503528,104.589613,144.488912,293.475414,351.095386,365.326649,316.869348,191.617603,152.73102,129.895522,145.384009,147.033521,142.41169,141.080314,155.616467,193.362636,267.808035,168.132167,79.581524,-73.716865,-119.190818,-49.752619,55.782509,249.388215,294.409401,267.786132,184.647345,145.814759,45.369341,-20.431441,-127.405136,-145.154414,-128.418556,-101.048197,-113.561125,-197.169522,-214.921437,-169.856661,-167.833273,-231.779871,-253.125711,-248.788703,-213.901192,-197.418832,-225.884886,-271.571503,-296.874559,-234.243725,-79.895152,-64.483968,-76.073054,-47.099901,-1.042377,108.094547,142.835801,138.149956,99.364812,-25.524829,-109.221343,-129.715212,-191.518409,-216.30091,-162.277027,-78.13046,70.728284,155.286649,216.266396,296.107132,301.490454,336.894757,353.076493,299.850517,245.711136,189.323842,296.941616,361.657751,339.465776,274.160944,151.499501,117.089022,138.288088,198.645135,213.368173,214.295095,214.360609,234.28546,246.868075,291.348339,306.095645,251.620743,188.50189,175.811416,159.382462,162.823272,189.591723,197.408187,154.982335,88.557964,94.22171,128.581054,131.566051,107.302616,76.239288,37.256059,34.014087,-35.688341,-129.422849,-149.875305,-192.33839,-222.146364,-276.060524,-287.267336,-230.325779,-118.833638,-88.066837,-106.148533,-121.7455,-88.543167,-63.516832,-55.922743,-72.705384,-123.788817,-156.820847,-180.117985,-239.982074,-239.789744,-158.457363,-104.671026,-37.789733,-21.869583,-15.9262,-26.502201,-42.747057,-23.874131,24.496414,106.89542,99.572832,18.773831,-16.829102,-13.642871,43.522901,103.084788,137.631525,86.843129,37.613572,117.513157,122.251486,27.908242,-20.525842,-41.351008,-33.481182,-63.559345,-106.215378,-176.790972,-140.224854,-123.018487,-200.723571,-245.377073,-238.734099,-220.544667,-194.767032,-137.938099,-111.41898,-71.978556,-44.489234,39.456899,88.650007,181.673761,196.845189,105.257557,-12.007126,-37.921541,-66.414947,-85.729362,-154.054556,-190.910043,-184.749474,-39.070465,29.715736,-2.197017,-101.938531,-298.392385,-327.93937,-210.017722,-124.769122,-93.956795,-162.307085,-188.336669,-233.75512,-225.490275,-114.689556,-42.185506,21.973512,-86.323705,-158.486511,-219.022238,-189.720621,-48.688397,5.870278,5.191039,-16.186191,-26.04751,-46.763099,-79.749472,-116.262005,-100.301427,-50.837663,-19.858599,15.417434,-34.687649,-39.597928,-8.152933,-4.900592,1.023161,14.272994,43.425488,36.156249,-87.613784,-215.291888,-216.817737,-115.450326,-37.50768,105.006402,156.347381,222.080259,152.102153,70.879904,-58.965005,-89.140962,-87.713474,-68.878447,-10.711181,7.607012,-20.460057,-12.094267,18.53197,42.866781,25.235143,-42.027933,-72.03614,-133.262378,-240.786386,-271.591401,-232.489796,-187.200653,-100.854838,-69.893544,-39.184362,-50.807931,-134.027099,-260.559266,-325.048391,-312.215294,-225.353327,-98.694099,-82.381669,-46.773163,-52.970502,-84.743379,-138.687589,-134.298549,-57.115545,-10.870908,35.865818,24.087594:-166.908036,-214.259456,-232.723871,-210.973348,-159.789658,-21.769927,29.253136,87.409412,104.941059,103.081275,80.811243,67.002324,57.526743,51.571015,47.975759,82.301142,165.371705,76.36232,-1.523048,-13.397456,63.213704,217.890115,231.388853,133.672128,32.638088,18.866903,39.9151,32.974308,-59.544751,-90.58647,7.863712,83.277796,58.25668,-125.914631,-190.913174,-261.536471,-284.740225,-267.214624,-204.065298,-6.333367,49.334036,-14.653908,-132.724599,-123.938057,9.576201,79.15821,122.027577,127.868991,189.600006,227.506859,188.627468,32.377373,-3.595466,102.736665,188.254941,272.399465,239.899513,200.569713,142.125153,147.806157,129.086633,68.903932,-20.489115,-8.26402,37.455129,50.436541,46.429847,8.654042,5.167438,50.873909,58.61446,16.034613,37.054809,92.80431,148.04615,103.284239,-10.204695,-9.437275,128.065416,229.382764,339.236216,229.081339,160.590086,101.711544,100.958873,137.194246,162.673671,205.87202,222.882169,208.493367,162.184642,141.869136,85.449433,45.109108,15.157511,31.137021,-10.022479,-109.746113,-110.197287,-41.546787,-7.243755,48.269533,69.012468,97.090972,102.192889,83.059128,-1.112395,-36.480526,-5.17486,45.803795,97.222857,80.188356,42.25587,109.046412,149.981868,97.249132,25.295322,-34.20135,12.373844,149.813849,120.627283,89.323087,133.051412,154.855734,111.418329,77.938719,57.242529,63.98058,-13.9952,-150.693521,-169.980384,-142.168884,-119.526748,-137.614531,-169.619156,-111.848049,17.500707,38.136079,66.808732,80.78852,56.64519,28.629948,14.92345,40.489765,70.835151,-40.201441,-123.433279,-153.865347,-70.975845,121.388155,178.03819,267.112621,270.31909,211.230815,92.134005,81.529053,144.188263,159.078524,30.025282,-88.229873,-226.254093,-156.38053,-124.740119,-181.002191,-227.117565,-234.587374,-187.361463,-78.07808,-31.992846,-16.736175,-26.508182,-39.274313,-37.249514,-63.164023,-155.577199,-154.913707,-75.717696,-142.861439,-231.825838,-307.277861,-263.60322,-147.554387,-87.065694,87.476843,168.875875,148.563391,110.080528,117.91701,145.024499,135.536076,62.730052,10.611012,-126.564748,-234.466946,-253.718517,-252.618218,-226.397629,-154.469954,-134.486346,-102.656924,-49.713377,-4.836977,93.695055,129.445566,215.251399,253.63749,207.963841,133.675512,39.872329,37.132598,31.835524,41.778637,56.508099,38.332992,33.647263,94.913001,73.703975,25.939869,-2.967266,39.705177,199.17648,257.391256,214.079886,130.675112,-20.90745,-43.195783,-25.298892,4.882674,18.113877,42.827885,50.684974,51.767067,16.186777,-0.555864,-7.193478,-14.099725,-30.738281,-26.338122,15.584704,37.371583,-3.772925,-127.447642,-156.20203,-106.506077,-72.511074,-43.98923,-9.749059,100.214901,113.806693,105.9877,112.426744,112.135268,114.978038,122.519323,136.277816,125.093942,40.627632,-13.268776,-27.831906,-118.860869,-155.042932,-89.849542,-9.067984,85.313953,-39.986475,-113.065998,-124.361272,-71.89091,57.968337,91.862139,93.299555,81.174135,-7.259615,-107.196083,-107.616394,-38.209781,1.570474,32.573501,31.746169,42.267081,27.585208,16.890899,-21.728755,-51.235554,-55.647319,-41.258619,-8.958254,14.857158,-24.764996,-185.119155,-246.218657,-308.403749,-312.045536,-266.693243,-223.973107,-107.943094,-38.308675,-32.595796,-42.543186,-48.207255,-1.244886,45.34326,132.26869,167.956844,163.048042,103.184098,70.357568,-44.871137,-84.764277,-47.479609,11.034868,127.36384,161.306758,145.039204,24.762359,-47.062418,-76.042852,-54.377209,-46.303937,-66.206972,-162.540684,-300.756126,-329.869467,-282.521595,-236.239976,-165.606857,-158.641887,-186.738382,-183.579295,-155.580678,-72.733315,-36.19019,-47.69459,-105.783689,-163.878393,-115.520153,36.498118,117.227715,86.927686,-59.284317,-76.674333,57.400741,125.074351,133.201433,37.840928,-1.081035,-28.917224,-29.262248,-51.104748,-91.872673,-194.190049,-228.680131,-302.268503,-428.39999,-453.697562,-339.076611,-248.864618,-119.970857,-65.720214,48.248669,62.982108,10.052063,-131.768993,-169.180071,-111.50882,-33.561094,73.451112,64.753956,9.649806,12.697002,-4.350691,-83.76713,-92.035761,-52.21202,-43.456723,-58.839396,-136.438109,-197.512938,-278.877049,-278.609045,-240.173574,-217.932023,-140.170982,-97.40414,-107.329453,-270.968569,-377.823687,-522.14897,-523.570448,-403.189663,-313.681418,-159.189783,-148.722126,-229.364376,-438.363624,-464.863784,-323.421076,-228.09905,-95.64221,-66.364184:left
22.907281,-79.835246,-137.662372,-111.38463,-51.902421,6.769761,-2.491459,-58.295992,-91.262995,-84.032927,-59.501616,-58.737164,-115.667352,-143.676603,-148.63961,-167.690631,-203.512769,-130.69095,-91.416845,-0.271192,60.118553,91.747519,22.610578,-184.102114,-200.439831,-132.058364,7.012275,63.367502,120.813201,128.444675,184.562854,235.067793,338.366234,324.470988,258.561478,150.070347,140.819006,150.318897,126.707714,15.13433,25.378702,101.871537,212.065373,203.374178,128.697392,91.902718,17.998461,-26.12291,-87.359257,-68.667899,-32.610234,55.949564,74.294191,46.761544,20.341822,-36.474207,-15.565802,29.380824,83.7048,69.367354,-18.535056,-66.958653,-147.925668,-209.076173,-333.489535,-269.56496,-202.927879,-137.528691,-126.369364,-100.680132,-100.66552,-142.260097,-102.851533,-42.836508,-0.398112,-28.626163,-75.31168,-81.103701,-83.463203,-83.546216,-64.671751,32.644517,93.762848,145.964291,147.805141,180.952386,198.37194,177.501282,195.825412,243.210574,285.588899,234.284426,22.076646,-70.345564,-112.539746,-85.417904,-52.189638,-94.219133,-117.215587,-133.992643,-141.062867,-185.778368,-215.915341,-235.001589,-146.721793,-108.830671,-141.529257,-175.663192,-187.485616,-177.907526,-185.30537,-200.174032,-158.710609,0.304041,64.558846,170.425636,235.832742,291.758945,258.988564,201.267723,261.877078,291.370264,237.449373,182.608664,150.033435,162.820214,107.834683,48.646371,7.696888,3.829257,0.700259,49.257032,60.135675,-36.485997,-110.468048,-185.018915,-128.430182,-94.727106,-47.608061,-4.473805,87.030173,88.09624,-31.785217,-113.389096,-170.006344,-58.778003,16.191133,106.873859,95.707189,14.052428,-11.908313,-63.545721,-141.793018,-146.141781,-63.540464,-19.369232,-29.372403,-69.042347,-144.156961,-188.707036,-254.618196,-174.636878,-98.731172,24.527729,34.599101,-58.021643,-116.390984,-191.668513,-193.36458,-140.314925,34.151551,92.388354,57.531585,4.032575,-57.980442,-71.372328,-81.499774,-25.881477,17.761508,66.204449,48.93111,-59.961261,-122.543646,-202.152471,-168.598624,-123.271576,-26.550993,5.871318,-7.776597,-27.820226,-32.167599,-24.269834,30.036424,111.567619,157.35095,294.96946,352.509742,347.129189,287.099816,134.640841,114.465396,166.882419,254.790564,263.885279,246.811556,229.75678,195.753341,190.7627,210.502774,241.694706,266.547116,319.042888,314.288458,212.999401,142.714336,53.666834,90.57386,136.583899,180.387022,154.912428,62.076931,30.249673,-18.866847,-54.731929,-89.040913,-65.760123,-66.834834,-76.591839,-64.539926,2.534937,26.837863,1.52769,18.457621,52.71515,73.156187,79.198518,133.471876,154.702884,98.989599,39.502737,2.856389,50.282124,71.02376,100.995179,97.202377,41.476429,8.921278,16.838822,151.399203,220.513394,265.065844,257.48552,266.173578,257.487574,88.942406,-35.421655,-137.735901,-43.63082,11.701754,56.973815,32.508416,-55.317314,-83.060516,-87.360688,35.179673,137.508051,233.942214,207.643471,141.683915,147.883369,208.511875,215.085811,201.81081,267.933268,302.536962,324.677958,322.706009,302.368575,276.406536,191.08271,137.940359,142.872216,215.175761,250.938157,209.190376,149.425962,41.320708,5.769138,23.6557,143.982837,199.77823,210.733211,163.407926,89.601068,92.298285,105.562161,110.775451,132.039287,213.074652,256.645211,263.337662,223.914035,133.149729,73.611512,-70.898232,-105.196834,-66.936439,20.517289,21.007772,-73.602969,-137.128215,-222.084231,-165.082287,-102.958676,-49.696306,-65.221045,-115.257255,-138.858218,-160.308755,-159.099044,-137.329831,-62.380353,-31.424659,-60.114821,-93.567618,-64.844024,-21.300984,-28.961885,-98.151868,-87.570251,31.576615,96.417498,124.993538,78.51259,-69.861047,-121.221918,-118.563852,-110.424761,-121.53846,-111.50135,-113.536465,-171.735354,-206.42883,-238.822882,-171.153414,-140.128517,-165.810738,-191.234982,-229.513602,-242.381339,-248.764975,-254.297603,-253.087936,-226.802785,-209.292149,-177.519075,-198.798595,-350.121082,-436.065126,-502.950119,-440.373027,-408.982677,-349.230908,-302.749338,-249.085617,-267.568081,-314.188246,-305.753947,-253.534336,-227.578168,-210.551872,-136.758232,-108.348947,-127.717567,-170.146549,-234.159768,-130.806762,-33.207124,116.781777,157.280729,164.484931,130.037008,95.878749,127.190016,223.325815,247.856655,232.504174,182.245005,140.030093,40.68348,-0.453754,-76.137579,-58.191867,-5.264258,80.647716,98.235355,68.829032,26.902158,-66.620414,-101.89043:23.19033,18.148693,-15.946412,-84.586378,-75.312288,-6.137494,-1.457157,-68.686836,-127.674469,-132.823419,-100.128445,-91.687422,-138.813457,-156.92396,-162.932363,-173.815798,-130.026056,-5.209056,24.700402,38.084528,53.416762,50.682198,-3.264544,-119.472376,-82.176094,-31.001365,53.780106,68.765854,20.347756,-6.973319,6.218436,25.53745,63.110602,178.310396,238.049708,230.744339,187.550712,125.789504,71.529842,-69.370799,20.405105,114.762814,138.761144,73.175308,-38.175877,-50.980247,-47.88956,-60.727365,-86.523992,-95.885293,-72.342553,47.096313,74.555173,-17.644541,-97.187667,-175.875856,-63.698541,4.384612,25.243275,-20.988544,-164.732304,-234.310375,-328.151395,-351.164384,-351.186126,-285.867893,-231.342802,-107.130848,-82.421878,-130.714685,-148.927563,-105.454859,-5.663396,19.171599,-44.141216,-94.845327,-141.367633,-164.475828,-240.403966,-240.463181,-146.150383,-76.581303,-29.036866,148.807124,221.490855,198.663915,108.769771,-68.4095,-45.301296,13.963494,79.84861,49.034344,-111.800921,-182.597875,-236.491896,-238.236379,-212.940167,-168.238944,-137.490034,-75.789399,-67.525436,-122.457532,-178.360565,-247.902264,-164.570854,-104.931731,-39.919009,-37.188522,-85.394126,-138.893341,-266.244081,-305.8136,-281.348393,-149.682777,-87.400041,-8.527304,23.652706,73.949255,75.384978,74.724744,139.407245,172.472592,172.582751,137.886122,66.345572,50.234114,-37.485815,-102.399546,-97.985863,5.119051,29.162807,-17.92,-74.752115,-135.873753,-125.576376,-82.562853,-74.399819,-72.34657,3.440463,52.187279,8.125635,-69.292882,-167.208311,-172.139703,-150.386338,-110.403136,-68.658802,25.908188,33.362595,-26.025927,-34.858712,-20.137671,-46.705296,-39.046749,30.758544,59.022887,54.29505,12.3351,-151.001458,-230.096148,-236.599794,-80.312537,-27.36362,-47.577407,-72.501319,-70.348906,-77.388307,-119.032988,-33.086351,50.831766,148.204414,134.970762,45.1636,18.117816,42.621525,72.974945,117.738166,92.818068,64.309843,14.752295,-10.38214,-64.159831,-76.159158,-55.754956,-38.217579,-29.469994,58.914119,132.747388,189.798358,141.921201,-6.748546,-50.861806,28.46277,197.896781,217.024884,168.53087,159.272239,160.634227,133.698684,56.478671,104.958464,165.021297,259.634736,283.483681,241.481886,170.839791,48.434626,42.895691,92.119843,118.908196,143.452507,192.36781,157.237022,-17.991979,-80.609104,-83.856342,-30.612127,-9.335314,12.596118,-5.70259,-89.954558,-121.246889,-142.32514,-145.705875,-122.000933,-95.102253,-92.941864,-50.612226,-19.573732,-14.104341,-37.845691,-71.678246,-5.118169,54.408507,89.408442,61.36813,59.462846,99.006808,116.101861,82.798174,86.241959,184.108568,231.669025,267.239343,240.966433,166.689529,128.069446,88.491946,198.296437,264.465299,311.337673,307.146315,284.289942,250.082186,67.668007,-50.806017,-146.14588,-33.615235,22.289332,-20.446243,-101.002421,-181.855895,-155.192418,-68.224341,5.390585,50.711756,153.928071,182.131489,146.977908,104.919368,20.536913,-2.821709,55.360164,205.009323,264.890988,277.638087,248.019067,216.438588,200.507538,147.812748,186.264232,229.412807,277.076486,266.003051,166.07932,97.835263,-24.35415,-45.244307,50.565859,189.62466,237.373176,255.548138,226.534825,188.584006,174.846709,116.783901,173.553052,248.336942,380.297015,398.933546,299.356573,232.245745,174.638812,154.349544,75.699949,14.284002,20.144096,76.416647,74.424888,-26.362176,-83.202701,-120.48524,-60.309081,-15.300797,56.120708,74.981679,83.7262,76.597604,22.98391,-19.254828,-49.019766,24.63716,61.026386,54.630385,2.137007,-148.25299,-204.506418,-199.440136,-54.754491,14.53433,91.783381,118.361666,97.716624,23.833465,-112.607544,-109.250495,-40.144107,-61.145162,-68.399378,-23.245988,-5.681473,-27.287422,-62.74892,-120.199415,-102.866334,-82.980558,-38.739036,-28.43689,-90.101959,-146.044127,-224.822475,-245.468386,-251.487066,-160.905345,-95.72402,-95.003836,-174.385386,-308.737671,-335.728528,-383.972222,-359.119373,-308.987495,-215.756437,-194.299027,-252.800258,-318.449535,-414.687874,-426.303766,-363.294783,-233.723494,-197.295353,-216.900252,-237.330097,-242.257124,-255.308988,-298.369132,-178.921344,-59.086691,156.782157,207.833513,124.90348,21.830819,-96.49903,-66.089419,87.151536,184.017893,189.417832,154.923898,144.291722,119.982179,67.218214,-64.128959,-57.593187,-28.22011,4.9553,30.478099,77.415502,58.761819,-60.966193,-119.237396:-0.103415,64.768468,29.74939,-35.315503,-20.340012,0.117067,-36.104471,-115.377212,-106.153096,-95.801972,-105.837034,-129.262257,-189.358323,-210.866824,-265.855447,-282.925169,-202.500278,-74.094273,-36.464215,2.253364,10.4667,-34.391537,-105.163152,-233.776369,-181.825007,-114.758268,-9.422602,-4.321047,-76.221767,-101.967912,-70.375461,-26.791191,81.098898,192.550754,228.853251,215.701569,180.119707,94.944284,42.754104,-56.444485,-46.127976,-3.803282,30.743054,12.826106,-4.82857,-1.368125,-79.950396,-143.884102,-164.035936,-139.953984,-136.497991,-58.506157,-16.349014,-60.3857,-125.149372,-187.504122,-108.438853,-46.616136,50.0544,41.046565,-134.401634,-233.083731,-317.39556,-318.606554,-305.493001,-287.283507,-265.760563,-225.636897,-215.064054,-170.762967,-149.030303,-144.923789,-76.355334,-22.751325,23.530169,1.81982,-113.138067,-176.725923,-259.183545,-256.847831,-129.708489,31.866497,77.780188,127.576717,143.464738,116.307236,54.507461,-62.263987,-20.782046,15.835322,49.637935,47.9816,-12.590087,-72.214032,-222.814027,-259.244202,-147.25551,-5.342141,26.093585,49.420537,27.917317,-85.410227,-157.69591,-230.224164,-104.922275,-32.969336,-37.534564,-101.618139,-250.717777,-295.73669,-312.759398,-310.639394,-286.168015,-195.944901,-122.937722,15.93486,50.691943,53.50827,39.549193,43.385327,105.809501,139.619679,181.780029,157.843966,26.719815,-33.128079,-137.187104,-179.718032,-147.434311,-17.658428,16.710475,-5.157954,-50.316132,-173.907249,-231.751698,-232.42833,-87.108798,-35.223533,23.786613,48.051183,0.101395,-90.305858,-280.031575,-303.17095,-180.971494,-53.508783,-26.770536,4.451958,1.753111,-61.657725,-97.571926,-130.163638,-50.152476,34.60122,155.582951,139.912987,3.446936,-68.886796,-183.708005,-210.566853,-152.039141,-32.246198,5.335853,4.402111,-16.821718,-39.997934,-50.140748,-59.507295,35.017606,102.598607,187.09094,198.274076,160.853786,119.038208,2.126447,-64.770304,-94.400123,50.179392,109.148685,84.051719,23.562573,-67.211277,-75.298936,-42.217683,-9.559486,-16.911335,17.414499,80.235104,112.194058,47.797406,-95.711366,-112.315156,9.281544,124.737816,130.812107,156.064728,195.266964,240.067951,206.785366,71.075494,25.818074,72.412708,233.838686,283.087617,231.787928,167.272217,78.171939,55.335761,40.490376,136.13125,213.658614,268.139005,219.042612,69.449197,4.229642,-39.669836,62.977736,116.134166,131.29532,85.743111,-57.892634,-122.447063,-166.321233,-139.214463,-88.91117,-100.434407,-87.91183,-2.972285,29.766409,-3.238793,-56.799667,-114.725842,-13.125761,66.471826,186.639448,193.874864,100.699961,49.495105,25.224993,62.575689,216.542376,324.221086,345.599952,369.959393,360.239153,266.040151,203.460333,194.762417,364.170685,407.24693,342.218148,316.470182,337.155107,316.727442,140.494549,29.492445,-79.679222,6.701245,60.624471,20.597528,-57.576089,-129.099603,-107.905952,-44.553803,39.622338,76.167185,136.927731,185.391855,227.092401,178.500022,21.563597,-20.042011,30.618319,133.010883,188.600083,262.043354,244.55706,155.626524,124.767298,145.815725,256.791057,308.464444,327.221941,280.538343,154.695283,115.486357,31.939885,-15.875578,46.18753,280.669993,345.618759,284.275515,227.270786,182.451467,167.690721,164.900944,292.949676,359.007399,419.371981,427.307583,387.287193,336.612624,213.067703,163.268345,130.197779,149.934896,158.024977,128.218688,91.456955,21.107597,-24.706273,-131.763224,-83.691488,7.609146,158.153377,175.75695,133.316177,92.895411,-16.841684,-71.150025,-108.52757,-33.018913,5.252832,1.440606,-31.051676,-85.884572,-101.745911,-121.162789,-89.407264,-40.736115,90.718664,125.753293,39.738258,-43.179709,-119.601127,-95.478594,-8.773707,32.27252,40.984861,45.941106,35.127519,-41.589245,-102.109986,-190.624574,-159.737649,-102.646426,16.558341,24.720417,-84.820461,-140.151654,-144.316843,-110.060752,-48.495528,-33.736569,-56.781178,-156.38668,-197.090684,-241.987343,-286.537138,-391.676239,-315.669168,-219.83923,-84.24304,-96.888634,-281.242359,-368.675764,-382.284168,-347.193779,-297.226085,-250.462151,-215.863312,-143.008075,-127.903439,-180.167252,-239.914584,-335.449915,-295.67919,-207.354286,40.377064,114.106925,33.190223,-66.349758,-168.92032,-144.806967,-15.53688,100.716084,128.463349,87.818634,24.479593,-91.453166,-119.956702,-134.105027,-102.952135,-77.994188,-35.302052,-28.01517,-75.391145,-113.084998,-160.687596,-174.054306:218.88664,101.411535,42.55538,30.0433,59.231764,82.011586,55.311724,-48.784994,-126.002527,-158.853609,-210.806024,-211.324816,-213.747226,-234.758331,-280.08702,-287.347775,-222.672741,-102.396064,-64.517783,-20.166378,-11.396029,-54.476858,-112.802613,-229.545154,-213.388089,-161.024264,-11.344671,57.606748,89.633714,90.750962,182.991497,242.084119,305.065078,308.098528,292.645497,257.0457,246.315359,207.564364,163.453792,62.960753,61.304344,100.09779,156.322886,143.723835,81.61316,66.715865,37.415726,-6.598839,-103.99272,-90.809351,-24.617925,92.471486,70.747576,-62.368036,-100.110375,-86.544897,-18.055828,23.170316,77.695713,67.185662,-12.272629,-48.90859,-142.698081,-228.402806,-360.972346,-299.213485,-245.842287,-183.170208,-163.233508,-164.538262,-200.12514,-252.219329,-133.974029,-49.983629,13.570974,4.3776,-20.262842,-43.77761,-115.645022,-132.683478,-46.178817,124.095431,178.199483,230.811395,242.047385,185.915763,122.711784,63.699345,156.053611,207.069611,242.615772,222.277027,114.685804,47.961749,-52.845157,-84.425987,-103.820201,-56.236994,-33.102514,-85.70853,-159.280792,-267.216808,-271.552309,-220.548421,-93.694687,-33.502868,-40.884145,-95.753691,-197.270851,-223.927577,-249.815944,-237.150187,-102.521021,10.556313,4.556983,41.511573,115.911735,190.978965,156.795731,106.625943,202.840615,251.079052,252.751678,225.42503,157.846788,105.270106,-35.124478,-78.16662,-58.66205,-13.796141,13.833528,54.841886,22.763901,-115.567726,-177.971719,-247.855962,-205.722678,-150.755018,-61.343,-47.681759,-66.900382,-88.848558,-186.25926,-239.911266,-219.30617,-92.920056,-31.807135,105.106048,137.834359,40.884779,-34.238221,-97.142175,-37.158172,22.873718,117.436334,134.820623,100.367037,35.984463,-142.193233,-203.181005,-177.410869,-47.148917,1.499154,37.572922,31.057298,1.760594,-13.249819,-18.259652,46.26735,91.153077,171.157065,208.041405,239.341332,210.348434,77.608416,16.328641,-4.209491,45.508748,71.708667,120.917874,115.7261,29.069699,-16.190397,-42.454666,-10.084183,3.596146,40.971977,77.324671,123.917869,98.69218,-22.928333,-58.907875,14.662659,115.071578,131.767847,177.505378,215.984013,276.816106,270.966649,181.019142,182.438669,247.546306,361.797727,380.51131,379.983637,366.5029,312.410583,292.320789,300.120055,321.592649,331.167347,351.099265,332.876697,198.844849,120.329312,51.753557,129.476278,178.428629,171.486332,122.988433,60.147011,52.920534,-18.276892,-82.282382,-112.655991,-8.214952,24.813235,45.738114,53.908567,44.585382,25.939201,12.685324,60.41024,81.294159,81.722556,76.785645,69.103606,63.440125,63.860203,77.312159,115.495881,135.236953,146.805557,183.132349,206.02297,221.008968,184.64639,120.970058,231.315676,288.146063,281.500916,254.089807,208.210308,180.238366,77.578974,-5.432156,-147.323537,-127.621805,-60.350659,47.148699,38.215646,-48.861968,-88.733069,-114.29908,-28.419098,25.972552,96.367169,121.076504,143.759113,136.929257,113.203139,105.684597,125.862462,210.13132,264.040421,329.548509,323.774138,253.198733,200.133362,116.233329,197.816609,263.443817,315.544084,306.683315,207.920164,131.135516,31.748857,37.004008,139.898412,254.811019,275.015367,232.718257,189.105421,128.289863,130.028527,157.998685,170.113094,173.095796,207.393484,235.182007,218.821934,165.50109,55.590008,26.032418,-4.274687,-44.19595,-55.158855,-49.002111,-59.121613,-148.417966,-209.159634,-284.860732,-216.313056,-156.191883,-99.019058,-107.216491,-167.112538,-201.64208,-259.804471,-282.808184,-289.622038,-232.409009,-193.696865,-130.498579,-114.437793,-109.90963,-119.198352,-130.691401,-120.788466,-120.074512,-68.151766,-12.325309,22.401526,-14.750067,-95.854857,-125.478933,-165.905766,-164.337778,-152.031721,-122.545702,-109.689879,-137.981437,-201.190798,-305.131231,-176.501961,-83.282624,-37.203044,-80.80324,-197.113533,-232.05095,-229.557527,-203.475337,-108.900635,-49.041531,-69.333897,-197.868489,-265.907382,-314.182208,-308.260733,-297.192233,-257.567187,-231.20308,-210.102261,-221.600131,-307.005158,-351.87409,-353.587387,-334.054708,-311.551858,-241.774105,-185.079586,-106.057538,-98.808468,-143.014369,-192.552,-275.444168,-191.677605,-94.464773,70.44476,109.532281,95.896039,54.565756,-21.828989,-32.954415,-2.810547,39.960078,56.001022,51.966481,17.78029,-62.761156,-82.590876,-101.67924,-125.645092,-132.136797,-90.913694,-55.794038,-69.910972,-110.00771,-139.40072,-137.644864:182.743307,121.241705,70.638401,58.374331,74.14871,11.277592,-55.380815,-132.048836,-122.496664,-126.070598,-131.179436,-106.996636,-91.469659,-138.240625,-281.136385,-325.837582,-277.472194,-111.454201,-32.991317,34.151256,0.906964,-146.583604,-216.416489,-268.755672,-159.986992,-82.918287,26.82006,55.315425,75.029849,86.945836,120.367356,143.489696,260.892018,376.28271,383.731289,320.400055,270.50348,162.812488,100.759315,-8.897341,69.253439,163.186089,215.79232,136.8252,-65.867612,-107.282889,-80.545363,-66.389492,-69.236137,-51.822086,-22.441941,46.851576,59.300568,27.462692,-5.124981,-41.055459,31.590571,81.261198,139.756888,150.656374,131.539441,88.804433,-61.620719,-133.353037,-176.484625,-139.221186,-130.573276,-163.743336,-197.51371,-251.921693,-268.888941,-269.021031,-166.613465,-97.312799,11.824009,40.950555,14.944358,-33.305616,-142.715773,-166.09236,-86.672153,51.46018,106.373649,188.334386,206.851447,138.776035,59.754643,-21.649593,90.327063,155.29747,228.566564,236.669722,130.293627,37.500529,-65.789511,-77.131999,-86.25912,-23.806399,29.936408,17.988169,-63.45009,-204.622274,-226.699206,-205.925651,-109.119924,-52.552903,-16.650962,-54.362295,-165.043187,-202.286246,-252.423274,-259.664122,-162.180478,31.325705,98.653644,117.107129,90.543496,46.133768,33.102013,41.465133,159.153908,241.620155,362.974515,366.169432,248.130336,169.404742,53.100575,20.855417,30.350252,115.816786,149.793588,123.307393,56.879133,-102.840817,-170.431073,-241.874478,-158.127288,-67.036464,90.529541,101.128998,-35.978702,-137.559603,-284.684825,-304.517469,-229.609722,-152.951361,-126.155468,-20.81371,-2.274807,-118.024968,-163.146515,-115.308811,-65.756131,-42.480324,53.733618,76.025675,-7.432333,-75.199203,-196.353096,-246.653095,-212.323323,39.250393,148.463006,170.75286,116.525283,34.943792,21.703951,33.709806,107.243221,139.414305,122.792779,102.521404,131.904746,151.443038,64.377938,-7.277935,-14.272498,77.541872,108.173451,136.324718,125.247715,62.460844,28.192244,-0.315783,21.980753,21.714132,69.473773,134.474378,172.126863,118.194057,10.913068,-1.719186,49.122392,117.718695,152.428261,227.700464,242.028963,212.859163,183.191192,138.160974,211.901506,283.617669,422.658687,469.593331,474.307056,441.629886,370.712723,339.964765,281.769975,273.770551,290.295818,317.943223,315.125766,258.400353,216.320408,157.386915,195.194239,248.548606,310.463436,272.642941,84.424181,-16.758382,-133.358426,-123.088778,-9.968952,69.542004,92.814233,113.317175,87.075654,-27.196808,-65.062929,-28.260025,88.148025,149.743093,243.550224,258.247218,205.295438,146.625405,20.49752,-8.458691,75.925617,225.023427,261.130575,273.512484,280.988387,270.844853,218.572414,145.111101,283.830477,343.671623,329.748402,316.366246,281.530191,211.960481,-18.971253,-125.556365,-194.926773,-77.292848,-0.102529,62.537127,29.395565,-112.849493,-184.514126,-196.533887,-13.939464,69.94455,153.616037,161.526018,103.902364,60.979981,-10.0761,-35.091484,-5.637607,131.053617,206.385076,286.62278,273.584884,178.388445,121.331865,92.177196,217.727831,275.780825,325.464245,326.608845,251.657413,172.199049,-11.15937,-68.318449,5.72222,248.701749,340.914835,381.907571,356.895585,253.064781,167.180373,38.963543,134.051459,224.14375,329.884558,320.757012,213.357959,155.966219,85.877357,65.259444,40.820181,43.954259,60.151116,68.30426,36.561187,-71.052839,-146.121156,-302.26532,-283.10889,-215.424329,-118.899192,-96.483502,-70.655027,-96.206504,-237.455645,-285.888606,-247.102573,-148.016247,-111.434328,-95.49699,-92.512277,-58.802052,-60.980527,-89.62637,-57.406537,-36.675231,3.405243,30.440604,39.966024,0.856642,-143.986603,-204.07053,-195.523272,-122.73966,-98.042654,-79.044944,-104.595725,-214.175463,-268.135466,-288.397263,-188.270518,-140.736072,-77.203584,-57.228687,-68.362727,-97.312961,-136.423329,-132.281794,-108.48315,-65.126781,-55.993411,-157.102186,-239.038976,-311.692472,-305.777679,-305.009001,-297.865299,-289.277315,-244.475051,-211.227365,-257.624565,-334.770197,-453.16886,-461.802389,-353.328532,-155.665696,-92.814617,-97.46769,-128.442496,-206.511405,-253.133326,-275.04709,-182.339444,-123.183076,11.094599,67.163179,46.184831,-25.667364,-147.531694,-160.060731,-110.46444,-18.272611,14.407379,-27.98827,-81.038728,-158.528075,-187.460568,-232.274955,-232.026214,-213.531071,-130.798631,-70.680042,-10.425061,-42.863231,-162.772723,-198.980632:113.769046,-40.77159,-114.2644,-81.044781,-16.847343,2.712693,-36.19132,-82.308525,-71.430932,-80.250286,-131.211452,-158.116955,-194.207636,-203.222496,-275.380001,-340.021226,-357.496708,-189.755277,-108.685715,10.889922,57.057117,76.018463,25.828932,-145.714738,-216.66194,-162.703125,55.527042,144.652893,168.290713,146.700605,188.383455,253.964887,397.148949,355.371909,268.233227,174.143169,179.641641,195.629956,179.842279,98.766981,110.670297,177.013413,278.975486,277.851356,212.815715,167.972265,78.397959,44.896017,37.409699,72.297258,81.702748,125.009521,153.18785,126.139116,73.085512,19.676037,78.399022,103.513984,139.969628,155.991534,109.221858,36.745382,-152.0138,-227.03546,-241.271553,-139.232155,-96.668595,-56.856601,-71.577361,-174.13523,-235.352227,-319.175839,-265.441483,-178.689345,-23.780033,5.642473,25.444222,47.630892,54.103723,23.05653,43.574451,211.666322,281.995829,311.726678,295.144719,290.878763,293.22803,319.984546,448.760194,500.985277,527.946948,508.150905,349.520573,241.200333,136.685396,139.94704,137.589835,68.27045,28.86178,-39.962599,-74.871066,-134.046453,-167.650664,-243.187421,-190.334835,-127.858497,-68.871967,-71.592846,-101.625342,-108.108563,-46.869667,7.074797,105.374484,182.587105,209.64895,274.274855,314.891894,350.117801,335.498334,293.953387,301.867918,315.574031,312.066765,281.404763,171.801544,108.895151,-25.947763,-80.387337,-89.533476,-8.378831,30.62795,36.270634,-0.957473,-113.472341,-188.981531,-343.300768,-336.723615,-271.59996,-121.37813,-65.867251,-53.130483,-93.236515,-176.200491,-190.454994,-157.916863,-61.750648,3.828867,103.955107,108.011211,70.584385,55.576823,-16.17347,-86.622686,-58.252362,70.222716,106.036651,70.232813,29.829649,-73.88498,-146.860682,-188.97521,-10.805072,64.69046,94.030635,78.38212,32.390096,12.06674,-1.963982,-34.225304,-61.154549,-5.788375,73.832028,103.729021,22.435402,-145.374871,-178.101856,-127.152392,2.367097,41.250234,26.656608,-7.758914,-72.854241,-109.369174,-204.601913,-217.986924,-183.309529,-110.370794,-82.084043,-44.210069,-45.558555,-53.863755,-30.955442,56.157256,111.398397,135.926937,226.214888,275.497045,314.509573,295.517093,223.502213,258.182765,335.192301,481.844088,510.870866,468.489081,425.200761,382.168198,365.105385,301.789638,349.827515,433.39614,573.767391,554.246405,340.518719,247.657942,232.725772,343.611245,395.399705,419.821895,375.790418,208.886041,122.374516,-33.73868,-98.317003,-103.820433,22.998643,43.189904,-17.334123,-45.301129,-60.821414,-64.833708,-59.685286,17.351754,48.835259,49.168294,52.465268,89.679836,94.580064,22.108736,-27.093629,-28.848139,34.201954,53.212372,62.482653,35.583979,-57.524787,-82.015784,-41.017909,114.039597,213.275266,305.707083,261.356025,98.725591,33.358862,-41.364937,-66.984665,-114.459083,-44.306628,48.375982,167.995704,133.433755,-47.617204,-119.990349,-138.319696,7.730387,116.945124,263.915011,254.083076,135.105981,101.906047,137.85066,158.864666,174.071336,255.322235,296.995667,303.102722,283.836966,247.201891,221.283319,141.482043,150.902025,197.963947,236.702716,200.29498,78.983311,41.138668,36.921404,48.631195,78.485454,117.226498,134.196331,139.25867,124.377138,77.1934,51.177801,-24.761128,-76.896783,-43.604953,103.980739,154.168059,142.060071,113.013468,21.804315,-59.42123,-188.658458,-158.172313,-121.259648,-105.870694,-133.099416,-206.240119,-249.801118,-383.035846,-431.041167,-372.061852,-243.933796,-246.110738,-332.87506,-352.189512,-350.475729,-373.007511,-388.214592,-249.123483,-168.517017,-95.133761,-101.794801,-131.716858,-145.302279,-175.914767,-154.178752,-125.551587,-77.691206,-50.693001,-6.970579,-22.981712,-137.095992,-183.217762,-132.401407,-23.812035,-29.182829,-109.881152,-115.690135,-46.356763,-46.169312,-137.546325,-126.920735,-82.855258,-60.815638,-106.522799,-235.563868,-264.1525,-212.410143,-175.666331,-147.346268,-131.5746,-129.557733,-160.903003,-199.284052,-290.348965,-313.559777,-332.181357,-361.72581,-351.791016,-279.831494,-253.761171,-218.021864,-177.466595,-139.683949,-183.452284,-252.92165,-152.556578,-78.066898,35.78204,61.704669,51.015487,12.244696,-89.652917,-39.5397,35.842673,149.143558,177.360122,194.716693,187.54414,182.966925,195.149109,183.180181,39.369342,-34.771594,-68.66668,-56.965511,-86.278661,-119.523415,-149.700174,-89.911536,-48.298119,8.491805,20.038183,-13.106262,-51.295013,-111.345478,-128.036499:150.085231,123.401368,98.350078,70.762269,50.762289,-40.807097,-100.553484,-186.834709,-197.535484,-192.990867,-179.682915,-185.891869,-274.754556,-329.709817,-353.018999,-326.550319,-253.098453,-144.374642,-72.456631,55.500214,66.610763,-51.425468,-129.189374,-184.512872,-108.08034,-45.199989,69.18374,95.38535,91.597079,104.632658,235.51129,320.747109,383.425889,304.67548,295.758232,361.251496,359.000436,232.572218,167.5492,115.534532,153.663247,192.573888,253.772442,249.106137,167.46207,113.746073,9.041074,-27.975896,-15.724893,74.678045,119.713087,165.243018,166.479382,143.11394,93.374047,-33.564235,39.796958,138.074002,281.755011,293.270032,184.002245,90.370582,-101.954979,-183.765264,-200.957041,-34.05307,18.490113,-4.238187,-46.418004,-127.362258,-160.701067,-210.909059,-152.575309,-72.661798,60.379138,71.946348,17.509793,-11.262169,-41.729677,-27.182591,94.920293,202.059827,236.474494,342.307448,394.476421,387.629828,325.077722,203.482731,250.273227,315.857783,385.061304,352.369208,144.784045,21.810171,-116.161503,-114.940729,2.742415,98.420062,89.242102,-1.197776,-62.109539,-189.763095,-255.526951,-293.878619,-110.829146,-22.017973,14.26739,-18.293533,-116.150236,-145.964579,-115.372649,-70.634584,58.686531,186.797646,216.283715,216.340141,196.178672,151.717772,137.650628,103.229792,124.192162,190.218331,347.166241,359.718331,205.873512,110.916027,-8.163777,-51.208409,-87.430702,-10.362719,49.753128,96.129168,47.371352,-112.028865,-190.235742,-311.24458,-274.846305,-204.031964,-66.66343,-41.73954,-135.307012,-225.525878,-356.53515,-377.442146,-332.95605,-176.707056,-73.791732,58.389114,40.068879,-94.943724,-140.702033,-150.780439,-102.399282,-45.208423,105.04049,152.385957,89.60637,-14.199853,-234.261125,-283.658316,-167.592538,44.84149,98.441762,102.295274,78.570301,2.222136,-39.121031,-48.626284,82.804683,159.259797,223.002725,207.341713,121.298132,74.152759,-0.589818,-34.230883,-37.972189,80.077892,143.377846,185.5137,149.597805,20.431622,-47.179641,-165.121782,-151.011347,-92.090386,37.803872,87.319437,99.738335,56.587053,-62.087392,-91.077859,-3.380652,158.944635,214.218561,289.690834,305.061433,264.723606,225.624995,180.522243,273.742472,355.900063,501.049247,537.135603,508.508108,472.552509,412.03824,371.52228,285.397737,349.934242,445.807772,564.805128,513.765601,269.814011,178.491734,147.631378,224.410256,279.860643,359.411785,336.091019,178.271836,105.62259,0.747311,-46.731665,-61.549347,41.578608,94.935983,134.029895,89.811525,-95.060945,-176.398356,-190.390434,-17.627277,51.977596,93.071194,114.09931,141.643539,102.76407,-27.865694,-63.473053,-16.450392,110.553074,156.718176,168.637934,144.572515,53.857716,-6.384103,-29.569836,128.755274,187.857197,179.421346,151.592397,94.09931,61.222889,-36.893909,-113.358481,-209.989575,-102.948603,-21.240446,63.250512,44.565799,-80.681806,-142.532294,-163.567306,-71.450533,-9.849179,132.909879,183.560348,167.993143,119.084296,0.713665,-41.808099,31.49835,258.55678,332.270825,328.968048,275.725136,150.680594,107.657974,104.333832,200.338924,244.770136,288.059644,285.40087,204.070245,132.838376,-1.660218,-24.679208,93.325471,256.399675,266.725664,218.048493,208.595586,161.988274,91.392448,-28.646031,79.279717,169.102782,264.437725,253.780904,127.722831,62.779802,38.68841,51.434371,-3.654769,-85.000743,-63.94327,2.977393,-18.990544,-164.481009,-252.442566,-380.355434,-327.562584,-245.167851,-122.84689,-117.817086,-194.977083,-250.395161,-331.105562,-327.737857,-232.235279,-170.62414,-167.672895,-145.132283,-124.929688,-114.203903,-135.008695,-195.211351,-211.873247,-194.687149,-76.356411,-8.82636,-16.321755,-69.262314,-171.788688,-214.04592,-199.959964,-107.546121,-95.58913,-123.181585,-135.420253,-172.567363,-229.817921,-323.113134,-158.387493,-38.526214,52.945945,13.049819,-117.748823,-159.664719,-187.87897,-187.886993,-145.649881,-39.157939,5.640415,-15.295857,-72.215849,-193.499894,-254.275076,-336.287156,-274.091132,-222.666245,-167.850082,-152.981797,-149.307577,-170.950073,-275.065067,-329.295992,-271.953951,-103.743451,-67.582114,-38.882511,-22.495464,-43.435119,-95.780148,-179.304052,-90.090479,-17.824392,36.879119,26.026551,15.579981,-2.063949,-88.113927,-94.36122,15.530526,63.961517,42.952227,-0.476778,-21.67132,-107.042356,-177.583124,-305.492155,-287.613404,-234.461196,-104.218844,-53.415768,-74.274901,-134.105895,-201.321674,-183.630393:-206.272078,-279.606583,-296.844737,-248.839713,-195.594315,-90.453485,-72.696739,-183.024473,-289.304525,-258.05619,-109.904087,-58.90641,-35.494058,-45.218105,-94.223403,-110.721451,-40.743364,91.371407,130.211616,192.911169,226.666731,189.125517,105.055754,-44.416183,-16.452735,43.303867,150.324576,185.148986,215.588501,222.318946,252.934967,265.249478,248.893917,164.916744,117.339729,82.610027,91.382936,129.132858,128.217892,50.679125,25.705009,70.527859,235.796583,326.822612,416.028488,390.207185,246.390692,175.645506,152.835225,292.511339,369.084482,404.061984,355.984828,247.754047,219.554842,175.741757,172.343606,193.12572,183.44779,157.997158,119.98188,85.692716,-53.327267,-136.676076,-198.240958,-95.694266,-62.861854,-90.427111,-118.971674,-163.071146,-182.406547,-225.039284,-191.023404,-130.820651,-43.06284,-31.900701,19.561326,76.884034,172.363005,185.136329,210.697954,294.780212,336.148095,377.194522,370.058806,351.962839,377.830666,527.086429,666.352967,674.035403,629.709369,582.055533,361.7561,245.790965,197.326917,232.558114,272.235506,255.912618,222.040197,129.605151,75.380332,-63.435834,-111.219697,-56.551559,76.50322,90.438881,13.36691,-22.498731,37.543178,136.404406,319.112631,338.817527,294.295911,347.287454,409.70967,466.456931,442.626923,389.147066,384.339836,403.207649,440.284936,420.435206,245.315781,155.091252,101.404484,101.665682,18.144198,-44.889589,-62.192326,1.145258,6.585705,16.31301,48.99156,67.181391,1.493406,-214.940175,-256.641608,-173.048817,3.359454,43.914176,80.928093,86.386895,44.935717,5.956254,-19.896317,80.106752,135.205553,144.339182,83.305946,-75.424367,-114.062289,-125.138,-165.865806,-181.010785,-106.21964,-38.528153,-55.162364,-149.063012,-346.383182,-414.032825,-405.51347,-225.039285,-136.966234,-75.194896,-110.566797,-216.771784,-242.916683,-266.091843,-326.632547,-345.317058,-284.232457,-223.442242,-197.644275,-243.545128,-300.512565,-296.192924,-257.721017,-155.742755,-93.190889,-28.14573,-50.901114,-142.723355,-175.010733,-240.738141,-274.363016,-243.15526,-151.537072,-116.777415,-89.627897,-103.888961,-118.803174,-87.695006,14.593791,91.415836,136.867672,241.768434,272.87245,266.282439,233.648238,133.077094,141.889716,233.255374,424.739243,446.329818,396.802943,394.239501,429.513227,421.388904,371.906956,416.99474,468.662249,514.186781,485.817712,394.455299,367.137961,317.193898,273.222831,277.47422,272.484573,243.303075,171.965096,138.087616,5.512388,-86.34891,-153.619044,-90.902827,-85.575663,-124.091907,-130.31583,-85.197897,-65.074389,-85.577662,-68.871464,-57.031595,-98.969622,-99.408194,9.499001,66.517247,78.774476,43.278381,-7.533604,-21.239805,-43.350406,-80.217979,-92.793735,-146.391317,-176.554476,-195.589961,-54.107679,43.948593,82.519009,45.064764,30.479409,39.500663,-1.912648,-39.248587,-92.536475,-74.830237,-28.933861,60.060754,55.701407,10.252933,25.647867,84.638351,85.187663,89.737207,109.13648,108.604181,78.455751,68.497651,71.892044,57.420362,21.994708,43.586286,69.29046,135.888066,149.105083,111.732171,80.190299,-11.380669,-68.258396,-45.836352,31.625853,46.624487,22.349695,13.934321,5.118009,-36.734967,-152.374638,-92.51782,-11.273982,70.254275,63.157359,15.461152,-28.46036,-116.179446,-98.49623,-53.367412,60.57739,106.256009,115.321809,89.06882,-2.427799,-83.331786,-229.146962,-197.167267,-140.482385,-62.157988,-48.425443,-37.771098,-69.216896,-261.93861,-409.715438,-394.604479,-259.429649,-228.035046,-336.224783,-414.51374,-496.863406,-484.817139,-321.728511,-193.365174,-212.731779,-255.269845,-228.071918,-149.221262,-124.915434,-102.588773,-52.813637,-8.000669,30.482472,2.855084,-43.707398,-28.960706,18.002153,19.695437,20.631094,93.028687,124.970198,144.415042,156.785642,197.861577,188.725676,83.972186,46.049952,56.813283,5.385727,-43.870014,-78.134853,-62.795547,-56.781362,-70.15347,-31.062738,37.263345,34.633237,41.050755,63.453635,54.785594,21.047132,-36.366998,-50.428436,-38.447211,12.176231,32.226511,28.328228,18.264402,7.242343,3.029008,48.046567,163.987395,214.321889,261.587938,246.29481,168.940565,141.457206,121.422666,112.597527,116.08798,195.257818,267.220862,333.225834,294.022311,140.630323,79.10341,70.379419,87.52688,54.254398,-44.418407,-97.604383,-203.937052,-236.571763,-261.263692,-227.256315,-174.737247,-58.447415,-19.533065,4.988157,-10.726919,-96.266346,-141.067409:-203.153879,-251.458592,-218.767045,-78.495925,-38.117718,-43.884064,-56.400124,-106.254011,-154.927977,-144.034438,-65.80966,-26.877634,-18.568912,-50.536318,-146.795271,-200.921695,-241.89024,-151.22292,-96.946457,5.341537,52.161087,45.288316,-22.504286,-172.573674,-173.559697,-117.010192,42.753344,122.431337,185.299786,174.23713,179.608964,201.490391,252.373773,255.014226,219.769515,154.375503,155.555221,182.847007,171.449364,108.237291,127.635125,185.35703,320.94853,374.433915,416.766865,397.370253,283.883029,196.279818,63.867716,136.346232,228.740783,357.490109,344.278339,198.570341,120.424908,28.446675,71.827901,146.251804,256.146215,240.320117,127.505977,76.847604,-28.695827,-101.778927,-195.272504,-162.212668,-144.14918,-120.488342,-103.354937,-106.908116,-136.741128,-168.430768,-82.207969,-27.698083,-23.791604,-62.418598,-78.732365,-32.628111,74.275497,78.302078,31.463,118.621611,206.87679,346.76154,374.730528,388.886748,398.179054,421.237896,474.967193,506.566807,528.692959,505.797885,355.00672,251.455026,121.561935,107.997467,119.382586,107.722508,85.417155,53.073096,48.820308,-1.288104,-56.658292,-137.967198,-51.521806,9.094573,-16.100707,-66.954465,-45.814756,22.761196,109.270288,95.152787,85.364546,233.98401,324.047641,443.125269,468.005769,466.28974,447.416754,414.089952,403.869938,375.892737,276.017745,244.590989,212.166079,176.697269,51.61045,-11.239057,-40.371538,10.493137,20.95041,49.625825,67.239991,-9.466043,-102.774995,-250.15048,-219.674581,-150.559815,-6.365264,39.037917,73.120823,74.639709,19.490861,-41.432597,-79.823314,58.645947,125.78549,160.63066,134.231968,68.029375,38.080669,-55.104872,-154.192799,-183.08891,-168.910658,-127.234322,-78.84013,-104.226014,-237.734853,-324.481877,-396.44966,-227.57969,-121.17434,-15.501594,-18.692698,-56.077639,-76.941325,-194.218199,-323.52952,-322.239823,-230.782275,-180.766791,-157.178715,-205.200789,-320.907606,-337.981876,-286.277401,-199.175525,-163.659358,-114.467782,-112.056108,-148.511936,-165.181608,-207.259782,-254.145489,-247.558355,-180.762162,-140.214779,-99.118167,-109.194333,-145.681578,-142.402061,-32.852683,172.426079,245.610593,304.062665,326.651249,390.905294,393.054983,295.32181,278.004627,328.385495,427.494934,446.89596,427.031598,417.929464,415.97523,388.765646,324.059271,368.124772,423.555697,504.968354,488.541809,353.677348,279.614739,174.347188,161.240533,203.402025,313.294732,336.309258,282.867775,228.309362,115.468923,54.709215,-51.581964,-113.804846,-149.779342,-195.600295,-172.645626,-30.10173,47.271796,94.11133,27.771388,-11.474185,-45.03233,-12.672404,109.962398,151.139781,150.036892,116.190102,42.604453,-2.849755,-26.500603,-43.817583,-36.211887,-74.101242,-137.406901,-194.191172,25.435919,150.926086,193.710065,134.462496,54.711878,58.696018,49.415762,14.963549,-20.116423,10.930909,24.412581,43.550495,39.514995,-13.275343,-29.482645,21.599665,112.380691,143.96608,145.360721,115.683343,78.311148,103.524737,158.516225,132.057016,60.285518,110.950398,144.094664,156.131433,141.432634,116.607104,103.717223,27.717341,3.475299,33.48826,95.94503,107.278731,55.515502,11.249822,-71.825035,-116.02224,-120.78138,32.302293,94.143387,93.225386,60.247455,-6.255539,-44.589008,-105.37929,-51.810031,-7.777924,65.564515,122.869257,196.371321,158.617404,-21.103588,-115.773391,-176.560606,-71.982183,-30.417767,9.622105,28.925416,22.84875,-31.958812,-221.310299,-306.356319,-267.288045,-203.909966,-237.501959,-334.961649,-345.248628,-352.305103,-378.562582,-327.332129,-103.185253,-42.495372,-77.591374,-101.919602,-62.028106,-26.05052,-16.357764,-8.099746,29.062605,74.680506,57.082138,-17.703155,-58.919092,-127.757429,-144.09621,-136.436024,-169.579559,-207.159899,-161.557566,-83.527589,-24.873935,-63.456321,-152.15561,-124.52613,-84.854422,-86.167531,-147.627194,-310.320504,-344.588419,-265.619369,-211.416065,-172.828096,-121.785724,-93.562801,-108.908494,-144.9916,-227.512039,-260.343089,-294.941569,-272.928671,-223.734715,-109.518962,-86.404312,-69.454275,-30.928835,38.944001,17.334588,-78.744345,-39.278966,41.150711,172.43998,159.397976,4.760976,-56.776815,-44.269529,74.535089,130.575374,221.410179,269.192556,288.192191,235.59069,145.020702,155.003442,214.984585,192.073233,143.884809,37.214991,-3.506457,-55.481577,-81.093513,-137.383049,-97.469577,-40.146178,42.05985,55.678857,50.042972,25.585742,-60.245102,-96.14335:32.330558,-42.373065,-47.037804,19.994899,41.863435,-24.786594,-94.726946,-191.749659,-135.979159,-85.841133,-72.58462,-111.371338,-160.604065,-148.959591,-118.90191,-116.201907,-97.168019,-29.370288,14.965044,102.225993,118.032515,59.431464,2.269645,-117.97174,-100.815852,-2.142145,191.194964,206.249894,127.187451,106.228633,162.106516,218.41273,306.026661,215.482714,142.610686,140.810522,183.42546,171.432508,123.389922,64.642293,72.050705,90.193968,172.614833,227.464248,265.951537,227.350879,131.722696,112.51474,102.797497,148.121107,203.595413,307.138599,304.585849,180.164101,124.412077,115.342842,134.691717,120.870861,116.309044,156.995373,216.900244,183.625822,20.421695,-73.080302,-160.361085,-68.061617,-16.220994,-1.239781,-36.014248,-162.751943,-246.251081,-367.67276,-268.978181,-175.139862,-60.559633,-27.21074,35.746699,33.55169,-30.32216,-23.776192,174.884467,383.871227,392.360031,300.127508,263.79897,238.248705,236.911615,287.135749,409.04935,453.366158,421.6069,343.719167,158.051367,114.094968,178.324594,225.113552,212.577362,135.087117,108.395472,57.826086,-0.191481,-166.49732,-206.101131,-135.680376,-30.962478,-5.430709,-11.913453,-36.284476,-57.72245,-15.01067,149.726192,203.243473,216.055466,261.715457,298.828341,290.783851,243.197487,216.02067,255.075497,308.709104,276.074886,252.85133,210.147394,183.296071,83.328149,14.500185,-65.567739,-42.472421,71.355651,108.763768,96.188608,61.409591,25.460634,-93.150859,-155.843642,-259.928024,-267.350641,-230.988549,-144.726778,-107.307332,-57.394911,-48.975465,-54.895835,-73.080086,-144.017787,-143.175972,-85.082114,5.729864,-25.694286,-173.128201,-217.740934,-242.70945,-269.061104,-245.054378,-55.160962,47.116644,40.56617,-65.270948,-227.055833,-223.621789,-154.634671,-134.758004,-118.071937,-42.596929,-32.888226,-79.36209,-81.93866,-65.822887,-95.979661,-93.441493,-8.647583,45.336013,34.536461,-50.372613,-229.652876,-253.569636,-155.195797,-49.316507,-25.844475,20.951181,24.856758,-75.121979,-140.904315,-188.737268,-124.108258,-78.665401,0.551789,24.01669,5.57977,-13.202707,30.320122,72.65976,98.962088,160.868711,223.858336,307.838345,320.691465,329.281134,312.447379,244.926778,278.942235,326.205849,422.643171,469.099542,478.17157,442.114802,406.329073,394.659714,310.293633,276.630975,312.180526,411.901383,433.318764,398.604751,368.39952,314.677189,288.549094,269.439312,193.667769,149.137099,64.688655,42.178802,19.634095,-23.938331,-131.878913,-105.947434,-68.785598,-59.757886,-80.100976,-84.577228,-81.960299,-85.954025,15.858162,46.652367,-11.968314,-36.035299,-22.364234,-18.037575,-54.005157,-95.323734,-189.247105,-169.356346,-110.356883,-14.574,-6.245476,-50.004437,-92.898391,-147.317164,-21.268945,70.385576,134.181183,98.244468,9.910197,-3.401237,-31.496295,-79.214376,-172.811551,-125.305093,-45.346677,71.83625,54.411078,-49.477469,-84.139128,-97.933356,10.277422,96.222569,184.76086,171.82532,94.334428,65.06691,88.431178,119.295227,119.575352,113.283582,153.903721,233.472467,219.151224,117.101167,76.065185,62.767718,109.310874,120.565605,94.259012,67.934471,23.108974,32.494731,79.574976,57.640218,-27.268364,72.263397,159.325257,208.483632,169.558122,93.037591,75.904027,40.306467,37.309338,54.301309,83.037719,103.474123,141.426089,130.65503,13.883133,-64.239719,-111.948247,-75.448962,-91.165984,-117.380005,-97.387803,-92.769741,-146.676488,-312.568659,-376.976446,-354.007191,-318.574772,-325.242649,-330.336293,-309.00626,-281.529786,-304.38032,-330.822438,-273.293651,-245.455012,-178.84345,-146.210638,-135.714916,-156.615055,-237.803018,-242.409141,-174.735749,-19.516625,16.152276,16.844934,18.186656,30.323093,20.440844,22.807368,90.36793,87.377219,9.366224,-13.06919,12.925082,24.500772,-7.831184,37.069614,84.400999,81.314796,36.214806,-45.514264,-63.679031,-71.114506,-73.956559,-4.764784,103.474953,90.820953,13.200278,-7.064236,-79.453004,-129.998518,-157.379893,-108.579474,-96.18634,-112.414972,-111.804734,-70.496042,-53.771821,-91.229511,-131.97703,-89.830149,74.272735,118.543778,149.106583,158.153701,152.50418,131.145589,56.050317,66.600142,110.941044,160.262905,153.958267,119.252918,121.963391,164.283178,166.228402,98.226023,-14.588176,-45.335792,-39.881571,-53.275037,-149.251703,-185.222928,-190.065899,-172.079803,-160.473002,-108.344295,-71.593426,-44.935189,-49.986396,-35.566415,-32.870576:left
66.094606,32.026324,-27.077658,-136.512427,-165.02122,-214.969847,-229.533016,-191.627352,-90.722014,-37.271109,36.690467,55.993663,33.312081,-20.877201,-130.774415,-156.170773,-135.34957,-2.451125,62.79983,67.02835,-8.783238,-208.089567,-251.862303,-194.518438,-95.443644,-65.607143,-94.783236,-129.359938,-190.23301,-225.20009,-223.506512,-163.996859,15.775761,154.915508,141.141687,-18.538725,-94.130172,-170.929038,-169.832219,-107.401545,-62.414674,-56.831606,-84.071444,-112.201539,-191.066069,-245.294103,-282.058984,-240.476814,-155.54072,-195.390516,-255.273091,-354.672806,-358.383563,-293.449581,-251.826551,-169.598635,-85.602875,-41.277332,32.248038,37.619093,-61.412153,-129.00524,-114.148467,-35.289895,84.287574,67.69942,13.02384,-103.139769,-131.54064,-151.582221,-167.556681,-240.78462,-252.456274,-187.215999,-45.451942,-27.961683,-37.401365,-20.026701,43.894276,66.480415,107.890585,157.436362,148.84243,66.014335,24.628918,-46.897587,-67.7388,-48.483373,-3.329759,3.559525,-19.780365,-29.670375,-67.387265,-110.036139,-169.188431,-155.019206,-65.128519,-12.256789,-15.859222,-26.966974,-37.797119,-68.434843,-53.326874,-0.843131,-24.382071,-23.548257,30.716754,42.534649,-0.768968,-27.3829,-24.7415,-16.051135,-49.576034,-75.741732,-56.881503,57.690862,138.599272,222.257825,207.748615,201.347322,309.883436,369.458245,438.698779,447.748539,402.670338,369.677393,350.561449,324.290959,191.530815,141.663815,151.176489,138.068002,132.188031,206.362143,283.089273,427.96785,492.346202,498.398087,458.078068,410.415903,294.440578,254.849716,263.044702,300.25703,396.963782,494.815469,502.127675,408.7412,349.026649,279.181598,273.548662,305.823675,341.545388,344.619502,334.719743,312.761606,150.901155,21.154242,-137.962118,-117.212862,19.825752,98.549349,117.041198,146.514727,119.757142,3.169413,-14.543603,67.541826,180.327485,236.027085,347.649424,378.044678,316.489628,238.964753,126.508137,123.180948,214.21089,392.170479,447.573205,363.718625,269.141514,167.788946,166.595438,186.753144,255.039725,301.216462,342.475966,331.625601,272.238969,253.088908,296.538832,329.836467,319.434615,264.444514,266.636684,306.574122,290.073302,162.481138,120.670393,132.979809,159.030562,162.953934,125.459533,94.487073,2.811071,-61.717713,-98.418802,-48.153677,76.795489,188.636533,238.539961,308.448831,321.249829,280.106122,242.49363,200.34684,175.039804,157.291698,151.028413,137.779876,-12.563323,-102.67167,-105.395709,-42.900307,63.631118,213.222727,287.090372,311.589004,264.646575,151.668146,139.900638,180.256263,171.130256,174.18387,237.259871,263.185018,212.160996,149.787016,87.810091,111.4785,197.173201,204.949738,156.131139,18.55898,-51.747928,-201.091314,-250.122805,-267.793895,-248.283718,-213.820819,-87.799433,-44.112761,-87.266995,-126.289789,-52.627411,47.921124,206.822578,263.473923,270.586456,263.371598,246.117042,162.854568,106.650012,31.641308,48.400136,73.529451,105.266622,110.953394,98.958787,84.907746,104.180873,126.176063,99.768687,71.501645,100.386526,121.5334,65.657759,-119.750262,-186.756446,-217.951984,-231.882315,-240.932551,-202.599558,-159.580846,-100.084278,-110.901572,-217.169427,-270.626753,-275.138433,-220.104316,-207.846985,-173.953783,-163.423133,-227.373416,-276.845685,-290.113376,-115.071231,-1.387925,61.563589,15.552128,-46.091241,-28.182313,87.511525,143.877232,162.391469,165.051124,180.221704,138.280059,64.392546,-47.33167,-17.552033,89.562598,72.244182,87.388455,241.163997,316.028023,304.504694,221.853971,79.890164,86.527495,202.129747,167.153523,65.448143,-70.061641,-66.818807,-76.082815,-105.81359,-98.124647,-32.426758,-48.83529,-139.776645,-148.933648,-121.656515,-113.863099,-97.94593,-95.242458,-102.592938,-107.734647,-116.59887,-135.333458,-146.129342,-177.20662,-161.70343,-68.954608,-15.064816,-4.646612,-36.275519,-86.232015,-230.70768,-315.242296,-448.192745,-468.094654,-382.709366,-239.077276,-223.625481,-270.478141,-287.631991,-314.985754,-324.752655,-289.36362,-206.370056,-193.282442,-252.544148,-276.577016,-260.181735,-245.294621,-190.05893,-147.908509,-89.125833,-52.531884,-17.473315,88.20679,113.131114,45.669525,-6.483094,-55.765992,-62.074421,-62.744537,-48.699981,-35.557172,-31.394117,-52.056887,-73.06126,-42.775117,65.54225,144.230092,163.118328,179.676255,157.585906,25.342124,-33.459016,-35.245149,28.191297,48.511502,47.915677,45.417776,40.834663,14.611758,-32.834155,-29.23074:-18.828058,19.125615,-22.311601,-143.833111,-200.25203,-241.816348,-194.756468,-64.725929,-30.081494,-20.958306,-11.927501,-20.528214,-64.001236,-108.189211,-209.533293,-238.847792,-172.338581,3.149873,54.722682,68.164503,39.540073,-74.565659,-128.60674,-150.812945,-67.055902,-31.99627,-54.389339,-95.877074,-167.148622,-191.068875,-184.305761,-137.212788,36.193011,166.684598,138.622241,-67.71974,-174.399976,-244.095693,-212.346818,-122.047674,25.512924,102.002956,98.953859,24.727662,-139.043245,-174.461634,-83.733626,-15.774067,23.539618,-7.774862,-52.960267,-220.586127,-283.342717,-247.223886,-190.11205,-107.604718,-8.738515,38.878422,54.381671,29.683782,-20.36572,-34.860342,-32.291955,-3.515972,69.801546,43.707755,11.346829,-16.924215,-31.605197,-101.347481,-142.223802,-213.722684,-221.804531,-187.925617,-112.767462,-95.958317,-93.483333,-90.936277,-76.711346,-71.479064,12.874918,179.973849,207.212805,111.293608,39.330798,-24.796701,1.109882,80.247722,66.137721,39.948208,-11.395629,-33.468797,-31.149613,3.768627,109.771997,143.591868,117.034069,67.822656,86.229697,203.051892,224.858429,117.115403,73.625135,136.899644,237.608406,237.823606,165.224807,134.876922,94.886581,73.750388,66.554337,81.460823,95.455659,104.953661,111.051072,72.5244,37.808987,23.292773,63.170629,222.581116,390.83635,440.257593,454.821302,441.011637,395.73175,376.944695,378.72327,358.047416,231.456329,146.149366,131.793839,95.519649,73.145911,84.703236,143.942828,337.267304,450.61246,432.557506,343.2464,310.000474,228.77654,190.409143,207.037789,260.014116,412.163122,497.985133,469.872053,367.519593,346.573278,402.307362,451.3729,481.274928,410.632187,366.093086,303.102485,286.238557,184.369752,86.515114,-26.567526,-6.271739,62.599671,86.291528,109.30415,130.54315,71.049672,-72.113953,-53.357407,126.188665,272.499625,319.002637,363.51033,346.113414,235.969467,189.300466,189.336607,216.021005,315.227175,480.412607,526.021128,474.193821,410.755433,269.370662,187.23042,77.395071,172.589568,255.135541,348.59215,349.879776,263.597649,206.358975,213.172745,266.524608,305.899068,255.542837,240.044517,240.92273,224.722747,122.503935,86.870454,121.835846,164.71207,138.96495,9.337483,-58.204227,-154.578289,-183.984409,-190.406135,-162.96462,-67.353271,51.327286,112.585042,193.825716,177.745511,63.287429,43.032273,129.29256,170.395266,131.209457,18.174861,-21.910921,-68.881718,-88.868622,-111.257747,-92.179018,10.606349,152.028449,200.581953,143.053964,55.136665,-43.618953,-18.296527,51.754006,55.408566,81.615142,178.521504,185.718796,77.449689,30.435244,68.794314,102.965993,48.319037,-26.465118,-18.221543,-45.146863,-125.951627,-294.750229,-307.865798,-204.116444,-84.801766,-52.229007,-62.754665,-93.963709,-152.492979,-170.584632,-140.674321,-78.329364,56.647806,135.158691,167.917469,152.454878,102.120144,41.877176,39.428549,11.265306,3.431482,29.842216,65.000538,45.589758,-56.298907,-92.118174,-54.336762,-18.017387,3.634221,36.272264,65.992833,60.959951,18.29265,-67.138507,-78.387937,-23.688982,19.907261,-21.955662,-174.781906,-215.176593,-216.255513,-212.280022,-208.253033,-219.57004,-267.400602,-245.064801,-218.80431,-201.321028,-203.028258,-236.365527,-276.102122,-316.54953,-181.501124,-92.055702,-46.26371,-76.896244,-78.790609,-38.076354,15.761173,13.884317,19.997744,68.233722,89.651291,93.220224,61.706188,-25.021433,-14.491148,128.749233,217.823772,238.682494,288.329413,303.649206,254.078791,179.332396,56.708807,75.217723,218.047683,253.983837,203.047271,62.615135,7.251624,-31.841827,-5.291514,69.4487,28.475582,-20.787655,-32.047415,-11.300874,-93.456115,-162.630899,-145.367371,-83.413477,-44.08,-92.146242,-102.446508,-139.32141,-187.235362,-238.213119,-192.529226,-21.917417,38.44147,12.306964,-50.091299,-103.766497,-327.52532,-425.298008,-415.457629,-357.212789,-288.285439,-286.211236,-285.945299,-253.675539,-231.676496,-160.012885,-105.32742,-66.568921,-152.716923,-197.203242,-266.68292,-290.665851,-287.432878,-245.4449,-82.679148,10.421527,112.602647,47.962377,9.490912,49.209146,95.695122,75.434173,21.241254,-26.498952,9.467589,37.861341,110.711428,132.419739,92.206859,59.949836,100.319333,166.413635,251.581229,219.468736,183.555859,124.976527,105.086455,71.408833,74.492673,137.248951,178.252011,173.46833,150.678505,132.120205,55.011791,5.032653,-74.35999,-82.823252:-49.574908,0.231355,-47.548123,-211.941224,-299.239859,-390.678939,-361.135429,-200.120513,-59.428526,-31.963735,-28.876494,-39.461821,-85.420293,-100.886531,-99.689774,-112.429561,-143.79691,-92.980185,-45.97122,3.410756,-27.934345,-126.572278,-132.778273,-62.831477,0.031256,15.417753,35.748782,29.060107,-68.418065,-131.345687,-138.458053,-86.294429,2.613377,60.40474,54.6242,-98.005867,-202.049605,-303.907498,-281.153082,-169.754654,-75.872109,-36.804192,37.530067,51.262038,-18.886206,-57.985325,-32.226235,7.506281,59.339242,41.551694,11.252813,-85.872057,-146.993528,-179.993831,-129.250291,25.263984,132.538899,150.885433,169.300836,171.374178,86.781671,24.395513,-16.073411,-11.903314,-16.681686,18.767009,32.895631,-13.066295,-62.300408,-129.827274,-135.608345,-144.672616,-182.349525,-187.924726,-175.828209,-176.367533,-157.294075,-118.40022,-3.372493,51.250832,139.585186,198.989798,203.282495,143.12446,90.298048,23.56929,27.962997,52.876054,112.411865,155.207065,177.222862,153.598217,85.825529,62.601292,59.176147,67.467176,124.741615,150.088604,105.11884,19.805692,23.981324,60.216967,64.997618,91.82082,163.265923,203.771647,257.866614,237.065667,87.054122,24.077288,25.522726,48.745022,46.555129,24.605553,9.971464,-39.285347,-59.428231,-22.137233,57.330399,292.744043,459.919717,482.955566,433.3966,395.441943,339.279629,331.586623,361.583631,361.917932,268.928885,92.107629,8.387781,-107.503735,-141.178269,-126.757378,-81.323002,48.899712,195.144914,218.47261,139.534206,95.59575,79.356083,89.625944,124.947418,163.258132,280.305397,362.117446,373.455108,333.264081,284.716615,218.277698,223.674032,235.936382,215.578759,211.730253,178.542416,135.186137,10.049655,-52.105718,-97.210956,-65.084895,52.581677,135.281763,148.261912,116.008041,76.398192,25.952641,39.436771,106.737025,174.47407,202.483948,240.432567,241.321897,188.160581,166.649381,216.617574,284.388662,484.084137,632.679286,610.587545,409.229366,302.574404,164.623918,119.374143,67.538671,94.342801,132.918265,240.641161,272.623032,209.192431,164.454287,187.57531,218.805673,235.976147,199.350579,157.452547,72.544294,24.298369,-48.592915,-40.383036,17.757867,48.481792,28.94347,-102.102435,-177.241861,-279.819943,-300.510646,-243.61517,-164.463798,17.015383,103.129196,91.176286,13.190506,-13.448355,18.939393,71.560237,171.650194,159.735932,109.750303,23.06236,-0.907377,-44.833643,-59.461751,-82.684929,-100.538797,-55.396502,150.903169,222.049697,157.913006,76.133405,-17.729224,-21.684189,39.007089,98.548984,93.576591,100.897741,130.178493,157.119787,144.861262,151.771362,177.969411,177.40649,17.565843,-73.406943,-141.041971,-142.536448,-131.743623,-99.211947,-58.698607,-128.533828,-152.493117,-115.528624,-87.432674,-96.605785,-106.508732,-26.547959,41.651747,108.386201,89.423399,84.332293,77.476726,52.855335,-35.920419,-74.935743,-87.356845,-4.236339,21.349696,-41.595941,-80.644114,-76.990206,-45.491462,23.747988,33.520917,19.109223,69.306345,102.94042,62.867001,-4.546848,-92.564063,-79.273118,-10.222185,-13.266095,-26.943083,-53.036864,-90.276567,-185.85392,-197.395066,-188.718309,-203.017599,-211.699231,-193.569895,-188.108283,-161.220241,-146.323857,-114.961651,-96.019017,-45.807551,67.51514,128.046072,138.686416,97.342803,69.572691,89.46401,116.834454,114.172268,127.3548,212.790563,249.69591,213.521687,128.887032,-5.395666,23.295946,171.229626,266.140327,305.385018,323.149221,282.339383,162.839392,122.212948,100.201854,102.00972,123.350541,132.419919,113.233728,57.161479,23.27728,-27.411752,-15.988262,42.362454,5.922171,-44.649375,-86.450252,-66.697328,-92.973611,-143.024423,-117.610256,-37.29621,77.055663,53.520874,11.145399,-118.726533,-198.348785,-241.684219,-156.249247,83.982312,129.957504,77.478564,-38.887974,-88.904008,-198.063023,-232.07779,-177.47348,-107.464198,-23.176029,-83.997504,-118.553049,-121.857136,-120.934058,-128.708486,-95.267655,43.513946,103.34423,70.801141,-48.639079,-100.298797,-133.962145,-112.677692,-52.780318,-18.774786,98.596815,145.307938,100.159644,-0.655863,-16.924196,10.131144,45.874572,120.5038,181.692993,237.332668,330.90649,306.919693,160.931101,130.082952,219.077078,273.441316,286.413879,241.327347,240.749793,239.664141,199.333038,110.284957,99.470803,122.574414,217.017541,261.752188,222.467777,153.246865,28.945592,-2.006551,15.476925,48.203347:-22.063459,32.696136,-11.655173,-169.067492,-228.292101,-260.194699,-210.468186,-84.202225,-77.610806,-62.812144,42.232082,83.229504,22.906518,-64.796069,-165.676638,-144.814239,-52.507948,14.659361,36.785256,80.772431,72.721962,-42.87589,-97.004504,-112.461259,-34.777325,6.619549,6.146331,-26.380585,-105.766013,-145.77092,-174.302348,-155.993241,-57.26523,49.878947,41.083589,-84.16175,-145.489693,-175.807608,-146.622996,-92.525926,-51.559975,-12.879081,30.535875,14.212371,-71.751852,-115.554284,-113.927555,-89.743042,-90.503461,-108.653142,-137.50158,-251.3503,-290.748816,-268.697784,-225.564749,-118.600794,9.825664,61.479061,100.558188,98.024402,47.97375,8.549665,-27.999377,-18.283262,31.698628,61.182014,39.652309,-69.062662,-139.486051,-241.685211,-242.778626,-185.041223,-136.918142,-111.536372,-93.568621,-108.167367,-98.708448,-52.926516,79.068641,139.87062,231.279099,246.559489,204.126541,98.776614,67.167156,38.310234,25.728878,-16.524008,-13.812244,-4.376428,-34.333082,-61.271243,-108.907167,-123.967683,-124.725282,-111.161754,-56.412312,-6.159189,-2.673182,-4.693553,-6.644984,-59.210717,-81.611116,-8.003217,130.904114,158.49609,140.95511,128.35197,57.064982,-9.052267,-82.402102,-77.641516,-76.493582,-56.20657,-28.281305,-5.896269,-9.867962,44.669429,116.579584,248.821877,335.162599,399.334396,516.259985,520.212719,408.88774,339.975824,286.816941,279.45446,195.210172,57.948485,-5.447257,-94.277497,-109.080892,-79.159833,-26.281044,140.955494,239.286704,231.36528,168.141943,141.318732,109.355628,97.305011,116.638631,167.437624,328.603431,441.329356,426.029834,284.225118,217.101618,162.124226,164.635263,193.916227,214.54383,218.690004,221.956615,202.936839,88.19245,13.680548,-67.425347,-56.350247,22.883586,100.844264,133.580584,166.534988,135.138791,33.988571,38.086809,147.468448,254.625203,305.41904,346.151111,324.831206,231.476541,177.38067,177.645111,260.530843,483.731376,575.380561,545.83569,409.970209,330.876125,210.220548,184.900102,178.105616,214.434799,244.420845,321.985376,361.274999,358.785945,323.53059,308.235543,327.573261,347.503257,325.319957,288.533399,223.289188,207.387905,173.409375,150.346242,92.297192,97.626065,120.869372,58.718829,-34.294806,-202.547706,-228.470451,-150.648261,-92.740599,-39.771806,6.373646,48.839454,134.257664,155.943109,129.359409,111.535734,138.097734,172.525028,153.937998,68.420398,38.633235,16.259029,10.654079,14.235251,22.851338,96.560989,241.304139,277.30489,246.197748,201.726089,123.701272,118.248018,154.729363,187.481355,197.849829,193.06564,184.316944,158.237651,143.354765,172.667716,215.028444,257.246045,183.427478,111.823093,-22.987521,-70.36761,-143.460175,-162.328161,-165.080381,-116.599176,-75.000551,-26.287451,-23.349644,-59.307097,-88.959953,-73.326369,-25.513346,73.156724,155.411976,158.771562,87.946315,61.694285,48.66353,34.439561,-30.379953,-34.49769,1.35456,48.114348,41.677214,16.039524,11.854978,-24.377379,-74.002031,-118.512314,-6.82397,49.714369,66.838924,16.990605,-124.81974,-159.98339,-126.342496,-50.842946,-43.858292,-72.500554,-73.359444,-95.570461,-130.249475,-170.734506,-176.184033,-184.496331,-106.034574,-48.140895,-0.62404,-14.25553,-34.22723,-12.016468,40.268271,77.564621,121.160256,200.596838,201.676276,146.262146,112.347824,112.114304,157.463721,263.194892,310.06723,302.895727,256.638296,209.949477,81.740297,47.244798,58.359624,98.560094,117.919769,143.725532,152.671938,99.820284,25.166743,-67.81651,-39.188362,80.228149,87.504992,24.468063,-73.589317,-77.931687,-123.314853,-165.862082,-171.927353,-108.984978,-112.289371,-190.956765,-217.997388,-238.781683,-245.864225,-202.841217,-171.491069,-186.084528,-224.827484,-212.962007,-185.940991,-202.973812,-219.844862,-168.296559,-19.312644,38.403773,30.289271,-71.503818,-153.809729,-300.091883,-339.877585,-309.991121,-256.404012,-153.573965,-135.931101,-177.991699,-245.545582,-248.986689,-260.933403,-255.220839,-153.617471,-34.384479,-25.934441,-118.169342,-172.670156,-223.345698,-219.776912,-135.006029,-53.333497,116.753264,158.768971,124.753966,92.265129,122.11918,161.687392,143.63423,102.98982,98.536929,105.156845,174.002959,210.259086,143.469155,72.658327,74.975968,135.913343,235.312734,284.485526,290.024566,240.864249,186.905776,114.550564,132.484682,224.140129,260.326006,242.871942,199.690656,196.114054,148.984198,74.479721,-35.261546,-28.909118:-94.711484,-66.040403,-136.505608,-299.776209,-366.913856,-419.762455,-369.105844,-191.659988,-78.694931,-40.397889,-1.344328,-12.592318,-91.871185,-134.758309,-160.233308,-153.417285,-108.910789,-55.456785,-48.283421,-44.908164,-52.702821,-68.259188,-56.069909,-41.019932,-38.236128,-18.430167,-5.905413,-44.457571,-189.205897,-226.694652,-158.8211,-120.600651,-82.199626,11.749021,31.969585,-95.088404,-197.662614,-259.332934,-198.694686,-35.892471,73.573483,101.688067,100.821361,78.492563,3.496399,-37.228516,-65.220336,-36.516996,87.961715,144.170854,96.564586,-80.785306,-149.158341,-135.031388,-65.182266,60.750343,117.749744,121.71115,81.062548,65.810017,27.282062,-21.705865,-104.409887,-89.120335,54.009751,107.951171,52.726528,-92.660562,-156.443055,-243.814811,-242.84083,-187.371138,-175.079121,-176.058977,-143.733402,-130.32032,-145.473314,-140.768186,-46.33054,24.911488,178.260227,261.453998,240.215137,133.269894,82.919897,41.871954,50.414475,32.432418,-14.710623,-7.216705,27.964953,16.684286,-81.005271,-108.170488,-58.331827,-38.207454,-28.919553,-5.706227,-14.676246,-41.344052,-40.819082,-31.583319,-7.299727,114.89577,212.161489,220.152129,165.248992,97.942562,-110.530912,-197.096142,-197.391585,-146.69158,-91.662787,-92.434964,-106.025534,-182.298403,-217.519154,-138.667491,-23.027975,236.61827,484.709859,572.015675,577.600021,516.267286,373.422901,318.696516,247.513325,212.994095,156.438761,95.218887,28.50259,-141.027384,-213.769787,-265.531889,-225.742255,-75.754572,104.16351,168.07524,126.531347,45.114541,-72.270894,-71.732342,35.869101,110.876783,231.611012,282.715335,285.561529,237.075038,180.969863,78.824647,70.899462,134.136385,244.225612,293.710109,302.285252,233.706742,-26.458723,-144.625404,-198.1021,-146.0403,22.367099,156.770095,171.619813,106.794866,53.651272,14.835969,47.917958,146.518623,278.472469,336.830509,333.653336,283.05827,194.164506,187.187998,243.871461,301.052604,476.49288,593.671966,567.938895,379.866632,266.010491,147.797983,152.946773,144.644961,120.249968,140.128761,195.062755,205.941937,185.631441,176.882391,204.37509,233.903581,314.05583,352.081665,302.782614,139.219094,85.560604,69.653931,84.199677,86.443517,101.519149,113.028777,24.160793,-72.693365,-230.006812,-234.745344,-84.874345,11.232704,95.202455,63.078135,65.398991,133.477711,158.520822,160.63739,162.042191,171.328065,197.920969,218.300486,218.620814,197.347532,150.02968,137.284336,131.581106,134.675004,205.811452,350.840611,389.835338,286.174808,169.174576,51.027841,84.244516,192.999245,284.834361,317.071664,283.500967,205.644299,42.4726,30.980965,133.01661,181.709339,237.919091,228.548833,166.806775,1.512823,-53.559889,-65.563567,-25.534493,49.560008,37.841161,21.128831,-3.807569,-22.997641,-126.547063,-184.929962,-146.658484,-39.127948,171.052331,208.687889,175.169794,86.58451,58.982197,45.006571,42.11833,8.807275,5.575818,37.706172,81.355104,62.026131,-24.019201,-50.293671,-44.651879,-31.624075,34.347285,115.645542,117.872748,58.383751,10.337892,-95.527911,-117.645152,-46.908726,62.266245,87.712274,120.240229,120.141791,8.587102,-57.066403,-63.778129,-34.627384,-33.572013,-88.746964,-91.217201,14.284654,70.960041,58.255657,44.012607,181.340611,399.146339,424.547504,306.706865,247.30455,201.651197,193.600379,220.121594,260.695401,337.076976,331.776893,307.902021,227.081306,146.728958,-6.768986,-12.689394,59.506164,81.229953,86.640044,120.127517,129.125689,57.713134,-14.66221,-113.719767,-101.680674,32.952356,68.828298,16.470543,-112.977906,-178.616565,-274.292584,-272.928154,-182.978843,-78.625098,-44.513514,-30.386969,-59.928501,-174.335686,-209.495471,-120.865451,-19.615784,102.714051,33.725103,-21.296816,-132.072319,-182.136105,-148.700092,-57.275432,97.720816,123.198325,112.485206,36.170241,-46.206242,-237.523682,-277.309439,-184.679821,-107.909908,-45.860823,-82.152905,-95.834457,-143.240266,-196.777687,-252.191918,-201.860113,-6.123455,123.942731,114.551502,-8.221622,-62.120625,-95.380452,-88.629784,-55.647466,-17.405301,145.557563,246.997421,191.8562,14.980337,-19.700252,6.602442,27.583594,49.863557,114.682098,179.851855,272.674888,250.409323,103.817827,52.873894,95.584322,149.718624,209.136039,210.292522,206.170509,191.633935,162.285932,63.437059,32.103692,77.168092,211.887154,248.911967,205.456986,151.539373,9.781431,-51.274203,-17.441152,54.810583:35.633112,38.928809,-3.885911,-146.001636,-209.766611,-272.876897,-267.309471,-217.867487,-186.350581,-168.36607,-87.435911,-28.99862,33.53268,-16.495349,-203.705255,-247.961275,-173.398197,-27.157932,15.36161,-28.989835,-113.500208,-250.022421,-235.572236,-123.479407,-120.422513,-148.869336,-138.980057,-102.107669,-100.140701,-152.994819,-237.745061,-219.716184,-79.741197,10.264304,-13.50996,-127.040502,-186.205347,-269.491993,-256.786019,-131.308207,-33.041663,-19.364245,-76.739005,-133.944758,-218.31957,-216.916714,-131.174287,-97.129358,-129.470473,-194.323093,-238.959482,-324.619415,-308.509929,-202.117395,-167.558275,-128.858486,-78.377125,-55.789153,-17.784361,-0.786186,-51.105718,-123.911441,-182.846665,-146.898226,-76.730095,-76.334575,-112.981905,-215.482653,-251.312707,-275.847985,-263.71686,-248.287431,-244.331068,-188.389705,-43.515571,-12.865466,13.534238,36.839205,78.580812,103.07363,209.627233,222.561017,133.522876,-55.4321,-96.217229,-99.297015,-65.817591,17.469268,-7.946177,-33.259835,-45.966506,-81.383217,-246.819091,-304.759645,-277.612285,-244.960728,-205.879309,-124.004283,-90.910515,-71.49355,-78.754207,-120.745952,-130.354756,-114.503785,-79.573161,-44.203772,26.75196,28.530062,-57.322411,-104.123784,-132.246074,-147.613764,-221.018454,-197.002816,-135.16036,17.845171,77.763173,110.809103,104.158329,131.924233,289.648135,398.675759,492.207249,452.19256,315.519775,243.988978,111.31129,64.003778,-15.386835,-67.342994,-61.976384,-12.029009,10.055792,33.473493,62.591964,215.932538,349.843033,338.122883,217.167299,188.167381,212.962528,193.11747,137.809036,190.580195,362.143219,375.71173,344.058722,289.936819,266.321842,200.88066,156.842099,81.479802,171.006383,253.265359,259.46544,178.057826,22.899226,-23.427496,-104.146196,-127.953718,-35.05082,178.301332,251.928027,305.246501,288.068497,165.247168,111.733422,124.370785,208.846811,254.196901,363.492229,397.573871,338.096509,273.10569,220.410349,237.914974,306.391292,405.377011,414.636675,280.930698,202.546966,199.82041,254.725446,296.646022,218.347863,185.238447,186.479204,195.005874,127.503578,75.423911,85.720278,147.600288,235.294132,229.220607,222.727577,238.125779,241.332504,110.395806,-1.390052,-83.975111,39.674562,63.825942,-41.260876,-84.969873,-76.559087,-90.723192,-133.708528,-92.039244,66.156403,173.387006,223.849823,325.984402,332.331358,224.846073,153.839792,54.411254,32.305921,60.631349,129.093959,111.172964,-34.943386,-90.239149,-56.463063,1.166209,154.956968,356.824258,418.1973,408.955818,367.017735,252.765521,214.730782,273.211617,382.614026,393.119884,329.723701,277.289363,185.755675,179.797476,282.049403,342.393873,368.824973,322.380247,290.713334,209.88906,152.574203,3.165445,-48.514646,-66.892678,-48.52633,-28.186335,-5.426518,-31.560765,-119.582914,-124.59549,1.567321,82.469558,171.8957,211.987779,205.863064,135.418741,109.785807,137.353689,163.389042,134.967762,59.38533,54.536364,69.836771,65.127151,54.135453,69.264353,117.902785,111.046589,39.885092,72.071514,144.614883,206.746784,120.717884,-176.165594,-252.635087,-181.067715,-140.813443,-161.311647,-142.776427,-97.073867,-11.456529,2.776105,-56.384274,-121.647084,-177.164651,-29.071859,31.493036,-3.950359,-56.692969,-102.99076,-83.173897,4.056288,129.902379,190.74355,241.488686,229.523998,153.614337,95.908284,33.64265,63.256399,167.879335,202.638452,205.112191,239.997671,238.46424,95.240161,-0.965238,-102.169817,-100.086978,-53.156275,115.092397,177.867025,165.03046,103.484327,-9.181007,-13.813923,80.978584,126.922807,73.65608,-49.049031,-74.293359,-110.790348,-131.802132,-161.506966,-142.638094,-105.902657,-37.950505,-26.992437,-56.87506,-91.838134,-190.217971,-250.384834,-293.109787,-181.622793,-154.842456,-194.030949,-198.088946,-151.848809,-135.322145,-114.833864,-82.092961,-80.710334,-120.284187,-157.901299,-269.506144,-335.130836,-400.025877,-367.705254,-223.599932,-146.364549,-176.000111,-315.501575,-377.892059,-423.91877,-394.370829,-223.94888,-22.42458,25.193581,-42.092319,-130.989919,-274.135318,-280.966264,-142.791866,-40.739035,107.364189,149.129837,139.547434,164.699489,207.871049,227.388283,186.093984,74.83559,26.761512,25.321973,-14.227429,-57.640706,-141.179775,-168.804324,-194.318177,-189.729721,-91.589867,74.203341,112.412581,111.25748,83.205811,-12.404664,-21.320005,95.806346,162.894095,123.062508,27.193914,34.54348,119.514934,127.132333,56.574959,20.778246:12.337148,-26.661556,-103.505706,-284.30576,-367.104923,-448.219615,-413.907523,-265.030699,-143.531026,-84.902298,22.952794,45.268977,-21.87414,-98.169,-197.514731,-189.213223,-85.132761,32.847314,46.265673,-37.598096,-106.188113,-178.753422,-150.681158,-29.76914,42.075259,43.128876,-9.52345,-52.182434,-125.744283,-141.705159,-140.843762,-130.039457,-44.754808,68.295289,65.334408,-74.883842,-161.347677,-230.318283,-184.138398,10.583555,182.46039,229.22089,206.853424,138.433944,-40.343059,-109.8475,-130.662111,-82.087264,44.968903,45.09824,-17.692011,-156.814277,-200.587201,-204.306578,-156.205013,-21.263371,83.746136,116.21845,77.101139,13.232839,-84.359653,-82.995135,5.965261,47.100342,74.401623,61.865927,26.315624,-105.25555,-190.971677,-306.741027,-284.87817,-131.486109,-22.760874,-8.575733,-34.493172,-63.04086,-103.143331,-90.94761,18.349407,99.628186,278.435323,358.894057,295.109359,29.39506,-89.063191,-173.843705,-129.290362,39.33987,94.015512,43.488551,-83.005469,-120.381513,-214.665124,-263.688981,-253.84984,-207.043941,-114.275856,-18.646217,25.544591,56.600928,38.358673,2.730619,17.477526,88.299916,158.948337,180.907717,116.957767,40.8098,-95.350025,-131.315079,-128.264423,-110.2693,-76.826002,-53.520369,-58.128079,-79.988284,-88.513445,-79.406307,-39.840052,120.653693,350.59105,461.186186,519.875741,441.634413,217.631051,148.53197,152.018905,188.555234,201.901126,88.383262,-4.548591,-190.252715,-235.273286,-194.851233,-142.785456,-20.304429,161.779694,231.621065,180.889273,89.643304,-44.986229,-58.931076,30.825188,119.437781,311.566555,401.978577,369.162879,216.570238,143.496602,75.049473,93.475723,159.531385,208.666194,253.888702,323.608304,286.329229,57.002401,-61.218466,-130.034202,-76.897402,83.39582,190.416046,211.628392,228.507057,217.800786,136.746069,116.662193,221.287616,415.922738,460.54434,403.182137,348.899843,217.565861,154.284629,177.888825,266.029622,448.321654,503.123191,464.488797,293.172302,184.105319,70.952556,124.607167,262.788669,233.93615,214.59154,218.509522,217.330388,152.632004,106.49792,104.815285,161.74343,320.424668,396.162514,357.807636,177.925888,84.825155,7.853692,34.687995,63.660827,24.107683,24.695258,0.451459,-40.723956,-135.288317,-155.609003,-65.532661,14.452275,111.487664,135.888501,142.652937,137.494756,131.70245,167.335871,199.66517,203.812204,177.725951,186.394047,198.370881,176.350637,84.805545,57.168416,108.901779,151.772329,203.801375,324.570834,396.725409,371.394719,280.722517,157.381088,155.543392,225.76028,383.479784,447.810913,387.719232,281.277201,85.293176,45.870874,130.416817,215.591843,348.127097,377.719961,329.456986,146.5653,60.594041,-40.851501,-59.171541,-38.032632,37.421563,58.359497,-0.172996,-62.450412,-157.981662,-164.895494,-74.654731,2.211074,139.403596,202.572636,179.900561,7.708099,-91.976365,-122.052104,-53.822221,80.351994,142.891085,148.688877,89.282265,29.436823,-97.612347,-126.445268,-78.196876,-36.774233,47.801073,153.992193,169.088011,57.875331,-47.010349,-220.122492,-226.897682,-92.415415,45.486952,76.856069,22.598865,-44.889666,-132.154471,-137.543751,-147.825605,-165.066422,-120.862398,13.941101,48.420907,29.243667,-3.762959,-19.584622,24.022172,124.750594,208.282367,273.99924,366.181289,348.811937,210.24716,139.1758,114.835429,164.628942,292.038844,356.512194,335.710931,188.63545,83.241935,-106.939734,-134.950455,-23.936772,112.963402,126.721577,64.103024,22.55489,-12.885943,-17.344773,-46.239547,-43.369145,53.448242,60.688507,-7.002556,-117.712636,-151.497515,-236.634411,-254.585791,-194.198943,-75.750147,-31.787426,-50.543608,-94.229139,-173.820241,-199.039993,-184.887867,-151.341167,-81.829167,-37.963782,-56.498277,-149.596887,-171.909579,-143.610878,-111.205433,-19.026185,69.35763,81.324992,-22.06768,-121.750051,-303.935852,-346.129311,-296.121041,-233.776034,-122.738989,-107.005397,-151.128069,-267.731735,-317.667183,-372.998581,-341.696961,-148.580159,50.544499,88.607009,25.605062,-40.50272,-165.369002,-183.844172,-75.476507,4.062108,109.761254,166.88057,175.082676,159.955939,131.337106,39.893583,24.279185,96.160352,180.118882,194.125507,164.315294,101.319601,-133.712226,-225.52809,-161.31543,-49.355619,131.277254,162.781777,120.18363,40.377131,41.232185,83.180907,109.891292,160.114249,179.514577,178.14479,169.918518,160.499086,97.144676,49.476613,-2.555199,-4.479957:81.035967,144.013346,156.85339,111.762071,50.114582,-125.526957,-190.137843,-186.498778,-112.050372,-97.899778,-113.533797,-118.462488,-97.616199,-86.657278,-81.364569,-83.940155,-71.922237,19.85393,53.221753,-32.42882,-126.845289,-250.782986,-247.984804,-180.691989,-82.223577,4.790663,134.81974,118.413164,3.581416,-40.884767,-85.674448,-85.869657,-35.815301,-13.328958,-51.992094,-187.679562,-247.566726,-289.326844,-243.553075,-125.447406,-142.818519,-158.252269,-171.861693,-178.240388,-140.996451,-100.648278,-68.398394,-94.900656,-133.724787,-112.817597,-133.605591,-189.010741,-167.523703,-84.64569,-63.1883,-40.071952,2.130855,42.375839,114.229539,102.015396,-42.845814,-124.521548,-179.726867,-163.239133,-120.163766,-140.187402,-194.89785,-306.539216,-316.781576,-264.583889,-231.34427,-183.288363,-117.632296,-47.571586,146.891221,213.127213,201.037112,174.541017,190.13543,207.370097,195.020245,116.083363,80.768809,80.582336,88.869289,47.530384,32.857891,114.213181,170.520911,116.791529,-60.805514,-122.403594,-207.537915,-249.329772,-271.4934,-251.21843,-204.699845,-77.006121,14.378844,111.602785,102.459745,71.353661,80.925996,95.441694,44.152175,36.843007,91.926358,105.20397,47.319142,21.098946,22.547612,7.377794,-71.853333,-46.005624,10.817959,124.737968,165.301618,171.932533,146.288262,131.233528,193.057882,237.208746,269.948,242.60038,131.578994,47.734332,-130.758128,-198.253482,-277.415609,-192.703753,-101.816277,-16.64757,-27.689585,-18.424853,23.162733,120.479458,142.766876,123.078311,33.990767,-6.270941,-0.926798,12.42709,0.300916,9.451338,82.58265,156.712874,172.221768,115.43793,40.799625,-113.950443,-142.964512,-115.469216,-102.841388,-110.353699,-145.560265,-181.112774,-294.215753,-358.815528,-389.830361,-321.495497,-120.360331,22.538458,78.511599,148.898294,137.657555,61.341639,46.210871,67.978678,129.900769,177.937918,241.808705,252.903647,215.015155,155.55712,90.467881,117.290323,166.478296,139.912007,123.374121,127.630729,133.900385,110.381024,115.955241,170.69106,65.353835,-37.489235,-175.469222,-203.294271,-262.797208,-298.980692,-288.113135,-232.087943,-99.51383,-26.620193,-12.630056,42.729371,48.50696,-89.61697,-162.651895,-136.947624,-12.624914,13.15489,-37.900211,-74.521014,-90.324104,-99.212041,-132.560225,-114.096099,-6.454619,77.079831,96.893919,125.043689,116.351083,15.528727,-34.93287,-78.810041,-169.863391,-210.054183,-180.325868,-157.941699,-224.437098,-280.452955,-268.653939,-187.660993,24.52995,213.286775,274.36291,292.053381,266.756569,233.541823,244.817554,276.944703,279.245955,289.099068,265.789625,212.220958,117.720921,112.41874,167.397733,211.700117,349.913502,447.103837,419.691974,287.493538,230.609889,135.52137,89.177495,46.265219,78.3559,69.832852,-41.615751,-109.824943,-214.491331,-225.210028,-92.528905,12.428483,157.477197,188.889883,165.921309,110.412571,114.446919,176.890026,201.058374,165.098189,65.569536,38.402277,0.28448,-16.967561,14.488351,63.125386,193.676427,243.49609,234.232949,218.988751,248.15992,257.276378,181.628309,-82.014105,-173.34964,-171.383479,-118.536088,-112.263385,-62.823675,-11.548045,64.055244,47.55756,-95.591358,-157.860543,-126.091804,11.60474,35.258533,-43.114542,-97.168585,-167.053823,-179.936284,-141.771251,-43.011312,-7.423216,-19.949495,-35.79038,-10.726326,3.724211,-6.313776,-28.03953,-100.111441,-127.3735,-108.263662,-62.852368,-52.602463,-39.521638,-34.535992,-52.680749,-75.161724,-61.757165,-0.466294,34.955806,42.446475,-11.775986,-106.066042,-83.964964,14.569128,-3.347394,-39.748787,-83.167588,-101.942071,-168.48372,-191.645153,-167.685266,-129.080571,-123.483413,-117.639652,-100.152411,-77.775172,-121.843928,-253.766133,-271.543649,-209.36122,-104.663158,-59.214487,15.671991,40.096471,-4.945728,-51.391898,-65.425932,-11.529911,-12.846285,-107.494518,-179.9953,-309.931863,-339.392135,-272.450393,-211.18313,-180.594121,-216.536806,-220.682856,-213.934891,-206.812194,-175.344692,-148.66326,-90.061738,-35.599179,-11.927654,-7.171936,-16.227844,-24.379419,-30.892669,-38.325001,-34.361939,7.440908,121.861608,174.205464,223.668866,228.6447,220.793042,203.748653,61.76363,-150.902022,-192.221408,-190.665308,-192.282782,-197.026388,-205.990217,-263.351934,-289.593075,-234.251405,-63.076641,21.384173,150.524515,166.404927,93.009857,77.939031,154.272788,115.743397,17.081201,-86.86979,4.225359,279.982142,320.496585,204.536128,135.183121:159.211092,124.237782,96.050391,-15.382066,-80.691638,-205.152701,-242.026691,-188.096898,-40.534667,-18.104691,-90.916236,-111.382932,-59.324633,-46.981069,-115.028239,-134.452588,-53.896835,51.305725,65.42511,17.053616,-43.041127,-194.100126,-225.571675,-166.818517,-88.200706,-46.743264,29.912375,24.157671,-98.916465,-161.392303,-180.215449,-134.051278,21.455059,86.154942,50.897091,-45.177511,-80.608541,-136.990385,-131.52468,-70.262117,-82.404342,-103.147618,-130.182837,-137.818902,-134.672236,-137.107923,-143.261036,-131.94039,-98.214154,-81.856038,-91.126563,-111.89267,-95.203845,-43.503341,-37.679662,-53.502785,-44.153923,-20.606391,13.214311,2.908301,-67.584395,-108.837532,-141.230099,-135.286164,-112.316553,-83.896727,-86.697713,-101.007447,-89.999959,-107.662095,-148.871255,-218.703194,-213.375987,-156.224878,16.05021,88.833883,188.938807,210.960524,195.094125,175.159822,177.318198,208.582855,187.923511,133.491301,123.99916,59.585209,16.937896,40.694377,138.215145,137.934326,20.913534,-47.281193,-121.467501,-134.028021,-167.489742,-189.503805,-159.766697,-56.273484,-45.663342,-40.273768,-0.303904,20.772239,-38.652895,-197.594323,-196.896073,-112.59575,12.088763,-14.942392,-119.038145,-130.209522,-108.603325,-124.463604,-199.006816,-121.420995,-12.304033,182.087698,223.939211,208.028853,177.797453,129.78832,150.458208,201.411456,281.484931,273.413499,169.785591,98.595933,37.087605,47.634686,3.094418,-82.340503,-69.726318,52.481068,118.426561,199.901582,229.436008,278.365201,309.43596,318.27543,239.530448,152.358617,-15.118994,-69.438797,-53.01856,11.457292,137.407742,192.706176,175.973464,71.879732,23.890388,-2.161227,22.888454,66.501518,34.998371,17.315359,-14.168544,-44.055982,-148.495969,-216.467375,-309.661072,-295.094454,-155.31195,-44.759173,-25.415504,47.798126,107.521478,140.789941,95.675856,-31.849644,-15.685304,83.964707,297.002306,334.315288,257.009487,183.15573,99.761523,109.893611,155.005279,161.866499,149.055745,121.817621,123.491491,161.078765,182.006866,160.135009,95.527011,80.29395,22.700443,-29.29064,-138.558787,-168.097404,-115.158667,-61.998061,7.059871,66.567562,83.16033,52.088291,17.150237,-59.376778,-83.754217,-84.798359,-19.298827,28.82875,35.665979,-28.270354,-211.464877,-274.454341,-234.6785,-141.898543,20.177934,47.08604,81.393682,247.395285,282.149793,138.472428,54.442739,55.301109,97.981011,59.809819,-60.037495,-99.735888,-170.997649,-216.429317,-259.128534,-237.286653,-82.401203,154.034758,224.201023,265.940687,264.002542,231.137419,234.301864,289.75675,280.867155,257.040855,208.633694,171.762895,80.408967,52.66702,82.187708,130.703975,259.597891,380.140939,382.087229,228.681375,118.094061,-54.904371,-100.04241,-148.808691,-121.974597,-74.34567,-30.684747,-62.042745,-157.485869,-157.030582,-1.506185,92.946205,185.186156,236.169795,271.439002,301.425864,274.297448,182.054556,163.674731,195.754412,200.002163,189.522841,164.060868,146.910467,137.407176,157.206358,200.337832,206.788157,243.975532,315.20566,309.724382,195.675075,107.9549,-95.810705,-170.654374,-193.081937,-130.486047,-109.864418,-88.59331,-63.055376,17.874863,40.325794,-15.88747,-70.206239,-102.075831,-47.113837,-49.493297,-100.599461,-123.476963,-224.430873,-296.645528,-323.570042,-127.462214,-18.88915,28.318246,1.703087,11.25679,26.812649,-6.286233,-51.666169,-135.992878,-126.992341,-88.388687,-10.491062,-7.217434,-68.580147,-88.074187,-97.311595,-123.63441,-100.87499,65.324055,155.181547,152.23953,63.070567,-62.557367,-45.082351,64.382807,81.189074,22.719017,-115.991847,-151.294325,-185.172669,-187.936247,-131.001073,-70.676153,-84.098383,-149.128652,-161.066905,-183.022366,-211.085481,-213.762995,-176.251236,-78.510454,-32.265867,-45.229555,-53.432966,-44.113004,-104.960785,-149.541408,-141.196625,-109.620846,-112.679882,-143.462119,-199.820347,-379.059141,-432.781131,-399.10687,-359.225309,-290.975956,-221.952158,-206.912386,-169.425587,-142.87894,-160.074669,-191.272195,-182.636933,-86.881313,-53.500106,-73.307902,-111.44814,-152.114951,-135.393556,-70.411528,-44.032434,-12.473806,21.81035,66.380478,181.582503,194.450315,112.183262,76.019234,16.766974,-120.088693,-158.804189,-105.005919,-65.619685,-97.329684,-163.066178,-251.654035,-245.517421,-183.109439,-67.925412,6.197518,123.224988,121.758388,3.142199,-36.310312,-15.681065,-15.535943,-33.993544,-34.450924,11.63793,117.2357,114.448353,18.587082,-35.075106:95.515966,56.522417,1.812989,-130.816441,-202.704338,-345.508298,-368.824759,-300.234826,-200.524762,-142.429069,-51.522564,-37.279844,-22.335074,-34.02451,-113.344369,-134.878131,-77.360409,-21.18295,-35.90436,-98.927657,-119.40268,-102.308435,-84.703796,-98.063223,-34.306304,48.405588,118.60845,86.733034,-19.900842,-78.309816,-122.390695,-95.097142,-26.640068,2.465106,-28.692908,-184.54063,-252.067997,-226.16569,-132.44355,28.772692,57.917005,66.588474,57.105498,33.02126,-47.912626,-97.79649,-110.037745,-80.350668,-77.660984,-87.443833,-94.406798,-183.376798,-236.140621,-272.144953,-246.87209,-176.848892,-109.998184,-37.264161,111.894433,113.426528,-53.83618,-154.10361,-204.547376,-152.084863,-61.809002,-99.806889,-144.123349,-227.335572,-263.543913,-269.936263,-215.211991,-111.186021,-101.966754,-85.825112,-19.772025,11.427182,3.711781,-13.777475,72.044909,136.761222,145.419376,101.357666,83.223675,1.349236,-48.919594,-86.106362,-61.108774,7.460766,-28.145938,-85.089804,-198.624096,-236.814877,-328.88903,-393.495064,-432.407744,-375.942109,-208.305502,-133.019355,-122.441547,-34.248066,30.982964,98.686729,108.289337,82.152693,21.991538,44.196549,141.650485,134.40989,-12.010933,-68.463548,-78.054939,-89.165716,-155.106404,-144.01092,-97.422859,23.224882,56.983393,34.870112,17.235502,54.834545,214.720664,306.233298,338.2661,266.311008,70.582171,-26.455588,-166.411227,-188.699946,-180.787794,-150.96934,-130.009655,-97.649204,-99.38083,-128.338072,-123.061078,-25.555742,95.257869,115.755765,62.223231,20.422658,-31.037467,-49.946862,-13.741617,60.242732,201.16337,287.701958,317.016533,254.7586,158.863363,-9.372961,-27.816866,47.307155,193.519979,253.392267,203.42165,109.927117,-46.420637,-104.123758,-191.663108,-177.651675,-1.293788,183.622034,220.619191,211.727581,186.533223,140.313005,149.515715,221.592638,239.527654,214.78511,138.761885,116.130792,99.83173,83.573162,87.894997,134.22617,229.75293,217.207096,174.29934,67.302585,23.057268,5.103047,53.774807,162.288849,116.494553,73.588074,26.664924,13.537792,-21.282542,-38.284088,-18.764656,25.127736,138.980804,180.680441,156.80981,105.624873,72.007667,-52.80081,-85.059616,-50.115026,-2.207128,22.763037,24.552587,-6.641291,-69.503763,-91.977356,-102.252615,-85.204051,-37.988667,18.756942,48.271415,95.063232,109.379772,82.5398,42.547963,-27.749966,-56.335625,-43.427828,36.621386,61.250829,-4.915559,-61.733057,-69.326815,-15.229178,127.646748,263.064636,299.960306,284.313084,249.0356,162.37634,127.507268,134.97375,264.918294,322.970556,251.575833,147.18613,37.718368,55.212769,182.930717,264.668323,334.045992,275.926029,235.788651,176.590909,138.275513,-24.482841,-92.234965,-58.379488,19.731795,7.2021,-82.210479,-112.784239,-143.467695,-168.882046,-163.604442,-108.994933,36.017072,152.159507,165.400434,108.536731,95.01768,149.158394,172.195532,119.45577,49.491867,46.988694,61.004681,63.578136,32.151564,5.144295,37.554297,88.040939,111.976386,51.400945,23.9129,3.736706,-15.091353,-120.666426,-158.596412,-159.473913,-174.368235,-181.518965,-151.601598,-121.471156,-81.454525,-82.260067,-131.097211,-170.532391,-156.235448,32.138358,95.294361,46.285533,-9.978909,-42.767669,-19.578928,7.96575,35.291942,75.53221,122.961336,133.29649,161.476767,144.092291,77.566662,72.821131,62.04381,0.30674,-14.456279,-19.790515,-35.982542,-110.827628,-141.43651,-109.132571,-5.488403,29.230758,57.964736,68.653264,51.03874,13.558548,-42.584644,-39.325803,-1.089695,26.291619,15.825119,-66.695454,-115.003248,-171.129743,-171.256567,-121.676812,-24.181464,20.984707,16.531155,-20.817605,-91.703429,-134.985784,-239.177215,-261.062511,-204.907698,-89.023221,-45.767671,-27.972028,-38.162813,-42.591952,-33.583275,0.519061,54.91942,66.250094,-13.216631,-94.792182,-263.912169,-310.42768,-253.929931,-190.546531,-136.028711,-130.885294,-133.841691,-202.07071,-265.438004,-323.23534,-270.5412,-100.530054,-13.763755,-3.343348,-41.099388,-74.053728,-123.119078,-127.856628,-47.17758,20.040135,61.755274,27.66514,54.999835,175.511329,205.183277,123.345579,54.42343,20.556688,107.745858,130.187202,23.991507,-70.770202,-196.804658,-214.481667,-196.932427,-167.584942,-58.632991,61.981326,101.393945,142.561206,135.623921,63.765378,43.199503,84.511731,89.572841,62.346909,67.346341,119.090043,236.489793,243.731769,142.080265,101.898477:left
-46.013692,-8.059955,62.385372,220.114612,276.507377,310.108986,286.688156,202.321919,193.676877,215.005292,233.234202,221.288071,153.918473,112.648076,36.221733,5.450045,40.583624,127.118015,131.969703,114.579362,108.915306,43.958125,-39.421814,-204.994543,-216.366108,-193.923549,-168.720311,-178.218334,-233.076616,-263.103638,-305.212592,-292.164839,-190.309083,-140.380185,-139.515263,-74.845259,-15.155781,102.633514,144.404713,135.99788,25.237762,-36.878118,-124.694286,-145.435906,-135.424668,-107.175875,-114.760739,-159.83138,-152.05043,52.846122,143.67095,163.678772,116.331249,64.751411,61.464895,-3.218205,-19.035854,34.533725,133.296092,138.521434,100.033206,81.443722,22.462935,-29.70941,-99.227778,-10.413239,94.940984,356.626192,450.560031,464.150796,403.176518,236.416388,127.175947,121.219708,176.314366,198.558433,173.548318,152.46949,105.155633,55.558156,-29.49921,-19.989305,10.632706,97.177303,133.125151,164.743072,153.168462,61.168087,-32.984168,-27.683478,82.420394,145.439804,199.022608,179.547919,64.323816,-3.905133,-69.502839,-38.274614,13.249857,166.726035,208.773642,155.624694,86.209558,-66.681681,-104.46746,-78.235176,-11.223645,32.435285,84.16463,59.171011,-88.916366,-183.220915,-210.781185,101.96455,270.860494,376.265249,327.627281,263.810522,276.190187,244.117282,172.509526,166.5464,219.619441,262.172677,281.392764,249.760852,163.862394,126.531882,95.640976,138.522629,159.595253,94.592957,14.490931,-118.134483,-157.188138,-195.210845,-145.607411,-96.149143,7.122766,44.364824,87.439913,112.44727,147.427497,128.737362,82.81779,152.16012,213.178244,270.634084,249.637945,198.880745,191.110951,184.945309,169.05871,168.922225,271.720137,355.710042,410.238623,368.752941,233.148446,148.315518,30.942273,98.845767,151.331132,181.967565,169.060473,110.796933,48.145222,-130.344889,-188.155379,-145.876001,-11.887882,48.677012,111.862761,106.090476,20.289443,-33.105192,-74.151548,-12.408975,61.057855,228.805842,250.105931,164.368268,129.618693,123.337998,142.066967,153.639477,169.725221,176.126104,165.069636,124.805469,-15.600467,-83.426247,-140.49668,-56.02609,33.066335,204.557805,227.108276,111.916274,18.01902,-93.813119,-35.786726,7.176338,20.504953,17.291544,72.862149,108.284941,85.086807,31.719316,-15.794585,42.621257,73.615099,137.69763,150.850803,54.26976,-35.01239,-123.918908,11.580419,82.450613,98.032727,88.841737,124.223399,137.691207,51.031411,-42.52946,-205.279011,-230.324798,-190.328144,-81.725597,-46.209287,-22.120872,-33.128766,-98.601798,-150.274721,-134.27855,76.383832,215.865489,236.662229,123.508061,-26.564199,-21.110982,-11.932011,-10.92707,41.164575,108.42546,53.204061,-119.939313,-168.946212,-179.672503,-76.074276,12.783808,186.831742,250.176147,296.060029,262.547509,99.103236,9.772157,-90.457004,-50.864021,12.081206,104.906417,91.198505,-8.110834,-56.525212,-125.770919,-141.48337,-138.137177,-135.239163,-141.234479,-194.418975,-221.93586,-229.06394,-231.871764,-263.687796,-306.357361,-313.741483,-285.960789,-276.678115,-295.932779,-315.604842,-338.457284,-301.135903,-271.872775,-146.564641,-30.627464,189.447435,227.838472,135.064807,64.023251,22.046339,56.710133,79.319188,140.377046,147.476348,72.846284,2.046483,-134.428937,-103.721101,-22.529583,142.358345,168.226172,96.377211,63.165274,38.637795,-12.894759,-177.620542,-211.524287,-178.076503,-140.313635,-147.418478,-93.751182,-15.814948,89.439358,44.450063,31.340495,85.736136,107.743165,87.866046,76.951001,20.773329,-45.878891,-104.238564,-40.337663,-35.593802,-34.666196,-1.266411,55.016055,33.877674,-86.55634,-214.567077,-259.903503,-249.413817,-190.873412,-49.893869,-1.530665,6.922649,-23.701848,-50.964857,57.187272,131.006034,191.776328,154.78374,-11.182734,-109.53868,-265.301109,-244.470507,-180.164214,-31.749938,26.289525,91.182493,145.21136,295.403308,317.348887,234.33713,187.986586,208.189558,220.674971,170.142908,22.787222,-21.364601,-1.860026,107.057759,153.276223,187.073609,197.459615,233.496403,237.148161,178.343304,117.690734,-4.336714,-10.743356,25.42562,45.107534,-1.397223,-117.481071,-156.010566,-219.544201,-202.937486,-137.068856,47.92632,116.549264,128.566176,83.496032,-30.745462,-70.334122,-104.851439,-104.293,-58.102,88.99662,100.728233,-43.824556,-124.07393,-205.990347,-178.466481,-119.752694,22.202518,73.293545,100.797988,83.959452,8.976404,-43.810171:-16.44338,51.410238,166.004012,318.125945,321.155243,244.264561,178.885092,114.324936,224.152336,268.075076,256.822425,253.830181,328.223192,356.505649,293.273129,238.979837,209.506759,219.321976,222.371789,238.850053,214.303318,59.16256,-48.160486,-197.629161,-147.913457,-80.292328,25.777636,30.987306,-29.117576,-68.047355,-198.49065,-258.344002,-183.138924,28.921771,74.227714,4.446709,-28.31581,71.747127,138.106523,94.617758,14.930586,42.420299,78.529985,38.11451,-57.38081,-77.097515,-129.75038,-174.752942,-169.484357,18.570204,118.617206,209.370272,207.233848,158.528614,99.204879,-65.473286,-90.348115,-35.035443,80.176517,103.883885,53.106216,-4.843246,-137.619957,-194.474483,-202.761735,-38.66596,76.741835,232.819394,236.09667,182.927165,166.247302,143.244688,138.710363,158.178977,232.7774,253.978401,212.914017,169.908234,70.682397,23.915473,-9.563602,-3.374014,14.592656,96.895135,127.170544,110.519464,70.140853,-0.467862,46.971742,96.829829,195.000402,243.784226,272.773165,223.665676,63.290633,-8.158503,-90.753666,-39.725323,33.278606,160.35855,173.376671,83.449247,0.706008,-123.539682,-87.128289,-45.062124,-5.908072,-4.901007,-15.779012,-32.029238,-112.144931,-165.125709,-140.788377,100.937551,211.896405,265.931959,215.292616,128.729924,130.3268,123.599533,99.033066,119.299829,291.868345,427.242104,528.786667,446.254465,224.668372,150.804657,100.7757,193.375969,249.004339,187.710596,64.211526,-129.318357,-134.351841,-75.370739,-50.911836,-26.651911,53.556997,70.23005,39.069677,32.835561,65.702339,83.893439,103.947047,94.827801,107.655085,142.543157,110.674798,-0.767214,-35.029612,-81.758336,-149.880307,-171.984044,-94.758458,-13.729661,82.058916,74.944888,-15.906572,-94.412255,-239.859616,-238.463218,-201.582928,-127.643191,-119.446872,-213.820299,-292.077618,-366.392766,-259.039521,-209.743651,-165.051351,-130.608929,-76.67064,-87.872514,-103.383218,-69.996953,14.880477,74.99127,122.171797,183.128939,161.48438,71.037581,25.178893,-58.761443,-43.977747,36.423464,240.331358,265.917622,120.516975,22.049649,-98.225332,-124.9665,-164.877435,-139.899661,-74.54919,41.736319,35.863529,-59.597409,-110.88546,-206.985543,-254.224492,-233.465267,-129.887466,-74.079338,34.94593,79.804952,55.698332,1.696843,-48.137603,-13.692637,12.685993,36.347448,15.943925,-63.166015,-95.910742,-125.346676,-120.211476,-91.472546,22.186801,61.141085,55.157395,41.241182,-6.278848,-59.21225,-148.71794,-78.671967,-12.352724,43.49149,24.475678,-4.529602,3.473829,-40.20549,-107.86058,-72.315314,105.935156,186.325039,224.814806,188.08083,72.923253,18.808533,-9.940802,110.380609,189.356867,249.200064,207.656749,58.186134,-28.756174,-176.289511,-123.543298,-24.798621,189.520077,267.778033,303.689315,238.40163,16.528387,-58.854438,-59.922575,19.372992,39.299065,45.415087,53.074672,22.65515,-44.101196,-170.148221,-104.05692,-60.153073,-82.824669,-113.711763,-154.862293,-169.882923,-168.879659,-163.200015,-186.44681,-209.840985,-177.420302,-54.927448,-22.137024,-46.945205,-97.75197,-264.114086,-332.077362,-279.126635,-88.068409,0.356457,121.171744,168.840597,207.989774,172.4463,48.341454,35.168177,95.850837,200.770084,176.603346,35.473372,-14.1021,0.592282,86.73922,119.626592,207.209523,254.261502,224.875115,151.95918,23.778198,-15.414835,-96.743228,-158.61881,-149.006136,-118.747947,-133.202982,-149.386703,-123.042434,-59.429631,-21.846825,-7.750832,35.409825,52.749083,17.771474,-19.021469,-70.509975,-88.588364,-99.647906,-43.541815,-14.523401,-13.529275,-22.033899,-7.715061,-24.137768,-172.62761,-308.639408,-301.828599,-140.230678,-60.349253,0.648123,28.278346,83.286972,69.745107,24.33433,139.194142,222.776741,248.649191,180.669903,8.526049,-59.309087,-129.792629,-71.275266,-2.579137,145.870642,190.931047,245.314476,294.09278,363.096639,337.147801,247.728267,277.054479,310.991792,274.168962,197.260356,50.13669,36.422741,123.096198,212.620808,251.512311,370.036843,414.125372,351.691348,281.090792,217.569937,205.775319,125.111154,72.245313,87.249566,96.986875,62.457983,-10.562044,-33.46456,-84.174094,-71.199934,-22.615045,91.957124,124.685514,120.664461,103.754884,61.184739,30.500457,-21.241458,-2.718174,43.077549,130.016238,113.917448,-28.280812,-101.208273,-192.759049,-172.020326,-100.233062,83.037284,137.123817,130.325219,89.06535,-21.15682,-53.446193:85.576538,130.339167,191.752335,295.832155,292.69126,209.445942,168.796225,152.965905,206.812973,229.490467,248.73789,253.945216,275.021481,274.54922,185.495569,131.582904,158.545999,221.243655,195.134207,90.636972,33.512601,-121.055881,-206.239222,-230.95977,-100.35595,-67.01049,-54.674761,-60.644336,-105.858183,-139.330655,-221.732119,-242.779034,-167.276375,-36.293217,-6.136306,-29.664486,-42.071482,-0.583812,22.912981,44.941374,139.533016,201.309355,253.394166,237.267696,141.009515,69.786038,-87.61034,-154.837344,-177.578642,-26.409326,61.69684,141.059569,131.983641,38.105645,-37.254676,-111.837332,-64.701817,-56.025824,-67.773343,-68.336606,-88.733962,-124.091864,-248.542514,-303.549414,-288.613737,-117.455487,2.25506,205.24392,243.578306,195.792432,146.91404,116.392946,195.024229,216.524972,183.83095,160.393967,132.948029,121.103073,69.489784,22.770855,-18.630674,62.729459,110.764132,133.875039,104.416446,68.202293,70.418056,69.529659,121.354619,153.499878,168.27918,163.588259,123.389991,81.339648,-0.866368,-40.789833,-123.453158,-103.024169,-42.953541,26.523409,0.090842,-91.380738,-132.404341,-231.258564,-302.472943,-295.391231,-171.421205,-80.384862,-19.35128,-86.026546,-274.341213,-303.457647,-164.718312,27.271301,72.149541,42.373481,-21.127487,-148.516272,-173.340431,-158.158624,-76.629748,-23.992147,104.409036,183.475578,246.498697,199.925281,61.674534,20.027285,29.193734,132.221185,182.748163,174.308847,117.975545,11.599247,-29.103029,-118.059723,-130.595539,-61.291352,126.829049,129.97061,-72.083583,-163.753693,-200.589556,-176.075206,-124.437487,-70.576977,-17.771813,44.141318,10.886356,-116.971119,-179.928008,-280.098431,-296.584564,-273.157253,-255.761656,-270.60675,-230.514213,-180.059762,-214.550378,-299.723594,-381.397299,-241.07902,-145.443744,-62.008547,-80.486724,-163.29536,-231.98529,-384.266279,-350.515749,-274.085348,-160.410339,-138.047112,-111.599596,-115.561311,-175.591833,-184.635259,-117.984061,-62.406752,-30.448875,50.699681,60.225326,9.238083,-30.656074,-95.116901,-30.537215,51.107505,167.132457,176.562191,165.333842,138.691447,12.643626,-37.697932,-60.071948,-104.531154,-96.206683,12.877656,27.681902,-125.898151,-233.829618,-322.720776,-225.07034,-149.160076,-20.012654,12.064577,35.713614,35.438423,-45.480122,-86.397316,-9.206893,115.905771,133.435237,102.699671,71.483793,29.89734,7.870234,-76.975629,-86.465227,-29.838522,108.800444,127.403368,95.427056,94.589087,11.636625,-95.9182,-234.906609,-154.399944,-76.218287,1.68897,-27.38556,-68.048095,-34.081378,13.166797,-59.594955,-79.453058,-1.733768,52.64913,73.682448,48.896198,0.779315,-14.287078,-5.01031,97.455007,176.25745,301.086278,293.620549,127.495833,39.121093,-14.456109,41.618461,83.070693,223.641132,312.273184,359.866182,268.845511,-14.967239,-100.123036,-68.782867,50.07283,90.900099,138.569624,145.0182,123.167458,100.656939,40.922552,-2.182606,-20.882548,-76.062084,-105.053837,-120.817973,-94.561516,-36.671745,-50.22525,-123.039816,-76.085311,5.655847,174.587998,212.745695,170.604521,92.488845,-133.244397,-165.807317,-49.788285,189.279543,214.185055,201.882096,238.522266,278.365478,238.558675,170.660913,209.750013,241.544051,266.069537,240.087208,128.138456,64.08049,17.020457,105.557081,163.461519,286.482742,330.039884,295.205647,231.710574,101.421181,58.648751,29.196541,31.495654,42.835923,58.531745,38.959237,-25.951332,-42.720522,-37.243894,-2.293548,15.039,76.393093,107.014151,78.080935,24.504559,-74.917803,-98.522255,-98.876032,-85.571829,-83.352205,-107.92911,-116.013098,-96.803188,-116.166496,-213.667478,-237.543702,-221.55256,-154.865455,-108.024457,15.056748,84.596417,122.781611,81.31669,30.76033,121.094805,165.227086,130.133928,77.168137,-23.913717,-77.125093,-150.807468,-132.958853,-84.962941,90.205212,177.134273,236.746732,231.021123,224.779037,218.044157,218.578687,265.925154,280.382947,207.401534,123.131123,10.36546,23.865582,111.767014,187.833581,250.799649,408.283262,435.339177,375.285442,339.854899,256.78838,191.487218,73.72917,82.379959,129.97346,195.155025,187.52507,97.010398,33.30774,-53.412453,-19.053608,64.099545,280.211099,330.315016,280.781792,237.951063,183.567995,162.210548,122.610849,122.155463,151.225393,221.776127,215.183527,100.769087,41.629117,31.78401,106.761915,132.291493,184.124788,209.021977,160.780184,96.419231,15.733334,7.50575:-45.51548,110.843026,230.744491,403.524678,436.238678,434.208549,400.673767,294.106507,278.068698,283.197792,275.3782,292.128716,322.72205,291.907282,151.451409,90.734945,96.431717,155.648831,145.107995,91.542582,63.485826,-67.076247,-179.09027,-352.358288,-327.731292,-268.080311,-143.603053,-105.752606,-133.340616,-193.406788,-317.654798,-336.462521,-231.92643,-59.298897,0.129502,98.480665,144.178998,193.261608,201.526501,179.367197,128.920265,105.111278,37.741849,6.821172,-34.955654,-66.321052,-164.240296,-190.957205,-115.020534,15.141506,77.362447,197.27668,198.133019,54.854871,-25.711061,-108.916922,-116.767486,-113.010047,-52.939553,6.285806,16.909694,-60.115455,-237.866767,-304.909406,-365.850288,-230.882315,-86.672197,199.175669,280.217812,343.418549,343.742171,246.386911,118.167145,104.928479,188.146181,225.745389,180.686828,115.533924,-5.279012,-38.003686,-42.063295,19.288145,79.676994,196.777263,210.645026,139.380042,66.673542,-77.388656,-75.472357,-35.959418,55.38677,98.551557,107.04806,62.383388,-66.686426,-123.751329,-152.160071,-66.347001,-8.225924,106.435077,140.872734,108.317845,46.523065,-111.340964,-191.205887,-178.666619,-87.2985,-41.989168,-19.817806,-37.463735,-124.099849,-182.190687,-183.500635,21.644931,118.10021,155.351984,121.086773,77.510309,66.201217,-4.157661,-15.986198,40.024646,201.353528,255.241362,230.52295,175.668868,75.31074,32.607975,-25.186358,28.3809,75.385988,98.185953,74.158477,2.864389,-51.370068,-179.187466,-182.426286,-121.521464,34.036062,73.399763,25.152992,-3.41765,17.151508,23.850526,14.927906,111.801417,210.671531,350.952311,315.420486,116.793412,42.489936,-9.81023,-17.990534,-12.129193,79.891517,153.058368,240.14747,239.121006,134.517278,34.39469,-93.753322,-17.515824,37.499894,80.62588,51.736124,-65.583355,-120.549521,-213.61653,-208.710078,-164.005177,-80.453937,-32.666422,67.842688,65.331855,-64.573493,-118.380182,-97.01268,-33.560636,-7.035806,45.134958,35.640102,-13.939036,4.301358,81.265133,70.53908,65.004581,173.970358,254.449505,274.444308,203.521564,10.027101,-89.842652,-252.049577,-233.713116,-132.965702,98.949713,137.628011,7.217787,-110.542261,-303.244018,-309.156493,-248.974335,-78.442741,8.818536,138.507852,156.551356,73.336689,28.742964,69.444922,116.884883,90.688202,64.31559,84.4505,62.061178,-7.132252,-144.561214,-151.403148,-123.551064,-28.380008,7.174852,-13.310221,-38.462088,-128.424365,-208.819752,-289.314252,-213.481499,-168.065277,-91.263795,-63.97951,-36.282706,-40.037004,-113.162032,-190.925693,-165.035275,-2.328459,64.037219,51.290464,-4.337605,-68.374195,-61.61471,-23.753613,33.301181,70.455875,143.379097,161.731467,98.931553,13.088899,-125.518938,-68.899079,2.996887,179.952371,270.386482,321.699216,259.996132,74.540994,-8.929156,-146.192254,-159.426988,-82.518637,108.836588,147.235409,81.992763,2.703965,-154.463673,-158.209644,-121.903779,-103.572094,-119.788946,-147.539465,-164.875052,-219.554374,-241.368478,-255.491874,-282.473747,-279.118797,-166.006659,-104.622716,-103.298079,-153.219977,-262.138371,-238.36556,-160.329935,55.255357,152.868499,245.107703,240.147673,197.518032,180.651548,153.861636,153.328301,183.434695,253.506805,239.073222,109.085094,46.945168,17.670493,85.043034,113.864506,177.70351,233.391473,315.299794,302.185963,147.888831,30.568019,-160.779997,-181.077746,-121.271934,-2.119949,-2.123429,-34.725836,-20.539126,35.439295,76.582805,68.911786,26.140474,22.343408,29.360336,25.370479,-43.836872,-120.642389,-233.355357,-172.77444,-135.933012,-131.498417,-122.71224,-82.124363,-109.088602,-271.363144,-392.584158,-399.655088,-305.519741,-233.460139,-120.248917,-88.052051,-93.857732,-123.169833,-152.501322,-96.090496,-41.942444,65.633634,78.699359,-18.221038,-109.945696,-296.438335,-328.536404,-257.651566,-36.351784,51.01045,160.797478,217.019608,272.978247,235.016727,114.762422,103.490134,136.559779,184.936077,162.521052,33.654019,-27.678215,-92.431331,-69.766786,-9.269634,170.46508,241.560561,244.484555,188.742698,65.934881,12.764975,-76.531936,-81.618784,-36.588075,55.920787,50.671463,-49.168283,-111.323112,-173.542673,-44.484999,50.760437,166.407542,188.37227,208.898981,205.999818,143.501175,94.860828,27.253512,56.655715,112.392657,204.382541,198.558773,113.1469,55.624582,-64.225989,-54.155186,23.213063,185.504125,222.108847,211.363415,183.276804,78.097157,12.127121:1.120316,91.814925,183.710223,359.43618,381.585274,343.961365,324.097732,303.532528,296.072435,275.975754,221.73831,196.566065,103.886067,45.374622,-28.941286,-30.53837,44.301327,98.962108,89.586004,40.364664,-4.856243,-183.130529,-300.910527,-433.892199,-332.462493,-254.811854,-157.707266,-152.361981,-233.389659,-293.819565,-389.348464,-398.597924,-284.048527,-69.198847,13.464067,83.637115,88.719411,77.742143,64.107742,52.253058,115.919719,155.447974,178.035842,150.805203,0.063154,-114.877744,-304.198045,-328.076158,-220.816022,-2.502149,90.843743,129.649352,80.010717,-62.76851,-132.987815,-230.134312,-219.632325,-175.945067,-88.214122,-101.691746,-226.626393,-273.336815,-343.854178,-389.658862,-395.896997,-213.899614,-72.89705,195.055003,274.430855,306.841294,266.742795,128.929717,97.061441,151.336911,278.874601,274.52683,117.502063,30.69842,-85.748182,-116.249139,-72.511495,107.806931,208.680637,293.543634,256.893147,109.996028,25.351392,-90.481959,-60.645463,-37.619731,-19.015975,2.083907,36.848235,13.394453,-125.526479,-194.424164,-199.975932,-57.78629,28.760275,139.138009,129.357597,-6.772716,-101.060124,-279.046609,-350.909596,-320.197969,-168.694088,-102.928864,-121.077361,-199.054463,-336.367966,-335.54677,-177.285573,9.83829,48.718778,1.969957,-46.010734,-86.508709,-101.57261,-197.542727,-167.32927,-52.964769,198.942668,258.188522,192.855105,90.101524,-123.264163,-162.770266,-91.393561,47.147133,121.372981,190.471076,157.565721,17.337811,-54.752041,-143.534625,-119.743,-77.660094,6.336804,17.14634,-26.133975,-60.501831,-175.639213,-231.407788,-178.542211,92.251188,228.598754,291.430639,198.800232,-25.542119,-94.999866,-214.453242,-277.203693,-214.039815,53.377773,153.687669,168.192815,132.080197,50.238072,0.392739,-52.082394,36.250752,104.32223,156.305079,130.416106,22.430282,-55.53739,-208.94896,-233.65297,-195.691776,-87.931372,-39.48056,-8.040937,-55.58269,-209.954008,-229.430557,-114.171079,46.255644,107.699127,95.314086,16.057763,-91.30736,-70.815556,10.261834,107.069899,175.939466,277.951406,304.994482,354.677429,335.516395,119.709716,-7.259771,-131.321876,-77.379955,22.880293,241.454826,268.732231,120.12696,-6.119988,-204.141875,-182.162821,-85.004945,193.070787,290.24819,266.976654,186.797305,48.534113,41.573485,139.730552,224.017496,249.569698,293.108207,296.33461,202.870157,113.890326,-19.984869,-26.214609,6.899917,93.767365,98.980949,34.301157,0.172387,-123.514105,-217.044362,-296.723434,-179.512247,-101.932673,-14.762225,-33.598122,-140.37142,-178.198412,-190.087496,-159.921295,-107.129129,66.541151,116.928062,62.522636,-11.294905,-138.62346,-155.164043,-79.263282,78.599004,161.709916,261.754486,253.20706,132.545488,49.899745,-59.078737,28.278936,140.879395,409.990358,503.978919,457.879048,331.840643,70.367285,8.232528,25.336114,93.888714,147.491784,252.978908,265.713754,193.950466,119.480569,-38.579499,-75.038622,-47.959644,-21.819854,-29.598431,-9.823283,0.706619,-105.229374,-200.090529,-242.553747,-66.424161,29.812947,154.626793,172.094326,104.446257,19.888777,-132.0668,-77.289778,14.901074,242.046249,337.824179,390.953058,351.596487,249.174267,230.896274,257.724546,307.126139,353.082963,402.570324,350.197504,170.623688,113.697728,123.229225,234.846668,290.450582,366.724313,377.243766,304.967327,233.921255,89.400914,34.770357,-24.80785,-52.391269,-47.746198,39.318089,100.194795,139.180898,108.919365,66.631816,126.720794,156.630418,193.404712,217.376543,221.258685,172.183289,5.932658,-65.295846,-106.245283,-52.233504,-22.665408,-7.21812,-8.198804,-27.117491,-83.120675,-257.886955,-286.148253,-225.90939,-64.567059,-6.193582,39.861862,46.064117,-22.490153,-92.774714,-108.203629,70.700713,158.739137,242.711551,223.746867,65.711726,-47.674133,-221.515449,-148.404158,-30.938752,197.85249,267.975868,293.806458,263.38173,171.67051,137.500234,145.196677,195.015636,224.327596,262.824866,236.684171,118.464372,55.516014,-10.068921,102.725204,200.714026,375.325204,412.916163,312.886307,208.160921,54.610892,21.309835,-34.912801,-69.63733,-26.889857,115.643048,136.238718,28.45016,-59.295662,-155.339769,-20.617492,100.257934,294.078202,322.690536,259.911938,212.107956,123.87511,79.458183,43.778387,101.614816,143.015267,195.993693,182.356387,64.051885,-16.136121,-127.877491,-104.215618,-58.640273,48.814131,90.83729,49.022547,-46.244521,-254.289444,-291.261933:-88.598476,-17.38138,109.05795,345.943002,385.523642,324.765565,276.239919,229.012727,240.058927,212.970375,117.526459,99.892105,91.714264,61.951312,-57.469991,-96.303819,-14.525024,83.72753,66.066983,-3.4302,-10.030017,-35.500214,-99.44944,-256.709434,-272.667771,-231.572122,-211.256156,-261.045385,-352.88302,-362.535006,-370.449987,-353.95251,-224.064964,-63.876471,3.123016,99.238104,127.788088,203.854917,246.55924,235.729618,133.501922,85.862059,2.765939,-23.800259,-32.876022,-34.953085,-95.405078,-136.907622,-124.024929,3.434904,66.392219,167.961048,202.979319,163.895807,65.834252,-137.710052,-49.052196,52.513688,100.463175,72.270972,46.011215,38.209775,-26.349664,-86.392956,-166.971268,-64.066403,43.69717,274.481954,374.430065,508.348235,503.285109,305.912689,109.324578,58.202698,16.547696,28.30004,48.783477,24.978531,-55.788023,-73.97005,-45.149978,6.08578,33.700819,106.23948,128.217936,69.644047,-1.399397,-113.008188,-101.476149,-67.134616,45.746923,123.354367,197.650919,149.140574,-35.589048,-103.503734,-121.522514,-40.490045,42.148455,260.672966,302.589894,184.036265,90.089081,-94.374544,-181.063025,-145.487958,36.536389,106.11822,49.217656,-21.584584,-88.890969,-120.980538,-187.5097,-29.58895,119.7123,320.855359,338.09327,312.221843,288.061959,189.540827,181.268822,218.241244,231.453867,220.223503,226.316054,208.460804,88.010658,48.019934,88.633685,129.241813,137.157277,173.088499,181.367902,123.215189,48.394271,-105.26731,-101.665553,-66.128313,6.698472,56.072125,142.644401,145.686929,64.583041,24.133664,51.909207,198.350148,292.090845,428.302028,402.043672,232.611326,190.363344,201.586571,235.586084,277.181997,406.966029,457.250902,455.812603,416.858362,284.023621,193.961543,110.748442,229.238779,294.144225,302.529612,238.357159,56.395117,-19.026592,-90.490359,-50.230148,-6.259958,81.739084,114.307532,153.770255,162.949942,101.306044,20.248504,-99.20204,-7.766836,72.513473,152.108445,136.526912,61.279106,38.025891,75.551075,170.561004,200.375096,255.218177,290.794262,300.101318,254.676474,112.269895,39.534187,-37.266078,42.099816,142.651957,360.624696,386.87537,183.513739,13.101631,-234.003135,-214.84892,-154.745739,-29.676489,46.787751,171.441952,172.700694,76.797579,36.264232,41.965609,53.656519,45.613631,108.329513,167.624486,154.429879,48.237417,-155.71233,-86.72888,-31.188896,0.719034,36.916219,133.402152,116.710336,-54.927114,-149.105412,-251.409137,-237.323896,-190.077869,-43.381228,13.04223,25.29189,-6.390067,-61.673379,-13.596089,40.864268,156.467199,188.659909,118.458432,34.694081,-86.968074,-101.925661,-78.999067,-34.377905,-7.454459,20.511101,-2.435208,-81.320064,-110.289695,-161.028419,-144.467631,-71.949286,169.99722,285.201457,373.574874,332.469678,150.540198,43.801011,-133.000668,-114.54493,-29.739169,114.488365,118.76933,23.896208,-38.393243,-147.182922,-152.538373,-122.635876,-75.771051,-65.461548,-56.654493,-57.498538,-126.93552,-202.35491,-320.935946,-318.818819,-285.455963,-190.545915,-149.484982,-103.408152,-110.731026,-164.917356,-121.025984,-48.156474,182.174691,318.189481,452.264528,420.295771,281.726812,221.146915,142.794393,147.315991,176.516381,215.859408,202.814573,140.325636,97.159322,-39.579238,-111.174703,-68.720519,108.575376,177.194978,208.810805,207.610551,170.917939,105.609396,-57.946889,-115.18437,-85.415785,25.255694,69.750427,179.867124,242.355911,239.930428,109.894002,61.093572,71.387029,112.558735,165.642605,174.825209,115.295337,24.361026,-147.192545,-181.437955,-154.239197,-19.446216,49.135143,68.323646,16.217196,-106.84418,-166.779644,-180.405866,-143.473744,-89.012846,-1.726168,12.378847,-3.330458,-36.078645,-60.76361,81.45626,156.279691,171.623407,123.149766,-3.702021,-67.249917,-175.163476,-160.395876,-89.857027,75.273684,129.346808,209.793574,262.607286,322.18341,287.669961,171.245152,166.34242,202.090231,239.063442,211.142036,91.463108,29.994744,-36.591288,-22.787346,13.479364,149.413904,203.215048,158.373099,84.501887,-54.173013,-105.460431,-152.545847,-96.471217,-34.215622,47.508219,15.773821,-142.585401,-208.4865,-261.758143,-206.143849,-150.128383,-36.613157,25.223247,127.984592,129.503024,23.969479,-45.94404,-117.296663,-90.818549,-50.560014,69.356389,98.7314,9.713695,-62.956297,-131.916153,-106.26469,-67.088078,47.021128,90.02686,92.920078,56.605714,-70.623357,-149.883214:-23.015799,100.694891,194.481645,382.145308,431.951225,354.59592,265.217172,173.018399,234.271803,259.774627,258.769953,240.169066,130.846782,49.907451,-74.611475,-95.053978,-20.704837,111.423974,137.47356,80.719829,19.491385,-163.877861,-285.977534,-465.663026,-389.387143,-277.81357,-103.467177,-95.942565,-210.817882,-287.690963,-424.472625,-440.490478,-263.238945,29.137294,144.645556,266.117665,261.962436,207.632476,185.740299,127.899873,100.972593,90.949051,24.950432,-4.673857,-22.974148,-58.863515,-265.31806,-377.008187,-373.317644,-73.661685,80.573442,246.773767,228.833448,32.194587,-90.935877,-286.986245,-246.748177,-127.040199,73.229853,81.631245,-39.701362,-125.007622,-314.068386,-407.595942,-469.102499,-268.069938,-91.158388,239.045263,312.560064,281.647895,209.179498,6.632435,-41.777988,13.851006,135.085335,157.158469,108.343907,43.736746,-157.603343,-253.433411,-240.866138,19.396195,138.674896,222.109595,197.580461,65.352154,-53.760453,-280.111077,-233.282709,-139.306139,32.893859,90.97997,87.664437,18.898893,-161.147739,-229.681029,-242.203112,-64.89968,68.698839,265.157203,261.594744,105.754039,2.451469,-223.631929,-315.159114,-269.627244,-90.694081,-25.857489,-56.173256,-124.763668,-292.079568,-364.533187,-305.116508,-16.237862,100.671083,196.7683,191.340439,112.014785,38.280743,-114.796772,-95.233446,-9.878009,171.64767,207.158688,132.44204,59.453761,-114.66895,-211.03417,-271.656044,-48.715032,100.312629,296.557461,302.284714,107.513596,-54.078274,-300.466937,-260.909051,-157.426638,76.549619,143.969236,95.785805,20.319976,-116.144241,-157.007408,-121.901285,120.944409,282.613571,463.626576,425.355083,197.782617,83.476422,-59.662893,-16.41889,74.066167,290.254839,358.26933,380.124121,362.024821,215.265359,82.330766,-76.176289,94.135657,236.680095,373.910813,327.436013,86.434517,-60.511892,-267.043143,-207.456954,-115.352502,79.924158,163.500372,193.288449,105.089428,-173.896609,-263.995334,-219.633086,-27.119438,69.030964,204.773015,220.882705,147.699575,73.241698,-37.580753,29.143238,104.238511,302.649442,411.584851,489.707961,403.790105,81.357966,-47.043519,-122.678003,-56.084057,40.302979,314.80384,390.11541,256.317828,98.249072,-144.107217,-104.584779,-16.424823,176.551886,268.778878,370.095034,335.770413,113.131505,15.742473,58.260043,230.748116,269.367236,295.721368,301.923852,212.196845,94.903724,-151.464126,-164.49836,-89.900856,93.536041,159.948551,140.949381,58.763852,-191.026522,-323.905514,-410.738648,-171.434655,3.835485,205.125623,160.833782,-44.5644,-113.112742,-198.841704,-194.127343,-119.206158,90.903142,158.593903,136.305462,55.910361,-139.597758,-199.688603,-162.561383,20.699739,110.746248,179.630594,146.446115,17.030693,-53.446424,-161.578966,-137.179179,-47.781614,230.559684,339.428135,358.885729,284.850396,74.20365,-16.538939,-88.077235,4.448504,92.874754,244.299297,278.142947,225.668762,107.866514,-225.8065,-304.368791,-208.135691,53.02745,136.136896,101.273319,5.860801,-196.173711,-275.455979,-353.509981,-257.967351,-152.817669,35.045178,68.246549,11.98959,-70.279383,-262.414718,-224.519946,-93.527363,269.437207,437.685633,536.035036,449.407766,196.0323,107.656059,55.973769,126.783955,205.766129,350.53922,349.739172,231.22401,160.890154,27.794366,-5.46343,53.987813,267.65108,337.601732,281.870366,200.242604,38.257095,-28.745835,-99.84011,-93.265104,-53.202988,88.125279,151.673957,202.763983,167.837915,25.237226,13.694725,65.919941,196.57887,245.634833,215.334912,133.34795,-62.822493,-140.124539,-201.545791,-130.489943,-46.458825,157.309338,198.050529,51.96094,-97.357679,-335.311221,-299.92786,-210.672254,-24.96306,46.472438,102.433093,75.752241,-73.976644,-157.738171,-175.453688,57.720199,201.353633,335.646299,298.406318,91.52752,-46.335418,-296.238158,-298.838218,-190.817148,86.520779,190.903573,300.288574,320.485513,251.817292,174.27878,91.621417,195.945443,294.411412,460.662541,454.61196,213.279355,52.673461,-149.792227,-97.948784,18.327687,302.479458,377.252932,273.052031,139.577759,-121.995269,-209.65371,-262.564398,-140.573875,-21.536133,164.103214,150.92544,-25.259704,-125.117222,-274.251545,-211.939913,-76.643067,229.131875,304.953057,272.059718,219.375718,93.698703,21.030922,-75.583303,-32.414888,42.89831,231.699488,274.9003,125.373281,-22.473468,-246.804115,-251.405717,-178.291386,17.446248,89.038149,93.624423,21.651957,-202.562693,-307.909639:-18.834446,44.604908,105.305066,166.694735,143.794338,95.267311,109.253407,154.930451,119.928826,68.538447,-22.225931,-31.71625,-36.678231,-70.856952,-141.387434,-135.150641,-80.155544,-129.459992,-177.362912,-164.284369,-109.625709,-59.934858,-92.559706,-185.717218,-217.900291,-215.662232,-194.553205,-195.321368,-243.720916,-253.704214,-202.971299,-175.827314,-128.817237,-48.207761,-7.286233,101.866825,180.749001,345.464192,385.272602,308.911551,148.50373,83.630214,21.156169,27.863826,61.859896,50.956361,-49.455543,-96.486433,-59.53008,65.449114,107.557602,181.020898,220.628065,260.56142,259.833376,244.845812,200.316478,174.703725,172.720271,182.942308,141.894371,116.002035,110.174497,96.573958,46.786999,107.9033,182.757809,335.278072,403.38061,446.04448,373.985434,127.500716,-32.831751,-64.982903,-51.107974,-26.128353,-23.329452,-53.364186,-178.997924,-246.876234,-203.202077,-1.320652,66.298032,152.853,162.437798,79.794236,16.825528,-90.451755,-119.252258,-111.209676,-44.819185,25.584517,120.739812,102.654402,8.263504,-29.060532,-71.93511,-34.001799,44.474288,251.871832,317.534889,294.034057,217.760815,25.276462,-97.565415,-107.198426,-94.735236,-112.973203,-146.90742,-135.586445,-187.229598,-285.956234,-395.358274,-192.433297,-55.395521,150.808527,218.838321,310.836258,327.820911,303.718302,258.743295,222.651312,174.939532,205.955043,334.96438,376.058699,382.623896,371.319248,333.900022,339.309858,383.321024,433.845983,387.71505,229.335097,159.86169,47.979726,-44.955757,-80.00497,-43.785927,33.894928,155.334382,165.237678,154.359179,141.77086,91.019995,145.288421,245.250363,398.065839,368.656694,202.346779,165.546712,248.055146,366.234457,378.376514,367.422505,391.644975,459.658352,458.389219,353.193945,283.993186,257.594357,358.703292,381.007146,303.537049,225.976869,89.316743,55.427857,-2.768044,-80.433507,-80.993894,19.883291,101.494372,241.295913,256.761882,148.420461,60.14408,-72.1118,-88.540616,-53.347558,64.419411,109.013122,119.398903,108.092317,143.308524,216.391183,221.381502,215.599076,244.125597,334.23636,360.811398,311.560355,234.564541,78.00173,43.263613,97.352026,282.218692,334.784017,259.838565,148.83399,-113.606889,-252.047557,-251.369244,-136.60225,-43.464361,82.911705,84.366556,29.521192,1.79653,-9.112902,31.595897,59.164785,124.2385,132.13683,20.546727,-88.102232,-268.176297,-213.537882,-131.120551,-42.403939,-46.824266,-89.724641,-114.617991,-171.988948,-214.621086,-314.0855,-349.031457,-330.360852,-232.87143,-168.655808,-92.142416,-94.926499,-115.23918,-64.949769,-29.609569,45.372372,86.283787,103.860097,82.113402,34.596389,-5.931307,-90.362797,-88.148001,-94.410477,-189.982806,-225.645777,-139.153835,-75.0374,-114.158366,-173.220747,-98.021913,153.274927,237.095804,234.219296,178.778735,56.547946,-14.095994,-197.278154,-268.436079,-214.092253,-43.336489,-1.316578,-88.648792,-184.733014,-338.291107,-320.111618,-264.739983,-198.507152,-189.764503,-128.809638,-82.266927,-93.729945,-167.831017,-280.418568,-264.280806,-255.747838,-220.307672,-170.529801,-69.790677,-53.087155,-81.883365,-96.361154,-62.925743,126.767056,261.430025,391.02732,334.251145,148.529798,88.836849,24.54502,35.311652,71.879087,136.273285,147.629843,160.272845,139.58437,-46.49253,-202.577291,-165.508761,15.510992,63.837219,62.565634,61.614274,56.05414,19.111471,-103.430083,-205.050806,-239.355378,-206.363468,-121.426538,129.339304,253.804251,353.995168,174.79094,52.690293,-28.158437,25.822888,142.478758,142.999351,22.276103,-73.291496,-246.152268,-292.668795,-244.838217,-47.113453,46.526746,141.395866,145.601218,65.402039,-103.903522,-185.962451,-234.002025,-188.194228,-57.377694,-10.420054,-27.81682,-107.771655,-279.374648,-207.781695,-90.149073,83.655051,76.563377,-107.89595,-208.495745,-241.535418,-94.008131,-37.990071,-13.342579,-0.958071,91.296982,133.758828,99.156609,42.065117,4.614013,102.992616,122.454087,2.27227,-70.705371,-82.201253,-64.93076,-121.189066,-154.375125,-114.879311,7.395227,59.097511,103.754787,92.995131,3.874652,-67.840081,-184.320389,-163.725186,-101.997835,33.681186,38.728937,-145.060949,-261.450129,-350.378754,-290.369736,-226.677548,-36.177478,44.376215,78.685301,62.010295,30.546652,4.623638,-31.590932,11.1822,58.948406,154.320787,160.839726,72.684587,5.99896,-86.66999,-62.107469,-35.801308,30.966015,85.836159,172.037007,156.626146,-14.771922,-116.018695:90.730933,85.20502,134.149603,213.934645,208.3651,196.243489,223.966569,256.287227,192.53265,155.755702,124.126887,113.988823,15.885494,-64.513443,-163.767207,-158.942502,-104.113977,-54.362388,-23.431125,15.067867,-5.259385,-98.337914,-140.715327,-206.98969,-294.517035,-335.729461,-321.23208,-276.218588,-236.116175,-257.089773,-328.886688,-341.099942,-252.528568,-160.513292,-160.695011,-154.57903,-110.895022,69.537479,162.423432,190.606987,19.052496,-81.165488,-172.325621,-157.005604,-108.440169,-86.110308,-35.018339,-33.599768,-93.468306,-77.578158,-12.7697,94.931083,102.458277,114.066195,140.035234,154.747519,143.640277,155.18611,198.327999,225.046874,261.26467,261.933381,176.515529,83.028426,-33.136244,97.228524,187.268762,299.24296,330.311564,355.207935,322.156623,159.093763,35.963316,28.537056,69.031086,77.270669,40.788026,20.370342,-18.124218,-52.38985,-91.130777,-66.691948,-54.905004,18.655957,75.747315,126.557642,84.725773,-99.213345,-212.719728,-205.175458,-72.922006,23.256393,124.756244,106.80762,-0.548638,-68.503086,-166.017508,-111.313522,-34.502066,125.734512,159.291267,78.442454,-3.788341,-130.68957,-129.340871,-102.850655,-79.393057,-83.508973,-84.058179,-83.002219,-183.202028,-290.532652,-375.070117,-139.174363,-0.958638,151.067832,166.536638,123.977511,98.557194,87.795631,111.250114,130.239351,184.543003,212.715657,210.493022,187.579242,143.656361,119.027618,105.422721,162.272439,189.368434,160.445039,105.233201,59.952978,68.476334,9.535233,-35.905448,-13.703104,5.574331,-1.43203,58.443768,126.926366,216.313551,190.95749,90.034879,157.648485,247.000004,330.330266,290.308702,205.23298,214.535288,267.662874,293.204437,326.305352,462.237453,537.781884,593.904984,555.846368,372.808117,269.799673,199.92349,314.159784,368.058288,393.141428,367.906449,273.992314,215.28099,69.505899,-51.559262,-80.711971,-66.31429,-4.185435,163.598174,197.274511,114.713629,41.72187,-58.61604,-4.867676,72.612166,193.056634,187.661924,77.663124,45.5,100.401571,164.730039,175.090311,197.67645,205.987249,148.436617,96.209171,16.705798,-6.337245,-20.338681,14.339842,77.067331,284.99892,356.11775,296.453263,199.138591,20.262786,-119.610855,-177.667202,-162.779067,-79.693447,56.611886,58.676952,3.569525,-9.603641,21.173092,21.844488,6.762441,17.471357,41.204271,37.094582,-25.792131,-174.282793,-138.472578,-100.609486,-138.553969,-167.938823,-154.275452,-151.655417,-238.395996,-298.055033,-350.397963,-373.008965,-402.045075,-389.443905,-307.629129,-103.072329,-57.431481,-95.739937,-113.489922,-83.543655,-13.232233,1.17829,-13.617127,-11.233274,17.554325,-0.952884,-59.440892,11.471119,55.455218,7.147162,-66.136899,-152.954482,-156.068198,-158.498009,-122.644431,-54.008094,143.806583,220.925296,259.242574,240.951656,187.757943,147.282151,23.830672,-54.058544,-33.539991,37.047627,22.290766,-81.28205,-114.840592,-153.099876,-171.300612,-152.580334,-83.050668,-59.281133,-57.414137,-69.817715,-149.351997,-213.61615,-279.61755,-271.545979,-281.275897,-290.757644,-268.945491,-195.783801,-162.487207,-108.692417,-60.237855,-51.98227,-2.397874,65.708898,165.785929,160.56408,96.401324,58.521229,17.327138,34.240043,54.34777,105.934592,114.426874,58.7688,-0.853924,-149.646664,-225.194245,-197.788564,-27.659436,64.809856,156.705779,170.915412,175.099802,144.239276,10.105799,-110.897153,-135.64586,-79.120776,-1.933315,163.675826,199.626893,136.670442,48.810015,39.180132,66.217292,87.20158,112.537944,112.425745,74.428136,38.20185,-23.301495,-46.490634,-22.370107,113.828112,177.667767,217.370088,207.586615,145.805823,11.56987,-67.959368,-143.866154,-106.832497,48.473437,106.766232,80.298168,7.831098,-79.645359,22.390416,105.844708,178.476945,127.116768,-44.788103,-101.99649,-160.802174,-148.492936,-115.104411,-26.818439,39.257979,168.487161,194.000685,175.55316,151.22894,100.425492,60.941698,62.356131,83.67274,55.922207,-53.879415,-84.517897,-62.992853,3.849392,19.468544,63.448017,124.881227,214.39379,191.543743,79.634291,39.717692,-23.038384,-70.413668,-41.667038,52.351971,35.542904,-153.425583,-251.026178,-322.043893,-245.705899,-168.304825,24.107615,100.319448,129.827151,91.113488,-15.6488,-60.565099,-99.082172,-48.833963,14.605168,186.5266,236.278854,173.275349,99.917089,-21.174144,-51.898546,-14.069935,141.35056,220.832152,323.255132,331.148027,199.586033,70.589266:-4.291575,90.457301,125.128148,222.563709,296.790803,330.195685,266.465792,176.603812,220.812085,212.888087,148.648147,139.881611,113.188143,66.480716,-47.473516,-94.457965,-118.083962,-52.077341,-20.129594,6.763152,-10.226918,-134.091263,-204.337535,-229.945893,-158.649419,-133.911889,-120.46045,-141.633571,-202.081303,-200.463916,-169.536007,-178.961628,-168.383864,4.884373,126.584142,296.271505,319.184647,350.326775,369.292015,319.848392,215.362515,169.386701,74.548062,34.635299,-17.762146,-49.881877,-136.839083,-168.123041,-154.542738,-9.454998,102.960954,278.751936,285.838504,199.314342,160.730931,102.309618,76.894491,93.674843,125.099241,101.290017,21.346468,6.718249,-60.127299,-146.716714,-248.317797,-94.58512,36.830184,269.920825,348.301783,421.354245,374.441264,107.893225,-100.693024,-128.008864,-129.809933,-111.179161,-15.201164,2.036591,-130.617013,-207.445314,-186.01015,-38.762168,29.778028,150.727362,173.936306,79.801512,-16.616459,-183.129444,-132.566007,-58.075526,29.913014,53.650069,85.751604,75.905382,7.853296,-18.471489,28.967256,178.460279,242.5485,295.402843,285.257496,241.714352,207.302939,32.374646,-186.605413,-218.928967,-92.439234,-8.442176,47.291214,17.933378,-144.700278,-237.766907,-261.791201,-126.725658,-63.159513,85.187274,158.151272,196.812771,159.567986,52.173076,70.73565,152.173082,284.747138,267.373653,137.237064,90.641459,40.34256,1.78728,-62.455239,75.210666,210.165016,355.321438,302.743446,84.480456,-10.547023,-129.451915,-115.062879,-87.235164,8.074238,89.017367,124.432926,39.803265,-129.647561,-160.910647,-111.341777,84.90607,168.249218,213.300935,213.32483,201.838767,173.382028,106.183147,98.739314,127.224652,289.66985,395.421243,455.433165,400.309705,257.94073,195.909738,160.416732,268.426785,306.544758,292.674154,252.447731,111.988806,29.293366,-89.540015,-80.382183,-47.579782,0.517855,35.074394,135.498037,151.881417,32.154133,-78.369585,-202.199068,-78.585739,4.748214,128.125283,161.929561,130.347177,91.20746,86.937195,135.980258,158.346077,294.049396,404.45756,519.774991,480.393685,294.301201,199.209344,112.006596,170.807836,222.510387,313.489885,316.122577,223.577711,150.202455,-57.035647,-203.672794,-179.902237,-16.055962,64.682509,179.454777,207.690348,143.303514,72.843258,24.135278,95.785098,128.514586,132.582098,90.271434,-27.964347,-70.583422,-126.685143,-138.030639,-111.684918,-30.782936,-2.726414,24.649723,22.163833,-72.991052,-162.787598,-280.005987,-217.184701,-156.039216,-51.714689,-9.300494,52.888082,39.280293,-87.602423,-89.723968,-4.912147,173.793128,204.532112,119.212309,56.156431,-17.071386,-71.555987,-233.099536,-228.333199,-156.12072,-27.430699,-15.648502,-59.100615,-85.050361,-193.599674,-297.54489,-264.137626,-31.965498,103.579799,221.995404,173.599959,-2.378364,-76.01728,-172.088764,-175.358449,-125.090763,17.325918,45.524758,-13.474197,-65.678565,-185.137818,-261.640006,-245.742157,-131.226575,-69.553252,-22.088626,-50.004969,-191.805457,-272.456857,-341.099698,-270.977353,-215.481417,-119.762058,-81.014077,-11.392262,1.416062,-32.445178,-23.143856,26.428988,193.09493,287.502949,378.851076,354.995885,261.116007,220.167593,162.914572,189.415502,222.068473,234.89574,207.416747,157.457625,137.79556,15.707759,-111.45524,-108.726971,-9.50954,40.221909,82.584318,111.37466,177.468284,144.001257,-60.864233,-168.481417,-116.124025,85.693642,145.481166,165.011775,170.257815,143.969207,62.778529,44.108049,98.825174,149.531368,148.969548,89.853197,-59.678108,-136.896703,-238.134781,-219.53502,-179.333181,-61.924261,-11.835479,10.244295,-21.396068,-148.536233,-209.723533,-179.690676,-63.437344,-15.801232,-40.675967,-99.811117,-173.715268,-179.149376,-157.93074,-15.080356,79.212802,137.102574,97.967669,-8.348942,-77.862402,-256.328607,-255.808677,-155.365881,117.861462,224.56347,250.883706,202.528915,101.514686,59.805228,56.296012,147.145131,192.846803,184.250567,112.813522,-18.751211,-45.034344,-91.586815,-109.956921,-80.962014,25.769483,64.953791,19.883179,-55.643213,-217.621382,-281.685828,-324.973625,-200.27059,-104.414584,5.580691,-3.003855,-95.645067,-159.492347,-256.172294,-155.58012,-56.603124,63.043853,81.895928,102.351683,95.385047,-17.894699,-98.559338,-153.107237,-68.377134,-9.588357,80.076451,71.375103,-51.133701,-112.889841,-156.529697,-105.314963,-71.765715,17.766737,76.208816,81.942409,-5.4892,-212.242659,-261.213263:left
38.762723,-90.804584,-140.74614,-168.876926,-142.072699,-15.455243,49.394672,83.23427,34.006183,-7.110332,-85.27257,-97.621085,-118.287857,-143.281591,-180.683906,-183.772938,-164.715992,-146.308773,-132.854285,-82.103727,-68.420788,-41.13603,5.853847,102.360785,78.735611,28.533125,-64.850045,-85.422194,-96.938865,-92.624357,-29.926282,14.16065,62.914941,9.175066,-52.169977,-119.228825,-109.251058,-65.092956,-44.722683,-14.115905,-32.394797,-45.596096,-13.629137,17.379592,11.081177,-22.030224,-51.473845,-29.682218,33.338412,51.961816,69.56759,121.190989,130.443098,141.547503,154.736235,114.90795,-11.871661,-58.253114,-116.853856,-136.42527,-140.252535,-134.975123,-123.480792,-99.125934,-23.524813,-45.177077,-90.12559,-107.926431,-51.253559,132.087778,192.041756,183.838966,114.34387,85.363707,79.297465,113.034394,186.920348,189.080842,141.333479,108.68444,36.117934,-56.773785,-92.928756,-66.693633,-15.848934,93.544714,131.542946,92.79431,-43.054887,-83.472881,-105.283751,-108.615935,-86.050016,-47.734927,49.214068,85.771434,112.407481,71.1412,58.498965,101.677618,132.093576,155.311118,143.898225,59.49301,-29.763964,-23.28478,27.708043,0.64062,-108.541428,-83.573226,124.651489,200.216297,227.081649,159.522629,89.731716,21.246479,90.344401,337.237982,411.321134,352.964928,197.968091,150.247053,115.655273,126.183477,199.839292,249.016168,274.064495,221.962657,65.554596,-41.447595,-48.701214,14.840855,44.454249,96.053211,132.222408,183.358233,189.712882,147.388377,-41.136332,-102.222688,-20.857914,59.470314,65.191389,-10.711374,-102.86236,-51.662377,-42.86422,-111.194255,-153.910212,-112.406229,-28.286826,79.859507,-60.651637,-177.54024,-266.449324,-209.495808,-41.562471,20.934003,128.709999,169.661667,161.062689,57.556544,-1.731026,-21.046585,48.354309,237.081786,271.304245,123.34364,-77.611799,-109.77572,-64.06069,-34.411717,-84.355298,-136.511797,-139.238738,-107.30353,-34.604056,53.527028,73.595441,89.003163,92.235661,69.432765,62.332987,81.07812,87.745434,64.517721,-39.890967,-90.643109,-128.405295,-136.330316,-174.931767,-181.704752,-132.733532,-141.797396,-187.719007,-216.280995,-183.176795,-91.092113,-53.618202,-46.06499,-117.288697,-165.390883,-226.348716,-208.116552,-100.920559,-29.115648,100.47112,102.731126,-11.951543,-73.56129,-78.385231,-102.741093,-125.896623,-193.567366,-215.066143,-141.256882,44.844874,105.291404,131.271561,144.934292,215.252661,255.285552,327.574971,340.321915,210.535455,-73.987649,-163.546289,-144.409254,-81.460422,38.570495,69.763298,43.163995,-15.115133,-33.55467,-52.247306,-38.392523,25.075688,70.917268,164.979997,167.995889,45.770423,-115.13589,-149.097232,-112.332463,-80.607316,-11.940831,40.468974,129.915651,123.145887,88.028332,-8.879189,-34.217588,46.272597,115.087232,88.552339,-10.14959,-161.190657,-136.795623,-92.521633,-41.256968,-29.179827,63.083028,116.483625,78.248856,-35.901052,-73.631207,-171.645585,-209.739056,-163.140936,-96.475316,-41.744127,-82.582458,-223.944952,-366.946273,-417.032865,-433.507553,-387.160427,-210.830686,-123.859069,-23.935652,0.28197,-3.359988,-1.198161,1.467852,25.124419,85.055369,236.244929,253.287088,193.789981,189.80647,193.029803,127.214381,80.771095,63.569128,92.28361,106.566897,-4.994306,-85.255636,-196.591445,-198.288526,-111.116435,-51.549366,9.779694,0.997407,0.440218,31.317772,27.995493,21.392037,17.061658,25.139567,61.504463,124.361369,88.878917,47.89993,-12.954623,-10.086875,31.216004,58.646859,98.384042,90.092658,107.294186,238.177567,258.359652,131.18478,57.504526,73.157777,157.983737,297.69807,203.041245,87.496966,-74.671272,-79.295486,-46.172301,-53.825669,-138.653581,-207.930808,-320.76531,-360.449171,-355.508104,-246.69749,-124.279748,135.522095,175.905014,27.519939,-152.93353,-195.930385,-195.666791,-147.023547,-8.827418,31.632207,-28.545618,-120.470394,-281.852726,-287.199992,-254.762638,-147.92203,-72.497345,74.848912,111.129878,37.038565,-89.447656,-110.358755,-143.352244,-183.926965,-255.195939,-247.644589,-130.571118,-64.753245,-34.836396,-154.907585,-199.026526,-125.580928,-40.386358,83.74357,96.309836,71.977472,3.86742,-59.42316,-158.236515,-159.006199,-107.824007,-90.579088,-101.324616,-123.871439,-160.838798,-153.803373,-127.947595,-12.022884,48.274756,77.380333,56.263629,21.852309,-54.541056,-149.139401,-320.881561,-318.979275,-212.078975,-178.106487,-145.715115,-127.403209:75.492148,-17.254306,-63.58363,-76.014716,-36.363502,103.353849,149.758777,93.002962,-28.495651,-62.377607,-109.783899,-128.097502,-87.758623,-31.59547,-20.563381,-99.019531,-225.196149,-146.351792,-58.77721,68.737953,41.569516,-59.006196,-29.752975,76.570181,45.95094,10.711788,-19.933642,-7.823724,37.073396,58.643309,85.245813,97.105679,138.966483,64.603616,-15.280057,-84.747625,-77.665034,-51.736575,-31.421068,-19.806936,-92.193465,-122.599257,-113.722802,-89.195801,-20.956647,19.393367,57.877797,48.000098,6.116711,1.012948,40.378111,128.086769,126.711379,113.012203,147.03578,151.934273,-27.980045,-104.667142,-120.624473,-83.425425,-40.238304,-54.183344,-82.36615,-78.937002,-125.723795,-225.201943,-223.991379,-95.512188,9.353988,228.033047,267.534188,134.166197,-3.907265,1.899203,118.019028,179.562823,237.495919,243.648341,210.733057,151.517988,-23.460485,-119.220741,-107.39446,-26.450114,17.48228,102.35359,124.966243,68.571492,-31.881682,-66.374903,-88.66622,-68.84208,1.361276,19.453261,-18.024604,-35.100115,-2.139005,-35.687611,-78.941817,-78.986179,-43.281556,19.776212,29.255597,-12.277175,-61.965953,-73.895389,-74.851235,-82.872109,-113.14656,-91.880846,11.695274,47.813951,44.187516,-61.215186,-106.41266,-27.577747,86.879186,293.175307,314.825041,180.505662,29.538798,-3.539553,-13.433972,3.937153,83.696441,134.160184,179.572206,168.79352,116.013696,-64.790294,-174.710874,-180.723277,-65.98223,159.744645,198.46782,190.33409,175.246144,125.881294,-1.076519,-15.048804,41.238058,63.882921,10.322413,-52.178986,-120.733961,-102.334293,-105.566115,-175.210404,-211.652696,-185.051391,-139.567493,-71.326841,-114.272084,-198.398824,-351.180009,-357.609886,-229.386286,-119.556043,66.791013,69.453768,-88.24688,-230.212961,-263.795864,-230.316224,-155.805476,28.02777,67.682523,-38.708276,-238.804437,-292.931218,-236.371475,-165.762965,-105.723358,-126.859961,-188.115712,-204.869383,-164.9482,-117.734255,-125.764516,-100.268107,-54.287234,-14.962761,-35.643359,-46.08202,-20.103571,-56.595776,-158.383164,-141.819248,-27.334434,-11.254532,-67.640431,-94.712891,-129.359187,-166.877465,-193.074,-246.525106,-247.20731,-138.989577,-60.050016,-24.708911,-178.02219,-255.257761,-270.648325,-211.264021,-42.622833,39.938898,104.272413,67.140936,-42.512014,-105.089009,-118.822764,-83.990282,-63.490951,-115.298257,-171.43887,-194.436583,-27.397565,59.431658,128.814046,126.648943,141.68074,186.284802,267.140112,250.75865,97.155583,-102.303438,-159.060398,-141.064313,-94.080457,-1.984727,20.531615,11.578967,-4.904005,-12.880323,-81.949614,-120.702897,-66.52912,17.087417,94.62378,49.198811,-103.375865,-221.102838,-263.83426,-276.198077,-211.792718,-38.034966,0.317327,42.13103,108.680374,110.353175,98.786016,125.073004,200.346712,211.90385,145.701674,93.784609,55.240591,53.907409,22.128379,-59.290694,-37.231873,138.332299,173.699841,46.022925,-45.173641,-65.705318,-143.621196,-157.424535,-44.493125,39.43794,115.563723,98.835955,14.368737,-110.527138,-171.038936,-201.829661,-164.95293,-33.326126,24.188465,55.753133,68.169613,100.891643,178.287615,199.585461,201.425624,187.755721,130.107957,116.751589,203.228757,293.783154,290.462112,236.068239,213.011641,215.183687,230.202575,218.602822,104.246349,14.92782,-76.176502,-39.432837,76.294095,93.357696,41.274589,9.636679,-13.065853,-22.029403,-31.494094,25.677905,105.414042,252.488873,294.54721,313.777379,181.500436,91.459647,24.677477,52.497157,111.94606,124.096838,146.811917,166.426655,217.53651,239.506717,234.203137,221.88827,217.168565,239.804167,276.712768,351.964673,323.102388,257.430261,116.250707,77.224795,76.878422,94.614883,81.836125,45.923232,-48.809425,-163.487325,-187.905334,-72.184587,53.288505,272.179972,277.554606,61.576595,-133.44254,-165.167001,-139.468356,-88.839149,20.56162,42.23107,8.612973,-30.684141,-124.039638,-165.992572,-140.430267,-55.365783,-7.223046,105.251994,116.599911,-22.133143,-150.518629,-174.664701,-243.11028,-263.885617,-170.666339,-90.631554,-15.625126,-22.554827,-79.941411,-206.915259,-260.954176,-277.902668,-230.227954,-20.22338,61.926085,0.501566,-118.947336,-116.403241,-51.141181,-43.098114,-96.706444,-116.038557,-108.290289,-102.557658,-114.756587,-127.421726,-106.232205,-5.506415,42.80528,74.853369,63.081936,43.707429,-1.199841,-73.367975,-223.852474,-231.902987,-141.040397,-124.946234,-211.663988,-255.671906:83.247106,-20.988753,-85.544679,-109.640965,-55.632946,119.373881,176.596774,137.828645,28.160963,-4.287949,-42.162588,-64.778877,-68.959993,-41.392662,-60.946188,-131.400477,-242.17977,-186.292008,-117.199899,-13.525031,4.229172,80.983652,138.093969,143.636661,23.337501,-10.427303,51.099498,109.812808,170.775077,173.390457,176.256808,192.284283,211.454554,91.295108,5.887663,-115.940813,-151.066806,-146.149522,-111.659109,-91.309555,-199.957915,-248.601009,-206.872434,-141.083205,-74.942019,-62.73493,37.936113,97.469561,94.08293,-9.586381,-32.91772,-17.325146,-3.547056,50.325807,77.801879,35.123114,-130.459729,-209.547604,-209.168439,-129.1739,-21.357752,-42.501273,-101.745394,-82.072726,-37.258023,-130.960101,-151.012713,16.059774,143.480302,269.706898,241.075463,82.901632,0.990938,19.417903,68.306302,82.150453,159.804366,210.201436,210.380054,178.195796,163.408612,84.801896,12.155326,-36.681265,12.002792,165.118873,187.849499,22.628497,-215.006339,-264.058188,-198.121329,-134.826456,-63.690609,-69.279851,-115.322293,-119.085688,-107.705514,-164.322298,-185.020906,-146.176706,-108.525271,-49.092049,-30.021508,-10.19204,-27.604352,-58.893852,-132.713575,-145.749114,-80.247855,-17.727276,32.896595,4.07092,-73.70815,-127.067923,-137.275481,-75.190738,6.157172,179.296938,219.381204,185.204486,105.536998,78.900923,65.702699,98.478575,184.525013,193.856234,155.066017,128.903929,67.322111,-40.094037,-83.73216,-49.541062,38.671304,233.570608,265.046832,222.661595,217.989538,202.188525,131.56697,128.428885,151.60331,122.624816,-50.762839,-158.137498,-275.827134,-266.362657,-249.060235,-237.226039,-252.817251,-304.139283,-334.010874,-346.398341,-346.208372,-402.391208,-503.259883,-470.908813,-310.426581,-243.273241,-177.969551,-186.225191,-242.17665,-267.176663,-262.44009,-214.459317,-180.70361,-115.062337,-97.603175,-148.841227,-253.454465,-261.364029,-168.789486,-118.97007,-92.101911,-113.136969,-208.348778,-256.619172,-277.150905,-273.821182,-290.68259,-238.451849,-145.207987,-4.695537,-30.536802,-192.802743,-233.579841,-211.325504,-215.029825,-218.739711,-132.455101,-82.918738,-110.903897,-169.30965,-225.918784,-193.193559,-197.246269,-243.54698,-224.402964,-67.262826,-17.242271,-62.315722,-100.969975,-93.177937,-32.346939,12.120807,80.979124,99.861706,66.776482,0.105614,-150.721952,-218.957284,-208.854587,-131.378493,-101.815532,-123.417456,-160.416815,-168.311154,-111.110168,-108.287068,-85.110009,-31.609655,118.013963,167.89479,126.966782,69.729368,-24.695932,-138.669349,-177.721102,-134.052551,-66.802956,77.501267,113.205215,78.583389,6.578144,-21.055841,-59.963461,-50.637381,33.806293,63.80517,-9.077036,-106.438377,-279.130522,-282.889755,-260.444668,-275.524958,-246.333142,5.028839,129.670519,198.307086,184.20929,189.816194,198.93412,197.053878,223.446471,248.53602,209.744479,142.218374,66.171492,88.163865,92.485725,100.570067,129.574492,224.455766,243.992316,172.995434,84.399753,31.692738,-62.141635,-47.171791,88.57473,160.690056,220.179769,193.891296,73.651185,-69.349252,-116.639327,-95.237255,-51.766608,60.12761,126.177846,191.848272,160.309427,158.644063,225.949496,251.419672,248.974058,252.190246,274.178482,287.666998,342.724969,343.334819,311.112641,288.707685,286.913799,216.158159,168.693512,145.107004,146.543186,90.225139,-40.76979,-39.736229,20.994882,6.732004,-104.276174,-132.222201,-74.146643,-48.828874,-67.095997,8.517699,134.48993,365.082038,387.830728,300.841528,184.79025,139.450515,127.530059,149.030223,152.791795,138.889607,142.869845,152.946004,142.706057,112.446509,98.141986,97.364589,126.187844,209.687597,239.568633,288.45086,285.654237,231.212796,98.183019,64.389771,99.738193,144.043817,125.378666,60.087098,-34.795315,-96.807647,-117.250776,-42.125866,57.800378,222.707985,198.085129,5.141577,-44.984611,-24.411562,-19.061673,-20.539611,-3.96032,-11.180724,-41.142337,-35.180552,-30.048296,-60.291019,-46.667264,20.892377,60.709033,137.668142,137.228333,22.915083,-90.812275,-101.173636,-78.096549,-90.657646,-162.426954,-153.866557,-9.379112,45.743434,-19.782449,-193.038444,-229.234543,-147.358254,-69.680749,65.040757,77.37171,-45.783144,-161.621369,-158.974604,-33.711236,42.612024,102.445058,100.273979,53.582635,4.164015,-77.792962,-100.858796,-65.347529,121.513648,209.833181,245.325653,194.255697,28.547141,-122.864255,-170.723255,-142.962838,-72.18739,-3.866018,-73.556209,-285.74136,-316.930411:142.259319,0.526756,-71.251514,-106.716296,-66.494765,82.857098,143.174091,94.37888,10.272382,12.93559,2.363594,-20.584454,-66.096086,-92.342583,-164.512992,-197.562373,-211.337558,-182.268587,-168.032715,-143.204532,-143.298656,-99.471221,-31.984005,74.116353,62.172192,27.13748,-38.62021,-29.707,72.501696,118.91004,138.723952,130.092287,136.232356,91.677403,23.778567,-109.370218,-152.769042,-158.157752,-121.069141,-82.172522,-145.79929,-170.79002,-162.382617,-161.061615,-172.727433,-139.505805,-23.842997,-9.921129,-70.520778,-34.120576,28.051075,88.654974,73.243866,89.733959,148.435318,233.124376,95.030695,-18.802717,-134.425154,-131.986186,-110.158753,-87.448535,16.395698,62.047037,44.051646,-46.082919,-50.591143,64.214522,149.25959,268.998573,269.686465,171.042463,73.2655,30.699128,-31.151029,-13.048123,141.033772,232.384485,284.432319,235.348321,126.621892,60.105008,26.446799,18.269088,63.338855,166.331043,168.913754,74.144641,-47.971231,-111.294339,-190.55956,-170.690498,-41.4668,10.241618,22.443133,10.06484,4.231734,9.839812,31.387884,146.427496,210.538057,246.077598,217.017083,157.954389,158.567951,134.434919,-0.917097,-55.895672,-39.133213,21.479829,134.798389,139.648385,34.925265,-134.105521,-196.279424,-173.627721,-83.257869,149.671957,229.513612,249.124041,157.829389,114.173176,99.364697,113.279613,113.357049,127.943328,221.470511,230.745155,75.828403,-141.120915,-188.841808,-93.326096,11.556169,205.250266,261.230334,317.198046,351.955374,310.575131,144.682734,109.405753,161.857403,172.027106,53.391622,-36.427108,-109.408975,-35.276884,-6.657854,-34.366885,-71.148257,-85.900174,-61.841767,-61.913973,-199.350942,-296.859335,-394.599639,-352.927272,-169.510985,-76.410385,50.063923,69.712895,60.285222,7.450536,-32.725932,-51.980301,-25.305779,59.838963,92.995511,37.404594,-153.163712,-227.424524,-232.844349,-177.003199,-92.329104,-101.076324,-165.842313,-177.465294,-128.920878,-131.899699,-167.810688,-159.492628,-99.261512,-5.989201,-5.844719,-44.426892,-84.536388,-108.264481,-126.294968,-108.435034,-88.039592,-107.678018,-122.403409,-93.101465,-57.916524,-160.84897,-226.954028,-246.741718,-178.511094,28.524063,94.286102,79.383331,-0.146257,-39.687084,-91.025994,-75.663588,16.116534,67.900767,101.494492,39.656115,-167.85846,-312.75223,-344.949438,-285.602754,-220.345787,-148.364889,-154.906019,-171.842307,-88.500387,-51.971784,-26.516229,11.324515,145.975966,193.351584,187.997175,152.647825,40.386557,-149.202921,-223.223066,-198.273781,-128.70384,-6.726498,27.065698,3.695629,-86.260308,-107.308293,-62.503619,-3.886988,103.510401,116.695246,52.11006,-3.119991,-88.38709,-157.94636,-203.734407,-216.58261,-146.200095,67.07311,145.561466,193.897974,158.5185,139.695731,145.61906,157.442187,173.247236,198.575889,209.60742,138.136371,-51.567751,-73.243169,-27.011722,65.509653,96.153073,159.320429,180.937727,156.29915,87.412437,21.313308,-161.288857,-199.258668,-60.277947,52.704368,147.703031,113.81153,-37.439981,-230.186275,-289.153349,-239.306526,-162.763767,0.552978,79.309133,152.310238,91.478486,69.408995,73.711289,69.213528,59.358232,88.099219,179.586634,202.378051,214.052891,206.944297,187.893415,158.272018,160.879148,185.285477,180.462526,120.277092,64.000256,25.49207,-94.816364,-136.693183,-112.301327,-67.458714,-3.745831,-5.233038,-34.118835,-51.851483,-49.364658,32.378769,82.275765,115.729936,128.952563,143.773339,34.353033,-30.355237,-70.64877,-60.811875,-83.349912,-98.894718,-26.360477,32.958251,68.798537,-37.557613,-117.526593,-164.462158,-108.786965,20.1637,47.151252,68.155154,45.354738,-20.008994,-176.126151,-202.67954,-144.248114,-109.464063,-113.959368,-137.702862,-164.519729,-227.575138,-268.077549,-214.168027,-92.981074,188.529456,242.86128,98.326873,-94.608176,-128.539514,-100.707181,-59.068971,-11.717038,-32.151617,-120.002595,-168.151169,-244.681538,-218.563207,-148.124446,35.497822,103.560631,144.242408,108.961709,-37.752028,-147.359343,-177.483543,-209.112133,-199.920533,-143.835792,-106.58783,-39.68805,-46.465841,-155.974748,-270.024578,-287.235357,-217.620131,-127.240514,97.28332,156.656207,97.665547,-49.873295,-129.617308,-243.820608,-231.900692,-114.209186,-72.180967,-111.609126,-168.282906,-195.782281,-87.346529,-20.748971,87.286152,100.323183,63.640841,53.339019,38.190585,-55.083958,-129.330149,-223.642018,-201.265826,-97.957182,-89.083593,-175.939136,-209.725199:-46.187691,-95.724643,-101.850806,-41.37918,19.461587,132.637755,166.569975,179.402503,83.917107,-0.125967,-77.041569,-45.812686,-1.264481,-19.000015,-70.554168,-86.848711,-130.149292,-191.649325,-190.822804,-137.516552,-100.448121,37.954264,109.371897,122.683786,29.323975,5.420919,25.350475,59.076892,174.114933,218.611934,181.109518,125.28441,48.149062,-8.041574,-45.860589,-127.689674,-154.703123,-131.435039,-110.574584,-150.950555,-225.906761,-243.664676,-235.961327,-219.793074,-156.473393,-86.024841,55.864819,67.011882,-7.568422,-91.019001,-92.971098,5.064283,57.903506,127.044913,143.651751,92.27988,-68.234343,-144.303448,-142.194681,-83.506332,-8.92677,8.456349,30.528298,21.948348,20.328627,18.6079,11.238074,115.25969,224.155845,408.344243,409.680273,182.678459,-12.868434,-13.049439,48.767789,73.282438,160.433293,218.958796,262.482975,232.251866,130.814797,59.552758,56.957089,108.510586,143.85806,175.058606,145.038286,1.4775,-166.334774,-223.220246,-198.901367,-125.121242,2.262963,15.413849,-24.665803,-38.8724,-28.922584,-68.512419,-93.889948,5.261125,108.922462,181.907383,131.53431,15.328815,-54.509901,-93.8722,-134.167873,-102.317512,30.700852,89.921681,112.590355,57.517401,-138.912029,-301.076979,-318.719692,-178.359452,-49.304473,168.349992,215.408138,184.111857,66.21489,30.494323,85.562195,144.880582,201.018799,205.769912,222.253913,205.697168,62.686951,-95.941455,-100.22244,16.49004,79.929396,198.334247,250.642046,308.87028,344.881716,331.977065,252.604661,223.694469,158.516353,103.069092,-15.01343,-64.105098,-129.879263,-150.182626,-146.636697,-139.763232,-156.330166,-204.31769,-215.933832,-236.391629,-320.991972,-395.506031,-473.478785,-424.803777,-211.541265,-101.456659,-6.092941,-34.907494,-123.589137,-168.072052,-164.455963,-87.55965,-40.13358,12.883456,4.865954,-102.514771,-285.116573,-347.377657,-280.214845,-174.354206,-37.820372,-43.918014,-134.789301,-180.357765,-227.78767,-318.589717,-357.681832,-235.92783,-108.255548,31.173525,10.753835,-101.953144,-175.18131,-192.678774,-194.511828,-186.301213,-175.628576,-149.135851,-48.648881,-12.418078,-27.014725,-124.159994,-159.580984,-132.683432,-61.335836,131.747592,174.800611,111.326006,57.61675,46.409691,15.853678,12.702068,83.866235,158.766774,211.193615,106.977719,-224.11554,-375.324802,-356.57364,-263.648772,-229.276434,-178.254141,-177.95229,-247.603362,-287.175898,-260.064721,-81.29892,38.788742,190.411214,207.308766,161.927576,102.599562,-81.898825,-265.257048,-289.527957,-166.049024,-70.04648,83.800988,114.873791,60.213348,-60.965317,-105.665968,-107.934736,-64.997059,59.390175,112.654709,125.135775,66.222302,-118.159307,-183.920784,-157.857954,-83.440381,-26.681235,111.234333,141.907628,125.911536,119.463359,127.933069,144.426329,161.746239,234.319796,265.772432,217.242843,142.918957,40.191812,31.99309,41.67324,97.293604,141.396832,238.139034,256.544243,158.558615,-14.019535,-76.573845,-81.425022,-28.683556,108.016068,184.277654,266.195689,220.366112,44.893605,-38.141786,-54.30548,-20.722876,53.755701,224.474063,269.148457,263.286836,223.623052,218.747627,209.864174,187.825566,169.863355,209.079181,304.771877,304.896351,226.782604,158.828961,163.062959,238.982231,278.526077,316.273247,290.024253,152.064808,53.47824,34.900097,-21.285481,-74.04668,-106.451144,-48.141628,73.988173,83.392265,27.924254,-63.943999,-84.502314,-1.692515,62.527106,124.12469,127.96131,97.243673,4.587951,-42.612598,-87.902017,-90.118922,-93.745094,-99.69924,-119.782721,-130.107326,-131.078393,-175.10731,-223.119628,-230.655055,-155.146018,30.519816,67.57783,39.553898,-30.22212,-90.570003,-203.699775,-209.645106,-105.42435,-56.143689,-108.909427,-168.484453,-193.771753,-213.772367,-236.600048,-171.589373,-62.887766,185.705479,228.880016,96.465589,-46.868336,-64.145179,-40.342674,-20.610665,3.110201,-2.962689,-58.268673,-97.349341,-146.054107,-91.696503,-7.935144,186.334471,231.873447,213.186406,178.901051,97.606717,26.302717,-13.691669,-81.25815,-78.081017,-4.321029,38.823792,67.429474,34.176501,-71.352545,-110.32847,-103.875924,-37.029848,51.018949,262.478803,278.149267,60.342816,-166.561879,-209.502221,-178.189381,-124.257299,-34.129508,-10.030055,22.405257,16.135155,-54.862021,-120.811682,-103.955464,35.214602,108.41937,169.27249,153.868921,45.372875,-98.509192,-162.245181,-233.937099,-210.867771,-88.047651,-53.466673,-101.074808,-137.617214:74.34721,-83.637906,-149.515018,-205.442444,-171.408094,-2.457081,71.075938,108.312939,139.636406,144.289393,46.904257,-3.990785,-13.087816,6.254863,-26.86333,-99.620054,-234.120805,-233.388916,-200.671909,-129.02559,-91.917892,9.616328,46.959791,17.787461,-26.179873,-27.218162,8.196097,35.013816,23.760413,7.123876,64.158501,109.361978,137.312249,65.584275,2.493516,-50.688702,-29.967276,-47.988768,-94.67918,-99.003624,5.421741,22.471113,-21.334083,-42.019748,-52.915836,-51.599247,-90.540333,-131.578168,-155.922236,-77.47042,-36.418372,28.565139,55.889999,124.16257,170.769565,205.272524,40.904301,-97.466257,-270.500598,-238.214743,-64.786768,-0.803535,49.115382,34.951088,-25.025222,5.499441,38.632137,74.26255,96.231882,180.021222,212.606534,171.968627,51.649398,13.08235,4.187109,24.221227,98.376878,133.1982,159.691342,139.489418,13.718843,-102.066172,-93.552035,21.937944,64.066399,72.763017,67.983592,41.520471,-28.165974,-70.841914,-165.907763,-189.980793,-93.234258,7.592465,158.297434,196.97583,256.921205,266.613859,263.441408,334.471825,390.983946,434.844304,425.266513,363.21415,234.862708,165.410801,59.219304,16.126599,-84.72985,-108.428261,5.241527,105.285869,185.445942,28.937649,-66.801727,-110.205325,-49.728528,119.20953,194.109749,283.222084,282.401131,270.453675,254.920059,250.021425,261.793715,274.036651,221.318968,149.464347,2.510651,-68.947943,-70.302273,-26.011711,2.49579,81.412567,145.273845,274.777413,305.805085,267.60356,178.085702,164.035231,183.444524,200.744954,157.461481,91.057458,45.889741,137.33489,154.578642,120.08621,100.366968,104.157095,122.035611,93.256606,-101.495196,-201.273393,-176.852759,-49.506882,154.080234,161.587233,123.16501,137.745729,225.257631,205.546374,131.790162,62.53639,130.705732,340.446554,368.703277,174.959391,-65.159241,-84.296363,12.156113,34.421618,-16.664079,-33.714409,-9.610738,3.286852,-23.505494,-96.416351,-97.930668,30.372699,104.762503,114.613582,63.701382,-31.47211,-62.479696,-77.479244,-122.385317,-134.487469,-134.152122,-124.266407,-84.414001,-51.63223,43.311331,40.408363,-27.432532,-122.370131,-103.095627,-4.611898,28.243897,22.163115,-29.245774,-63.509342,-139.538267,-149.03383,-58.671783,14.468125,78.89431,21.623143,-197.010886,-310.554148,-302.830835,-228.934568,-197.501867,-166.534468,-144.710357,-47.630607,26.923831,16.182339,1.355833,47.112549,203.803817,274.806706,350.042133,327.985197,118.149536,-120.193224,-176.769013,-176.810573,-132.683144,-5.527845,30.038438,-0.193009,-57.071472,-69.972579,-11.446349,63.517028,131.260886,98.235913,68.462207,92.350444,83.969865,-48.305029,-113.030939,-129.017351,-89.824129,2.776203,56.450891,177.313485,193.69982,137.254968,-11.938054,-46.892305,18.951316,75.629652,47.77967,-36.927232,-157.446499,-149.656428,-117.058951,-34.832845,-7.048175,10.157401,5.055347,-46.198798,-96.552504,-93.342693,-91.26195,-109.398249,-124.557017,-106.837438,-88.258326,-116.448899,-248.831595,-405.874252,-424.467496,-280.276354,-186.239725,-68.157404,-17.537167,74.446045,67.202343,31.734198,-6.701626,-7.800283,5.412101,40.754708,116.236611,110.413174,80.427085,131.886837,147.839638,111.198607,82.636023,78.563484,109.680586,179.526638,132.208468,42.6635,-142.219236,-178.258711,-176.487219,-163.489351,-85.975414,-28.813084,55.577113,47.936287,22.954235,-26.535257,-44.85887,-16.58515,16.745785,28.050692,11.444681,-3.933532,-69.538217,-93.288312,-107.296166,-114.915053,-96.582172,-56.68206,41.707094,19.631372,-57.005348,-186.188533,-195.812804,-134.248265,-90.37465,-30.046689,-48.017996,-100.822315,-207.620161,-215.185246,-195.069143,-187.408899,-148.571149,-153.689429,-248.474416,-365.923742,-408.149427,-355.165269,-237.22796,39.746312,100.689486,4.669399,-126.936722,-137.61167,-123.475433,-132.014638,-114.753008,-62.44492,-26.893094,-94.374497,-205.384774,-98.679874,-38.611189,15.620821,50.316219,138.343437,139.49843,24.334935,-45.801866,-29.837611,-31.715511,-96.247086,-231.743282,-220.385885,-109.418252,-102.043271,-219.040825,-294.488799,-252.91698,-107.4921,-53.362998,59.305939,109.059707,61.226315,-92.807397,-144.504794,-211.278488,-219.521157,-112.228466,-32.24724,-31.657575,-118.556386,-234.212638,-195.320109,-172.400098,-35.412054,84.464966,223.268538,190.719203,-0.557269,-165.859074,-222.997279,-300.957534,-296.764501,-228.127486,-207.515524,-205.86906,-189.230285:108.686022,-63.46361,-113.35977,-95.473087,-36.965762,111.149234,155.289167,120.262672,57.023283,49.375043,62.294831,78.383128,118.131272,124.626595,56.008167,-19.857046,-183.547292,-256.071933,-235.629279,-81.126269,12.195415,113.711685,116.613818,78.83068,0.148894,-42.181183,-4.689041,73.516265,163.499373,154.616059,151.222976,168.708969,141.69498,4.148044,-63.091681,-121.909767,-128.78816,-130.856789,-106.302971,-8.6595,-31.643896,-111.23171,-196.597443,-156.731544,-67.337601,-64.240803,-71.32098,-59.972144,-46.53793,-64.988253,-58.608568,24.631522,76.567369,169.172337,206.228528,165.963742,-52.510125,-169.89256,-250.80025,-192.067597,-5.417344,76.080075,187.263171,193.049635,115.560431,65.726263,89.085496,225.937789,304.419947,409.868696,406.019297,228.355647,0.206367,-45.102175,3.503089,54.960051,123.690175,143.900702,178.067685,176.064442,106.906809,-26.957504,-63.851108,49.978693,152.866123,252.332065,216.642299,25.950951,-164.728555,-213.381126,-179.749817,-114.407021,1.527267,21.168385,17.638743,31.19115,68.141099,20.735964,26.652672,197.140349,291.644712,316.997835,259.631505,155.387202,123.883333,90.479882,5.785755,5.03592,66.07925,87.765178,68.533258,20.020579,-144.189134,-335.210014,-367.541104,-208.191784,-83.48161,72.865496,103.742957,107.007444,62.909037,47.994334,61.23421,89.478368,203.533894,269.899551,291.906005,227.218342,36.095992,-128.881284,-169.471077,-94.31346,12.567199,240.030888,306.302672,355.791172,349.761157,292.840265,177.927678,194.030583,297.657772,301.5812,153.558692,63.646968,16.282846,53.2268,52.075462,27.740362,21.424374,45.187248,54.181775,-25.890991,-247.881374,-370.789491,-427.282646,-299.708012,80.994269,194.434193,179.999034,134.654306,101.221143,16.862447,-39.497158,-22.827874,58.08811,266.334244,321.019106,183.818024,-165.809186,-305.595053,-329.521689,-229.98526,-5.313253,65.238262,65.915155,1.230963,-152.069094,-243.060723,-245.65564,-139.098398,-68.686131,-36.007667,-79.275425,-194.93706,-242.852444,-244.137588,-228.947573,-204.271563,-148.403195,-131.478897,-105.931455,-96.587148,-77.85856,-79.164986,-97.542074,-117.740399,-98.930429,29.782667,123.472827,230.79511,141.193646,44.062155,-84.683839,-51.498215,119.922212,164.565565,60.392972,-59.056463,-289.162819,-437.26556,-466.41589,-389.253974,-301.231604,-151.745868,-138.619239,-205.690686,-242.900183,-244.027026,-188.489147,-107.404632,111.578335,189.732483,167.616482,71.505718,-162.855097,-305.012066,-313.937581,-187.067816,-85.739084,71.464302,97.428577,-9.017521,-201.502313,-213.598129,-0.405136,121.282932,189.084732,181.005413,152.400837,85.089883,-98.43582,-135.372625,-117.659563,-66.836126,-16.008408,138.896279,205.1741,221.919469,101.980527,37.852877,-22.233368,-14.813356,67.713674,138.364703,215.792944,156.989421,-76.920202,-165.160201,-115.326205,48.882097,109.279632,182.117774,185.569793,80.985596,-61.284409,-100.052433,-96.612884,-64.891233,49.430567,114.825859,145.3507,84.914962,-106.561849,-242.96,-249.357983,-133.372838,-66.219269,41.364605,109.786998,201.80691,108.101611,39.738847,8.334071,36.872049,108.817643,162.215902,284.992893,297.134031,182.119964,64.429252,64.385722,137.972047,168.816212,214.896886,226.847082,176.408689,52.470085,-14.753127,-104.828392,-120.146957,-98.225306,-53.641899,42.91944,53.386984,4.483304,-55.581943,-60.771916,-16.210198,-1.593623,6.420932,18.403012,9.997761,-75.481584,-126.290253,-167.5726,-152.530632,-137.974084,-144.88499,-137.646088,-133.585039,-149.729355,-228.672681,-279.300912,-292.635192,-250.581031,-117.621128,-59.876446,-55.780573,-172.449962,-229.792657,-291.100947,-287.440302,-176.85305,-82.371051,13.846998,-18.314938,-134.765815,-265.034325,-314.104543,-237.322754,-97.145323,196.558657,242.922293,109.879186,-58.336348,-112.375821,-165.758879,-143.098533,-17.28179,39.732525,28.863563,-43.350516,-166.609573,-134.89257,-70.412128,106.243243,188.781558,281.174658,259.904669,90.01407,-30.094196,-38.496409,-43.859332,-65.947692,-116.687273,-95.75158,2.86628,-5.476244,-141.633131,-180.141619,-137.970319,3.517329,100.992668,315.535891,367.15673,265.053846,44.603873,-46.008677,-154.089261,-177.620145,-135.476601,-58.397491,38.655042,-15.652747,-179.734121,-158.542835,-105.199851,17.130706,90.985668,206.89947,204.132031,52.741988,-88.53306,-119.046442,-185.93309,-214.35329,-187.99266,-153.481225,-144.319301,-158.81217:48.517529,-160.987323,-229.97514,-215.592445,-158.848309,-3.825912,77.341911,170.628162,187.70977,201.825745,218.629655,199.559718,102.631417,57.028857,10.916044,-27.796035,-140.678267,-170.226645,-168.787516,-157.951863,-113.063131,53.468382,115.228488,85.10378,-22.272293,-41.46007,-25.8707,-26.400655,-72.67509,-87.815768,-59.610777,-33.576201,30.267857,60.489462,46.553887,44.11958,59.462981,57.771784,38.447971,16.476834,126.71591,217.268161,291.682846,245.565074,93.66378,44.200446,16.045698,23.795214,85.810432,118.162067,100.017558,80.717718,89.037284,118.754601,145.690843,163.461865,23.276922,-75.801042,-201.417459,-195.205088,-67.815504,-7.689879,-39.695514,-109.794088,-169.994837,-100.173463,-59.391528,-28.176942,-34.905381,-5.576313,36.855002,65.328839,8.111205,-19.816,-44.966734,-11.109569,122.589653,156.324694,146.374931,143.787429,109.959605,34.459323,33.747148,95.57237,125.215433,174.653243,206.47157,240.556449,184.77127,138.201133,44.629682,18.319697,70.762014,138.429147,231.246883,243.642803,290.750498,323.163267,296.230953,245.623284,256.124087,301.226288,300.259719,211.969166,56.049093,-18.562941,-91.818541,-97.103405,-129.551441,-130.657803,2.91708,85.74832,85.178766,-74.507805,-132.904499,-115.312718,-61.678232,79.068431,168.082592,289.489382,306.44982,306.774451,315.011521,343.672756,387.954349,358.24065,276.793414,268.995081,263.943071,168.680534,106.779528,74.740617,100.035602,146.439448,174.446259,282.921412,369.968934,347.065003,187.729834,137.950564,197.098793,253.732813,275.390533,239.733577,222.449812,275.073554,242.811458,80.924709,43.285401,149.609163,224.280591,212.246065,26.469668,-49.739972,-40.084495,42.155385,192.624751,205.720023,188.224709,219.192522,333.255334,316.734867,236.061501,119.445306,148.524854,275.933054,292.151554,174.460515,14.132681,-16.759124,39.037687,81.33616,78.79846,49.953097,43.479015,72.543952,111.174241,60.561702,59.231736,168.654942,206.519831,139.678454,91.023308,82.537266,146.200616,162.768101,123.144103,81.210207,10.083355,7.009447,91.529318,135.198446,164.86475,174.159242,147.975041,20.985534,-51.155623,-123.791535,-100.956507,-16.767465,-32.142265,-75.035425,-163.598188,-177.201984,-95.053939,-29.837257,-9.112022,-81.461637,-239.320317,-236.303642,-207.070295,-163.73422,-140.131617,-71.791729,-37.032901,35.264,121.140647,143.795019,154.910574,183.312942,292.656296,339.097111,325.832442,258.227224,95.1294,-15.692335,-51.920894,-106.69664,-118.221968,-81.296051,-63.31299,-107.034272,-142.289797,-125.927775,-29.456106,29.327654,43.194088,13.38823,46.867406,89.434062,61.570576,-45.281376,-69.456017,-107.379291,-158.96619,-222.162419,-167.999742,0.473978,-5.938563,-59.593291,-97.888248,-58.809913,56.912131,90.017299,40.605421,-30.788855,-138.466819,-74.132801,-15.868778,34.346517,40.824335,87.915208,116.201094,97.159907,31.974833,15.809547,-32.487587,-85.517965,-189.002996,-190.774301,-114.825066,-106.878675,-279.16676,-530.669354,-552.12249,-302.987022,-126.121984,29.181968,22.491003,69.943985,149.655048,145.973674,106.148467,92.271681,52.623519,44.409232,110.101799,130.345654,-0.268063,-187.599564,-187.465255,7.314274,96.026502,106.554142,91.092766,143.904652,140.315654,71.582926,-89.024053,-128.478598,-127.373405,-120.36669,-117.724945,-103.919989,-61.414728,-35.71911,-40.300332,-113.130109,-146.209954,-131.861147,-117.349891,-113.420468,-52.054139,-28.024624,-74.657428,-95.440376,-52.904063,-40.692672,-95.662296,-125.028247,-133.659076,-168.817269,-222.128683,-325.831537,-350.134642,-300.792939,-227.106439,-131.072548,-151.578438,-162.496613,-188.763549,-217.025773,-273.658257,-261.044918,-162.703081,-143.602672,-193.415531,-255.612507,-281.679347,-232.300749,-136.735575,45.235862,67.394933,10.627189,-55.862551,-70.203934,-69.494058,-54.505767,-7.873239,6.086785,-14.572209,-26.220008,46.828348,106.185622,64.7314,-16.968543,-15.774153,-4.404016,4.471087,72.106351,108.038627,81.679793,-2.849673,-28.162061,-47.16407,-49.613161,-44.245642,-51.997501,-51.564364,23.187601,55.344528,90.835775,107.491671,176.016514,218.329877,209.381645,109.12449,95.283771,137.604856,139.757443,61.607714,30.567129,54.158419,58.222603,10.621903,60.684096,121.831247,217.892334,228.019008,164.077856,115.014502,40.353005,-7.458133,-51.255329,-152.16977,-153.092704,-108.684066,-129.777547,-172.967096,-139.959766:118.132141,-90.074048,-146.341702,-136.484958,-126.314355,-87.967321,-30.571405,88.392619,148.548957,160.278191,108.470835,47.112656,-53.782397,-66.009379,-64.006918,-76.533348,-136.542244,-155.132463,-103.216655,47.040507,72.915698,28.614027,22.34285,42.587449,-24.658552,-86.164927,-141.087924,-110.385726,-48.211168,-60.38742,-89.244653,-63.669747,32.624667,46.404997,15.352993,19.68111,59.216697,93.123671,72.91128,10.32794,63.871782,140.838483,250.800207,238.499454,62.097009,-42.001936,-97.82974,-46.681116,79.897868,96.51742,89.322969,140.775776,172.054798,197.740487,213.399872,185.034552,21.636332,-52.712302,-124.151673,-124.109303,-94.189311,-79.013385,-58.762831,-69.39396,-96.073242,-45.81846,-23.251844,-17.255488,-0.941072,79.356617,108.059526,105.908898,80.763436,78.54827,105.079696,133.408286,180.573718,171.19171,125.811826,121.974542,134.241955,87.989256,67.600499,137.174136,186.904933,218.884595,235.334534,281.551298,238.265962,178.173639,33.88113,-14.262231,1.678848,59.713213,183.983279,229.703849,303.911059,254.924507,191.246801,156.230302,187.455898,233.32405,220.706225,111.875446,-7.012419,-22.194339,-4.397946,-18.573681,-122.468849,-142.77796,-7.086291,92.276843,194.760493,77.351832,-27.962259,-84.408247,-2.705938,190.232537,227.792053,192.836453,174.304547,200.189284,230.728328,215.673948,179.965242,185.873026,219.350444,204.795715,110.007183,59.545723,64.162494,82.7378,76.506918,76.14482,110.947072,202.672028,227.640569,206.658793,91.729006,30.484451,-8.185024,6.567635,43.663414,57.631057,89.11217,98.117608,59.401015,-61.045539,-85.820006,-5.462987,64.274631,119.275948,9.61019,-58.350515,-48.222772,36.188366,142.400243,121.008175,104.373301,145.044559,223.959562,175.106801,112.847545,70.671271,113.47976,209.145189,209.969348,94.215578,-53.692781,-89.22138,-64.234861,-31.257264,-22.908845,-37.197193,5.695086,64.829105,148.576805,109.86701,101.245887,181.551424,216.956402,188.928171,158.44076,157.270216,229.336079,247.387251,165.708493,89.950382,-25.518521,-42.311241,19.199666,71.32802,134.74573,74.348788,-4.393421,-97.717924,-86.263381,-47.866789,-44.521716,-93.626624,-183.00894,-231.348195,-311.628175,-300.267045,-165.661231,-85.955703,-6.462086,-37.528203,-172.312933,-206.099094,-184.630933,-156.107049,-147.458855,-101.853668,-81.1918,-58.360083,2.049044,23.687389,47.428634,82.713435,171.725208,208.319037,276.536271,280.547853,150.247019,-37.235525,-85.062431,-111.452143,-113.592961,-73.393523,-28.724892,21.027762,-43.168482,-90.385973,-120.931389,-91.973664,-16.795159,8.303087,45.452489,60.025359,79.415517,50.139667,12.695729,-68.071188,-96.450923,-107.180274,-85.149332,3.715367,63.28941,26.252395,-100.401253,-79.877635,158.446166,249.944996,173.92888,63.351894,-105.536013,-147.194292,-127.460177,-78.879862,-53.627582,50.115847,97.695225,66.385769,-50.237222,-97.290683,-136.638249,-109.393326,-3.027053,24.448787,-43.775772,-122.986292,-300.41251,-460.677181,-508.260319,-422.960657,-296.602467,-34.527707,52.977489,112.643467,123.992695,129.211805,92.939109,53.596704,13.218043,48.821891,174.134409,189.568159,87.160969,40.602651,89.721767,169.953849,148.063191,100.69605,130.560088,215.765004,124.325047,12.343863,-173.288576,-207.404696,-201.44274,-171.364996,-73.829065,-38.927613,-40.631999,-113.598755,-130.888762,-68.259202,-28.220754,-9.147509,-10.323557,51.677711,59.10238,-38.293046,-258.428005,-263.861029,-107.310579,-43.480026,-45.624685,-85.199262,-112.424003,-93.548464,-104.687478,-137.400374,-150.15926,-93.058342,-5.912916,117.438799,31.525307,-41.079264,-156.819894,-186.212732,-190.104494,-192.167581,-217.770132,-238.942024,-301.753267,-357.391838,-367.883929,-302.637595,-210.393263,-11.155097,22.982574,-40.207893,-115.478289,-142.838198,-161.908401,-144.964465,-105.142135,-73.841994,-2.183508,-19.167404,-157.274295,-242.379489,-231.753104,-105.553393,-9.845401,150.819405,176.807066,108.787,33.179111,25.890973,16.252301,-11.867559,-98.26887,-115.479995,-77.004411,-67.134588,-67.494985,9.40076,49.352988,89.006948,110.216627,166.808724,181.111008,159.662447,112.068597,66.165438,-43.272219,-55.189863,-0.5501,22.258489,34.635464,22.35819,-38.428532,-53.743301,-12.936019,116.744129,156.157895,146.753079,114.278103,15.221202,-87.913192,-135.050503,-212.707398,-218.911967,-214.080931,-218.350579,-158.575801,-112.950064:59.025151,-55.047328,-124.666528,-198.898487,-162.778289,16.876813,104.863976,181.80826,213.494791,250.24222,276.914713,236.13761,122.12499,66.185809,-48.480003,-70.457541,-40.923106,-134.127182,-213.458566,-199.498856,-107.588498,86.673317,164.466997,241.879533,212.2065,166.214674,55.111104,35.228907,38.836654,32.207243,40.194644,58.605095,102.964054,96.172302,46.194682,-98.372934,-152.308112,-176.152903,-142.321067,-31.654466,29.584386,33.430127,16.411724,1.308378,-57.495418,-100.790488,-150.32156,-121.652536,7.506415,13.264188,-26.168235,-6.961321,33.362596,59.544895,55.770349,17.755841,-42.140086,-58.632266,-81.490095,-81.009677,-52.980422,-31.990162,44.588599,84.124684,103.813487,63.746385,56.708944,116.398673,171.859738,289.915968,321.026881,244.206325,41.092044,-46.392113,-77.691199,-22.603972,125.869666,194.075565,286.26749,277.468494,133.273088,15.342137,22.951841,103.597934,112.686044,33.840206,5.06369,8.217548,-33.486664,-68.880382,-74.089813,-36.157768,18.458883,12.471042,15.582944,54.00119,190.51888,284.502119,283.03319,269.852563,286.850024,296.821483,261.472441,200.968526,193.041483,150.269341,16.928957,-27.472532,-45.611202,-17.916994,41.336248,23.073376,-88.764697,-204.736726,-250.980616,-260.295541,-205.190912,-28.000047,54.852681,126.457722,110.000919,118.339037,237.680822,335.421423,452.30656,426.677174,257.069695,174.221501,108.257541,74.515774,31.823845,4.552549,36.527311,107.3838,170.004223,364.699362,444.198953,403.674123,271.943919,247.80435,292.270567,309.644534,233.947158,158.562679,98.624235,161.928775,180.231483,145.767543,113.819328,126.556147,159.647776,100.565217,-108.360893,-176.995568,-167.759131,-110.429783,30.065499,100.396439,238.784327,283.565644,263.925013,140.682736,90.61361,80.770688,102.47832,151.407089,195.390839,271.928521,109.531659,-41.106569,-188.54769,-146.041415,-44.432057,-41.188624,-62.870589,-57.411557,-15.921298,-61.669303,-106.392798,-67.429801,2.671172,59.197724,11.071247,-130.781115,-94.4274,-23.925001,29.921083,6.159364,-66.363655,-93.485894,-106.289958,-91.48802,-0.764049,69.41265,40.86531,-34.49737,-27.917969,35.37424,63.613907,118.72539,157.807251,131.18254,16.841061,-9.017786,16.481346,20.606283,-52.988861,-122.488316,-229.165307,-255.413469,-285.294383,-328.267475,-285.758123,-167.906145,-156.56721,-161.133311,-84.267619,-45.917838,53.798105,138.087745,265.526668,280.324597,263.673354,202.293197,-55.748089,-233.71902,-237.914375,-157.228376,-117.33881,-38.306695,10.555515,24.62171,-55.192337,-74.527742,-21.422735,45.727733,99.158305,47.999728,-43.388492,-54.064708,-117.811584,-196.023339,-206.339695,-201.633314,-188.325613,-73.667577,14.07739,89.036395,45.151546,19.132852,-59.092886,-93.949381,-56.382628,5.088461,49.43861,3.323508,-115.420568,-135.304577,-102.455861,26.384595,87.178337,120.546789,84.415282,-41.446424,-87.182561,-84.161789,-84.784147,-79.674867,-89.014591,-110.017763,-144.472851,-160.775215,-201.198451,-293.146329,-334.252985,-262.626063,-159.411969,75.470899,152.972857,113.082771,-15.97178,-28.930626,1.57536,-11.926121,-95.758037,-101.44973,-14.69852,9.542056,-47.149054,-93.809278,-71.284655,-6.922475,-3.394117,28.712685,88.312851,162.763343,96.649954,41.690066,-89.298816,-137.569378,-141.366996,-113.39108,-25.700245,27.695162,109.240294,78.705454,13.723453,-80.41734,-60.630774,-5.218,-28.421043,-95.962512,-78.83846,-84.440581,-112.558429,-86.372337,-39.391987,-73.946774,-159.428792,-155.292026,-124.71261,-175.715896,-217.702601,-273.495366,-255.028981,-118.105303,-74.170016,-145.817678,-203.4207,-197.661309,-237.007972,-267.58554,-240.513022,-173.403283,-68.010403,-98.082046,-216.009271,-230.039563,-234.76494,-205.105678,-144.918348,-8.255865,37.138444,49.394989,-20.531809,-59.64718,-76.717666,-36.713105,68.088669,95.29569,56.623164,1.687843,-33.216396,13.962372,18.262383,85.802082,167.4787,265.791924,215.526601,31.302368,40.809762,90.784432,43.987003,-50.469279,-180.641406,-169.283683,-75.530384,-68.876215,-151.299854,-182.419599,-159.264615,-46.558188,33.202458,194.130417,244.400306,213.401772,94.495783,56.95955,48.746513,56.36513,24.017197,-13.729129,-66.669698,-71.845864,-34.931926,11.261102,17.483017,64.354635,105.924401,151.240997,146.733527,102.886299,15.525717,-62.464543,-224.920146,-246.597509,-195.086875,-187.778649,-219.090566,-197.115182:left
-412.615686,-255.931826,-160.497996,-34.866151,-21.601659,-28.937736,-9.638937,28.520471,58.436304,109.975069,184.761308,172.319394,106.194456,74.96238,19.287064,4.94604,15.116574,3.936402,-8.938593,1.729505,3.814008,-53.334296,-90.363978,-109.475976,-54.226023,-26.363099,4.217919,-4.181648,-98.688843,-139.679888,-85.562584,-29.943825,9.160997,64.698857,143.46443,275.311383,264.450179,159.40872,114.333407,51.033685,108.535716,191.92647,359.608169,421.43232,454.860833,423.785566,332.05762,269.111153,135.717852,163.29325,242.496664,344.502229,315.241818,194.906536,170.096938,168.971554,81.102311,18.660003,-55.508605,-74.565427,-117.772558,-132.991958,-132.49139,-126.90192,-98.64545,-32.049502,1.978953,64.581741,70.224988,-17.681728,-91.410203,-246.670083,-326.216836,-321.74733,-254.762299,-217.965792,-202.744415,-218.331605,-240.67348,-257.097156,-309.086312,-291.62877,-265.856895,-266.968389,-295.546356,-338.686018,-348.447828,-399.060077,-398.371221,-334.272568,-132.71089,-34.507225,57.580778,33.808894,-39.119163,-50.993746,-60.129554,-54.847129,-48.398537,-68.306837,-91.764984,-120.43255,-131.938922,-190.501075,-192.72222,-155.211093,-108.953855,-119.835391,-167.395909,-170.03475,-138.809475,-147.079525,-207.38119,-212.789481,-180.173047,-89.763776,-63.311192,-72.645644,-108.779673,-207.796363,-172.552267,-113.098642,-68.584683,-93.652277,-188.892136,-241.854738,-303.672883,-306.737139,-300.507605,-312.556195,-293.88904,-198.648914,-187.789327,-300.373551,-376.478384,-498.363448,-511.255327,-460.798368,-303.326898,-232.660639,-228.078965,-291.38725,-347.646597,-311.599817,-246.659589,-231.367952,-221.896069,-201.866102,-198.464761,-188.41759,-161.376241,-102.790375,-80.893595,-84.549448,-126.439782,-123.333939,-42.648234,-11.969377,-3.876735,9.117041,93.101981,163.765093,175.445566,194.932777,195.794991,156.508097,138.534437,129.208559,175.779048,236.799651,358.707021,367.131664,276.543126,232.312386,179.85663,129.842185,8.553825,-9.388314,2.18842,4.510371,-8.546005,-34.046152,-31.082234,-66.931837,-183.280465,-213.641639,-198.640108,-195.110643,-244.507827,-256.394733,-201.869841,-180.223318,-177.213074,-122.447825,-61.112355,65.949169,87.485018,43.879985,13.920486,-3.713213,79.704148,138.82488,230.017912,246.26186,153.911836,60.585338,-94.074525,-134.591557,-115.830054,-38.493261,-32.527992,3.906985,68.0907,179.23821,176.448089,96.159873,99.863539,114.683078,56.225563,28.856348,64.254033,82.284036,26.817049,-21.153647,-41.292212,40.347067,68.875664,62.429163,54.335849,43.149762,6.193941,-129.416561,-156.108837,-118.945791,-9.399783,49.646494,87.136074,60.148307,3.130514,-15.495755,-20.988577,64.778304,134.332518,210.190477,162.765303,15.653616,-7.375544,-29.859821,-95.330955,-77.048905,82.855404,170.927207,228.355809,186.803546,91.397291,70.737508,56.992918,57.406025,66.144173,102.962968,100.748633,38.573118,14.628127,-10.018743,-34.751071,-42.492159,-59.264098,-57.129376,-22.112001,-4.568017,19.892137,18.335426,8.843877,92.701582,172.108657,317.587377,348.154158,339.140984,326.166837,316.297389,345.97645,372.004803,393.546578,388.196284,363.590628,334.369993,257.566063,226.646409,197.359748,252.292249,305.024782,324.92856,277.076744,224.049483,235.48918,188.816605,105.217612,122.004288,198.235171,200.497095,114.181359,54.396629,-1.62165,14.229426,81.876419,149.342853,180.844009,224.88305,210.611291,111.540703,70.523476,48.474579,47.375661,41.078151,59.936075,88.357344,71.508881,14.140179,-47.530139,-17.867552,68.890511,48.490349,1.224846,-26.158795,8.7156,80.960297,99.213216,93.098166,74.094227,59.060563,-32.228504,-77.817833,-106.769001,-101.649417,-78.310814,-78.020115,-80.174179,-26.98216,6.842348,68.451279,72.304186,-4.65235,-58.267233,-167.155545,-210.574664,-157.552483,9.498679,50.454429,37.485062,37.654794,96.387137,120.721925,117.907651,99.420869,106.240875,119.780908,81.826392,-89.453518,-162.476756,-172.806981,-40.880663,17.79113,24.947047,0.700449,-20.215654,-22.891581,-54.63641,-94.738867,-158.55643,-121.686144,-101.520975,-83.541457,-70.674416,-66.381984,-87.739166,-127.189909,-81.829188,-38.068287,6.348688,1.698495,3.002377,27.178726,81.965739,82.114962,61.556369,99.02126,134.316493,176.501087,171.659991,163.134712,171.072205,145.596847,70.448491,60.091522,119.713672,160.181368,182.756759,159.922873,65.143413,17.852171:-280.060268,-205.703862,-156.250245,-5.521939,75.298707,188.140131,214.673429,199.569933,140.61302,124.256051,163.911415,199.842579,164.397827,95.570252,3.580719,11.650904,69.495533,72.661708,84.084181,168.517515,175.483057,54.784334,3.687511,45.654964,112.092781,123.371829,182.317139,201.480388,116.492781,41.462165,-56.948993,-56.875571,36.48867,143.45807,161.825261,136.674021,112.445523,82.719065,60.139518,-50.029786,-39.589744,62.472289,284.911977,343.838902,376.463281,368.880422,295.342493,223.980531,81.425176,70.885457,113.277585,181.438717,175.742306,135.314506,119.031064,61.55499,-6.464952,-4.61817,47.28792,46.682016,-8.822543,-34.599221,-112.841561,-171.8585,-209.354643,-71.209863,9.062136,122.302043,145.698978,96.018628,15.192846,-218.113675,-323.039126,-289.002616,-169.397865,-141.728919,-190.966656,-230.904477,-271.206927,-269.86171,-209.629248,-125.244685,-100.184335,-118.425291,-173.32269,-279.722902,-292.758341,-274.366204,-202.967626,-152.94346,-58.593899,-22.587571,-33.590465,-73.560298,-118.059969,-118.667797,-110.161772,-35.666587,0.530127,-34.763404,-92.272428,-195.947582,-219.669204,-198.141413,-137.668854,-110.742581,-69.650507,-50.601664,-38.347059,-56.497279,-122.282345,-150.184726,-171.541013,-164.786697,-157.336717,-116.652392,-70.987318,-18.99125,-68.105043,-231.897288,-206.016032,-153.341058,-142.64031,-158.45689,-151.682719,-160.000934,-295.757389,-393.582617,-494.220949,-435.773683,-358.311106,-191.794228,-175.443397,-311.855859,-393.357155,-438.965854,-365.729797,-330.968884,-289.62437,-278.861037,-302.53175,-335.257189,-396.085367,-406.205652,-349.364917,-206.652089,-140.9043,-72.925552,-60.103193,-42.965475,-52.944553,-113.900407,-120.113279,-94.476235,-35.680356,-4.995743,48.871333,65.133356,88.288452,103.65564,133.024548,114.557723,122.391573,246.531988,284.893137,125.817447,4.862176,-19.002565,172.17726,244.89803,317.086422,330.103177,278.261636,211.508618,48.059844,-29.288458,-88.55428,-31.352416,-12.961219,11.124237,18.63107,-30.22024,-91.454121,-266.336788,-366.162319,-347.569481,-302.601468,-316.234008,-378.379513,-395.531247,-356.063726,-314.257527,-238.737798,-165.611474,-111.680055,-3.811024,7.093248,-62.868138,-112.896678,-161.543856,-41.500348,33.5751,64.670727,24.478787,-96.992786,-135.526634,-146.351836,-165.800903,-224.814193,-154.998041,-80.524292,40.096188,53.846588,18.306228,3.672239,2.891244,9.30417,-2.567041,-11.6019,3.122297,-14.286369,-50.390212,-88.701477,-72.072997,-2.487814,13.662741,0.436325,-40.778895,-64.809648,-69.240162,-51.775397,-68.066478,-157.582317,-161.715053,-18.811822,48.193895,-15.122327,-93.325988,-142.369975,-128.042639,-151.628867,-124.381488,-40.280259,97.515114,70.541704,-96.070042,-158.049035,-176.898671,-80.725325,-18.38681,98.343733,139.887423,148.4752,123.571923,44.92526,3.582975,-19.666524,55.790163,94.328531,122.452149,108.206151,61.654065,40.227031,-31.041737,-78.066961,-60.454419,22.906818,70.583484,117.510771,88.024833,-10.697754,-6.049181,153.256918,232.80317,216.049631,254.602609,301.819009,330.095837,334.752356,401.782393,440.066142,418.194378,364.792119,364.57603,384.644938,366.329967,236.686977,168.410786,171.24887,283.301587,317.538959,325.377791,298.459304,219.414696,207.581098,264.8677,328.184999,341.798593,368.244281,362.795884,215.106821,116.755783,49.709366,68.091574,118.571749,159.212932,163.556603,163.412134,159.746162,101.780818,62.377755,46.682209,112.673347,153.362672,196.47876,176.277649,37.189346,-37.048305,-65.090779,-29.282633,11.289331,-44.077819,-48.833602,15.783072,16.50906,-17.976132,21.186688,161.966309,211.783526,179.350319,90.133945,105.160577,188.640221,162.403616,-39.544483,-126.893564,-111.888561,31.945634,83.749979,126.702676,111.469602,21.802714,-38.911838,-182.524009,-227.149707,-180.05342,-51.540923,-13.599859,4.776629,16.486281,29.133623,16.317331,22.393961,72.701573,95.827966,98.709736,45.968991,-137.325038,-209.934651,-234.575806,-101.975025,-22.896454,32.869624,22.119537,13.470138,17.350258,-35.836104,-102.023165,-166.592411,-64.805774,-12.672055,38.309355,44.12577,8.695319,-43.860279,-165.046334,-142.279828,-73.536282,61.149652,96.055181,114.637678,126.271504,164.185326,150.338282,40.633351,32.70305,119.814905,336.074782,363.199653,228.041916,153.493868,106.503221,113.531381,130.719422,194.190299,215.948629,187.106686,143.281664,29.371077,-21.568952:-329.510217,-135.048003,-22.168043,127.122608,155.07437,137.450474,111.711065,72.587854,64.55907,74.444894,119.210622,136.200416,103.714932,66.442288,12.816442,7.920013,44.922874,99.539009,117.636682,113.57878,95.864079,83.401013,88.147128,78.682913,60.325342,52.961336,71.237636,96.001993,87.809877,49.614591,-55.204529,-114.020141,-181.557359,-104.680827,-16.171903,131.701916,132.427865,2.709209,-73.924504,-114.328857,33.983619,128.426374,285.567073,340.241471,378.664722,375.618278,291.302877,179.229599,-53.68007,-52.351324,15.461777,119.137002,122.317839,94.219292,89.018983,58.125399,11.943576,8.685986,33.172516,47.859103,47.608093,23.313329,-66.297731,-107.699656,-121.924131,-73.410261,-38.295334,63.598854,92.712367,16.486373,-72.815648,-263.009536,-312.46543,-265.083326,-137.906051,-113.028978,-166.669047,-198.697932,-233.667567,-251.577689,-233.313499,-143.067504,-127.326049,-172.626491,-216.098119,-305.847257,-325.538896,-307.477926,-226.775392,-157.946508,-3.538652,46.966918,21.205149,-49.129774,-189.378986,-192.866101,-56.194029,-7.470377,-39.819418,-39.187885,-18.675872,-77.5895,-136.53983,-147.872619,-61.098089,-72.606224,-132.338589,-112.829037,-57.668568,-74.622345,-179.594277,-224.721696,-225.5028,-172.67421,-147.847964,-75.091452,-46.874324,-107.665593,-194.223268,-333.588654,-326.212897,-303.442666,-252.882535,-219.80957,-186.930977,-206.591755,-316.800175,-384.796444,-455.81024,-387.1515,-312.385868,-209.444789,-233.943778,-370.637885,-415.92598,-422.987156,-382.322977,-350.081307,-272.969665,-249.473346,-263.024964,-292.269688,-374.672602,-408.886304,-345.616999,-109.837205,-21.259931,-32.093708,-90.475086,-150.422206,-142.952315,-97.406377,-25.518922,3.89276,36.436624,48.532834,75.43452,92.478733,61.26853,-5.782865,-93.676322,-14.782102,44.019325,146.594375,173.232035,97.264655,5.365554,-73.440356,126.305126,251.007933,345.510693,312.102709,200.853246,144.129704,-2.768982,-69.176959,-44.703791,79.370242,92.380408,35.043509,-6.253197,-105.501884,-159.510585,-263.045279,-352.74017,-386.690378,-364.558404,-312.935843,-285.613067,-326.76948,-405.253524,-402.486295,-305.946749,-166.81955,-100.596445,6.750033,35.720392,18.779211,-38.59444,-185.184974,-139.606231,-44.793997,98.298894,90.982933,-93.142461,-203.964466,-326.34975,-345.405234,-305.492753,-186.520047,-134.830689,-94.64487,-113.276078,-150.201891,-134.233677,-72.620376,-37.614609,-31.334912,-14.423775,-4.019329,-2.202062,-11.094322,-56.30009,-78.915882,-26.549507,110.222321,136.376357,25.049656,-74.547512,-163.14535,-133.403586,-71.692972,-93.072373,-96.869057,-38.001116,1.546023,25.766023,12.543002,-29.574049,-55.822166,-85.955417,-30.690536,14.611593,48.55092,39.602925,20.844166,-4.087487,-82.473332,-24.69378,48.28351,138.595967,148.825542,119.065375,91.094333,35.517861,1.918573,-37.212211,28.153103,92.247236,193.006305,174.37092,12.342037,-62.181962,-114.462289,-44.522336,0.368544,15.022721,-1.595882,-8.960854,-5.120807,-37.78805,-65.622252,-47.865326,86.598004,158.636313,254.279629,272.564801,282.46503,279.32945,288.60894,372.563036,402.152787,381.048778,348.534747,263.81754,206.828665,76.621885,39.439826,111.801102,270.650849,313.620131,324.357989,315.959181,289.27109,255.062836,182.431328,255.933738,322.245231,340.200734,277.979644,122.692848,65.732624,-5.026011,-9.409591,53.370874,128.959616,165.163848,220.233478,202.89792,114.615015,82.408402,43.716298,87.783539,141.09669,222.629807,228.398053,131.473798,52.345794,-49.908637,-61.532727,-47.593122,-17.048087,9.114965,33.789743,18.299735,2.931538,15.179646,22.989702,56.540134,107.158557,206.812344,211.396105,120.940365,70.109413,-26.424826,-94.969053,-172.669034,-66.846107,12.331491,123.144747,122.32378,8.915884,-58.450862,-147.904483,-157.066031,-108.395975,53.344805,103.109039,48.95759,-22.954036,-117.246033,-109.488435,-14.218164,42.026782,34.647841,-23.127508,-74.388062,-187.953124,-228.926236,-238.246927,-98.55241,-0.484345,122.187886,127.621144,102.535612,94.408198,18.377147,-46.945504,-82.056142,55.2919,132.361499,160.562352,104.103021,-32.498627,-81.467277,-135.692478,-83.912659,-8.92936,153.951123,202.014144,215.215311,194.983096,121.751302,81.036296,59.932252,156.019686,228.844359,305.350384,275.681852,161.420568,105.222095,10.823136,53.366019,130.410319,264.717848,280.190016,245.231813,225.511375,129.00197,50.959006:-416.934254,-268.510609,-147.388788,32.357505,51.181417,43.675013,49.821039,58.423554,92.148709,109.651196,117.78834,133.647713,162.084013,141.089961,65.779724,37.889009,28.389518,38.650125,30.611863,39.668162,56.618716,48.736912,18.74368,-51.257079,-67.56303,-50.957969,15.357112,44.788588,-15.54636,-103.667183,-249.952231,-271.746627,-222.757608,-145.215651,-98.046638,68.967484,141.594464,152.671761,116.137105,53.639644,134.083841,219.530113,307.346103,289.766088,224.753925,199.3104,165.807906,154.393398,152.338152,236.633499,278.171008,245.414209,186.655711,78.452617,46.661382,27.219319,-2.130162,-22.49301,-47.287296,-48.502838,-27.652574,-20.011105,-47.575198,-76.231074,-85.018535,-34.961383,-23.285102,10.529081,32.376034,14.474666,-42.756091,-241.036798,-334.182365,-289.957554,-138.533719,-88.137744,-98.460267,-124.448856,-149.193278,-180.88578,-255.401269,-206.534706,-180.283974,-224.952207,-275.572683,-318.022049,-304.845313,-352.332811,-426.395232,-362.409155,-89.24413,22.103146,72.54773,36.189534,-34.162944,-43.96174,-28.481927,-69.740204,-122.50978,-186.354015,-180.759896,-168.243253,-182.211091,-199.400662,-152.94915,-129.152442,-101.683158,-90.311094,-115.359563,-160.934479,-256.38219,-276.969625,-243.326015,-208.532103,-213.452416,-186.161432,-141.244435,-89.62824,-122.970244,-257.135613,-319.153688,-311.070297,-280.276815,-276.149018,-306.633175,-334.122931,-406.775688,-453.575356,-493.776564,-398.030794,-325.76022,-259.26897,-293.783348,-374.437459,-383.131139,-432.478019,-495.445433,-469.977935,-333.537427,-279.138304,-243.265991,-236.157839,-216.365075,-216.527954,-226.366212,-179.930531,-146.566253,-130.536913,-145.060275,-149.18854,-138.327521,-160.487951,-173.858944,-138.801925,-45.087744,-25.195105,-34.686127,-24.30708,29.678597,36.440984,25.049008,21.925962,16.704414,28.824353,39.321832,39.89546,34.033281,31.998705,109.244319,187.577154,356.06758,402.214017,365.011224,309.940348,188.96629,117.262051,12.723811,42.819235,79.928593,102.124396,76.179479,21.357375,15.187604,-25.142302,-131.43169,-169.798979,-206.69553,-223.402555,-275.936863,-293.369838,-220.899156,-150.929496,-86.136522,-106.633461,-82.764192,42.837877,86.637737,100.79733,104.052923,114.579634,136.086094,173.836599,225.7359,188.485086,-12.463537,-120.385518,-219.733135,-213.261525,-166.073204,-95.238864,-42.564113,58.080325,67.705828,-5.411828,-36.001716,-13.052646,43.657942,52.197644,72.426763,105.064801,131.773164,97.463515,-12.464922,-56.219794,-52.251591,61.524359,109.508287,92.210334,35.774302,-42.276984,-43.019183,-45.575114,-61.375179,-49.575469,3.740391,46.25026,123.769069,114.040453,-18.663507,-91.047491,-110.843876,10.431174,60.200396,89.891444,85.784338,49.217831,11.570366,-48.619521,0.892717,43.834149,83.410803,90.253197,109.803243,105.354633,26.562928,-29.435774,-68.055581,28.569457,91.122205,131.749833,97.969465,30.037376,27.367024,1.817533,-57.828633,-57.562204,-44.745317,-53.26234,-67.189921,-71.405502,-81.515134,-71.514098,16.732531,111.906295,143.605395,230.938561,279.43454,316.851473,299.78224,263.331739,317.991662,363.002623,420.820976,426.867424,354.976909,284.175866,185.025423,178.819293,213.69419,258.836979,284.747437,340.416452,343.87787,276.157052,242.809164,236.6669,239.568348,236.318095,257.948671,255.102546,138.701399,60.619637,5.372229,32.680588,146.205832,207.047925,188.041123,140.121691,116.134875,40.709262,18.641087,25.22718,40.036639,44.721406,44.973362,45.040289,18.578473,-29.645216,-160.826402,-195.77181,-135.057493,-49.808943,-57.635926,-108.833134,-123.473761,-106.631036,-70.741674,6.511215,49.286612,53.72494,10.995282,-23.092307,-70.395695,-89.67404,-186.244418,-260.120376,-289.05645,-128.087488,-59.583999,-17.984668,-39.242279,-120.448079,-156.617743,-246.799677,-301.210459,-257.316532,-100.177121,-41.552741,-24.226072,-52.777333,-81.001236,-61.408627,3.03009,69.786866,105.641835,149.474243,122.902345,-53.937091,-153.558529,-229.576469,-93.723887,17.392281,170.702253,194.159038,185.210096,160.530697,73.842241,25.969719,-8.929533,65.094931,98.647472,100.053443,81.605954,44.741179,22.402998,-56.498429,-32.974286,40.713058,130.718682,125.495338,126.244226,151.083625,168.339352,134.177926,66.72847,92.837554,138.627204,279.452563,324.688127,265.574712,201.67875,138.460906,160.281567,170.1918,185.280391,206.829896,212.748592,177.7422,72.101919,30.569165:-318.841207,-85.302768,14.99403,77.996737,60.26399,44.620415,46.705332,32.870766,34.125892,45.273661,86.928881,93.877965,34.535655,1.721767,-14.757663,-3.748818,62.093112,94.409842,62.962213,-14.618624,-22.697227,-20.575044,-57.600112,-173.548832,-152.844204,-96.43506,26.50224,55.725849,-39.146305,-116.939388,-220.749796,-258.712729,-261.093048,-137.823199,-80.558188,-2.112489,28.979179,41.28596,18.503617,6.696056,90.313099,125.372958,170.239024,183.065988,149.143484,112.752878,28.080287,-14.750577,-34.189706,56.256074,112.740685,164.009896,127.602548,-14.510816,-65.933498,-94.757726,-103.868207,-114.890477,-96.422708,-67.058365,-22.354565,-11.758966,-30.773028,-72.291781,-148.980805,-83.4234,9.376154,192.814027,207.809757,35.46958,-96.310282,-276.190506,-283.561608,-244.998335,-67.843789,23.921129,19.954556,-43.194662,-127.138058,-155.757939,-187.201758,-133.313029,-96.713972,-75.114613,-104.820599,-232.767382,-313.263217,-426.418741,-346.053626,-236.772477,-7.259627,65.673828,89.11054,50.930612,-97.561118,-177.027776,-199.132201,-103.566514,-87.383967,-92.125502,-95.844109,-108.685097,-121.41373,-188.090633,-229.469649,-209.420833,-109.515764,-60.638978,-78.663118,-146.477297,-298.363253,-349.488155,-340.25512,-247.013349,-213.873927,-149.617878,-125.045806,-163.462631,-222.067694,-333.729435,-348.222133,-315.245071,-239.239146,-228.607312,-269.120543,-290.76258,-309.10835,-336.266144,-396.382001,-313.652938,-252.658121,-238.465286,-283.546252,-378.971206,-416.708886,-504.238325,-519.901074,-467.88726,-266.728059,-169.048402,-127.87029,-166.051577,-230.050579,-241.993542,-197.928896,-82.807415,-39.977332,-43.163151,-83.099706,-161.485282,-173.656923,-139.163054,-50.950831,0.403313,89.980046,114.307406,95.019274,50.057625,-52.524103,-67.370876,-24.274394,-23.920232,-33.660847,0.709823,21.575369,7.946363,-13.800875,-8.517396,140.858671,239.173205,360.744485,368.092173,317.337714,274.174341,121.109494,27.595751,-16.330784,92.134867,108.627211,57.48923,47.349768,95.700806,102.582608,-19.174184,-185.115629,-215.908909,-178.169405,-153.218606,-182.854698,-221.088531,-261.461852,-257.093052,-194.531998,-56.691256,33.202038,166.105853,167.913865,103.365269,74.040234,14.539834,26.944396,96.60059,251.773834,253.396065,61.662794,-64.509844,-211.797657,-211.615482,-135.383328,-68.729492,-36.728718,-13.809938,-33.068726,-40.68714,-28.713491,-78.724193,-76.664423,0.702684,176.148294,216.483199,168.524883,108.805658,-5.409811,-44.381648,-28.305665,75.406752,126.227601,145.165599,82.442947,-69.080492,-102.123237,-102.643946,-49.031956,-6.883905,110.034555,175.691215,182.178934,92.046331,-121.639648,-158.975608,-82.012375,-28.793144,-29.751985,-20.942843,-16.194355,8.219193,20.879801,-11.11358,-10.783884,30.021453,129.106305,167.424321,171.88657,128.639135,-10.879327,-80.478428,-134.676478,-40.997978,47.759005,167.916673,137.859494,-7.867594,-56.55841,-91.190777,-75.662341,-53.555605,21.849431,56.69568,19.322736,-55.670279,-198.093367,-207.431579,-59.710158,153.694507,232.177385,308.63556,301.466222,253.151598,225.115372,191.111754,308.040366,391.024017,472.221916,466.099074,383.57132,324.791878,219.816507,193.11385,224.464842,315.288567,363.85301,435.262167,430.325515,308.935323,223.168887,127.634159,192.728262,262.680592,369.010004,349.402994,206.621124,153.387389,81.548947,54.211205,83.995756,152.449531,176.217484,188.020132,157.805312,97.611697,87.772952,33.908085,30.185014,74.185809,149.415785,177.291668,204.802022,155.642716,-63.15883,-138.611003,-84.861146,54.169474,87.982911,62.731771,10.408798,-68.067323,-62.732878,-22.3556,41.849366,70.002843,61.51507,41.769308,2.126371,-21.478297,-132.882133,-227.78417,-341.298962,-195.17352,-73.760758,62.301149,59.530743,9.748583,-18.832103,-104.463026,-163.698853,-144.142701,-37.647332,-0.334737,-19.548984,-40.055711,-33.603374,-6.440437,52.322406,50.055512,68.145365,175.420863,181.139149,-0.745497,-118.310042,-204.618396,-22.136915,102.866765,249.230528,267.368941,237.634694,192.643591,47.517727,-17.140603,-1.513596,122.184165,145.726444,117.611398,103.527903,72.899595,24.91751,-101.807279,-57.059786,28.631797,128.475542,110.339806,33.536159,16.231163,-7.135415,-25.732214,-9.315586,85.501821,132.389322,180.669423,165.347386,79.573014,42.426746,4.127896,3.55686,36.588486,173.351909,223.208016,177.921943,121.956322,53.92399,47.163603:-535.61237,-403.08107,-310.151384,-158.273583,-112.496492,-35.165128,1.416259,6.6791,-30.816114,-4.479818,64.398701,45.599242,-49.641874,-85.638782,-127.489319,-130.700838,-92.484894,-78.634508,-96.342224,-106.702784,-95.682723,-128.970078,-177.551479,-235.687322,-172.901221,-153.062468,-259.479823,-324.842585,-305.034229,-262.483702,-266.235102,-287.486447,-231.505505,-82.988809,-19.207989,69.872026,85.40691,100.78296,133.270428,146.210983,81.791702,104.754983,253.141681,313.634502,294.589611,234.483231,170.56605,189.968798,274.724353,378.432527,410.758989,341.620677,256.780783,118.803642,83.391717,18.517698,-96.555985,-147.680472,-200.418328,-198.380528,-157.552959,-140.57897,-124.112828,-121.001509,-100.784681,-62.374462,-64.73852,-102.125413,-127.841133,-201.014077,-237.660448,-290.640179,-318.961842,-315.424695,-238.073173,-187.22834,-170.955267,-184.793443,-147.719638,-131.84768,-187.519947,-216.544326,-221.022779,-283.585328,-319.386657,-339.438823,-334.392098,-378.600587,-437.876081,-397.47567,-210.644172,-125.269676,-16.450905,9.49039,9.237245,-3.129753,-34.306395,-76.673106,-85.26984,-65.47638,-59.633462,-82.66204,-95.517637,-105.230519,-87.833322,-67.7464,-23.415455,-10.647828,-59.423315,-124.302447,-242.380998,-267.397265,-249.202263,-203.789404,-182.826383,-135.423799,-128.151408,-156.974668,-168.469214,-184.962534,-192.004815,-176.541816,-158.479994,-170.784423,-237.45387,-278.479204,-321.818084,-320.23908,-277.334884,-204.739619,-172.569998,-121.782356,-133.370955,-284.790156,-369.174454,-421.21853,-386.078075,-351.673625,-200.736332,-109.98288,-71.540104,-139.687222,-262.798577,-258.44502,-183.008379,-180.851218,-221.640723,-269.353853,-233.544663,-155.788712,-163.627414,-191.004757,-142.492705,-113.018045,-60.415322,-12.27262,60.247711,31.713739,-67.313759,-63.676803,40.69717,71.582987,65.15564,94.60263,94.931617,21.951084,-6.025762,31.513235,141.778713,205.489735,322.239928,335.430634,218.621061,149.329547,133.898316,155.589145,132.542184,41.745771,7.946461,5.915292,35.032295,124.450894,168.48515,199.539179,153.334755,117.169691,56.143897,39.639903,24.869221,34.516712,72.141689,59.900222,-12.197554,-20.099814,12.113663,107.872301,126.515272,70.587813,38.173282,30.684112,77.084503,124.113441,230.572595,256.727776,196.432961,113.970165,-56.508139,-113.031276,-149.54138,-110.971085,-88.803559,-29.138606,17.751302,93.241166,110.732351,149.524384,179.089302,162.642646,119.388311,126.495678,173.0295,179.241192,71.160628,-28.648494,-82.297227,102.724994,167.233289,151.292519,111.173376,61.471721,45.933139,-24.210044,-34.663932,4.976977,53.925664,52.617263,91.725582,138.863828,181.671356,151.613122,102.985169,177.661321,213.416868,161.955475,76.985904,-42.850817,-14.782298,102.449382,77.59073,49.921192,38.949384,47.683941,87.500853,91.407275,35.11321,10.640359,35.595773,70.948517,63.005255,6.388181,-18.814478,-19.798797,-13.505256,-39.60063,-50.985706,-39.067551,-56.477939,-77.321213,-90.889314,-95.817493,-80.576305,-45.622145,24.944268,58.409096,90.813443,189.241094,227.986235,265.203848,256.191439,202.809492,250.722019,307.413177,355.078941,338.155592,278.02125,235.731034,134.560427,105.346337,139.506803,205.791565,209.685456,202.766121,214.426291,230.011181,212.759614,138.467277,66.92109,52.910365,103.872706,141.828408,102.932446,33.025452,-43.183539,-10.621715,147.940657,218.140473,183.345347,95.602005,71.245649,43.416893,43.890249,19.851627,-38.634265,-32.985649,19.703781,45.256354,69.277049,64.653058,38.986427,23.338084,25.485915,48.075805,36.051049,-2.558467,-15.543175,-30.498386,-23.991917,0.287698,11.247472,1.070106,-78.63423,-130.972199,-194.345672,-205.958582,-215.837139,-209.608439,-146.532277,-74.447392,-52.419981,6.868028,21.428019,-70.680804,-146.25413,-234.324832,-230.316369,-178.497167,-15.314662,27.763232,7.646727,2.919828,58.922847,95.284204,119.728837,57.955218,36.478051,38.671432,9.565336,-129.495707,-190.746632,-218.628354,-91.522904,-10.439377,69.948319,72.358734,35.103878,5.41679,-23.553216,-24.489043,-45.089569,-68.617452,-66.247487,-27.608616,15.464717,126.519747,149.63792,81.166123,29.436301,40.382535,79.878681,105.352594,119.375422,86.49008,-4.320982,-25.160621,27.989022,92.538026,96.757865,98.139603,97.427439,100.762214,124.197936,159.448983,126.620854,131.809357,162.646893,152.955583,95.531593,70.286272,57.474672,75.266161:-346.165766,-161.412315,-97.144869,-94.062664,-108.662959,-74.361231,-46.406997,-40.492503,-57.37651,-28.133172,112.175025,157.140892,67.682228,-21.365684,-111.968537,-104.739336,-59.443035,-41.39298,-46.468876,-71.880167,-74.281747,-69.399796,-109.873707,-270.61157,-279.4442,-210.528794,-100.617129,-89.257756,-134.359199,-179.067122,-287.515201,-335.179223,-355.869115,-249.233637,-147.513056,44.22659,61.636213,-22.041177,-50.5813,-22.622834,68.529242,131.988457,262.83715,278.51872,177.231503,119.552283,84.560074,95.314463,141.325762,231.196041,276.6355,272.242052,209.203732,62.311176,10.931658,-84.525409,-145.213908,-151.559076,-166.644639,-164.129167,-136.245922,-140.293638,-175.022147,-175.748899,-124.533331,-50.077126,-15.42166,26.105875,16.214175,-64.157892,-130.757574,-283.566199,-323.036533,-275.317954,-105.299525,-25.07679,32.156631,16.356194,-66.286479,-135.836229,-231.519614,-128.625351,-51.302184,-28.166806,-80.172078,-192.036091,-237.435797,-332.155755,-339.090553,-260.089428,-37.461432,18.669245,29.267743,34.520642,13.55143,-8.063661,21.317264,9.388182,-41.40163,-69.07967,-48.000911,-67.535042,-110.541462,-201.066194,-202.411283,-170.842603,-83.65662,-22.184979,17.956083,-56.480314,-270.021092,-316.715892,-251.970873,-162.695935,-143.416306,-117.215136,-112.215111,-183.62278,-250.662397,-293.750224,-186.311666,-134.180061,-93.833576,-106.945755,-178.505559,-214.933306,-273.876558,-298.649834,-279.61967,-199.079215,-168.987418,-136.713149,-157.569846,-299.816469,-383.061244,-446.147291,-322.930437,-238.485053,-92.990401,-43.352709,-69.777581,-131.637656,-205.259772,-193.775544,-112.372446,-41.280011,-25.645487,-39.139337,-79.900297,-154.531029,-146.776419,-96.479058,-46.199294,2.410476,121.222716,165.173182,179.718868,138.530485,-0.930727,-57.030925,-104.228306,-87.465116,-27.861431,136.067972,149.834364,15.746994,-42.467718,1.560771,167.059022,230.775367,311.759876,338.475264,282.699935,201.058598,50.359757,4.528486,5.598562,102.533781,125.746097,99.313129,89.064981,103.302675,98.903027,25.268445,-41.56467,-50.136584,-42.362967,-24.119795,1.648836,-20.476164,-105.036929,-136.204003,-129.561302,-11.842467,78.697627,231.116175,225.13196,62.30103,8.208771,70.944507,183.980354,226.860951,313.307892,310.890324,103.95966,-32.467186,-162.159674,-166.571842,-126.926229,-58.517793,-25.945183,28.30903,33.354124,-16.703306,-41.813621,-24.501733,50.957708,85.978145,164.770502,201.524114,181.280329,125.247805,13.430595,-23.605087,-25.273913,81.140361,151.440843,233.186508,206.286955,35.959366,-60.492979,-158.864966,-58.809508,17.342678,60.067069,51.889329,86.446952,96.416254,13.87,-50.35557,-83.845445,43.062156,106.420066,110.547535,61.09647,-21.642059,-33.844941,-33.859017,-20.730921,-10.275231,15.635087,33.959024,66.098171,62.921296,-10.69794,-60.427848,-101.524327,-24.614955,48.645218,127.098082,80.071741,-125.600854,-209.068385,-231.176161,-105.059935,-45.00256,-27.004758,-55.032547,-113.567521,-130.769473,-148.36039,-138.159079,-49.19428,52.369027,89.929633,154.188567,167.54281,159.0858,149.718217,136.936292,190.80903,239.99514,368.668657,415.268682,322.348386,202.07823,9.663567,-14.747264,93.381808,262.270378,318.740524,354.697427,322.72412,193.98258,129.358016,80.072688,176.471602,222.267397,233.999772,212.308986,133.568661,94.23234,45.772342,31.737268,75.896267,212.333007,264.373767,260.785138,209.65172,113.922418,90.480909,26.826568,-20.591329,24.257606,190.946012,243.365671,204.756446,128.547347,-44.338082,-98.369774,-66.234792,49.997784,79.919797,98.38163,101.914186,92.57131,68.72627,19.13541,78.386296,114.66874,101.217675,70.77159,-8.998982,-65.615731,-161.419992,-166.558326,-62.252031,82.598538,127.333458,128.876404,72.151535,-78.485838,-124.025877,-172.364917,-140.20905,-74.792825,58.160963,93.670452,85.521382,56.800543,26.367477,34.406032,67.198218,100.847619,132.547315,208.854002,203.885296,40.864346,-69.370844,-137.398562,84.649492,209.049569,283.984434,253.95175,152.507763,93.835453,-26.071888,-71.87068,-37.582906,103.217707,117.144289,32.026256,-0.755047,13.119617,35.746121,48.887529,83.59453,128.435511,169.211514,135.375801,8.01513,-46.9675,-110.864637,-133.01194,-132.114952,-28.880488,47.612056,134.729643,105.212234,7.124366,-10.147228,-51.758484,-80.937162,-26.554473,155.217517,202.122439,114.741708,25.723563,-75.465125,-58.999928:-594.423078,-461.887557,-366.354619,-270.890341,-272.26293,-257.231874,-215.738087,-152.598224,-187.504794,-194.367694,-168.153486,-181.115475,-276.657226,-323.040167,-337.315728,-309.922748,-259.229064,-239.905926,-237.905756,-226.013637,-215.749237,-223.376733,-246.237213,-291.62616,-297.361209,-289.191746,-268.884913,-270.986824,-332.667023,-363.293986,-354.28857,-341.587103,-271.21963,-54.156528,49.620098,117.549117,86.10706,34.398467,64.222257,159.769417,118.53714,79.947685,126.6003,196.603013,250.025787,213.725847,126.858441,115.73447,207.959511,344.520841,362.455159,302.6129,253.492591,175.119742,133.996897,-18.342894,-128.549809,-158.071851,-301.951728,-376.344843,-354.798149,-280.611965,-162.102118,-136.011326,-80.740385,-35.060032,-36.901023,-34.076845,-27.086816,-32.256648,-54.805421,-173.338447,-277.562039,-279.860043,-234.819372,-198.435471,-109.145875,-83.435722,-77.739068,-65.89835,-1.220487,9.80908,-22.03689,-63.553617,-71.815098,-180.778085,-264.49674,-363.461193,-367.323424,-339.556704,-260.265322,-217.484986,-139.316499,-112.122542,-66.521202,-29.759001,91.867926,117.807199,69.077438,0.978532,-6.435592,-36.92401,-39.941473,-10.92963,-6.080294,-4.236757,-10.159032,-24.893439,-25.755226,-11.957863,-47.802389,-107.399798,-201.49623,-162.948432,-121.212463,-80.651861,-78.318599,-84.410209,-92.237899,-114.769633,-98.137683,-55.672522,35.795078,48.509801,-18.917144,-71.900622,-137.164844,-137.00503,-59.031364,-34.174111,-86.528416,-121.470749,-61.890067,9.625422,-13.68184,-66.093545,-147.45114,-196.587104,-185.753272,-115.318198,17.268044,32.887183,-39.721356,-101.217208,-165.699869,-135.462749,-113.049376,-88.470558,-91.527697,-143.711769,-198.343368,-300.393401,-224.099651,-130.733123,23.497736,59.147265,47.046825,13.515161,-32.431999,-25.512378,1.81378,-4.83781,-4.24589,21.556093,24.529049,21.691124,31.715966,23.650209,61.889066,127.424956,236.402429,252.509999,207.11484,165.30878,111.080197,96.641759,45.852454,-15.303382,-20.562323,10.307353,28.776222,76.954563,111.162563,191.940043,217.484729,176.190126,84.908972,77.561146,62.858104,58.77947,119.70361,135.006295,80.164606,60.648448,63.410229,42.062468,31.749609,41.398845,50.480749,23.707063,16.013219,55.498942,160.225598,174.728219,50.239105,-51.450902,-159.21749,-137.87794,-37.231084,-25.152967,-36.470357,22.39454,80.895783,181.822963,218.541577,261.719997,328.024032,363.719093,351.491097,327.331317,323.848443,326.277029,256.915602,183.501055,102.278345,184.760062,220.932391,209.518891,188.586342,178.653969,185.979206,164.978861,134.561283,136.179545,124.13441,125.590023,209.405991,271.895448,293.136963,230.103591,158.117618,308.380041,375.038575,309.937976,199.566397,5.023035,-31.885275,-55.548023,-75.442874,-40.84946,79.87939,115.875639,98.542394,71.581727,47.882266,37.010442,-34.821829,-144.435298,-160.445872,-98.207776,-86.157842,-166.215942,-212.736336,-272.179901,-295.479846,-276.864305,-182.548551,-121.76176,-47.874908,-46.036339,-56.798579,-63.441329,-54.386135,0.260867,15.498072,83.452869,147.267666,199.894736,164.670515,91.889776,187.821377,251.332391,205.165981,118.959129,-4.556743,-26.760592,3.796852,36.061027,40.820214,14.306132,19.016205,59.038119,75.528725,60.09952,30.212672,-82.139401,-184.100855,-184.326715,-90.975435,-35.088797,-4.255473,-23.995572,-41.236741,-24.702517,3.914969,-24.606593,-34.011581,-35.930163,-44.442135,-47.170356,-19.945486,50.079889,51.385433,70.885962,177.708112,203.799656,141.472336,104.319115,108.294565,126.542749,158.762501,134.705503,97.325486,81.802952,101.430072,136.98849,164.143279,187.363394,54.982288,-34.130803,-149.877777,-172.383733,-148.750621,-109.335968,-63.02021,-67.793045,-9.468679,115.26448,129.141774,123.856314,138.691297,127.476275,85.479914,-23.939474,-53.26432,-17.608296,60.053051,99.096959,225.304292,279.414965,270.184331,214.564527,76.143259,-7.24346,-15.940687,5.8999,14.911725,-49.247027,-119.393289,-209.33376,-139.048191,-85.028189,-39.261139,-33.793035,-27.032391,-46.913868,-134.433043,-173.683782,-203.280057,-217.892776,-239.867212,-271.56586,-258.134349,-155.990337,-87.51146,-3.569239,-3.338137,-1.248267,40.894691,60.195186,28.635152,-21.780666,-116.22324,-145.498498,-160.907686,-143.888618,-142.132074,-109.154292,-74.768412,-14.085872,12.421231,60.633977,76.380529,73.030034,53.778207,26.529489,-83.374267,-139.16693,-157.741169,-130.354433:-405.933734,-403.103316,-368.813473,-192.783133,-111.27853,-82.783318,-99.356847,-86.691359,-55.477123,-42.02649,-28.198534,-47.955383,-136.406105,-171.489218,-216.480947,-240.224461,-237.547089,-181.182974,-178.271881,-198.001848,-196.341597,-180.873103,-191.382239,-295.95124,-333.761096,-282.620295,-191.996583,-188.552427,-232.847308,-246.559909,-192.820532,-139.832624,-36.854416,72.429229,152.993192,302.529065,310.207473,206.247549,159.619652,144.260281,135.89346,110.457833,131.709013,200.166454,314.469645,312.744252,232.278742,201.275851,207.075137,261.840136,303.749224,347.571641,298.153825,137.062885,93.95286,23.743542,-126.821523,-211.149166,-312.437715,-286.022256,-149.918891,-126.688449,-177.228111,-187.011899,-111.45587,2.71489,36.701973,78.041051,90.498125,46.574848,-15.577296,-194.181882,-370.096996,-411.807613,-338.00784,-261.75115,-225.258275,-263.973234,-327.803957,-341.069035,-314.175695,-221.822645,-197.911848,-239.882408,-295.816433,-390.464841,-397.904537,-383.076467,-344.43001,-283.63836,-110.466398,-35.157756,47.168784,60.117023,59.753255,40.948996,-31.575076,-41.501256,-24.543153,-6.519584,-1.068728,-0.49666,-22.128584,-91.953575,-105.528498,-111.943205,-131.816602,-116.638012,-78.681395,-76.718425,-90.58705,-93.367808,-88.851688,-114.301,-115.540512,-33.175821,3.984121,-28.399027,-66.270644,-111.124061,-110.452853,-104.51491,-94.677736,-80.316908,-73.218788,-99.663073,-153.947418,-163.956726,-178.589072,-191.122129,-183.696354,-149.52831,-138.788046,-186.982785,-251.125254,-409.508497,-477.624847,-432.54269,-220.995213,-128.414377,-136.191936,-202.990499,-279.927722,-283.663522,-286.538436,-300.292946,-303.641922,-249.516719,-192.306844,-133.259227,-156.860936,-241.478292,-243.472509,-208.972479,-142.217111,-104.730453,-20.619486,-5.911602,-33.596249,-35.892006,34.481228,129.244058,158.749094,142.72773,88.406317,-16.20934,-27.82535,-37.790721,-19.809266,47.892188,206.031704,245.982031,213.184105,166.585246,111.094159,91.926137,-17.926713,-154.353596,-156.29429,-37.278789,7.969631,1.590098,-7.144934,3.747112,-33.324105,-66.870564,-85.403966,-75.134088,-59.937121,-47.348958,-17.21818,-23.041703,-68.620767,-54.973485,-39.298253,-79.721963,-115.766055,-109.856339,-79.179783,-87.498419,-109.280654,-63.351226,96.033002,163.924661,163.036753,98.743733,-12.283563,-35.989618,-58.955882,-37.216196,-9.594446,77.15657,143.191874,274.10268,311.706603,314.594145,266.760874,248.755663,213.81097,183.02387,85.590614,24.288804,-66.96028,-80.636973,-44.183534,41.999536,72.623637,84.264013,80.254797,101.238123,118.508235,88.745216,21.874815,17.838283,108.482148,195.945747,339.952397,364.599585,327.596144,267.057948,152.182302,206.284639,268.893403,311.559097,257.281229,95.101178,52.587913,26.866769,35.180757,83.004263,214.725472,246.693678,218.645362,204.159726,232.468486,212.720021,34.209015,-26.886569,39.671133,135.023825,95.621867,-72.735713,-142.319542,-190.860173,-163.764483,-154.401522,-121.345232,-71.864588,48.565621,76.137793,60.20027,41.219785,36.697878,75.018335,103.294637,219.805638,288.080682,326.715986,280.104919,153.0179,147.020039,170.033971,142.344524,98.339263,53.156053,59.475818,66.151053,40.855923,-12.747686,0.276889,-5.567058,-52.990617,-62.159824,-34.622979,-26.923115,-68.626577,-112.811995,-108.577107,-50.37459,-10.539504,33.674219,18.626921,-52.402725,-73.055196,-51.678425,-0.169293,19.50521,43.397077,45.517939,3.970009,-25.735149,-56.522332,-64.351826,-54.250897,4.110224,37.433207,40.487336,5.736056,-35.540924,-13.906562,49.722784,27.208605,3.663031,42.731171,84.133487,90.865985,69.295998,25.381839,-25.519272,-43.866834,-80.096805,-96.258879,-114.97533,-130.011212,-168.040801,-169.130391,-67.732283,86.687198,115.086519,101.413467,93.626027,61.608012,23.813001,-63.790475,-94.891023,-72.177826,18.946042,73.173075,141.251998,138.364024,134.866491,148.436507,141.832279,30.666131,-44.988667,-120.899453,-110.980681,-123.611063,-174.262253,-221.501119,-68.226001,1.972934,3.850699,-5.330762,18.971432,25.679053,4.08995,-44.714641,-184.84857,-203.272195,-172.517025,-126.9659,-106.124648,-47.195462,-30.158183,-50.687016,-45.306566,-25.670862,-14.370635,5.593261,99.113715,130.075757,114.633462,82.240186,22.538549,-1.019303,1.818631,42.835979,62.681866,85.676523,110.269994,175.440222,207.772611,207.807632,198.073015,195.165655,149.837374,114.537734,66.962624,49.135408:-430.907603,-371.926776,-351.421275,-278.114033,-238.971478,-211.312257,-193.328196,-141.926181,-119.081511,-92.291712,-18.641938,-24.457719,-115.118252,-151.477767,-197.733024,-201.246216,-137.846031,-105.893017,-117.75141,-127.087227,-116.841283,-108.659738,-133.316863,-213.194477,-217.676237,-199.378827,-223.921883,-272.42859,-349.73838,-344.707628,-288.530435,-287.150091,-304.20103,-184.106061,-101.51249,6.385975,31.936996,49.907734,46.311392,58.824078,146.876633,183.676229,172.407322,145.91048,102.178956,82.342073,109.057798,169.700763,279.71225,339.053739,382.994764,395.32016,308.870882,100.253499,61.221296,35.596972,-49.101128,-107.289931,-235.87086,-277.765428,-241.251958,-173.539937,-55.018491,-44.600147,-102.807449,-142.408374,-119.441821,-0.028099,30.286889,-54.93893,-120.311715,-198.095234,-222.545281,-219.756282,-155.355372,-93.959307,12.043443,42.176306,70.003945,53.270035,-10.487987,-46.2114,-64.631455,-57.280529,-31.802737,-80.089909,-172.589694,-378.301739,-408.428084,-328.900663,-96.230058,-12.037696,0.288054,-35.370393,-46.611237,-19.855423,40.844702,70.384159,49.558508,-41.164928,-73.784538,-58.93717,-40.121644,-70.011929,-75.15618,-39.225894,-3.674678,-18.032212,-38.132898,-46.749451,-122.919588,-181.976216,-237.737172,-124.608983,-50.61115,-14.306142,-55.260857,-171.226143,-193.839679,-85.809788,51.320053,42.954918,-75.359955,-113.385298,-113.633422,-119.598133,-201.094333,-233.406185,-153.399604,-38.016603,-38.089517,-68.736641,-70.012742,-73.895269,-88.777936,-162.588933,-200.963916,-170.456598,-33.368116,41.835373,77.348016,12.72295,-171.805025,-219.99957,-168.574755,-69.041376,-36.168406,-31.368997,-79.199331,-147.122431,-119.735871,-73.331994,-49.003167,6.381611,127.452171,154.422591,137.489838,94.765756,-20.406607,-60.163598,-72.860102,-54.208844,-53.489734,2.174062,50.227698,75.088526,48.186194,-16.159443,59.817998,171.043899,345.137296,329.339722,139.043534,63.291556,60.562899,83.13859,81.981551,61.738574,60.514118,78.177603,86.366464,113.520418,151.333841,197.271799,142.316725,117.068723,95.218823,93.586985,77.231614,75.006222,130.881882,137.829001,51.863729,87.898647,170.766576,247.809504,213.880735,123.93974,102.625068,107.501021,183.391897,221.600697,199.696168,148.658292,35.884937,-25.166963,-133.674141,-154.727178,-96.840714,-31.073525,-42.320468,-67.120573,-38.168334,73.781695,110.238996,129.139776,194.907487,232.130638,266.562843,280.89362,276.62119,242.303628,149.487789,104.720209,63.222503,103.195897,119.909252,160.431059,179.710229,106.152089,26.7387,-50.481376,31.603946,79.52021,99.269837,86.959145,112.864317,162.080865,207.509709,153.349246,39.733837,109.686724,145.708397,92.115718,13.69153,-137.22334,-153.526602,-67.126158,2.441749,-0.089596,-2.903088,26.692423,90.050095,92.794983,20.053032,-51.808162,-170.314862,-156.547697,-122.064522,-72.642918,-73.331662,-106.900613,-130.314331,-216.923555,-254.206166,-223.948111,-178.171636,-170.27576,-146.152871,-138.098506,-102.650056,-69.925538,-19.963095,21.760529,65.749541,173.237553,197.364502,157.651275,110.518453,12.299275,54.160277,138.208002,249.403781,245.117578,149.646646,92.435538,60.191217,74.442891,102.704257,172.307578,217.160376,252.749555,240.564115,189.780396,160.689773,96.387996,33.642378,22.996869,53.897942,76.537385,56.845446,16.871709,4.632027,56.465003,177.68784,152.937214,102.942686,26.518404,-10.01982,-74.875868,-73.62475,-38.927473,-22.798725,3.106708,80.206409,95.798241,52.567041,32.325835,67.228563,93.832244,77.582853,-21.939915,-50.765355,-12.630054,20.147971,76.092351,91.716687,75.755773,75.71954,65.99587,-8.164266,-41.127354,-78.765619,-105.204018,-174.328699,-196.649446,-133.682738,33.456852,63.139267,18.062646,-12.318351,-61.932076,-78.89199,-108.465077,-83.772604,-56.019029,-25.043704,-3.558936,39.493146,55.430443,118.04073,136.533385,104.185409,72.387392,66.212695,65.596997,57.037249,-29.330058,-95.124651,-143.285276,-19.544023,58.668146,128.911236,115.166444,46.26426,9.707268,-71.913153,-122.275969,-172.992474,-115.241701,-104.475361,-141.373867,-139.351454,-45.067385,28.400261,117.398511,54.692531,11.542607,55.754072,132.520224,147.65514,63.017263,-62.160516,-81.748022,-117.315849,-91.727764,-58.23928,11.75105,24.954168,-33.903304,-75.972095,-86.567548,3.408579,51.996326,77.535578,51.297478,-10.067012,-26.213025,-77.463479,-112.168874:left
12.534893,-124.686349,-172.096484,-143.978119,-82.09421,-52.210565,-112.896546,-232.425691,-219.604003,-189.547654,-157.373143,-140.827826,-30.8917,36.9464,83.437678,81.54138,112.40745,136.021532,135.597163,137.087031,130.450284,76.281526,49.629675,30.874143,-30.428854,-71.318373,-65.675983,-12.688738,107.90536,128.269777,38.49591,-36.798324,-97.023661,0.052201,33.305658,-18.244446,-39.073719,50.68601,117.67848,114.07794,-48.230296,-78.557757,36.754784,119.690678,242.331359,262.202524,150.432246,59.22166,-53.084168,-118.687343,-141.044114,-92.417683,-25.260321,47.056116,20.983189,-56.563776,-90.79295,-85.628313,-39.007245,-17.849999,-4.644123,-8.431287,-40.348168,-82.946779,-210.300691,-240.864231,-185.372832,-32.017849,21.327775,30.271024,3.325921,7.952233,115.076974,163.879863,189.835884,174.226445,139.128874,137.722175,128.949177,86.763875,4.714011,142.566317,252.44098,353.252086,342.493428,260.683821,209.455375,145.114247,133.54831,135.940504,138.405442,131.669172,103.829857,75.760629,-23.66865,-77.046101,-123.477326,-23.549841,67.592162,244.684581,301.382958,288.613388,231.714072,70.361299,-98.492275,-113.540186,30.01251,112.217898,190.462821,198.703432,161.901276,117.822112,21.454777,5.683262,44.775511,172.12841,222.768362,169.20039,67.683856,-113.196427,-135.062785,-99.725034,-65.700336,-101.547447,-182.607964,-192.291652,-181.06287,-168.129299,-111.308429,23.862402,80.770516,103.011786,114.690939,192.979054,224.77216,208.772794,123.3464,95.731144,100.215001,109.316464,98.805377,81.284642,24.712831,-25.231377,-168.756609,-225.438277,-198.565888,-137.584168,-120.023481,-83.87405,-73.376312,-100.548426,-145.822279,-144.013866,-72.483585,-17.590361,78.402788,91.945673,53.535792,45.086245,35.420349,-50.23864,-74.868748,-37.791066,-18.029828,-70.167693,-113.826665,-129.869504,-56.788613,24.212109,203.117336,226.423838,147.459325,93.732983,-14.278868,-66.83801,-140.877917,-94.030976,-23.64652,125.558206,197.593065,282.463396,257.5753,75.527859,-115.564213,-115.345073,32.510993,69.473213,31.210145,11.769013,-17.090008,-33.265403,-29.549673,43.042332,91.641171,203.78495,265.59145,330.824221,301.656669,119.392567,7.22618,34.876271,81.809311,62.794721,36.94791,56.603439,130.477259,140.419975,37.409693,-51.611346,-35.807107,41.677134,75.434598,88.135404,59.585065,-35.800111,-146.451109,-161.887647,-45.332148,44.745865,123.469928,91.914694,-23.781807,-77.996717,-177.198317,-179.868606,-130.270766,-46.45442,-33.87921,-49.25086,-70.146372,-78.815261,-61.522959,-75.157603,-108.190616,-96.02035,-60.63847,-98.136724,-262.608196,-315.550609,-300.854754,-176.895775,-115.697017,-31.764782,27.79746,136.539739,126.108903,0.690664,-105.331972,-94.406678,24.480332,56.782309,31.348112,10.759291,17.50601,41.970795,46.266169,12.03209,16.925621,68.878813,111.004993,172.728178,165.330213,121.473753,122.487583,122.773719,79.305189,52.552285,48.569946,53.346285,13.642143,-2.417874,28.857716,51.980181,38.915861,5.105323,14.472956,50.480249,29.898226,-115.489195,-263.547656,-292.077594,-276.238683,-240.447232,-97.351246,-16.310615,44.092888,17.136826,-85.537304,-152.786012,-151.472145,-73.254422,9.067492,170.281505,190.790705,105.869202,-18.18783,-30.072511,72.920017,123.037069,142.13218,129.366466,63.071204,7.257718,-113.092954,-147.661509,-127.722203,-116.450752,-138.587674,-199.51143,-228.035434,-233.38636,-173.489665,-154.566204,-166.829352,-175.363874,-164.385734,-167.198995,-214.959435,-230.300263,-151.985589,21.054039,69.619994,116.993317,146.149093,108.854212,31.761518,-132.47276,-243.531442,-249.503952,-159.881617,-99.850192,-17.501007,-20.530893,-147.559797,-231.542364,-297.493717,-203.44619,-146.927591,-92.056882,-84.153108,-88.159953,-110.937394,-218.004721,-344.261359,-348.407655,-235.630897,-189.195802,-174.467746,-171.570316,-131.765884,-116.542812,-130.388266,-125.907046,-91.194276,-54.970655,-97.07379,-228.093544,-263.573707,-282.43493,-309.078969,-299.648352,-189.844085,-113.891344,25.301097,63.588808,44.219804,29.427012,62.206278,81.716057,72.404464,89.232793,121.260155,134.137257,96.37255,44.282511,90.160157,117.605981,119.641801,106.41877,144.515823,198.469161,268.56606,251.77687,138.189613,96.763206,133.013136,187.288672,178.971926,93.154818,21.074207,-83.756123,-64.734566,-36.849687,-39.64715,-66.486728,-112.772108,-139.539073,-206.712891,-224.360564:-97.86356,-135.238493,-156.367719,-202.791628,-212.842018,-231.283207,-252.397188,-313.382137,-354.197079,-338.595265,-235.115533,-165.740318,-56.38317,-36.766216,-42.271005,-50.13944,-67.844757,-44.54867,-4.373364,90.350289,98.363765,-15.879858,-87.455936,-152.85263,-137.662191,-112.367651,-52.816128,-23.68992,36.255115,42.866067,-34.084652,-86.437376,-105.680378,-50.26916,-44.43017,-29.697721,-2.26959,37.070797,35.527485,14.760237,-2.352023,-6.02138,32.417635,72.3722,128.332816,123.574043,53.581865,15.459692,-15.742088,7.396206,36.763932,90.941061,91.115127,66.084541,68.534464,56.055927,-40.316768,-58.761251,42.250199,111.14788,121.311483,75.295796,61.396604,90.277263,53.409249,-27.576726,-9.238401,106.948055,159.267418,185.804289,152.32205,47.528942,66.915652,147.442394,284.26981,277.290192,174.707722,130.584228,75.070226,43.616899,-21.795002,65.537136,181.564792,402.910375,449.541389,404.290822,351.249188,248.233965,158.915309,125.648319,89.349377,97.763503,115.544454,88.517652,38.951174,56.112543,108.389482,146.37307,189.441381,321.909095,374.16297,362.348742,304.103676,151.680833,38.554025,22.669509,90.139671,159.38963,260.93594,259.764549,138.0343,30.224815,-140.017744,-67.682438,39.189163,252.13053,308.362982,260.216936,185.713483,76.568079,59.783892,56.614479,46.935816,47.878494,35.799155,2.835226,-57.877986,-53.459811,-1.518295,98.121669,160.368161,254.424001,278.038297,270.60307,247.74856,178.74797,70.16913,13.436734,-69.711729,-74.758567,-8.203108,4.477981,-98.02297,-164.362439,-225.097765,-213.884914,-172.207165,-53.463036,-26.571306,1.83039,35.178951,26.79778,-119.011252,-159.161394,-62.822843,19.600257,57.343784,25.620273,3.407241,6.907516,-7.327206,-19.058433,-25.229214,-51.451361,-82.762369,-191.379319,-237.5611,-261.092548,-228.548723,-187.941562,-79.080472,-39.415821,10.749148,16.082319,-52.195398,-115.709463,-230.769238,-150.409683,-33.352873,150.409916,174.555261,128.105482,78.750488,-37.805823,-115.652353,-117.206177,-72.831974,-70.851367,-152.887629,-196.867983,-221.120898,-222.261618,-223.633384,-136.256311,-64.611274,77.265925,133.160337,139.336023,77.499613,-92.637847,-156.68393,-131.300038,-74.626136,-63.587243,-76.623355,-98.768184,-52.118551,22.634663,89.786679,42.863647,19.826592,-3.271604,10.180626,49.746075,41.885311,-32.531013,-94.477192,-95.300719,-20.941467,41.454074,82.692891,29.20832,-104.99785,-132.90065,-140.514598,-110.675462,-71.791076,9.716442,25.639749,-30.76107,-72.256288,-99.34875,-121.994911,-118.272935,-16.464016,58.338934,135.603668,92.854597,-102.987074,-188.843258,-261.981399,-245.512737,-209.649864,-48.356109,52.267314,153.238201,144.97352,47.748771,-102.257447,-148.482783,-122.134906,-46.639095,154.905397,211.132371,170.579733,110.910965,18.534938,58.611149,108.243701,177.20902,200.572836,222.585183,197.039135,84.792571,80.818901,153.559514,293.067521,299.868467,223.898672,191.002026,188.249352,188.365832,107.982635,47.823542,70.06605,136.785784,148.429224,81.26059,12.844574,-105.675363,-105.39017,-69.94257,-30.305851,-24.378351,13.077518,49.540773,105.226503,80.393273,-81.763203,-122.975785,-66.679811,29.008971,56.085078,77.021577,60.154656,-10.836586,-86.852332,-94.564693,-34.181228,20.373573,118.354708,125.984812,74.067881,33.211605,-96.460002,-170.256529,-152.226124,-131.513326,-150.161831,-204.379766,-230.765934,-282.013983,-324.751905,-302.812353,-174.158556,-117.833174,-87.981692,-99.650093,-139.465584,-187.205768,-252.581154,-60.585394,73.37619,183.222009,160.191114,106.555541,90.594282,-10.248947,-143.873911,-141.567904,-27.843618,15.224255,7.461313,-23.67405,-99.936997,-145.290609,-202.828135,-143.857774,-108.749394,-88.217858,-88.483753,-109.667115,-130.374885,-183.795757,-277.184969,-300.516604,-216.446727,-140.828672,-64.006369,-72.050244,-104.396803,-115.809122,-126.37217,-63.557267,-13.13021,7.452389,-41.034313,-201.479501,-264.228286,-286.514607,-254.509264,-231.130943,-162.751164,-125.63827,-45.937599,-18.263361,-42.712713,-80.532768,-78.238988,23.575314,32.156638,-27.49797,-26.644627,29.739345,22.237859,-53.952643,-67.450007,-55.217035,-34.458164,-2.750466,114.493383,163.351042,183.72883,151.555115,50.098828,60.055599,122.756647,228.674761,232.577493,150.337608,90.177931,-19.859561,-103.410802,-119.016298,-96.220402,-70.806259,-27.836999,-34.327685,-92.830087,-123.092599:-39.552743,-89.44734,-132.13741,-171.200781,-176.813378,-227.494892,-258.407663,-293.858691,-310.744274,-293.62744,-220.316133,-169.850739,-57.484805,-33.214838,-58.75985,-71.77994,-63.122174,33.132217,105.879339,176.535538,155.450657,51.632331,3.423734,-49.893973,-74.043221,-63.357826,-10.588395,23.284231,106.350965,124.192207,25.809009,-71.973359,-196.527648,-113.324444,-75.161471,-103.844057,-96.728401,22.626113,62.002234,19.473554,-20.170581,-13.386508,4.245503,37.990995,158.706124,180.576946,113.635964,68.315115,29.455144,89.712357,124.155638,163.491219,185.565361,196.559207,159.45896,46.714724,-11.949468,0.601744,70.757085,103.800855,137.204785,134.29971,120.785585,107.195901,17.413033,-24.897122,24.76888,176.09851,216.408057,160.937891,96.866662,12.218559,52.307962,114.335931,230.055728,246.076439,194.252838,152.228803,87.117703,63.566523,33.936543,110.46819,209.361348,415.155188,449.498144,364.929985,305.734098,213.199283,109.04633,64.537644,-2.621233,-28.960418,-20.640645,15.3395,51.822818,24.215494,-34.668966,31.150318,108.329436,295.875291,349.878867,280.325883,212.441353,124.343973,39.793681,25.934012,108.433265,180.318641,272.417263,254.150094,117.64398,44.021663,-38.826009,-4.299095,64.477266,303.439055,408.902673,360.338538,230.264898,25.743243,-17.411958,-15.684053,5.776673,25.725362,25.867536,-8.655298,-72.818031,-86.165032,-79.064484,27.001522,81.730905,115.484224,114.843631,97.375943,71.289443,-5.277853,-65.301918,-58.808965,27.481264,73.925824,87.063148,43.253033,-78.201237,-126.539381,-176.927159,-142.49636,-106.192169,-37.007234,-5.327023,52.660117,69.887061,33.019624,-47.144841,-52.924315,6.566644,22.010954,-45.696122,-94.530212,-140.398223,-147.7977,-153.720763,-124.451154,-114.979175,-129.075647,-157.74771,-274.12889,-318.823364,-300.795891,-191.903352,-116.622616,12.937566,44.503694,36.628568,1.496208,-75.560971,-102.166017,-162.99129,-115.482419,-34.025815,83.493119,100.224024,69.46535,10.681762,-152.811055,-213.932933,-175.005986,-64.20085,-50.441084,-145.010762,-225.13722,-314.923295,-302.506116,-228.066994,-125.99545,-65.24601,45.467043,59.766536,-10.384669,-53.894542,-129.706766,-158.750126,-110.272578,12.476893,24.504765,9.411816,23.272487,59.994784,58.552029,45.819754,56.637744,56.789156,80.869733,115.137244,112.542325,49.301658,-91.24407,-125.71303,-111.249534,-40.636619,18.679212,118.897329,115.42597,-3.128367,-80.116223,-177.497885,-149.997564,-101.15636,37.598189,90.84109,68.344305,28.974979,-2.229036,21.622792,52.071188,89.998643,87.89119,81.704135,75.254062,9.013267,-61.965665,-177.224374,-89.198619,-0.620902,115.436312,131.054246,118.722874,96.54088,-2.830607,-133.704025,-148.9717,-7.835175,103.798496,247.710425,252.368923,173.020023,137.925194,155.083189,222.790728,254.045928,303.196999,306.633543,246.10041,195.073155,108.124339,102.012318,133.328999,188.656669,196.601104,200.294618,193.671496,160.374443,142.722074,90.350573,55.821523,64.693622,118.435995,154.530905,167.13954,118.846983,-17.706053,-72.222948,-52.694008,35.79423,73.08197,81.542898,53.929957,6.484641,2.757484,-22.417563,-33.020763,5.250774,149.857302,218.781184,249.912026,207.852042,43.424044,-95.612654,-80.559586,51.090257,94.091712,93.963133,65.129063,-35.237205,-95.048059,-162.7497,-119.686416,-93.27128,-113.446623,-144.414966,-209.918632,-258.045618,-376.426903,-385.712474,-329.852373,-222.996369,-195.960946,-177.345787,-182.98218,-194.110239,-203.948557,-213.341539,-104.146864,-30.61884,66.622606,74.266456,-8.896584,-64.973546,-129.802123,-147.93381,-126.058588,-65.006642,-48.21859,-27.657102,-31.170343,-112.37727,-189.302916,-294.474149,-202.62775,-124.971618,-19.636731,-1.749274,-51.744597,-116.727127,-263.605166,-285.127933,-225.450113,-91.605497,-52.857921,-33.903523,-51.740334,-81.575499,-82.122166,-112.079243,-104.825838,-45.78193,64.864042,53.207214,-68.907945,-103.467929,-99.136781,-154.734523,-164.699103,-57.388082,9.717525,46.693953,38.559158,43.513932,35.101597,-4.138712,31.523539,55.609828,40.363614,7.297098,-86.259545,-132.507359,-198.605367,-172.538344,-108.190791,6.632071,35.457957,91.186821,107.380696,59.874525,17.137393,-15.189679,49.916777,92.458044,141.164427,144.461354,116.557849,101.604351,77.707443,5.601172,-19.39336,12.19095,44.486099,53.852721,16.159686,-118.463788,-192.282681:-126.414457,-187.27805,-218.452429,-271.314708,-277.312224,-265.990043,-258.545086,-245.045375,-284.213495,-296.011813,-200.683438,-103.193991,80.19404,115.680449,70.292893,54.171293,115.343988,198.380852,222.829893,230.301609,211.335759,103.195018,24.22088,-89.652632,-106.762482,-85.831281,5.267303,54.2564,113.112448,106.852462,27.269899,-19.040069,-89.237832,-82.91213,-71.315655,-101.407791,-105.299291,-48.413176,-17.386046,1.028636,-22.163674,-5.588349,129.21013,212.473759,288.290163,262.809632,175.355481,139.428562,55.603446,54.035755,95.028854,143.476555,137.571505,86.812889,49.364854,-27.670389,-96.490996,-103.739469,-86.997443,-100.78161,-174.685127,-193.690062,-123.361723,-62.72748,-49.334235,-177.451029,-212.857749,-125.126091,-27.562411,93.916624,79.087269,11.960982,40.918741,99.280684,226.836239,258.646704,265.541232,259.109634,222.329537,186.64172,131.382803,195.566659,258.885751,332.428556,327.581294,226.568629,145.532224,73.389685,92.468718,63.861315,-31.010976,-54.761298,-55.069941,-57.25343,-95.681488,-123.746437,-176.494856,-169.938166,-111.853928,59.900433,110.266778,104.78238,89.455403,26.955123,-114.759356,-151.695997,-71.346598,12.263595,136.921152,148.299834,80.814467,28.782219,-52.140426,-35.183591,18.437433,162.712837,216.349425,170.66847,65.526469,-143.877729,-176.969221,-153.091104,-150.579811,-176.336776,-192.717641,-177.039547,-179.069761,-214.152167,-275.314923,-175.05481,-97.560644,-14.569835,13.145088,71.32298,73.49049,26.708792,12.043281,29.477503,77.53764,88.672166,102.69101,106.349321,47.293806,-9.764927,-116.382108,-108.895927,-61.175792,-27.192763,-54.13415,-38.766527,20.491512,41.652451,-137.697075,-185.338568,-79.246181,1.132244,38.32653,3.892989,-58.6832,-78.488873,-138.386689,-168.386069,-141.055577,-51.490259,-33.161022,-96.303827,-148.847443,-212.440354,-183.176731,-112.583375,98.353163,170.355863,147.146101,75.669329,-40.482407,-47.669751,-42.292556,-48.244554,-13.677026,104.070803,151.793899,173.339894,146.484771,29.087046,-80.97421,-67.206831,63.214409,106.460192,65.589567,6.170056,-57.746686,-31.364232,58.068345,65.213486,52.996585,120.740764,207.754814,307.490659,270.834935,142.238408,97.442654,115.511232,150.126697,136.25967,96.87664,109.370406,197.539725,224.35885,131.739027,-14.75318,-17.100744,97.439639,165.328721,229.038083,204.254391,80.189426,-36.701336,-42.301043,69.876923,128.06009,136.973906,104.131532,38.989809,2.064016,-112.042249,-196.318394,-176.462134,-20.931941,56.431389,82.659697,51.371832,17.386934,-6.36273,-13.301284,16.807045,26.163728,39.304552,57.957316,51.451956,4.856166,-107.208241,-84.154309,-26.167016,98.247471,152.566177,189.344687,148.000898,-23.313085,-179.754044,-201.185039,-113.544714,-21.421657,182.768879,244.065114,249.747276,221.473205,161.702556,178.72977,200.714135,219.232052,241.794854,275.169239,239.887901,85.316564,23.94504,62.513276,112.856053,99.646253,106.654276,120.503285,92.627047,54.98498,-32.428295,-12.701649,37.543534,108.888229,134.658068,185.27043,170.597238,17.810658,-82.050834,-75.167396,-95.785819,-119.687169,-42.271673,38.197366,84.855634,48.102732,-29.126518,-34.604864,-3.418373,108.656886,169.133725,201.333807,170.439809,78.145849,-34.12602,-57.222256,-2.852423,42.531448,115.248002,119.979717,13.113948,-72.562871,-165.284149,-107.471693,-79.794142,-111.929419,-159.05047,-298.247983,-374.352414,-448.072287,-405.243421,-374.640239,-336.780598,-318.665758,-281.020405,-275.240503,-282.47131,-289.341844,-275.856301,-167.059857,-113.962205,-80.229748,-70.607404,-49.055978,-77.229648,-209.344417,-267.795694,-244.072059,-198.332171,-202.526914,-206.431153,-201.042253,-244.256204,-304.89965,-381.185377,-223.116293,-114.991946,-19.349822,-26.25689,-109.008401,-172.631071,-273.567589,-279.577313,-250.644909,-209.129286,-200.927288,-172.556518,-166.767721,-171.929663,-155.589229,-101.47158,-65.451483,-39.54151,31.43314,48.61621,-49.73058,-149.78075,-271.83695,-211.263676,-142.774121,-16.346487,18.84913,73.122264,101.627199,107.386508,94.573857,113.825073,180.178526,181.745593,108.434283,89.650581,89.67919,63.954751,2.602609,25.52739,70.73858,167.847478,206.790213,282.997916,300.868997,248.166591,201.459375,119.759716,70.921144,72.345032,101.958978,115.545274,130.919646,133.160899,117.641449,99.845537,104.660716,89.74917,59.598191,2.619639,-28.117602,-117.774699,-164.57418:-281.763625,-253.922934,-231.072118,-182.078717,-172.280861,-192.795774,-199.472103,-244.694359,-326.563137,-313.866976,-183.012273,-104.144702,17.340982,32.656712,25.256722,44.263994,84.59318,133.367933,178.329033,210.636737,183.940751,79.431508,14.54402,-67.359118,-73.195379,-69.664448,-31.34581,12.205776,92.861034,98.620391,7.192725,-75.27534,-188.113101,-179.132141,-181.985822,-179.157096,-128.659376,-15.799621,-7.034324,-66.2921,-98.002106,-51.224764,136.90839,238.597256,373.434312,375.38011,285.063411,227.290541,141.272588,187.416659,240.186284,297.745109,291.864454,187.589927,100.183265,-53.567481,-140.543943,-135.319215,-33.550673,15.046423,55.478852,45.279626,-50.307932,-118.132377,-213.771341,-192.111595,-143.371434,8.268805,82.251034,110.462613,68.595949,-21.103057,-0.882538,73.985847,260.012863,323.031453,366.826875,361.74266,335.020095,310.580091,240.688894,236.446964,266.992113,355.709667,406.152792,420.767757,342.137926,109.155672,-29.191046,-61.765621,-97.854702,-90.518921,-53.282305,-69.481256,-183.20088,-245.262465,-309.890792,-260.578099,-185.000253,23.866382,103.957876,132.323394,97.300959,18.396182,-7.298055,5.302615,58.94991,106.128954,208.998142,208.119489,93.070012,29.767734,-33.951177,10.410325,56.056402,201.615533,270.716308,208.504886,79.606681,-144.8035,-127.386187,-76.456102,-70.155944,-80.518088,-22.410001,3.109648,-58.409649,-121.883399,-183.436837,-97.369575,-29.680827,55.769536,47.673048,-43.58142,-84.302191,-105.090932,-94.385545,-70.563221,39.220676,102.162748,182.569383,183.747633,118.720732,51.866703,-114.185378,-107.821909,-41.818423,34.692379,32.269881,21.861336,10.717249,-86.022022,-207.122102,-209.011839,-76.965566,13.361229,89.227128,32.985276,-178.784845,-270.880464,-349.688411,-270.11852,-202.968317,-67.591568,-21.440572,-56.944886,-115.45522,-179.673928,-131.575702,-58.928123,117.356235,160.508611,102.814733,37.917649,-53.033251,-84.932111,-164.356717,-124.256437,-16.256406,207.75121,237.155488,97.504395,-13.036098,-144.415222,-139.922927,-95.074212,6.019872,18.656506,-4.869886,-8.416128,-38.021075,-94.036914,-184.781611,-46.461498,68.419005,188.630602,183.515538,127.027591,95.143571,46.94444,48.064148,64.292787,123.685683,169.46257,231.801389,224.327638,150.617047,85.321242,-56.756852,-86.044762,-59.75152,41.610784,104.529882,173.188661,148.250654,-21.243117,-186.626007,-181.196654,-10.455924,82.924249,156.117784,127.971726,3.604737,-69.704137,-192.630936,-184.441255,-113.064179,65.460528,108.865689,78.090824,57.404017,55.995098,2.294776,-28.494279,11.107208,69.014281,126.293951,105.00425,7.619474,-49.382226,-131.445186,-78.571302,-6.367952,132.406127,170.778127,150.035738,90.730256,-84.914888,-224.310634,-231.14846,-100.943619,17.50216,244.574127,285.016069,180.11596,92.936554,48.181739,207.718303,263.535494,252.742928,248.769402,251.007374,212.763727,70.14584,-32.888152,-22.809794,91.910644,153.627627,226.244219,211.080559,73.242583,-8.073116,-91.679541,-33.17808,27.145345,189.863613,270.814491,281.402698,195.860259,-21.505471,-119.68685,-96.486987,-4.521551,25.550476,72.420208,97.784675,117.965085,91.162188,5.200719,60.05479,141.261684,277.924417,309.730513,313.45578,293.964908,165.59182,-30.745457,-53.539832,56.044794,128.819118,231.864447,235.330572,120.273261,22.581364,-116.224829,-49.26604,-0.321611,3.232388,-30.605789,-144.477779,-222.618071,-371.863698,-410.890624,-368.529363,-227.60047,-168.605436,-141.18356,-170.32305,-202.970371,-201.01322,-207.091421,-135.216958,-77.62157,-21.001124,-28.133387,-55.81957,-72.019967,-162.236574,-270.8638,-295.187201,-281.229912,-227.193139,-59.689878,-23.47496,-117.385574,-201.826022,-292.222801,-162.359936,-73.641293,7.377233,14.564945,-21.707589,-75.287446,-210.031919,-258.479388,-225.104763,-141.122729,-113.683887,-85.58848,-102.164279,-161.006571,-184.189016,-226.460409,-155.217688,-84.64867,-2.32246,2.022381,-36.32674,-69.482712,-148.180604,-182.704582,-151.670054,-17.711513,48.616325,115.20821,107.637589,25.202085,-23.71239,-68.095863,-62.503568,-47.656318,12.976178,14.508523,-155.736562,-267.635179,-305.955276,-184.48212,-130.003494,17.580841,115.146048,194.29131,154.508753,68.306751,41.736889,-50.86852,-103.575778,-71.515663,31.547019,60.979166,38.799125,-3.23565,-112.201714,-150.921632,-105.231675,34.326264,79.886492,83.550189,31.608453,-176.007032,-289.102954:-40.638828,-96.888457,-95.000248,-85.48258,-83.008994,-82.157338,-86.077577,-58.211532,-29.861852,-20.985428,69.931687,143.580779,240.602746,245.513138,221.521538,229.377286,300.283075,366.567665,352.045183,201.847032,117.169444,19.243025,1.110207,-14.645356,-75.054554,-102.439668,-77.234216,-40.826308,56.239682,91.391148,24.739527,-25.877055,17.027312,101.80852,81.308162,-23.696231,-41.966604,4.688604,17.480852,-40.113127,-119.56221,-88.70353,145.51341,262.3773,347.369929,323.726419,212.459326,155.372128,56.182743,-13.766459,-26.562325,-23.353494,-16.249434,-19.861999,-36.298655,-112.993349,-243.962669,-275.275076,-214.564723,-166.145487,-94.221281,-87.316072,-169.187546,-211.156339,-235.900645,-288.521493,-300.132524,-202.176347,-119.832391,-31.041885,-29.550215,-26.392146,-36.764079,-34.775439,40.704061,104.673734,253.421556,313.590442,341.688103,316.575404,254.024333,247.613138,252.303537,237.446505,236.797008,235.520032,202.292783,48.490281,-129.928237,-168.954665,-143.654266,-114.057861,-50.660423,-38.358909,-124.298628,-209.604136,-348.303387,-288.923861,-190.353109,31.356149,110.967798,130.852146,81.697625,-67.983806,-162.354127,-136.938639,-48.091538,-34.065432,6.989018,47.036474,96.785695,83.59356,-11.59414,-60.385757,-29.463026,102.340489,138.971356,21.456326,-98.932912,-275.080026,-302.89968,-284.917784,-233.383226,-210.614881,-167.887041,-161.847103,-254.775782,-339.261522,-456.201208,-412.494083,-326.590062,-86.979849,14.741776,82.037452,65.492221,78.610986,164.833426,187.816558,153.057141,135.451614,214.899705,252.123838,108.807548,-46.436735,-258.059462,-161.267923,-96.5493,-140.462724,-181.85451,-137.457719,-110.060246,-185.175818,-299.492402,-281.178512,-71.747789,37.780047,98.821861,67.552417,-5.683105,-37.347231,-110.711903,-164.020586,-169.987638,-156.581943,-140.840745,-99.220086,-90.345444,-105.415694,-43.564565,45.268943,233.698352,276.403395,262.986916,212.385794,28.318404,-49.296583,-92.913582,13.32053,101.288137,223.4742,251.667744,289.590389,282.86358,162.825854,15.847954,6.793482,144.399376,233.230195,286.281856,239.557808,136.412841,126.110599,143.671281,188.073136,231.611297,355.564191,418.507475,453.616271,415.874435,298.847881,221.286228,218.485598,246.647172,246.464046,182.69954,132.67095,63.935251,50.588128,21.134099,40.705164,85.614018,168.556004,192.428299,212.177085,189.939435,81.965086,-2.449116,-5.362723,87.832707,159.266268,228.007564,210.8855,132.890426,81.730593,-53.734784,-161.652551,-168.433542,-77.395994,-0.454965,102.012496,103.291295,103.392093,154.015218,150.592036,68.837689,30.441801,1.270335,-4.472753,-16.761081,-39.538991,-119.805088,-78.065898,-1.569856,132.452036,169.152631,152.895504,93.863513,-65.515686,-178.49569,-165.648377,0.370925,82.434558,98.259003,32.186706,-77.496683,-51.344744,88.18531,160.719963,174.501537,190.516156,193.560725,178.617124,137.386135,-22.912218,-107.319402,-63.467492,89.801359,118.135013,56.681082,22.509103,-4.923539,-26.839969,-90.675377,-78.04133,-37.847935,37.389185,70.789238,166.440174,197.795661,86.631504,-154.703073,-217.212142,-209.300318,-169.267146,-59.684577,-30.630734,-57.065371,-71.874739,-82.9692,-91.191889,-77.131916,-12.587317,37.55549,157.45851,184.008841,112.722783,25.8819,20.173897,77.167468,120.734797,166.589235,153.648962,97.540794,63.970713,-73.719363,-163.839961,-120.080637,0.951922,10.307347,-78.805549,-146.267012,-254.499328,-266.759845,-255.293953,-265.21681,-263.081778,-214.641903,-206.727047,-258.813266,-270.16084,-189.494956,-70.235994,-20.471236,78.029631,105.418093,30.26402,-53.233352,-191.160249,-258.966083,-268.358785,-212.271321,-166.62202,-167.280076,-217.730812,-321.666344,-352.299419,-358.868071,-229.698668,-123.016718,-17.791166,-47.326748,-164.282452,-217.590873,-332.73859,-403.066122,-360.57997,-225.631225,-202.437277,-190.16525,-169.291312,-143.624056,-143.124661,-128.191755,-68.416714,-33.112729,-5.144856,-6.42052,-17.483242,-54.023075,-197.632066,-273.0801,-245.754984,-103.561848,-24.556615,118.076193,160.554911,113.38723,54.01716,30.315217,125.868555,141.31919,94.438494,86.368397,117.275624,113.580646,66.616259,84.696322,132.459428,218.148703,232.713116,224.449488,197.269108,127.320709,117.271228,135.16922,151.35445,147.729387,107.302186,89.980524,77.575649,59.928285,9.153374,10.880707,10.150175,-46.138961,-81.291671,-106.913555,-103.454088,-136.94717,-199.127297:-252.790871,-263.332151,-223.647282,-121.493362,-90.279383,-101.337741,-125.112509,-156.88578,-197.028835,-197.489412,-86.453648,17.14249,227.430191,274.866263,224.467707,177.7169,144.514853,211.249792,240.313619,237.175444,212.977948,87.828995,3.315308,-107.38977,-150.486816,-147.194817,-75.746065,-24.352811,81.949717,115.201748,74.421463,-0.612482,-151.57635,-99.877463,-29.815956,25.712967,14.489887,-29.847824,-51.700997,-81.941294,-82.65432,-30.44734,186.542276,302.609708,410.398507,389.168562,294.062902,235.931028,89.443088,71.499884,128.144743,230.240051,226.689662,125.667375,67.058552,-111.904094,-294.325743,-268.050213,-61.360674,-3.48541,-28.807449,-64.981425,-146.352343,-181.418993,-210.293634,-201.301071,-173.90173,-40.175658,30.145108,44.732926,0.360857,-80.79596,-62.619207,17.709878,229.10967,283.006926,295.609618,310.276948,334.364334,298.967817,183.790131,218.947872,276.143504,317.316229,296.973474,210.454223,153.987056,46.107999,-69.203838,-114.288514,-116.022052,-89.774201,-53.123929,-61.207573,-151.681385,-224.419325,-355.864041,-335.850106,-247.389334,-23.572525,43.526074,40.030751,8.43892,-82.992668,-187.929812,-184.879564,-47.603622,43.267543,143.782364,132.660122,34.04829,-38.383686,-171.189817,-107.351071,-23.23333,83.938061,99.41797,45.638696,-20.097488,-136.970992,-208.050277,-223.056924,-199.903075,-172.342037,-114.73683,-119.860542,-288.078055,-418.0937,-551.63774,-384.711207,-241.470875,-28.966948,7.046367,2.423377,3.891777,38.322451,45.751885,37.341436,66.202186,110.494837,209.463201,225.0633,117.18511,22.639869,-103.832116,-69.156375,-34.987678,-33.548909,-41.002027,-2.702619,3.106863,-152.75309,-397.79818,-395.529684,-92.279953,75.006452,187.962373,132.103231,-45.228747,-124.347144,-257.142455,-219.34895,-140.981119,-8.238428,24.216266,-27.474788,-105.393695,-192.913034,-42.833777,75.371763,231.423137,253.312267,233.065877,196.071387,60.0703,-23.080542,-144.625162,-78.798377,17.7208,175.277406,212.771228,229.993318,192.973679,21.51883,-76.111433,-30.552797,151.270904,210.840715,205.813392,165.027858,69.475303,32.636137,13.869513,107.559819,185.368805,330.14325,378.161579,378.02922,320.574913,180.934676,159.055166,192.113892,229.5574,220.231788,228.322038,242.309393,167.069139,74.509685,-64.926508,-12.14829,68.034936,259.928484,325.56708,273.878522,173.440423,-29.238436,-127.969994,-108.615244,58.413708,158.968479,251.839274,227.595449,103.758942,21.499895,-167.961474,-249.456592,-195.103554,19.936981,101.346576,94.605746,42.624957,-37.983324,-97.813652,-105.262898,-23.218508,50.097893,143.505716,121.237903,-11.760694,-72.122168,-121.452721,-52.998209,6.825179,123.849138,158.555903,119.87444,51.37696,-112.461392,-250.291551,-264.189006,-99.986948,42.874815,231.902566,219.262966,86.363194,30.357596,3.160686,102.026387,151.90784,210.947297,228.353111,206.086948,159.885722,23.084079,-92.80281,-103.039283,-45.056989,4.607171,121.392021,137.745803,-1.209566,-101.148544,-177.169918,-78.223868,-12.006464,91.062448,126.533902,138.544781,107.154441,-12.189194,-138.370838,-156.019896,-84.360159,-26.857847,56.675125,60.53172,7.106411,-20.1232,-72.411938,-105.375833,-69.242211,121.525313,227.577271,307.019076,261.219147,68.970104,-84.401092,-84.013708,61.811645,172.001882,316.52494,283.03862,57.034783,-45.094173,-134.07504,-114.592201,-84.448093,-34.802734,-31.285883,-98.260302,-169.331456,-329.122709,-360.150357,-298.533419,-151.975712,-119.960025,-129.049599,-151.531166,-221.458313,-250.776937,-255.115822,-165.594994,-69.217362,129.205946,154.142649,41.875735,-30.107783,-153.816828,-268.212168,-286.838397,-242.627818,-194.516791,-89.149722,-74.244418,-177.370572,-259.733586,-312.003062,-164.46823,-74.011531,47.762984,54.146846,-66.966497,-150.950601,-260.675089,-291.243913,-266.396472,-170.871385,-126.468233,-56.311299,-44.221607,-75.549546,-101.235733,-133.156382,-70.307626,-9.119139,96.945458,131.079041,120.99775,55.930535,-144.803249,-262.664368,-236.814856,-74.798109,3.187422,119.035641,146.804379,77.403089,8.004324,-66.363562,-14.534632,31.590585,88.769089,91.288695,46.424437,-3.470039,-122.905454,-137.957627,-76.676915,81.07611,133.10574,154.601434,118.149007,27.176451,15.693035,-15.836707,-107.944122,-119.974154,-65.014926,-42.30126,-51.500504,-70.004768,-147.163567,-188.940888,-138.403288,16.725291,59.470028,44.056755,-12.784583,-193.984628,-269.638364:165.914648,116.105418,103.568546,155.167951,217.211682,267.228635,241.256242,257.802192,354.649174,355.708847,307.438562,313.768383,398.383164,449.907983,505.011534,494.427536,434.759634,384.068451,338.943704,197.703633,134.663311,2.413215,-76.367178,-149.133881,-92.963046,-73.075391,-68.790718,-53.868068,19.194107,44.606431,40.851873,59.346526,156.891119,176.865771,173.601271,196.933819,212.77391,209.765619,171.742704,105.189435,156.977756,184.505742,211.660025,224.202962,208.63744,172.473563,97.98217,76.586191,32.327443,-21.244614,-36.172151,-89.480554,-145.480909,-254.347629,-268.791427,-252.245126,-254.229914,-227.632637,-117.826227,-97.112457,-129.610592,-119.195132,-46.529257,-37.798156,-119.737523,-237.721152,-248.1652,-140.404368,-69.397518,1.403971,8.116185,23.74581,45.003383,60.795439,94.342425,105.696492,162.791245,212.74322,271.398022,257.125177,207.20013,218.513626,219.304935,149.129969,118.736608,90.174317,48.020696,-75.449058,-165.151729,-195.817502,-214.386377,-187.781819,-71.01405,-32.570497,-109.575176,-193.403066,-296.251948,-267.49446,-239.511916,-199.341613,-165.129477,-82.410948,-71.738711,-110.390458,-149.903135,-158.569064,-123.091757,-76.079106,35.527327,64.471402,38.503596,5.33696,-58.829876,-16.852562,48.556972,124.534726,97.709902,-72.65222,-188.480926,-351.993233,-328.905738,-284.622508,-244.451774,-230.861458,-118.194568,-58.389644,-124.440002,-232.887566,-360.379797,-237.291778,-130.432708,-3.205761,0.351202,11.947898,59.775485,222.114418,316.596488,304.510682,229.35578,201.455302,218.476439,222.530748,50.907345,-105.669475,-314.512626,-304.125078,-290.449144,-276.681908,-236.817599,-148.058576,-145.781596,-224.506142,-276.737443,-232.64549,-76.63812,-43.073153,-79.021265,-92.49058,-73.4066,-77.346701,-179.41007,-249.539205,-215.051436,-103.179732,-50.258054,53.44396,76.756387,53.496852,92.547716,173.58183,371.975228,429.854298,372.196646,274.593166,87.964795,44.51561,18.899737,17.264621,37.568091,91.568083,128.645249,231.941065,274.865843,262.23804,137.41136,120.819145,230.631655,287.970382,281.006798,235.843116,186.887337,200.181817,217.472398,174.352729,166.922098,239.710194,312.224797,413.206655,392.833987,232.568042,64.139603,21.24301,40.951959,66.103515,28.694133,-32.31967,-132.57915,-160.750685,-230.298374,-215.552536,-144.46804,31.604776,97.761614,108.922028,40.002968,-115.011243,-91.623243,-44.317498,-4.719533,13.282285,105.293668,131.158863,76.644422,40.292106,8.559358,-35.153071,-51.98344,10.267699,71.291037,148.044136,160.019759,159.805584,115.074583,76.509219,-10.217771,-53.620675,-99.093341,-87.860885,-62.193296,-84.83316,-183.920947,-154.176513,-74.368259,38.087244,42.139392,-5.580864,-37.087735,-102.637077,-167.676862,-162.966533,-76.187771,-46.33862,-109.808567,-181.640617,-230.205925,-184.704553,-102.160922,-78.044599,-55.762442,3.442035,30.69578,17.798146,-49.081428,-205.210696,-204.396431,-156.320091,-73.270192,-63.249082,-105.385273,-125.075138,-115.302155,-100.261202,-64.639545,9.12779,42.42653,50.715745,50.301873,109.146832,145.122987,102.47732,-90.163896,-157.63324,-148.114491,-105.555467,-24.472476,-2.69268,-9.167288,-22.643221,-31.633616,-13.56123,10.31717,99.021092,153.673357,248.912812,267.476532,222.166177,125.037914,79.869706,66.343905,98.805135,180.470287,215.739859,239.488254,207.697873,54.029391,-0.315121,58.503496,160.032013,151.126242,63.885403,13.819254,-63.782489,-104.179067,-113.959022,-134.846538,-151.42804,-162.083707,-140.224499,-120.659653,-146.762225,-127.521627,69.744687,139.214867,100.460819,46.170637,-32.460536,-71.723337,-166.892777,-212.286973,-189.797743,-115.580225,-116.172916,-160.229643,-149.606795,-90.812399,-94.428087,-176.06872,-112.353864,-14.11751,34.60009,-51.152595,-205.521257,-191.951197,-92.646223,-179.346411,-268.107335,-311.242414,-240.196824,-41.737052,9.836705,10.19862,20.537283,52.966189,8.933508,-19.167516,-36.532431,-24.994152,-19.288422,-40.193053,-104.030352,-137.271705,-121.119542,-38.022934,10.667322,50.814331,19.755065,-73.654782,-98.65002,-55.051662,69.197248,73.820343,-65.006504,-121.501366,-79.317422,-26.008654,18.089233,6.312182,19.371221,68.922518,61.819648,10.162784,11.072992,54.552612,57.675254,35.567323,95.900641,129.262763,118.908541,93.350472,46.838009,19.410438,-35.921563,-33.282412,-14.202837,-41.501481,-110.904748,-245.333702,-257.882444,-208.747568,-189.208993:69.700136,-19.183173,-50.17579,41.24513,144.694305,209.468329,159.078913,123.95424,147.500851,136.039482,121.817545,125.219417,171.714874,231.136873,371.227322,392.300893,292.341901,189.572955,153.523314,35.247361,-17.95009,-40.096588,-25.210428,8.044725,1.531069,-7.852185,13.818527,43.515671,105.6038,127.847393,139.024605,129.58,88.567539,39.202245,16.961901,-15.259094,-1.967549,77.045393,101.339805,89.726198,23.815013,2.55131,54.403592,105.432246,151.180246,117.797655,-10.588171,-63.028973,-136.590355,-149.743226,-126.79953,-115.181767,-130.050008,-123.072441,-98.717029,-71.124502,-61.086227,-38.333719,-39.058772,-80.466619,-133.445207,-125.006442,-108.702611,-110.128915,-148.312602,-276.051099,-315.970904,-217.191317,-134.789371,-119.356458,-148.574681,-88.117791,35.762846,69.407037,57.413187,27.925303,22.153707,42.033966,52.921932,41.802292,20.831819,71.653618,106.808876,100.843733,75.121295,46.692776,57.091689,120.017631,114.126154,71.79674,-27.536032,-58.724718,-38.595152,1.326279,18.580411,-55.259155,-293.120705,-271.369318,-131.178852,136.090646,182.798667,127.152117,74.100443,-46.689755,-163.788897,-179.169957,-91.208154,-4.884204,152.698885,174.946767,89.475564,9.728778,-123.077067,-31.462807,89.269584,265.640553,267.641685,101.053987,-14.38524,-165.390987,-223.024737,-234.33784,-180.957997,-138.39486,-104.963648,-105.037247,-142.132987,-170.472637,-155.82209,-47.450656,12.91681,98.140872,116.450469,147.897609,182.116599,250.368938,208.293634,167.121085,139.323847,146.537048,148.97826,130.801173,47.886206,-8.485884,-144.151457,-215.240661,-190.542624,-99.80165,-72.07212,-84.852266,-114.493642,-187.157784,-256.472793,-252.93583,-117.319622,-23.98538,75.275281,60.333611,-17.620903,-30.461033,-39.691081,-132.763027,-181.294956,-176.942925,-109.501238,40.035332,58.972286,-2.440888,2.225276,65.541782,224.006439,268.001676,248.072234,202.075273,123.364832,108.167139,55.298416,5.307602,35.897706,158.755026,217.142172,288.706701,277.633008,130.063229,-33.427675,-21.826546,156.296,223.016629,209.670226,168.362076,133.981742,146.881188,135.18522,71.473145,79.457091,209.152101,304.438032,419.476212,381.002203,144.584984,-15.294915,-23.173621,-11.28001,-7.705822,68.004901,125.912825,121.104346,42.53019,-112.681741,-104.772474,-56.708497,61.72089,109.596813,105.385436,54.404638,-36.921477,-18.984198,23.513274,86.907322,97.793826,129.187551,136.917819,73.666235,22.394627,-44.548971,-55.870811,-41.716092,-10.985466,-15.289832,-41.928901,-42.787185,-27.368971,-61.923889,-88.201889,-121.301528,-141.164228,-199.881382,-232.54558,-291.939445,-308.467388,-292.49753,-158.976369,-70.347447,16.191495,23.36884,46.421527,48.783848,-7.032068,-96.435957,-109.328266,-66.513587,-49.513563,-50.146063,-62.707103,-61.733969,-30.559622,26.6155,59.019786,83.141305,130.040073,146.506703,135.50009,95.94772,12.948235,-13.657103,-19.329378,3.700408,38.365585,89.849878,78.903749,9.043406,-14.790121,-2.867337,39.985532,47.424067,9.757966,-17.846902,-20.593398,-2.529329,-18.69621,-161.84928,-242.807779,-292.42039,-243.38839,-40.191739,47.004704,40.695391,-14.724553,-66.963059,-52.178124,-44.90054,-0.314714,50.414409,143.597742,151.817483,125.767049,90.227745,68.747307,74.401895,103.947589,166.711205,170.453982,90.68544,25.613637,-89.991834,-39.841836,38.424249,110.7502,81.845962,-9.65782,-41.043374,-101.497512,-162.683333,-172.740897,-161.212961,-160.012166,-190.839626,-208.600644,-206.703632,-184.165863,-114.796302,-9.408408,50.168976,98.946987,74.261875,-22.73097,-66.816106,-134.018688,-200.113761,-186.389484,-65.09091,-23.249777,-25.063413,-46.967286,-105.179963,-131.537975,-150.520722,-107.828286,-77.538264,-53.098387,-62.377628,-88.301382,-107.882407,-251.937092,-443.256938,-446.699617,-291.922067,-211.18386,-112.269563,-87.286694,-54.475078,-46.002902,-72.559993,-96.334842,-89.471877,-95.064692,-109.41108,-104.597392,-101.032281,-179.350568,-290.502113,-290.408137,-161.17523,-73.024251,65.875392,95.255996,73.024759,58.620201,121.4342,216.671613,196.562766,77.096252,65.057749,146.11838,174.992991,177.082489,183.347401,204.910612,220.483771,184.529501,110.618538,97.75179,98.51409,120.043092,178.334312,171.964983,150.528517,128.207873,128.832636,86.259009,37.150651,-16.659274,32.904351,47.00499,-10.523743,-59.445957,-106.241485,-96.182213,-85.471528,-110.450591:30.386077,50.063751,71.883476,96.238029,103.949698,109.93739,91.888174,87.162634,157.458928,168.802215,168.013301,219.432588,401.592036,435.12352,380.001643,371.72722,342.929403,254.293179,226.447531,110.103029,25.522385,-64.566948,-73.060475,-117.151053,-184.257932,-175.84313,-81.911155,-49.487818,-34.90532,-12.978362,34.875387,27.151132,-3.227221,79.311802,125.102298,91.64381,54.580867,33.371127,39.192812,81.844276,87.722671,92.109538,190.993079,253.449409,317.388489,306.995629,205.492759,145.001384,69.808354,62.042942,59.935038,2.180379,-27.860545,-25.221741,-31.217066,-165.699913,-359.078456,-381.110055,-199.34205,-70.045442,41.30014,12.310046,-89.777409,-113.152083,-107.151598,-113.106642,-125.059167,-139.203016,-125.337209,-40.407097,13.916137,86.207723,83.575615,81.671782,133.585758,170.287397,233.608387,263.146274,285.951962,254.110435,156.556981,193.157719,244.202036,282.717821,266.651353,170.484223,103.402558,-21.445327,-186.23728,-252.552747,-256.732649,-218.64072,-136.978662,-111.767729,-177.295569,-277.392476,-471.313711,-437.211219,-351.433842,-204.973268,-160.921228,-97.121008,-75.980177,-78.48103,-163.394237,-202.380204,-185.23019,-137.636844,-44.301379,-19.642541,-23.428367,-51.788394,-135.258897,-121.004541,-70.529576,-39.203646,-92.115469,-253.111438,-310.213246,-371.897092,-422.722364,-449.786321,-498.963601,-472.226005,-257.610987,-162.655385,-236.379287,-357.091905,-495.048489,-414.088678,-309.771573,-86.951867,-14.774826,57.57593,80.297561,134.32201,153.675071,149.15308,183.180389,219.092588,282.630189,296.221554,201.885002,88.743963,-122.799307,-119.867611,-67.976311,-80.721816,-129.880226,-138.050495,-116.611284,-186.870918,-285.369378,-229.114778,1.189062,59.398377,-9.49988,-78.908951,-158.926552,-164.887477,-173.796202,-183.107929,-173.544468,-113.753557,-70.874312,-35.151092,-26.676241,89.326032,183.181632,182.69501,276.148643,365.626739,366.207903,244.697459,-9.003283,-53.398192,-27.735346,39.936461,93.981453,206.104127,255.965621,326.248681,325.570159,274.959378,269.08084,284.50475,308.153871,319.55069,307.518795,271.100238,210.110268,207.314906,229.544067,270.326524,307.876226,423.759633,473.54382,454.586607,388.85852,290.04346,270.983023,237.991325,129.897234,97.512426,117.841163,145.480365,110.189421,17.689487,-189.376036,-113.817748,16.997911,197.178929,212.092756,201.292221,195.346949,104.337975,-51.660885,-85.284141,-3.180782,70.550405,132.958184,102.116944,8.418835,-16.839524,-59.596153,-87.145508,-62.973223,43.03187,98.581709,142.30757,115.084917,46.415423,29.037561,12.335219,-14.376933,-2.733181,-14.117655,-65.913413,-113.094066,-54.627506,30.163265,-74.477127,-84.659312,72.347703,148.237058,93.675093,-3.943033,-138.208388,-163.317286,-150.657569,-61.465413,-5.794227,45.90412,26.672037,-47.560172,-49.469377,23.695951,20.665016,-3.224852,24.830914,64.625509,105.920057,94.78627,2.32566,-91.122718,-104.612046,-98.798305,-80.011545,-4.792016,4.435813,-96.909196,-155.896096,-180.794584,-102.034937,-44.971997,46.729056,68.014883,71.711529,64.473766,33.066042,-79.494657,-140.005826,-147.762478,-101.401725,0.294535,29.319119,10.541105,-14.279816,-49.053743,-105.259627,-104.46981,10.800996,96.04151,236.328464,245.529662,92.287418,-58.597817,-58.96075,33.94038,76.253562,118.867525,126.983355,68.05671,-10.959798,-181.788657,-171.381403,-93.357758,-11.770443,-48.547998,-138.882023,-150.988831,-180.457591,-280.264216,-328.033109,-347.030798,-309.942069,-180.447158,-147.693969,-220.721545,-256.905787,-188.304409,-50.014287,-13.794976,1.244835,-12.946003,-98.737927,-142.228312,-190.82323,-265.148988,-276.223766,-182.104531,-141.073395,-141.605194,-155.413103,-211.496027,-247.583123,-245.267717,-100.48941,-32.690689,-49.579289,-109.478655,-179.233275,-178.892404,-149.760795,-100.378646,-82.284844,-80.264975,-98.976397,-150.091876,-148.617113,-59.962685,-26.448069,-79.145553,-102.54546,-51.136067,29.298388,28.685544,24.138451,16.138155,-61.386157,-142.354128,-143.693868,-85.308359,-47.717791,48.097888,89.910823,79.90452,28.423666,-66.828939,-30.424575,2.542072,28.104979,46.812555,76.810176,60.935877,10.492422,7.963572,33.891282,85.451994,88.469569,105.843359,134.465395,197.993182,202.341549,89.116301,-36.55796,-59.761527,-57.991411,-29.839776,-0.48618,-27.006135,-61.82104,-27.302964,-13.310254,-40.753929,-71.533473,-84.956051,-72.016281,-90.527567,-131.117225:left
178.281325,218.197984,163.90386,-10.748318,-77.453747,-139.44573,-151.279979,-123.247511,-57.656834,-72.482471,-141.528472,-132.528751,-100.178708,-136.428751,-285.665422,-332.00015,-250.679804,-103.356112,-84.903095,-141.026504,-182.33998,-205.451943,-174.351092,-82.095512,4.659885,72.754536,276.269034,348.740659,351.455777,321.969555,241.89364,199.898591,210.639854,316.947814,360.396482,382.565055,366.221808,346.833365,344.787163,324.079687,326.97105,339.981047,349.69862,334.526773,247.259362,186.797397,74.573742,36.253454,27.078588,109.459089,180.687515,278.215615,253.775261,101.693819,21.659405,-80.67391,-83.751098,-42.956631,76.923823,125.984075,210.906398,249.283097,210.224973,126.141364,46.162574,174.186733,226.524947,179.822888,122.02616,97.924853,114.217495,139.893978,272.377312,360.415145,432.074779,398.984981,260.998759,202.680607,153.274358,144.610503,150.17419,153.22981,104.88,-85.885981,-177.588761,-233.519392,-200.502877,-128.608638,-91.215589,-72.576711,-33.888786,-6.383331,98.569955,154.326838,153.732118,97.130154,-3.310411,-4.996223,15.091193,27.856165,1.291307,-112.90126,-181.115923,-270.472322,-275.993212,-246.531705,-109.955593,-48.516058,-60.744673,-107.299853,-151.490424,-142.667179,-81.998436,8.049795,29.328568,6.164246,-25.908413,-105.574741,-135.942409,-154.370608,-133.003552,-114.739683,-78.379345,-66.603583,-30.531624,-0.764932,-0.0043,-42.545368,-70.145914,60.895148,113.206295,31.170951,-74.173528,-219.807336,-249.82486,-261.915696,-211.892798,-189.686541,-136.73125,-97.230916,-53.638633,-65.26727,-129.439995,-153.595341,-200.465475,-306.863141,-349.897015,-384.117974,-383.844968,-330.944845,-303.209043,-329.201968,-320.279817,-252.852176,-70.402888,5.310491,66.715572,50.13533,-29.800237,-54.300321,-12.867116,48.530734,66.766972,79.20692,54.824886,-14.523507,-25.207803,6.742467,23.141044,8.872397,-11.216621,-8.523128,-34.924233,-70.371376,-152.975869,-200.29585,-282.172521,-269.188746,-220.95433,-117.236786,-96.09017,-113.182104,-127.153679,-96.104737,35.704002,104.640908,164.22841,120.466693,-70.489643,-128.71831,-57.231418,42.742414,228.204501,251.51609,214.946357,103.467219,25.24209,-122.677397,-151.862986,-116.619777,-56.875362,-32.397714,26.933657,47.302494,84.278005,129.200244,199.611707,183.596915,67.379576,-45.926777,-54.565615,13.395072,47.408312,68.816074,57.357923,-12.889477,-117.212822,-146.057686,-91.15407,-67.421313,-157.073807,-216.855967,-246.50816,-234.201967,-203.714737,-144.754865,-121.137741,-153.841127,-205.028051,-304.441291,-321.809576,-274.363551,-190.822626,-142.940435,-31.634707,-9.363362,-73.627509,-103.438172,-88.752766,-55.633439,52.689082,112.150966,101.641606,27.220861,-20.272259,-71.29621,-89.794176,-183.026545,-270.380214,-282.184804,-289.836886,-317.266522,-369.848224,-350.718202,-289.919586,-284.745571,-267.082925,-198.532094,-161.356773,-161.641262,-224.524106,-414.905036,-493.967447,-519.913159,-412.152299,-378.945069,-365.237207,-359.359408,-368.696971,-392.385993,-461.8861,-487.988452,-478.076742,-408.752025,-367.005252,-349.552058,-387.056904,-443.851793,-436.807896,-398.371376,-354.808482,-317.506739,-214.127911,-170.40317,-111.348562,-93.737625,-139.058949,-182.520255,-155.659669,-1.795544,69.080288,119.067074,90.645855,0.39117,-27.247684,-28.445013,-0.101303,28.867698,97.075123,115.44363,175.900807,215.239259,174.231483,101.37802,40.485144,101.193897,115.612141,91.251428,75.731344,23.718918,-41.858749,-165.439523,-140.450834,-114.973742,-105.089979,-132.489432,-234.182078,-261.954368,-234.449343,-202.618713,-117.996989,1.806342,67.386581,153.250081,144.808063,56.517459,18.202598,9.778534,60.674525,69.177567,12.888822,-21.639669,-22.836079,-0.51916,-15.338385,-50.660255,-51.266075,28.775504,30.157669,-86.99717,-151.173071,-159.405549,-133.382189,-110.794031,-23.076605,54.042502,210.841808,276.482925,328.790177,296.917754,167.374306,144.313389,272.234253,377.535838,350.577349,193.687814,87.591454,-101.188146,-140.880502,-89.682771,27.141616,79.868746,191.339104,239.395538,237.968317,174.465925,-29.643447,-87.196061,10.316245,144.608052,152.694691,45.401124,-36.438222,-131.040445,-147.2603,-176.577713,-121.973126,-68.482448,-24.99001,-34.730265,-19.643839,2.6902,-23.423807,-62.05114,-48.266398,48.48237,71.930049,74.632242,70.109144,63.565658,67.027087,71.497329,29.992199,33.754299,184.582518,270.198994,290.065162,253.369006,177.998744,138.717599:103.46408,118.82242,112.755975,61.109134,-14.659842,-164.028747,-154.501158,21.895658,132.759227,111.855265,50.556204,50.545984,48.975947,8.035604,-141.921758,-195.445121,-183.091058,-113.301498,-89.435005,-60.718328,-59.51487,-69.971192,-55.736736,37.534541,108.805433,123.560235,213.534351,267.313864,259.160949,211.243793,111.186317,79.517019,111.827766,201.047094,237.033306,283.525918,278.865888,227.420062,205.109074,204.06736,279.025247,331.477733,393.933692,380.398098,285.361104,218.462008,77.949841,57.743734,159.113727,268.839286,314.242313,391.022097,382.247949,232.202492,122.558448,-56.098111,-108.876741,-82.015956,40.262089,97.274495,174.167216,199.132466,154.825928,95.640342,98.327705,186.984748,171.586442,117.811405,133.969339,163.967731,140.854177,122.027042,236.515197,297.71457,358.232797,358.001318,314.630656,281.011763,164.637264,105.188524,115.249419,185.679825,157.924592,1.055105,-74.960482,-140.074642,-131.366351,-81.50463,-7.72938,35.081639,76.286759,60.793769,40.765585,75.623104,159.62596,155.741261,80.626775,90.951205,138.310445,156.413356,106.091489,-23.566609,-87.006588,-165.935165,-114.747785,-76.755272,-43.13365,-49.406036,-118.394078,-171.788449,-197.342721,-135.73867,10.216386,63.721431,68.913274,-0.047708,-65.97981,-137.085676,-140.190122,-138.253493,-61.610523,-4.281564,61.579387,74.766856,99.635789,101.105343,22.304912,-37.953859,-21.881024,168.594519,205.453252,23.524818,-103.040309,-166.377139,-143.498647,-144.356263,-103.416665,-60.910903,-8.578508,14.966759,86.07316,96.029754,27.342605,-9.195218,-43.562843,-49.880394,-34.472107,-33.014119,-74.786887,-198.464027,-248.779954,-292.515893,-245.429056,-180.844833,-40.135399,-9.395308,8.664299,35.394498,71.964143,57.312217,44.434517,140.324254,204.732942,255.525031,219.913852,67.771166,-4.07421,-16.111907,57.504957,51.907163,30.467916,48.913217,61.278491,20.168162,-125.267163,-175.573843,-162.523545,-91.387943,-65.67414,-41.214593,-49.942356,-122.925976,-172.799954,-202.643165,-71.544034,17.828337,134.992653,134.599621,41.619531,-11.548292,-57.093368,-22.004378,120.994536,205.981108,215.106041,176.909804,130.371826,-21.139546,-103.793581,-160.368043,-45.747648,20.378181,85.645504,110.315064,188.078746,211.185645,184.817415,168.880591,155.847347,57.178567,11.695615,18.569775,43.137655,39.611742,-6.741604,-116.558767,-136.440735,-122.928642,-106.060127,-134.90293,-259.377201,-299.242008,-262.942009,-213.809805,-164.756592,-160.69472,-151.341266,-185.459492,-222.31864,-249.323289,-243.780779,-212.848084,-204.770115,-211.87786,-180.479742,-155.304255,-113.679028,-78.828311,-15.957261,2.7305,70.69776,131.487449,116.802664,-54.422883,-151.352727,-168.485209,-135.427902,-153.16168,-212.410044,-249.946789,-351.865255,-401.225046,-448.726167,-443.016759,-413.687804,-386.491901,-282.521756,-169.416008,-131.589286,-162.323969,-236.812992,-412.172248,-476.906337,-513.152738,-434.874725,-394.661828,-367.337915,-376.11129,-454.64286,-523.573485,-613.676268,-607.760882,-572.9412,-566.201603,-539.351091,-443.885986,-416.422461,-438.289356,-464.465606,-466.010572,-383.837582,-330.804091,-245.781739,-222.608302,-205.03112,-203.868378,-179.684745,-147.700302,-95.68023,-55.966616,-10.686618,79.24992,84.100178,-16.307971,-96.966637,-192.652567,-130.644421,-61.360438,49.997774,51.522665,-24.705409,-63.746993,-56.938242,1.585386,109.078412,89.232164,69.755798,47.237785,27.338229,-36.687578,-69.679999,-86.685159,-50.201359,-35.572078,-20.316971,-48.472239,-210.012495,-283.556133,-276.489488,-205.177714,-24.886088,83.31397,95.011717,46.095079,19.509671,7.302252,-12.429208,-38.22874,85.947595,148.251449,127.155794,68.087402,-15.542012,-30.599645,-69.130488,-90.663823,-97.392212,-40.828738,7.409266,34.287,-14.004849,-163.208305,-213.528902,-162.058685,57.911664,144.109634,183.183494,188.153325,229.709026,216.389172,82.720925,41.938441,106.763921,156.256283,154.136999,108.373123,37.515933,-145.759413,-187.784613,-135.123597,-83.468147,-74.596327,-11.54828,12.120701,-16.93217,-28.576968,-12.566235,-5.407922,15.382261,45.186869,42.71967,-39.709773,-110.543713,-229.110071,-260.931326,-292.833094,-266.258465,-206.7047,-55.08103,-27.761412,-86.790598,-130.200355,-172.702376,-148.907475,-21.781711,55.33264,36.173385,-32.97419,-25.364377,21.04925,13.540642,8.236039,68.966053,96.632366,168.949798,212.712697,240.15086,208.946562,113.388707,100.173654:137.29933,132.073744,101.270903,36.531838,-11.230853,-116.246414,-112.264923,36.938799,113.014969,93.818339,55.726081,32.130344,-40.19176,-69.107096,-145.059864,-186.727168,-161.818902,-9.831445,43.51648,-9.358538,-90.085272,-179.919801,-155.733358,-10.686874,129.256104,164.939304,219.23291,249.111979,245.646411,199.118814,105.448054,93.930767,121.389249,187.172813,227.140828,238.887946,201.992882,111.065243,101.353743,210.851081,365.73818,395.314297,361.622529,328.927274,249.831085,209.656284,174.530004,175.597933,177.268235,268.814482,346.183345,389.49758,333.706207,165.44912,80.53169,-38.195756,26.453395,119.530052,258.033776,248.865897,166.781792,159.453124,146.6169,108.958615,74.299552,138.896284,167.300962,182.436882,166.115646,65.854093,15.203089,50.046171,187.535484,235.023186,308.176908,336.603397,298.369499,224.324253,85.763091,83.243842,200.647421,249.721303,201.580084,13.559052,-85.54384,-217.293836,-228.89391,-107.122061,84.34278,134.500329,140.135679,132.037,140.766164,147.743705,150.702655,163.876296,232.957962,266.144833,245.379426,150.252034,94.315329,-37.965421,-105.56498,-133.942668,-34.469244,6.900815,5.429931,-32.169352,-123.98503,-171.25707,-239.147665,-216.117397,-50.539694,65.337979,71.434843,54.07706,53.675814,58.606101,36.929393,-44.40655,-34.214222,20.254691,154.111742,196.612586,199.548806,181.075242,154.421442,143.230698,131.252387,173.166469,193.512652,131.051004,73.850953,-8.428985,-53.239978,-109.812004,-24.346108,32.953209,78.79602,76.549084,59.775885,36.789186,-12.334871,-9.027572,27.253863,13.949631,-16.605574,-82.175545,-99.792144,-130.867123,-149.593961,-163.692738,-115.941241,-45.840263,123.8675,157.313872,95.380235,52.359302,31.995346,74.298292,236.164162,283.907965,236.313447,122.833204,83.917842,2.708219,-43.027003,-58.098269,39.342839,79.202091,113.416901,118.57878,61.290877,-14.367156,-150.974374,-157.789622,-90.742812,-77.775835,-97.059476,-120.88051,-121.73374,-109.591403,-90.250769,-6.690181,54.941748,65.47497,124.058415,140.955891,66.056837,10.018536,-32.383474,-5.05356,74.929736,107.803415,106.539507,18.299996,-65.626568,-213.283937,-241.54905,-167.086078,4.374523,80.824801,121.176374,79.340151,12.640873,23.793028,62.093852,57.150227,9.932694,-8.866106,22.845454,75.07206,28.916242,-122.478138,-141.623346,-106.040757,-129.783851,-132.704686,-97.54469,-116.739308,-245.319006,-282.74715,-255.946238,-224.248792,-165.220056,-125.948932,-113.360428,-129.994268,-150.580356,-176.675629,-183.934436,-148.258865,-103.442241,-122.321953,-141.240824,-118.777669,-132.428405,-172.101708,-153.514733,-83.894881,16.19001,58.423728,76.221957,1.468734,-58.953283,-86.026718,-91.799874,-133.962959,-114.262694,-109.932604,-179.047483,-238.201764,-326.639246,-339.030356,-294.189659,-226.74047,-72.557588,-73.270326,-108.850359,-158.886481,-197.776885,-330.727895,-382.464972,-335.891062,-196.845719,-191.227427,-282.779342,-317.792786,-371.180433,-415.467152,-510.4066,-544.089921,-550.018448,-422.991136,-346.984634,-303.903448,-326.809022,-383.098365,-415.376454,-457.038787,-361.8127,-272.567265,-169.045529,-195.397409,-297.769309,-305.528712,-242.835057,-207.955057,-142.500909,-62.335184,-16.25386,37.346312,24.65992,-37.361946,-59.199322,-71.728759,-61.157337,-46.243788,-18.594089,-20.014123,-38.159091,-43.8792,-40.468385,-25.128069,37.783198,112.341466,129.64299,98.899285,67.262237,-27.835626,-82.056176,-76.987778,38.06628,61.395903,61.227574,48.929929,-82.518935,-180.031735,-249.276757,-204.476957,-80.025077,7.974826,44.300631,69.252473,46.161264,-44.941575,-88.566633,-76.011081,47.87192,101.139635,120.950341,73.819998,-65.398944,-120.7251,-182.629909,-168.779105,-34.234071,85.166942,92.12364,-17.954212,-110.548758,-247.513348,-245.322519,-92.200842,109.497034,175.920635,183.244066,142.857833,100.037713,101.465655,67.099928,50.280386,88.899997,121.246751,110.295319,38.230841,-29.176574,-178.606601,-217.757764,-166.843924,-74.660167,-66.548808,-71.126926,-62.054616,-35.239446,-38.649063,-92.089218,-99.185142,-8.656689,102.636392,105.368535,-11.556329,-88.784728,-193.11809,-211.34958,-175.226364,-48.534738,19.991129,63.607653,29.525739,-34.700157,-29.178191,15.177218,38.56188,115.069595,206.436003,226.306616,179.77879,131.037015,54.473963,19.236396,-46.562928,31.85917,122.596418,242.540568,225.606979,128.163489,105.951503,82.286446,62.241472:199.999175,215.340602,185.792163,13.040389,-106.931545,-242.852435,-218.128565,-88.636661,-91.631098,-131.388167,-124.050415,-98.266523,-141.066865,-195.932335,-303.522052,-346.042577,-339.225172,-205.903276,-145.931245,-134.717207,-165.436476,-164.000446,-122.489375,-10.465289,105.255262,161.084895,304.319314,375.429913,404.792549,365.721694,267.122057,231.243004,205.336286,233.633431,270.243029,326.11252,306.865198,220.321272,201.166861,241.789386,315.130312,326.102397,278.445365,237.027234,153.963377,124.065032,121.036178,138.314523,161.548768,156.925341,150.607557,133.493863,106.59307,12.84787,-29.276727,-46.971451,14.166822,75.009536,227.842272,256.768759,188.629242,153.805,90.130496,38.433507,2.897555,69.866923,93.284596,83.514498,58.355614,55.201746,89.82139,161.555625,217.802053,247.512119,306.62916,325.509514,264.593957,178.317775,17.641309,-7.50212,33.935972,60.340636,56.008602,26.592372,-17.473876,-120.741243,-134.499698,-48.385412,57.857345,77.743429,123.361869,143.671788,118.901232,100.457738,98.102061,110.194834,150.432299,195.328782,216.965326,188.6069,116.531058,-70.990762,-132.041042,-136.363299,-89.066809,-82.079016,-87.94623,-85.590293,-68.745816,-67.009406,-84.660184,-90.428552,-34.239824,86.079709,102.717415,26.205776,-2.84204,20.820071,25.984696,-3.581171,42.814876,96.187776,204.175109,230.747734,206.127407,178.023162,100.684663,60.460817,110.9834,288.750757,315.680534,181.20304,96.425817,10.99817,-35.854919,-155.029073,-145.570694,-114.025918,-84.654418,-78.705961,-66.056277,-73.113092,-130.616674,-158.594898,-171.241434,-157.893139,-165.131714,-239.388536,-276.987425,-251.692414,-213.026668,-195.67455,-149.660106,-72.867828,105.248479,163.77724,195.612161,174.621641,87.476247,71.198586,158.793059,164.192474,109.071473,36.861348,28.561981,-2.314758,-29.461821,-24.17332,66.397279,84.057199,26.905923,-22.914274,-109.164147,-133.493812,-149.400274,-154.249734,-184.694162,-188.892694,-150.957227,-51.41373,-20.267495,-13.66191,-43.832932,-91.020388,27.477796,115.654669,198.707507,168.806926,39.61246,-8.359324,-29.478238,1.54025,132.905093,280.705159,308.243868,169.479682,41.489793,-159.641525,-210.348572,-206.630714,-105.760877,-77.585969,-60.716667,-38.051347,7.020226,8.009764,-14.945445,-19.608096,-39.465647,-104.010266,-109.922133,-45.829403,-16.736661,-11.312464,-23.358972,-55.679818,-90.720866,-92.022014,-56.073532,-71.79593,-215.312152,-268.816644,-251.268551,-220.325688,-167.156595,-103.447514,-83.408402,-118.678307,-155.820406,-196.884947,-188.236267,-116.052916,-64.697538,-61.35798,-48.240707,-39.250903,-51.17419,-68.892018,-91.657626,-75.020707,8.017012,95.978163,140.840643,161.091032,128.923529,80.050163,54.563894,-48.886465,-90.497933,-87.771087,-148.570428,-205.163039,-247.364113,-226.927457,-232.381339,-251.706145,-184.109181,-44.104274,-17.422337,-100.417911,-170.297031,-264.636605,-306.73585,-367.789633,-298.687515,-242.150886,-142.798545,-129.673065,-228.378078,-297.34247,-386.946032,-415.631572,-436.351124,-408.051067,-382.564891,-341.059665,-353.035442,-429.71281,-455.915841,-406.654074,-258.507539,-201.933303,-132.349047,-94.352711,-49.734192,-70.449799,-150.444166,-160.340994,-77.74186,34.301326,56.997322,42.892033,34.558081,-26.257343,-85.910564,-94.312862,64.399123,114.852599,71.446761,19.65058,-15.052973,-17.387865,-63.663699,-61.51578,50.606604,125.249725,120.188959,94.287014,85.885601,27.95273,-31.997206,-96.458424,-34.71422,-24.278484,-49.851125,-66.197485,-138.4669,-185.226602,-230.577174,-204.883481,-71.759073,2.865883,17.619845,81.860857,95.57215,-5.205721,-78.62928,-91.794693,-14.714845,-18.672674,-34.208737,-29.405193,-79.789884,-124.033767,-190.75295,-196.959134,-95.938963,37.683087,51.612332,-20.558164,-73.793002,-151.494552,-166.390389,-117.19252,12.625869,74.712169,163.187503,175.466746,113.884511,66.138945,14.944412,36.289015,166.264741,233.585531,224.430944,170.688938,103.073167,-113.523103,-192.983548,-158.314267,-26.067874,21.418279,123.631168,161.764208,175.293179,158.058796,69.902641,38.39112,106.608926,193.504217,167.17302,22.204521,-38.611688,-75.573834,-67.317635,-82.778227,-62.607133,4.132771,138.669766,156.431194,139.143058,149.343216,187.147415,185.782282,171.61749,187.016886,203.184053,232.065877,228.812281,187.001304,158.194203,104.733888,112.268376,135.891383,173.412583,180.911655,177.762617,169.479277,127.731354,101.456297:129.333383,241.477737,218.490233,-10.942712,-121.48316,-163.441802,-136.448444,-133.193824,-138.838187,-109.100073,-63.722157,-86.628281,-197.300967,-263.652316,-389.403456,-408.697671,-284.727894,-78.418236,-28.785389,-100.11012,-168.898379,-197.864029,-161.658484,-78.717234,53.186353,148.195255,340.083175,396.424201,334.34118,221.482584,-18.47651,-56.076813,65.8216,217.029445,262.139169,251.325976,167.424592,-23.015196,-23.80597,150.728393,252.367349,240.809558,209.326044,206.27683,175.330602,133.681594,41.733309,35.498189,125.485644,220.775284,235.765642,177.120479,111.605794,-24.377165,-72.595962,-58.093434,101.497558,180.626583,269.460192,273.186418,254.62113,248.858427,158.735302,85.611756,60.103501,150.593593,153.75891,44.90694,5.958408,57.295845,93.631719,119.364259,132.141068,143.737941,216.356105,252.853371,175.314924,58.026706,-125.654046,-103.963012,116.763928,214.7882,172.523321,19.397706,-53.198016,-143.265942,-137.693329,7.295565,171.357863,208.108405,226.625792,210.985794,151.838536,135.833741,121.966937,105.741491,82.663528,178.949892,239.273228,179.731448,72.986096,-86.177789,-115.268645,-136.549012,-138.386003,-119.280749,-17.663223,34.883465,46.336671,-2.255744,-133.001251,-155.796449,-66.18015,64.725858,85.12161,54.221896,38.064712,-3.868432,-27.058735,24.882,211.385219,308.245082,415.257504,398.790464,287.164919,240.319458,177.928646,164.878663,235.76061,333.420082,332.762399,238.647522,190.013463,126.797258,69.174292,-75.729167,-86.066797,-45.892759,11.217045,-3.829001,-81.668936,-114.61159,-170.651519,-199.256811,-211.161594,-126.81821,-89.036486,-111.376124,-146.213764,-196.072907,-215.122328,-172.37777,-2.404792,87.070629,225.311514,252.273471,231.875471,198.962937,103.801712,87.162827,156.945259,232.394313,232.353987,125.019016,47.96256,-62.112795,-93.458038,-46.113858,100.042322,130.136852,137.377764,129.497933,29.589484,-58.522718,-224.165493,-250.590966,-159.454561,-42.69136,-26.375908,-47.444422,-50.733589,-51.226694,-60.884819,-13.999807,114.45068,158.908714,201.365666,188.849253,87.484567,40.402154,23.863201,47.300654,111.054717,200.282916,237.741663,158.799247,43.853828,-160.937429,-199.813556,-147.08098,-36.848823,-0.203564,14.385184,1.484807,-8.995554,-2.642407,6.048401,6.868321,-34.313477,-84.945631,-61.987255,-4.167366,-14.05463,-67.047136,-82.955871,-81.413864,-49.068784,-41.894498,-74.597706,-100.659093,-153.552203,-184.883951,-228.540626,-208.723977,-78.171689,43.309851,66.341417,8.273607,-55.401777,-145.775317,-152.910325,-123.225823,-75.7534,-34.514124,54.661717,59.355517,-20.908545,-72.423991,-143.169189,-145.314183,-55.923243,127.688467,214.752135,253.808901,210.77306,107.996553,65.06732,7.446957,17.296004,45.986669,72.8352,33.535945,-100.159952,-146.249582,-169.762316,-140.565606,-12.281158,45.012259,15.156969,-62.996073,-82.438967,-157.306811,-227.362792,-298.145846,-205.919112,-132.07886,-15.475791,-8.427661,-104.625918,-180.660704,-303.192041,-322.377805,-271.958995,-174.311659,-148.906483,-177.064222,-210.935524,-323.761089,-407.659276,-495.5159,-287.741884,-118.562887,56.138081,3.149452,-187.942731,-223.543462,-183.790156,-153.568091,-83.935062,12.05698,58.641962,97.068381,78.929478,6.488888,-27.9791,-58.732399,-25.753248,1.03408,37.758527,30.716031,-57.372083,-118.102438,-153.011977,-96.237638,37.857807,78.722112,94.30331,90.810955,66.804336,-1.779917,-42.342792,-22.434661,108.519123,112.455579,9.115082,-30.796882,-84.982073,-144.88963,-266.668082,-248.940654,-82.135008,28.715515,55.405538,86.859602,76.504509,-21.348963,-65.349285,11.833358,153.357259,156.118628,72.613416,38.2573,24.90296,7.444037,-132.326102,-193.078557,-115.412103,59.307077,100.724501,47.865584,-19.707966,-118.529511,-121.905759,-23.459306,96.734248,125.521193,165.78281,180.350226,158.908024,121.23262,13.12978,-12.472064,79.099045,211.144497,219.421305,118.644791,54.942069,-80.407779,-170.93421,-272.646363,-146.593947,-65.950595,1.302515,3.767752,1.137951,-19.776854,-70.14083,-42.404777,98.276038,149.235021,123.066513,10.839864,-57.902324,-156.176889,-159.814063,-68.882581,73.769437,125.696381,152.805141,143.552685,149.473556,150.915976,79.759123,46.023158,109.666909,228.720295,252.37481,224.555915,180.587144,84.427604,54.412374,51.404738,134.06838,183.129303,212.186137,180.917333,61.094439,-3.97055,-87.635842,-85.795221:214.23652,244.039447,212.864798,109.520536,49.696216,-113.988106,-214.460657,-285.282229,-139.461,-94.124041,-141.996215,-195.112357,-294.495868,-340.200643,-445.565759,-478.843437,-398.308464,-246.054108,-207.223115,-165.460014,-141.676908,-110.383854,-110.71216,-63.115528,106.700639,207.379665,391.550878,442.912781,413.693019,373.246431,337.084628,335.662012,326.709662,282.858864,270.560295,309.652736,333.995538,310.586595,267.538924,218.90466,264.895339,272.150191,203.655276,155.72158,74.830782,35.554013,-37.951501,-50.853031,-8.342435,53.303759,66.547156,31.53554,-16.505394,-113.399628,-143.800568,-113.474044,36.908344,88.894664,102.819292,97.79466,103.7395,97.38987,-14.553867,-92.864077,-85.042969,109.143838,167.471344,76.26251,-6.524159,-25.464118,15.989879,54.061982,132.584325,227.934774,375.052578,362.29832,218.601799,131.006144,-30.795234,-61.285979,39.956873,104.978563,47.011558,-153.443726,-251.077297,-356.611582,-334.888753,-194.375705,-107.815973,-95.022972,-29.687527,31.969519,119.897403,115.974651,46.915792,10.788904,-14.901036,55.436643,96.257065,64.179807,-10.869728,-199.279973,-276.284853,-304.342358,-233.752716,-212.29595,-175.237515,-132.730444,-26.53887,-21.648617,-131.228236,-164.244528,-74.376123,43.725542,50.850531,-41.698895,-107.155539,-172.007033,-167.002659,-128.066675,-74.293649,-48.163518,-12.847853,2.117657,24.425421,14.181387,-54.271774,-86.013451,-57.279405,89.105636,129.325508,39.666918,-35.708904,-93.925833,-108.161561,-181.659412,-191.06419,-158.247268,-74.82562,-52.76367,-102.758549,-159.563121,-220.271505,-194.945668,-111.690031,-119.773516,-160.479014,-268.197415,-306.294189,-286.075843,-252.39198,-224.167798,-151.66283,-62.633695,129.284056,176.442116,135.595014,81.394677,0.373978,-5.901275,64.619799,146.077727,144.294619,57.862077,-5.891684,-113.001767,-124.662925,0.315794,172.05856,172.850102,46.464604,1.944843,-22.750133,-44.742268,-140.990808,-202.983043,-278.970621,-232.426403,-180.345464,-102.908458,-93.659824,-104.10957,-95.106973,12.488492,163.729026,201.424341,179.455763,133.808733,11.055818,-48.103385,-122.667598,-105.686478,113.074989,352.860484,363.205151,164.139191,22.893792,-166.716452,-203.677713,-199.268137,-68.906437,2.491971,27.635326,-8.097866,-35.846365,-11.093766,19.793,9.706574,-13.594249,-20.903552,-3.912755,79.529783,123.43062,175.147374,164.888754,64.889264,6.07947,3.345855,20.945834,39.474924,-38.33621,-149.669219,-273.10965,-214.536716,-14.464164,14.114192,-8.211793,-46.783572,-86.729586,-194.783603,-231.204835,-179.347373,12.210526,103.660259,207.90013,199.746103,76.148738,23.208179,5.068569,4.082838,8.435429,88.747836,146.917689,181.067283,144.082152,74.629061,56.858556,31.252315,31.89226,20.729452,-40.551119,-75.895453,-138.38056,-161.723159,-186.271144,-165.306009,-30.321381,85.24517,96.109152,1.442087,-81.57204,-176.894744,-176.2682,-173.552146,-213.091644,-217.609573,-150.150802,-103.682331,-93.066314,-133.857619,-219.017051,-239.472217,-269.235533,-268.076706,-226.674633,-148.995263,-166.406586,-274.087889,-304.41599,-251.268977,-147.249658,-108.226329,-22.690788,16.932087,10.142496,-26.424578,-75.777768,-81.615169,-77.785541,-44.9324,-6.560895,69.76228,80.894721,52.814587,31.036356,1.948054,54.203847,108.289473,192.012568,216.317172,245.837299,230.899751,118.25849,77.331667,133.43592,176.578915,152.576949,127.937766,146.859391,143.332715,71.609713,-134.747754,-220.270976,-208.639338,-103.630731,-64.029958,-134.065196,-202.454839,-269.872926,-237.633115,-25.658739,151.33188,139.105439,34.975089,15.079996,-4.817255,-45.676902,-113.059562,-14.100545,61.280302,121.109713,103.144317,31.080148,-0.890588,-31.579303,-37.669107,-37.823943,-5.895581,17.61369,26.319184,-11.843238,-113.866603,-134.295663,-79.957069,13.769449,34.851733,65.364464,90.961936,104.062022,81.169575,50.394137,73.204781,158.852939,160.900188,146.413879,148.771942,124.614057,-3.412971,-57.985437,-44.942754,83.236878,136.119904,181.460118,164.501928,54.118369,6.389467,1.236017,29.649134,91.188515,142.22613,168.336478,158.866939,109.267961,7.419556,-21.872265,-19.545329,75.798488,122.681722,181.437501,189.946885,140.725155,110.355028,108.462015,120.2024,146.533223,221.988626,250.173746,173.19295,94.903502,46.440107,90.416187,181.132483,137.602376,101.932058,142.147639,187.266371,191.238177,159.146741,103.87872,96.183885:39.247129,213.983947,226.040055,78.215183,-22.014432,-167.713723,-216.092254,-259.987612,-233.343156,-206.741434,-157.583606,-161.707879,-240.562215,-304.56782,-433.521375,-454.21583,-363.981682,-219.234503,-174.539696,-138.166569,-128.243591,-117.408051,-125.695992,-93.313362,113.981769,252.846548,470.095158,496.304419,361.151406,259.031492,130.190182,118.900374,169.595591,262.022977,319.937982,368.405862,316.100453,152.937079,113.353263,156.27381,234.411265,241.950995,208.97985,181.438551,88.210545,28.982867,-31.002828,-17.213684,39.442189,71.632992,85.724738,89.574258,44.949598,-127.808112,-186.774447,-101.04238,126.052124,208.901164,297.606026,299.422302,186.494609,104.249299,-23.326745,-56.145769,-55.725321,23.420965,72.2613,91.546811,56.576076,-9.974158,-16.112028,55.44215,225.007978,303.128803,349.330866,287.628946,41.685414,-68.276935,-151.088696,-117.332945,21.916651,49.113722,13.602419,-63.548354,-104.326075,-191.148043,-213.813297,-150.501475,59.213272,161.001426,278.022753,282.563717,159.092215,66.300335,-23.105674,15.550213,166.745516,222.596245,209.196028,113.570269,35.213813,-116.837288,-162.440911,-152.967396,-61.139487,-24.693203,16.4241,23.942617,6.066811,-18.390304,-89.040402,-99.029982,0.492962,126.402318,156.998294,134.953863,85.253536,-12.991124,-19.701014,70.4194,196.562708,246.579896,307.932096,298.935926,180.567749,101.14582,-19.739429,-39.647862,58.046314,268.09392,323.614792,224.060791,124.985615,-27.985468,-92.682851,-190.935153,-124.683483,-52.486942,-0.440028,-35.957403,-149.631829,-203.089604,-269.10305,-254.525947,-129.250355,-46.983594,-77.049149,-247.470687,-310.007333,-270.623411,-227.13386,-194.082709,-50.08857,82.139861,288.602136,303.680283,192.163707,117.618079,8.950139,5.54698,107.236476,201.381132,217.051692,142.634018,34.630124,-183.596334,-207.832543,-33.6929,200.26004,237.412223,186.819655,140.985398,17.299107,-58.792349,-153.895242,-143.024397,-102.563497,-94.45305,-65.422857,-39.898278,-63.385856,-76.990975,-58.878096,11.692521,155.014664,226.648213,314.282703,317.110466,221.509194,125.418687,-74.636826,-97.633727,63.206201,296.71647,356.796323,226.702015,59.426231,-230.507626,-279.257747,-176.189522,22.430493,76.393163,82.19306,59.59325,14.513096,6.859682,-27.378991,-64.698769,-83.096355,-15.796747,5.926018,18.588519,32.373782,56.384962,40.475051,-13.382815,-19.474845,-17.573151,-21.674055,-50.783761,-183.343527,-248.004465,-274.543129,-220.484952,-56.963394,20.087054,34.812191,52.059106,26.117118,-81.119554,-102.425235,-17.403066,78.072631,111.771547,198.50973,203.475305,72.839187,-12.682161,-109.457768,-102.705402,16.411763,193.739894,258.631204,254.737466,197.029658,73.658621,36.456548,63.279183,149.508833,155.779278,119.504995,82.340512,-43.677284,-109.836381,-199.089207,-180.321873,17.168767,185.750672,199.705786,52.123966,-88.680868,-293.935478,-306.360079,-220.324978,-108.067323,-55.644086,43.545189,52.963644,-64.821685,-157.783836,-332.43564,-379.108491,-280.429907,-75.728108,-45.901072,-153.830193,-237.107216,-352.531995,-368.652113,-305.635099,-150.123486,-56.874996,86.439635,86.472406,-36.038064,-86.855812,-99.148938,-79.987363,-31.950597,3.62167,33.173412,107.038694,99.750262,-35.466945,-87.659958,-24.631354,113.714615,154.298522,159.130783,128.681421,51.471651,11.578338,-74.584148,-76.539834,61.758011,169.427199,159.814666,105.009499,83.222897,9.683871,-56.435083,-150.902776,-55.74473,17.085902,103.079392,98.547649,-29.379966,-126.233412,-265.02739,-252.92106,-57.811982,97.948839,114.783783,87.642548,50.808972,-54.119952,-94.364578,-54.778481,114.204098,179.92483,190.972502,148.64428,50.754655,16.193522,-60.063953,-92.111468,-12.132448,152.532276,167.028046,60.875521,1.806185,-50.571166,-61.573759,-16.475918,120.34437,152.098636,172.924064,201.215908,181.670021,98.364887,-47.644945,-23.204969,178.109842,324.611192,338.966897,248.472429,141.858964,-103.656535,-166.921764,-108.598915,39.144427,85.994278,117.16584,116.603391,82.9705,42.791283,-33.101061,-21.817617,103.802655,199.913161,199.547318,106.264267,38.918478,-55.328003,-63.948,-4.584081,102.031325,141.284735,143.711519,108.820623,38.261521,32.541915,46.718767,59.340328,152.996137,249.07715,255.566546,161.523708,66.739945,-99.642221,-115.034113,7.255565,141.894814,155.949871,125.889287,93.88931,-7.646181,-45.354071,-66.927335,-70.078916:160.762982,255.615182,281.287391,192.979293,94.03751,-53.97121,-72.779916,-95.023963,-146.515563,-165.063833,-220.869196,-252.201895,-246.993513,-223.250403,-228.577682,-250.335617,-231.896372,-180.615045,-186.586935,-189.003499,-149.921159,-54.25861,-50.280816,-66.089512,118.113878,238.779115,331.360289,321.182692,314.153153,315.440271,278.139851,251.779676,251.399095,302.341743,320.072813,316.239619,287.735539,199.95106,156.878656,124.473633,174.979467,186.460425,141.84882,111.862381,100.07035,105.274237,39.386388,-24.761781,-88.646174,-59.627933,-34.893474,-30.166627,-66.073361,-100.409825,-80.442098,-50.606749,-5.086628,22.306566,40.388728,28.868148,-23.123427,-51.293046,-108.981689,-134.922387,-125.996822,-75.897531,-71.36886,-150.562931,-225.139972,-316.683938,-301.267298,-210.243712,-82.217621,-9.228265,67.598585,42.860452,-73.813617,-100.620239,-88.85732,-103.948886,-157.272971,-146.603373,-141.813873,-217.693506,-274.563693,-285.532356,-258.192979,-259.603347,-177.689555,-78.188043,93.222085,129.119426,117.560687,101.123779,65.84937,34.035935,6.010078,108.606531,163.019704,79.586877,-48.497166,-237.933783,-268.307307,-295.909139,-287.767242,-262.539558,-214.255627,-207.73128,-194.597144,-160.759822,-103.923217,-123.289458,-174.270435,-101.900375,-64.234291,-88.226424,-146.565227,-261.186558,-284.992374,-307.167165,-332.218573,-330.663253,-289.55493,-242.673994,-150.226898,-156.016671,-267.422097,-316.720768,-317.837826,-222.637516,-165.680493,-146.659074,-196.747194,-238.850755,-212.794288,-165.169152,-69.963921,-10.352261,43.637414,39.441171,4.809036,-28.977829,-114.329521,-129.371344,-86.077573,-108.074994,-160.909717,-233.633276,-237.01144,-227.219178,-222.797671,-184.74253,-84.203808,-20.762,139.394134,220.916038,271.967261,229.348288,77.31968,5.12618,-30.828879,35.07596,39.271651,-22.187229,-42.515039,1.010489,41.704589,123.667272,200.63577,186.943238,40.32879,-23.572623,18.817282,96.324333,97.444351,-16.186859,-249.487237,-321.42191,-322.244317,-278.277381,-242.4838,-202.994539,-191.883985,-118.948398,-26.274218,-21.230469,-101.936227,-143.170923,-149.312193,-131.050359,-156.111615,-192.712135,-142.161505,41.386475,85.789522,23.719862,-46.645538,-162.567426,-187.256672,-131.79529,15.920918,72.867406,100.024461,78.909322,43.853654,55.084554,80.49708,64.388544,42.556319,130.047844,183.071411,257.556564,280.366518,284.909886,260.028159,182.012889,197.82375,236.710105,279.230482,276.154338,185.954109,105.167429,-21.446584,-36.719759,-13.36278,-41.026856,-51.084887,-36.071826,-28.790973,-5.644007,2.660837,28.20144,168.2544,269.551936,372.041953,320.469968,160.965905,139.202255,144.210943,120.691408,79.540822,118.366241,143.315472,161.016941,154.526766,126.609481,114.962098,104.284322,110.470502,115.300018,122.474097,116.392929,82.055805,61.112177,7.41376,-10.200642,51.673841,171.01185,207.779654,196.754677,138.064588,-14.37296,-59.399426,-25.066566,92.862986,120.770535,117.919234,117.879535,100.428866,66.835756,-37.141656,-93.736291,-131.478006,10.043509,116.845631,214.402945,164.407941,-23.52708,-78.046927,-27.069326,73.564849,98.438362,163.701498,207.349905,207.469772,164.391215,106.902017,106.132087,105.317232,92.724607,103.896858,159.32145,172.995183,118.782019,77.423186,81.317225,197.119866,238.060611,258.049241,249.067262,202.662894,181.556666,155.441003,152.098488,155.607075,104.86913,85.046367,85.869937,65.605934,-51.333424,-120.088809,-189.613284,-141.561684,-100.980021,-22.8105,-15.534313,-62.854326,-51.937134,22.656071,33.192226,64.745837,126.7666,120.249072,51.905185,10.28605,-85.17598,-121.103416,-89.604671,7.030293,24.546922,16.195764,20.846872,84.203521,128.44617,139.022951,93.61978,39.022348,93.045347,100.903558,52.193523,28.609124,19.299044,14.630946,-36.201815,-94.97675,-100.028264,-30.710154,13.23433,3.92821,-47.025561,-127.920414,-121.002303,-42.086939,-33.194223,-58.828553,-114.638961,-130.968947,-99.265186,-79.807693,-98.894126,-100.597545,-58.179587,72.834411,110.180841,35.847354,-49.17029,-190.815475,-218.62155,-150.480552,-42.456278,-30.557128,-36.333478,-20.275074,14.94938,-0.658056,-61.956398,-35.175777,-0.178757,49.416982,57.676427,37.893829,8.998365,-77.788718,-93.867779,11.37895,124.627597,123.638124,36.954722,-15.515625,-37.559352,-5.752968,9.389268,-67.009074,-88.438126,-24.17647,51.684023,151.50554,142.293879,73.813123,60.886504:200.353892,206.684834,143.311206,14.113927,-23.246804,-117.663653,-178.8193,-209.683789,-131.565976,-119.023198,-162.109173,-193.311049,-243.629788,-261.799359,-282.331757,-270.649879,-215.93691,-191.828916,-189.435329,-185.829975,-180.176846,-142.722241,-120.585978,-61.66263,79.424272,162.329725,309.788952,343.919299,272.270493,215.253407,181.328707,191.468979,222.607053,237.341721,242.016677,305.133201,346.06308,309.137059,236.715812,141.499755,165.996552,181.356294,172.035333,156.607473,108.176055,73.536556,-21.015559,-70.213476,-94.443853,-15.702995,38.417423,130.289048,143.132521,112.558858,86.616624,38.511854,4.664024,-22.377797,-66.288015,-58.076559,40.281159,101.876221,100.991097,37.747109,-21.67701,77.144026,100.647357,-25.42934,-116.75421,-136.282298,-80.219078,3.865148,79.883387,135.310032,241.428089,260.68859,196.031994,150.239169,90.348445,63.60687,19.114658,-34.182831,-73.426388,-156.376267,-216.483714,-329.500087,-339.710604,-291.589957,-233.74037,-210.087205,-164.257331,-118.873014,43.221458,122.172325,129.199639,40.70483,-141.805954,-113.42215,-52.358249,-15.241558,-59.879294,-186.28134,-242.97788,-308.471166,-283.365799,-267.729928,-243.22532,-220.434784,-154.798574,-122.592695,-95.827233,-93.886675,-57.787197,11.126975,33.146522,-25.424896,-101.081254,-204.909867,-211.596563,-259.891167,-341.313198,-342.942559,-278.103712,-231.170181,-163.550735,-157.9997,-207.214542,-237.583178,-232.264989,-156.508178,-125.483316,-138.651804,-158.090826,-117.869569,-93.894105,-143.120974,-134.949432,-83.554501,-3.876615,16.239669,45.294886,46.904572,-1.113561,-34.37044,-74.216279,-128.145859,-185.264268,-340.408016,-399.800497,-398.048305,-344.265847,-212.95173,-126.741173,-93.245764,6.020144,71.48364,194.191553,213.240841,56.041631,-70.197767,-155.308137,-74.998653,-58.039021,-46.074149,-22.469582,29.150406,30.481985,15.055348,40.43368,17.023705,-123.344344,-167.884779,-85.064371,4.080104,54.650123,-27.028607,-271.048476,-386.033136,-361.805548,-209.36595,-146.595616,-122.092091,-134.273972,-139.678831,-54.68406,10.535423,74.831643,38.047321,-109.46573,-136.366933,-24.505515,57.366035,143.359323,149.145481,146.22971,85.328803,22.693206,-57.509745,-52.321556,-8.461129,32.411598,37.136669,46.169855,67.065883,121.261999,151.835675,186.841423,172.842663,104.559752,70.503437,96.831753,202.705111,255.857054,333.305686,325.638375,162.286086,41.249284,67.919052,167.927764,189.522603,104.665563,0.109168,-193.732533,-214.339553,-120.769868,-80.332438,-98.67532,-153.309986,-179.980141,-210.373995,-206.017868,-151.316311,-19.557238,57.958414,144.059207,135.414153,55.851464,20.27897,5.025496,25.554278,84.108868,109.014328,107.228224,100.755542,112.62242,92.88889,20.565001,-130.333992,-131.178859,-119.66849,-154.984709,-184.436889,-213.619078,-215.33075,-224.821478,-221.218974,-137.462431,-16.06209,26.448458,57.662188,34.109317,-75.258664,-135.028073,-210.875173,-212.223342,-195.597,-151.061334,-141.915297,-183.635551,-227.279512,-323.197749,-337.725519,-204.894328,24.03046,103.214673,95.751921,14.362638,-156.318441,-188.532372,-143.144503,-105.779364,-100.983378,-18.87495,40.462998,43.467362,1.744441,-38.842509,-28.030497,33.140205,105.887864,125.393747,88.858575,49.256623,18.011268,23.072321,41.896976,120.250324,146.158161,127.503379,121.509983,192.690814,259.279201,278.81259,188.913467,-17.332604,-33.733421,20.594268,152.910713,184.964621,85.944461,-41.886119,-261.348441,-215.801924,-169.48908,-195.380118,-238.937742,-310.621193,-328.222877,-286.293903,-215.062179,-19.288327,93.396375,94.706235,16.042073,-34.894131,-88.106099,-104.103629,-126.069019,-45.453296,13.964834,66.077585,65.000718,85.718926,112.764467,97.911765,29.160501,-64.09233,33.981598,74.276582,32.63157,-7.4817,-37.346123,-61.150768,-151.275421,-102.878775,-35.634325,75.212065,124.097259,186.249712,173.281451,87.598547,56.567748,72.172155,103.09486,90.033728,1.020564,-57.496188,-110.822954,-81.02071,54.816488,144.909961,164.629113,242.748413,280.201334,238.850874,162.551972,3.895215,-18.806421,72.244928,167.98027,194.709083,202.47511,169.22862,33.114075,-30.255429,0.380381,137.628204,135.904669,46.266235,25.753983,5.35716,-17.552053,-39.580407,-21.070359,49.326645,68.867518,50.812785,14.89265,-1.454889,-26.079244,-22.818876,16.429092,41.132952,52.835115,153.759304,216.900905,235.480429,196.576448,121.216307,105.270794:113.749648,246.702214,256.723576,165.230273,106.599209,2.645797,-51.519118,-101.376907,-52.829119,-53.971422,-140.806197,-180.45163,-198.423338,-219.613526,-332.20144,-361.605687,-291.909218,-224.349268,-202.705494,-122.107123,-80.883845,-41.100736,-39.995729,-5.965426,154.053885,242.424615,344.658173,370.98909,363.351679,323.242512,238.243405,219.781477,244.16714,260.720978,242.120386,223.260864,231.845035,198.584145,141.912165,86.602705,181.114044,207.950574,173.834872,152.064115,83.725689,13.757964,-113.364123,-132.732681,-135.020041,-163.373615,-157.442786,-124.761134,-140.046163,-199.05032,-188.946551,-76.035794,58.559513,103.340398,140.718394,123.623595,22.930726,-9.082405,-31.845513,-84.574038,-231.171486,-207.249277,-130.565357,-15.804955,-15.436452,-27.999151,-21.6494,-36.702566,41.223697,126.011495,218.524946,189.932412,48.482275,-18.162871,-110.562888,-133.079427,-76.651407,19.318219,10.136114,-130.51877,-213.2904,-284.510445,-272.266876,-190.462389,-33.999595,36.838607,136.119855,191.298889,232.816049,189.115992,89.922802,80.999892,130.615388,138.232651,106.089243,12.891252,-31.278377,-89.02164,-104.81024,-138.958817,-167.245959,-155.907106,-54.857796,12.676301,75.738016,59.48645,-23.198669,-68.772463,-55.535277,94.115126,134.051975,67.165271,1.658219,-109.17732,-154.812228,-216.099645,-188.208021,-130.204817,16.991445,49.512825,-26.379481,-91.894178,-179.020502,-203.510305,-195.345081,-39.45194,44.471292,67.479933,33.392859,-5.038423,-61.437796,-253.833896,-178.570714,-59.084621,68.021092,50.252403,-54.007892,-106.40221,-177.365359,-158.396384,-16.889315,-27.805059,-103.439369,-172.450239,-147.884916,-124.709841,-154.641077,-191.285082,-73.078603,3.79937,128.338545,184.401215,217.825611,173.028158,23.638821,-20.123641,65.090094,233.658689,246.468842,87.843584,-24.578977,-132.009034,-108.01691,19.475953,156.37523,198.219937,221.221981,200.36763,80.080701,20.720482,-26.017713,-57.406352,-210.238641,-293.119736,-252.637712,-146.48771,-118.913845,-56.772875,-24.993267,13.706113,96.550915,144.944086,165.650594,130.66645,1.0759,-61.709331,-124.395011,-118.994105,17.305512,223.453046,256.845729,117.942156,-0.520187,-116.535234,-94.545117,-15.978019,55.141746,89.688702,126.285863,121.853505,113.840546,110.72459,43.544798,-3.569651,-17.234258,52.513099,76.814162,86.170558,76.133209,82.546886,111.314997,117.588079,35.263269,16.952252,59.781594,76.111605,16.373666,-37.836315,-131.992614,-157.830996,-132.690588,-43.27536,-2.233935,13.601454,-11.065693,-40.623174,-38.418013,-29.167734,96.310934,200.899023,270.870376,193.582519,25.326571,17.614971,58.936778,52.544415,63.09671,137.448084,151.828732,128.109491,105.986433,59.761787,41.058899,62.458013,155.669086,173.263218,112.741272,65.228448,-6.223238,-14.662559,-3.062971,16.661809,118.64386,187.286909,188.461597,149.111092,92.091889,-70.939024,-137.608563,-175.929302,-63.47131,3.227435,79.203165,97.492234,54.580604,-12.409724,-144.456106,-177.68318,-148.851027,-40.150695,-2.95884,-50.835943,-136.457347,-310.050085,-330.922203,-200.398223,-19.328884,50.269853,167.829141,191.435742,102.140204,36.057078,-18.078441,-15.084145,3.374857,2.238111,0.212929,3.891105,0.328653,-2.873891,9.513667,58.912057,154.542265,201.734962,221.863446,204.491136,179.095927,152.599224,3.546402,-77.868756,-76.952304,45.958913,66.578362,5.332755,-41.869145,-61.711375,-51.841521,-58.945825,-33.782418,-30.406125,-27.1733,-10.566342,-59.946409,-114.521954,-104.297172,-51.50771,30.944646,71.482189,52.945396,-20.461709,-27.229182,-1.29451,-4.709433,-29.915312,5.225572,30.61006,53.549997,57.527748,66.765165,84.829748,92.651794,43.981434,-41.753757,25.790163,59.475508,40.764793,14.718242,-1.590783,14.839748,97.532108,127.228129,76.388606,-40.063198,-44.95184,14.568284,17.422299,-49.925828,-45.791037,78.018732,146.649383,145.526205,88.010407,20.94007,-94.831138,-100.320377,-45.410081,-5.126825,2.588573,31.91576,55.124266,67.722366,43.09307,-18.327695,-5.574586,110.873919,191.964333,198.83312,152.533101,94.494134,-62.728798,-116.851969,-53.244952,91.422541,115.748054,128.903851,124.956583,47.514293,7.604791,-25.265781,-30.600963,8.85889,107.042305,158.01671,195.19478,170.612521,131.335188,141.542908,153.350833,121.535888,99.73063,85.797543,95.923531,88.786074,69.098453,17.393957,-10.51414:left
-54.702193,-210.864687,-253.898802,-160.053771,-96.230891,-64.747763,-61.453678,-24.873911,19.482205,20.510373,-54.165998,-101.875195,-141.731191,-124.513992,-60.626007,-35.564182,19.690245,37.266308,11.19025,-86.056245,-149.168472,-251.238465,-262.727291,-219.26118,-145.54311,-99.034035,-48.788845,-92.561979,-268.97171,-325.560338,-310.157133,-250.880359,-60.190986,108.307933,137.89547,76.668066,20.701783,-62.311163,-79.955658,-71.895592,-45.666577,-32.003593,-52.706765,-120.169883,-241.878704,-199.943036,36.894619,141.977667,220.611415,154.10733,121.38097,52.664615,2.164385,-29.322554,6.750912,142.24127,273.194275,262.113849,82.495338,-20.712054,-134.870635,-138.209202,-108.672097,-96.430709,-118.765374,-260.186731,-322.764325,-359.541507,-341.481097,-260.294451,-227.730707,-150.530105,-15.252173,39.392725,98.896666,83.131679,-10.645043,-15.452109,99.451969,166.550994,204.407975,109.042141,70.489636,31.908654,-7.717886,-65.961787,-39.569589,58.572577,122.124339,133.982417,106.694074,68.553992,-25.929263,-39.825492,31.392545,80.373217,123.513411,59.967695,16.224376,-25.963822,-50.439176,-157.70465,-185.898057,-71.749587,80.964033,79.687259,2.133906,-10.957388,30.096867,82.080536,208.473737,240.973588,198.196421,44.769669,-45.040081,-161.606589,-162.694726,-81.213797,-34.973594,83.751182,239.359239,252.168555,172.848108,154.408877,144.815126,111.855674,15.556957,2.72528,104.361967,172.576369,135.776978,8.670351,-38.131357,-75.062672,-93.374969,-152.503909,-151.392611,-141.437468,-133.376109,-131.888958,-131.002729,-106.170216,-40.906301,-52.791739,-165.450453,-208.989309,-178.642029,-141.552195,-147.523354,-119.421543,-88.342289,-56.186584,-25.295298,-3.981853,27.795035,20.49098,-81.883478,-130.337467,-78.364894,-4.528291,104.83024,139.574909,136.958608,25.565553,-74.399205,-159.811237,-121.254632,-14.720603,112.145977,159.061951,107.731645,27.863694,-91.331979,-84.530962,-25.294904,-31.642564,-23.085568,141.705163,218.980344,189.332945,117.832358,140.314917,234.520681,292.760906,116.351849,32.506046,-58.615206,-99.169055,-191.546316,-188.23285,-38.313015,44.057809,93.350463,110.393745,160.885744,187.633034,115.626608,-17.196349,6.593043,196.672079,298.823699,261.893597,161.902505,137.268749,95.861129,106.396278,257.742579,333.118047,339.64668,263.927443,237.735085,205.862187,192.567338,163.823563,151.553574,133.570224,104.301748,66.804516,-23.753672,-65.371346,-194.106382,-257.834051,-272.385889,-228.173479,-117.046904,-87.450424,-124.43847,-256.243103,-306.100509,-255.732838,-168.823668,-34.875963,-41.678852,-56.914754,-41.78222,-29.890865,-49.194087,-77.845587,-120.902517,-113.193977,-68.056423,-49.234651,-39.471653,-58.186715,-109.49402,-177.711425,-137.317188,20.472619,52.480254,10.185511,-40.680073,-40.821081,-78.288649,-104.379102,-132.718818,-150.628344,-148.112249,16.869353,87.793097,-53.571824,-207.51975,-299.172495,-229.611162,-78.323075,37.382931,79.237552,137.285051,142.301372,80.92558,73.912384,203.146475,298.343001,401.389291,271.734863,184.24393,113.719738,93.381266,74.969396,128.454229,370.328212,584.552602,606.97135,508.440913,430.962208,304.013176,271.405877,236.924589,227.70219,232.609563,213.655131,161.769928,2.599286,-39.559118,16.081549,80.880101,229.488201,347.418168,343.946337,147.306002,-9.673339,-217.36461,-214.369924,-95.301213,-29.506292,50.098874,-7.255749,-47.772697,-69.935898,-62.174414,-33.079816,-19.338956,-12.385596,-22.151368,-42.170633,-116.921393,-161.596133,-241.936955,-261.101034,-227.638292,-171.612188,-83.633632,-148.742499,-180.757057,-164.985858,-148.998717,-157.762163,-168.59505,-97.602325,63.995368,87.72599,-17.147409,-105.853506,-286.683784,-339.420282,-311.377107,-247.205357,-105.544505,-132.520243,-201.940383,-267.30611,-246.958334,-156.803101,-99.682357,26.37069,81.074383,53.192305,-39.861104,-84.411009,-170.113939,-197.131207,-175.901976,-140.048837,-145.005053,-240.898515,-257.020569,-301.798645,-359.496718,-392.979312,-339.106834,-216.111098,-121.236046,-50.555134,81.210892,82.087411,-56.634292,-112.380368,-90.455807,-67.20895,-82.393408,-82.838276,-73.682043,-111.350041,-141.479221,-140.537073,-108.594691,30.655438,217.467892,246.75979,166.10851,107.597437,-17.579901,-82.025243,-142.107862,-130.133416,-80.727169,-102.041108,-150.80168,-243.949371,-249.139907,-164.484481,-112.081866,-91.635847,-181.408314,-221.779358,-222.681927,-205.267531,-191.8699,-168.653842,-65.248958,-22.519446:-11.893894,-123.589269,-180.465725,-195.681214,-138.342177,34.13689,71.493346,-8.452206,-33.006968,-9.387042,-41.438529,-83.108266,-65.276759,-6.464525,38.069416,3.287768,-74.35847,-130.093768,-144.230785,-157.731496,-190.406724,-281.057446,-276.009165,-95.870284,91.038323,106.367561,38.696038,-13.516961,-173.136605,-252.783686,-256.906704,-179.66584,-40.505022,-4.682379,10.216598,32.602743,19.40771,-74.595964,-130.004289,-142.166926,-56.805464,-16.234335,18.10621,-16.472629,-93.421062,-58.599979,99.421755,146.395456,127.201179,76.924608,80.078621,60.031796,-4.35791,-110.965127,-94.707386,22.917774,129.933978,114.787695,-103.887673,-233.429039,-294.254658,-242.725862,-167.590746,-140.027444,-82.461081,-204.816598,-299.124418,-354.010296,-316.300736,-238.086175,-228.312342,-132.700028,87.501783,129.110943,30.214938,-51.436319,-141.344224,-111.08721,83.170165,188.056033,242.56179,83.905569,20.565193,-49.921869,-118.711554,-251.245106,-233.226639,-14.224648,175.729489,175.01352,74.389009,9.24409,-128.857257,-144.922063,-15.119128,64.331177,80.344147,-71.982135,-127.951799,-132.388726,-125.85895,-138.365694,-117.745172,12.983302,110.525499,84.263569,-43.48303,-79.393514,-20.506599,58.287781,145.479478,121.805336,74.73005,63.199727,12.363603,-132.828547,-164.318654,-128.134275,-93.555426,5.39168,87.773505,75.31031,1.01461,-29.324034,-69.571429,-73.277977,-69.636061,-58.822364,10.33327,50.408207,30.687508,-70.385239,-104.290648,-58.545666,-43.816241,-106.229863,-89.923085,-82.040507,-174.414547,-216.37147,-146.384071,-60.519076,12.463742,-45.394844,-248.3317,-339.26992,-318.833075,-301.964299,-316.603451,-257.613983,-195.198164,-123.037119,-122.15524,-129.831827,-115.191746,-101.800096,-126.24856,-150.280326,-119.007531,-44.129075,151.805824,189.239054,121.136928,-22.699799,-41.623325,-10.153638,0.563129,20.817777,73.516041,83.632334,92.740072,104.937962,90.323091,87.946239,116.744274,91.532083,-0.301822,-29.123905,-41.89862,-97.755133,-109.692578,39.302491,156.596856,219.61889,118.310497,85.759934,-8.747096,-106.500894,-253.848419,-216.321891,11.275509,96.518341,99.966492,13.11276,-4.530244,-44.280739,-74.152652,-50.468039,8.449532,114.013346,125.691276,112.78203,85.27838,57.582036,11.839146,38.306197,202.118247,272.718182,225.175877,99.498053,98.564826,129.840684,106.165584,47.206166,66.441147,177.915113,199.81505,141.150197,-44.818563,-144.933625,-303.191028,-322.566077,-248.500366,-208.739494,-185.937019,-187.088809,-214.297007,-355.443505,-396.050943,-306.150848,-245.150838,-202.853635,-176.381482,-169.344551,-186.267663,-203.744666,-254.310654,-267.127251,-220.271735,-177.837481,-114.859393,-108.96082,-137.407398,-239.97477,-275.512215,-224.629692,-162.943412,-82.110617,-87.828431,-97.495979,-71.841719,-53.559487,-93.521652,-134.028971,-137.696009,-105.673339,-84.282902,-42.557781,-4.719214,-89.509924,-184.698283,-243.869555,-209.649834,-103.763296,-9.388308,-3.815563,-32.659542,-48.134767,-73.624468,-45.803956,154.510509,289.396554,442.740882,355.05433,278.801909,160.180586,115.983046,84.563061,117.96797,287.968684,426.655462,398.742529,243.861206,209.183668,217.71533,198.268673,120.232671,107.619589,146.230704,190.238436,157.842619,-23.20166,-84.706737,-21.950127,64.524354,212.61219,222.455295,175.270222,48.913523,-3.342463,-39.859988,-29.5931,14.157499,49.276564,112.269149,48.461902,-3.250589,-59.052707,-75.40314,-60.329641,-20.47718,24.833847,-11.087393,-12.680688,-20.004102,-87.23086,-251.954141,-252.851582,-124.618346,-47.320851,70.280316,20.225443,-33.345325,-98.786335,-138.487492,-208.684613,-178.589836,2.088093,60.554709,19.512951,-59.692895,-105.787517,-179.388653,-154.460684,-66.318261,-50.515819,-38.509215,-67.697374,-97.113525,-137.759809,-141.245781,-76.578967,8.170327,205.955975,189.009407,86.279727,-86.461531,-110.755797,-94.175027,-88.030656,-78.397258,-43.803954,-12.395743,-125.290272,-146.920816,-165.239181,-209.255471,-207.89721,-145.157722,-45.883959,-31.450859,-28.634877,-1.288833,4.858613,1.719464,17.074304,66.865145,76.330692,74.024759,86.877437,52.562545,-137.134117,-205.673136,-149.475445,-73.24471,47.948332,115.008979,135.653844,67.708225,-40.995293,-247.891028,-287.358074,-247.131834,-202.003739,-146.755042,-167.035209,-207.479202,-257.708899,-216.310985,-91.710988,-68.52231,-89.569279,-158.243715,-189.724964,-218.166084,-230.269127,-255.217942,-241.169786,-108.94816,-8.354243:37.997392,-84.344496,-162.323384,-242.740379,-223.410711,-118.542674,-67.339046,24.215349,113.313586,112.936021,-7.925858,-83.988478,-73.773052,30.939157,184.739788,150.337555,-11.871292,-53.659494,-26.349842,-10.977393,-40.011995,-62.981122,-36.995777,54.694136,138.505563,151.736178,97.575977,25.456224,-154.370935,-207.244221,-167.044279,-106.358026,-59.723841,-65.022627,-20.439657,57.813359,20.716901,-169.866843,-225.263134,-124.878663,-11.308763,-13.996634,-70.038341,-100.510758,-77.523607,-3.600951,154.771804,185.311017,111.509372,13.564505,38.366836,81.038288,9.902534,-120.074595,-76.853546,91.699332,127.169225,84.849685,-58.642281,-126.519193,-197.337447,-210.906364,-197.058518,-129.456508,9.154998,-178.817234,-311.527519,-399.205533,-366.940215,-248.209807,-171.462041,41.535659,176.772017,154.594417,13.735885,-53.693447,-115.733628,-77.103549,163.287293,279.53196,269.262649,101.339295,61.033219,5.221781,-33.081277,-43.630137,-7.458045,112.326766,185.40536,179.140229,138.859855,67.49657,-164.83407,-210.703627,-76.09484,-0.637463,-41.476233,-165.267768,-146.653542,-52.478042,-81.106521,-187.120465,-146.282614,91.130762,192.110863,141.645854,10.971488,-0.266237,66.086987,94.550598,114.875857,129.724492,139.728818,53.455783,-14.916177,-126.268331,-146.212706,-105.075597,-34.238785,192.340126,246.167454,152.499047,-48.618923,-102.240373,-163.235685,-167.203218,-109.708921,-73.546239,-7.549197,91.668205,101.022657,-31.491271,-90.800437,-84.845693,-87.780105,-153.114711,-140.745477,-140.979773,-259.051024,-311.340259,-218.137869,-116.967006,-56.125007,-108.837109,-212.355399,-221.602431,-222.766825,-306.970789,-354.016512,-283.252334,-195.295506,-94.377188,-82.621143,-88.812982,-137.571434,-167.011237,-161.024452,-125.396359,-53.180949,-19.778854,59.116085,109.775551,110.154366,-3.459409,-99.97013,-160.829345,-97.229761,71.100217,105.522428,83.678099,62.623135,63.943144,97.502977,133.499429,171.587664,140.22626,24.327685,-53.097969,-81.76981,-142.892496,-150.444856,-42.898315,45.235147,138.19439,75.044218,42.269993,-15.184699,-96.555944,-268.781907,-259.114835,-98.416463,-30.109433,19.869619,18.12537,-6.731625,-203.737803,-299.77419,-222.432109,-107.678594,41.600755,70.057136,36.571681,-55.333005,-60.181928,31.28961,83.508685,159.035378,191.988901,186.891072,107.699059,61.118884,-26.319329,-33.048663,44.98522,84.255197,71.97851,-22.729731,-55.486928,-91.151365,-132.889535,-233.970297,-239.625794,-196.244396,-194.266723,-220.984594,-209.166729,-183.03329,-180.762932,-191.849158,-135.768274,-92.745086,-58.340038,-88.478222,-110.988604,-124.642836,-125.480481,-152.760561,-167.393124,-152.479422,-124.787554,-73.938173,-52.665449,-55.241887,-131.905804,-181.573065,-187.607012,-143.678484,-31.169556,1.35944,-8.736307,22.937635,47.80536,-10.382173,-87.662714,-157.303135,-114.579724,-45.055971,-58.608696,-59.617871,-146.669767,-225.330773,-276.879123,-240.653412,-143.543805,-67.031908,-16.102992,88.279907,69.550046,-75.962239,-72.925834,135.112228,227.471016,282.236393,319.203521,319.359311,178.504517,91.42962,66.888906,107.72339,186.563711,244.600279,251.40272,183.916524,120.711516,10.278055,-24.158177,-56.988593,-44.447943,28.581917,52.511602,-0.180935,-151.97123,-170.819612,-118.744845,-86.424295,33.759713,147.945401,138.641653,-15.926162,-114.971203,-174.517485,-116.62412,86.483745,182.615354,171.747165,-46.930192,-100.226278,-91.017514,-63.889781,48.172493,95.909068,77.826102,-15.134076,-58.786948,-135.544038,-173.884924,-192.768126,-145.796071,-15.920889,11.362603,-73.531541,-233.909826,-247.531091,-166.263641,-158.658155,-208.893893,-194.071761,-97.914881,-62.440069,-57.507698,-77.474788,-144.851413,-246.686474,-185.72931,12.994922,34.489098,-71.991561,-126.546667,-105.353511,-87.067743,-99.724102,-92.564154,-49.694484,88.263212,55.625713,-33.663271,-148.339716,-162.981071,-143.7362,-116.474082,-95.088151,-76.360809,-21.951116,-111.689184,-169.289851,-252.152879,-274.374214,-186.127764,-91.529203,56.157984,62.141354,20.122971,-40.389159,-44.096556,-8.726504,47.551283,153.101019,154.718545,112.646834,68.224409,18.66521,-89.032286,-96.552266,-55.273491,-46.728979,0.13591,76.497671,49.715174,-162.650829,-270.580767,-325.105273,-299.563004,-255.90937,-225.175071,-120.064871,-134.270552,-229.374752,-342.311721,-277.666356,-126.519686,-118.595798,-136.614157,-116.206202,-138.033945,-277.407417,-337.082536,-328.033842,-267.273897,-86.844906,1.423638:-102.451056,-178.218192,-204.359755,-165.357616,-120.293682,-44.043297,-17.96121,62.773312,167.750277,160.264048,5.399874,-70.271216,-54.709925,26.389816,158.218317,170.744513,138.301487,89.228782,83.272558,78.093385,36.289387,-91.701142,-106.498003,29.438683,168.517894,172.201729,82.78589,8.154074,-147.982787,-198.092444,-185.665818,-120.640145,11.378226,28.257245,16.536105,-42.91767,-107.151392,-238.508959,-253.551308,-149.980625,-40.311718,-34.020756,-78.611251,-121.939343,-185.962694,-147.506122,53.365628,161.464925,285.11277,204.170628,140.518547,90.149871,81.102921,78.638232,115.679666,290.015323,393.989465,336.622387,77.860667,-55.534575,-203.272339,-195.937471,-90.034108,-43.202874,-43.978234,-176.277331,-233.784572,-264.463362,-258.757244,-215.673863,-177.416814,-58.02762,91.491693,124.447827,91.216651,34.845093,-101.775775,-92.508479,130.96264,237.661235,293.942782,238.130209,205.903996,128.444264,78.036501,23.494401,41.781239,139.834027,195.369317,175.270413,94.488957,36.807693,-112.288894,-146.458589,-66.795215,2.933385,76.316777,13.468262,-18.02399,-32.5124,-50.706383,-128.719132,-148.383406,-79.075154,9.524121,-4.058865,-97.129216,-116.199745,-54.656287,9.685996,123.989264,147.439973,152.916115,142.23402,92.487484,-99.766338,-148.068197,-15.196666,91.629419,252.252367,342.32174,322.436559,221.558967,191.105862,136.432022,98.551597,40.281824,46.051466,100.916667,71.863052,26.958992,-111.119984,-177.640762,-189.755837,-155.251545,-107.21218,-102.922683,-127.83518,-230.944122,-267.109807,-204.48979,-129.157491,-73.657961,-112.806698,-172.709101,-140.119921,-126.729514,-147.504515,-156.201265,-114.63751,-85.199731,-38.711636,-8.383794,-22.614729,-91.070425,-127.911783,-170.893348,-160.247634,-102.19415,-62.846934,41.039136,91.359018,91.051248,21.026858,-64.692167,-213.991577,-215.461995,-67.005882,89.485324,97.496162,33.005986,25.353552,69.369676,92.100144,101.66152,88.122331,84.774309,120.480632,123.110837,65.250734,22.921843,21.424611,62.278977,116.361216,110.8242,96.724931,21.74172,-49.974181,-186.456522,-185.480793,-31.214161,53.371758,92.218397,48.167472,47.474054,2.489095,-56.78192,-88.225066,-26.990684,155.290908,250.612993,235.297616,133.706143,65.621853,-39.502011,-16.823383,177.207053,267.80906,310.507847,205.661333,145.502752,69.802308,54.470748,76.746962,97.427635,107.661125,64.132818,20.928582,-60.138161,-100.406474,-222.501597,-272.58023,-242.004523,-175.610773,-64.328593,-40.858657,-56.994397,-164.064418,-223.412102,-191.497794,-115.316665,-7.535921,34.980373,56.167476,78.477863,53.678617,-55.673752,-99.236082,-94.102661,-37.999319,67.890608,8.562949,-37.937737,-106.289899,-140.723701,-141.768597,-93.039541,34.85211,85.305677,71.126944,57.145967,63.246495,23.884282,-19.555822,-60.723047,-47.213308,-9.470512,57.366508,73.155646,-35.96112,-97.020761,-82.291974,-59.616652,-61.443609,2.943158,54.869198,124.508924,124.026205,68.095916,68.25041,202.090282,289.594647,387.015575,350.191403,291.82399,152.340616,98.978374,68.592408,106.290149,309.209752,443.387027,402.908876,276.720276,249.822275,221.776607,213.724034,231.020343,243.023504,216.320817,146.718777,98.310715,-43.528969,-82.708408,-34.001853,4.336653,72.878656,176.101359,201.720426,88.942316,-21.754801,-142.35447,-126.768207,-55.671996,-19.217704,55.609855,48.869287,19.146998,-46.761657,-74.466564,-58.593113,-10.967762,79.422622,65.081222,9.399983,-132.175773,-194.0689,-270.281683,-261.208158,-143.444608,-72.255875,-49.070739,-202.114722,-252.262812,-259.726047,-272.129381,-301.399075,-287.853547,-209.744097,-91.385077,-62.081565,-118.253382,-178.632445,-261.115022,-255.739374,-165.470359,-111.805255,-83.439378,-178.992883,-231.94414,-307.235485,-321.404826,-244.782457,-173.492339,-61.056923,-17.395191,-45.054638,-185.97951,-257.08231,-299.664836,-266.618827,-171.261127,-124.82735,-89.742751,-203.001833,-257.984594,-296.071929,-304.508584,-302.246499,-271.877608,-149.644029,-69.203665,-76.237736,-118.490264,-146.426821,-205.733307,-192.567809,-67.87038,-15.083654,-10.866805,-40.762125,-44.85748,-73.842464,-89.354462,-81.864216,-59.091642,27.484041,107.392735,122.253996,75.78109,-3.895134,-199.852253,-250.677388,-215.932789,-154.09605,-47.275453,-131.88557,-222.232556,-290.301246,-243.564381,-105.520483,-64.011617,-56.696778,-91.743231,-108.003068,-152.734459,-189.288412,-194.867527,-142.357367,-49.708941,-37.611072:-13.905061,-70.222181,-105.735022,-123.540801,-106.054606,-48.593273,-15.390463,69.435535,140.580535,135.655235,41.26934,-18.064477,-16.203719,58.407704,190.133393,208.470408,184.716282,148.733612,147.625705,108.691697,58.806005,-7.582861,13.058745,166.612642,214.063811,144.002958,-19.364707,-81.740572,-169.092328,-177.473889,-109.388093,-48.138725,14.119891,-66.425754,-118.12637,-221.091585,-274.644802,-318.966911,-281.706323,-91.817713,41.661566,22.936923,-90.532659,-126.310299,-139.793349,-130.246487,-32.030048,68.754896,206.962968,98.727564,28.831161,-4.652273,14.376787,105.993045,189.64942,378.540014,396.349811,304.01607,42.745744,-68.820286,-184.204257,-171.006562,-19.627968,69.347165,111.699481,-91.245435,-221.827596,-359.593597,-345.913261,-235.077885,-160.347815,15.252875,107.758012,91.63657,8.712266,-36.140374,-80.571488,-46.01989,123.298401,205.57678,244.788446,164.347488,120.735723,15.711542,-23.243934,13.36478,63.241984,148.501377,189.981875,178.858578,115.1952,42.315053,-158.989498,-207.039372,-103.382289,2.862187,114.490909,-6.748027,-94.733482,-233.901266,-284.476623,-290.923557,-225.764019,-42.014241,27.055917,1.614691,-110.610497,-170.022871,-168.449359,-84.233035,99.977396,133.610261,109.605933,106.436481,102.225743,22.692194,-17.195095,24.029437,100.025726,262.192733,266.317673,186.895598,-4.87814,-71.04891,-91.039297,-60.526147,-10.138527,21.55813,98.247156,42.625935,-43.029707,-206.072364,-233.22559,-178.502379,-145.816924,-146.045121,-183.30866,-218.228658,-345.940528,-403.709133,-353.91798,-241.663977,-30.552889,7.594305,-58.559927,-217.493081,-266.81248,-270.787769,-241.680153,-140.943884,-87.970363,0.608721,57.154945,60.000429,-66.663612,-187.59108,-304.563059,-251.785239,-57.769393,30.514272,97.528172,25.317694,1.897851,-54.934594,-113.191642,-195.830158,-176.573262,18.419649,191.813717,176.479581,59.076602,51.440869,161.649671,207.222697,178.959726,141.908547,129.378188,156.53938,133.094941,-15.043827,-87.006374,-81.380442,-12.27405,109.365416,124.241243,123.749282,77.409732,-19.116006,-236.177326,-224.867584,31.482432,137.720067,141.039276,75.109524,52.678809,-111.911723,-218.151903,-204.531436,-103.670885,66.199478,143.553296,158.143852,149.26594,114.337329,38.292577,52.858897,171.481916,214.999217,206.834437,116.08701,37.168337,-138.983307,-163.402761,-26.598086,66.519784,132.433777,0.888413,-74.353087,-144.759697,-164.480869,-200.153801,-198.187673,-119.132761,-59.478326,2.205897,-11.862773,-34.241069,-142.105282,-197.534036,-186.281328,-129.694593,-5.857618,79.943439,95.140565,72.30325,50.498604,22.987011,15.343514,17.41559,41.842772,85.708919,38.382908,8.460552,-72.97946,-130.108185,-137.29819,-48.565115,177.527729,192.434622,124.169152,-28.784353,-85.361438,-112.917425,-89.939587,-21.199664,20.699067,55.946972,13.576143,-14.751549,-176.425818,-274.400758,-281.856985,-209.824121,-90.488565,-16.347576,24.465527,48.185553,-8.256767,-118.527613,-77.096483,113.755432,170.086638,210.225199,241.670692,225.558738,112.476886,59.557509,83.499178,154.450994,265.916803,203.745217,142.581034,102.705938,109.769311,90.688265,71.61301,40.001038,39.886956,66.05631,22.028171,-49.846149,-182.193615,-172.507522,-25.881478,52.341534,187.333906,207.084281,142.933739,-61.549246,-153.000341,-189.28445,-138.968006,1.889724,66.029001,85.4746,-24.483745,-38.276486,10.263378,30.915161,102.830505,145.52052,161.654225,133.133851,114.779563,-2.311774,-93.15947,-164.333857,-109.7583,38.798373,71.426891,-6.985614,-192.625074,-240.050624,-243.194163,-240.645448,-200.271676,-142.233704,-24.311819,-38.120352,-85.430482,-155.143123,-168.01349,-154.239118,-113.374324,-13.52082,11.563701,-1.180238,-60.460308,-94.08039,-192.468016,-239.471435,-207.371593,-133.610508,16.283265,71.598296,21.894195,-207.279422,-304.382113,-312.672019,-257.971068,-174.326265,-142.232036,-102.55807,-154.237042,-194.994801,-295.880315,-321.588936,-231.934931,-152.976156,-26.145728,4.460629,-21.354802,-95.410892,-141.045903,-203.994483,-173.262908,-8.541047,67.630512,164.143419,156.488212,69.799776,-182.28254,-235.938825,-123.587264,-34.066581,92.289321,109.854549,69.433667,-88.521483,-186.099499,-278.711452,-242.545635,-103.706935,-26.686477,101.266452,-24.738778,-165.070017,-264.00441,-186.10736,-40.551178,-45.160108,-106.810136,-83.786207,-63.773141,-119.870277,-193.057039,-258.102444,-204.487338,-44.31609,6.178906:-42.778151,-131.151451,-145.958265,-84.439565,-41.615965,26.613663,55.512722,112.5744,155.126122,126.173738,-21.324655,-69.475582,-45.660018,-17.307069,18.910145,49.862145,153.507079,196.93997,168.218105,42.251138,-29.64732,-110.616229,-112.226988,-62.656488,-23.804273,-49.77846,-127.195079,-141.827375,-166.891392,-192.861831,-253.487635,-249.099563,-92.92074,55.191472,53.56744,-37.745576,-95.676339,-206.63207,-224.454095,-114.180143,12.340948,-2.934928,-123.18301,-160.636924,-155.89845,-128.162919,13.307624,133.040585,318.52295,275.176252,208.306365,104.610517,86.687097,160.803802,243.599822,396.210913,420.235138,379.233305,220.793586,106.554752,-82.951813,-95.566262,-27.551645,-15.532356,-67.022628,-163.900549,-188.151327,-193.762115,-199.607735,-183.511749,-155.626554,-109.012153,-85.692352,-59.467393,32.208598,51.335666,-3.800867,-12.271378,125.054759,230.784524,349.760403,255.366563,178.324224,73.350319,24.651056,-45.008939,-27.244988,66.172675,89.959034,75.61618,57.259578,27.062294,-86.567416,-100.15066,25.745295,116.975841,192.266677,61.333771,-1.013211,-37.545322,-66.853416,-160.438207,-179.050645,-125.614925,-39.470439,-41.188536,-101.42255,-113.592241,-67.50243,-11.656765,81.159488,83.809219,61.598923,56.248654,21.523531,-110.112066,-135.6473,-1.334285,89.410379,160.127223,206.202006,258.424639,344.11418,324.461384,163.934097,85.503073,19.336571,19.537966,41.040076,4.17402,-34.193115,-82.994053,-107.190217,-175.51402,-200.21689,-191.134929,-144.475695,-135.580556,-136.207528,-149.299698,-192.283708,-183.699513,-97.775771,-55.075044,-6.154844,-46.47699,-99.169261,-199.758034,-202.841218,-62.667075,9.179925,-32.43718,-116.883832,-97.452054,-52.594728,-77.639681,-169.998597,-190.560114,-162.150513,-116.197327,14.027434,50.73233,13.7122,-110.612541,-178.284825,-278.503613,-290.809399,-183.876948,-19.374361,-20.628156,-116.760552,-122.296384,-46.456156,-9.398292,19.151816,30.002086,144.10549,310.19954,320.228167,157.107325,63.016429,63.990318,134.715565,173.281797,33.436055,-40.622294,-119.117742,-154.232512,-218.007736,-170.79473,44.835648,102.824557,63.359109,35.152321,62.198398,73.33366,38.76371,25.983184,79.633223,245.258757,333.515194,306.433347,150.692326,59.304925,-11.078553,53.348095,260.860184,306.403103,264.608141,271.630651,297.338906,232.970338,139.313905,14.892481,39.438867,165.20052,151.01867,89.436742,1.699666,-25.124287,-140.934899,-187.762962,-128.638354,-68.56597,7.334651,44.873887,38.527318,-70.93064,-151.772619,-195.709028,-132.441086,60.962044,174.25359,174.982007,152.069111,140.176191,82.997363,64.428265,64.969155,59.810663,52.15374,83.239098,87.317225,-24.509148,-116.083242,-179.260067,-137.552043,-43.206128,-33.550256,-64.019062,-131.713952,-157.108656,-198.898683,-176.462495,-9.595393,65.442135,84.164254,88.307011,108.473733,37.980932,-53.492992,-124.432417,-82.941856,-5.414123,21.671505,28.223363,23.416234,12.951881,-9.320132,5.299451,108.756515,175.312341,255.015773,181.631524,135.240382,88.22605,42.31185,-55.068248,-17.890973,238.883422,372.871023,338.04562,246.270592,228.266032,202.485552,193.591215,211.216882,214.244438,167.408079,104.812016,64.037713,-55.155083,-85.026346,-4.008829,65.51849,177.942493,240.909722,211.090785,3.093043,-118.973446,-258.073766,-248.584455,-91.526434,13.111298,123.989406,34.710432,-16.075736,-56.461195,-68.502244,-82.43049,-84.285879,-73.801246,-20.994092,-14.901958,-95.240064,-165.666112,-274.975251,-270.902685,-178.570535,-134.872828,-94.239378,-111.585569,-116.06064,-139.970438,-177.754613,-221.79326,-196.758413,-45.645785,162.711978,190.013755,25.044901,-111.386194,-311.09324,-334.052765,-311.909464,-311.253449,-314.283913,-331.331264,-353.389912,-387.613195,-386.056981,-335.501752,-292.624097,-166.756011,-78.077627,-99.232599,-206.534468,-252.01144,-276.388269,-236.095548,-96.009636,-51.196906,-90.438131,-224.005463,-265.142163,-296.149457,-320.056482,-354.858163,-335.861386,-234.018833,-110.875887,-57.998286,-8.016684,-35.762725,-186.11449,-240.798068,-157.865502,-51.610064,68.019285,-5.670379,-38.872109,-12.957975,14.572485,31.41399,36.918387,117.642636,279.288298,316.22416,196.396545,73.082017,-80.185474,-53.276891,41.121549,41.794827,30.56605,32.765699,-1.268618,-92.843951,-109.825358,-69.373805,-41.938329,-22.370876,-18.372566,-35.941102,-118.043423,-160.454349,-197.522806,-164.610465,-4.334469,56.305931:21.990323,-51.971398,-109.55581,-165.4823,-152.658033,-46.844387,35.771586,184.571679,230.723292,191.904471,9.25713,-82.278195,-102.743926,-11.141966,237.12553,320.342897,345.379913,246.929175,192.765982,99.644269,41.492543,-80.74656,-97.36247,17.715835,120.131916,84.017588,-72.07499,-131.505769,-194.586645,-211.231377,-191.505418,-131.269429,20.062985,-5.398014,-81.560592,-242.589212,-302.491498,-302.134209,-221.395462,-2.919266,45.406417,-10.138935,-134.919661,-177.134343,-209.630928,-168.43228,55.37219,186.868686,309.119553,206.931674,131.912905,7.812425,-30.09487,56.83991,189.842196,452.864945,520.895685,465.123386,198.615245,27.415264,-199.990645,-199.944294,-29.330466,65.232962,99.241568,-122.701529,-238.942791,-324.274753,-315.892793,-236.828362,-160.106296,39.956388,181.75473,174.271896,-11.289534,-135.13458,-202.452428,-90.121075,230.226679,329.835399,357.833974,203.107485,97.055844,-53.298137,-81.737139,-49.553235,-1.777492,113.391169,156.915695,120.684353,-9.775449,-101.452676,-280.405628,-283.724444,-82.637849,44.226877,163.740467,69.060854,-14.675748,-195.21049,-272.339331,-325.400885,-280.644399,-91.872966,9.096309,-23.368222,-173.49076,-239.950693,-254.281697,-186.182034,12.693108,80.803365,124.122536,93.9064,46.496427,-82.85809,-123.118393,-47.940814,49.243433,233.860741,345.871267,351.13464,220.409215,119.655711,4.718138,2.509827,39.921408,81.436896,151.156818,53.06032,-38.377942,-165.494952,-179.722615,-148.875424,-118.926484,-35.216717,8.958074,-40.28347,-234.961321,-310.115738,-283.656579,-179.9792,26.71369,72.4566,62.937588,-61.19688,-141.121204,-241.94097,-242.582966,-152.547414,-88.721509,38.426101,106.186747,76.506671,-67.221022,-145.8097,-240.808383,-222.814678,-113.480425,-66.589675,0.040864,-23.117407,-66.18363,-164.383216,-218.410034,-275.592339,-237.521104,-40.67022,118.020996,125.603166,32.011978,-24.423287,-41.308902,5.282074,137.550387,201.68789,285.989841,244.034222,169.966588,-30.144411,-96.867311,-44.885362,40.753609,186.172371,198.118122,134.147008,-71.194932,-168.905738,-245.728,-186.672322,53.448497,156.905378,202.660625,111.56542,81.228502,-13.980664,-89.27107,-101.856168,-6.952237,211.712485,308.254158,304.801419,191.1347,82.819299,-107.931331,-92.793762,160.758001,276.270048,275.739504,102.534803,31.855353,-41.633731,-58.428622,-37.287232,19.838379,160.175837,98.974552,-12.92443,-161.900912,-162.023789,-149.990034,-157.345295,-107.672156,-43.671461,95.151178,142.882307,91.99945,-151.905064,-266.759552,-263.555004,-149.858944,120.098293,231.532124,195.946939,57.624927,12.538741,-25.904441,-34.226858,21.385884,99.846485,231.695746,147.950448,46.492398,-170.603391,-249.493788,-239.28687,-150.668393,46.096949,100.06284,54.96865,-69.310434,-117.829804,-199.821172,-201.308668,-82.909059,-0.11408,146.355238,168.672616,100.586205,-115.059563,-193.033284,-177.639044,-112.536228,12.244599,78.117907,80.683887,13.899593,-51.310926,-166.594367,-161.901717,-11.994493,98.942127,310.354935,302.117897,195.990995,-1.869223,-26.710026,45.92739,108.114336,251.387502,300.79373,242.835098,101.928146,76.353933,66.828289,63.03995,75.254387,92.862181,131.87168,129.459019,85.672326,-66.880211,-115.231831,-69.366764,3.053806,208.979927,318.599831,247.844722,-75.165874,-216.366165,-268.283596,-215.598764,-99.412255,-34.956529,67.234995,19.014352,-35.524018,-124.07071,-141.725956,-83.286752,-29.130863,55.018781,117.437326,110.496935,-37.821257,-131.970006,-183.921515,-130.334061,5.740596,50.940438,66.170806,-73.016902,-165.666299,-289.358721,-303.060979,-214.280082,-136.816065,-4.554283,51.104938,24.33098,-105.858197,-170.814093,-235.852067,-230.186523,-168.343166,-116.384595,-41.641809,-160.917768,-250.065346,-334.103554,-337.02601,-266.403449,-186.639713,-7.963025,67.076642,28.766469,-178.427425,-301.315673,-426.841944,-392.836782,-201.520077,-99.931797,-39.464422,-193.834666,-269.000117,-356.815454,-395.248229,-389.952653,-297.636353,-29.638035,47.511823,-18.509213,-181.812548,-217.912991,-219.765252,-207.089697,-129.85258,-61.653609,53.9557,28.789984,-37.726481,-173.757209,-189.166034,-71.716434,31.07175,224.628894,292.287478,237.549616,-6.661428,-121.462738,-206.859193,-182.860981,-38.844472,62.761804,204.393158,117.578084,9.60405,-108.676225,-73.131817,42.737082,65.229018,102.493418,156.610473,121.890107,-58.655316,-131.459107,-148.663551,-99.417403,48.500847,116.513529:-108.903838,-49.523349,-45.698734,2.137382,63.300851,152.973768,143.618877,86.311789,138.04818,187.346496,208.110144,171.907871,62.958544,24.418102,28.723091,56.886718,129.712432,173.503217,156.497258,82.689406,39.119092,-107.396915,-196.324317,-285.072383,-292.67977,-322.388029,-359.445923,-315.094882,-192.766791,-183.824938,-277.000735,-319.410094,-271.174771,-94.186457,-19.814286,-2.032236,-46.267173,-104.833544,-82.759012,1.232416,-13.566541,-70.228331,-182.619071,-219.244094,-264.063418,-229.200343,-12.662966,102.888469,217.961736,201.232018,161.800337,29.499464,-36.860222,-18.753295,80.486906,288.157956,332.849871,290.684906,158.879578,119.222239,107.293057,97.226548,33.897931,3.358436,-27.95253,-90.512664,-130.88743,-185.975995,-197.237976,-144.217223,-94.823971,-78.93514,-125.156676,-101.542791,12.188227,46.257391,26.5771,21.307382,102.998165,151.531843,198.331172,182.606067,145.7793,20.402145,-48.684668,-115.896057,-108.333653,-46.52558,-2.482024,-22.888717,-84.504917,-93.030744,-101.335016,-102.414103,-39.722651,11.387918,70.52336,64.159161,74.880559,97.263627,65.31404,-13.421926,-11.793705,13.940822,-28.875699,-58.214159,-29.802067,27.286622,116.531656,140.656879,166.160645,146.066634,67.271009,26.187588,0.274617,-48.999305,-36.97188,46.208037,88.582157,184.491355,316.772418,366.436001,393.12207,377.631576,279.684176,197.788994,31.422014,-5.426076,35.721859,13.948903,-25.383679,0.609473,43.288916,27.23472,-35.661867,-163.877645,-134.084016,-71.262375,27.53167,42.981306,39.010012,57.496945,136.681356,151.925404,114.675132,62.50325,34.058485,-45.332633,-78.473956,-45.91162,5.675522,73.736996,99.438695,88.14028,5.689092,-44.999564,-139.458748,-169.258462,-132.657705,-72.097323,27.452657,20.993438,-13.937553,-120.479024,-171.781537,-210.718661,-207.079409,-189.212437,-138.263674,-127.767506,-185.531421,-236.941026,-284.173958,-259.718036,-227.149636,-227.865926,-80.18646,188.500335,237.408668,114.606397,24.339192,-26.412581,-3.803163,3.073698,-49.360757,-90.370019,-170.824991,-182.515289,-141.387948,-101.91871,-27.075163,-12.655598,4.882553,77.319773,129.117596,190.574893,154.722113,14.34238,-5.460269,75.387466,121.131819,108.902583,44.977692,-30.52357,-213.294256,-214.923145,-1.035605,91.791603,80.496623,62.259124,113.137961,159.942495,109.991927,-4.273443,-13.930844,37.344281,87.487154,78.882487,17.382972,-1.678588,-17.533362,-11.023567,67.079858,118.399443,187.439552,166.087623,102.088741,-114.558118,-214.323491,-210.01397,-107.921554,125.544041,242.255818,250.16951,252.520293,248.468456,182.523244,156.369658,159.28708,145.260298,53.71357,7.855937,12.275128,-45.992444,-139.034953,-293.058929,-282.494008,-133.100691,-37.719103,-60.210025,-133.446584,-140.546927,-129.9621,-107.77719,28.209322,129.70583,287.821633,286.334498,242.782224,101.528796,19.807312,-33.255021,8.309597,100.048709,99.227508,67.353027,-14.008862,-47.182535,-67.841552,-34.024091,101.438656,148.096636,141.045871,86.9522,52.24696,-47.073607,-83.723807,-63.340429,-27.315444,52.351514,123.210385,117.662428,41.50495,22.326142,52.748296,71.713189,86.85132,105.104271,166.609217,92.620302,-22.139504,-266.3269,-295.526418,-109.808284,-3.044928,85.467391,110.684206,93.249909,-34.812163,-126.922647,-278.649896,-286.643352,-147.968441,-41.937137,125.330058,58.085415,-32.78803,-128.417569,-126.647347,-101.515652,-91.034105,-79.509349,-91.812448,-101.522505,-102.800757,-106.987679,-144.00171,-146.558612,-70.557597,-20.14064,25.114195,52.985738,89.309705,151.857329,148.020721,68.243889,29.775933,66.57173,195.084146,214.108537,117.23627,29.141285,-163.904811,-242.004561,-304.219969,-301.434795,-292.860977,-287.060838,-277.746628,-297.313521,-318.851196,-289.545004,-252.905734,-196.704306,-112.642654,-88.475148,-154.664117,-221.032764,-297.961535,-274.277303,-190.258444,-174.462638,-135.34784,-122.059701,-137.334221,-145.809113,-148.911241,-164.0957,-161.514216,-106.512496,-1.225744,31.494742,21.295148,-10.467766,-67.011222,-64.005774,2.994485,44.134784,113.534439,162.25283,177.485939,122.472755,52.264747,7.423055,79.40043,312.451369,412.460367,368.729799,187.929695,108.001564,47.936304,74.358388,147.52663,149.396558,128.901227,146.451145,158.93275,179.113493,172.175944,118.217561,92.396297,55.615983,67.062436,71.098134,-3.068664,-54.77345,-49.434819,16.012244,150.040782,181.078465:4.583928,-129.298571,-183.966498,-90.812012,5.456855,112.792028,128.867,159.921335,195.627,178.811082,35.691154,-46.742584,-86.71832,-54.341547,-4.28372,17.730968,105.20586,147.561183,127.251115,54.242679,-6.668897,-202.284863,-297.703233,-338.867423,-220.47524,-198.49544,-226.023231,-216.144596,-160.918007,-136.03784,-95.961749,-85.454045,-29.448408,105.732758,142.727881,86.020244,40.467731,-17.047048,-40.260924,-50.032559,-20.141599,-13.442898,-40.903168,-94.403588,-218.043623,-207.119878,-18.867989,90.906506,217.584219,171.402779,119.541981,28.744083,-10.953821,-20.700659,29.724911,182.571563,256.601389,220.881059,81.135098,29.366757,-23.479168,-36.556499,-25.757621,-3.213311,-8.126766,-118.105502,-159.910291,-168.099718,-147.60381,-63.447594,-23.761254,-18.015171,-3.357993,56.03288,228.302506,280.984583,211.656379,136.569696,124.887955,201.030597,341.587459,304.863846,258.725097,161.511266,94.958211,26.108427,52.189963,108.650723,89.787059,81.688662,114.071222,123.439782,77.26739,75.250429,163.510813,201.860903,184.104272,112.831339,107.831453,89.796252,27.24541,-118.200757,-133.359195,-20.988468,108.187532,121.814277,103.497428,85.492637,21.50292,31.875204,176.660834,235.73402,235.802987,122.920339,47.623217,-33.579901,-10.49354,97.142693,119.370591,120.470231,234.609022,290.881486,293.233473,265.188338,227.312197,220.106024,174.921293,143.293577,151.091676,180.89844,159.835026,72.652465,26.859601,-52.705573,-100.144128,-195.713307,-170.45542,-122.277023,-42.071909,-18.564159,-11.811967,-2.478055,46.50492,40.167649,-52.877302,-105.389217,-100.657795,-96.207019,-83.529907,2.290118,33.808407,24.832551,42.022713,69.510926,138.554548,149.536483,34.446854,-54.773651,-143.276601,-124.457248,13.258327,98.17564,64.905013,-39.822357,-69.138223,-69.256537,-46.301511,24.72967,107.528923,108.063001,-27.129323,-121.542722,-219.803592,-213.549516,-179.131749,-155.295637,14.837016,256.761495,309.523019,247.95112,178.959816,85.344083,72.275117,70.214354,-18.942322,-93.60834,-147.902459,-129.967205,-140.203148,-153.820834,-123.04561,-92.289159,-27.611289,48.19266,93.823781,152.905191,134.694654,46.208043,29.824001,84.281327,180.704693,208.551225,149.083143,69.449963,-36.877139,-3.091761,159.637676,200.428419,139.801553,80.727479,117.09346,213.644816,201.230915,127.458945,132.516244,201.188559,165.612053,89.797545,-1.96626,14.459907,-0.482718,-61.466636,-121.797516,-69.363344,96.545438,76.168628,-6.304435,-186.304962,-245.965902,-191.453685,-89.682301,94.79924,181.740483,197.069673,186.493187,176.329558,170.688461,162.534598,112.324126,83.847718,70.651494,116.789811,132.254036,65.166916,-19.523585,-135.846139,-114.613321,13.113245,78.530418,49.431478,-53.45383,-75.71649,-47.299089,-15.209323,25.908614,17.762911,12.316593,100.253569,127.446811,21.489927,-70.927673,-151.611205,-143.793823,-81.31401,50.093559,86.087049,76.124926,70.718822,95.642393,124.254161,180.56369,201.495482,246.508499,219.566515,187.151039,172.631833,177.884219,169.848961,169.85118,270.561202,440.821492,460.53591,355.734112,292.506385,256.96794,281.489729,325.52871,324.322984,278.709531,189.314033,129.211319,-1.425548,-40.602066,-12.701996,30.589946,103.297135,137.402857,109.792444,-50.310712,-150.834507,-308.262455,-331.347293,-274.998369,-228.646885,-113.191157,-41.854693,-50.572451,-95.707311,-104.99142,-92.648563,-89.817415,-100.566831,-104.596631,-113.203821,-162.347978,-196.686056,-271.280216,-288.633238,-230.252782,-178.809246,-161.757483,-237.281977,-234.54715,-148.172602,-128.242792,-143.709545,-142.526026,-91.018581,26.088441,60.233738,8.472791,-68.765646,-269.563058,-339.335302,-365.278433,-346.397228,-293.834795,-299.52662,-320.269036,-314.773104,-282.116471,-195.369293,-156.112175,-101.595587,-60.21222,-38.819309,-18.373903,-51.456786,-171.382523,-193.684044,-163.325702,-149.623505,-157.650372,-187.288526,-168.513545,-164.602869,-235.575852,-344.816715,-290.412297,-52.280924,81.392827,94.808821,83.324945,46.350979,-92.399685,-133.27016,-90.243353,-52.454085,-10.466603,44.050321,71.412217,26.671202,-48.081294,-119.698833,-56.76744,172.128577,313.42555,306.917167,185.854216,125.912724,87.658601,90.593365,45.119355,-5.302056,-46.653435,-8.330823,-10.249321,-68.522102,-98.3212,-107.787427,-101.554457,-101.817793,-66.612701,-52.316008,-83.446245,-112.407534,-150.689273,-138.314436,-31.169989,30.687265:-77.183949,-81.632377,-138.059774,-195.560639,-152.262999,43.509994,136.566087,183.663571,121.74669,98.415328,80.440609,66.701546,-0.958863,-22.440458,24.476041,69.478648,131.087874,165.6874,165.199455,89.76467,37.612433,-51.655651,-100.529687,-158.244752,-106.800801,-118.575432,-276.397441,-331.55431,-290.583646,-240.988319,-180.706648,-172.145451,-142.909048,-87.714972,-78.608783,-141.913384,-203.416508,-256.866935,-201.003381,7.80393,90.784811,31.147246,-155.302842,-200.183185,-163.888573,-88.140363,151.92222,241.795241,243.495952,151.42825,107.339863,39.508271,40.722611,151.552847,245.603334,439.477024,493.217847,435.139505,243.623388,142.615426,-34.55875,-75.591314,-41.107352,11.851111,97.90433,30.438041,-45.090299,-180.041034,-208.505989,-155.04413,-100.781405,-8.249434,64.56733,77.037938,-16.08896,-89.709653,-100.764078,-13.778663,187.728523,246.806559,346.719434,386.707685,315.894804,40.814228,-84.356379,-164.369609,-127.262506,-42.915485,-28.55408,-32.047996,-52.083815,-84.022141,-164.3917,-161.367991,-41.351188,25.151827,61.979364,36.945837,59.976323,108.915142,59.908705,-138.767482,-184.369671,-73.345933,87.872224,86.450854,-69.045618,-131.223419,-106.019548,-31.538307,181.943671,264.373485,262.233997,95.651739,10.821754,-45.338907,-11.970492,102.719034,163.743322,291.410882,341.718613,314.592049,226.526185,194.265876,129.014237,91.078269,71.560605,99.12951,142.307855,66.545336,8.973222,-67.62623,-78.691619,-34.794526,6.312873,17.492224,-76.859209,-102.574613,-49.473275,-11.818089,13.868845,25.6385,74.065642,99.491859,123.781074,29.625892,-49.799928,-143.913599,-147.808465,-90.556677,-50.172943,-12.443143,12.953187,20.109306,-45.509602,-117.765569,-219.381099,-197.006604,-62.128697,-14.80332,4.459974,-61.903631,-119.723133,-211.090366,-236.194814,-225.105371,-180.056639,-97.583576,-88.145231,-76.537615,-65.275989,-98.16137,-127.158456,-74.004484,24.051166,33.258231,96.275939,187.740297,174.735938,59.504321,13.1629,5.279398,26.976154,90.201923,70.862615,-0.489041,-102.934184,-108.112219,-114.733354,-94.65282,21.339179,63.086724,67.928666,76.025561,81.728045,5.38404,-60.547543,-75.757369,-6.622364,159.215564,232.637791,216.227816,94.154939,14.063412,-108.443076,-110.056452,43.03025,137.895697,164.939323,19.361246,-26.025626,-34.374528,-51.805452,-116.410321,-109.720574,16.826604,62.530115,9.099452,-87.056372,-95.985322,-99.005196,-97.830221,-65.365109,-34.980263,48.163555,109.78372,103.769656,-31.222402,-134.874662,-177.487276,-73.934129,171.037684,223.885347,214.431911,250.905829,261.559222,160.381784,102.83054,118.761597,161.64829,172.150593,62.173972,-1.914233,-154.671156,-247.090274,-296.011704,-220.264938,-44.570568,-6.435988,-39.127181,-141.336516,-196.912611,-259.933176,-215.752381,17.745995,131.286523,209.200509,154.187315,123.741269,69.094406,37.535788,37.729056,81.122352,123.986286,75.603537,49.886561,9.65143,-18.504676,-81.681055,-80.439499,-0.390304,44.064973,110.462413,66.042721,0.48347,-104.931867,-140.933242,-129.386585,-55.014645,132.654836,141.457239,60.687402,-69.440329,-63.090791,17.703828,55.623343,70.856382,44.452349,15.560292,40.719693,17.763151,-126.629347,-181.593356,-116.592999,-31.691877,76.546671,86.868772,62.295508,-81.458627,-181.56668,-298.559388,-269.156083,-78.140746,11.564721,76.544964,38.936738,23.129862,-51.608931,-136.432554,-210.383279,-141.02514,28.42502,22.326382,-26.86467,-113.596809,-149.928036,-220.976131,-206.214578,-58.306021,-4.315801,-18.441432,-68.994999,-63.492492,-21.950849,-27.454041,-77.981601,-77.800018,34.143345,178.699111,190.420868,60.159802,-54.972917,-239.737039,-266.961279,-262.97065,-265.263399,-258.318548,-275.411798,-306.705578,-358.721505,-352.224391,-279.731146,-243.561247,-175.098356,-142.786224,-183.222582,-284.175185,-297.855323,-303.842973,-311.547594,-270.736566,-210.217866,-116.095499,-167.298539,-197.365005,-208.63693,-214.488065,-235.62792,-231.01412,-175.728453,-120.12488,-102.480457,-87.646433,-103.500612,-165.734087,-165.765007,-47.336508,19.62223,66.033062,29.630526,-15.65354,-81.114781,-54.233169,80.189064,133.581534,200.872704,249.385005,228.974109,105.427751,45.929402,-3.921018,22.726801,128.803151,158.824914,196.970449,227.896805,193.064767,88.168302,78.927487,128.474146,145.024575,168.926066,155.776089,96.694461,-12.188736,-11.249129,31.345909,38.775392,78.711976,133.320563:left
-295.269458,-361.588072,-374.170889,-349.694693,-318.287253,-247.770148,-183.850921,15.956853,147.602646,177.250898,236.387457,262.816432,288.152406,275.102293,196.4679,155.591523,59.364306,-47.248311,-64.324146,-50.317697,-43.893847,-22.398148,-12.004532,-53.677206,-120.655941,-101.514031,-36.878106,-37.849692,-23.923117,-0.92507,-7.53401,-39.886249,-114.793814,-121.033938,-127.413168,-233.048625,-277.229267,-238.441441,-188.210793,-141.882458,-160.585494,-168.307119,-205.280116,-232.559597,-205.92504,-145.118855,-10.235785,39.518784,43.885401,-17.928363,-21.650569,-5.524186,-9.730265,-30.078486,-16.551118,75.291844,75.254087,1.654013,-180.244606,-218.582152,-160.099483,-128.347511,-181.216593,-234.36515,-244.436175,-121.38921,-90.94387,-128.247902,-117.733974,-38.004602,-22.83013,7.990206,77.336841,93.90468,-40.375431,-198.011072,-391.261746,-342.323442,-87.897357,31.40029,110.000451,52.556883,36.816843,58.88655,99.26428,189.549868,194.131249,154.500216,188.185904,204.546716,99.073736,11.845498,-19.988096,29.493202,116.046095,126.058934,59.111986,-112.888521,-186.910624,-155.713083,-53.633555,136.972465,177.896989,212.255001,232.840954,219.987595,119.344842,58.171866,35.160284,65.736731,89.227818,68.753119,-10.210007,-122.704307,-174.049347,-182.935528,-139.879714,-114.995151,-154.187212,-163.544883,-14.314346,64.333884,113.773221,81.887329,57.257588,98.125677,182.769424,199.759237,228.264591,251.083351,228.070039,122.631554,92.158211,146.298196,184.048418,127.597113,-45.709561,-95.160064,-55.296436,3.170952,38.595837,-23.543738,-101.156152,-36.226672,70.998899,-53.770776,-114.911918,-179.529853,-224.18659,-333.902596,-358.963789,-323.595619,-306.549578,-342.318489,-356.280325,-280.106791,-116.634537,-105.891041,-99.308423,-47.986776,5.633803,-51.475883,-51.004035,8.376179,9.382791,-85.177602,-97.686488,32.176,91.197129,75.388234,39.748414,16.582713,40.037741,108.398313,235.607989,238.888704,115.043843,-30.29518,-58.454531,-63.740501,-92.860152,-216.835976,-246.925138,-178.258541,-160.692917,-208.588254,-319.077608,-349.104152,-275.006833,-163.020868,71.724994,127.714481,96.544642,80.692602,106.733156,135.828894,158.298316,266.066639,327.926109,400.745878,372.061504,354.620463,319.777589,280.404113,213.556531,185.26371,110.012879,92.051568,91.498602,4.282628,-67.178804,-184.643153,-207.480852,-165.422375,-133.415923,-124.77015,-118.350613,-95.479086,-35.337402,-13.205613,-42.861544,-107.899833,-237.435107,-253.744295,-260.73053,-301.00412,-311.767043,-345.295304,-366.833942,-345.16474,-283.960165,-69.619105,128.805603,160.122834,82.467915,26.727532,-14.553556,-28.171554,-102.019627,-122.822721,-55.066249,46.690085,59.82397,-19.139765,-87.327813,-155.748105,-128.286831,0.271884,55.367806,27.945395,-25.282731,-19.955742,15.260191,36.514426,139.887032,220.400943,329.084679,280.173472,213.46357,121.98492,140.926803,224.480475,242.491234,219.066511,188.103938,206.67214,203.32261,154.321677,107.562352,124.09075,145.225006,143.717964,91.115903,15.55519,5.659393,23.532476,51.494421,127.002217,160.609814,218.815191,210.577327,197.892184,214.579897,209.3591,119.116729,68.413062,48.702205,77.4047,132.830776,146.086821,140.837507,123.778015,150.539926,349.912277,469.499223,526.353088,386.217534,347.314649,342.819053,326.21149,271.609178,261.459955,256.051467,241.763778,205.655715,219.189662,228.461905,194.053953,166.394721,108.102821,98.032793,184.957866,202.617138,119.656761,-103.992052,-169.234971,-99.495435,13.563047,180.166265,184.203984,158.896519,244.821668,280.496776,240.267968,214.287257,226.551166,227.7247,195.73051,185.081833,208.333338,275.426724,284.155904,239.562275,203.467803,189.102406,236.571153,307.777,147.786383,54.602108,76.627119,182.313904,329.844623,302.80738,185.914223,208.347702,249.094667,175.314203,72.654613,-13.778235,14.804855,92.458499,127.083452,183.893523,224.009745,218.734712,87.468953,5.832875,-26.243489,30.491055,192.663693,173.435233,56.661002,-179.537285,-208.436061,-98.118141,-33.773975,-4.031407,-19.177964,-34.9261,-85.798392,-129.116398,-175.184173,-175.380664,-174.000689,-170.037116,-137.664161,-117.093871,-114.321944,-144.419662,-202.544046,-314.776814,-310.872481,-179.00038,-81.872432,16.902566,-105.488987,-194.039366,-257.615667,-215.097476,-108.070141,-81.890573,-70.673013,-49.385469,-11.992565,35.334012,3.755322,-65.620134,-48.195747,35.718479,41.13293:-117.175704,-123.922205,-113.811383,-140.271386,-151.973598,-78.18067,9.339585,156.759488,190.067389,208.789041,208.414735,172.045411,129.02103,141.353816,176.293821,168.771696,48.088231,-105.388551,-129.532424,-118.710604,-111.538272,-70.145326,-27.766699,0.019755,-102.665068,-119.017764,-59.591635,-31.347139,31.045436,73.381195,113.037592,97.372699,42.085305,46.849294,53.398771,-9.08181,-67.2958,-126.91731,-69.263583,127.220791,70.377166,-45.248943,-176.435526,-172.315856,-136.667242,-109.907814,-15.491146,27.111986,13.247022,-69.585576,-94.606165,-97.815578,-80.542666,-6.102069,63.743644,197.634,123.782266,27.654517,-133.896219,-180.117324,-154.809789,-88.869145,-41.370383,-108.459968,-239.300801,-187.351873,-156.633809,-104.713304,-30.518802,92.328221,76.657032,7.889922,18.302728,30.979362,-67.398323,-174.447553,-236.151553,-144.778033,67.599303,95.106559,14.082873,-41.027689,-64.621928,-140.949314,-121.75259,65.959368,134.481244,123.67555,127.620928,143.782376,-7.377426,-141.342642,-208.021386,-155.590082,-59.424546,-11.13434,62.052012,-25.825895,-118.284579,-177.755595,-100.163737,69.10575,94.390958,116.98819,153.253186,130.567377,17.256213,-7.742627,52.876594,84.965403,95.453611,86.85419,41.107948,-51.444232,-124.065217,-183.052996,-126.010272,-47.997426,-68.505929,-94.906793,-73.019212,-47.249268,1.939365,-9.56085,-121.18197,-162.370867,-56.929602,57.436295,184.106624,129.107693,91.391415,62.108785,69.230863,93.379162,95.042313,27.716642,-118.729321,-146.01615,-26.09631,68.324347,113.016095,41.664864,-3.432366,91.052513,169.583009,-41.071897,-109.028291,-140.867775,-151.900844,-130.892005,-99.836165,-120.083347,-281.614365,-361.87954,-368.98977,-282.3067,-103.094045,-59.255556,47.198936,123.6998,149.441185,34.840473,8.467456,19.217751,3.587761,-60.802716,-22.351611,138.479583,59.183308,-15.804537,-65.441718,-78.070713,-74.050039,-15.677908,131.267541,138.790797,-6.438151,-136.622413,-155.688366,-175.215569,-188.780737,-143.346106,-67.542993,44.555096,-43.948254,-113.411139,-189.574667,-181.817764,-64.082594,16.059475,122.872053,140.183383,126.792707,174.384021,204.444771,139.343914,115.420284,262.94804,365.956477,412.819916,341.081235,335.795624,325.166119,286.909434,232.018966,224.279304,211.936623,217.054314,188.745971,24.947494,-52.652721,-66.130251,-25.001594,23.151798,6.058635,-48.322645,-35.266186,-38.826643,-78.043785,-72.385924,-87.424158,-154.268914,-264.300713,-255.039634,-252.989834,-402.606567,-464.376559,-442.0161,-399.239023,-392.118083,-392.902045,-278.727056,-145.717372,-120.519127,-166.29506,-221.943996,-283.316445,-266.578804,-201.096487,-199.480622,-243.921655,-161.402383,-101.442139,-142.630719,-231.369957,-296.327785,-232.778042,-90.167079,-127.128361,-168.95243,-156.001895,-117.34669,-63.018375,-36.094829,60.843815,91.84332,25.393237,-23.943044,14.076088,100.533212,120.566247,102.380572,64.428579,-11.249101,3.737178,26.921515,19.108194,22.700482,104.095301,137.736439,173.511914,194.129645,140.349818,5.69322,-12.133328,36.215456,68.029654,85.764215,80.201504,91.861201,123.810915,149.22068,185.111451,165.538153,95.981778,91.63217,148.064733,162.368894,96.050658,56.26421,91.918113,243.418096,339.500434,538.923479,618.522243,616.796949,477.779569,435.826426,401.51122,395.977012,380.845441,361.506351,319.193602,293.774801,231.474065,177.502358,145.910587,83.141173,56.005149,10.240712,31.538506,191.207222,260.058692,193.09804,-45.040923,-130.046232,-74.800475,47.389915,241.792381,239.108795,165.977046,234.062267,265.20348,222.711141,208.935781,298.108259,344.51934,305.571852,257.584261,293.053787,351.420977,332.811172,280.534392,279.297099,357.32242,418.546053,426.724913,227.689381,128.403635,155.101172,258.832214,360.170962,337.847036,303.923983,219.449986,153.024462,76.486094,72.390278,75.206074,68.448254,141.36553,227.742672,314.701454,233.486348,165.602939,44.416477,38.282045,110.584657,143.253582,166.540042,71.536003,-30.932602,-222.699802,-236.853416,-89.784453,-5.153192,77.558318,101.42736,124.243581,-15.695154,-118.220786,-207.743747,-185.313221,-118.116053,-92.18923,-76.288535,-111.799995,-126.317025,-189.697848,-230.250039,-206.214737,-155.821957,-78.092588,-35.882351,13.439373,-98.405241,-167.129478,-182.997815,-141.455026,-110.929283,-124.521158,-110.815455,-43.786341,1.666687,29.057523,-16.229639,-73.558106,-36.539042,53.589732,42.862824:13.994044,-83.32666,-103.634278,-49.721905,-3.296323,67.175962,78.592164,100.466131,172.348507,196.114684,127.712125,72.716324,83.805639,154.423815,255.872431,215.567629,55.574471,-16.747573,-68.981466,-197.252101,-181.422914,-8.280068,46.634378,9.769105,-52.313757,-43.225201,-28.760116,-48.493293,-52.510217,-22.474479,45.879585,89.458488,182.318483,197.644803,174.180306,80.732429,33.553015,12.379022,52.145049,152.172913,104.29479,15.164446,-138.43729,-142.884163,-31.09024,30.576597,77.120187,70.234933,67.548724,65.598625,40.580315,-25.149167,-50.866853,-50.693304,-7.149658,73.515558,8.953344,-69.49695,-208.229284,-233.447423,-175.080966,-99.397111,13.488878,-14.177066,-183.556596,-263.011347,-251.020771,-114.77871,-15.930335,81.591886,93.301184,118.610283,43.193726,-36.660889,-169.452878,-180.054763,-51.926966,35.500009,110.313896,96.308828,8.024953,-78.562759,-105.046204,-114.890076,-79.31754,26.709627,55.288947,88.431887,177.732437,184.744305,-3.706944,-110.518348,-84.006119,-4.12679,46.801439,19.817603,-37.281477,-28.373418,-2.506903,6.877063,-24.898723,-93.610311,-89.409522,-18.976162,46.085518,73.394554,57.991286,31.201107,65.822505,110.042975,135.481855,104.150243,32.125868,-23.720869,-109.828932,-243.454925,-207.654041,-104.437484,-93.742772,-99.748472,-178.55666,-232.826773,-260.12201,-231.340007,-150.301201,-103.985591,-26.847304,-11.010974,-2.10169,-20.530183,-41.003218,-38.688429,-16.163178,19.920774,41.489354,41.131224,-113.598156,-182.08834,-109.300175,12.873854,133.495199,76.171039,33.721831,126.766481,230.366894,86.069579,11.60129,-73.472536,-67.169087,13.126134,32.811972,-38.220064,-207.807891,-293.758369,-367.769518,-330.155926,-183.845629,-115.944097,28.833405,93.311025,104.271423,54.305129,42.851898,-7.41355,-51.299038,-45.748998,43.769904,199.626571,16.064551,-124.106191,-189.428148,-119.867493,-8.803309,1.906143,16.098732,7.798928,-57.053218,-113.576774,-147.094577,-223.689303,-219.812239,-44.171181,57.911801,23.474925,-127.183039,-129.19019,-114.668784,-121.281818,-37.171503,35.609978,96.537023,87.481354,119.629459,254.084719,266.223771,112.598982,77.970798,283.469362,410.071802,442.267667,340.086943,308.144539,279.186692,294.622191,340.318597,335.786285,311.519118,291.634432,157.412308,16.767228,-9.029818,-60.58523,-101.24914,-126.973964,-106.753887,-42.134463,-3.568467,-31.446231,-47.122979,2.095732,9.503366,-76.006974,-238.039432,-273.924965,-344.756564,-425.837503,-454.233188,-458.620565,-426.706332,-365.391774,-351.395222,-289.168692,-178.385921,-149.674422,-219.623999,-273.199548,-259.134138,-203.993112,-136.005091,-174.228268,-315.748644,-236.95931,-132.955225,-40.792545,-67.765549,-96.136196,-65.042282,-49.427047,-164.984622,-187.433194,-68.003762,9.444283,-5.035842,-47.637112,42.017039,111.936249,66.393363,-11.238792,7.564658,82.805025,115.512226,112.28425,78.965997,19.0381,-37.98537,-55.634068,-24.224203,23.978942,103.995105,97.414069,50.013412,55.715908,100.164969,65.966996,22.311227,-16.836011,10.172395,90.209152,119.781812,159.874959,121.530299,90.52264,97.398364,106.124184,86.054095,89.714388,131.510081,140.038789,123.736563,109.484809,120.357379,206.467717,284.018027,506.075542,604.640916,565.323412,363.268884,343.155559,360.126141,325.407888,243.103252,232.719454,257.83594,275.220423,255.404716,135.720613,68.701672,-0.344726,12.007626,76.090804,98.696576,90.381124,47.900156,57.953125,98.915317,86.691462,38.973346,55.810279,136.745087,135.327852,65.131657,88.281263,100.578829,48.671995,55.298705,213.734528,289.565672,296.797378,242.438681,219.811467,138.573773,131.940736,261.356282,336.70939,418.069075,417.285555,307.770723,147.834136,93.039972,117.716951,204.268838,331.525164,310.938821,237.473959,148.458913,87.787897,54.584677,70.526292,66.273619,63.791543,146.560667,209.313166,255.619384,196.189414,153.030828,45.197983,1.636607,20.079863,78.469956,205.712455,217.714423,136.531609,-83.215326,-121.065446,-12.873837,64.903698,158.695014,184.412025,216.609844,88.255055,-41.94587,-163.219561,-124.649888,-89.649989,-109.467691,-85.114387,-54.968098,-90.43674,-204.216781,-214.064179,-92.544779,0.179438,144.845342,161.044571,71.58407,-25.546014,-43.703595,-56.700636,-70.999385,-99.804423,-80.972729,20.372306,57.793756,35.173677,24.263164,49.458458,83.418756,92.327185,111.116277,80.029239:-235.718656,-287.572188,-284.716512,-256.720593,-235.008869,-124.821368,-36.679897,105.04179,135.082119,166.134831,283.685247,315.329231,289.061809,258.404022,218.917445,212.527894,144.181326,1.300265,-55.035725,-99.829591,-70.283635,39.770077,65.71257,33.503743,-9.202672,-7.998254,-40.37213,-82.368675,-86.305849,-48.652296,-10.315098,-6.479166,-16.541323,-96.544983,-150.735403,-195.658543,-164.978421,-64.439655,-22.240106,14.026723,-65.123655,-133.530056,-194.549563,-152.914282,-3.729851,41.696437,74.658896,106.555865,165.746531,122.01176,76.500851,18.654928,10.715132,-12.28052,-6.927184,70.625717,62.789761,-5.45369,-129.204067,-132.103982,-74.066319,-55.805825,-53.62748,-70.067391,-146.821366,-206.918187,-212.830401,-167.814281,-110.992634,13.26524,50.424075,85.301094,92.421901,69.686196,-29.216337,-79.622529,-82.167267,-22.20063,134.959071,179.131707,88.212067,-72.965589,-93.876429,-66.958844,-30.025397,92.268487,143.97672,187.391507,172.300195,153.801302,96.859237,70.786704,98.848656,148.646649,224.810915,233.904727,197.233164,72.723229,5.378534,-61.213899,-56.579235,16.818244,80.633572,203.622582,222.952613,194.80216,102.26772,61.360603,26.804806,19.435823,49.786733,84.550176,84.635951,4.46796,-46.136381,-125.54699,-144.580145,-190.955671,-201.907947,-142.535602,-118.871465,-141.950742,-163.950511,-163.910517,-159.226754,-122.567176,13.800448,64.315304,78.359005,41.735619,26.528025,2.773876,1.807452,69.602812,140.865452,232.482752,83.102471,-22.898417,-87.186611,-44.80164,49.979374,45.734574,14.440329,55.405392,130.766609,66.447501,28.389554,-34.973584,-50.528146,-23.474068,-10.035802,-50.763922,-170.714009,-249.177188,-333.71249,-292.70034,-110.801485,-29.378617,77.00797,104.710282,74.972545,29.93944,52.427349,107.071222,88.256953,-18.810421,-26.898064,91.121582,91.368264,26.691303,-49.097586,-27.446959,57.066489,98.405628,182.668016,194.924789,107.375906,-25.864379,-92.050536,-213.164192,-229.078645,-138.6093,-77.802397,-64.969508,-163.423764,-184.027474,-178.814086,-173.493344,-88.188119,-22.038227,33.482279,38.827816,111.168578,206.838729,202.527319,104.269412,112.489717,339.786236,451.716027,465.858481,352.812791,324.055935,282.021937,254.30892,253.469388,267.951938,254.554386,239.628263,194.009748,41.647184,-35.537531,-42.225881,-2.912541,-2.914403,-45.784734,-83.301449,-7.328388,25.446935,68.222523,74.248182,-23.032499,-117.876822,-249.473346,-256.875161,-238.42059,-274.318274,-319.711115,-393.579719,-398.397389,-328.91761,-237.288043,-11.217373,36.035749,1.86935,-57.679695,-83.929691,-118.853689,-104.586727,-24.457162,1.841127,-33.750226,-108.139844,-122.80993,-79.568403,-43.710316,4.751603,27.0947,52.19351,-28.656081,-73.639242,-58.54476,-22.254092,-3.616007,-7.448308,58.806002,116.39305,168.242403,150.325134,125.879524,58.909138,55.123475,94.209581,111.141378,137.514316,125.245198,120.401626,129.882842,116.797351,46.407513,11.971173,0.50295,26.389367,56.755945,0.865432,-17.337706,23.535511,53.773647,78.358103,88.228339,114.698946,97.657473,102.392447,170.791909,182.195107,127.125022,101.186042,80.748793,82.997785,116.727533,148.609639,154.56786,194.262387,242.740417,368.158897,424.349087,472.326727,405.119072,363.916056,307.155608,265.817643,179.849992,177.18469,226.116687,241.411741,209.299013,121.556381,81.755544,27.880817,37.594855,123.613545,158.745944,165.147711,120.146343,90.04105,-34.640405,-110.438568,-122.743784,-60.897402,28.92327,33.005714,25.484715,32.351817,37.208133,73.087304,121.260752,238.496349,258.710193,176.371926,62.803714,52.978837,98.109619,121.996346,174.782019,200.425157,235.139357,248.327893,213.05751,51.889486,-25.101565,-7.179273,85.371276,190.119879,155.73763,110.238051,147.789317,131.522633,4.245533,-61.136971,-85.107059,-49.240474,66.945064,132.289931,181.796311,101.046084,63.344599,27.650203,26.556598,58.024344,93.34959,187.84779,185.230965,116.533602,-47.421219,-65.653717,60.708143,127.446845,137.507133,115.64009,91.141527,-0.08084,-69.936602,-154.692875,-157.188561,-108.455707,-58.922317,42.18558,44.489889,15.535754,-69.781863,-117.225713,-128.923044,-78.820507,63.498249,118.708883,117.491466,-23.309511,-100.78567,-176.720229,-161.597103,-67.712839,-22.752809,33.900316,93.207838,132.699958,160.762207,110.386276,1.010873,6.07645,54.731377,43.963651:-2.908755,-128.782102,-165.945033,-180.524442,-143.887755,10.131921,92.222402,170.244181,143.058601,142.248528,169.615311,186.401042,243.722263,277.759845,309.099015,295.233566,219.539956,91.814815,13.834345,-80.531127,-65.07847,49.304691,102.092388,115.110792,14.11539,-49.404702,-94.759377,-70.701679,-57.254192,-82.807273,-86.043466,-52.610155,-29.9001,-87.238236,-114.245928,-149.263189,-132.375593,15.025102,113.940946,212.588636,56.321721,-81.735035,-230.411965,-162.123736,134.105189,223.424978,202.677385,185.814411,239.298434,198.513255,111.793747,-16.137287,-20.228256,46.035063,99.178313,154.885109,36.651819,-65.642807,-228.590342,-255.519258,-191.5202,-119.50813,8.136768,16.131346,-93.61276,-219.672728,-240.061669,-152.259924,-72.73713,69.463669,147.145042,279.020848,169.213758,41.403836,-161.183674,-186.827612,-60.222286,50.617071,210.132755,220.323868,97.524506,-30.18889,-46.105787,-41.689457,-33.825473,9.681447,61.413152,190.462229,197.381163,144.093709,9.383891,-1.190678,152.639637,247.768955,345.690138,343.204048,239.65528,105.405623,49.414431,-64.849007,-87.303342,9.593676,105.614801,252.591557,226.823343,193.644703,128.803575,90.089727,49.156765,56.375405,124.111363,148.580333,69.975186,-39.389114,-77.717523,-152.633474,-172.537312,-167.930284,-145.181421,-98.973094,-172.416868,-246.688123,-331.598009,-320.64555,-206.531841,-104.240108,75.89327,89.218384,-2.417599,-76.372641,-91.430391,-59.081469,-21.370047,19.68934,51.39901,151.696936,64.567979,-51.69495,-195.175929,-165.233063,-8.019709,57.348551,155.127272,183.746857,127.867231,32.027267,8.697661,-21.897175,-7.508067,86.310111,115.893847,49.281295,-105.971444,-167.180236,-195.721477,-160.138098,-49.504415,9.301453,134.396728,169.585739,99.896088,-9.740355,-30.02611,-32.826769,-33.766246,-35.982144,-6.053989,74.684379,-6.342228,-73.185187,-110.14248,-80.028008,13.850545,64.299626,152.296011,170.125525,63.886092,-171.458124,-263.991422,-298.347139,-236.090914,-60.73828,-6.340992,-46.791323,-126.700087,-118.020235,-71.384454,-51.717876,-35.723769,-38.666735,23.858432,89.537345,194.371799,180.763707,107.934004,-33.158157,-12.512964,211.595003,327.723996,368.205528,221.485186,165.973105,136.344372,147.225036,182.847069,196.838663,236.013781,254.845019,187.960884,-18.700866,-105.687819,-149.819437,-131.384662,-101.74175,-88.028871,-36.833708,-9.224083,-24.586713,-51.7295,-45.17137,-69.296341,-131.1733,-286.49818,-342.449017,-400.062972,-418.545803,-450.078396,-534.2502,-534.083302,-409.511145,-310.199652,-131.872807,-105.096256,-135.008287,-191.462493,-193.699335,-111.448367,-39.767682,75.642612,66.751113,-88.972537,-186.657095,-183.367989,-174.191214,-159.134107,-21.446985,71.742036,110.856552,-38.292747,-80.737638,-61.623111,-64.223994,-143.761807,-144.749804,62.413714,167.825798,94.394002,-116.315688,-167.563771,-137.587199,-51.271764,131.252742,168.223635,144.160983,44.982355,-7.891552,-49.479825,-20.55154,72.293158,84.612095,53.99481,57.097266,123.94412,93.785204,-6.716301,-150.430834,-94.270695,159.853415,243.226745,213.552266,81.033178,61.860552,90.42452,94.265423,115.39037,139.654309,161.014242,166.163109,198.888879,221.404855,231.633823,295.855634,334.349192,387.535069,418.309768,448.138037,366.8467,307.283426,178.283979,117.240983,88.337142,134.445211,235.689558,247.216013,206.992044,115.314314,31.52528,-135.470741,-134.498058,56.475946,154.307631,181.986099,61.768738,-0.411285,-85.003412,-85.811235,-8.179657,37.429864,117.640959,128.216189,72.36181,42.956845,16.034481,-59.435173,-31.500272,157.373884,224.954556,189.409474,102.051052,100.664586,108.261343,111.154693,162.941613,180.407459,186.407214,198.478741,179.799619,62.925438,5.816827,-12.692292,32.625417,148.319513,195.154272,248.65376,133.802378,18.830249,-134.634212,-112.758375,16.737669,35.947179,8.954833,22.308995,69.034037,32.601204,-2.013042,-50.50265,-37.418507,68.648646,131.987747,215.900277,173.389689,81.818195,-106.232647,-97.026094,117.153128,203.256907,229.181892,216.570902,153.758081,-3.006299,-87.894301,-181.106574,-177.284499,-101.117658,-39.758398,38.976684,-12.106614,-46.132579,-129.381702,-168.405676,-168.048472,-125.22107,31.122907,105.420725,135.071625,41.307865,-31.469812,-154.627988,-166.404997,-78.015344,3.237433,142.168732,187.894363,178.919628,105.302578,65.548027,53.706953,92.070249,194.349474,190.760279:-267.517345,-340.587022,-347.823183,-289.13472,-238.204274,-125.56387,-65.758849,47.34874,88.503146,115.560418,309.961743,425.298063,486.137914,450.017025,383.114609,355.044945,281.958987,216.279617,175.54082,91.712135,87.351324,152.056203,175.838645,122.279926,-20.903538,-56.008375,-36.900288,-19.576744,19.812357,34.148707,26.80705,13.723485,-81.394704,-223.28275,-251.034163,-237.697362,-208.554273,-102.132416,-50.458499,-49.889036,-160.041038,-199.083958,-184.328653,-141.831986,-38.634903,14.000128,131.552255,192.180684,254.201801,189.966516,138.297035,112.682967,137.789848,132.854332,97.867169,106.771463,162.26974,133.103587,19.574559,-31.550464,-100.623332,-85.409116,10.692199,8.05837,-113.557837,-144.631072,-113.868965,-58.186091,-31.7445,66.147329,131.297138,214.794855,155.500862,84.804783,-100.150172,-175.601344,-161.163622,-84.096055,73.731971,122.131162,103.114142,-15.232323,-52.047769,1.543623,89.834512,262.567992,286.735164,222.352394,141.750464,129.804044,136.263012,153.223576,274.757935,346.051676,386.418608,363.839688,251.495219,46.569128,-39.485313,-57.554183,28.021563,281.265051,366.483164,363.914603,255.307065,223.492337,173.488651,128.432537,77.157608,97.879051,144.637672,143.176612,94.111081,-22.767543,-92.123199,-204.82526,-237.743238,-280.038128,-282.702223,-174.586781,-35.845293,-32.430229,-120.189637,-151.346037,-117.627966,-66.952343,55.03532,108.368357,111.76939,39.465014,41.133444,68.381517,72.518978,145.369736,211.584349,234.287475,82.505758,28.904684,44.596172,72.089176,37.678831,-31.739866,-106.991295,-67.640338,31.11866,-27.817923,-119.443953,-245.030013,-223.610165,-160.316025,-183.941311,-274.004252,-303.62374,-300.331734,-267.323856,-239.744966,-178.026882,-144.521754,-61.465623,-26.070597,-29.102803,-28.890079,11.765311,78.811286,57.922215,-71.101336,-92.11276,49.558683,149.053151,147.24046,158.047228,172.880473,185.951392,192.798061,197.837536,172.561045,43.745435,-140.688025,-212.945768,-269.644494,-282.204211,-373.406956,-417.442791,-372.040061,-287.54608,-290.613621,-349.727125,-369.989881,-303.933064,-210.4322,-0.839548,62.578734,71.724611,42.002507,32.593581,24.929503,62.797499,234.654706,318.647481,389.657844,405.778604,412.133064,338.008333,267.743604,193.019343,183.458431,135.312914,105.842708,56.690183,-43.110533,-96.508401,-145.537911,-154.958174,-199.867615,-223.490298,-174.662647,-39.14453,-15.82806,-16.370503,3.950385,-6.922658,-62.05522,-146.845891,-159.949571,-226.525783,-227.053638,-166.34309,-111.156211,-140.668834,-167.937794,-115.433465,91.705359,227.379636,235.343183,154.768131,80.115384,-9.397762,-2.686802,32.04128,42.951218,96.3076,143.491934,118.769501,32.562315,9.840497,-11.375731,-18.064498,-12.020638,-1.232923,16.943489,40.23204,25.395334,28.068008,64.235429,161.953215,208.951933,240.78715,186.651978,156.696108,119.084495,124.930081,178.591108,206.330676,231.851806,209.867187,205.651365,196.602325,164.990599,75.30426,43.278456,19.644354,18.148401,4.050167,-28.073068,-48.563361,-61.358507,-31.240407,56.313086,101.619466,208.419251,210.253534,179.402549,174.317556,177.215732,129.566506,105.344238,83.360367,84.159943,112.982488,128.633105,116.467603,99.259743,125.783045,252.069369,322.644568,391.369791,355.206391,318.16822,228.686175,203.511094,205.358799,201.563898,173.275002,165.472327,149.577522,88.115603,48.834952,49.089637,96.797099,149.185899,141.801418,137.648299,80.411385,33.823755,-51.477619,-92.069186,-106.004159,-69.294389,-14.630337,-16.639857,12.840777,71.626848,64.856466,67.044971,121.272485,218.056456,191.655161,37.75406,-2.904179,37.999772,60.659842,27.347186,4.006859,35.615281,131.629375,162.321259,106.623253,-75.658125,-153.510872,-121.541302,-9.122036,149.244586,128.011067,66.574255,128.555394,131.233779,-36.317689,-134.834361,-143.202622,-88.149633,-39.615297,-33.138657,20.503635,65.470673,50.003118,-49.818814,-89.544071,-78.981575,-27.891245,108.346546,84.736354,3.664996,-99.652168,-77.272241,31.172639,51.980602,-7.687446,-23.191998,60.923045,41.012696,-55.468051,-209.874626,-233.045569,-275.099225,-286.801888,-200.072765,-106.148809,-104.563457,-107.769938,-107.34182,-108.718901,-85.005592,-13.996644,0.094841,-57.995157,-167.743717,-203.322002,-208.404609,-177.899533,-105.155636,-76.288989,-24.530144,42.732665,84.493776,107.614357,58.205363,-60.27073,-70.669337,-6.901253,10.393785:-130.589071,-229.261908,-245.197683,-210.63887,-158.082344,-22.790908,39.840844,124.163549,124.263594,132.945378,240.528702,295.484851,299.136319,285.229621,335.879648,360.014834,272.300419,90.516143,30.944255,15.903933,46.72831,119.798657,134.010832,113.112047,38.463235,-17.326895,-128.479997,-159.040552,-128.646184,-80.6224,19.789157,44.030302,-30.384391,-220.852358,-300.09879,-284.563145,-180.176024,11.781551,31.722963,-31.912129,-160.94921,-211.908798,-208.123769,-160.616535,8.805291,98.226532,206.252417,251.767353,322.888642,228.345105,144.696589,88.884042,120.100555,135.095045,110.124649,129.539006,160.463519,114.567064,-21.374206,-61.539068,-66.737651,-52.358208,-23.549242,-33.520547,-126.373158,-175.483784,-168.947331,-110.956311,-42.844432,144.528776,231.305887,309.937736,172.25493,48.745528,-162.428794,-204.367593,-107.192722,2.462861,196.130068,230.016084,117.337518,-62.249795,-88.328879,-18.363716,38.557668,155.084876,215.730422,292.252536,232.102954,181.379275,114.922785,118.519457,260.006149,374.15609,478.238558,424.877492,242.694347,95.005061,32.629625,-16.468184,25.877171,192.713053,276.696429,376.321001,359.394355,324.434335,213.647307,146.833306,73.597388,85.930238,165.846,203.793961,189.166304,22.07778,-84.553402,-242.576011,-265.056578,-208.944613,-160.09629,-81.060208,-110.650324,-176.087031,-325.932338,-362.78907,-238.919109,-86.598152,166.066279,187.488929,71.669773,-32.571063,-56.637806,-42.346657,-1.793633,104.653783,172.245241,265.739235,94.556851,-45.526305,-170.487562,-146.336303,-74.725437,-51.928441,42.680664,105.784178,92.499655,-48.278604,-100.740656,-151.693007,-119.507381,27.268059,54.412946,-38.315955,-107.487672,-117.515249,-194.277973,-238.056618,-172.609519,-62.831096,133.976089,160.444337,81.508048,-5.75266,-24.016981,-21.194224,-8.575289,24.738198,61.543249,136.251075,51.590822,-20.786678,-80.338572,-42.590437,95.563244,148.365959,198.248272,194.575376,123.120782,-19.123059,-106.355571,-252.82971,-273.243033,-202.31228,-162.572957,-159.13216,-192.006993,-195.550946,-199.091494,-197.84357,-115.658588,-34.899628,97.700107,114.055712,73.457864,35.791965,15.553291,15.605555,73.686602,268.513991,362.338516,433.086088,273.442965,182.841903,131.529054,149.411836,176.847187,179.842854,189.141163,179.369079,76.01298,-75.764136,-137.980057,-199.372645,-191.759726,-137.652715,-104.473369,-24.384106,2.149403,-47.699353,-161.646805,-155.043735,-95.967459,-112.832092,-205.564256,-249.676135,-319.764455,-297.295718,-281.852837,-355.870246,-406.269293,-357.56991,-254.440337,-26.717417,38.5231,3.623202,-80.885899,-95.978607,-25.60604,42.28635,130.902009,133.79847,75.131536,-39.342174,-99.906107,-167.254338,-146.653993,3.175345,81.197742,81.872839,-61.311841,-93.272183,-86.392804,-89.210181,-41.903995,41.537081,209.54319,225.886317,130.417822,9.914292,-37.935003,-56.605855,2.868001,183.088269,227.265501,154.939099,64.562073,70.587619,63.906735,17.423624,-55.37632,-44.247988,37.484384,72.533903,74.810343,-26.660137,-87.864352,-124.968583,-84.272429,75.694361,162.963689,217.129085,84.675138,40.411843,71.094559,87.902003,45.422366,29.087026,123.222416,203.070195,236.932498,92.848438,27.071322,56.045434,147.965845,314.397878,356.38408,389.649407,347.363156,305.23291,204.031183,167.248577,178.463848,206.75664,220.925905,199.83786,124.431194,22.984197,-31.39786,-98.776611,-66.1488,104.441483,169.608595,171.693339,82.95523,44.896194,-47.525925,-102.776417,-101.885401,-41.230779,30.903483,19.910695,10.594449,14.455482,-26.00815,-84.914966,-22.785204,191.434115,236.654517,156.533084,61.331583,43.94193,-23.406418,-54.105707,28.955379,112.623132,214.421365,204.315421,65.859691,-104.401645,-164.704708,-159.300063,-79.419717,93.986046,140.187248,186.665646,100.919332,-5.373147,-176.307699,-191.085433,-114.576935,-60.246018,40.402036,83.950458,117.829166,34.494914,-29.020536,-84.075746,-55.396349,38.33487,81.061189,144.18928,107.518991,44.877699,-79.445346,-90.970253,15.406211,79.648662,123.550175,126.476547,138.84045,28.191098,-80.416416,-206.996106,-188.013596,-95.807306,-51.732178,14.897496,-30.402681,-89.230666,-182.601569,-186.408977,-104.745413,-46.119942,24.331969,21.405384,-36.146293,-124.842392,-169.862895,-183.454159,-137.041098,-12.898793,32.64366,77.238177,109.546387,116.552625,49.667019,-13.735672,-77.946766,-59.317248,15.448934,42.493586:-117.354681,-164.616337,-160.828135,-161.462338,-150.475576,-82.883389,-42.316947,41.6805,93.89876,124.469384,294.8753,403.876715,508.747067,500.079889,442.144893,408.11679,321.654342,234.1107,197.920701,146.273657,138.50085,137.805432,123.927783,46.306902,-90.425658,-159.843239,-201.30768,-158.815441,-37.396301,6.528407,51.010781,39.258827,-90.90834,-231.653962,-252.424139,-209.672728,-170.569423,-114.754786,-98.258619,-28.433389,49.116162,54.083982,41.828367,54.023284,101.28864,130.0982,216.964742,259.263318,253.661403,153.204434,118.291252,117.362596,120.155918,45.455393,-8.574174,-14.546763,70.48981,82.834262,-5.908855,-93.161417,-244.15306,-276.777021,-286.919567,-279.674182,-234.601207,-147.558573,-105.926547,-33.725351,24.074993,170.725787,226.690926,256.680249,192.436787,159.56118,61.792189,-14.031364,-74.983763,-28.159282,99.659902,131.439219,92.15536,-35.807097,-92.648971,-136.319904,-100.929208,18.883052,26.649305,-78.843335,-176.214458,-205.017367,-226.411823,-174.313207,87.240012,204.992939,256.687679,229.63761,149.323573,6.633393,-56.817979,-6.679841,114.581836,380.640355,452.112276,390.319249,224.51426,203.228478,269.505938,300.128413,323.533491,327.939589,300.886133,273.868123,227.887857,174.884851,130.93426,-25.711673,-111.036628,-181.793104,-168.411541,-106.559247,-70.703055,-88.41508,-171.831728,-214.113342,-241.421834,-212.57409,-147.916831,-155.898374,-213.994204,-170.035421,-119.867273,-43.171126,8.221903,167.179461,226.904222,217.595268,94.877544,56.156865,109.516204,161.468432,178.507918,142.719444,96.593371,111.089375,143.574783,110.187113,67.044866,-30.448368,-66.844823,-112.426967,-131.333207,-194.523062,-266.092182,-262.310213,-147.661973,-97.005029,-115.272997,-143.27713,-83.151249,-7.982279,45.715606,10.679619,26.932876,80.198942,79.270256,26.133988,16.768317,79.393774,172.715053,226.635693,313.411287,307.348947,202.442215,138.778508,39.009631,6.928066,-36.331041,-91.331739,-143.574876,-316.204755,-404.110264,-496.469861,-512.144909,-497.443027,-437.042388,-437.061885,-509.802417,-533.937697,-428.168356,-319.000789,-120.303317,-43.272381,29.776948,-9.419375,-32.062579,-29.540407,9.243647,133.875578,176.44005,175.274347,175.061907,196.669706,169.994646,109.219138,-13.564121,-53.014443,-75.292251,-73.120649,-123.964943,-284.833109,-369.335789,-469.735954,-483.776922,-442.00986,-380.701846,-216.208185,-143.886299,-158.820751,-188.452879,-169.389915,-92.384526,-76.575613,-103.781945,-107.436675,-63.160492,7.575465,38.048183,31.328066,-3.927682,-45.230996,2.551868,204.217763,262.156009,216.657763,87.279845,31.000383,-18.224005,-17.138403,-9.731911,4.32563,9.694344,-126.206327,-199.866043,-265.765672,-266.914008,-214.626046,-181.050815,-181.333711,-275.43115,-318.020246,-298.83131,-256.452814,-206.47296,-198.228574,-155.121798,-107.831193,-28.34921,-56.613159,-70.173641,-13.878354,43.129426,139.423839,161.598146,169.708523,124.920129,110.741569,159.885343,176.203916,100.8895,36.234498,-29.372738,-25.604036,-49.49477,-105.567424,-113.073902,-100.821781,-76.062342,-17.307911,13.627445,129.492778,179.491461,159.126692,170.705227,194.790213,184.422152,158.828417,127.54447,135.308717,169.399457,137.835969,89.270557,-12.973951,-25.227513,32.672563,66.826591,119.440778,154.411928,159.619498,167.760092,177.542089,163.55887,122.095812,28.554319,9.040896,-3.098216,-45.905609,-73.04031,-88.20874,-61.44252,6.424131,4.775496,-55.291307,-123.979051,-158.811764,-199.989997,-204.07856,-222.911206,-230.657591,-174.52077,-124.696011,-79.65549,-88.098228,-68.891862,30.326108,82.126741,123.961801,105.986442,23.449029,-11.655674,14.706644,48.430916,20.91094,-51.095459,-55.505286,6.016528,23.949133,-92.406781,-242.481137,-234.542236,-81.150513,7.032575,78.83562,75.552918,128.004771,159.461086,118.551398,-15.995766,-84.841831,-139.857777,-115.037908,-24.77736,24.545584,81.055084,-5.250006,-84.757358,-196.985863,-195.615882,-100.379772,-46.664784,35.082747,60.020822,46.128513,-10.972535,-57.226194,-135.812511,-148.826975,-138.442119,-101.527866,71.821166,230.582558,225.628111,26.825071,-83.555331,-115.291765,-64.574921,11.690778,35.042748,23.17892,2.41153,8.513195,-5.274793,-24.196754,-14.780952,20.190157,36.593082,-142.829206,-244.959842,-287.213949,-208.390296,43.486514,132.287953,146.476097,129.413588,161.117777,172.593447,111.269676,15.704001,27.726528,81.73769,88.428428:-148.692265,-237.691388,-313.980401,-429.91096,-411.87834,-273.072995,-207.233665,-98.063933,-14.799149,28.383604,151.034257,214.391862,267.364823,238.398957,128.092749,88.178211,47.725566,15.115474,-6.456788,-31.438522,-19.753445,-6.445901,-39.740954,-171.886402,-260.951821,-252.772206,-197.5152,-176.101364,-66.833808,12.97411,35.541939,-46.72946,-231.170856,-216.698844,-165.84135,-205.522598,-301.967405,-410.393644,-351.162163,-147.147339,-98.01443,-110.585905,-151.878644,-173.060227,-98.914656,-14.65751,104.459464,140.850289,170.539595,127.912205,118.283641,126.534647,112.978036,-4.607909,-60.332627,-1.315897,93.879111,69.248194,-52.949377,-114.901891,-226.392146,-280.9722,-353.420228,-332.383024,-226.685008,-200.975217,-197.52586,-124.107264,-58.953982,29.092518,27.190109,10.954847,70.153225,93.790908,-27.509578,-168.739299,-342.951788,-293.070796,-25.545537,88.952544,114.686337,10.194002,-0.508399,55.81264,93.097451,151.373348,149.076571,82.26321,28.971869,18.877101,-27.235045,-52.090707,-3.774906,51.976555,126.120219,142.408556,100.691103,-85.733838,-161.869625,-61.674123,107.961662,385.511819,409.9465,316.045967,228.148778,233.327382,270.755875,258.768259,222.962993,215.404447,177.658392,158.353345,160.248442,109.823893,37.674872,-108.516798,-139.525056,-169.372212,-198.005819,-176.481339,-20.018664,39.081934,53.660429,33.246588,42.446648,86.022499,172.665888,185.528079,146.567392,83.837513,62.209312,77.093,133.112943,259.291889,272.495987,201.36037,103.728132,91.899538,176.722866,216.737829,185.042805,136.348338,144.070248,215.614991,288.437375,119.174969,3.269607,-136.659242,-155.967734,-140.049527,-126.906301,-158.000261,-259.906653,-296.467016,-255.665304,-200.977752,-183.341142,-214.308717,-145.036367,-57.061532,-40.494298,-98.882005,-49.294416,57.89226,32.967515,-86.021792,-75.641749,89.174908,182.375724,208.3991,265.145732,259.118881,247.983024,262.93158,211.727482,144.833903,27.331036,-64.949222,-103.843259,-176.306493,-238.706937,-428.952816,-498.289534,-427.540097,-236.984914,-207.769626,-247.094715,-266.43011,-263.004177,-224.178753,-40.396048,58.345096,75.296522,-11.832119,-4.197986,33.682874,45.716908,124.460698,180.23712,242.20795,225.420397,206.686114,144.769231,90.819463,-32.006656,-89.201713,-168.346184,-159.928694,-92.860702,-175.18589,-269.884699,-416.724434,-429.540937,-348.399406,-291.053996,-208.479056,-157.519914,-124.351626,-46.027145,-20.390993,-29.854131,-62.962765,-124.432742,-141.074023,-167.042898,-109.089546,-48.361263,20.036632,16.46105,-3.078796,24.1996,178.293131,271.293372,269.84915,221.037277,157.058764,-18.139334,-66.334304,-6.589098,60.734174,107.295597,58.867303,48.134478,18.60747,-6.099259,-21.566091,-29.288091,-84.865295,-112.498486,-96.278252,-38.870957,-26.184665,-39.161972,-32.808108,81.732169,168.382803,229.356709,142.526457,130.967304,200.666117,248.253218,287.404593,276.487073,262.840283,234.208285,210.972421,178.184271,174.500614,193.381699,188.243556,137.315854,111.767424,47.911305,-27.042118,-45.951324,-29.131185,-6.797121,34.731246,69.970553,193.013387,262.624361,264.264318,280.08935,283.179508,246.425776,214.824939,115.44315,53.628699,-40.136639,-48.059194,-15.1645,74.390896,113.10175,168.710644,182.204853,191.61521,196.762383,202.958508,211.151214,192.941832,104.901026,41.808435,-82.76404,-99.778938,3.77627,90.170466,52.527433,-71.298667,-78.165361,10.999295,61.16526,152.658826,121.143394,13.187242,-233.583145,-260.452318,-71.541525,40.220776,96.921036,82.644296,122.406168,186.491736,189.516751,179.203163,198.143871,242.792935,231.853818,200.461944,227.944595,254.123456,284.884316,263.747923,179.833512,160.294626,183.151908,198.249918,145.000022,-37.928247,-104.305815,-30.000187,84.767228,237.067666,235.424615,207.478903,187.411986,142.443287,-26.348603,-102.472942,-84.78312,-6.795032,140.871187,174.61613,131.361196,49.12213,25.495772,-65.639452,-124.936953,-139.223717,-77.452497,77.523946,42.55821,-46.130081,-182.883813,-190.959817,-168.171397,-195.017019,-269.666223,-230.177637,-6.878661,77.642717,24.366488,-160.623623,-236.105941,-239.601681,-179.888811,-70.63704,-34.324926,-33.675583,-83.908452,-132.721268,-180.998864,-162.745618,-74.002796,-21.536283,-20.441199,-177.794927,-246.576107,-270.64214,-225.183925,-98.393564,-46.425951,21.422087,64.836672,89.11928,109.618293,85.848908,25.864746,17.967128,15.231157,-0.782311:-67.116589,-190.432829,-236.449268,-224.372374,-148.002952,47.802203,100.847888,118.123696,94.201534,112.371285,287.869993,367.659859,349.698547,310.129011,316.987172,330.010247,253.077304,167.234284,148.510234,55.926266,16.349407,40.422405,73.342691,154.722148,182.295851,129.685453,-14.671219,-39.231378,3.245979,17.93305,-3.563555,-25.208691,-77.954358,-159.436393,-229.082485,-343.806069,-318.072566,-111.234931,-17.999096,-3.008448,-123.786623,-163.731671,-158.636199,-119.911192,-1.932651,57.899439,166.078214,212.529217,249.706652,193.241013,130.552682,1.881339,-14.747538,-22.176602,-55.987406,-58.605291,61.227428,79.18637,23.931989,-9.513685,-90.856689,-125.814334,-114.658252,-79.729055,-39.094072,-64.315324,-70.572762,13.246451,104.435626,254.962003,274.474865,242.567997,131.728584,56.272328,-60.407103,-84.309511,-102.984974,-111.788592,-38.951196,48.107939,122.806833,-5.621496,-53.089445,5.135063,68.441461,87.75521,43.651323,-1.397956,5.884225,2.534661,46.265814,93.55892,183.119857,222.513964,264.354021,246.064589,116.002158,-26.288811,-53.709799,-54.585433,-31.461777,136.028896,259.044052,368.654855,252.217574,207.580487,166.006729,119.788655,37.816336,45.808342,144.04011,200.752037,198.878227,34.152866,-26.595294,-89.604293,-141.819661,-252.260939,-255.6347,-167.825511,-116.60509,-137.721013,-220.141151,-244.828087,-209.062762,-146.054105,-6.721017,10.446065,-65.841263,-50.451964,-8.876932,24.257775,27.754214,58.645462,93.453879,170.529876,123.260851,53.146457,-31.897522,-30.944087,2.718939,14.685403,24.470705,44.735531,68.191968,15.971933,-5.593983,-38.33401,-63.311659,-132.010337,-161.306807,-182.318033,-175.660765,-162.97055,-144.530336,-166.265146,-222.050625,-189.440854,10.521597,89.69458,57.433311,-2.7119,28.929529,96.330918,87.716156,23.022175,14.468816,115.103775,193.492976,165.369782,94.920708,106.011324,175.305065,186.387437,154.923581,133.028088,63.092077,-78.077512,-160.6548,-286.587475,-303.302472,-258.901748,-241.208448,-304.615964,-409.268618,-414.994394,-345.366865,-304.616122,-187.272439,-103.564651,-34.589454,-62.375372,-35.13395,155.197649,222.683997,217.110775,194.384085,212.624066,238.854005,271.866357,261.2969,249.291851,214.943341,192.471578,152.741538,136.728385,112.254158,99.057188,35.430954,-103.835044,-163.683842,-200.152603,-200.072119,-239.225834,-264.499655,-227.469159,-163.622195,-174.824762,-161.278272,-101.429819,-46.427584,-89.876692,-152.439305,-130.817948,-117.798503,-187.053961,-190.141981,-157.863585,-161.547266,-146.610571,-73.595849,128.899741,142.51164,94.070942,34.931419,29.146769,45.834919,57.651826,59.364957,57.230554,53.849593,-12.384767,-73.836895,-159.505915,-146.570103,-74.472584,-68.807556,-108.96375,-114.380607,-100.33911,-79.899165,-91.613746,-107.655955,-75.812585,30.812673,58.889483,-5.288969,-107.92694,-99.182854,21.270465,88.150804,178.756903,213.093082,214.501901,136.247678,146.101641,212.741307,201.114272,108.638303,61.971193,-28.953927,-64.001687,-65.891839,-31.469617,-38.112724,-94.729345,-114.670051,-85.562959,-26.344954,114.911333,134.596064,132.483822,179.113831,177.638304,90.776203,51.055873,38.158771,67.635934,154.836539,140.012664,91.643343,10.033022,-10.401499,-30.838387,-15.411853,111.964874,199.287231,182.615884,106.941429,84.980431,123.000135,160.584885,171.455893,138.998231,37.417724,-72.823412,-120.680098,-158.828516,-126.584572,-15.829764,20.814013,19.745488,-31.919162,-42.127932,-57.728242,-87.446568,-115.371798,-96.804784,-63.858242,-47.458839,14.639624,17.065758,-33.441108,-135.428975,-124.77202,-4.420733,42.382772,0.851634,-125.011592,-132.942906,-57.248161,-39.775733,-81.975764,-87.499953,-10.500616,16.830919,-68.826394,-204.741549,-211.540264,-96.335574,-13.90558,56.087636,27.341063,4.087495,43.782545,28.602173,-85.346134,-155.681197,-174.387643,-100.411587,55.122288,82.640193,55.568483,-6.474775,-42.791758,-117.955683,-139.205479,-110.931926,-64.852908,41.173208,54.305404,38.856097,63.492727,87.776166,92.019918,76.732963,70.037762,88.240498,142.908632,175.13083,162.228818,42.045779,-28.631173,-74.304032,-68.056552,-70.765362,-69.096174,-42.303206,19.141909,13.813844,-32.196898,-22.928617,51.19447,85.013333,112.127274,30.572748,-54.813123,-189.147431,-173.065963,6.973451,93.099317,185.551752,212.265119,177.406365,39.911862,-22.473343,-64.802625,-52.747821,-30.632708,-16.328526:left
-255.677733,-243.540161,-241.132921,-300.289396,-343.858518,-332.500809,-266.245881,-143.822398,-77.197418,-45.460432,-27.714037,-35.888442,-34.524115,-48.201752,-109.788947,-105.726132,29.280715,184.518882,216.854711,210.670505,158.224034,-71.009479,-181.698885,-237.092458,-181.350558,-184.725852,-265.192285,-309.304517,-355.357275,-353.869686,-313.067194,-294.387984,-250.729644,-161.790779,-161.975689,-348.90933,-482.099301,-625.724213,-596.955029,-404.806463,-263.633715,-246.170366,-236.338353,-223.974688,-216.761734,-212.064231,-117.947419,-51.284954,24.785955,38.646957,25.792149,2.040706,26.633677,147.526886,204.848176,238.951649,209.262545,210.461828,207.635738,177.329323,88.136612,43.22219,4.583246,50.434974,234.783488,323.162992,316.957844,302.163499,290.288842,200.746679,159.466381,187.015856,244.401376,217.002761,77.800969,31.826154,-10.848299,-48.683259,-91.052893,-72.227525,-47.50623,-92.25345,-148.384136,-300.7558,-343.094063,-328.101059,-307.216209,-307.349321,-356.173205,-353.445154,-279.576496,-262.673033,-334.261888,-386.281185,-436.025143,-438.032806,-415.128231,-365.838649,-347.240552,-333.314054,-352.824588,-440.599262,-453.129038,-387.459147,-364.90958,-387.825518,-402.03884,-368.289672,-332.030233,-365.118818,-414.994072,-397.494799,-317.267461,-235.068845,-207.319274,-140.689623,-101.086698,-64.782432,-39.976225,97.657547,276.093382,370.543853,509.877043,521.046651,466.660651,436.32745,430.263324,467.487451,599.252136,655.065993,602.713837,412.646533,335.543384,284.518778,300.87221,398.748447,585.618459,663.375476,639.303538,546.387283,408.912423,427.149677,535.602789,564.376442,631.080831,738.948248,716.948798,483.001693,352.493159,212.747867,208.537572,257.911366,296.9722,321.849203,361.46625,356.347667,292.367062,242.809731,184.997393,219.742807,374.395749,410.220489,382.012718,332.085214,300.220454,216.045665,201.595536,284.582507,430.897748,470.695592,433.187628,391.768457,369.288353,384.447824,407.170028,397.011404,364.72213,415.745316,453.298539,423.935585,343.229635,158.471878,129.550772,206.24195,262.67234,251.570487,172.238013,147.204125,175.45118,180.859021,122.994964,105.521596,152.07336,241.38817,268.637748,213.624638,109.798155,-133.758947,-175.699801,-116.734984,-92.896327,-84.006449,-63.063335,-79.633343,-114.493652,-80.767018,78.210429,134.372053,200.617368,341.170054,369.602719,304.157061,270.252681,177.256185,121.056861,131.399498,267.379706,308.9949,245.513886,167.27072,38.450303,15.67587,62.526742,96.041993,171.029246,323.259647,358.015008,241.655422,154.724551,92.343031,116.508643,122.835781,57.587056,81.050039,130.941877,77.598746,-35.583116,3.324785,171.366254,197.183114,154.154715,165.743226,183.043198,202.179408,180.439626,44.343449,-15.281604,5.140121,77.145914,74.045726,-9.680831,-51.344839,-50.85554,-19.119994,71.300952,115.342176,138.279899,152.09171,192.119377,218.441461,173.822341,96.957816,120.772881,270.218088,443.132391,492.413882,380.489446,236.82306,-17.550849,-97.088836,-152.170856,-107.69322,29.491313,23.317288,-17.598707,-28.689569,-18.323406,-57.134946,-55.443841,48.802826,142.946051,181.303555,257.371063,272.373727,196.912557,130.938567,81.24473,98.104111,147.880589,204.327508,209.690637,167.613179,131.340553,63.958659,64.606282,119.765867,139.780739,151.593915,209.468409,235.89414,172.603217,66.612305,-104.614485,-101.652393,-6.131322,37.974531,11.322665,-77.868561,-107.095579,-199.237184,-272.868537,-308.868392,-137.254606,-78.222199,-163.005878,-254.388803,-353.766093,-357.684218,-311.841484,-268.406223,-211.254441,-263.07284,-313.127599,-384.467152,-408.101846,-480.122515,-505.125189,-467.911704,-391.958103,-375.75127,-412.754316,-477.578887,-684.412715,-758.347564,-679.500983,-571.697774,-450.328973,-434.514375,-393.26963,-229.671505,-163.468919,-145.861899,-172.795215,-218.422622,-180.861656,-126.579371,-86.436522,-129.770168,-221.943437,-249.424022,-318.795544,-347.392951,-312.472058,-169.168575,-116.749558,-127.914858,-181.989733,-313.354519,-330.961972,-166.997977,12.09978,-0.790507,-155.503538,-208.277575,-191.368501,-180.060759,-199.749713,-160.037246,41.786059,154.032782,128.190581,-6.430973,-64.283524,-150.428681,-187.413517,-204.141917,-146.213086,-124.09654,-157.093195,-172.360794,-103.238176,-63.693193,-36.077603,-20.071949,-16.498549,-99.502364,-136.189414,-158.334424,-172.175131,-178.728179,-144.635538,-59.768438,48.133193,111.989034,141.472303,111.306053,73.945177,60.755625,-0.738546,-26.453762:-183.910664,-197.48249,-188.712198,-244.402624,-304.496065,-309.132791,-221.70253,-35.993063,31.091065,5.519694,-143.240246,-191.379387,-143.28457,-98.230436,-38.951538,-11.85799,27.185749,33.341667,38.374664,77.357622,60.721522,-130.246789,-225.068069,-214.557911,-101.083158,-112.569325,-273.874514,-359.269159,-408.654546,-377.286828,-328.493063,-339.467426,-339.24518,-260.712135,-258.960713,-441.408071,-585.142767,-707.794626,-648.466038,-452.073452,-350.548258,-353.672354,-391.564648,-397.646048,-381.295129,-342.971575,-169.774562,-92.665679,-61.083396,-36.321419,-17.273935,9.873489,47.664614,153.02536,180.280712,161.169632,135.228071,134.639992,92.37565,46.16642,-34.149473,-42.408606,-3.57886,30.560749,130.543924,242.902554,288.404285,309.436417,265.787319,121.172943,73.390932,122.604134,242.116026,211.110858,-16.000301,-95.33537,-97.867219,-86.984535,-99.236699,-93.034216,-8.320922,13.952627,-69.591741,-273.268552,-315.556875,-288.773132,-244.617408,-151.02336,-155.466035,-193.306245,-263.519355,-293.862347,-389.158595,-438.673543,-419.530319,-352.191621,-229.930138,-201.532752,-225.135467,-298.293524,-329.177354,-332.879937,-305.432855,-299.50854,-350.784711,-362.999526,-354.65677,-339.59225,-378.376632,-447.942057,-500.006528,-446.5779,-286.788048,-119.024956,-63.098054,-56.970659,-86.78555,-93.510865,-27.102079,185.246799,327.818053,389.383063,497.068461,501.565969,372.247542,278.769706,240.79812,328.180816,530.027874,514.94117,443.544164,284.913138,222.584537,220.396862,275.205321,370.564166,463.879274,520.170065,514.758821,438.265184,272.429719,252.712127,348.64309,395.414519,441.111729,481.898826,466.386678,345.887506,262.199611,132.826982,133.883057,223.192379,285.739518,326.678854,382.874238,350.499951,194.16135,136.553614,219.052214,331.763527,441.411813,340.516597,293.496994,233.157518,192.869231,152.571126,178.809623,306.534473,483.826412,542.372277,524.998044,494.926881,499.665545,510.417743,534.607803,548.89906,501.223132,458.873998,488.33159,472.06674,363.282241,103.297439,53.51381,115.71796,252.176494,298.750465,279.915997,263.082141,246.795614,186.912167,12.127039,-10.436578,168.690322,365.002072,324.05349,45.484122,-73.42844,-134.038966,-82.832008,-7.022863,-90.923583,-92.594073,-3.052512,-1.262872,-80.082012,-72.102022,87.081205,174.233505,287.369231,312.049505,279.502985,221.726169,214.319914,139.073006,83.702975,69.251405,136.377052,146.896567,106.730303,87.135648,32.095054,-28.363408,-99.543552,-71.462181,54.809882,148.47619,107.723178,-78.555584,-121.182533,-72.338115,-36.17871,1.405594,10.346557,-16.833901,-167.744612,-254.749717,-299.763382,-219.652571,28.139088,92.46402,69.913142,57.61836,72.703731,117.254741,137.519504,120.605671,87.513491,20.643881,37.490102,65.484518,13.118338,-50.70632,-93.897513,-59.917189,73.922404,144.698885,218.631467,224.832693,235.947719,244.541567,217.403059,165.432353,176.130423,288.051632,483.094781,549.519396,437.289266,303.19163,114.627256,64.047564,27.578335,59.697946,156.334112,169.988924,151.915782,128.29272,115.78795,62.345446,52.216977,93.751766,209.164376,292.770942,373.253811,325.096844,152.105581,111.249789,147.641744,161.534655,142.460436,181.507785,207.737126,179.451598,147.422236,118.428758,111.768599,126.457331,151.071471,123.402502,66.815821,91.61081,102.957706,14.879907,-143.280723,-106.726681,86.241741,154.217071,103.201863,-76.809003,-139.296977,-175.165796,-181.461446,-169.63002,-64.228841,-37.367354,-122.557215,-175.893444,-250.024124,-284.257787,-249.134716,-166.191409,-17.567667,-105.975016,-219.930537,-365.891698,-361.581588,-327.007836,-320.050034,-273.467724,-268.52718,-310.931361,-358.731777,-365.385501,-518.408037,-631.669939,-623.7522,-497.264071,-277.136952,-255.217043,-288.298516,-298.789036,-254.346073,-149.139738,-117.318022,-81.931411,-9.306601,50.75419,72.177065,-3.001228,-189.362408,-246.217917,-284.343396,-286.11473,-249.965589,-81.194861,12.211853,22.821726,-67.609606,-233.11114,-226.219378,-58.403714,25.845666,-23.797283,-182.054349,-243.965787,-283.817809,-234.364251,-48.185382,22.508171,76.260778,67.464319,7.9379,-172.185655,-205.077143,-140.326318,-112.024093,-113.448524,-85.207721,-72.702756,-151.396588,-201.751679,-224.447331,-223.496288,-159.19299,-85.36721,-54.317985,-227.171041,-287.487552,-250.001296,-209.877683,-147.01756,-91.352093,15.272451,79.519583,101.45047,7.275943,-96.601905,-190.760767,-157.211046,-124.671079,-165.315653:-281.87066,-287.655802,-226.318376,-181.941177,-231.409682,-346.09811,-326.110059,-129.678707,27.037477,33.566714,-52.109523,-105.933972,-186.346423,-205.083904,-154.018672,-91.47607,22.596758,70.655555,60.019738,-15.995622,-73.780757,-192.356768,-218.539506,-164.646544,-109.166168,-145.67374,-308.305859,-382.736898,-461.900824,-472.784798,-442.793014,-414.259509,-364.693542,-353.891001,-400.421289,-614.140909,-700.620064,-674.384123,-626.74084,-605.820348,-502.810194,-409.874302,-365.722457,-441.403254,-587.404783,-564.774585,-344.411583,-251.287865,-184.758713,-122.012818,-102.013643,-107.182973,-93.466871,-6.426129,31.760548,83.471881,168.994805,175.709861,22.381373,-87.351234,-227.893889,-235.697104,-133.0706,-54.956839,79.768155,109.200829,75.245314,0.491517,-18.618108,-70.69828,-76.968057,17.083698,81.358819,27.243303,-259.191756,-395.01437,-466.397014,-423.010323,-294.470736,-222.297948,-74.542883,-83.29369,-150.236075,-257.687604,-263.964692,-174.524167,-118.303829,-88.425427,-132.818214,-177.172383,-273.265856,-286.937379,-326.579424,-389.538479,-433.694663,-369.022589,-231.582964,-208.715854,-194.899181,-181.149324,-261.017754,-529.700661,-562.464075,-354.903588,-230.494673,-275.836677,-431.910762,-475.074098,-465.099613,-454.142297,-463.978654,-460.922829,-358.63371,-202.578479,-164.267587,-176.735689,-199.695931,-143.064932,-42.236754,162.726458,270.664009,323.380035,400.176841,383.224564,231.361569,156.402123,172.931105,247.417292,356.379314,328.202999,284.049224,165.908342,103.811915,58.63156,81.346461,147.064961,290.967884,386.398665,412.346025,308.231207,70.695368,39.649099,129.175068,179.356835,291.302901,428.244629,429.258339,263.43131,168.224589,102.481003,142.153375,237.268082,229.112092,234.993456,255.213544,232.979304,133.69199,93.183111,158.542978,260.932414,425.814371,365.188739,272.163241,111.07217,60.498341,37.595007,86.718123,251.008122,369.960503,407.537436,427.176153,405.356269,344.327462,323.872507,361.18256,409.694528,442.503828,357.847263,303.093945,222.291042,189.777664,101.108727,62.269882,102.260709,326.274928,409.669513,388.392216,340.468561,211.764949,127.297345,63.803204,105.463872,228.130564,256.08063,200.946287,26.083024,-40.440934,-72.106844,-38.38962,-0.006297,-51.951975,-32.07516,69.005388,77.02419,-19.903327,-59.578836,10.416745,102.078711,254.186746,248.663311,205.783497,156.45998,158.422111,154.827368,147.968867,149.794214,201.998253,237.840154,236.298572,193.971149,47.82727,-29.482856,-51.990157,-11.544111,37.599238,89.027896,87.731136,-11.397588,-51.930037,-90.249731,-102.914724,-86.068514,-44.622671,-36.184117,-64.755727,-119.213518,-245.880906,-234.490535,-28.195952,67.776277,112.730843,101.217877,92.494498,65.149461,63.280739,102.593128,133.715418,166.969204,196.420105,207.254636,169.010619,135.178748,120.965307,150.504413,196.106731,192.783131,220.608924,336.524933,405.970676,452.87889,396.555024,287.438713,308.042804,447.464,586.960831,641.182485,593.33822,481.800822,271.867856,229.361324,254.772458,282.846968,298.09514,290.320604,298.760536,305.058407,272.257459,134.554815,90.313892,151.668821,332.143126,431.309929,520.958207,461.907108,197.762016,96.326223,117.68528,181.283009,203.182938,194.836527,217.182559,180.255239,127.130281,105.317123,133.351956,150.751683,117.7394,111.62953,107.900361,99.210527,40.780119,-13.76012,-23.701192,50.372848,212.930839,232.60546,161.804163,-30.050416,-91.843443,-157.491738,-185.184517,-150.625103,-1.847753,8.601378,-134.168024,-206.511255,-280.37367,-305.056558,-301.20098,-245.90179,-68.258424,-28.88761,-91.361509,-260.99789,-318.910392,-278.614499,-201.564105,-114.162889,-159.550768,-212.246043,-356.836066,-405.677946,-394.602328,-366.316339,-312.228756,-273.124561,-168.157216,-121.357628,-127.146184,-99.813314,-66.911101,-47.476109,-50.143449,41.745672,238.043083,294.91504,216.494131,126.878664,7.622965,-37.648838,-130.186929,-133.907135,-64.927621,20.111771,27.273726,-135.693688,-235.627601,-217.390097,-114.070108,63.529594,99.118024,76.234109,2.171088,-15.03517,-28.215459,-25.774016,51.919756,95.949008,100.767284,15.863507,-50.526155,-132.711165,-120.920053,-92.629742,-98.739743,-122.491544,-85.773855,-46.200869,-57.294669,-108.5502,-188.432918,-198.047573,-131.036758,-74.048507,-67.745804,-193.503527,-233.552376,-219.835748,-198.011847,-89.055049,9.947808,116.256196,76.861622,51.250193,-47.869111,-125.585836,-243.670234,-251.331204,-220.254124,-217.684242:-135.185905,-103.536582,-127.780252,-243.81965,-310.677466,-364.429863,-332.763887,-219.40301,-108.157475,-75.19375,-67.45561,-82.716976,-175.174512,-245.859274,-280.779692,-213.910392,-33.589104,33.520827,9.483063,-82.141296,-134.836544,-211.803619,-198.424863,-90.228546,-41.957978,-93.574845,-292.484661,-368.826748,-447.183516,-474.060242,-465.651353,-426.483437,-354.288137,-344.949594,-377.012805,-529.527699,-603.922145,-628.557504,-605.293226,-579.864595,-507.152556,-451.461265,-441.33179,-485.919023,-531.207501,-488.115895,-303.610977,-243.798461,-246.323088,-203.181113,-166.450095,-117.019682,-82.961076,14.659438,47.7284,68.77644,123.803147,147.721847,101.681314,56.385719,-2.537933,-25.704657,-89.426894,-118.200848,-106.370479,-7.640258,49.386622,122.322626,111.623479,-4.733061,-57.620377,-64.743304,-18.183735,-32.293927,-198.963734,-304.506155,-414.958177,-402.251224,-282.654748,-228.280515,-225.420929,-268.89356,-254.490269,-203.83489,-213.442887,-218.004649,-160.606771,-55.491358,-82.529347,-83.88399,-59.476034,-89.244831,-252.010579,-341.509398,-421.4782,-398.625883,-330.420901,-328.412205,-341.927745,-346.187768,-352.219966,-417.499135,-433.19205,-399.670865,-414.641203,-426.325641,-419.495685,-421.854722,-439.812774,-449.048423,-484.2399,-496.030236,-399.301378,-217.300539,-164.583638,-135.061252,-149.246713,-188.673931,-159.254521,23.147747,190.903243,263.699252,434.866092,486.887573,414.813944,322.51917,239.334561,283.521063,414.066043,397.235856,329.456293,214.411885,185.035345,140.951282,136.943255,209.966035,370.721701,446.562345,487.322451,443.437142,302.862022,269.672185,372.777768,451.630526,536.611706,594.498176,580.439494,401.435463,289.146093,154.510156,147.686654,216.524523,307.293702,348.328751,348.35963,294.41704,177.461253,149.48684,168.857535,190.674271,202.535837,228.713736,241.789552,212.026683,174.636617,113.487798,114.426192,165.644414,207.772215,233.99194,301.759742,328.460351,350.79921,340.911187,325.149577,332.363612,329.33271,359.278982,396.611595,418.863585,372.690701,241.707352,228.292807,291.663971,361.862256,376.290768,330.72466,308.717434,269.69525,218.200772,120.348188,120.288807,199.633779,267.190468,244.10445,63.352488,-43.72088,-150.949005,-128.936551,-38.208268,11.242004,39.716433,48.26264,11.600253,-71.535335,-77.17797,9.224312,73.106582,203.565573,289.148018,292.378946,330.554745,368.775885,330.263012,273.442082,248.698135,298.767555,323.205838,343.979659,308.837801,166.59349,128.731449,205.179594,260.243386,299.514374,318.634231,299.326101,206.585071,171.065856,102.40785,76.944199,97.358609,157.623214,188.798844,151.587358,61.878148,-70.769747,-32.209797,142.992172,176.736636,156.628545,196.568495,205.482279,172.881229,153.444517,80.08074,47.24672,79.876812,196.033381,237.862779,177.9654,95.834833,7.414709,33.421863,170.829264,241.582956,310.06925,327.837749,342.72078,321.755753,284.44358,262.541932,300.674052,422.887049,546.159171,588.001608,518.954084,397.249446,164.497635,123.437898,186.241276,244.530416,276.829683,180.788858,125.01075,58.277382,54.910584,73.457208,84.111042,113.556694,214.792103,280.410601,311.817282,271.241016,174.564285,150.301819,131.127558,101.604838,71.459469,237.194193,311.406534,262.262761,189.538106,142.829355,173.005488,209.899498,152.010965,124.906874,116.54765,126.564795,82.058527,17.708748,-36.512737,-9.939165,32.061495,56.312302,52.958198,-47.915614,-138.110596,-278.500383,-290.692359,-227.440796,-143.556511,-141.419969,-228.716273,-283.051419,-378.64484,-414.669621,-368.520599,-285.727423,-163.587601,-209.160374,-273.339841,-378.831311,-404.3437,-428.592592,-418.097611,-361.60632,-358.394858,-386.914869,-456.013209,-481.816415,-535.961714,-557.723798,-457.027171,-350.294345,-241.543823,-271.89784,-277.086085,-214.719843,-167.367974,-117.53393,-101.10382,-8.207255,124.636784,174.961865,186.203565,144.725336,17.367588,-64.272304,-254.157841,-324.190574,-303.53203,-141.71692,-93.452962,-94.376945,-116.19233,-171.888136,-188.615128,-158.685534,-61.088543,0.355918,44.398262,-9.516198,-167.570005,-199.80371,-129.598514,-61.280362,53.657867,107.314215,82.308707,-59.182202,-119.409899,-188.565076,-214.055612,-231.003029,-164.791878,-113.204665,-94.784253,-126.165591,-163.523824,-167.009483,-138.920316,-111.084441,-128.451356,-215.743301,-235.216101,-224.588714,-213.984619,-144.176654,-69.568566,79.615902,154.796175,170.879163,119.579793,55.269352,-64.835146,-111.669111,-167.553261,-157.330387:-86.225088,-55.037202,-103.019145,-280.912939,-354.61942,-401.469982,-355.550938,-172.974735,-27.288266,2.675794,-39.400301,-117.254389,-324.877197,-381.27373,-314.391514,-248.604177,-153.680633,-64.64857,-52.48495,-162.991981,-248.345859,-298.604719,-248.505067,-115.487915,-24.300893,-26.263603,-198.880253,-331.614766,-536.627841,-580.476398,-546.080406,-477.730689,-326.905394,-308.423292,-363.111436,-563.894094,-654.108706,-651.907397,-595.950846,-549.731174,-478.538031,-418.044115,-435.541969,-502.43713,-574.707687,-564.722757,-474.886205,-407.475738,-253.822821,-142.200934,-137.582128,-193.706713,-209.291001,-150.870242,-97.275393,7.838602,107.087028,120.205534,14.405669,-68.682347,-168.148296,-172.499677,-144.959582,-132.849451,-66.154327,41.413485,46.751611,-34.097251,-86.408394,-178.938641,-182.179574,-81.978088,-49.488325,-119.590837,-399.005014,-523.386776,-556.300713,-499.079255,-387.125935,-333.984993,-229.741992,-225.91946,-249.513255,-247.184547,-225.472252,-190.836481,-175.072778,-93.047635,38.269498,61.885365,-0.417707,-39.873744,-155.899866,-261.900472,-385.440075,-326.185635,-141.550566,-176.503036,-247.984912,-350.499946,-401.761436,-518.935939,-514.35448,-370.05997,-308.715256,-334.650262,-416.173267,-449.807802,-487.708198,-499.973991,-515.853995,-508.348092,-421.833234,-272.212093,-197.500557,-117.931569,-155.490062,-280.826924,-267.997668,-79.395569,120.822688,201.703101,337.480268,371.612937,287.070257,196.839184,133.44875,180.540418,262.56787,216.943442,175.807492,87.590328,29.293214,-48.617003,-31.229832,69.17533,218.112758,287.949028,264.663872,163.504967,-32.377919,-46.718648,102.692702,196.741325,344.225025,431.717826,413.806854,246.749513,121.115133,-41.688546,-6.519333,154.452869,164.208274,146.319202,170.218703,177.0009,90.837043,35.81582,77.771927,169.176191,319.770129,281.138926,196.045046,31.9472,-22.63314,-86.472749,-64.880071,110.380771,265.818063,279.898114,213.753335,175.550285,139.227181,134.407831,197.424021,266.441801,362.929916,382.956484,381.074145,348.639891,312.109414,202.648479,154.890292,187.986267,431.608052,516.746969,444.178709,361.228025,251.475789,208.719676,141.578904,141.699933,252.108291,386.166144,364.668004,150.780804,45.190863,-5.742323,48.71465,145.151378,137.432613,148.406339,164.203248,141.565259,35.654727,-32.770221,-57.914397,17.492876,228.927074,300.893882,272.561233,230.103693,225.371128,197.177719,196.33106,238.584851,280.703736,298.120792,274.56371,213.504625,15.99934,-66.245037,-65.255487,-2.157575,128.277964,208.858496,192.231275,66.377767,16.523723,-13.146722,-0.82999,89.320492,217.741695,242.583842,86.634687,-67.656707,-252.746313,-220.729003,-28.075738,60.679572,161.348132,149.603278,104.122976,34.393453,38.277093,64.671571,63.944263,55.525071,135.430358,181.95549,148.784373,97.956786,53.881668,61.135904,91.318698,119.191428,241.527037,388.251119,418.482393,348.364719,278.160897,235.64647,282.418742,399.70856,523.6911,586.279065,582.823162,492.376561,256.373857,188.491593,197.75968,227.622391,268.5976,290.053411,262.649194,97.785529,15.195858,-8.570331,47.57303,180.986142,271.63018,293.868311,293.442028,273.101816,180.435312,125.993089,64.598767,67.284876,146.213128,235.593593,222.717796,113.222495,86.663386,139.980479,179.644942,209.214659,176.658004,163.729588,172.00647,175.835368,126.745683,91.972282,95.433368,102.500305,73.439612,111.260199,115.37392,-13.845142,-102.63293,-198.612249,-198.140313,-144.633068,-54.270473,-21.216697,-89.783034,-193.274175,-354.728863,-346.626174,-227.55818,-179.603154,-137.029239,-172.612877,-223.25455,-345.51674,-402.939385,-439.117737,-393.721161,-239.977563,-146.255057,-158.564086,-297.002703,-380.949187,-439.57256,-402.298697,-272.149292,-216.749355,-150.1979,-115.398145,-117.48514,-141.236798,-145.550402,-119.992829,-79.343869,42.322822,193.096242,263.89483,233.231294,119.569778,-105.340182,-157.136804,-148.211356,-133.124462,-149.330256,-153.067706,-158.013765,-190.588292,-197.348808,-175.731008,-143.954373,-65.379979,-1.62132,28.725279,40.067569,6.223896,-119.814255,-169.142118,-99.277491,6.322665,141.676044,37.199842,-50.08688,-135.650076,-152.612923,-272.973105,-334.392607,-275.558574,-82.602131,-18.138343,-67.373606,-171.930281,-363.194586,-381.088132,-249.479836,-168.774371,-146.627361,-207.691434,-204.747802,-198.97275,-225.306883,-213.102464,-124.685101,84.628563,149.845612,138.016288,45.18671,-36.545322,-208.119401,-251.720241,-229.332778,-203.272176:-175.564988,-174.604654,-234.024522,-433.453464,-497.24489,-440.919737,-338.589562,-158.507419,-112.189118,-93.783239,-77.529371,-102.263202,-172.266278,-219.792859,-295.647982,-263.450101,-61.563952,96.220967,104.791609,45.32319,11.209339,-47.602704,-71.399662,-108.694427,-102.011353,-94.915628,-173.042455,-263.755331,-443.84149,-485.678709,-461.175331,-430.969194,-354.834704,-219.494561,-199.980161,-366.942927,-487.694185,-570.618263,-509.754468,-333.755304,-226.535915,-193.757375,-188.006372,-196.632229,-182.759232,-173.497976,-126.10017,-84.662626,-32.362461,-47.423428,-76.353673,-106.370597,-96.63278,-43.477987,18.900791,176.896536,227.864976,207.780298,96.173684,39.021884,17.210441,37.878005,88.531215,107.926627,130.475658,178.330152,196.028476,157.842358,111.579467,17.131626,-14.874771,-30.515276,2.180707,3.612052,-107.070266,-192.782199,-298.280755,-301.795875,-235.759539,-209.332707,-216.05699,-188.077324,-189.818535,-264.619342,-292.22093,-295.54405,-287.014231,-261.73624,-251.391503,-247.965897,-230.852989,-242.284854,-328.424614,-356.201295,-302.791569,-262.73541,-240.594969,-243.505076,-266.928259,-348.353706,-378.058844,-387.369958,-350.744101,-284.558851,-366.918276,-395.060688,-303.207957,-227.1197,-156.84169,-186.778537,-344.670759,-420.224061,-416.561284,-283.445739,-255.517769,-321.285962,-380.629846,-408.076129,-325.037196,-31.641376,178.323602,226.406177,253.680336,273.568948,358.904642,366.129266,315.662003,321.287754,395.97936,440.37365,413.275983,258.138809,177.345438,99.060333,115.456124,216.012362,341.757231,423.771839,505.555134,463.814766,365.852832,374.844975,485.060591,541.824078,624.539014,671.778281,645.192193,437.471971,296.036386,142.326218,160.827959,192.699192,103.173895,105.455052,201.77836,230.106349,230.557109,221.069159,176.777863,149.163942,147.565968,213.699546,238.215314,232.566627,197.255131,90.464182,64.534952,140.906205,274.181728,304.271598,246.169186,192.767046,193.831038,234.601399,244.273649,216.401566,197.394537,267.047662,301.689406,303.790027,286.535578,253.876456,245.050927,250.528827,298.225424,329.54623,316.902739,287.148991,272.389848,263.09343,216.729618,202.840505,217.696573,326.439401,364.937785,274.226118,166.07225,-43.572135,-100.396998,-78.481094,31.128774,80.131644,91.614248,46.567154,-69.191527,-98.373226,-10.132067,83.146117,230.65583,319.172485,339.59864,336.778881,322.042627,288.408698,298.625151,356.239214,385.349949,403.333962,417.692154,379.112419,228.964578,178.851532,221.405213,277.862426,381.839286,442.69489,410.554659,299.598914,280.106979,218.033325,167.989787,189.089281,242.466232,196.766234,9.325695,-56.685731,-29.305837,18.194517,65.778176,71.061427,66.33404,34.953362,0.434102,-51.538667,-49.586245,-50.991828,-68.970219,-75.466882,-16.904516,9.611698,-1.727384,-45.016004,-135.83866,-133.008162,21.042622,115.53834,184.61325,168.128043,151.867012,101.693499,94.583915,104.653638,108.176142,190.310188,366.924331,417.417482,316.650564,176.48633,-74.459628,-110.834704,-44.986249,-7.347627,-15.713145,-99.006051,-144.351047,-165.493201,-126.612119,-52.019282,-37.664435,11.377879,109.436667,153.072898,178.69807,163.358187,120.907108,105.407042,44.476478,-9.743051,-31.56226,95.055261,126.404022,93.939642,81.017295,131.881709,179.672197,220.216389,151.408884,118.959948,138.524265,170.084567,138.281233,70.940455,-7.655374,-5.227469,-33.769143,-93.35237,-105.697816,-130.718632,-160.87156,-248.435796,-275.935238,-212.919423,-72.743987,-42.277328,-105.495156,-175.693918,-324.064982,-378.565216,-339.065785,-252.581618,-156.903699,-242.199037,-290.173947,-359.747114,-391.916502,-397.602446,-358.92936,-276.385861,-295.529295,-341.930428,-446.790905,-498.236402,-605.110284,-633.20525,-578.09227,-538.049676,-514.45336,-455.330607,-413.632861,-329.128789,-264.606301,-121.191321,-79.385255,-102.686535,-171.944986,-163.128054,-82.878276,-60.481037,-120.389436,-189.972828,-282.891803,-271.851431,-214.294188,-200.322308,-184.193796,-118.911243,-99.314646,-146.153172,-190.410738,-189.972258,-33.214174,38.059467,-7.836732,-104.249415,-254.208172,-282.822391,-247.681896,-184.994894,-38.728899,49.245735,25.551668,-140.175096,-222.689832,-332.412326,-364.620372,-380.944276,-352.823889,-310.85411,-227.544868,-223.406015,-261.414648,-269.664456,-194.379372,-125.428458,-60.49835,-116.338311,-151.955507,-198.302666,-208.967612,-202.156565,-166.470872,-39.374558,61.237713,76.610266,29.739694,-16.087651,-79.934811,-97.749325,-154.4635,-173.480427:-117.449047,-99.2023,-140.118521,-282.220106,-359.921785,-438.944221,-389.999273,-168.046426,-7.811931,8.539353,-70.827847,-138.584087,-270.065309,-333.855283,-392.091138,-347.414342,-178.227097,-90.652368,-114.305835,-233.685265,-274.912509,-232.935833,-163.921484,-12.204263,93.551591,74.776774,-169.727704,-333.994105,-519.93882,-519.981358,-466.337096,-445.48554,-335.299412,-223.524976,-263.004837,-458.085254,-523.886872,-494.21534,-431.17687,-332.125475,-317.903499,-331.089002,-377.082336,-399.954572,-439.911567,-438.631441,-320.426404,-235.414959,-111.024019,-113.790632,-192.661699,-320.259711,-294.956229,-189.241258,-160.937506,-65.787588,85.915705,106.581367,8.523392,-55.894554,-132.532732,-144.423007,-110.852217,-69.29697,42.807337,83.735698,44.758713,-39.08214,-60.293452,-128.304621,-146.449704,-70.063195,-19.0032,-61.406453,-272.591701,-392.892985,-536.223076,-541.75256,-402.335688,-291.286054,-150.967326,-163.596502,-188.93253,-234.334777,-259.849094,-285.461399,-256.884014,-121.82024,-15.823612,-12.388131,-80.452118,-144.136693,-323.663754,-391.079332,-349.91921,-264.209655,-140.944002,-155.346854,-195.019679,-333.173871,-421.720275,-513.623702,-481.48651,-366.832385,-322.979046,-318.017313,-366.801404,-415.713112,-432.30199,-388.154218,-333.55947,-358.681353,-400.397993,-269.73948,-205.808084,-252.787222,-320.253119,-375.709882,-335.884476,-146.242411,65.675861,169.875831,362.021445,399.19097,255.200953,135.385334,93.029308,178.427478,364.211003,384.775953,295.858914,52.195311,-22.769667,-35.221722,1.733129,106.718215,234.851048,289.79753,277.64851,204.764162,97.147444,115.582282,258.019362,346.538671,481.314642,511.304108,469.903697,251.165618,115.824044,-19.562435,9.36041,115.218754,147.889852,173.705842,207.56561,161.036101,-22.810932,-83.816147,-32.679177,47.565132,184.274535,196.081039,151.209088,62.295657,42.189062,-1.02323,-12.758622,78.138442,253.961456,303.134023,238.182248,150.43973,35.74742,53.440249,199.32541,271.049058,340.832589,397.690976,407.41338,325.236296,258.776928,170.085237,173.286114,254.421661,400.352029,463.422265,428.762919,355.196681,231.634073,182.525159,132.292892,167.599408,340.816601,393.004448,314.711642,112.651937,55.295828,24.142222,40.35082,115.062583,182.095408,200.084339,136.953485,56.470862,-78.956298,-107.723325,-75.581489,-8.112217,186.250825,300.112136,290.884705,234.654937,205.063312,148.238406,164.794447,307.523101,421.344845,435.78593,373.880434,300.692679,131.153174,65.049581,84.546839,172.930913,316.194125,318.978552,283.625615,168.636956,109.005519,27.764238,46.471583,210.038839,309.031409,267.659113,34.176386,-84.835403,-164.451086,-130.309079,20.249257,102.533507,187.208714,182.935613,145.62476,1.710785,-73.912555,-158.664846,-144.195118,-28.678658,75.09043,99.029366,33.676377,-41.210144,-137.52292,-140.426087,-48.84919,51.950802,254.593506,290.011213,248.619843,149.944073,121.341594,90.32423,95.687842,243.119762,485.458508,538.397204,389.768495,224.425307,-53.061771,-95.971834,0.514461,85.321103,181.385975,114.466189,37.577657,-79.820916,-72.283288,25.961101,66.482561,120.939171,172.361946,177.609173,117.735372,77.86646,36.830446,28.657663,26.951023,42.734356,111.939724,181.538401,185.298866,126.519562,86.916404,71.365062,121.564196,258.598018,292.961599,280.994883,228.484682,177.518702,48.251111,-9.982956,-83.985252,-97.225866,-58.343919,20.406418,2.826809,-147.317895,-211.086951,-268.669565,-276.515699,-175.913813,8.274834,10.828667,-160.124226,-259.898289,-439.56058,-495.684389,-413.821949,-313.367672,-188.742403,-198.380616,-241.946534,-351.993124,-393.248319,-414.607679,-380.726976,-244.526054,-163.641254,-192.316165,-363.870892,-455.254535,-563.241398,-572.490993,-498.61521,-445.881372,-370.496602,-280.606683,-233.470936,-210.695278,-232.455856,-237.11172,-196.270998,-75.847223,55.06824,119.213464,141.499954,70.550535,-139.420849,-210.322544,-207.72845,-159.767213,-56.161464,6.836202,-16.594431,-182.323705,-256.349588,-270.467111,-238.702847,-202.082138,-128.28862,-49.65891,30.99209,-12.240065,-200.041979,-281.611803,-261.274101,-163.926208,24.298284,38.835308,-31.254059,-228.739081,-306.417637,-403.570861,-413.357628,-310.324302,-165.457266,-139.346946,-229.70819,-307.62606,-394.643865,-388.17094,-277.275788,-197.314196,-86.248232,-69.878398,-101.198644,-232.639756,-289.478898,-240.328953,-125.183625,124.243249,213.980918,192.785705,64.790283,-18.629289,-160.357154,-202.038052,-217.849621,-194.596798:-479.171287,-436.103672,-394.386291,-401.489549,-439.183122,-412.470015,-341.247644,-218.947951,-150.910903,-109.109429,-46.234355,-40.880103,-54.745531,-78.739109,-121.468202,-93.549106,58.736928,194.563064,213.079412,203.856981,204.960781,175.702672,141.836456,83.257242,30.628435,-7.225336,-156.240727,-245.877194,-332.894869,-339.935479,-344.400457,-321.175644,-165.630598,14.972715,19.383956,-119.756875,-187.653094,-238.650273,-206.421904,-54.969779,100.210753,162.397084,231.468087,251.801982,303.953686,325.710337,332.208768,306.914835,209.399632,136.149631,108.520181,40.906877,17.999396,31.082922,63.188899,100.008637,65.955008,35.546608,-49.775293,-52.176799,76.621387,136.498215,167.762477,177.739799,228.148692,319.087722,358.04435,346.240616,296.053868,153.446947,102.589947,112.379051,136.954772,113.029587,18.990703,-28.08663,-73.207515,-69.461106,-27.62467,-3.584265,-9.677261,-45.714285,-58.536222,-118.216806,-153.108945,-195.974514,-214.688672,-304.92846,-451.346345,-494.479927,-467.532886,-406.976767,-300.050814,-289.155793,-275.848625,-244.665542,-187.921344,-179.501908,-199.551564,-265.908791,-290.375479,-304.490899,-287.109126,-218.327166,-161.654607,-132.973648,-74.739125,-66.656803,-96.398007,-116.147505,-148.820521,-170.332433,-240.51582,-286.87688,-293.888152,-349.629881,-418.880422,-532.387008,-490.67349,-218.875007,38.673439,140.670033,302.303786,345.501742,332.918591,271.349281,157.501452,178.438062,341.822888,431.834524,424.575962,358.307331,308.597229,182.822713,126.746297,131.952791,280.385818,331.694781,306.350359,240.411428,115.114007,112.491662,229.440465,306.784638,456.378663,562.198699,533.28237,317.101566,214.20826,127.169511,128.116851,144.729193,95.185567,65.853439,97.057161,161.382826,277.592868,281.118811,195.079955,157.486801,153.998924,141.415798,125.048856,115.406204,105.666143,53.793002,32.625775,26.716604,41.838274,54.112354,25.4922,-19.929484,-62.800064,-50.239121,-65.700588,-102.577717,-152.205609,-100.765523,-53.864156,-24.9112,-57.585315,-135.606501,-143.981708,-95.646503,-3.395395,34.510243,51.617463,67.489632,156.060804,177.229457,142.189333,109.13584,33.265923,32.801025,74.641577,176.962828,191.291787,119.676992,93.163528,120.922705,128.766748,119.36055,98.881866,72.702167,-8.935647,-25.212828,12.666776,36.239055,104.231468,206.815127,227.972433,204.784193,196.120026,230.709789,278.585639,400.712224,412.966736,376.97033,324.881372,313.486992,256.99748,230.733913,282.077208,326.866291,331.172673,299.371402,289.801491,220.946155,159.897482,46.682278,30.390641,92.822438,145.469318,133.432821,10.646291,-68.704958,-111.216683,-78.734733,-76.932062,-125.404189,-176.870034,-122.527043,-132.354333,-249.194692,-289.692586,-268.936694,-241.680242,-198.883998,-73.812844,-6.033897,-23.630231,-98.203842,-206.568153,-191.197541,-20.269816,80.227843,148.212993,117.463418,124.794936,126.272551,98.101541,17.924073,-15.940776,-23.362877,69.769929,106.140997,-2.281873,-115.287083,-230.278222,-244.801564,-319.232569,-342.137033,-287.800118,-290.584599,-325.692286,-290.937098,-216.949882,-135.126888,-140.786804,-111.617187,-57.37963,-65.823893,-88.092467,-61.675191,7.241,-0.116002,-76.349533,-113.430798,-140.361695,-59.566081,-21.18208,-40.895493,-66.557902,-48.673575,-2.756091,104.299373,149.831897,149.278417,167.57582,182.166611,120.156139,47.342654,-34.534954,-27.850952,-30.421966,-86.514065,-116.286264,-134.16976,-104.877826,-72.629602,-100.930998,-88.69623,36.508485,70.946871,96.719681,83.426347,-58.240684,-147.084781,-177.221688,-119.7769,-55.828973,-115.613438,-150.256673,-226.112078,-262.940906,-252.160193,-182.350632,-14.511352,-34.037652,-110.5086,-276.076065,-342.976393,-443.109,-486.529636,-512.054549,-464.56353,-343.155042,-328.858042,-335.810017,-281.566846,-214.088755,-70.088293,-33.182549,-56.963257,-94.515378,-89.332959,-40.530435,8.622266,118.146032,118.962977,-14.985936,-78.715361,-97.68532,3.854841,70.865415,84.55188,23.066502,-65.44241,-59.535314,-22.386922,-14.973066,-22.767411,-63.296551,-88.066321,-174.175488,-243.602392,-308.92247,-270.16206,-141.038369,-58.590284,-70.323996,-198.238056,-275.185423,-408.342789,-455.891677,-468.845685,-383.387005,-324.420439,-284.791039,-309.995141,-284.317458,-213.175273,-61.498458,-14.007764,20.494745,-19.213299,-61.885535,-122.426487,-126.087184,-118.1146,-120.724283,-111.43346,-21.96271,15.89008,-46.141748,-108.922197,-172.055099,-201.034649,-280.395694,-277.462714:-353.894316,-326.616648,-336.861646,-388.741583,-393.056668,-334.275086,-283.154729,-156.355227,-23.04607,28.069401,34.488312,19.303566,39.772789,29.087024,-43.854909,-34.784247,99.442356,243.068785,279.469068,268.504084,225.829899,82.316582,5.224878,-107.656452,-125.752334,-102.696097,-103.136118,-142.553131,-205.939965,-203.580708,-173.334576,-170.861169,-140.608928,-31.931393,-19.907869,-157.006407,-260.14555,-391.999126,-368.415518,-188.928948,-47.062763,-2.808584,43.409836,40.446522,9.825612,2.301827,39.492481,65.795956,65.81712,67.348652,79.826056,63.296857,25.373843,-2.148602,61.646579,218.462829,189.902807,154.055209,132.250742,139.187544,138.613778,104.539419,72.132592,119.622241,229.726849,268.046542,300.817493,383.566084,380.741475,250.524416,165.909989,79.530588,124.911248,153.476367,106.882448,38.689389,-62.992967,-72.294441,-2.577566,49.342891,76.365878,-3.643916,-76.471737,-231.549556,-276.792349,-318.693423,-332.089018,-371.008168,-452.400314,-465.327537,-412.756852,-400.536729,-441.531694,-452.131073,-388.567709,-345.128218,-324.669165,-313.096543,-295.551705,-281.384488,-298.718731,-367.274533,-372.132643,-307.085236,-268.051533,-253.716642,-210.313008,-194.173472,-180.894138,-195.918388,-261.047511,-277.865665,-287.313294,-292.941623,-269.779699,-206.704505,-213.438383,-291.555956,-262.675604,-1.936302,212.062925,274.050208,367.14258,384.996669,361.512455,331.486677,303.340426,352.516919,555.890575,632.098822,572.339985,398.164108,342.029112,288.586054,267.472062,250.713643,345.311106,403.87555,436.993198,414.013372,356.560457,355.754414,425.090496,463.462662,557.398474,676.783357,672.211234,520.371793,437.115829,335.188741,312.733405,280.914432,231.924426,220.373314,214.29767,207.852538,200.803971,186.931468,163.015175,183.547795,228.601715,244.611265,291.108665,361.317216,306.417488,108.613771,58.582178,101.579397,185.241713,198.622556,176.483149,165.865787,150.902362,125.009386,39.448794,10.909231,36.526914,137.085952,151.10644,67.244953,15.944677,-39.34112,-45.809387,-42.507755,-25.281946,-9.025617,7.782379,19.483245,54.471344,33.071298,-88.070218,-137.538492,-156.457764,-63.941657,5.189337,120.421281,133.030243,35.063454,-30.605794,-92.342893,-99.713845,-98.492921,-87.459089,-84.658782,-72.07874,-50.368276,33.810542,83.544408,168.697972,271.679239,302.693812,265.832621,214.944376,90.485632,65.269781,198.114116,351.191388,339.759502,203.909644,144.624383,72.465115,46.725347,69.258286,126.958458,258.270355,318.70556,292.841869,165.365765,117.758224,108.736791,134.196519,163.948943,121.639082,110.196903,102.133056,87.194615,80.581721,89.379249,49.91911,15.474964,29.471758,68.183325,51.073745,39.407741,54.977722,37.775319,15.926531,53.107902,128.098482,92.358543,-88.877701,-128.884042,-45.54791,-7.1099,14.203368,38.836539,69.236569,69.961025,87.653581,84.674299,48.287626,5.27761,30.070378,102.903112,89.307376,71.089453,22.296875,-44.64349,-249.415399,-329.988023,-329.42513,-258.688128,-154.695807,-157.282481,-133.045948,-26.485559,5.210539,-15.517652,-22.100558,45.191094,89.240198,72.518538,23.377695,27.764804,85.930119,84.009592,-11.057152,-44.448213,-1.014736,70.26377,57.613657,-43.857053,-82.43177,-59.865271,-15.591555,46.523887,83.167839,113.390564,180.191689,214.321948,217.933249,141.155243,-70.084791,-112.6208,-46.383659,2.380119,-53.813529,-186.705361,-184.2431,-169.928493,-206.301667,-200.616212,-69.775128,-46.7314,-66.675661,-76.345346,-154.315524,-212.274467,-204.351329,-146.466885,-107.319448,-161.843798,-163.734054,-134.947401,-156.112624,-287.903985,-313.706704,-202.124855,-157.517292,-197.835414,-279.257186,-308.696002,-415.985627,-487.823843,-529.312508,-481.885648,-363.811141,-300.533507,-263.582972,-156.363497,-122.706784,-130.987401,-141.297674,-145.189435,-146.276811,-127.360116,-70.776229,-42.637118,28.400463,34.364748,-93.832912,-173.222945,-171.695707,-8.562592,22.660428,-82.598931,-153.590776,-230.339862,-229.487804,-117.089594,53.421746,73.687646,-15.835774,-53.302619,-92.590317,-136.36729,-166.112956,-85.271156,131.156534,167.714051,111.375684,-66.582741,-147.73221,-234.775227,-229.070028,-150.938882,-134.452093,-151.525269,-140.259547,-90.914659,53.815025,93.357684,100.572931,111.978015,147.63414,159.115926,138.568464,36.108244,-25.577605,-113.888007,-134.120257,-98.018044,98.751588,207.062972,261.58245,210.960537,95.519278,66.79924,69.883505,65.149664:-207.29639,-255.604531,-282.294939,-294.903782,-284.705837,-279.344191,-273.194746,-215.250178,-108.839111,-53.732981,-7.942491,-22.055561,-54.51821,-77.042442,-141.185118,-133.562603,-8.654436,86.213412,73.850621,-13.774962,-46.760127,-37.48591,7.105503,137.158147,137.696422,36.114692,-220.920574,-299.465579,-385.465892,-439.320068,-513.551888,-473.011068,-254.876371,-92.479792,-108.217607,-289.112651,-363.559813,-364.805193,-311.384446,-134.800104,9.859775,7.812611,-86.024949,-99.668494,-41.915691,-20.482293,11.462949,42.848798,107.686169,86.082223,28.016127,-112.40963,-167.486405,-186.159508,-114.153863,105.24518,135.782149,71.476071,-43.14287,-56.532427,-90.333757,-130.31318,-108.757567,-32.097902,77.646444,90.278627,114.765099,165.222032,133.38807,-22.256431,-51.497579,46.440862,87.871126,46.757134,-109.869187,-192.768894,-282.702261,-280.648746,-190.000136,-138.224269,-131.075154,-153.750651,-162.17863,-194.863587,-188.181671,-122.865034,-94.906775,-98.055999,-150.982479,-174.500331,-201.834007,-222.033724,-284.097968,-297.726116,-264.498572,-237.65935,-193.141236,-189.64307,-207.648178,-252.717688,-277.565182,-338.510502,-358.411532,-339.39621,-299.47894,-287.75762,-241.015183,-187.120146,-93.908578,-108.970916,-204.111473,-234.81754,-261.86961,-286.0209,-320.057756,-382.417277,-374.600217,-348.995194,-341.599079,-218.445532,27.710984,137.087209,258.430724,265.022235,235.254682,229.203996,224.715261,215.83237,223.535592,262.277122,234.40617,76.471278,8.732466,-23.103694,-0.463683,67.606506,171.897671,227.915391,225.693257,156.047912,59.039461,94.400473,261.463272,327.628307,378.097487,391.941617,357.569561,163.088155,80.570112,49.574929,62.336959,86.320371,51.352349,21.885383,38.464729,69.89479,73.545277,47.708278,9.632693,0.852833,30.723714,130.417356,139.765981,64.712384,44.889264,75.304204,101.495128,120.517956,122.206417,148.489555,143.427766,84.012182,-34.120637,-51.342809,-7.598011,22.355561,69.175058,186.946334,254.820373,284.448524,248.704334,146.091252,112.809723,134.299643,197.328297,228.587945,263.430649,246.283657,187.936883,176.011158,184.005403,192.779426,205.328718,238.503478,250.6459,189.613462,124.249517,31.099472,50.116986,197.813748,217.299726,161.011086,47.121734,-8.883488,-77.31112,-74.50738,-29.123442,17.972402,135.94719,182.388514,188.979071,242.123414,269.407982,281.617477,291.952787,334.459035,392.349256,455.235968,511.284375,423.411005,160.13533,93.36746,182.833104,300.324823,436.286745,365.763552,310.162316,230.950979,218.914326,232.116612,241.767349,218.240045,206.45046,218.221768,130.887918,33.985824,-75.737888,-75.360661,-56.661206,-33.017368,67.907191,149.2479,118.026414,-54.589183,-111.705008,-140.128516,-149.815723,-119.506259,-5.030492,33.292582,-22.520712,-98.093289,-174.719316,-133.843563,82.986109,199.031926,249.669589,135.960754,112.764937,138.388304,144.970283,141.765786,155.342653,220.334579,297.032788,317.716904,252.822995,155.672378,-64.45199,-131.189758,-142.759724,-108.591593,-36.886277,-40.377348,-74.216146,-128.729092,-143.010694,-184.264129,-171.00112,-16.45113,90.750256,68.702276,-2.724815,8.740492,64.767734,49.254081,-38.255207,-73.54833,-99.787006,-5.567115,22.324046,-62.03842,-91.971797,-12.979097,52.574454,131.238941,165.827451,192.081083,160.877155,92.251729,21.405708,35.280263,11.684744,-57.784425,-193.059701,-158.773731,-130.695736,-153.185849,-179.669952,-248.121262,-276.952268,-225.885419,-87.326427,-57.891716,-110.004064,-155.265323,-218.489963,-236.076029,-197.342807,-135.709476,-54.44511,-99.075494,-141.51005,-225.465551,-256.993805,-286.533723,-278.013427,-191.690359,-143.775542,-185.624376,-360.552848,-449.476515,-554.114739,-572.845099,-551.79527,-507.124772,-385.833288,-297.124094,-280.335101,-238.925641,-191.651063,-95.24759,-67.581467,-70.500476,-120.606502,-113.437524,-11.337927,40.3047,34.024726,-35.590876,-181.754828,-187.836826,-112.877824,-56.28064,-17.148764,28.897946,-7.912249,-123.293846,-140.257229,-89.86469,-49.54354,-47.25696,-89.952543,-124.808354,-210.64203,-271.94377,-319.010099,-258.907129,-82.730567,-49.029837,-107.118377,-272.036949,-325.857808,-334.873856,-317.956661,-320.784983,-290.0455,-235.95285,-182.945025,-221.891309,-278.367905,-234.908292,-99.466649,-67.918052,-65.985029,-50.655649,-36.939094,-18.392114,-18.701723,-52.364917,-63.107552,-7.240126,74.273714,72.9933,-34.143925,-107.41736,-232.997854,-283.784339,-345.472635,-337.287713:left
-244.406959,-274.321477,-207.159516,-28.074766,8.779653,-20.882099,-24.507092,10.421553,4.39962,-15.948521,-34.227971,-10.660916,9.888046,-32.886425,-135.830987,-145.782329,-57.493454,38.785016,30.202362,-48.863211,-71.856023,-52.15054,-40.60579,-114.267336,-149.975281,-81.667939,62.335238,102.134976,177.930384,191.336176,130.281693,92.459603,66.63282,77.925676,78.059221,61.343867,44.998739,27.316739,26.196399,-25.945597,-120.166047,-158.786732,-209.401997,-202.652153,-139.531222,-124.666215,-141.041399,-134.274253,-55.581865,33.754418,49.353156,-8.52278,-56.031498,-87.469311,-70.58325,-19.92575,45.808237,77.162583,133.266508,174.039128,281.425476,340.400112,407.303335,383.552642,325.742433,409.755561,454.292548,445.676427,398.030119,252.827295,174.37811,46.465728,60.962745,104.83243,104.490373,81.622693,102.400855,118.673466,68.774805,28.974988,62.658701,226.936532,299.41115,354.712901,331.536982,267.828227,269.33842,330.278396,422.106226,452.263817,445.973884,446.183627,483.574819,485.457987,399.462821,323.237652,246.448984,361.270435,405.240884,330.521996,243.847868,87.585486,60.931695,162.263535,343.883439,380.701277,242.492891,132.224541,46.354912,79.258628,231.807444,290.98277,238.48606,133.575218,148.96239,325.157492,423.499666,473.906112,421.881133,275.205103,266.665489,316.019594,357.808154,327.336526,243.475604,223.135506,240.09578,269.190674,345.305401,380.614516,371.075872,368.60276,385.493559,363.068253,307.097739,177.381317,89.410992,48.083948,-11.312171,-3.489356,45.183151,63.628692,85.751612,80.810652,83.28862,167.824372,226.410185,317.633201,318.675299,239.514013,199.946515,165.41871,198.72974,221.492703,209.210675,190.690231,156.146421,133.279644,116.929673,117.984774,99.372299,124.825037,149.927488,163.059673,154.654018,159.239311,171.217375,107.041511,-9.074497,-5.994434,92.851754,135.456929,111.201194,67.773682,32.592116,31.271305,28.897666,44.278693,56.422924,70.364872,35.981377,-125.74299,-207.113842,-308.807934,-298.103472,-239.763102,-100.773099,-55.952422,-23.426071,-19.718486,4.450816,31.476442,109.038967,163.658163,143.43901,35.491047,2.705791,4.154494,-10.492725,-140.241655,-224.602245,-177.541187,2.553528,56.524101,46.118758,23.5951,-8.28267,-41.989407,-120.205203,-70.542934,10.376478,219.14794,277.219034,220.282107,155.569007,25.226242,-136.256389,-207.98917,-242.411329,-187.859685,-32.469187,7.279069,-21.503369,-76.61302,-170.684689,-120.341957,-77.904689,-79.861651,-131.558998,-252.54245,-278.655253,-274.777099,-266.174757,-248.604373,-186.916043,-154.2847,-100.523466,-91.337946,-119.272868,-146.17212,-186.910492,-196.058942,-198.898527,-184.983028,-168.116821,-164.984854,-185.165651,-223.026847,-136.722981,-67.508755,-1.486169,17.696961,67.485455,50.169444,-104.500474,-188.545129,-232.635965,-154.136966,-134.146531,-145.139043,-150.748748,-156.469356,-147.265644,-68.196739,22.304961,35.368993,43.660999,67.881664,45.062185,-41.403582,-231.450571,-284.118954,-303.02578,-284.647577,-288.244887,-278.348369,-253.266725,-199.74152,-172.913192,-123.453675,-103.18647,-97.762094,-55.623885,-20.547037,20.286877,20.752745,12.146373,-3.975103,-43.591535,21.913053,93.106681,257.89524,318.21715,319.671761,281.462496,216.484232,236.226122,289.190566,370.545605,349.710919,259.20146,241.925783,247.795787,237.081252,207.799724,261.783182,317.035852,423.496544,436.18923,358.291004,297.39922,149.675468,30.734128,18.721065,34.612237,53.24641,114.098832,129.322896,64.617758,6.342239,-21.350786,20.26903,-12.819694,-151.281633,-195.742592,-236.872317,-272.243363,-344.894637,-334.402681,-320.437916,-279.269619,-229.807589,-144.715835,-150.112551,-218.939496,-236.43071,-188.921664,-120.872007,-96.852742,-48.676738,-53.842626,-168.068617,-228.254538,-227.50648,-122.790909,-90.93098,-75.977521,-66.06278,-71.454148,-102.143619,-204.713321,-263.360392,-286.641936,-161.417041,-122.865058,-165.967821,-210.644475,-248.804987,-240.038874,-235.775647,-236.814618,-203.517029,-86.83438,-43.769848,-37.418347,-48.695614,-72.364589,-105.909352,-169.146187,-120.791115,-89.512663,-61.459507,-41.052188,-8.798855,-35.418085,-170.946919,-179.517267,-110.421472,0.984117,4.517209,-53.687648,-71.389487,-19.292209,17.057756,31.714836,32.388201,40.749053,25.906458,-12.745012,-121.075859,-168.678775,-259.534671,-296.824277,-261.434913,-148.98743,-106.513183,-57.88623,-57.336485,-155.719737,-242.406205:-191.174539,-154.521601,-130.536199,-49.500041,-16.827124,-33.816982,-76.392159,-151.356961,-117.090136,-80.301625,-85.537913,-115.714892,-118.177766,-90.359011,-100.152103,-154.463469,-229.750761,-183.565989,-149.940358,-148.36588,-185.27788,-243.4915,-260.503925,-308.751757,-225.53786,-115.961978,70.546287,101.153809,52.138076,7.821015,-36.455432,-24.266015,27.171559,44.014732,31.278464,-12.979944,-28.553222,-91.028141,-164.574103,-306.139098,-279.326809,-220.389263,-164.075948,-188.093784,-254.896423,-261.922983,-234.540466,-220.110472,-135.270732,33.325328,76.546002,17.175715,-42.19137,-112.995218,-122.465965,-100.108391,-41.844095,-8.838848,121.646467,217.534496,342.517124,353.859062,338.666708,328.153626,336.045039,452.363277,532.502461,555.725324,476.156072,308.669575,265.825931,196.356934,163.990371,192.119225,302.736304,357.321898,405.855251,389.701619,252.194605,164.828567,162.436452,349.343072,415.137041,422.609999,385.665089,328.847105,327.451914,339.511765,382.642136,431.028508,514.82372,513.490077,422.802022,372.590159,326.117479,310.270577,270.438878,283.71508,317.011163,370.100708,344.914962,183.203487,116.976355,166.242693,328.347467,370.574536,327.628487,248.648919,76.12276,47.775287,148.669323,213.718581,240.310528,209.113246,220.792215,327.206658,368.354978,314.820049,265.952896,249.965803,332.359887,391.660271,451.94461,425.183078,320.624039,286.458277,271.144729,279.329114,330.244338,351.173284,346.517969,381.903878,391.302329,283.34257,194.650394,107.400598,104.82595,71.767948,11.360093,13.015936,6.352423,-4.5623,-17.873488,-39.621675,-65.747777,52.431315,139.961532,274.552549,280.277061,175.793272,135.218594,175.434431,248.358703,238.399761,171.444762,153.893521,165.149692,177.388661,145.350614,102.52312,97.004822,216.652644,262.842633,258.425836,224.030596,186.270427,172.146266,85.224307,77.190977,109.925062,99.319542,54.780546,-38.705322,-61.255351,-32.863001,-10.255812,14.379294,68.307018,91.451409,56.069134,-14.65983,-194.479283,-240.381056,-199.320971,-159.236441,-167.792953,-137.916999,-99.729317,-77.079395,-84.287654,-59.869565,-41.616758,14.064882,168.785256,234.888075,225.598566,168.028618,74.368388,56.122091,-15.935636,-110.084891,-102.149338,8.742346,40.541571,12.868999,3.368405,-9.695665,-35.491913,-63.665377,-29.512652,7.102909,162.658105,236.710675,210.342317,115.536546,-116.964616,-277.541958,-298.094767,-203.847823,-125.792411,-43.980836,-49.655612,-122.701097,-168.149486,-158.130206,-79.729533,-80.107999,-146.696774,-195.15023,-259.154191,-243.343356,-155.332769,-156.272216,-174.234693,-116.426098,-69.880593,-101.850424,-158.231355,-188.277079,-173.525297,-178.831337,-182.426051,-159.915674,-110.679056,-112.840599,-140.662258,-131.66122,-84.058479,-47.7857,-9.431647,110.241707,146.946358,104.206739,40.289536,-109.844199,-163.119809,-127.877518,-16.153864,-0.560659,3.050902,3.104768,-77.686151,-148.875936,-191.87668,-54.083865,5.59554,51.962295,74.07794,96.68622,66.005837,-81.783874,-185.209802,-353.210997,-317.37627,-234.78145,-68.421122,-40.342577,-104.96515,-140.762288,-128.039533,-33.823713,10.616287,44.392935,27.024028,-20.50569,3.046719,91.539446,82.922249,19.42763,78.34797,141.320033,261.351122,274.250058,151.501502,74.193903,34.560576,114.748177,168.18408,276.303394,312.347127,287.583642,244.490783,182.017078,168.975476,217.862845,311.947571,332.699317,332.919838,316.248576,227.182583,162.345006,69.582225,83.332123,99.624771,94.013215,87.275426,55.196901,19.372726,-34.312723,-29.519772,-18.232034,-86.154292,-113.842181,-102.369455,-84.038046,-115.770143,-183.394936,-293.615542,-234.559826,-189.971229,-126.691612,-92.785943,-85.701963,-123.460435,-182.564313,-181.081745,-125.20327,-19.369536,34.143147,66.939085,19.673297,-110.289396,-125.344522,-53.179196,74.498681,141.367143,206.786814,188.862387,55.146609,-30.558679,-140.974883,-162.766492,-141.712214,15.864618,93.842771,64.123128,-20.302769,-121.901524,-127.57329,-124.345723,-44.07419,11.608,40.469668,13.158857,-44.609842,-44.164107,-35.633814,-71.952034,-179.776713,-181.641399,-133.093111,-24.923455,-12.469328,-85.687412,-140.570817,-247.425825,-271.484728,-210.655076,-17.158053,30.382807,-46.930588,-101.137066,-109.037495,-75.777053,38.728278,113.148777,113.922765,78.619629,19.329798,-175.729925,-258.860802,-317.491617,-244.133084,-180.916299,-82.26956,-56.016546,-55.103829,-97.488822,-245.883829,-300.523453:-163.662133,-110.678361,-46.0023,-9.241025,-55.296129,-126.238346,-116.535727,-90.453827,-102.904274,-109.28622,-97.299664,-91.442519,-133.51458,-167.737242,-197.309283,-194.085165,-202.824778,-216.882841,-197.136795,-170.873323,-189.047713,-241.449884,-274.601696,-341.965585,-236.236577,-117.233855,61.113001,81.336521,45.401382,23.752065,-32.168141,-75.252602,-133.004936,-69.837447,-25.264199,-35.67587,-90.09105,-211.675978,-257.801698,-296.068339,-256.365843,-219.149053,-148.461453,-138.042167,-157.949913,-162.636832,-134.660835,-107.544829,-33.295109,40.242636,47.310307,-13.562534,-53.031085,-87.089297,-91.724394,-76.389046,37.357275,107.192144,210.089628,255.39872,361.275514,412.665447,441.390161,418.938845,432.717335,542.466256,560.948527,466.74409,392.249445,311.643374,294.017222,200.835187,123.070856,131.190652,240.524084,309.76333,347.008754,306.394122,184.461722,150.695477,237.58976,420.46307,467.317686,456.216994,430.82392,371.783652,317.857052,218.996261,302.226877,381.695909,447.913472,409.039722,257.562472,194.533395,112.134137,72.816365,36.722573,94.297768,124.158478,165.202883,177.092222,139.666702,97.880305,68.546952,139.234645,172.227532,170.459648,125.819844,-6.829078,-38.504239,29.085422,88.073022,145.590938,171.137407,223.372039,366.25178,395.517962,339.678443,293.324767,233.916484,256.660277,297.6856,380.543936,383.399803,303.092588,263.238644,231.060351,226.774094,233.211022,323.440772,394.726402,400.814301,297.650257,36.634778,-44.753699,-37.377861,66.666741,76.202595,38.526077,15.74576,-64.831889,-99.999887,-127.23412,-149.570319,-155.671009,-3.172694,82.474961,141.827991,114.642798,44.590654,40.657772,82.30624,99.400554,96.883901,143.460189,181.050326,146.869383,87.090743,31.235242,47.980977,139.15912,232.610797,247.828318,232.207997,230.093957,224.359939,175.583827,-22.016997,-85.855515,-25.203351,102.609956,112.82452,6.506936,-70.607627,-123.759805,-94.217009,-11.137973,58.939633,82.10144,34.02595,-39.244025,-175.262825,-210.274229,-232.878445,-236.739334,-225.55292,-174.699849,-171.668839,-227.161895,-246.258153,-221.102844,-184.907488,-75.903015,80.185492,158.791081,204.834253,152.576931,42.515094,30.361053,6.080885,-34.556467,-25.409255,36.961382,51.967281,-10.027208,-38.115818,-4.935484,2.730705,-50.738339,-32.662093,27.453797,170.78183,199.649428,127.890149,55.337158,-89.575219,-176.622757,-179.829313,-100.010131,-47.035037,15.027611,22.234972,-11.355429,-46.171995,-70.908251,-3.092361,45.057503,98.953105,73.757859,-56.922857,-122.719482,-158.110356,-63.093166,-32.800531,-52.381423,-64.033956,-63.609033,-68.865517,-70.681129,-53.396079,7.335542,36.41814,28.761413,6.627776,-9.895479,-51.632987,-67.070548,-98.96037,-58.618662,21.901117,178.566064,204.685459,181.631714,144.085197,-9.198821,-95.26468,-134.844471,-11.689947,62.304243,143.332857,125.867942,14.012577,-41.117775,-75.995546,31.383598,93.147051,93.026074,43.622386,-11.495323,9.429677,32.877953,-9.607783,-118.479524,-94.982021,-24.907034,119.150479,125.083129,16.587892,-27.32755,-27.159495,13.816471,40.779011,121.461468,140.415323,74.186453,53.168429,116.991036,144.406203,148.278821,220.13638,287.348384,374.520814,359.08187,220.159984,148.289909,122.965767,199.919393,229.164005,262.923268,276.815541,273.464274,240.103438,147.450886,137.134418,270.506867,392.123459,373.936041,268.876823,216.109118,146.912477,126.472348,89.535019,93.594215,97.790228,92.944447,98.024551,71.839173,13.749924,-120.730614,-140.314502,-73.973528,-47.767592,-60.759636,-69.347205,-72.170689,-98.091013,-121.587687,-170.471669,-160.617735,-141.937344,-121.900691,-114.288394,-100.110031,-107.028205,-172.219625,-217.122597,-207.064764,-19.04114,68.385482,104.069655,59.42316,-49.163542,-75.22275,-27.304097,126.792399,207.883071,278.201166,245.999264,105.620997,48.484762,-3.554248,-27.880543,-59.964253,58.329868,140.254739,175.55621,133.485316,-10.661874,-100.973992,-210.354419,-104.951525,-11.540867,96.640808,84.122015,-41.722843,-110.381608,-178.300157,-176.950696,-132.473285,-79.35751,-47.922554,8.672219,-5.681837,-141.88692,-221.984748,-262.645735,-162.665495,-127.765026,-97.653059,-76.107386,-46.27631,-55.762056,-103.983148,-106.321349,7.747731,128.192491,128.285223,66.060741,18.590655,-123.571046,-192.676165,-244.983301,-164.205181,-105.575608,-42.833641,-41.993003,-67.409571,-95.632141,-213.102072,-288.019914:-172.805179,-79.282369,-37.302273,19.737264,36.009531,41.264988,36.310121,12.740987,-32.086536,-57.798543,-105.388266,-106.914803,-94.198591,-115.78291,-164.597312,-155.270021,-91.219369,-19.38106,26.481011,94.876644,81.447609,-4.423809,-42.748568,-113.420955,-95.846664,-32.483512,78.326663,89.148374,44.664968,25.70722,48.660843,58.108767,5.662168,-9.505577,13.085261,15.315183,-13.643512,-80.299109,-110.530054,-220.922251,-283.256726,-238.947805,-160.187882,-186.399286,-272.484529,-260.35643,-122.595261,-65.805396,-41.636983,-6.3358,14.43326,15.406797,3.086201,-31.140801,-37.85281,-1.575334,98.217004,160.826014,275.950385,331.095031,424.490992,443.310798,422.047948,405.505697,456.171906,579.636295,599.079918,525.391737,462.225636,329.198006,249.341598,62.605501,-11.875008,15.180636,120.183827,186.909468,264.425495,225.665641,48.452454,-5.901757,92.91227,280.444948,313.859807,302.882609,293.062916,297.110093,309.808038,322.861769,338.727556,351.001767,362.129812,364.925143,357.276194,337.092749,256.715828,210.574067,199.559936,318.737021,359.592413,318.991113,262.856158,135.919374,90.924603,102.273451,181.564145,194.760515,161.552472,138.463564,90.346731,74.849234,98.380908,121.254568,166.64833,201.276368,196.714534,231.31829,293.388131,385.466699,372.136468,304.759757,361.142798,413.816796,418.920464,363.973907,219.642657,169.922481,158.336838,179.55709,228.135722,282.43423,321.0169,365.328089,328.740624,189.861375,150.755152,147.124036,111.593616,70.594412,-18.398807,-55.532076,-87.634459,-74.051479,-51.565861,-80.069126,-85.878944,92.211616,162.250999,195.728285,184.231349,130.349377,105.618519,109.765792,174.509042,200.550645,190.653025,160.38068,81.522498,56.904716,39.796024,30.871837,62.521618,117.21093,120.331898,126.478027,125.945486,108.474244,100.39703,36.699704,-0.73573,42.625116,138.965361,133.209489,19.024865,-41.098517,-85.693694,-85.885681,-90.147349,-64.37804,-44.496859,-27.519502,-57.658161,-207.545962,-274.350378,-317.600468,-308.120632,-297.216237,-242.748776,-206.456546,-192.361086,-209.229987,-185.389949,-142.084473,-64.078856,-4.464773,20.342264,56.487129,53.908425,-39.398643,-116.719005,-247.019316,-221.855071,-156.408635,-76.345748,-90.252944,-121.162771,-103.146278,-74.614304,-103.625984,-180.155642,-119.18218,-49.218034,95.774419,151.342282,171.482178,127.445715,-53.709488,-256.610385,-302.689774,-242.798878,-166.073883,-33.66409,-3.366121,-2.920383,-31.488422,-72.883697,41.250441,109.841248,104.494662,33.151644,-110.253684,-151.769558,-179.646659,-101.413341,-49.201026,-6.43896,3.818516,-0.123285,-40.970643,-138.348193,-144.925587,-75.776657,-48.830419,-59.196654,-86.966104,-109.923095,-162.114914,-190.741979,-244.351345,-153.52324,-50.487374,112.834416,142.540152,112.662371,50.229367,-113.562534,-156.867782,-103.986276,-8.389433,1.676858,-12.019662,-9.074306,21.524257,29.187706,3.863908,14.010285,37.371096,67.482956,84.391227,110.466223,79.405959,-70.700909,-133.778743,-155.905113,-139.180857,-138.080048,-77.674668,-31.09329,-41.591004,-81.822051,-47.414001,139.399527,197.041998,167.924803,135.450368,94.819862,73.62239,40.35236,28.253887,8.334206,40.986855,91.340211,230.481524,268.478253,227.299311,193.200444,183.149955,228.991095,262.437398,306.647621,299.076721,275.938994,280.038304,236.091807,180.900964,152.566021,268.720671,314.203327,312.701196,280.954052,210.622848,170.002992,58.831168,-8.632786,-8.305424,50.166725,98.296645,116.985193,69.79668,-24.995909,-50.332373,-87.379608,-111.220417,-122.780953,-148.001798,-145.661791,-143.697439,-192.416781,-348.686295,-336.354693,-272.513273,-195.462258,-194.366088,-207.860202,-209.297229,-223.203882,-240.927183,-225.789088,-153.938174,-139.174093,-150.188563,-170.607063,-227.363794,-237.846288,-184.841842,-93.096488,-47.735514,24.653664,19.857779,-111.292656,-191.296474,-254.483454,-253.062344,-226.67426,-133.801581,-95.213744,-101.639616,-137.397179,-200.45784,-211.642743,-217.371309,-125.974255,-48.256679,2.408392,-34.582813,-91.949396,-77.055162,-24.746747,-34.568544,-96.47886,-49.034041,-7.132422,-10.14893,-41.304015,-93.894789,-116.024035,-156.95771,-123.706201,-73.250261,2.662516,4.538082,-54.51926,-87.71678,-86.888489,-51.415944,52.614858,65.786798,25.661517,-39.843196,-71.935756,-176.473343,-216.63712,-234.854437,-224.965365,-208.670213,-146.235541,-121.071988,-133.179095,-165.371181,-255.31117,-303.076264:-117.460473,-3.299372,55.878807,55.20516,6.553755,-33.455316,-23.526638,-32.010512,-87.053513,-110.581341,-102.178603,-71.480756,-35.946775,-63.345466,-179.600909,-208.943851,-135.559411,-5.196793,48.42439,85.485933,58.191544,-39.710744,-99.653242,-202.838011,-106.97882,1.283353,135.34621,132.186884,53.781929,19.654106,-20.27164,-57.618914,-130.104765,-16.324488,74.789557,76.08542,-30.951248,-254.217878,-313.916036,-329.657666,-244.08265,-203.357294,-151.573343,-127.258667,-114.383363,-132.167466,-170.573774,-162.641371,-42.957869,119.206102,147.71166,67.676435,-0.660102,-89.592728,-102.79218,-76.804541,79.046123,202.272442,404.332476,440.234382,425.217088,415.146461,397.940691,389.528576,445.527032,576.499617,606.500609,534.85648,446.721062,268.07193,204.472143,83.163669,-2.255808,-0.789441,104.967878,187.359919,263.204409,228.154533,59.697424,-14.238779,41.124753,268.370419,352.895866,361.469466,305.174985,268.154903,295.007477,300.101877,276.242034,292.760474,323.624926,295.741349,165.629124,114.427052,53.284369,7.393171,-47.860164,71.942537,139.951796,147.869938,108.60952,39.332966,14.451402,-8.268603,29.948633,43.494215,29.912116,12.451284,-39.168135,-54.003729,-26.876783,-4.906272,20.108563,44.284712,88.331285,237.324127,292.578641,312.752737,291.973014,242.892454,247.079167,263.626228,316.801001,320.050423,178.870049,78.114032,-12.599569,15.109445,154.946371,256.100148,292.177159,316.361383,247.270989,39.302312,9.855003,101.512513,121.789911,75.937063,19.794096,45.509502,39.066103,-42.557735,-189.893737,-181.435049,-67.532458,6.789701,45.650798,161.951602,182.606669,87.750342,30.471975,21.402841,137.822441,203.187414,243.590557,205.189082,77.339088,26.233445,-39.367358,-55.524316,30.316858,192.288871,231.454555,229.765376,196.303924,83.134339,33.163638,-12.465453,32.896141,80.629943,136.304697,121.570086,19.335635,-40.721446,-113.098838,-116.058219,-89.431675,-61.412021,-30.148118,-0.610658,-49.286588,-199.726239,-251.122824,-286.264816,-251.758895,-215.776081,-128.135584,-114.200104,-198.7365,-256.327238,-289.590201,-259.417482,-123.33154,71.65605,153.998555,203.48144,148.262312,-12.48104,-59.160164,-123.579768,-148.871785,-113.001232,-40.991126,-49.72181,-118.117743,-140.171867,-154.474925,-172.068646,-195.420754,-118.975259,-59.721368,44.648084,72.770419,53.193734,-1.012202,-174.131109,-266.459271,-228.688914,-66.610855,-18.889519,-47.21226,-73.367149,-91.104929,-96.113719,-67.320172,42.276869,105.551075,203.137207,205.995743,88.453445,12.016121,-69.631444,-37.400647,7.023533,102.231351,110.900151,31.418673,11.690095,48.869783,45.752573,-14.23551,-29.531709,-0.21035,51.927489,28.573353,-63.367168,-85.617467,-56.233322,13.107009,38.319268,115.336212,175.565329,204.306489,129.841509,-69.977329,-110.2379,-8.812385,134.876992,166.48917,188.876581,178.826328,115.02186,76.265649,24.806227,79.009632,137.103327,231.819349,253.063637,258.003325,223.641276,33.034551,-57.784708,-47.365813,51.723912,58.665136,55.663837,69.071068,49.168648,-12.582307,-113.481982,30.914797,146.20763,255.71979,228.707899,109.695815,84.582581,113.908762,120.535536,97.847731,99.932934,125.942259,192.242238,203.706766,171.533708,145.996787,112.409021,125.316977,163.191465,295.53207,338.305246,269.316364,197.261014,138.953783,158.392742,244.169746,333.418383,347.697516,267.544491,184.281016,61.870186,47.698416,56.932886,111.552392,147.629063,188.445311,185.55513,96.230494,20.216467,-108.079861,-138.967132,-127.354777,-70.363489,-44.875054,-30.941149,-58.341432,-162.289462,-218.781968,-287.690675,-230.636752,-157.942044,3.146916,15.427322,-150.141627,-227.877616,-239.401073,-220.85271,-186.364604,-103.871131,-56.251412,-0.793761,6.810865,-35.759233,-91.919044,-149.433283,27.55798,135.088266,179.233706,108.65186,-86.763082,-141.327205,-143.489366,-143.624938,-155.939549,-59.397976,10.0867,61.617561,35.6124,-42.25207,-77.827834,-137.757976,-113.094407,-67.935634,-11.102408,-21.484996,-83.745013,-125.458731,-223.477116,-254.034442,-209.667147,-91.648392,-44.706113,-0.697333,4.209351,3.898033,-28.022481,-164.248532,-184.61113,-130.347208,-38.711581,-46.352443,-125.064802,-134.002695,-107.824341,-108.406975,-78.997914,-2.511323,14.673368,-22.703666,-75.892291,-220.155544,-280.013088,-308.322955,-227.235305,-178.417251,-106.974514,-91.551054,-113.917298,-137.393115,-208.619115,-264.369427:-145.923723,-107.062471,-36.95476,97.688717,113.354585,119.738294,145.488109,151.352911,83.023442,66.100451,28.019645,-14.266432,-104.325839,-112.493516,-24.922437,31.786384,139.318472,299.337144,355.557081,320.994233,266.715849,179.780205,139.702078,52.018848,46.767155,79.955202,107.195341,95.785239,104.597265,135.041566,176.669082,158.641129,92.169313,93.992566,104.583627,68.414978,35.580196,19.555517,30.025923,6.106324,-44.050325,-55.73831,-86.846883,-107.102519,-124.849621,-115.262183,-78.867084,-61.933432,16.64859,117.289851,129.218785,116.992139,111.243269,77.872588,61.402621,80.02271,149.360647,185.571397,240.821048,267.819335,343.959048,384.17717,410.215378,402.539522,446.775613,505.349117,488.844711,413.866738,356.207141,130.351695,-13.554806,-213.972321,-237.652188,-224.711711,-227.517816,-233.193748,-206.710042,-185.648286,-184.616551,-194.938513,-128.467642,67.079959,158.606851,244.375808,232.236572,163.421695,152.330003,198.697834,256.774928,283.481063,330.076743,330.971417,275.176481,247.01173,237.288612,224.887798,214.348148,320.675912,343.991779,240.620872,151.527442,16.021369,-3.077026,49.02186,110.405006,92.644262,-43.888361,-111.57104,-144.539197,-116.54832,-16.668571,37.247647,127.92987,143.143514,97.585356,85.175114,175.19412,376.247608,399.245114,293.890286,253.756454,284.58133,285.093418,224.351043,57.091041,11.413636,52.382713,100.071578,187.200383,226.555226,221.094209,241.717838,279.364437,331.426532,322.789867,231.07324,100.92495,40.454673,-20.456671,-10.662971,-30.146895,-77.511094,-99.275637,-46.821285,124.037681,264.180574,277.334128,211.263334,176.19884,178.720415,200.393224,171.765395,73.928216,66.858107,147.332504,184.592934,153.943746,112.932488,115.352006,143.405131,134.50015,46.759902,5.215708,-32.62289,-30.546496,-18.122585,-6.340394,11.357489,-47.929438,-70.730971,-6.270434,57.894637,66.751168,-22.353218,-207.280333,-224.522296,-135.98238,-46.068609,-20.621189,9.125454,-19.445907,-194.153102,-273.39017,-322.428091,-283.572194,-228.418671,-88.715247,-41.568088,-34.53328,-48.527128,-46.076107,-35.215648,3.196573,15.73853,-5.191661,-36.668019,-48.688733,-115.055831,-152.974786,-222.989538,-272.79806,-244.31267,-116.685187,-81.685997,-127.591325,-164.611846,-163.327093,-145.655052,-136.244301,-59.429722,20.319841,157.707459,157.453658,43.359418,17.919422,55.999347,-75.822707,-191.980977,-272.83619,-223.333601,-86.467545,-30.838617,50.440178,53.308472,-20.650248,-14.085867,39.38843,93.010933,42.024403,-124.495988,-168.210667,-166.527073,-141.133461,-139.072376,-119.755162,-80.571564,-8.77101,-6.57164,-45.600168,-78.388133,-155.320747,-141.789692,-90.281567,-3.45921,-12.177084,-104.968931,-139.034882,-125.407616,-33.476764,6.688603,47.153737,77.330248,108.154978,66.443213,-57.857641,-90.229423,-66.602851,-11.721564,-25.445651,-96.019768,-99.06474,-40.036163,-12.834951,32.072366,76.384715,87.90905,90.943878,94.442296,87.256994,48.009582,-59.387864,-88.905959,-102.529178,-113.003476,-133.435701,-187.069681,-191.818615,-140.76093,-107.775186,-49.618308,71.759505,142.951343,203.852088,197.757118,114.593405,46.049077,-24.190258,-30.508952,-71.138814,-56.249863,-15.710294,59.800813,96.06973,185.569676,218.023362,193.609107,149.213808,180.480827,288.553545,309.122573,229.224364,161.658532,123.909058,162.908918,230.605339,237.188424,252.383602,292.675929,272.169364,177.774045,152.780289,135.207782,105.552344,93.776764,91.591531,118.841211,169.800691,140.269897,10.00546,-44.450904,-76.923689,-17.483104,-15.093764,-117.362096,-166.241313,-181.916804,-188.242288,-274.147365,-346.438615,-328.123574,-205.240831,-145.388382,-126.610769,-154.618355,-183.808118,-174.670007,-168.115979,-199.48213,-193.380898,-132.015004,-127.500595,-222.923583,-267.905047,-267.283277,-214.76436,-176.497592,-111.806046,-127.75129,-276.338384,-350.658663,-422.217134,-433.597971,-358.192735,-227.136737,-226.039342,-280.515303,-269.737741,-191.738662,-169.532968,-199.409217,-204.974394,-164.572516,-120.616258,-135.708183,-146.733452,-135.694698,-144.480171,-157.594282,-118.401582,-17.197576,16.851376,-9.322645,-57.627404,-106.648059,-90.694661,-58.026007,3.922717,58.385415,92.896005,43.444592,-65.397379,-64.207196,24.68509,49.642178,35.859939,50.451793,55.398382,32.069278,12.429872,-62.844633,-127.723961,-262.592042,-251.059143,-180.569036,-66.518983,-61.404477,-132.485818,-179.286098,-268.048721,-317.893707:-163.9057,-15.935854,24.515405,25.491691,26.728303,65.629014,82.902785,49.445009,-44.848875,-81.010589,-126.543713,-139.372009,-142.258685,-140.705985,-146.735851,-137.529306,-27.853283,159.350565,237.375835,291.836764,241.566583,38.617385,-60.258308,-150.006494,-39.849396,45.289638,154.336199,157.673733,82.442836,54.079659,36.908724,13.141961,5.77611,115.918259,136.105424,19.198237,-71.803661,-179.787188,-175.386657,-137.774008,-164.069289,-170.006044,-114.157091,-83.921786,-108.562268,-133.45763,-93.620829,-48.973688,11.822556,68.683913,104.425061,129.726953,97.83677,4.886114,-16.169735,34.448823,192.58215,273.273593,371.625034,401.734468,455.038863,475.342419,478.750699,466.64795,531.997303,674.502845,667.676219,482.453583,381.219031,242.048766,171.009627,-3.035152,-107.118374,-100.57021,-14.49547,15.561302,-26.521765,-75.826475,-167.893451,-196.17025,-128.874352,52.539623,109.763382,144.447436,152.867403,183.791463,189.595819,147.462721,119.59695,141.625184,214.405077,226.302054,145.872658,96.646797,96.209117,105.266972,71.801396,108.915661,164.647685,203.666671,151.154942,46.167313,50.208992,63.25086,28.396009,15.976762,-49.118816,-100.076196,-149.067182,-129.178495,-65.84404,-41.061298,52.711688,138.849023,137.025698,152.445726,188.680856,232.546212,223.980727,172.937405,197.648382,239.512472,250.538388,207.811688,77.904779,22.969126,-25.999684,-25.992022,58.483713,180.498234,187.482221,115.461487,69.153692,11.350084,14.921879,54.877842,58.138912,42.345216,13.527526,12.400708,-31.048577,-87.689255,-155.529523,-145.049879,-58.781668,102.389732,164.772466,153.525166,99.881521,27.942087,28.804682,64.49886,124.327802,167.378141,236.407523,238.951023,194.974368,169.473946,101.215429,52.506379,28.215728,136.993045,181.160767,151.116332,71.180637,-95.477131,-119.346755,-72.862004,-10.659821,34.661171,146.987054,170.413867,48.773989,-78.644481,-270.796658,-261.133469,-77.644167,9.419312,-0.860153,13.691397,4.39241,-139.152869,-222.092641,-309.033159,-311.156339,-258.287934,-58.088205,4.73683,-67.115702,-149.406261,-243.023059,-236.475344,-121.151518,43.891148,95.899281,107.766196,68.587161,-75.752765,-156.683025,-263.595028,-207.643588,-136.630863,-68.284021,-88.640608,-173.880462,-210.258523,-209.581237,-201.205414,-226.234381,-120.358396,-15.943071,85.554735,58.024631,-26.783703,-53.2189,-103.27405,-139.430683,-143.707558,-140.463095,-120.284885,-37.399638,-4.65709,-14.061669,-46.996848,-34.491785,113.032428,153.896179,107.557837,59.345731,-21.865746,-51.037743,-77.539431,-59.036118,-30.613232,33.540166,46.5243,37.290962,33.784828,9.103565,-14.024053,7.003893,43.270672,17.292275,-61.035484,-97.328544,-128.473855,-114.213759,-79.170517,8.811897,75.647126,134.697801,116.957696,49.322283,13.308689,-68.184556,-102.593648,-70.514286,11.170758,7.687064,-3.376806,22.590326,75.640284,73.701169,14.06555,19.96724,91.172773,233.286842,231.015073,121.745162,61.84108,-42.440372,-67.538306,-37.298027,-14.143885,-29.110318,-30.29885,-15.435906,-48.514755,-87.343808,-81.416993,106.917716,220.430853,323.113226,283.347085,113.769677,60.480106,52.358678,46.280209,2.043756,13.831924,42.891279,96.550197,98.719336,77.790219,80.710856,100.744323,135.629203,186.13508,291.833653,289.812131,190.798057,156.286094,143.860664,134.172886,160.407876,249.988423,256.30407,196.264132,153.225618,39.779301,-20.625017,-82.089327,-13.628456,48.003237,133.623827,144.129244,79.315978,14.149603,-85.80382,-103.392621,-70.395683,21.069196,29.561221,-48.729635,-105.503256,-223.75915,-276.626774,-303.696812,-165.463984,-80.208777,1.859437,6.431816,-28.060358,-60.629602,-83.918161,-68.636617,-46.1061,-25.923611,10.664902,60.259754,32.160628,-92.667972,-153.7109,-182.222153,-33.771123,52.792938,107.992215,74.268598,-62.467439,-140.206024,-248.035063,-265.499648,-228.620307,-157.913578,-128.473582,-88.927738,-85.23921,-77.946216,-69.769511,-109.234404,-114.241214,-56.99658,33.920238,19.319864,-71.514206,-119.056058,-200.633632,-216.622776,-148.571155,52.603867,140.820187,132.718523,63.721683,-24.916712,-32.652575,-64.667662,-63.336932,-11.010051,92.633121,91.894435,-20.868779,-96.317952,-174.036938,-154.799297,-34.494326,54.363043,42.845823,-48.674212,-99.856014,-168.495455,-163.543168,-124.541575,-153.771429,-161.153782,-129.611751,-118.540329,-137.157162,-162.10171,-245.036976,-298.79739:-58.528753,15.072973,65.92358,111.490985,132.481519,212.799977,249.655715,255.271183,232.891298,218.664798,130.492647,102.974609,127.733708,106.172836,7.129324,25.139725,226.576911,406.257917,435.745563,413.517132,393.191954,391.407087,406.818803,383.043298,336.383225,352.45256,375.831113,364.145289,356.044389,351.119125,323.841409,315.268791,328.547072,399.10426,415.3347,356.194839,321.419685,314.241772,320.302194,293.873526,232.653387,184.458629,61.604245,33.204052,72.129479,100.862009,144.222164,168.545407,213.023652,250.021679,256.218044,201.02809,142.150675,42.212345,32.660488,63.694468,90.122186,91.196567,61.973093,53.266314,97.90617,142.778011,224.592171,241.157148,222.027612,166.758174,144.62386,168.560159,177.084828,23.06392,-113.170773,-279.468154,-311.192757,-348.280986,-462.633945,-502.541714,-501.709323,-446.125944,-236.541854,-150.781266,-116.558633,-89.583416,-38.015625,82.342821,120.730004,134.942959,131.074666,99.935533,27.423452,11.706186,11.91621,-3.089514,-43.342282,-40.41952,11.273192,27.85411,48.880591,84.042957,64.812752,-30.413753,-86.73501,-223.207371,-272.640509,-285.008452,-283.66776,-314.685124,-429.550125,-475.797161,-471.25681,-430.607772,-342.193695,-312.914644,-271.938072,-224.473735,-208.132792,-142.572154,-70.525693,73.450913,97.501355,43.605252,18.100809,36.413729,-4.796723,-76.240828,-149.181799,-112.414468,4.026967,17.810858,-32.997662,51.341043,148.867627,302.401954,336.585009,343.163114,321.762517,202.320402,18.027239,-42.557942,-42.325652,-16.444213,-56.841626,-106.948298,-47.04951,70.099064,268.8564,304.092216,285.354567,277.207379,304.431095,349.065618,347.20919,323.592835,310.349073,310.37475,311.630109,309.074551,286.647576,284.138455,323.217499,317.819302,185.711024,75.581729,72.723398,100.142846,88.856284,28.976655,18.655833,-33.119849,-164.92701,-164.554846,-8.548673,53.654886,-37.600374,-150.990454,-265.027952,-241.996581,-176.14363,-177.613481,-176.062532,-135.983142,-127.364725,-142.544911,-153.953406,-221.564906,-218.099075,-149.280504,-44.638331,-24.294256,67.51177,125.852683,177.169319,186.57608,209.061745,170.309526,126.751834,87.418927,92.923889,59.395092,-5.145167,-194.088726,-264.028468,-223.041179,-99.627434,-60.837542,-55.049215,-62.360385,3.457761,47.105896,-14.511073,-78.054742,-8.215539,181.934256,203.471855,104.983827,58.267142,-3.841329,-122.399529,-186.35698,-259.819144,-246.72243,-119.639822,-50.209436,-13.360809,-38.576423,-67.459519,-9.494178,20.124314,-23.174529,-98.321119,-227.138897,-242.144776,-285.389469,-400.244741,-424.030232,-357.258431,-289.573154,-194.10312,-194.993207,-234.650917,-233.245376,-180.253077,-130.031409,-115.438695,-82.288992,-75.915844,-108.422759,-113.667365,-35.909222,55.755155,54.008479,-31.844844,-58.777921,-28.586804,-25.411808,-118.389046,-164.265709,-132.645194,-48.488934,-47.512679,-54.463434,-24.010805,40.368432,50.214959,48.143875,77.692105,119.902956,178.894148,164.909254,63.61092,-8.049369,-119.397764,-126.065839,-56.03426,-20.504013,-47.31595,-112.492992,-126.14357,-152.816152,-156.701172,-90.438413,27.916126,78.440106,149.320261,184.45495,183.712819,95.947735,-109.108563,-134.254279,-79.018029,-59.203723,-87.321153,-133.894922,-101.834242,51.686098,113.741793,108.738359,32.822641,28.134237,104.366753,147.511595,97.304545,8.227936,-90.068708,-46.640421,142.53009,222.242035,186.98252,130.569878,142.467823,158.652478,136.820192,80.865058,119.419459,157.457956,193.473599,218.606449,307.192728,338.471152,333.337403,292.408251,181.071091,124.146994,104.778959,7.482497,-63.984571,-150.007994,-148.915,-167.29898,-185.961562,-139.501028,-13.42102,24.516659,7.727327,-27.818546,-44.300132,-25.8008,11.870504,53.114033,62.839647,47.131448,15.366079,-116.488446,-179.841525,-213.974967,-163.112666,-119.060298,-57.956407,-71.971045,-158.076687,-177.987707,-139.405918,-129.380172,-145.368549,-144.034469,-156.09884,-221.333974,-241.161339,-194.196524,-145.89227,-110.932901,-142.153496,-145.339027,-151.181154,-155.650466,-138.620373,-107.72136,-45.965996,-70.168419,-177.624449,-111.223089,-48.490773,-55.259628,-103.860054,-103.737409,-56.616303,-37.097716,-73.407084,-38.731581,65.978181,60.783622,-48.001535,-59.280047,70.667559,127.078101,109.830188,75.766552,86.3165,60.929324,-0.316211,-165.25573,-240.301383,-323.160728,-262.767324,-206.308412,-158.550276,-153.372437,-107.115156,-90.660735,-138.608126,-185.419319:-149.324872,-128.241889,-61.57122,58.192995,71.980299,53.665646,59.406178,80.248822,99.324725,105.147252,64.900079,46.498642,54.767827,52.778004,6.308662,-1.894225,111.05347,255.174514,254.524967,169.104254,134.078717,94.512629,78.158042,17.417571,4.581269,54.505098,176.823283,204.22992,188.022342,175.091913,205.827408,234.444483,252.363275,247.969024,245.831357,268.45619,294.983252,288.539492,246.716071,152.518157,63.370931,21.583155,-31.060145,-33.450026,-5.53423,2.231515,4.292381,27.0022,119.020973,181.365968,179.959822,82.504006,-8.352907,-133.985235,-115.017078,15.7442,77.872486,56.848251,-13.808305,-7.202826,67.861608,83.361911,50.76052,28.40652,32.92089,88.111673,99.605398,100.891133,88.586509,15.795273,-40.290282,-195.746402,-252.731675,-205.718384,-123.099135,-132.154885,-152.623792,-130.13842,-60.621267,-23.316731,82.932338,201.045344,243.371577,248.621597,204.569006,165.447611,217.722344,306.287465,258.232882,245.812488,243.904833,224.19233,188.623062,189.082374,173.457263,145.239294,126.786281,147.254486,115.615054,25.737607,-1.478648,-72.036856,-115.69849,-153.996135,-105.046896,-78.154789,-103.640543,-155.745408,-267.475672,-287.003699,-198.56992,-133.782658,-84.914129,-75.985807,-57.382242,46.031495,129.314136,260.41757,268.502788,162.039711,63.122748,64.078003,90.76163,104.036332,144.33178,153.156011,155.918746,154.795936,133.675348,154.37535,191.807448,283.69339,314.272032,299.702369,261.572283,143.841356,3.077843,-35.478007,-24.6603,-1.773258,29.829795,42.947052,55.46229,57.874563,130.90684,265.243642,301.019389,315.468588,299.564933,181.27153,103.125048,16.889719,71.857349,131.172637,195.934506,176.653571,69.655141,40.650748,122.907818,163.743828,99.668537,4.663552,-18.997175,-39.589467,-29.889786,40.434258,91.716543,115.898351,0.0741,-58.412936,-79.863062,-18.66339,105.135248,93.646899,4.293013,-9.300915,31.519758,30.266431,-1.679715,-80.197621,-131.822907,-243.851259,-272.376973,-266.958646,-225.970408,-202.754352,-117.997902,-35.81035,82.562266,70.251134,52.21643,93.144171,158.349647,52.34584,-63.356384,-207.84472,-174.974846,-69.943899,-74.635508,-178.485685,-211.102408,-157.114616,-40.640427,-21.909212,-10.629953,9.848613,89.484874,109.011048,54.099737,52.331496,99.858835,234.148267,287.310381,276.068007,219.019162,105.32804,-32.783656,-139.643242,-281.553814,-255.56242,-129.758782,-99.060637,-103.748414,-141.947854,-252.320688,-241.304684,-200.000834,-133.906863,-127.973523,-156.71641,-174.245879,-234.142147,-259.646989,-221.463634,-117.099768,-89.527976,-98.364422,-111.381113,-121.406089,-125.126629,-128.599322,-137.470129,-132.818812,-82.690113,-72.138525,-125.131545,-149.393316,-122.16097,-19.039061,28.079454,73.54166,103.17958,154.117859,106.323958,-114.824116,-181.112004,-94.780505,24.997135,16.860061,-65.148703,-97.242134,-107.842595,-78.922416,22.992301,63.667403,58.188304,57.27145,61.509929,0.853268,-62.939738,-123.63591,-112.642174,-111.963457,-188.83404,-230.355813,-221.010651,-170.079324,-65.391803,-29.06556,3.942255,33.650195,77.589803,143.064547,128.144308,32.393245,-18.783554,-52.325053,-28.357646,39.451915,36.866235,-3.177625,-17.972603,56.996424,220.216851,233.807773,187.119946,198.627502,228.350161,267.598162,256.672061,181.043604,143.436599,142.466995,173.754105,230.964463,233.067883,228.908506,269.083118,303.135708,326.258589,291.860409,145.475179,55.448733,57.901868,94.870996,115.567649,152.26218,173.106143,205.420529,184.35982,109.908782,103.983016,89.267251,-13.434347,-78.706399,-157.075679,-172.982922,-224.264465,-208.760494,-167.49021,-116.262873,-104.97464,-67.949375,-31.924558,63.151131,88.187062,60.380177,36.192078,47.25682,58.479911,31.607196,-60.083448,-98.78196,-204.32869,-248.065841,-182.171805,-49.494224,-49.460266,-136.466563,-172.958777,-175.853816,-172.868195,-187.9744,-156.452667,-137.215789,-152.652498,-172.403681,-174.136119,-171.552425,-230.453092,-289.011218,-270.531219,-217.347049,-211.063861,-153.517777,-95.867132,-57.439604,-100.543459,-187.68077,-148.237009,-100.109763,-66.380475,-86.693632,-46.904598,23.365979,67.0893,3.508946,14.230665,80.400266,86.377904,16.277845,-31.824482,-41.158285,4.632913,102.642456,122.088495,119.963503,116.200472,82.05017,-38.869123,-96.291978,-222.511664,-249.952353,-201.630675,-127.257536,-116.080493,-91.837293,-93.350281,-180.600431,-246.691234:-83.960076,-14.90419,8.301597,28.946705,61.7177,174.408066,213.842548,178.730039,85.448012,72.65779,72.20895,40.979867,-98.322193,-163.421437,-143.829799,-40.947407,246.265603,417.369786,413.838285,320.518704,287.42244,283.745181,285.91826,234.057502,163.99047,164.009337,207.352369,226.575522,230.365417,213.039898,146.582146,103.111827,77.144831,145.322627,178.074531,208.472493,194.254732,146.449713,150.271747,156.497735,51.668805,-0.673433,-31.707012,-26.596908,-33.4566,-54.076164,-67.497756,-24.17765,143.820893,255.618211,251.683677,207.213187,178.461206,79.251913,47.739455,73.587639,159.244972,207.651403,270.565333,281.168907,247.364396,230.192841,300.29371,366.551085,463.621494,467.093567,419.146629,295.42164,233.762538,77.393285,7.138405,-88.542251,-186.034081,-237.89844,-325.151902,-346.247139,-332.993564,-307.053196,-247.721029,-231.221924,-207.393644,-151.696096,-109.880776,3.566303,28.383834,-41.129235,-68.026463,-7.470698,66.63503,80.234347,96.531517,112.054407,146.812559,157.478816,156.713046,140.543424,137.574571,215.500996,231.960759,157.962451,97.952721,24.138598,14.903868,-9.88292,-56.055173,-89.306061,-189.450675,-226.548868,-269.464867,-288.960056,-237.788497,-153.032062,-19.319625,-70.921498,-108.03386,7.910881,149.890277,320.039785,290.514462,134.376811,93.626065,133.452983,168.160014,117.694998,-6.141001,-11.888466,81.897331,125.316805,142.280411,116.257916,112.779653,160.776124,188.278297,195.985833,193.174863,171.022827,65.31621,7.715712,-53.130186,-64.739151,-78.894845,-88.422918,-94.439469,-68.776169,51.127151,178.025896,201.28501,151.904801,126.997886,171.004151,212.162619,259.840709,303.21435,313.000274,280.019396,275.08563,271.776255,232.78767,176.524177,205.154757,261.215247,167.102598,86.506586,-13.473919,-26.52312,-35.780966,-30.344042,-30.926314,-91.615054,-109.700975,-57.072824,-15.532526,-45.56037,-123.980923,-259.92065,-257.908249,-124.089881,0.977088,25.070098,0.053778,-50.881478,-187.24662,-235.883993,-262.800431,-191.600888,-104.070759,107.670893,156.445855,95.826703,55.947147,42.946139,43.212282,61.613972,92.187628,66.822692,23.55307,27.207367,-62.508262,-157.631747,-287.265543,-236.422148,-172.763124,-152.51585,-204.702758,-225.118904,-168.48451,-94.697926,-127.786161,-187.91173,-3.485984,108.446935,136.629162,73.65767,-33.076034,-59.400156,-93.951425,-119.181763,-133.861459,-158.924575,-157.102738,-134.563114,-100.468014,26.89375,66.850055,79.495341,134.471352,143.003415,52.969483,-18.443033,-110.059005,-107.843159,-107.766148,-204.247941,-241.55611,-224.054822,-171.919138,-56.220528,-42.604281,-82.135429,-89.879634,-81.613867,-93.701256,-93.666236,-71.488789,-71.96714,-79.150839,-64.818929,-31.675971,-12.766844,-9.056583,-25.142014,-17.45849,48.159962,58.652159,-50.612928,-140.588425,-208.824152,-123.557696,-115.946627,-169.718428,-163.15578,-46.213463,17.560899,27.269632,-26.404964,4.385881,82.395573,73.277998,35.233887,43.019947,27.296176,-36.746122,-150.562827,-79.418422,-47.418837,-108.881453,-162.719888,-198.360015,-153.535243,-17.985613,53.788742,91.074965,191.355692,220.629767,171.475865,117.81839,24.306086,-24.384119,-113.836348,-130.408977,-124.418071,-94.993465,-56.426947,69.246226,126.162688,141.769315,71.792139,45.176824,70.578038,107.290149,82.872692,24.546919,-36.377287,-26.169276,14.920591,40.310152,44.819535,81.205586,108.843559,97.007249,58.820074,2.560873,-12.568343,-6.764303,54.255467,110.84297,180.28096,164.292858,58.712206,-7.500117,-58.757065,2.012491,0.549867,-80.208054,-136.131698,-243.484474,-259.638482,-223.932688,-162.890266,-114.019382,-41.649853,-33.102151,-11.989822,3.980224,16.794557,-1.367807,-94.420147,-103.416146,-63.998635,-22.893897,-58.135636,-204.546145,-253.53808,-220.132471,-128.929109,-106.639,-81.177383,-69.478511,-131.038478,-211.867851,-297.142929,-258.796779,-153.960928,-184.405901,-224.008398,-261.76707,-250.629129,-169.301974,-115.68433,-82.590166,-135.249452,-132.787142,-76.189011,-52.213121,-35.513086,-53.066745,-141.297806,-180.441039,-129.017451,77.562052,153.190149,156.967458,121.090105,51.50473,12.882478,-70.693289,-46.56939,10.541865,49.337893,14.760062,-56.956513,-59.267308,10.642931,55.403398,109.14541,101.555903,71.416786,17.966141,12.298727,-44.302013,-110.96988,-197.825808,-158.009921,-148.230353,-206.058597,-212.552059,-134.535118,-107.977368,-158.515777,-230.249392:left
-107.578657,-192.398456,-228.117451,-194.308549,-168.591332,-145.257922,-120.335385,-85.029777,-64.279908,-29.525796,66.153966,96.527455,78.536799,74.203544,130.599805,130.666623,63.175024,77.003858,95.635129,58.624164,15.186504,-18.5112,-9.04589,13.85302,81.269503,93.278819,-6.373584,-84.115261,-213.424919,-225.532517,-120.376972,-62.695364,6.888734,65.113722,72.598043,6.914434,-61.402367,-159.037302,-149.874731,-82.206607,-51.087066,-59.823888,-101.334578,-101.180249,-72.124725,-85.397459,-157.85416,-149.546808,21.556703,142.641147,124.866747,-6.218411,-105.19959,-254.668392,-250.099199,-145.16768,-61.385231,-21.332162,97.536825,141.721618,94.0523,47.781896,62.412215,82.602013,65.312841,112.563746,155.440143,155.693571,92.909562,-60.343325,-82.458058,53.137719,254.027144,261.568251,129.486353,74.281566,34.400328,44.498636,91.614089,94.718952,71.975732,102.412504,116.556881,110.107626,98.463928,104.588061,149.603647,298.913918,406.687454,406.004452,299.295287,262.209783,333.557214,395.82665,448.621384,430.113723,382.674862,401.944559,415.620213,400.997393,373.916902,359.528902,383.867294,403.766606,351.334232,299.715239,140.04926,43.815328,-101.343579,-107.708185,-23.91014,6.513401,16.132669,30.271904,22.271943,-42.005159,-63.781197,-16.731287,19.833101,23.895537,66.877707,126.349408,226.767494,249.159513,222.635245,191.353892,183.832432,237.671373,448.994699,517.457973,441.648652,264.605891,218.712036,179.148111,169.507919,195.233249,265.808983,263.674369,155.366425,83.774584,-62.942524,-122.095667,-116.213439,-51.358303,73.616793,70.133173,42.376536,55.80264,101.886125,197.338741,214.977845,185.555634,129.664608,61.238155,-147.588598,-230.915837,-275.108602,-241.130372,-100.571288,-27.448857,28.943127,21.417756,44.628436,38.976029,-50.627012,-228.562591,-220.657227,-64.921817,48.465073,36.532962,-54.442819,-89.589158,-124.355575,-129.453493,-139.428005,-147.658671,-124.195386,-40.908336,-1.171185,0.369406,-54.017109,-163.4881,-162.058017,-80.446693,22.28929,79.854234,164.314845,158.009272,50.506611,-10.959134,-44.303384,23.211747,262.889738,286.086526,195.443977,24.902013,-28.400361,-44.088877,9.783045,113.702808,44.848881,-6.806432,12.705055,53.644529,13.580342,-56.82196,-90.256759,-18.722204,142.007907,112.170248,43.434837,-87.61367,-143.279919,-176.254711,-141.236902,-86.791234,-65.918674,-37.453109,-14.97344,-56.318598,-188.35901,-223.856836,-229.902891,-230.49057,-155.105012,79.285785,177.425797,206.862348,165.99246,115.37356,136.032822,174.595244,63.086623,-6.203822,-45.479161,-41.832864,-73.445681,-92.412861,-104.111795,-99.754998,-58.014684,-11.969275,-13.701818,-76.647322,-132.468537,-237.166257,-268.556422,-288.267403,-250.428469,-238.614685,-223.075648,-201.919987,-190.345358,-194.706254,-163.226589,-139.622991,-52.398472,124.23824,187.862443,123.479999,-3.866537,-208.869057,-194.818257,-18.401936,82.627902,69.782671,34.981196,51.998249,97.98448,91.378627,10.612936,-42.013741,-97.000159,-55.350079,-11.738227,35.323445,-1.998315,-107.775573,-125.719272,-117.063512,-34.08298,27.911838,96.255663,85.831963,36.573013,27.839255,48.602915,73.696863,140.089603,152.870989,130.596019,49.784799,-18.963506,-119.838515,-109.65882,-74.888627,-84.119878,-86.123944,-98.270665,-116.058753,-189.257526,-227.195279,-206.96275,-149.068177,-94.171003,-244.555702,-325.13753,-330.870938,-298.34873,-271.829997,-244.901028,-128.641053,-83.933921,-117.9724,-180.580455,-176.223292,-167.80852,-176.861161,-130.33671,-65.360963,59.34764,70.694983,41.399143,-35.35567,-71.938479,-91.852317,-58.381889,55.355072,132.330236,143.473884,132.326969,114.78199,51.610385,23.029175,31.971688,55.844292,49.385958,-34.451241,-68.647304,-165.161906,-240.773804,-316.011827,-285.753873,-189.98213,-227.091393,-300.910476,-413.491481,-411.278639,-386.881119,-406.747647,-465.506601,-477.982955,-459.005372,-415.964096,-384.855357,-301.725151,-275.814365,-265.897442,-252.433461,-163.865359,-2.497666,68.259799,125.6282,115.973108,1.861951,-82.7631,-182.02581,-182.992625,-139.072724,-119.367768,-121.672291,-166.605782,-231.283716,-343.230953,-332.118077,-228.439818,-117.728044,-64.569653,-29.92496,-97.933329,-365.777786,-434.94118,-256.817339,-105.876329,57.950983,80.675819,94.54231,125.355817,119.367942,116.502728,125.36457,96.996703,52.951037,39.900702,15.329259,12.250535,35.321129,68.564429,135.78754,123.186873:30.797475,104.42467,102.129748,-4.788334,-53.80478,9.215937,89.113089,164.106891,206.682381,258.139954,310.56815,252.418227,22.600447,-9.983998,190.368306,267.33253,175.512232,72.175697,101.565792,191.176318,181.133697,81.562287,36.433701,-28.653153,-64.16938,-80.056511,-130.738378,-154.581969,-200.886618,-213.978393,-179.40509,-145.035287,-83.115304,-40.78152,-18.79685,-14.178734,-57.787178,-144.410118,-143.383323,-106.694821,-89.933739,-90.752972,-110.999792,-121.956392,-99.026098,-68.685505,-38.179059,-33.174374,24.621264,65.612372,56.265612,20.900218,-4.756223,-40.675559,-39.633994,-7.578404,82.984976,125.167558,175.865018,177.719291,115.143214,102.127437,187.497567,234.832128,236.493966,192.171145,188.587345,183.738993,139.850728,-22.57375,-57.261895,95.986161,278.571392,275.03304,178.57175,137.511902,92.300429,101.289101,133.278517,120.355312,74.707667,67.04449,81.944151,134.449122,142.221849,121.801794,137.219218,256.695191,334.473396,304.176571,155.245155,89.385566,57.690138,90.243173,181.95092,214.077473,219.708761,139.580857,94.536578,119.361929,196.417663,340.449963,366.868777,343.865152,252.521452,162.878431,-42.178132,-101.955,-148.797152,-134.95404,-17.129046,24.213119,-1.168781,-12.463604,-3.074095,-45.335596,-87.209487,-100.587434,-66.164566,39.115465,175.463654,214.021223,144.916451,70.255762,22.545457,86.025282,255.777815,296.615455,309.538273,239.095741,176.694382,106.39224,110.152821,124.695404,115.761137,117.223459,115.476134,62.919173,-47.908992,-84.420191,-188.796032,-226.085364,-177.349398,-113.061655,-9.085313,-26.89017,-64.716412,-112.508176,-116.099227,-81.803132,-51.6458,-16.75188,-27.380068,-64.411719,-200.699086,-257.403416,-246.430458,-175.684103,17.13786,80.741123,82.131359,46.187831,45.210349,-2.457654,-64.82984,-147.1752,-128.489854,-9.774463,61.553657,12.369058,-160.26653,-206.573128,-244.902128,-257.034006,-201.007281,-139.47452,-79.533721,-79.789635,-43.601454,5.892826,-29.487469,-131.623462,-127.817829,30.612121,181.150962,190.159959,121.078634,58.033314,-96.526334,-132.289865,-14.960668,99.512932,240.357567,174.634379,103.128394,-33.866201,-78.702371,-56.592147,0.903595,42.475647,-33.04596,-30.267166,41.315331,54.415187,2.270104,-41.284298,-67.448867,-24.204995,107.136771,91.790538,31.713414,-80.818741,-136.460174,-212.845332,-191.161628,-61.966742,8.989913,3.822481,-45.034414,-66.106048,-104.436258,-130.420369,-152.583966,-133.312187,-71.523481,-26.932956,8.287926,55.893498,33.768079,-9.467495,16.919812,97.002416,51.330876,-1.927737,-63.683955,-65.022331,-21.354846,-0.586428,-27.665162,-39.925561,8.704711,-25.811928,-87.683596,-170.536193,-180.13257,-188.527345,-204.231958,-192.869593,-49.686578,8.516447,9.342939,-27.869368,-116.242014,-145.600105,-136.870315,-97.786555,32.129974,157.43754,192.088466,177.047088,120.794998,9.812963,-8.874254,32.37266,141.182429,172.808076,154.725702,120.529295,34.193152,1.237709,-12.109746,-18.501679,-110.638648,-166.171462,-132.609608,-60.661305,-64.935931,-152.107671,-198.685833,-179.672463,-76.962266,-70.126313,-139.261882,-183.926721,-211.112183,-157.644292,15.43012,79.912544,130.897496,89.764105,69.815116,57.837599,33.755404,-54.126788,-74.019814,-7.257426,74.15058,51.540341,-93.843944,-166.54782,-226.295192,-187.925535,-4.557745,74.79812,78.309272,-41.310227,-78.860393,-85.470768,-71.57278,-8.070544,42.858137,131.513083,92.599711,37.130794,-21.736492,-30.764362,-69.337785,-81.430882,-43.515848,9.968313,162.702026,222.343567,171.022536,29.70702,4.161434,57.4151,104.715666,167.348928,203.380798,206.594467,175.71171,161.132958,113.192018,67.243455,-7.264017,-2.035691,84.726677,130.783564,100.39034,-63.35918,-148.514708,-191.724605,-157.091598,-82.180987,-98.347453,-143.05528,-280.339964,-346.263505,-388.506635,-354.279717,-250.513314,-222.381655,-237.100654,-303.336869,-339.318647,-384.880184,-360.548831,-207.445779,-138.036501,-63.710503,8.665227,22.137079,-8.773271,-20.654433,-26.759908,-28.922394,-38.25094,-46.854869,-19.358738,-16.439753,-63.904963,-203.952933,-266.648375,-301.057486,-260.882819,-134.835536,-87.03556,-98.907904,-123.437969,-146.698352,-260.06259,-308.800263,-281.895805,-210.830028,-33.111871,75.314082,92.536721,61.87246,39.575017,97.451652,145.173312,136.722603,105.804419,116.960586,122.434601,101.188757,84.66214,106.753014,96.870857,46.46672:251.04658,194.73175,176.12418,157.211435,159.347063,199.085223,209.513569,211.651418,295.497195,340.949023,330.507817,249.600015,-7.286561,-67.679084,84.898381,190.075249,204.336211,41.608314,6.363957,100.695231,153.655743,149.411437,117.252099,70.912115,-18.70149,-111.242743,-278.003936,-297.560323,-243.046626,-212.208765,-165.317271,-126.658097,-23.075471,-48.019292,-91.964068,-81.371516,-49.261732,-37.291407,-49.09741,-54.698441,-26.004374,-27.606055,-52.925441,-69.594691,-118.798758,-103.658669,52.66676,121.590283,119.127482,12.960432,-14.829121,34.23145,64.811262,46.934772,10.719942,-46.298605,-5.966724,33.384999,78.854031,77.578496,113.336063,194.252485,347.580018,334.606886,189.120015,115.951728,122.152611,91.372673,34.843952,-28.964247,3.685967,127.721368,170.078952,160.724447,152.224707,127.258292,19.200213,8.015626,110.784323,140.297923,65.159485,-27.900131,-32.583151,15.6557,24.290374,8.347734,36.614119,181.672867,227.750395,174.289187,47.271231,24.130003,62.593629,94.857902,113.019721,111.323885,130.671121,44.948238,-26.316854,-7.435492,88.882478,250.010098,270.571784,274.519063,231.140593,144.115581,-79.152389,-153.392741,-222.613336,-216.525672,-102.53735,-37.281494,-9.900295,-57.371934,-67.210785,-105.406397,-143.939825,-154.007597,-110.896151,22.095888,157.204637,174.568868,72.693388,5.722978,-32.394158,-5.305477,95.040994,166.312877,283.047536,208.987393,103.406639,-103.562021,-133.046763,-50.651332,-2.294333,61.320727,10.247077,-83.019447,-256.567293,-306.165632,-377.905238,-383.039686,-284.243902,-202.78225,-70.51953,-86.297791,-155.37663,-296.020023,-300.978709,-179.661481,-137.171345,-182.667072,-191.773443,-164.259106,-210.819669,-295.760562,-396.586556,-346.50187,-112.010983,-0.396349,67.827925,-32.135404,-61.623988,-78.463138,-110.352705,-169.630287,-156.41203,-65.356991,-25.23254,-66.653147,-209.787306,-260.734092,-287.31337,-274.230934,-180.101539,-98.559237,-10.897345,-56.383934,-24.672309,86.015671,73.42822,24.191187,75.991397,255.982228,293.543897,248.029764,98.670749,-0.959927,-172.292625,-184.290184,-63.314202,16.656993,109.998702,63.813255,0.437283,-137.893054,-182.711375,-147.064371,-76.226268,2.161141,-73.919263,-96.784469,-66.582848,-58.206747,-103.772781,-125.950744,-63.839513,13.339764,136.257008,139.930503,91.949849,-81.661144,-155.272922,-139.156813,-79.276645,-44.052408,-92.521365,-73.146198,16.160344,4.530801,-131.938942,-156.638908,-25.183917,58.151768,80.2892,-37.227839,-47.750088,45.354174,73.465976,50.717195,60.37932,189.322381,250.130646,180.425379,-16.363168,-48.898792,41.84767,94.045099,80.049243,37.972214,-16.248357,-78.033977,-125.775431,-162.541401,-143.247704,-116.481143,-124.846122,-104.069773,58.833367,122.658886,97.273376,44.44938,-28.153602,-23.698116,47.111959,89.010019,152.259409,162.348887,170.384602,239.953417,259.093745,164.924655,107.331215,167.069806,282.156227,255.269713,167.7426,174.990551,166.651377,115.028345,35.167086,20.670407,-44.773701,-160.957143,-188.759,-134.510947,-89.167261,-67.456331,-77.290217,-25.241163,90.115118,95.880802,-16.914496,-86.950277,-136.235292,-83.324474,107.296197,179.161158,206.385954,158.369872,156.972346,201.856028,210.704441,149.968675,109.196955,99.58492,125.656345,118.249419,72.120303,12.984589,-137.608737,-125.861015,125.689009,242.389781,250.06997,144.814462,127.852326,142.690639,147.429089,139.428649,141.645718,177.664527,215.336819,194.990016,90.119598,51.715072,22.292689,7.266609,-38.502896,-34.906921,132.657105,303.019458,283.871452,215.839048,221.660136,182.491544,129.881743,92.178498,165.442745,178.273653,109.108046,64.024347,31.698796,41.648979,83.154929,123.091346,181.038903,103.517552,40.932596,-114.329253,-190.843557,-195.419856,-112.828535,62.930951,16.307282,-78.423126,-208.76916,-235.417498,-272.018761,-259.527687,-170.883718,-134.56602,-151.648722,-224.919863,-214.4778,-141.07315,-142.906659,-172.323715,-147.015666,-73.733538,-42.309031,-18.415985,50.546976,77.40872,87.202638,71.811396,25.588957,17.189739,46.576322,28.042203,-3.798303,-89.689045,-147.286076,-194.565748,-147.769899,4.10497,67.849639,54.647252,-12.164713,-69.643311,-210.143472,-234.225451,-152.052313,-95.809445,6.418295,145.179717,198.313044,173.034429,113.836846,53.557027,72.225982,135.173087,143.331846,116.438589,54.862791,30.041211,-6.745559,-0.163385,56.921675,105.308042:37.409888,-38.978931,-82.639879,-90.856703,-63.59739,14.323855,37.717096,39.717572,89.002765,126.697233,146.650971,107.632427,-44.267618,-80.026495,50.124289,143.317721,195.191305,91.591114,46.351617,33.321664,40.532395,71.143427,91.681147,94.519609,44.818466,14.414543,-75.476123,-140.130195,-225.5655,-216.473653,-121.274759,-63.451294,41.195017,89.567036,79.413069,30.19526,-0.334961,-26.198674,-9.184429,-17.424952,-120.332319,-147.998073,-101.027254,-57.307324,-11.640927,-6.196959,-6.113126,-0.851055,68.378729,144.603796,156.729047,145.34763,106.12574,-25.451864,-62.952536,-63.947994,-35.977618,-15.616973,30.313069,31.20018,-15.697919,-5.1326,110.826729,143.819772,117.424115,86.695831,71.078126,29.973712,4.354447,-38.13877,-28.481424,56.7473,115.94812,122.094917,122.351922,91.949556,-10.207616,-15.499928,72.003245,107.174272,73.826824,-26.960497,-36.911713,55.90942,107.307331,127.329219,126.007621,210.880118,320.479215,303.781573,181.602528,166.186558,253.91823,293.920134,298.262886,286.285947,317.504172,361.042068,341.370129,274.104465,264.14316,304.76579,328.352825,305.223438,221.599497,167.885174,42.678513,-17.891556,-147.282439,-190.35531,-151.347767,-106.307674,-84.811013,-128.223321,-144.525227,-160.977128,-179.676571,-225.685497,-229.437469,-160.774714,-10.692071,42.546042,40.048324,15.041575,-16.657654,-6.816963,100.205035,183.529178,300.861186,214.510268,107.686998,-102.191042,-166.309308,-161.439514,-103.679673,6.804137,58.747426,67.825704,2.308145,-82.882173,-279.1056,-329.998159,-279.652742,-211.349416,-58.684749,-32.066175,-86.31858,-145.300628,-100.808103,49.984631,90.579086,107.458341,133.525242,94.859857,-119.385396,-223.422612,-284.814105,-238.11087,-98.539861,-51.582521,-50.117146,-89.398176,-71.367774,-66.391872,-123.775297,-208.569628,-177.767941,-23.293915,90.72464,69.226715,-74.417667,-125.948476,-178.02034,-195.968995,-167.13889,-113.700343,-12.023442,16.000266,32.83484,52.637064,24.316462,-49.492447,-59.237637,-6.795123,98.444223,122.189689,108.668163,91.199324,-1.039973,-72.171065,-170.693558,-149.987599,40.233735,174.572816,163.359806,47.373779,-19.38377,-60.843351,-33.770156,3.641927,-1.549663,15.507266,83.3113,83.333081,-39.490022,-114.284527,-134.530691,-61.318491,138.759091,188.482091,145.172271,18.05039,-45.493859,-110.216239,-93.163384,-9.809782,60.976544,78.576413,77.189495,61.222038,23.187697,16.032583,17.110294,20.464179,63.844311,131.523183,145.758863,127.951406,117.958942,143.012003,172.30458,215.535767,208.872998,184.485781,109.654956,69.211577,40.187795,65.288158,100.464297,85.189674,56.257832,26.98862,10.926834,4.80432,-9.800776,-111.007425,-171.481473,-184.046308,-38.667061,10.455718,-29.069055,-69.718086,-90.872945,-82.486447,-66.93782,-39.430587,114.257005,260.407393,274.563183,193.555926,105.403349,-60.97622,-82.732,36.010327,205.067344,211.70774,126.623879,111.349495,124.666514,102.243002,-11.670196,-61.499846,-72.463048,-31.661054,-18.934809,3.760793,14.481086,19.320337,9.931243,11.180133,106.237482,147.289293,108.955218,56.707227,30.06775,65.020152,101.755892,83.821628,51.529833,42.597619,49.990203,90.353118,87.319862,12.915837,-13.92971,9.593272,33.092315,-1.824841,-96.078015,-112.818381,-149.481997,-172.373005,-87.472104,6.252461,56.209897,-124.523256,-199.460707,-187.695589,-142.200687,-115.389886,-126.791973,-87.500271,-19.185099,-49.047811,-171.920644,-207.124137,-247.476659,-269.028168,-254.459696,-201.872695,-30.176407,73.99653,45.188224,-56.321213,-73.711529,-36.387399,10.532475,95.948816,90.824648,67.978265,11.424993,-8.228353,9.803835,33.747582,56.584055,65.055878,111.310321,72.960145,-9.013212,-194.768223,-249.134413,-235.483349,-185.248815,-79.729716,-72.156555,-107.09174,-175.362562,-197.356092,-239.904098,-256.286383,-276.371212,-278.294156,-261.646902,-264.032583,-265.482122,-272.247535,-286.702773,-255.632605,-201.8174,-114.454593,-44.776716,-6.626375,54.665235,69.717056,18.456272,-37.869712,-72.011052,-34.725153,12.489116,-34.442487,-51.039377,-125.739332,-212.098602,-312.32309,-269.718195,-138.550428,-72.090331,-41.057543,-18.875893,-67.251626,-219.349077,-245.368078,-161.931648,-80.759112,100.894516,178.317699,167.722753,127.934518,117.145275,120.332564,126.153616,146.948551,202.721526,218.640774,212.433022,199.233331,146.465345,130.969049,156.382391,175.736338:146.594722,23.302631,-25.481841,-15.478686,-17.821355,-4.076953,50.538409,206.40896,292.955569,255.245131,83.345697,4.604085,-122.944396,-144.613155,-9.04371,108.804276,235.110277,142.658938,84.995312,69.897284,104.50891,190.478868,201.897632,102.940542,-47.74703,-115.536992,-265.146683,-321.703786,-297.464543,-233.200099,-95.689084,-33.282558,43.762168,6.17085,-25.298701,-45.405251,-36.764002,41.126808,92.876161,51.952316,-143.736491,-198.597678,-179.698821,-163.861385,-157.087409,-119.577742,20.991135,83.806022,134.355142,78.433959,54.235876,78.193212,89.216151,18.694136,-10.914748,63.243973,106.185212,62.991448,-35.071445,-52.940878,16.611653,89.4439,149.939681,121.599125,90.5995,78.072279,37.742719,-61.05062,-83.056076,-31.1059,29.381468,141.685807,156.478415,140.57455,113.833355,86.09359,21.268433,30.428835,96.830831,115.782232,119.078392,75.98902,59.263493,56.406171,56.059815,78.345643,119.330195,256.989467,317.832193,269.966902,123.516771,85.308936,114.307328,145.09371,133.036738,120.094576,195.263146,188.14602,111.969573,48.315262,99.273733,207.133827,223.888414,263.160531,244.72166,146.020998,-97.181665,-163.967264,-221.521151,-249.707865,-256.631501,-205.280373,-68.575518,-47.879438,-85.531512,-199.548472,-234.572435,-182.296455,-131.340973,-65.479284,-20.680305,-11.087821,-4.279502,-6.274481,-35.661322,-31.509916,49.099634,96.434274,139.394921,33.170878,-66.932028,-244.264827,-277.11577,-204.218946,-124.7443,-2.075555,-12.6688,-50.956385,-173.140547,-261.944275,-392.852076,-379.935722,-213.462225,-105.846233,48.650819,22.875018,-41.341714,-139.281562,-136.797004,-41.596198,18.757364,96.543001,65.717603,1.808106,-189.597402,-294.880111,-396.126816,-333.952066,-76.606696,29.230986,106.388608,-12.363941,-109.376007,-227.419161,-215.40323,-105.820774,-56.801077,9.801539,52.206501,35.419929,-53.744498,-98.060773,-143.236046,-111.973922,60.746314,146.07276,153.331468,-2.900795,-16.515402,92.357155,114.788458,99.117493,123.140509,191.319572,163.764278,139.925604,136.540201,117.634423,-43.014838,-125.712373,-119.605866,-42.808371,96.349745,88.647497,37.810546,-77.787835,-107.45736,-50.516733,23.722155,124.594567,54.023614,-1.70306,-17.332853,-4.101193,-54.648902,-82.991562,15.473635,132.569251,304.586626,247.505903,176.38683,16.856251,-59.793505,-75.706467,-7.952866,121.100214,148.158305,159.045235,203.179368,197.370889,114.867058,81.574827,92.606695,124.234477,133.399098,50.775546,33.516684,56.174119,74.535098,121.523853,152.345421,231.995834,291.258555,285.433166,179.848333,117.482113,130.209242,197.321838,262.63509,228.907864,116.104981,26.053768,9.618414,41.66295,43.568225,-37.296819,-77.347882,-50.776609,113.756651,177.795661,162.351259,101.937728,-9.891658,-26.569772,6.411832,53.693029,218.211915,303.613421,291.143894,224.656009,161.540275,33.794794,14.095999,100.008524,193.783859,173.240873,138.858442,160.970916,130.299914,48.211654,-99.255714,-99.817209,-30.044914,-64.461418,-85.70314,-59.268225,-38.564256,-4.406373,24.621059,126.600594,212.267592,187.563559,44.374455,-6.668687,-8.337876,35.004399,157.921001,217.381417,307.160812,280.348367,217.128926,94.44083,87.94818,178.272766,198.683099,145.068129,179.25337,213.971927,128.952865,23.434551,-90.715963,-54.798618,102.905643,170.716007,198.494397,107.259587,73.172538,78.472642,100.195026,133.32977,128.150173,107.661899,90.291958,45.856169,-62.404113,-114.444965,-230.720667,-245.863264,-161.41851,-121.770623,-47.056905,51.812047,48.897645,-43.188301,-65.658689,12.111905,76.906434,128.492028,107.618744,95.336821,28.391843,-21.250108,-63.487192,-37.03851,83.355073,153.454901,241.22278,164.294586,48.300136,-265.373944,-380.984827,-332.652646,-201.213868,4.915327,-31.359353,-96.875152,-188.771177,-218.476959,-252.457432,-241.321574,-191.699045,-165.523852,-134.533212,-184.381999,-219.665242,-264.486046,-275.041206,-243.087521,-193.055505,-70.367695,-45.173518,-63.349469,-29.97678,5.082889,-17.982235,-63.883,-97.441346,-69.619714,23.314138,52.918358,27.310696,-89.710778,-164.701433,-236.84924,-193.514649,6.668507,130.284943,126.434698,50.669134,-17.425673,-163.214362,-167.907149,0.059612,79.826119,95.897303,123.898675,170.967891,134.607443,43.920301,-48.308318,-7.664852,141.005459,206.440793,182.459695,106.965726,80.035615,42.430872,62.785309,197.563082,253.548341:-196.468622,-227.710337,-245.012849,-249.486146,-225.742127,-155.964259,-123.335563,-119.868922,-172.640433,-174.220839,-110.728721,-78.143372,-69.882993,-56.603251,69.837155,128.587638,115.000652,60.598949,57.396474,48.459485,32.590088,34.539304,57.75118,90.995588,92.378321,78.552743,29.123817,-3.142417,-82.068185,-100.194984,-53.979847,-6.698157,121.227541,230.623866,227.350513,105.969765,19.660772,-88.521166,-89.217702,-39.029992,31.789224,46.193069,-10.496334,-41.895935,-42.826961,-50.318572,-89.028143,-66.617075,68.430317,143.873945,140.117795,92.946368,24.325322,-170.575527,-226.269344,-208.9548,-106.657786,-54.302079,21.531795,28.151902,-57.708202,-101.092188,-78.445016,-58.2568,-15.839072,134.197854,185.249136,112.772475,24.731664,-61.588942,-38.798516,58.920423,154.327346,163.257616,106.277429,76.218363,40.517721,42.617399,73.841744,67.684955,18.662943,7.880348,17.843632,49.795377,83.574111,226.968902,301.225387,354.583414,350.296578,337.196131,283.468002,278.777554,370.20932,435.32697,478.699615,439.589221,372.913063,432.207805,461.350185,459.070588,458.73594,519.085917,558.00786,559.82352,474.26648,423.167158,272.505548,160.859522,-29.90357,-56.105667,-34.552814,-43.881296,-71.833443,-25.823496,-11.881669,-100.104589,-181.180262,-224.806286,-164.3842,-57.764767,-97.886599,-140.115744,-96.264375,8.553936,148.955293,110.752843,-25.988657,-15.621885,221.128697,348.641521,262.072709,3.964973,-64.829195,-23.827222,36.772834,90.360581,125.287452,167.112628,190.201171,127.940843,-104.199935,-193.617758,-193.813427,-136.252626,-17.508196,-13.948802,-61.155773,-85.775194,-15.069312,212.077042,292.175095,313.897452,224.089975,148.359467,-56.798469,-159.303831,-248.007022,-223.737585,-115.068206,-51.556136,69.147071,70.105909,20.972665,-79.677464,-124.335557,-227.167855,-248.403428,-103.029335,133.799568,161.157773,30.85498,-39.136375,-87.03866,-86.069303,-83.321088,-92.234959,-132.134206,-137.237918,-102.979529,-52.543458,-98.273159,-252.415527,-278.23794,-195.224598,-31.330513,31.042103,41.870144,-5.133369,-139.935682,-179.024945,-120.026815,-35.200448,148.719301,205.873259,171.058275,31.770556,-48.542203,-91.914113,-8.655003,200.366446,169.104395,84.884783,8.222249,27.050158,-0.03876,-66.250204,-140.92676,-101.535823,35.469738,83.275276,76.224157,31.500928,0.335379,-49.122368,-54.990932,-21.753832,35.566213,50.556912,33.640081,20.064537,-27.782126,-69.370371,-125.122916,-105.926966,76.843308,280.490782,302.302286,233.989747,214.165397,244.106325,261.640293,244.906624,180.549057,149.920467,117.516997,113.441728,95.196693,68.256273,-20.309328,-51.588746,-39.238064,-30.983984,-31.056754,-37.876065,-80.011768,-224.321087,-285.011058,-317.138619,-213.413641,-168.01623,-154.265594,-144.324328,-116.124095,-129.958979,-179.741234,-173.769079,-46.613939,105.113413,128.251408,72.6715,-6.156171,-197.406079,-233.315478,-106.277842,43.783722,40.8265,79.321112,177.625587,268.688766,196.620276,10.743487,-18.902004,72.576762,201.167271,219.874979,164.433717,129.17387,133.733336,158.896763,173.294216,199.405195,235.131601,262.516862,228.888882,128.425186,107.720348,155.991886,206.006936,271.056425,207.243837,168.996841,156.481091,128.851255,-11.529725,-56.865749,-46.575526,-1.462395,16.597444,18.370434,-1.638015,-63.614463,-87.445634,-118.667079,-135.205078,-146.057722,-184.151694,-218.88918,-226.10006,-211.67702,-223.569787,-248.099583,-292.977814,-283.371815,-281.604216,-312.571466,-327.806608,-321.833547,-289.861636,-205.563002,-170.183216,-78.407262,-5.514009,-12.882361,-64.393879,-70.92153,5.408708,84.840242,220.317593,232.17525,193.357898,66.768171,10.257078,-64.923285,-78.622935,0.24397,79.161567,165.323909,66.103182,-33.418838,-228.864101,-275.344021,-255.63284,-226.468249,-180.338771,-187.337971,-214.114707,-268.133332,-296.911208,-381.075981,-405.765777,-375.064797,-349.8803,-337.749766,-309.40733,-239.127072,-100.778461,-119.332776,-249.887826,-280.342154,-234.690637,-66.471442,8.292237,16.146149,-18.546694,-105.939922,-151.147893,-186.036401,-183.346223,-177.201697,-167.123662,-153.120457,-178.862105,-245.06859,-314.393711,-258.679479,-112.057184,-20.101968,24.9426,35.295739,-36.69593,-255.512159,-302.498067,-158.110122,-33.577198,139.213666,188.797125,206.06877,244.833252,227.819404,105.47104,52.645456,44.613036,97.233127,108.917316,84.340622,74.296801,118.900896,173.780211,265.744342,270.430819:-60.410892,-142.416444,-172.008223,-172.947189,-166.940658,-118.977469,-71.441454,3.918653,47.602623,48.026264,-48.824338,-128.342772,-188.384058,-126.503198,81.11582,173.207036,275.16219,126.648496,3.09692,-49.362119,19.924802,104.116308,81.176911,43.124153,78.515838,49.058527,-139.979047,-231.414438,-261.286959,-206.46174,-78.855147,-24.845108,89.073092,101.489109,34.092661,-133.862773,-172.379878,-95.016844,-27.17234,5.49312,-20.804999,-7.639391,12.311578,-28.322027,-184.749493,-233.246707,-189.206646,-101.517881,129.802984,178.266616,123.193786,19.570697,-20.458599,-67.848937,-47.60675,43.232367,54.303925,14.438501,-38.194914,-33.288274,-8.559314,16.223934,78.049146,82.799316,50.342274,62.468251,69.726207,-15.894609,-99.662117,-140.311243,-53.74396,162.726188,194.077614,145.320581,57.826515,33.596601,-0.062167,10.886528,120.521232,191.041648,214.754827,72.204901,36.556238,85.847209,118.761232,174.080546,206.624837,314.661496,439.892156,418.30303,234.275239,170.854343,191.400345,233.02874,271.52207,268.223856,289.24693,316.801387,310.296057,293.428623,289.527156,319.058192,360.538165,441.038782,365.669916,252.777659,12.663425,-74.132274,-214.518542,-259.748634,-214.392356,-136.944789,-0.586039,-20.475726,-87.709211,-236.551297,-286.029276,-287.279151,-235.599127,-98.646707,-37.375731,-43.945859,-64.631652,-75.447976,-127.75993,-132.731937,-41.803291,27.772832,155.717465,124.237095,20.57255,-207.362358,-256.902388,-187.934273,-118.089544,-4.310806,71.994207,73.746637,-13.443305,-81.553446,-209.039996,-250.430223,-246.764766,-176.973593,37.862836,38.848714,-51.530804,-153.062133,-117.186232,53.609638,140.277257,249.324181,266.929674,228.33906,32.797518,-92.491586,-240.105141,-228.155576,-118.802726,-59.88683,48.768501,32.279337,-30.803496,-168.615033,-216.461183,-195.862737,-129.124459,29.904121,131.845851,122.659205,-18.063044,-108.23868,-208.697758,-196.401035,-82.600556,-19.344703,53.600593,28.168436,6.021385,-26.06141,-68.289062,-145.081695,-120.019808,12.5461,81.600489,77.851864,53.394905,20.812344,-131.016795,-191.266136,-125.137983,-13.692466,217.78326,262.695232,196.243147,-18.129282,-111.083778,-111.512823,-9.485126,195.772528,177.813519,118.067018,51.167017,21.55421,-117.479307,-188.482502,-181.106449,-85.161815,151.533945,212.21619,148.70947,-64.41686,-142.211904,-127.938958,-64.560623,45.746353,92.6446,89.559869,47.274269,17.538991,-17.420666,5.048441,101.113957,153.671973,277.895047,293.819582,234.348453,125.82407,119.725541,193.686673,257.696061,421.431993,495.322202,442.637401,280.909197,245.341967,278.191972,296.144786,267.619738,243.559798,190.533858,76.138171,43.26431,65.721921,56.639183,-38.444686,-79.336591,-76.0544,39.106058,71.517881,-17.30971,-96.13287,-173.022473,-156.1516,-71.825991,-8.462768,177.914873,290.321657,275.153537,134.892614,21.627812,-173.297755,-185.485611,10.775033,227.710521,214.349923,78.318643,52.434711,37.41608,14.127811,-20.724683,-29.49849,-56.636197,-34.099383,16.075042,82.463433,65.550927,70.827936,141.018266,290.792843,294.167157,241.711998,65.640326,-26.826229,-66.601838,14.271585,198.326246,235.457493,264.505445,268.450396,234.135993,125.802803,68.25578,10.561631,36.764982,146.467957,161.331757,96.820643,-52.561536,-80.1191,-77.585092,-71.895959,11.295681,90.657627,157.149179,-10.259329,-117.178904,-189.691519,-155.23536,-67.614921,-43.493087,-27.42558,-21.410654,-50.659615,-187.402141,-253.25014,-342.760184,-356.268274,-257.352777,-176.199909,-56.566355,-5.399924,-11.802989,-81.411104,-116.741162,-62.471535,31.288123,193.712171,191.567005,137.541058,-12.767398,-69.319379,-53.31487,-0.85273,83.409624,120.886181,201.196401,142.113826,25.85449,-299.356511,-414.058077,-354.104313,-226.107484,-30.340844,15.210874,-8.779557,-148.693437,-227.78197,-300.745356,-286.922564,-216.784315,-173.878239,-109.402911,-142.614428,-168.331557,-211.232284,-233.720844,-215.792143,-160.500829,-6.807291,68.561939,43.45567,-27.081712,-25.623441,-24.974714,-50.804989,-87.61216,-82.911182,-38.356165,12.561186,10.225083,-140.891351,-254.565021,-310.286959,-229.567735,-29.614778,38.999338,25.707592,-50.841028,-119.636208,-235.540932,-220.130916,-72.669857,4.133166,116.280768,143.067549,133.709543,96.165266,66.075398,43.899219,51.112177,79.429935,174.391476,197.718376,118.450886,67.326009,61.69727,114.664235,273.810664,333.79667:-158.436116,-168.582514,-182.262009,-191.251264,-180.521326,-118.418193,-98.328138,-168.726492,-235.401745,-213.672157,-107.452311,-62.798988,-49.204169,-56.011768,-34.053492,-26.198331,-39.651918,-45.399293,-23.217615,45.584741,27.509938,-58.631299,-40.70523,59.486321,51.431683,28.752476,48.881262,73.993182,32.463234,-21.198995,-30.583118,22.074418,131.693439,173.392543,182.045434,184.262124,137.536714,-45.577718,-102.124357,-61.558653,-26.55224,-57.179397,-112.289311,-121.123158,-182.734318,-225.038149,-220.116819,-180.472322,-103.388539,-95.574935,-132.512778,-224.810521,-262.542776,-341.660593,-380.666818,-434.28467,-443.725757,-423.349325,-281.841988,-197.826505,-165.091571,-179.346223,-116.886884,-68.122117,5.654513,92.681034,128.380614,145.177726,115.913208,19.570371,7.349596,120.760474,252.467948,270.825833,292.684407,314.474019,306.06786,307.610089,403.030841,425.161368,300.671155,168.700278,155.834722,194.056977,218.719,234.68118,232.599353,237.759019,236.647017,244.403194,295.633112,313.332624,302.620237,300.869707,341.992398,360.525079,418.373283,521.53731,523.548791,436.248026,410.030847,458.195239,510.207663,561.994615,481.308052,409.436221,311.2804,312.681892,309.91302,256.434008,94.007099,34.313742,10.389657,-1.623824,-44.512144,-172.002519,-227.153261,-221.869515,-180.091932,-196.598058,-268.536258,-248.675655,-108.441066,-29.197364,4.94182,-52.496309,-166.785912,-153.42069,49.234056,215.486725,187.859175,27.883357,-28.873062,-26.467092,23.703438,105.246965,96.528905,88.113671,116.342786,129.802223,41.181888,-46.250929,-146.226291,-116.25287,61.416233,132.42403,78.673482,-34.082021,-23.940086,129.15916,207.620771,255.93438,192.900662,133.699999,52.892876,43.549404,35.509311,41.880074,91.205106,120.850454,137.795234,104.766259,86.903943,13.868702,-38.205019,-67.372424,-7.048117,245.971779,439.285283,418.897072,209.534246,112.846373,20.133927,5.715749,-3.959835,-14.866494,-34.128489,-71.648459,-113.289482,-181.838731,-194.435956,-206.847994,-209.556672,-176.217128,-94.358699,-79.27572,-131.560526,-165.136979,-205.983009,-208.640219,-137.673971,-69.983416,71.04448,128.253185,88.860111,-59.972538,-103.885736,-15.028442,94.711363,202.247202,77.016342,4.167401,-46.319941,-39.927106,-69.357212,-116.614345,-169.438958,-120.593227,90.464296,160.000214,95.410938,-62.020292,-104.17222,-148.273834,-163.14951,-147.782043,-49.92602,-10.373678,-10.072706,-12.613555,10.578786,1.469223,-107.043887,-169.909998,-129.455537,180.21734,330.041727,422.987232,394.210113,326.173944,285.497207,162.431137,157.902729,209.399056,250.043074,226.582927,171.67727,130.847112,-67.21887,-179.223957,-185.765349,-8.374463,38.556949,36.681361,-6.353844,-147.153581,-200.540856,-215.715773,-208.540154,-229.425345,-225.9433,-170.282048,-38.459378,-25.126206,-123.34054,-162.516477,-73.265638,56.567143,74.073902,60.008161,16.720444,-129.784733,-161.210137,-47.145305,53.079466,41.886927,83.517366,171.982439,299.960599,265.774268,96.340726,58.154328,128.460651,252.135068,286.345437,279.562905,277.953851,345.688329,376.703628,339.829613,320.339018,341.850619,333.159867,306.604299,292.344522,313.221332,367.352115,364.363441,260.512849,128.299249,89.953298,25.642353,-32.10087,-114.267437,-73.31024,95.394504,120.675227,96.868424,107.958835,132.663298,143.751069,127.292384,56.216146,18.622182,31.090493,63.963636,32.273121,-66.349859,-96.222374,-103.761737,-91.583947,-81.88385,-135.780507,-165.348771,-148.486434,-119.041136,-109.008879,-116.095188,-106.538521,-93.143396,-55.540427,1.03435,40.147906,110.33879,142.038858,241.150599,274.99698,224.891529,176.166939,148.715352,-3.449615,-82.628558,-145.144642,-121.07076,-9.545596,31.724358,43.836946,-32.446728,-111.999919,-290.490105,-340.66981,-327.38076,-293.682358,-218.966055,-155.724607,-158.710035,-241.445906,-275.339731,-242.602295,-196.705903,-170.437114,-209.81889,-300.352881,-261.918315,-196.810438,-122.019077,-150.397994,-245.158419,-268.179279,-268.37861,-153.649577,-76.591708,-53.775853,-91.668485,-163.249484,-193.69699,-269.913458,-322.683964,-394.023407,-331.955266,-265.043824,-178.971129,-195.82024,-242.448117,-221.987028,-121.648206,-3.216422,21.844606,-35.611892,-79.956025,-145.876238,-155.665005,-71.408831,19.779843,224.63916,301.962712,268.409832,109.715561,19.843228,-52.709675,-31.436914,4.687286,47.280026,63.646399,13.330556,-18.085465,-20.8076,-16.814352,-19.459879,-3.179583:-262.830069,-231.888913,-226.564268,-254.041905,-277.606801,-261.872013,-234.118296,-269.724853,-312.118416,-267.401383,-140.053949,-113.56999,-125.103817,-117.504578,-75.176727,-88.293957,-152.804552,-95.321391,-42.053138,-35.55289,-87.393064,-164.172905,-156.324165,-104.861776,-36.22389,-6.058412,-39.343958,-116.546841,-279.30607,-282.950075,-147.424242,-77.437054,39.751557,165.158511,205.527975,157.800865,62.544412,-139.750969,-184.168137,-146.504118,-47.709222,-30.162516,-66.631442,-83.627586,-135.012376,-180.652853,-209.452407,-170.470099,-54.113621,-17.414793,-29.921779,-169.521714,-314.187254,-484.882945,-443.642889,-311.424923,-257.646453,-223.217574,-75.810263,2.867402,10.633767,-46.412605,-133.777861,-145.47385,-78.251189,87.346463,147.558034,147.488184,87.615538,-53.403053,-66.611888,78.283955,295.428813,335.650011,268.048015,243.590274,282.217309,305.482385,297.697129,262.478036,193.554772,195.008659,197.561403,206.29141,231.734473,311.22656,338.929311,343.827281,343.380497,332.562352,309.357604,338.314203,439.897877,469.336222,482.096834,473.362112,460.678607,449.762366,423.603973,390.582205,412.83646,487.046596,497.828754,440.684013,357.258276,319.487497,231.604196,182.878401,105.30114,71.869566,-45.10117,-107.919536,-88.052842,66.813417,104.309912,2.770575,-105.170465,-212.18543,-164.94114,-39.210835,-17.128612,-23.12096,25.217382,84.017169,101.227765,49.879235,19.308556,84.619776,301.621796,339.233145,238.238258,20.978363,-5.799194,97.090158,160.991325,205.177893,208.716541,200.185978,163.188772,141.229889,42.420572,-30.773854,-115.970808,-86.020049,78.772671,132.999933,80.544271,7.237772,51.753459,227.821273,272.505758,187.479363,43.860328,-4.303993,-75.712404,-99.08272,-89.240282,-52.325848,24.595011,37.746629,8.965373,-56.322387,-84.841018,-114.796163,-121.406743,-105.413876,-62.548607,84.726551,149.849308,109.15475,34.285944,41.275501,27.29102,-6.491904,-64.451561,-116.794604,-221.655791,-134.505386,-77.798148,-104.604914,-167.456781,-238.648588,-220.808734,-144.482039,-53.009296,-7.43932,42.423844,27.767883,-76.992259,-117.240316,-45.107116,58.799958,226.350922,162.042162,81.096899,13.577494,26.552729,66.729803,95.913219,131.425386,75.421713,51.906957,76.33105,101.335313,67.576141,2.697867,-100.486059,-92.107357,15.870832,67.509417,46.571227,-42.49316,-108.217811,-177.831598,-133.821954,-7.071665,-3.913696,-20.548542,-30.83078,-42.060871,-158.018698,-255.299754,-385.322863,-377.71208,-208.678728,51.898156,149.669462,226.070416,211.199011,139.744887,117.114388,94.981535,63.785991,52.930538,59.241081,58.690091,10.366211,-30.502348,-117.572336,-135.521591,-100.596684,-78.631315,-52.401291,23.775722,-2.163734,-181.154691,-240.081851,-209.768662,-172.15571,-195.95435,-206.725253,-171.523691,-155.143107,-178.372603,-151.431493,-93.951684,16.261187,50.790732,56.809719,4.981566,-85.476571,-244.102258,-230.14747,-101.242212,-51.843849,-60.305298,-32.081976,32.287642,145.872388,143.012735,45.611191,-8.280369,-12.71238,116.204675,166.515039,143.768905,90.68315,56.743046,92.570286,189.357091,326.864664,393.541824,412.135663,377.847831,317.935284,289.195536,238.821855,249.358943,282.031796,184.824575,133.662963,84.653402,47.966383,1.99783,36.873538,125.983061,120.784769,120.692544,158.665874,164.197038,117.645831,76.905142,-9.85754,-20.924604,45.468305,16.621377,-54.192515,-150.353162,-158.642335,-144.974395,-142.101256,-177.01674,-223.247893,-232.193642,-190.011802,-140.914248,-121.519841,-161.22563,-136.343234,-51.967841,65.901717,39.955237,31.231892,69.696945,90.88861,130.573125,162.122176,197.208227,181.088375,174.323622,161.748433,145.335136,64.501491,30.309457,63.291819,102.358434,116.005551,38.848358,-18.435312,-162.772276,-230.085441,-281.859818,-275.845375,-272.95639,-285.012185,-301.229814,-368.707603,-400.480523,-393.142965,-348.667381,-271.464672,-271.284117,-298.582876,-258.096347,-216.989801,-174.091994,-177.902348,-209.175784,-238.622538,-260.906613,-104.155053,5.725541,121.73134,100.630756,-69.324279,-176.853731,-339.686355,-357.332634,-229.935767,-123.714447,-146.582228,-241.329239,-278.090986,-246.769534,-166.219692,-55.670381,-29.791415,17.612389,84.818503,28.328747,-237.952092,-334.180727,-271.603701,-167.154731,-2.564292,60.363306,72.062637,54.921739,28.443697,18.251638,30.654161,8.592192,-16.269996,-1.683771,23.334539,4.82406,-89.871646,-118.673566,-68.038527,-32.181018:-206.642897,-250.475437,-262.585108,-153.798762,-90.233046,-97.75378,-128.361423,-144.505414,-162.88324,-171.401083,-135.433726,-108.796514,-87.999014,-80.496836,12.071254,84.584076,122.761168,14.726525,-18.524046,15.981145,36.293302,28.108689,40.898272,111.658697,78.169664,24.299481,-37.501473,-57.719141,-126.957756,-131.85698,-53.343068,-16.014865,42.560621,98.47303,95.02436,16.309654,-26.461393,-11.417429,30.679438,50.889242,15.087188,-4.628988,-55.711781,-67.417724,-50.926938,-54.172644,-99.781615,-95.035793,3.442233,24.476287,-21.417764,-90.204447,-99.832277,-146.078647,-179.500877,-195.221485,-112.895125,-73.880218,-69.221507,-97.184757,-144.854381,-131.044888,-90.631164,-95.886307,-33.093028,90.261267,82.290335,-7.328137,-27.623363,24.007778,81.156689,180.848655,202.61252,195.651011,154.677205,120.620163,100.726963,136.249,240.269049,282.085485,292.581812,181.909548,125.673658,103.559135,141.903833,231.91831,249.048337,262.426411,298.448854,321.401906,339.759419,315.387891,230.58729,213.896636,267.926081,300.295268,367.234166,466.834015,480.907158,405.825913,356.305204,341.170087,393.755217,540.857908,501.838399,391.812087,220.701373,213.458186,207.811503,162.644696,67.773278,46.628218,44.001252,52.377339,34.638034,-91.350884,-164.622152,-180.103665,-137.391114,-103.614859,-151.841301,-166.826763,-100.2576,-20.90725,103.405185,97.911486,-21.862611,-68.256964,-2.081472,76.075384,24.257718,-117.541585,-124.008193,-23.379631,17.437196,7.687787,38.265524,88.780915,138.412918,101.827052,-81.554714,-161.737726,-172.454244,-122.940745,-19.045666,-26.845864,-61.115807,-80.11874,-39.570437,101.899871,168.091974,274.198689,290.508691,229.566923,58.036609,-3.372932,-77.43829,-104.721704,-110.704355,-74.62496,30.303227,68.621081,58.015867,-23.684885,-92.604323,-167.920355,-124.838635,78.634485,211.841692,213.74532,144.666362,81.417082,-39.685803,-35.000282,97.952953,135.173153,51.023829,-36.39461,-33.932291,-14.00986,-40.78636,-152.045442,-173.815051,-86.520727,-19.726584,-29.398821,-30.687347,-41.800715,-166.00264,-221.350024,-150.693489,-49.261221,102.432324,120.221077,111.763556,78.534226,42.253738,10.282631,39.353983,78.930972,23.277889,-10.288913,-37.885843,-50.109312,-132.039829,-184.538055,-217.873648,-182.668076,-56.216475,19.298062,18.72179,-52.69386,-115.109226,-156.061818,-102.708039,4.29566,-7.466249,-23.766946,-25.889908,-21.318141,-48.032004,-73.662178,-63.343959,-11.537095,157.38084,296.024165,310.459872,247.909666,210.927091,238.737813,301.099655,389.611355,380.062387,344.745912,250.326523,225.273309,196.799625,173.034419,91.434799,27.317825,-91.298959,-81.468565,-16.341669,85.022352,61.463612,-31.784927,-55.84091,-135.135426,-191.209206,-167.707651,-131.607695,-150.671771,-215.487336,-225.079493,-157.345243,-96.647882,36.695383,108.386389,86.087004,-1.800732,-59.52092,-183.46064,-173.529039,29.189981,164.604591,137.874259,85.236862,126.877199,216.099995,207.830105,146.535465,112.200741,65.975662,136.67451,189.148228,206.069332,170.656252,158.488782,198.333345,252.644757,301.44653,297.462433,128.911517,36.575103,25.297592,88.460257,182.408496,176.760495,150.144075,150.405042,115.833726,16.534528,-6.187132,23.405875,51.751037,63.577085,54.906006,50.478787,-9.653707,-46.940042,-27.794734,18.646259,26.877698,-12.315837,-7.353161,25.753189,-28.851861,-162.553819,-160.063049,-57.184955,-28.5987,-78.91619,-136.664318,-146.400257,-152.15595,-136.489515,-103.036021,-103.483186,-121.090881,-131.907612,-99.096287,-13.832281,15.628052,92.790235,135.175789,159.359997,157.527712,205.103476,219.733202,140.658648,-71.423295,-103.50786,-60.641439,-57.895497,-74.439605,-43.76127,56.105093,-0.087168,-79.575129,-238.571488,-289.356893,-264.950004,-205.301539,-121.805893,-134.37421,-143.002918,-127.679314,-118.821164,-130.856151,-149.750161,-187.00211,-182.323268,-124.139813,-112.814948,-131.320683,-181.506128,-213.521597,-198.66794,-146.154779,-112.668838,-140.695829,-113.169207,-38.869887,-36.337158,-94.419304,-129.700259,-185.109965,-209.246406,-213.162205,-122.235379,-86.827774,-126.611283,-179.383611,-225.509901,-201.945056,-109.887159,14.917388,81.028847,114.789729,44.577681,-144.294916,-155.880779,-5.758587,65.274045,116.477633,119.88491,119.155235,91.683083,61.848014,19.475867,7.585287,-5.7197,39.699872,52.746887,34.252142,29.960813,7.251377,2.660954,102.648459,175.876473:left
229.084858,350.656563,350.965858,217.677585,138.376747,34.58385,38.781038,167.071723,273.081319,296.655908,345.400452,332.171277,151.459439,63.731374,103.248047,174.977768,183.729384,75.38455,30.403874,-29.427031,-56.022343,-121.063592,-124.734045,-22.309934,88.969039,101.10812,34.939439,4.91973,43.182733,70.898132,86.034851,96.471336,135.879505,156.904816,136.230564,42.276747,6.911165,29.202725,81.71133,170.633758,175.730423,179.409757,157.875473,113.779964,36.752257,38.93878,109.435695,124.716424,51.573444,2.009229,23.864949,117.640138,150.57076,80.757951,-0.578359,-74.132095,16.143953,78.684734,175.496503,198.423933,160.817376,93.740267,-43.10346,-62.486993,-28.282993,-5.165283,-1.875939,19.220235,25.676251,-16.118329,-32.299944,50.374936,247.305187,341.781552,450.420131,449.113586,334.300939,241.406686,85.040008,59.738391,118.643566,221.311917,232.092559,129.837163,63.306871,34.02476,81.94579,179.670376,189.246534,194.499224,169.606814,122.205442,24.887272,4.40769,58.893483,126.80424,230.91823,173.73513,96.264651,-9.825973,-6.32062,23.024735,38.948638,112.856524,171.736386,192.804348,217.061338,189.87001,51.63409,-10.186966,-20.851014,3.942081,32.768076,63.949424,51.627424,-81.188296,-154.380243,-177.530578,-128.597056,-25.984823,-0.697394,5.761788,1.630427,-31.366171,-121.696292,-148.24228,-137.718949,-115.401241,-99.567116,-82.889694,-53.096354,24.727312,76.49228,199.677967,238.174013,190.276141,25.784798,-44.402504,-106.214674,-117.703243,-163.970686,-202.004703,-225.214911,-179.447884,-49.33738,-21.371331,-34.290141,-54.27422,-85.577993,-177.303564,-189.499882,-177.355782,-155.111377,-87.484398,-12.271189,-94.762377,-308.443134,-323.291132,-173.588827,-89.626436,-3.218401,77.024049,120.053019,134.847436,125.953572,164.396949,205.127411,271.389562,374.352834,463.816237,567.028974,537.054465,381.752426,288.832762,147.534552,129.040034,162.486672,135.856454,75.087208,-18.963213,-12.822389,15.875448,1.317826,-68.288593,-126.520897,-126.7801,-107.872836,-110.619561,-174.508592,-239.753366,-314.848612,-284.622639,-219.639875,-240.119376,-238.970244,-210.900767,-213.291823,-261.120845,-273.89112,-224.792625,-163.640077,-126.616622,-5.765695,39.351577,-7.916287,-94.469191,-249.669239,-268.898257,-197.484879,-93.645636,-75.846817,-140.525249,-189.507526,-233.390364,-232.874191,-213.424307,-100.11121,-11.705483,86.212299,84.177604,33.87899,-5.107684,-11.430811,45.268614,134.058092,68.109148,23.537213,9.404077,23.056699,-12.429261,-62.585584,-103.30488,29.146723,122.594496,132.147662,29.574311,-142.563515,-154.032037,-136.813093,-164.621466,-248.357108,-179.336802,-127.557787,-141.818234,-190.807564,-309.892275,-359.335175,-403.70791,-390.775717,-370.413236,-378.20765,-393.364487,-338.713728,-288.231778,-223.095582,-206.251199,-160.306437,-49.93157,-16.958156,-68.548736,-112.148421,-185.285793,-241.588277,-347.992777,-286.968318,-223.803122,-232.586909,-315.365067,-471.731904,-489.224018,-387.686548,-326.452184,-341.594468,-389.591885,-374.515704,-347.498446,-334.05208,-272.051517,-227.993962,-154.215157,-70.471094,34.187796,284.60904,358.213595,395.471255,391.136999,387.035202,368.95882,304.697384,310.968977,310.244455,242.216837,200.02398,153.912492,158.042003,187.914822,214.624676,243.82274,272.216372,240.513237,119.961653,50.643513,-20.100304,-6.795299,-37.793636,-146.590289,-165.369145,-183.005332,-227.243767,-378.701643,-405.953039,-242.451109,-68.762904,-39.654888,26.657921,67.477727,54.936564,-11.537933,-173.799603,-216.743727,-163.229398,-33.890247,5.681336,2.688401,-33.574827,-157.433638,-202.928246,-182.405939,-160.387622,-163.621019,-175.823579,-206.909707,-337.326207,-397.473476,-379.984428,-320.754096,-265.992841,-292.285568,-288.381408,-286.26379,-325.73756,-463.543468,-504.684348,-498.275287,-520.78882,-523.268435,-436.052765,-383.411812,-351.982052,-373.490235,-392.468795,-356.114296,-230.559914,-129.948691,-113.944428,-114.496415,-96.204914,-31.926094,-13.661484,-13.268685,-35.737752,-33.148791,1.575227,-3.945127,-69.487239,-100.294441,-140.302543,-138.243009,-40.316382,74.352098,76.153848,33.388877,30.493505,5.495487,-23.101475,-15.020341,50.78234,50.30666,-71.498606,-145.299136,-207.22329,-214.814148,-198.389044,-163.67469,-77.360467,-57.063059,-99.20791,-240.754759,-298.705654,-370.525236,-383.345027,-315.988239,-140.300971,-49.967052,6.398588,-52.159124,-234.053294,-297.607874,-315.345258,-291.610894:80.92724,200.890237,227.23324,196.789033,185.738363,112.728418,37.828954,-1.841753,165.157908,225.429744,167.647392,98.846811,1.760345,-31.457873,-47.876325,-16.066637,64.797264,73.186536,42.277014,-63.49246,-120.701491,-166.416694,-112.974323,86.241706,154.759362,121.500188,52.15129,61.848983,131.927631,137.977048,75.868541,51.225732,98.482379,177.147429,163.422166,47.392066,-3.538311,-6.699334,34.114622,120.701045,160.582389,159.83416,97.809393,54.129159,-33.581653,-85.487448,-119.221266,-93.474242,-76.144925,-79.126977,-43.538813,65.595799,81.517391,3.039439,-24.204382,1.654284,31.215868,46.327163,116.560725,173.607545,217.226176,163.642621,17.116865,-18.171901,-3.582189,73.335127,101.957302,110.700218,98.495953,76.433693,101.667123,205.098203,268.824103,304.824748,380.895695,386.66988,309.013169,246.31116,151.196424,134.575933,147.695286,179.552952,173.272995,67.101752,-1.571059,-36.524711,15.221245,143.701581,154.096235,134.551304,77.251393,32.683843,-43.310587,-52.986471,-10.11423,23.513112,51.446579,-2.976289,-40.762347,-33.819196,-10.855405,-40.308519,-50.327686,58.939766,235.491561,287.495033,230.114519,138.505538,-18.108692,-43.281432,-12.274857,2.063663,47.210817,187.546083,212.547492,65.993541,-38.436441,-80.260069,11.329718,218.057379,258.860806,241.164304,126.619482,35.666461,-113.188877,-148.245515,-117.00959,-55.001116,64.321965,95.467093,80.190374,16.02561,-5.438579,34.995163,85.418687,140.432612,59.187728,-10.478118,-162.130825,-219.189288,-240.075581,-212.004399,-96.133669,-22.075971,79.083978,48.124585,-5.673106,-87.935703,-93.599109,-68.228008,-61.116565,-64.444139,27.489356,100.391361,122.877628,72.917696,-5.82259,-16.346044,10.662229,39.445495,102.991651,171.917935,176.145305,104.911261,79.1898,142.482626,211.949663,297.494571,348.755975,392.465179,407.609844,360.82026,200.2926,124.333302,56.438688,36.511616,14.868395,36.102536,-9.453484,-179.274322,-210.116705,-150.272976,-129.12005,-152.76546,-122.397184,-82.523621,-71.839303,-115.951691,-278.837303,-350.129098,-329.907545,-256.356824,-149.241189,-173.508315,-199.849583,-207.878213,-206.353719,-232.141913,-230.793473,-143.007112,-27.049056,1.953027,-1.29039,-20.851178,-97.666045,-139.50996,-177.158088,-193.017687,-213.90492,-161.188407,-173.139858,-325.437987,-386.988777,-371.904918,-331.261689,-263.055924,-165.536326,-107.046182,-58.333713,-82.004275,-189.342452,-223.722957,-168.915213,-114.34074,-43.953606,-51.664803,-91.245292,-178.32397,-197.525041,-194.866664,-176.148457,-122.902736,-32.032135,20.992892,-18.703402,-110.926799,-237.857768,-256.914272,-316.488406,-339.866078,-259.957394,-138.342336,-141.740209,-263.672427,-332.375763,-397.648825,-390.573766,-345.572634,-344.499662,-368.643418,-420.125807,-426.108949,-430.645165,-441.079273,-408.83494,-360.835166,-232.256138,-85.099932,-55.212533,-103.255339,-133.567685,-171.536925,-205.524155,-278.335563,-214.600285,-145.972797,-124.254608,-191.679207,-314.439342,-317.791258,-271.040559,-269.627855,-283.616409,-165.428846,-93.216727,-92.009022,-147.31399,-148.860422,-53.437478,147.390396,220.745267,254.831581,310.296372,316.406269,349.496809,385.159012,434.89161,427.284329,353.10583,266.700019,224.23251,124.105702,73.837779,40.803834,84.004869,218.630661,288.301069,302.208614,285.950014,242.616349,83.345055,-1.174846,-53.969496,-34.537932,-18.277807,-18.070235,-15.936033,-51.865155,-103.697723,-195.437982,-186.139307,-102.00138,-33.351215,11.5614,86.71673,80.025132,-30.355169,-96.369051,-144.715946,-124.795014,-66.628905,-60.752923,-77.300509,-78.279506,-65.134823,-52.000929,-38.942041,-22.256566,-72.766347,-87.031682,-58.328735,-59.035926,-182.021849,-265.507682,-275.467765,-195.92477,-48.660809,-51.283278,-88.849511,-138.934376,-157.25728,-251.456598,-292.8796,-293.642987,-263.874588,-233.201173,-149.659975,-145.963229,-269.688933,-341.131622,-317.469249,-235.696362,-97.437499,-60.329828,-70.718278,-84.430487,-72.468476,-56.176276,-56.206249,-45.802679,-104.558705,-143.213772,-159.186077,-155.995227,-144.80914,-131.838186,-112.599872,-107.421869,-68.170433,17.16409,38.311446,-5.102578,-49.589876,-116.677716,-118.904938,-76.088117,-44.107238,-45.719619,-106.90102,-165.294626,-285.072656,-317.533943,-254.77509,-180.421067,-85.771041,-137.97707,-215.617314,-339.504415,-346.666479,-311.395444,-298.952753,-281.191423,-195.813668,-116.991286,-3.842813,-12.749779,-163.707549,-250.680232,-276.180573,-241.10069:22.435884,136.238949,141.694808,64.92473,32.135525,13.507784,7.11632,44.439327,119.423219,106.265393,26.520573,2.985081,-55.764901,-94.863887,-85.118929,-32.86404,44.980032,49.231903,42.667627,-7.415796,-58.398065,-121.255214,-77.915375,99.529365,200.851461,196.70468,114.456975,78.615051,71.391485,96.89151,183.878279,208.961078,179.644922,118.530216,88.469502,21.570008,-14.191692,-13.591948,48.757241,171.021126,153.646633,144.536959,139.8128,105.501154,-8.92354,-51.005176,-64.052308,-60.392733,-126.684258,-230.739533,-229.250361,-99.725168,-40.999856,-16.923737,8.170344,104.434286,106.421031,76.610428,37.760767,45.398268,68.539539,55.858117,20.72269,29.651633,93.142615,145.72423,142.78872,121.662219,133.524586,182.200554,195.033184,182.222032,167.494219,179.772794,237.125343,256.803378,225.074432,180.27218,114.246414,108.050427,124.389807,128.617858,92.947375,-61.575934,-132.964761,-142.401779,-94.258629,-13.694883,28.038459,40.945058,5.626209,-28.025783,-60.09948,-61.021255,-49.343927,-43.461452,-33.407299,-39.346294,-62.726994,-87.742664,-86.759947,-101.506866,-91.750283,1.109752,116.638729,149.537839,94.040273,-0.345434,-218.218921,-269.006967,-175.670154,-80.73275,61.033112,94.6908,65.245748,-61.473014,-126.414196,-148.043746,-85.255737,90.055542,183.339033,197.551301,145.76663,62.029109,-139.822858,-208.921774,-219.662465,-157.64566,15.795823,117.243551,118.370967,61.47818,44.293257,76.060476,108.86869,124.29859,27.763515,-38.990615,-156.85688,-200.946401,-265.374091,-265.933292,-149.70132,-67.706059,11.061711,-55.769625,-95.932998,-105.04069,-87.071873,-60.303483,-61.562566,-50.048477,59.45551,105.985115,61.789914,-2.209019,-87.81949,-84.559343,17.872054,71.014223,108.778598,84.484219,42.231298,-29.051063,-19.856319,58.026994,101.665189,199.318953,261.352985,248.976821,189.801377,161.111302,50.926712,-17.430641,-44.337028,3.969995,120.942182,103.24759,5.902578,-213.60718,-249.292637,-198.847737,-163.488686,-102.399242,-63.60432,-67.826966,-119.468187,-155.021456,-229.921358,-252.249329,-241.56404,-222.583454,-168.079204,-106.829954,-91.872791,-119.940649,-166.737285,-215.705902,-183.305829,-125.386992,-97.393133,-56.975318,-29.004895,-85.371609,-241.386974,-269.186684,-252.976354,-274.587323,-325.78404,-236.801325,-206.045813,-303.00871,-387.963062,-440.06993,-376.694746,-187.014403,-65.892715,-43.846881,-79.350591,-116.758657,-165.109399,-167.460198,-163.453169,-170.228366,-184.370883,-206.605346,-215.325333,-154.8758,-119.58603,-126.090404,-120.853656,-78.268613,-79.494924,-76.952695,-107.715009,-155.7268,-229.254366,-242.233512,-286.215657,-325.113855,-332.349345,-196.534119,-137.319667,-165.442936,-249.855566,-371.255812,-345.392774,-228.34711,-194.682606,-223.597262,-364.413024,-427.830364,-409.949097,-339.921442,-197.794007,-161.155835,-128.510374,-118.066994,-137.072975,-142.587376,-116.33218,-107.139494,-127.281233,-128.755663,-79.560102,-68.02678,-76.24202,-101.018814,-213.603109,-259.637921,-194.531436,-113.848589,-45.046531,-90.076449,-86.93254,55.354533,154.499512,248.810981,250.758433,270.571712,295.495692,289.860298,280.102683,293.40987,312.350696,305.871085,292.733289,279.325619,247.320181,225.787961,183.255116,95.785052,94.913558,161.042222,218.964816,323.330394,341.687352,342.218554,310.965687,250.397784,71.748251,10.103472,21.131299,54.510124,81.996038,69.312153,38.86448,-78.207601,-142.080281,-226.202054,-223.564693,-131.830227,-14.526162,39.862545,63.192723,18.956817,-102.758258,-146.858676,-165.757856,-152.696552,-100.906916,-53.522873,-79.866802,-192.644053,-214.445148,-138.057757,-64.591626,51.450253,71.790181,64.7845,3.776342,-43.210386,-109.170052,-123.118409,-93.464894,-43.257198,42.045839,-10.305194,-52.751956,-79.234836,-92.467212,-146.972116,-154.68401,-132.908375,-131.188406,-142.125913,-168.012727,-171.04878,-153.936116,-130.875905,-21.795513,51.718575,135.778248,82.952037,37.723492,-8.068674,-17.75589,-33.788407,-16.876686,62.373085,71.995984,40.838443,-38.471078,-87.938365,-164.926939,-143.815298,-22.884723,-0.476257,-31.039447,-24.14812,-25.88972,-86.557881,-125.606011,-144.938096,-110.619069,-14.663767,-32.50664,-94.821734,-209.683765,-223.887265,-224.983681,-241.083265,-239.48829,-207.706816,-122.274774,-60.948228,-73.641313,-182.408753,-242.203887,-299.591899,-303.550345,-279.449404,-103.027328,10.208009,63.001305,4.752608,-152.421792,-215.543968,-227.644274,-186.416389:203.709255,281.416297,279.443418,179.1924,116.470731,9.741354,-15.198444,53.25516,155.50501,160.024611,88.628228,43.453862,-40.372977,-80.482568,-86.194715,-47.389213,1.680744,-23.446115,-44.765958,-86.755656,-105.84524,-126.948173,-108.428626,-9.571991,62.381418,62.102782,20.89417,3.627592,2.22599,21.117731,99.006324,135.803525,132.303315,64.960722,37.210538,0.738381,-4.655202,48.188295,115.944496,243.789575,258.658885,254.599412,206.227404,143.705129,3.104661,-44.594878,-35.112985,0.016364,0.802276,-31.859257,-17.362872,43.306649,50.354765,6.496788,0.860918,6.274107,-20.502033,9.395448,136.662704,169.544487,128.221836,80.175419,8.976924,0.601076,38.33935,164.44544,221.842045,191.796428,125.014038,58.64112,77.823711,145.553008,247.225522,306.42717,374.446133,370.019872,274.27303,199.541135,98.094944,88.763732,124.241638,150.255133,119.376911,-5.994295,-42.691873,-8.133444,29.907002,65.738234,58.021756,63.84021,83.247462,82.27532,43.723398,8.353308,-11.660671,31.665632,146.103828,152.282526,95.834857,-29.087698,-50.684673,-40.769696,-23.549932,29.611031,75.4966,93.649486,66.091499,1.336193,-169.501063,-234.374657,-239.109591,-179.931664,-47.392223,-23.642026,-69.268421,-209.745466,-247.320028,-190.101851,-126.159837,-37.849516,-13.012386,-5.644433,-29.29474,-64.845897,-130.434559,-142.690003,-92.012761,-36.232405,53.814066,94.992359,99.506681,104.502518,132.750853,217.980801,244.689379,221.119673,116.446463,67.925716,-60.531225,-141.959968,-222.545327,-215.607648,-151.884662,-104.549644,-14.022787,8.765842,-21.912308,-95.033737,-104.945534,-103.095763,-102.819794,-74.455472,19.429524,90.245256,130.875515,62.590228,-83.179879,-92.908063,-6.436944,46.988125,120.159136,179.199994,189.581715,179.13236,187.996131,238.518029,258.136237,250.837776,264.124724,329.411574,485.080852,485.966286,308.533689,201.143211,83.788896,88.742926,184.393776,204.198955,154.817453,38.132491,-6.540818,-85.535063,-112.60333,-137.283463,-134.291473,-110.039704,-94.992076,-114.017922,-114.682228,-112.851338,-165.587637,-175.863512,-124.494028,-120.011174,-147.384607,-156.860863,-130.648677,-105.263386,-118.839371,-160.46444,-132.86173,-78.511696,6.727921,-3.898721,-113.069139,-169.547304,-236.836816,-264.16773,-279.213711,-189.975881,-160.894815,-251.040886,-327.437308,-344.099353,-286.929388,-200.714113,-110.258618,-21.735582,105.713867,99.537229,-13.283802,-96.772142,-186.318951,-141.949688,40.318861,81.797725,34.390717,-26.275074,-14.850516,11.415902,24.642522,73.372903,66.111887,42.443392,-5.341275,-39.030605,-116.97053,-138.84494,-162.063902,-193.813802,-281.368466,-274.340686,-233.092854,-192.754639,-223.430443,-311.936946,-314.26865,-247.870767,-231.427124,-229.175999,-235.88987,-260.181046,-301.449191,-293.142596,-194.938349,-125.204226,-40.305264,-55.939857,-71.640216,-56.086263,-49.314856,-135.519133,-192.953155,-157.857688,12.603527,45.546004,-78.276206,-188.422612,-335.013543,-328.556768,-181.946331,-113.419757,-116.66631,-168.948431,-165.374982,-144.678942,-141.4558,-111.752754,-64.382777,51.193768,130.125868,184.053857,299.147025,327.620955,330.772634,321.105845,322.0646,338.532303,363.713626,370.277149,341.310908,193.005951,121.942405,97.765164,151.8091,257.002299,244.614666,245.381982,259.550296,238.333668,107.980944,15.794674,-81.212052,-68.387981,-40.217795,-75.915824,-125.219111,-256.229741,-292.476696,-291.672776,-281.219738,-263.161872,-199.432853,-131.630419,-11.92432,-7.962599,-101.865389,-169.972086,-258.937037,-249.855038,-147.533953,-65.584293,-77.175258,-163.750363,-198.776847,-196.899505,-152.563807,-68.115725,-115.74695,-155.238505,-175.031891,-169.742188,-210.712544,-258.808102,-314.043661,-295.447991,-230.606702,-212.967044,-217.834338,-244.270795,-266.338699,-329.914409,-350.635807,-344.086525,-334.336653,-312.427614,-258.449471,-273.016449,-345.770266,-350.257902,-256.629748,-173.170994,-7.955316,41.190053,2.775144,-88.716065,-89.651257,-33.133919,2.070326,106.633068,181.934259,181.770646,130.057816,75.03061,-69.507917,-97.583872,-11.179189,42.482606,74.832173,46.693686,12.612394,-71.835997,-97.390243,-113.324312,-107.506999,-83.267937,-100.408281,-108.36445,-125.896049,-152.772085,-208.496597,-213.927218,-154.921886,-115.05776,-75.652361,-62.716166,-85.888423,-197.780038,-247.371057,-326.911125,-354.250633,-314.253867,-185.898145,-106.694941,-27.299499,-71.202491,-219.453872,-271.986299,-307.100315,-292.502006:83.616603,196.050054,216.869167,117.143617,12.07323,-113.87249,-82.294263,59.383325,121.809413,114.701632,48.793837,5.638672,-78.437726,-120.564208,-134.498322,-94.83171,2.252036,39.393366,-2.306817,-150.263081,-192.454832,-168.672113,-110.802069,37.915146,112.90492,102.378802,22.869616,-22.669326,-82.153631,-71.46121,24.794261,56.068471,36.57355,24.588119,27.255071,11.441652,-3.867111,-27.404609,-20.510342,65.841624,193.991203,237.381004,169.556894,50.728826,-190.068423,-241.775211,-178.691967,-107.722669,-4.39107,-18.193755,-59.592483,-125.00301,-139.943087,-142.676684,-114.8607,-24.478035,25.562473,47.101684,83.382028,60.174198,-59.436205,-96.336547,-50.76345,13.278547,150.744908,216.271689,221.717468,226.329367,218.818508,192.62449,196.265906,220.170801,282.218371,325.531131,305.1769,248.15665,182.89274,180.31632,186.096044,196.377158,232.085435,194.035166,121.255237,-19.628707,-40.730254,-8.919902,12.059074,10.938936,26.58345,57.014765,63.922043,22.358416,-68.572591,-74.164283,22.58513,88.836486,167.796549,173.108379,148.224544,73.448605,30.461144,-21.528464,16.574716,169.924258,235.505252,219.724467,77.831829,-30.863204,-227.955085,-276.422061,-219.761949,-148.641215,-8.071126,102.773191,94.934184,-93.213274,-212.562554,-268.833033,-174.249177,51.889497,114.510567,108.391502,52.822357,-10.800071,-159.390084,-171.387268,4.685355,107.45123,167.750728,195.782403,235.803754,271.166114,248.286272,204.74057,235.046688,371.279448,423.811363,380.988545,171.555745,46.840673,-109.005196,-118.562167,-27.258898,52.636705,190.134971,190.464691,142.911752,43.614337,-4.312543,-80.000242,-68.354217,20.713886,131.203872,183.474466,165.180843,98.975045,-16.7888,-34.859951,40.925603,117.434817,251.740805,271.563491,222.105525,118.850423,111.268325,162.982377,215.026221,309.114207,323.395382,333.190061,371.776881,361.75139,224.383634,135.292171,36.844818,40.113969,145.735514,218.852199,170.920976,4.198982,-58.191863,-132.631219,-129.638973,-46.351899,43.908867,81.337366,91.339576,59.157774,-46.604124,-101.009202,-125.912929,-104.33733,-70.915137,-13.189035,14.852532,-6.941438,-55.475134,-94.40663,-46.58388,45.784846,17.29887,23.200568,69.167843,45.504668,-106.963942,-172.577546,-192.043353,-173.902711,-109.88155,-34.902897,-40.842623,-159.50037,-229.274716,-258.628002,-214.729659,-98.565689,60.333305,143.734703,174.739041,119.206649,-10.454762,-54.064653,-69.011372,-33.163964,105.11081,213.830772,195.321089,72.365156,38.592995,44.128777,55.03075,77.732081,146.223232,180.636752,141.238231,71.933338,-49.666762,-74.849594,-78.430656,-76.842454,-78.885044,-97.160863,-112.291634,-135.473343,-161.479696,-236.563885,-235.863554,-124.367798,-46.276458,-68.906639,-193.629665,-250.834573,-304.695898,-310.842017,-247.115853,-182.219101,-95.473732,-86.436277,-78.653476,-17.249878,12.801503,-15.595557,-58.790262,-61.365807,51.817242,75.527307,-44.935832,-160.466185,-327.281568,-326.030052,-159.952433,-76.121562,-59.61866,-53.584283,-9.148087,63.441226,65.632562,69.671741,111.560285,216.055136,268.876239,302.29743,389.19591,411.315294,349.149859,285.920526,198.325541,196.282475,296.245137,400.503283,380.310923,255.650868,196.284807,134.855946,174.419408,338.931197,368.575353,346.3352,309.980725,270.280337,102.993834,22.616902,-24.576845,-19.57118,-0.713675,63.109965,49.849944,-98.071049,-168.619099,-248.887454,-269.115726,-265.502913,-170.494628,-97.122974,6.573429,14.081497,-74.483409,-152.030901,-252.96289,-245.127872,-134.245823,-56.193612,-90.791192,-231.786185,-260.945222,-174.188569,-96.475456,17.937257,64.749234,62.68024,-2.203842,-44.221061,-112.349959,-139.338728,-146.042619,-130.545965,-111.350289,-96.574815,-97.961589,-133.031454,-170.286876,-249.937393,-250.404463,-179.815264,-141.040526,-129.460792,-104.850101,-110.91086,-178.946857,-199.236194,-82.075962,28.738191,177.094406,143.788314,66.912516,-63.099771,-72.696825,-48.217297,-24.878656,36.135599,95.905981,133.738235,137.214258,72.107267,-67.729131,-80.379947,-17.347079,12.533344,28.457031,-5.607975,-49.771651,-167.765061,-231.098717,-327.669516,-331.26659,-276.342716,-193.033735,-162.106154,-212.808898,-270.029807,-339.376349,-343.721593,-267.296705,-197.938387,-104.529815,-134.255779,-185.1782,-307.045161,-370.448289,-490.222745,-517.02214,-426.266492,-192.570342,-86.770229,-31.154131,-89.046503,-286.310962,-365.572044,-353.827419,-282.006553:284.936641,291.531469,263.945562,168.239117,104.30333,-2.883068,-11.650498,85.658564,256.714622,329.279102,349.783576,290.757115,115.149396,36.738976,51.935878,156.201948,267.585013,99.042295,3.321599,-92.053762,-105.390689,-135.244182,-144.231558,-77.52008,9.940407,0.925421,-108.318083,-162.207537,-155.299377,-87.300731,84.173492,134.722756,105.192512,27.635455,15.649593,35.574429,59.94523,105.54858,127.611544,211.14666,293.13334,303.607874,253.028097,200.874114,109.813443,89.625932,96.573105,117.331135,150.678823,124.766203,104.847313,119.470887,147.834213,114.389908,43.068579,-58.456024,-12.804102,44.171822,112.652433,99.283235,-12.616594,-97.885567,-160.155469,-90.722443,91.269584,151.184539,119.043126,-13.622722,-61.784327,-101.27876,-111.464518,-85.036422,64.545702,183.339889,384.386883,389.669203,230.730698,147.731127,84.521123,92.462959,120.115594,134.750434,126.035772,82.134123,63.641045,69.805312,99.236048,151.508941,128.689018,109.309267,112.801702,124.022805,96.458448,80.632495,148.922623,204.764928,257.355112,252.569861,220.560223,170.102147,175.619026,152.291906,132.382072,181.758636,248.131451,232.704619,107.662937,34.459768,-33.713256,-30.100254,-21.932632,-31.128069,-59.707469,-67.274049,-72.977044,-151.221428,-212.534864,-268.544108,-231.764273,-109.746451,-107.97501,-122.68446,-107.596321,-96.124339,-84.803386,-85.285453,-67.118261,-38.379905,-5.554059,-25.855107,-15.406192,101.290851,167.209846,195.648725,177.924927,156.613123,104.794221,55.006688,-47.901894,-86.530761,-137.154345,-152.201201,-103.214301,-33.95117,24.330846,-43.310399,-52.071002,-63.129636,-105.493792,-229.870162,-249.34257,-122.067635,45.732562,81.531156,6.694415,-84.263023,-213.070844,-219.558184,-125.365574,-55.545012,2.216002,32.927785,85.763912,181.225315,200.86124,223.279078,236.701921,280.959324,405.439649,495.824063,591.642933,562.545441,406.588202,317.16648,222.141883,230.351796,232.297185,127.352778,67.961469,18.920058,42.551364,135.923947,167.618302,108.663928,-51.352056,-84.032644,-38.813331,-12.158406,-40.706946,-96.632293,-186.142255,-190.457371,-204.326648,-229.891303,-206.707982,-115.945698,-64.324942,-5.116411,-26.832635,-99.056169,-45.448362,14.173826,88.496042,91.423781,20.345631,-39.662143,-81.588219,-57.729243,-17.75268,12.578932,18.152146,-27.946913,-61.351943,-80.525747,-53.727076,18.027713,62.470109,97.291304,180.131792,197.511826,144.255385,90.898526,74.671876,142.683979,283.243663,287.555494,275.472555,280.958719,283.211575,256.584558,246.663307,249.779374,240.084224,256.485746,267.491656,229.279389,162.523974,151.925155,118.821701,77.270402,-46.964241,-53.357125,2.886441,74.800511,59.207395,-48.074569,-92.528748,-84.250449,-56.393182,-54.443381,-78.709148,-107.607194,-135.062658,-124.554017,-94.480449,-68.982929,45.385518,209.472404,253.104477,201.797314,127.149003,-27.012499,-56.155111,0.196294,17.603615,-5.118509,-84.013237,-144.924034,-213.978713,-190.152106,-107.675556,-105.441769,-230.005817,-334.658311,-314.416972,-231.200106,-224.863461,-271.357958,-270.07397,-181.234034,-34.982945,47.215013,144.283466,175.897372,295.132968,350.444607,360.654618,337.984731,359.228429,453.782203,448.900037,347.784798,326.255583,356.768441,372.28254,353.767303,290.162852,292.687838,343.162034,335.696787,187.40463,76.224806,-18.004343,25.739194,94.164843,-4.50656,-72.913775,-190.152782,-262.16403,-454.869184,-507.153501,-372.867834,-152.098291,-91.787512,-15.782414,3.884605,-34.752748,-84.777331,-183.81532,-201.876371,-141.343876,-22.396222,2.037191,-58.354394,-116.778143,-219.904932,-233.089569,-167.460881,-115.321326,-122.667767,-186.915213,-237.779335,-361.557536,-415.312151,-399.507638,-335.171697,-263.423516,-335.194215,-367.069531,-330.961224,-297.081886,-320.947902,-361.301197,-414.643902,-401.706623,-360.344906,-252.931676,-232.512111,-327.456571,-387.877492,-313.671939,-197.929201,-40.815879,-46.708836,-71.680304,-69.74083,-41.73374,12.933893,34.526927,51.376752,58.030589,90.878825,151.643499,139.513921,66.389503,27.678167,-29.822384,-30.381533,33.892209,85.883814,79.493008,42.330383,23.530403,-42.664878,-68.886933,-51.277482,-25.769682,-34.276437,-117.046911,-164.982449,-174.748198,-153.662735,-101.87399,-45.990564,70.370756,30.809855,-35.459799,-197.207663,-282.933767,-398.654473,-398.442601,-299.845389,-165.25822,-100.615819,-53.623345,-101.4284,-264.655596,-329.837227,-375.603764,-341.948885:230.149595,331.963764,311.850371,145.520452,23.542877,-186.563554,-186.144967,59.985099,268.189268,284.706013,226.277964,177.047148,25.169832,-65.470717,-134.410839,-89.981239,22.511281,-5.006393,-60.852168,-159.396739,-190.397629,-229.899977,-226.118739,-100.595784,77.254846,99.006183,-20.528071,-102.264326,-159.732675,-126.223423,15.911689,90.427022,177.395424,171.800646,119.417937,-31.143357,-78.888338,-43.572128,52.69342,317.820327,395.047355,317.434929,99.988374,18.127633,-120.335643,-176.002558,-152.455406,-85.458161,28.043594,64.183189,39.725423,-75.347669,-130.072529,-182.568171,-175.45162,-81.562075,27.156172,43.295572,-7.161059,-49.466543,-111.070518,-119.154811,-52.288788,24.730722,191.611891,291.550757,298.282204,227.238388,170.217631,84.285943,77.629516,143.490348,279.808761,346.433632,412.114175,406.822555,278.728199,176.456308,119.935073,188.712507,318.969528,265.686263,171.970464,-42.925867,-99.125448,-63.723115,-1.748867,122.48325,182.530874,194.103052,170.945535,134.330579,45.815558,33.382668,152.319956,237.367366,332.687545,359.913962,352.643147,278.054254,207.674905,72.109002,83.146604,271.931909,370.085287,326.819639,151.187889,82.256882,6.62363,-29.409088,-75.509716,-65.366215,22.253352,124.074776,107.20613,-82.225534,-169.832806,-170.131544,-103.816417,14.729081,21.202639,4.628985,-17.181503,-25.949193,-41.121506,-31.005178,43.074686,87.660471,168.61248,253.182742,261.028085,213.028323,211.62509,267.971268,304.188677,390.878709,410.771271,359.090262,141.584233,14.914635,-183.509438,-221.868232,-87.728241,43.667602,197.935353,185.578965,158.497012,62.581579,-1.146188,-83.876804,-66.593569,78.283311,221.544754,244.570728,174.844982,116.569288,28.344375,10.543399,109.317413,206.423964,318.024941,304.856966,275.515887,210.932408,206.502738,237.553304,257.784666,315.075583,399.774811,465.769912,546.865101,512.263183,325.424826,218.072947,116.53539,150.561531,277.961396,262.99549,195.446051,95.488633,83.330477,44.071383,22.5074,69.801289,163.135126,197.186498,219.809857,189.863616,65.542067,10.865306,2.58852,36.47619,81.730621,64.948958,47.265064,44.453858,65.261347,111.186514,124.45094,120.932767,107.757392,127.207667,164.967326,137.794275,0.266648,-63.641953,-77.415144,-36.444403,19.263163,19.607287,7.270712,-59.484713,-111.516611,-193.869064,-171.821224,-12.409951,120.978028,175.058136,228.609798,193.98426,50.924556,-8.761413,-24.249102,37.656994,260.036028,337.808563,273.024534,138.965587,120.770599,136.394449,148.977074,181.876512,278.78681,324.865917,235.405617,113.60652,-57.758917,-65.175635,-15.308437,-11.615551,-66.299196,-85.031107,-64.886181,-28.084026,-44.967303,-130.721248,-137.235467,-63.038479,-21.024652,-9.87899,-19.847339,-42.230374,-87.62442,-116.716912,-126.969242,-72.221753,76.643275,108.318682,82.481073,21.166453,-18.258637,-109.730615,-116.945286,-17.406847,86.622926,105.893808,73.130721,1.630715,-225.12287,-294.054717,-168.436106,-48.23926,12.159603,-49.864473,-44.707786,-51.0996,-100.423187,-178.77873,-138.28216,36.189088,148.075644,193.038504,259.965761,270.067628,263.110775,259.555678,279.437179,295.067156,307.774558,343.82989,363.247385,309.441056,236.73827,122.997371,136.434817,260.816628,303.200266,290.469381,270.554854,250.186284,107.777444,-7.849717,-161.328818,-148.811153,-36.285496,-0.324275,-24.007959,-165.008205,-267.317291,-406.962218,-410.00274,-284.372032,-74.084148,17.459915,90.51542,56.021611,-78.206608,-131.704037,-162.200678,-145.986864,-85.740055,-26.817651,-24.969374,-109.69733,-167.956682,-169.080789,-87.967862,99.881466,127.283814,89.159917,-27.660076,-100.56207,-238.57998,-272.851704,-224.049983,-164.865323,-76.958907,-102.507846,-152.619352,-231.215659,-257.162665,-309.273994,-293.589285,-160.726566,-53.674908,-44.256204,-130.659013,-199.677722,-297.623844,-307.868191,-205.487836,-109.598331,26.927303,21.441449,-14.89083,-96.024969,-123.396577,-157.5437,-151.922409,-33.237114,139.910948,180.893228,145.752591,93.210774,-53.479792,-130.024728,-149.677111,-77.753201,59.521223,31.602862,-12.888463,-108.34193,-180.74074,-326.84763,-345.671266,-310.971339,-290.280917,-275.779054,-272.365433,-291.614421,-363.638495,-413.954079,-402.735969,-297.794666,-70.082747,-98.306096,-190.740214,-374.403378,-450.270417,-571.0357,-581.556225,-463.545553,-297.037352,-221.837124,-156.460793,-208.206885,-434.977312,-536.658539,-548.378958,-455.112622:123.821845,142.940524,96.00782,-43.913507,-68.640978,-23.99534,-14.540005,-23.466102,113.506797,234.874188,408.277881,417.768232,367.007291,355.613155,377.391476,388.165385,356.779211,268.533762,210.077713,97.551779,68.666934,12.447356,-32.124106,-53.422924,-15.895866,-28.181313,-119.362273,-181.538418,-254.556875,-235.451002,-108.345918,-30.641996,35.265029,-7.36957,-3.285648,60.792281,90.964036,108.689261,114.0584,184.144518,216.539757,189.074032,133.806215,121.614987,132.356404,167.608703,236.132052,216.361075,96.365411,27.459861,15.670524,33.743956,75.583547,130.863786,108.439398,15.780312,-14.671556,11.601254,49.842344,19.869106,-70.777967,-90.068024,-93.658139,-89.986679,-44.429897,26.899001,-3.765362,-237.637673,-331.984155,-338.72085,-313.079924,-294.744192,-218.516364,-137.139123,2.064457,23.25216,16.643097,17.421142,40.1158,42.437296,-31.164393,-73.254103,-55.025041,-63.205373,-85.298816,-83.48133,-71.082768,-83.645398,-116.76425,-116.1574,-83.07748,-63.75728,-42.864132,-26.991316,67.752013,130.025305,214.926526,261.919281,268.430094,199.165308,145.337997,128.26989,176.912752,275.37828,255.144043,216.202299,126.714013,85.192405,43.39734,28.00903,-36.439617,-66.16406,-73.806754,-70.121587,-98.205334,-176.698345,-199.295084,-222.186704,-229.213369,-255.671152,-331.506353,-350.496754,-295.278558,-240.030252,-115.797699,-70.252617,-46.04073,-45.64973,-60.487362,-149.419585,-197.595063,-167.973764,-73.304362,116.720835,148.666141,128.068148,81.625548,31.876917,-113.694338,-157.118572,-140.046277,-132.559948,-132.630192,-99.255693,-65.868126,-244.81064,-341.400721,-359.645592,-314.519153,-305.158626,-331.065198,-349.179314,-374.747693,-377.378352,-397.704969,-445.405512,-518.774948,-508.155294,-413.173189,-344.846214,-231.820956,-183.77117,-178.20745,-153.674589,-91.078412,65.212295,94.873995,83.739875,102.149218,130.168855,158.388797,137.051747,52.32373,12.682898,-29.017892,-35.151438,-50.88787,-66.295986,-85.131385,-125.96874,-122.192999,-96.852175,-107.400936,-176.984622,-253.933885,-265.471517,-216.257052,-185.761809,-220.447862,-272.706912,-278.594789,-222.813112,-184.453102,-255.653329,-243.403418,-89.032136,1.778608,77.020546,55.632061,-15.759762,2.159651,67.707481,233.306332,267.290503,182.267675,100.3195,0.16311,24.489006,140.697372,197.242806,208.666543,179.113179,143.761239,112.684301,124.330936,138.588909,144.778761,182.803865,262.120042,257.244341,203.455151,190.588671,235.128887,278.821223,316.676236,345.986417,393.660911,493.744535,518.712253,506.822458,488.782328,455.242447,423.018735,429.48087,432.666454,417.065888,438.233239,461.578969,445.987748,410.924646,350.897019,391.454183,431.675379,432.907033,374.612765,191.401514,123.122638,91.467875,43.727569,6.565702,-14.424528,12.108607,109.568918,142.160812,161.51683,160.933696,126.377806,173.112416,228.33625,230.24802,172.894863,47.836921,5.114127,-37.093441,-34.625604,-10.277902,-1.424695,-45.890987,-160.771686,-175.507538,-89.101781,-49.360023,-125.305601,-282.509321,-302.266002,-225.102266,-176.849149,-152.237124,-188.372079,-277.041529,-205.797989,-110.243718,54.294225,114.027682,264.970714,336.103024,382.519134,364.601378,332.6392,394.036915,426.366543,396.392943,354.265062,318.250591,331.944011,329.141982,204.671181,147.494633,149.738634,187.158807,226.713233,197.605087,127.189329,148.081734,249.816606,236.993916,147.340009,-114.335972,-215.346624,-329.985319,-361.950667,-357.68228,-254.604199,-177.288248,-60.421023,-45.48958,-48.683984,-63.677777,-136.292016,-168.42872,-154.956945,-80.052121,-81.759246,-189.998206,-244.12545,-272.232672,-250.657474,-177.325395,-105.008573,-67.706764,-95.135595,-193.202174,-396.913347,-403.206064,-173.020932,-23.79726,53.219828,-89.282272,-111.224948,-10.76844,68.086977,120.565792,66.835597,-53.924557,-75.058444,-69.359385,-49.772727,-43.631894,-20.725148,31.765414,187.454702,235.374802,248.250691,226.873969,217.214178,248.338118,280.671056,281.109817,268.946077,308.102296,339.079471,351.701271,378.247434,344.780927,203.935979,161.500667,175.897663,208.166905,246.995892,255.002845,286.684756,368.653918,373.854513,317.940769,287.226324,219.516419,152.83476,140.920787,93.655099,50.3605,9.742048,5.678344,34.890018,101.748318,244.057042,265.061708,248.403299,151.054133,83.070064,-11.499469,-28.225438,7.66476,123.011218,186.493241,217.517065,152.935338,-35.901804,-86.989548,-17.233113,75.704194:230.060424,237.257392,195.770765,135.533732,124.868792,68.05627,33.09658,70.745977,267.18112,383.67523,514.528961,499.743228,373.864435,309.260837,276.998571,304.452571,296.027914,186.179371,156.126243,97.852445,22.457085,-150.325961,-173.857131,-42.155192,76.269683,56.218073,-33.491202,-39.506339,33.006555,63.449952,75.8083,81.934468,87.574554,92.220282,101.191365,98.946124,99.931884,149.234734,194.924837,276.242724,304.394321,313.658277,293.83896,253.601566,225.299164,273.54187,392.631853,382.993822,204.058035,131.365032,183.773641,332.581977,353.637915,195.092065,89.956759,36.185426,98.468972,125.038852,156.604482,147.350232,69.380972,12.330806,-86.769157,-105.432533,-38.076277,75.71013,54.212492,-115.432866,-152.102625,-111.853392,-109.329582,-112.792114,37.173229,166.34806,365.191041,371.333393,269.317416,231.902565,180.886056,135.150233,54.544539,130.418964,191.429009,192.478891,143.410184,86.203322,99.465269,153.428702,209.39097,233.506341,230.006451,200.752919,121.362309,93.485115,126.407394,184.188304,252.068487,223.18494,209.161099,171.044857,138.847361,76.199261,81.783065,206.935618,299.39697,288.881197,219.863534,178.016388,81.623944,28.45065,-64.896397,-98.177402,-131.279882,-100.766678,-105.338955,-170.463484,-180.501279,-172.356599,-176.850966,-158.085641,-129.116556,-134.190679,-176.168071,-203.91125,-241.225736,-242.509287,-219.408787,-210.738676,-221.286825,-254.060819,-266.130523,-158.076057,-55.582093,20.234469,-12.320419,-67.492926,-119.031393,-168.533847,-257.027728,-281.314281,-308.146431,-315.13301,-314.523818,-309.833578,-305.997466,-272.348752,-244.267659,-241.524184,-284.044083,-401.685105,-419.391762,-378.554274,-415.930973,-424.752187,-403.428768,-433.906432,-555.935815,-592.724116,-525.012109,-426.276821,-275.664944,-281.018867,-282.372737,-218.770103,-160.596915,-44.630579,-20.525451,-14.806444,80.355385,150.851181,242.010973,265.46217,258.136889,192.835912,7.239307,-35.212914,-18.528521,-62.435089,-113.144881,-120.972658,-58.020915,39.295043,17.549313,-89.68541,-153.417943,-164.93915,-149.647803,-123.859675,-120.243208,-176.97792,-314.373226,-332.964132,-319.780129,-346.17157,-333.608091,-228.566481,-177.123389,-192.83458,-249.1904,-323.163052,-281.029264,-218.064298,-53.048989,0.453832,-58.974893,-149.049265,-258.084476,-240.850326,-163.475789,-132.138228,-122.819346,-69.817578,-32.581324,-19.473466,-45.995211,-97.631028,-79.939859,-23.708666,117.528641,150.546612,124.678739,98.305519,86.655013,113.542108,172.153114,182.293663,185.781759,205.386679,209.242044,145.3917,82.985026,-5.427634,49.35175,113.813685,128.157697,65.199088,15.00995,49.669971,51.829188,-14.090154,-152.485408,-94.30488,-23.566109,-12.774138,-79.051895,-187.089239,-189.777402,-206.405512,-289.351514,-286.686698,-234.742371,-235.555539,-228.973188,-187.581711,-88.969854,-70.589647,-70.241289,26.676115,81.463651,67.589516,4.467064,-176.497602,-260.155944,-304.457805,-194.866236,-146.666675,-172.576122,-234.378232,-368.749753,-415.376237,-411.608827,-378.839154,-388.635223,-442.615716,-428.41734,-366.538704,-342.134309,-308.341078,-303.959769,-298.13114,-170.558644,-31.867369,238.86047,311.887376,381.770026,408.711731,437.359352,441.999658,447.53934,402.756687,349.29129,234.194836,199.862388,179.992291,203.546738,279.006284,244.582902,217.505672,208.869201,207.847191,179.498758,140.424034,55.510054,51.336806,97.664699,92.443866,43.23637,-104.175926,-171.498596,-307.832712,-349.058535,-244.151762,-57.976055,-15.800899,-1.803916,-5.193147,-33.498083,-62.785293,-107.235035,-121.352664,-144.515055,-68.59438,-4.280468,16.831618,-43.381294,-188.146364,-211.239902,-158.446876,-155.247028,-165.661529,-146.588284,-157.0261,-290.69822,-363.111187,-323.796934,-220.335772,-92.370563,-147.356544,-183.028363,-239.692277,-257.324134,-248.362079,-230.831672,-230.439908,-290.257246,-303.709407,-283.928007,-272.255507,-269.041981,-277.878946,-270.202557,-226.256642,-94.073361,-36.019011,-25.660424,78.324035,178.894389,330.186962,322.194161,192.336801,120.429913,140.456562,190.021407,179.868495,86.083929,27.796312,38.894266,129.488565,260.779747,229.420084,229.611275,300.931115,340.268591,320.621818,269.926005,239.115468,308.054582,310.713244,174.640229,74.341277,-48.351794,-53.302359,-6.148686,17.362066,30.59964,28.315086,21.862067,-50.819793,-96.949288,-157.060449,-178.350724,-168.037394,-32.67937,48.564283,73.601314,1.799494,-156.197919,-188.2354,-136.678871,-74.508633:301.656806,298.845665,274.763445,187.895851,135.649607,49.47566,31.309976,73.363389,157.613573,197.20325,240.749662,228.171196,155.143165,115.995768,102.340604,135.243252,203.730837,197.390102,156.452928,15.157601,-56.616828,-125.130374,-90.819639,76.513331,116.883442,59.033588,-114.642022,-189.962567,-211.160866,-154.409346,7.737743,81.658024,143.371488,75.119501,41.759747,86.670195,143.228165,199.217149,199.24685,218.594421,262.384836,253.276402,139.275189,60.286961,-52.314919,-55.485361,41.029625,79.633429,18.962472,-17.170657,23.984695,80.200431,59.834561,-76.293556,-149.381584,-130.833924,-9.576431,0.724814,-42.244477,-70.395604,-111.084366,-102.189881,-24.097536,17.732624,94.923684,169.975617,157.79551,39.051031,-4.448575,-17.322599,-19.693174,-11.102595,79.406453,153.951468,263.414327,249.427738,106.337382,31.698212,-15.42326,18.134777,119.951036,218.928246,224.39992,80.755119,8.773139,-2.194015,19.403355,15.082052,-56.529493,-93.60965,-128.501755,-109.957448,-4.264188,43.788417,95.375792,116.349772,190.657678,260.881173,246.714766,135.153844,87.197055,87.967876,120.302763,149.476239,185.709249,206.205299,90.706762,-24.118657,-135.466774,-117.248644,-71.931826,-68.148877,-55.567406,-16.642635,-15.731688,-72.295897,-104.123195,-159.328791,-183.17995,-199.152698,-249.796569,-280.31694,-258.434032,-218.040423,-163.044591,-142.622375,-84.924564,-60.175926,-17.090994,23.108318,13.287364,-9.595822,19.888764,97.172832,129.419816,204.638866,199.356803,151.160979,-11.259651,-94.065557,-150.983168,-127.600894,-50.107485,-14.088094,-3.307901,-68.401352,-95.213592,-137.42277,-180.943836,-280.356161,-271.69559,-120.063168,-23.957767,-39.651505,-100.769426,-122.501981,-189.785679,-230.070791,-183.607248,-82.124831,92.41129,87.028465,46.550037,-2.315082,17.661293,108.226967,146.885512,191.137749,233.354007,263.149778,291.467567,271.162849,145.359072,65.467337,19.2965,45.155692,24.4452,-35.045958,-26.855786,-13.494251,-26.707017,-35.162594,-16.28229,15.252645,-7.251339,-1.408059,9.82342,-26.030792,-103.398655,-106.337713,-44.664712,-20.513686,-108.257609,-219.327681,-194.944079,-36.942162,43.294093,126.357591,123.584263,54.81072,3.073071,38.632945,161.042571,156.030159,16.810465,-33.287053,-31.927568,-8.481313,34.716691,84.563863,101.15556,42.26663,-19.378419,-108.111185,-114.328426,-81.514567,-7.348611,58.440694,124.615292,96.511351,42.638032,44.903404,67.637955,89.059701,152.523399,202.361675,218.777729,239.313238,253.708385,265.864507,261.374754,268.218808,287.418141,295.061193,238.549785,193.38235,200.701941,230.891475,230.392311,216.515923,156.878339,81.595928,110.708807,204.821543,195.668064,112.29465,82.145533,12.832529,-107.274481,-120.337132,-21.350584,27.658432,66.087364,68.040703,67.512207,73.818354,68.959643,52.216464,58.475126,94.286336,104.911375,75.021834,52.322024,65.383849,90.035118,58.239061,-92.391729,-160.690901,-191.956784,-179.720179,-156.522571,-145.985009,-132.533953,-113.019073,-106.603436,-124.950576,-139.999121,-171.527057,-183.075053,-124.591985,-8.162117,13.589119,21.826281,53.658066,159.182421,188.797183,207.309541,222.699215,257.585843,282.605552,264.77591,200.586686,213.635943,304.673955,319.555608,240.451307,103.497095,82.237634,147.003118,182.939149,184.123086,129.72915,0.214239,-4.124628,62.193475,44.708237,-2.392133,-130.935642,-217.151277,-383.055339,-409.324631,-345.278081,-232.530536,-154.350597,-10.739331,15.496191,-43.952358,-124.068527,-256.089139,-244.82427,-146.552193,-131.636221,-148.636706,-170.334665,-174.162328,-201.338831,-183.77953,-16.527645,21.862381,-27.197624,-96.309849,-151.255545,-317.902304,-330.892671,-170.252627,-111.124267,-166.965272,-209.410899,-182.28277,-125.720487,-112.969387,-99.732353,-95.893592,-98.015565,-100.027601,-93.298952,-83.129136,-84.008135,-95.053594,-104.936885,-31.22312,64.282748,190.608147,128.561064,79.72456,64.474245,83.234466,77.9653,62.96616,55.660496,116.286837,172.843118,174.761524,109.047899,-0.572535,-19.80559,7.160081,42.992352,113.884959,140.550306,116.62064,40.02416,22.218067,-5.67273,-44.921726,-141.798257,-131.638771,-89.470103,-93.165871,-143.003247,-187.417643,-155.268848,-2.232306,78.176217,97.5266,35.045472,47.271291,60.620568,14.035266,-158.089835,-226.216031,-190.023113,-11.007399,67.732788,122.750187,69.593185,-140.021924,-218.124723,-176.393854,-81.060683:left
5.746471,-53.524192,-70.523182,-53.502177,-37.956811,-38.126745,-43.97452,4.010908,70.010697,55.89379,-13.090615,-13.62215,25.610814,29.734915,83.87596,148.57253,282.363171,353.484076,320.562115,158.61296,111.319868,194.636295,297.892766,425.521624,315.955802,225.61675,80.199529,34.653167,-4.517941,-2.179434,30.334657,43.409044,30.868854,-41.640425,-104.057399,-173.290919,-132.596614,-13.992913,12.902099,37.013397,25.137664,-6.404415,-101.103551,-130.204058,-79.141548,-31.498462,-9.655732,-18.609431,-1.657534,-27.495388,-67.685171,-76.363214,-40.326203,-24.982358,-42.781382,-9.625363,133.511178,200.447679,203.04363,165.766509,159.025321,182.829913,203.254231,182.648122,89.76477,-53.223676,-151.798387,-288.556876,-291.665252,-301.530971,-326.876772,-260.978889,-105.933819,-96.313584,-201.588577,-241.641734,-235.057834,-212.496664,-92.648371,6.501235,94.39171,-98.11358,-222.453479,-315.856931,-259.69402,-47.087074,47.332469,146.905106,150.773705,116.344264,-47.552457,-114.746731,-35.468547,64.190947,158.343524,135.837283,11.223443,-145.77146,-219.688928,-294.478997,-277.086716,-173.410735,-106.981074,-4.452022,13.320184,2.290851,-48.994446,-61.164207,13.010069,71.050139,105.425587,68.911231,-32.728383,-126.283947,-174.798338,-160.450292,-79.285153,90.15049,140.415092,179.682344,149.96152,122.115226,89.826837,99.240809,142.121179,156.426421,180.172507,184.586976,119.448568,23.905197,1.492999,21.396998,61.195989,138.649258,157.166283,122.158351,37.636414,30.846248,15.905049,-32.451061,-91.092434,-63.509819,-34.547254,-90.615123,-248.518433,-321.665905,-362.645291,-438.101883,-407.9447,-225.394004,-137.306217,-45.280757,-66.887816,-102.505602,-160.98384,-158.462506,-109.26774,-107.036398,-169.694278,-195.20896,-204.735228,-241.457914,-280.993407,-349.850179,-343.92301,-220.175509,-119.106272,60.361481,106.346529,93.782023,62.66988,58.397442,52.962777,32.37569,-21.728658,-45.509135,-68.744746,-20.541946,-7.382489,-23.849311,-15.802311,47.229708,99.77754,195.342994,134.867147,59.2,-52.722149,-49.172847,60.484125,126.011505,211.062723,215.226451,152.470135,82.553929,53.421205,2.791702,-2.224413,23.141539,33.491154,10.428936,-63.538165,-110.272941,-234.776676,-274.428763,-216.920089,-155.511555,-85.116765,-79.511464,-79.300699,-103.889496,-134.139631,-158.667884,-125.549147,-28.050913,2.753811,22.686669,12.817348,-9.885818,-110.686348,-170.665142,-242.569333,-239.241835,-154.419472,-104.714103,-81.056838,-110.379628,-117.183917,-109.013684,-84.096738,18.95769,78.676722,170.537118,262.423172,301.513522,251.277388,173.990379,92.634329,120.13381,260.525783,318.007149,283.049476,133.696544,77.885878,105.200103,183.6591,286.661243,281.878783,223.394979,75.708525,-5.97089,-104.179392,-122.202137,-108.755112,-93.572037,-92.359014,-110.408814,-130.374323,-114.75486,-137.169981,-203.89655,-181.183469,-16.966446,37.086388,-19.172962,-46.47615,-21.160036,-102.479698,-201.294448,-250.773659,-160.758647,95.88184,169.11597,108.957816,3.33117,3.213724,3.370451,-12.042604,8.068807,64.490085,229.488604,288.925783,250.611993,130.156168,97.698667,137.798271,184.06161,247.870004,258.829658,275.115101,243.671421,192.140084,169.137992,234.542441,364.319563,382.718207,350.86871,258.174044,220.969286,215.69305,248.269666,335.43994,364.119475,406.983798,426.12144,413.5717,326.293042,292.271214,314.716871,350.607085,394.520536,408.62924,405.107437,302.984074,236.377932,127.283503,107.354177,161.512933,210.456186,289.778281,300.501727,249.150639,196.799999,161.142402,6.04412,-72.898947,-108.26296,-65.184194,28.804427,9.114353,-30.395952,-102.472809,-104.072178,7.033084,66.903015,80.035415,52.940398,-21.203773,-149.523545,-229.957489,-265.244495,-185.389213,-27.475444,-31.592608,-140.686297,-137.46253,-89.207274,-93.083522,-143.594235,-122.007501,-21.724731,171.61017,185.80172,75.69408,-40.010871,-86.028291,-123.476542,-87.096665,54.05699,114.530555,140.681405,66.120701,32.616553,-57.025477,-126.431243,-211.041611,-191.450356,-67.883327,-9.571671,31.550161,-33.548207,-103.3458,-190.527393,-152.855649,27.32038,104.874985,109.145491,-33.000558,-61.050464,-6.63116,26.8968,81.631084,109.841965,126.732056,111.017335,74.658627,17.90566,-28.248761,-128.394505,-154.466081,-121.74176,-85.308591,-55.722143,-66.745386,-65.729559,-133.363735,-200.221117,-267.80282,-247.625143,-100.248968,-28.888114:-63.471058,-176.234118,-198.54967,-141.258673,-89.335949,-16.370217,20.427384,137.853344,135.579014,57.698896,-76.833623,-58.134609,125.770998,209.603884,271.53407,263.185363,235.004652,231.966543,222.934061,198.184634,185.412638,199.642733,262.748236,373.760501,266.129882,191.00429,91.715329,52.029552,7.290273,9.657211,41.268678,50.302514,2.057894,-125.963472,-205.184134,-313.060114,-309.284106,-196.470877,-133.385842,-89.215193,-95.295283,-100.399535,-111.791545,-89.728197,1.731902,31.074943,33.085042,10.928785,-57.851388,-99.130908,-111.138923,-144.085225,-145.498596,-63.070881,-2.300766,74.688347,107.210602,113.829361,71.724931,43.686609,50.216643,71.752872,101.615689,102.713337,52.094825,-127.616258,-241.021546,-337.341123,-314.749099,-281.287735,-273.702155,-210.476534,-198.279207,-220.978853,-245.131109,-241.075952,-218.034256,-171.469128,48.789228,158.171968,168.744848,-13.387011,-74.928964,-20.765786,68.872695,178.807995,179.275059,180.665141,191.828731,171.765997,59.95681,10.628369,31.904461,72.130862,108.878562,99.06062,5.514554,-179.505342,-266.374554,-316.506492,-275.71816,-166.960491,-141.266274,-147.550444,-134.885274,-123.786343,-157.813736,-161.965996,-36.829896,29.951589,-40.194874,-145.058361,-266.412732,-251.948821,-237.333086,-135.847353,-39.231217,117.217185,146.048494,127.122113,105.484406,120.568397,118.412695,93.22956,77.48201,87.567868,121.435228,128.710778,55.931591,-57.375656,-91.924608,-96.803087,-53.292002,94.468598,153.228963,144.310699,-6.472986,-70.03621,-130.087482,-140.330229,-62.004172,26.606982,120.237929,65.879896,-160.268918,-300.176184,-317.813976,-299.962311,-259.780087,-125.576936,-57.730429,21.277233,20.519596,14.470576,-7.867566,-37.59491,-116.280373,-130.8758,-71.405671,-40.912841,-50.502964,-125.798817,-185.617542,-276.847629,-273.889177,-164.886533,-66.781555,146.165038,177.762774,95.173237,-79.639627,-95.332559,-65.692068,-77.905659,-120.70542,-142.714862,-189.817338,-158.505125,-121.813048,-95.74213,-95.194762,-23.541249,46.573542,135.695456,53.870504,-16.03702,-60.02888,-22.927813,43.777816,42.458355,72.968976,128.495736,169.517502,32.460341,-45.023303,-91.022226,-49.895615,91.670735,151.726637,127.849157,-35.956435,-100.912463,-217.009452,-264.347248,-247.166324,-180.087953,-25.206378,1.884508,-75.415395,-216.786984,-270.305147,-248.715427,-184.855312,-79.601828,-52.198898,-18.70984,-20.069245,-48.830176,-163.173584,-220.686156,-251.023012,-221.028831,-175.011445,-190.907442,-231.209929,-201.026995,-194.551839,-226.146911,-206.880318,-22.220507,73.826818,132.186807,106.224461,81.661656,-5.370925,-22.489385,56.544148,106.134714,151.148735,151.04475,100.679543,24.049277,15.2361,81.87404,129.267251,199.748835,229.811347,247.827164,139.387749,43.030291,-159.988478,-196.924212,-89.319678,-23.098672,15.278914,4.727316,-20.711426,-41.713116,-60.718408,-80.715451,-51.104405,58.0978,93.317236,109.700097,85.558576,30.506972,-105.424309,-112.25394,42.100999,141.398201,215.527211,178.780262,53.413257,-52.120316,-78.176377,-51.606317,-12.493664,90.964702,158.75656,292.335218,348.439276,333.075232,219.42631,176.303479,252.175237,327.229344,363.085828,318.897848,212.214729,163.541056,172.68806,259.294563,307.833872,336.461507,338.198368,386.454777,413.934565,385.214902,303.894733,299.431582,359.126212,390.63604,439.119852,439.205121,360.368292,286.573626,281.792575,350.068128,395.629784,432.138991,445.570359,471.614092,341.414455,230.07806,75.137879,81.715471,236.733308,305.168882,316.962253,286.561863,223.903145,188.914423,169.189461,61.423996,-15.34244,-50.126286,30.256474,225.884859,197.414548,102.338917,-68.149759,-82.936246,32.297257,120.827328,243.274099,234.619997,75.859478,-131.172716,-201.313709,-201.061633,-134.533008,-13.483336,-7.609468,-65.237038,-85.643916,-75.3445,-64.327975,-58.238093,-3.461747,35.836971,112.679384,145.520119,158.492297,103.784864,58.055625,-49.439342,-66.423361,34.484193,101.239282,93.836679,-18.999989,-57.33723,-137.662141,-177.792353,-180.999804,-130.151201,7.966035,34.971682,-37.152153,-157.9942,-184.181818,-132.091466,-85.762552,35.679683,120.299389,185.244621,15.640566,-66.52489,-84.826858,-47.860567,31.139065,65.067462,112.155794,109.640094,49.453381,-6.72168,-28.083916,-52.180513,-52.876005,-65.899153,-58.70512,21.343956,34.534943,-15.783298,-112.916936,-114.527223,-81.199287,-79.91545,-62.104752,-41.662551:11.125762,-60.518541,-59.841382,8.364396,40.401921,45.76903,31.173105,35.02983,66.130975,43.713066,-50.073961,-60.758927,4.308714,56.604244,213.238425,294.821957,348.284008,266.840413,227.465676,236.793726,274.584695,314.548176,306.005121,278.213575,222.240756,171.837197,77.707944,58.052108,87.747244,131.746849,199.578137,177.949647,66.662174,-63.371402,-166.172115,-377.046513,-407.979944,-292.987076,-211.125695,-103.344198,-87.812335,-121.182034,-195.83999,-199.333347,-167.149505,-160.91405,-153.927036,-134.258312,-70.393243,-65.070048,-104.955052,-171.987779,-175.109032,-155.205015,-127.363763,-6.203187,132.777385,161.727712,89.161912,29.74827,25.622734,79.649484,163.633501,151.012893,38.048911,-91.535565,-153.329854,-193.754169,-165.112709,-126.868349,-127.2803,-140.663634,-190.770957,-206.83942,-198.519251,-202.125882,-217.330918,-183.686569,-44.863563,-1.029446,9.205722,-9.326873,-49.263379,-108.7561,-80.238252,8.785465,23.069358,3.825643,18.90298,29.341723,-25.113854,-62.694752,-66.726074,-40.08387,-1.12103,-23.125389,-145.825706,-303.320873,-357.518623,-290.043978,-191.909848,-72.887526,-92.583797,-224.932938,-295.233692,-295.944165,-289.920424,-265.567223,-158.940036,-113.177641,-102.989797,-140.439689,-238.015639,-246.946837,-221.320141,-150.836868,-97.840005,61.678788,136.27637,158.36107,97.57327,83.990186,43.990062,34.507452,63.825178,78.74215,96.957883,81.223155,-17.848256,-106.984728,-131.548739,-83.183288,-13.371439,83.119532,89.458482,80.371063,56.018376,11.532016,-146.043218,-207.190177,-189.886136,-138.589696,-71.669886,-67.560936,-62.097994,-99.398041,-163.68196,-229.594977,-177.743487,4.333241,59.358935,47.638738,9.228716,-3.717481,-38.656015,-59.323103,-136.374636,-171.088914,-113.223819,-42.36954,19.00683,-64.705656,-136.578127,-232.250452,-212.332789,-70.244397,3.431311,106.413839,60.212762,-32.337564,-171.687698,-161.027467,-86.584842,-91.670869,-123.248173,-106.768187,-85.138111,-180.300475,-245.147291,-255.765918,-169.494051,64.800362,137.328812,115.859264,-20.867022,-66.365564,-70.598322,-63.765546,-65.380962,-21.56085,192.14066,279.898976,226.811573,-0.728933,-75.261756,-112.461744,-98.84205,-3.60631,65.122806,113.708879,1.300034,-71.18604,-174.52546,-196.253271,-187.117632,-147.476772,2.878953,40.439407,-71.997314,-221.048824,-267.113361,-320.044333,-306.391812,-171.061758,-78.793346,8.729916,-83.738044,-146.820033,-201.579776,-183.115692,-109.729644,-86.596627,-106.514341,-130.741017,-115.047298,-87.199975,-113.308,-104.868687,-40.858515,71.255123,87.967474,81.802082,69.472563,31.700871,-127.242063,-163.202802,-45.34154,28.777883,101.13778,113.218327,84.01462,13.76756,-19.036067,-44.952299,-25.226874,73.354862,123.134574,118.602962,-6.673891,-73.81007,-174.470252,-185.341862,-107.37249,-54.578567,0.254874,4.158773,-28.54739,-120.367362,-161.004525,-129.747158,-63.264522,74.813167,125.024696,195.309876,168.431355,83.105506,-78.934842,-69.972526,74.769725,140.27314,208.113183,219.233221,215.224852,166.132242,130.168058,79.968066,72.881739,114.102203,171.326497,299.001708,289.200964,229.934252,117.951372,94.013229,107.581555,147.056642,266.830694,295.954622,236.506979,128.452333,100.408071,142.40138,191.761213,270.982955,303.14066,346.764958,293.936488,242.980982,161.93031,140.267133,146.988966,198.166997,366.885092,420.37901,361.028456,200.467467,168.425236,243.55471,311.918891,393.472358,402.973627,411.157062,372.477159,323.850367,204.595901,185.503905,300.850977,372.550047,379.033807,314.722937,184.144493,144.456874,111.245438,11.517842,-8.912342,52.828579,116.884759,226.714591,177.712663,77.907689,-110.95315,-134.546414,-43.575482,50.763841,246.812434,274.594888,149.593774,-25.030061,-97.445154,-160.358645,-118.210035,45.547137,93.873926,45.735108,-65.087269,-79.335092,-21.346861,17.561491,78.506601,103.740785,168.751069,215.979065,291.213187,209.411792,118.360428,27.705793,71.231095,251.668419,312.127603,261.133638,119.969286,74.068281,-12.952023,-76.511115,-158.570315,-110.32634,106.889719,162.849884,78.39405,-56.213526,-84.919012,-94.170524,-80.258417,20.046494,84.451423,127.41114,41.423476,-9.28847,-14.261856,38.173174,112.450008,104.266459,97.656962,104.571251,47.922074,-21.856199,-20.356813,-25.751729,-46.054059,-38.645378,1.155483,43.698959,-57.918952,-111.1128,-98.691035,-48.351668,24.035841,35.983938,30.988423,11.922561:-16.036213,-139.383821,-169.380231,-89.354029,-34.280457,-45.052938,-85.039004,-91.881727,-7.555823,14.982998,-45.18112,-70.059182,13.987786,65.796348,95.333152,114.469232,174.285377,160.672744,130.07911,100.828131,118.469448,191.554589,244.56693,341.595172,301.444829,227.054809,68.451753,35.769621,54.295215,62.230113,73.076884,82.279434,44.322016,-74.306419,-160.844283,-336.37509,-341.715539,-156.311905,-66.540524,-52.355803,-116.943356,-105.374022,-39.515894,-21.658447,13.019847,52.110587,104.648749,73.175147,-14.883718,1.968584,-3.386848,-91.524327,-126.262637,-129.287945,-113.25793,-50.131551,79.901364,138.937881,126.220795,92.51826,114.72905,130.322566,88.913428,65.71645,54.238144,-11.863559,-101.644259,-252.209202,-246.719325,-188.120342,-189.569102,-184.723954,-139.015934,-148.078312,-229.945697,-256.386209,-238.855794,-210.051124,-122.94067,-60.736606,41.283361,-29.782889,-111.457583,-161.645524,-108.30798,-5.848724,-3.772471,-35.593664,-32.801888,-47.024013,-137.658884,-161.934339,-107.183358,-70.942091,-24.491725,-8.214506,-24.858003,-129.778458,-205.579131,-296.106141,-274.535008,-160.36721,-118.076262,-115.314089,-160.882326,-184.842396,-248.646989,-258.024479,-162.317726,-105.63754,-93.809114,-125.257425,-191.418918,-218.14483,-220.363895,-195.943134,-147.441625,-5.152888,39.592608,47.817457,44.976884,35.310267,-35.687386,-48.961073,45.734213,104.392001,138.790671,112.090536,17.600668,-47.91365,-57.981389,-5.677702,51.819462,142.850988,147.779743,99.888638,57.22158,36.931747,-77.817988,-155.889855,-195.809533,-149.665169,-107.072869,-154.874421,-272.306096,-319.625434,-352.807602,-369.366406,-297.871022,-59.937506,28.966143,46.879586,-26.291101,-31.586433,9.023056,11.168143,-48.013694,-78.17784,-51.007368,7.395183,83.331858,-13.9786,-95.528478,-204.375081,-214.317934,-132.143399,-34.527032,151.078371,133.426954,75.478525,-26.240832,-56.24264,-63.553874,-41.781738,1.863436,-7.012055,-24.690186,37.610525,42.602926,-0.521029,13.77967,125.81498,180.446532,209.932117,140.36018,108.088221,99.681101,109.728168,122.741384,143.599529,242.91447,283.111027,259.103128,175.880746,128.57626,-0.352354,-43.397345,-2.055635,54.479237,109.768125,32.711127,-44.96799,-217.978301,-251.45759,-132.167978,-35.311695,63.547275,47.568873,-78.431545,-187.748877,-201.118005,-166.63386,-132.355378,-58.54964,-18.303969,53.46045,50.665965,18.837634,-70.724409,-110.916554,-131.140179,-106.710791,-51.708581,-41.881422,-49.251761,-73.120398,-85.142966,-64.000058,-11.979882,138.379754,197.458121,249.71315,249.031199,234.736665,168.530624,128.854815,79.055292,79.661927,155.522076,215.579646,257.167808,149.708492,91.527466,68.173177,100.869937,167.13773,170.567604,95.853766,-29.435475,-75.873464,-149.458054,-160.961596,-80.484103,-24.277451,1.63624,-37.776011,-105.267428,-61.465231,-39.089864,-60.766141,-82.904397,-51.171605,-3.56725,58.077101,45.995506,0.65289,-120.912463,-144.757796,-121.585692,-104.741,-44.413851,14.378004,131.17932,112.365108,59.429036,12.541451,52.415275,215.642085,305.807528,441.443002,418.934034,332.862184,155.723707,130.027939,185.069414,217.965685,237.526215,230.147732,233.923548,238.675639,202.774862,136.282188,151.04562,226.002484,261.288838,323.795248,294.647143,257.365999,239.430973,253.875213,281.114265,294.009635,355.836615,385.450438,334.057684,243.709059,245.041027,293.670978,305.865526,312.035744,333.210884,346.87285,224.688255,160.982739,103.910711,116.933521,186.962056,208.593083,256.546838,296.797996,277.329397,103.422485,20.902831,-93.264303,-117.845622,-87.734046,-43.60294,43.181899,35.637311,-26.462472,-198.659279,-238.594931,-152.705922,-64.73371,72.074405,78.508148,-29.58243,-148.131956,-185.049824,-196.418689,-162.342994,-70.359504,-37.36828,-27.829933,-73.794522,-67.423307,-28.933136,-33.110307,0.037133,65.613029,204.182051,229.493405,160.468886,31.243605,-12.691436,-20.434301,2.320081,67.274057,115.71877,173.103847,110.208142,85.088312,58.610763,22.332964,-35.18529,-8.063091,104.090586,127.161155,79.346186,-6.405883,-41.711691,-35.116085,20.699234,137.543276,153.988254,121.055535,99.23097,101.085557,92.994037,89.824343,78.302813,63.670359,67.974455,77.761631,65.288126,46.079115,23.894688,-19.371181,-12.727195,22.364465,24.125595,13.933976,6.922545,-22.71411,-144.131949,-193.217666,-177.600972,-113.375943,40.773633,58.209672:-112.856398,-138.9649,-131.244153,-102.216707,-90.626582,-76.828721,-56.030975,2.925032,11.095284,-11.005525,-99.630359,-125.71882,-56.987765,10.365596,135.415927,173.55301,182.296234,121.424558,86.036944,103.471411,160.394071,289.784968,332.145426,309.043466,233.373946,202.03132,93.509462,29.548969,-37.30747,-15.998623,125.578472,193.049354,197.942871,-16.26785,-157.291969,-280.952162,-239.752968,-107.85894,-57.530939,18.010893,-3.581586,-57.825887,-145.85483,-136.536062,-14.362481,47.760305,88.381959,85.229788,101.603,74.439032,2.630322,-122.432875,-108.87364,0.950717,34.86714,46.157334,64.518522,55.678307,-29.735138,-46.653741,74.761341,159.096628,199.490444,159.826215,67.876704,-38.346529,-93.455727,-115.231267,-84.374468,-44.40413,-38.633517,-15.971753,-42.095526,-90.62816,-185.881648,-187.445746,-78.834931,-15.251966,15.551665,-8.408638,-39.892834,-76.159996,-104.575592,-75.368477,-12.592106,85.113711,88.054369,29.337058,-60.572818,-116.605282,-219.86867,-228.438053,-152.4186,-110.345329,-62.826084,-54.473669,-83.203281,-184.952839,-238.047171,-236.105635,-190.310846,-115.575926,-105.522987,-124.011732,-130.066893,-136.482091,-199.761263,-218.160931,-144.975824,-73.184265,31.799475,25.214778,-64.729818,-151.87314,-182.394485,-117.779784,-26.061751,123.833481,154.294345,166.267005,149.598144,115.816552,48.374916,59.936082,162.423365,215.755662,232.844463,168.510709,22.529695,1.430903,-17.794573,-24.123295,42.197497,220.422973,268.752639,229.8027,115.217769,50.366721,-119.389689,-187.994889,-204.898581,-164.456499,-85.682292,-91.140437,-158.651641,-163.970514,-165.53304,-200.147911,-191.994493,-33.180222,79.261992,165.063691,46.163637,-19.224411,-55.419421,-45.138789,-49.189391,-51.597392,-0.361149,36.125604,43.566448,-61.331589,-120.669523,-133.401337,-85.313067,27.03727,72.646199,121.293264,83.852555,40.018664,-34.071659,-40.454096,4.12896,30.05247,51.46084,46.199131,19.900037,-35.158562,-71.700309,-40.16638,39.362392,193.462657,232.910358,233.446074,142.78025,72.536941,-36.208729,-31.178215,89.290783,178.065129,363.095257,391.611256,233.004238,43.466321,1.254556,-42.662506,-49.579511,30.448797,99.039115,124.505698,-56.06966,-173.240578,-338.008129,-353.478518,-249.333474,-153.199399,27.796505,54.285573,-78.692978,-263.487178,-297.279237,-257.691609,-216.171694,-144.301328,-114.71304,-47.365418,-10.664967,-49.47381,-192.825835,-224.674236,-171.044743,-124.079167,-34.282027,-5.860793,-53.883466,-170.638088,-188.042845,-106.180101,-27.681369,135.925264,190.987731,219.168806,139.902665,61.945886,-86.599458,-106.692893,-21.820805,46.156035,141.426173,152.334884,141.061408,78.616958,17.546821,-21.230054,29.466324,136.073604,144.752022,91.920815,9.150401,-54.382146,-215.928867,-240.323004,-109.308359,-41.38749,-41.443185,-71.754518,-89.78951,-106.377956,-134.433609,-147.307524,-116.682526,-15.268064,37.953153,70.183988,-10.063981,-60.000939,-87.22245,-42.831844,62.471629,81.697334,117.412661,157.662881,212.24221,149.565248,97.683081,52.976159,72.642106,199.090325,293.879687,383.736055,244.936196,167.854079,108.57085,103.837608,99.793326,113.719349,158.153084,165.794863,158.732882,125.759112,109.837486,141.348103,176.998226,247.835187,284.089896,305.335679,196.507913,128.900344,73.42937,92.75063,170.272748,203.142661,261.640113,293.286908,319.257549,215.465024,141.06896,124.097294,194.098565,327.950972,336.438456,244.867375,139.240297,102.76407,65.749051,83.113114,183.578707,235.609236,238.190354,181.234056,71.443719,-23.430068,-86.234899,-149.278128,-134.780143,-45.043692,32.087689,144.68206,-3.642377,-144.045486,-326.204333,-325.093022,-205.541716,-125.276715,23.470755,69.503549,44.509071,-178.09055,-298.333621,-310.518904,-214.72997,-66.771381,-50.60114,-58.839972,-93.238225,-141.426966,-229.873247,-213.02914,-101.018159,-49.677238,79.185808,144.120412,143.852964,-15.127901,-93.475244,-138.460664,-86.736881,95.528754,162.699561,153.458396,21.987054,-47.429212,-135.471077,-133.932684,-34.264804,41.217629,131.187547,109.832512,7.873235,-68.379512,-101.87382,-155.881044,-148.601666,-9.526386,73.029885,73.316528,-63.787175,-96.477414,-79.202153,-67.686077,-63.070201,-39.362334,50.520612,71.704504,50.884894,14.81266,-6.394212,-6.357806,17.074969,56.812489,67.727823,48.400949,-49.958942,-118.933236,-229.898358,-239.048499,-178.081662,-111.726929,58.765585,78.909718:-68.117521,-116.644177,-158.831528,-158.816825,-138.983547,-132.664682,-115.50662,-67.069152,-92.193481,-102.417594,-81.750032,-53.996043,2.146691,14.930898,73.843859,124.242796,180.429627,135.194908,81.595322,47.54035,98.654011,272.858809,374.455591,510.141675,393.012539,284.454213,151.054435,116.919243,14.200453,-42.514737,-52.19405,-0.768563,81.442669,-12.761338,-107.021925,-200.505696,-152.76014,34.519819,109.68912,152.667486,92.694577,66.439915,46.028523,36.857347,27.057418,34.552772,47.410308,40.500015,23.96075,33.231599,31.942729,16.517563,22.05193,49.621539,58.250461,76.796612,138.784122,168.078306,141.441728,110.305127,126.579386,158.645581,178.910205,155.019826,33.777803,-120.694123,-157.191639,-152.325543,-155.249464,-182.388493,-168.956029,-108.241803,-106.486746,-122.791263,-134.634311,-128.537847,-147.869926,-171.116777,-131.24467,-63.649684,7.318598,-96.798784,-164.801042,-210.171113,-192.182946,-136.315123,-93.705853,-25.463482,-109.000256,-179.55504,-251.472615,-224.067773,-89.390889,-32.384834,26.971699,35.939949,26.489233,16.494953,-29.418572,-196.557068,-230.292293,-130.450573,-58.204305,-2.673587,-49.639197,-87.025026,-177.735296,-205.926682,-156.328933,-91.588026,27.213458,64.435851,45.586289,-120.732631,-199.717101,-208.500738,-149.463358,-66.823279,-71.764141,-62.069645,42.200043,66.126239,-5.127087,-41.599759,0.542355,50.893202,120.604315,127.32009,84.65276,22.148308,-9.920702,-44.725928,-0.170789,195.528794,267.343902,236.032726,78.314665,18.95472,-54.76713,-95.924566,-150.589882,-122.36035,-27.96575,-61.008163,-271.319105,-376.819928,-398.124526,-447.741566,-424.758493,-190.400177,-38.766061,81.287452,-58.384066,-116.323372,-96.23773,-58.420917,-22.545197,-24.069224,-39.00964,-56.473372,-119.513519,-171.905493,-199.02137,-248.624018,-239.935679,-126.239379,-46.732285,87.242798,172.235456,173.339617,116.925723,117.517234,182.010565,197.058479,177.029877,161.615229,129.757488,93.462041,81.257579,122.652063,169.565045,264.205497,314.154187,342.614229,218.743842,150.829709,80.914405,102.479937,267.672216,358.464803,400.744305,342.80209,202.486787,170.083966,176.275849,149.824488,99.68223,-11.701364,-22.345594,7.027372,-46.980302,-112.258282,-266.49234,-298.808284,-196.605936,-100.638662,19.771283,13.845576,-66.437475,-154.195484,-186.875296,-179.248416,-132.362011,-12.315718,35.87316,100.566281,151.317188,146.196571,11.709242,-74.933176,-161.441532,-146.00835,-9.848519,60.852036,90.660549,64.413176,67.638008,88.755275,110.420424,176.657871,220.519771,320.919168,360.918503,346.194267,262.320427,200.661731,106.206645,113.335378,244.547392,306.762559,270.566198,85.273394,5.271869,16.104244,112.454045,275.682111,272.204439,148.601507,-2.127253,-50.340321,-63.663106,-59.384176,-90.454104,-113.307051,-147.207382,-176.65557,-226.070626,-161.013062,-146.795387,-210.04531,-214.211298,-89.486869,-29.846913,-72.367516,-155.707638,-160.216244,-227.763468,-284.747596,-263.877655,-184.928593,-39.55149,-4.446232,4.61708,-27.343191,-59.628405,-93.492272,-49.098401,117.667554,200.97229,329.515426,307.22329,238.902377,114.966885,105.453459,193.302598,250.04712,265.35363,216.123622,144.512747,151.462806,126.93012,67.34447,91.088628,200.324731,227.804078,196.983985,86.002426,55.941645,126.872421,179.912213,235.438751,245.310071,260.338389,288.898958,382.670918,358.251777,289.276373,216.440028,256.564308,345.537325,346.092898,311.50677,194.538272,108.204722,22.191581,49.753869,171.88621,220.313953,248.338953,239.445697,210.395962,160.320029,111.463719,7.334034,-18.74185,-35.652338,-34.456911,-7.819766,-18.014366,-59.093333,-183.265347,-213.283933,-92.446805,8.736798,81.329507,48.699073,-56.807321,-210.678428,-286.659233,-256.488839,-150.393336,-24.519924,-57.429818,-170.653309,-193.734046,-173.059007,-150.134796,-157.7299,-120.511055,-54.912644,93.33604,128.647549,100.725289,19.15176,-25.54209,-77.220736,-54.412351,73.878716,142.248001,203.289313,154.905484,120.827522,34.982311,-29.428117,-122.82628,-114.388704,-1.088976,50.892594,43.078984,-6.094745,-32.438351,-62.490833,-16.310217,123.095162,131.640542,-10.276934,-145.016005,-129.340313,-2.027542,34.92904,22.596006,10.745328,5.846948,-2.805511,-34.21444,-39.39561,-34.766713,-41.995564,-52.287344,-61.316592,-64.847232,-89.631001,-73.809227,-71.311492,-201.688413,-300.425524,-357.956158,-278.166537,3.208101,83.81797:-34.371821,-195.310857,-230.537944,-132.792088,-83.471675,-88.201843,-83.407795,-55.178294,-93.526052,-113.939951,-159.143849,-163.973508,-50.317987,42.453877,178.939948,199.331229,167.295039,72.186665,7.703036,10.133402,106.44692,300.201925,338.015004,317.398225,213.084464,128.466722,-63.2561,-123.625358,-97.351661,-28.026378,132.143864,179.765822,130.031758,-58.60057,-147.353695,-203.746587,-147.678868,40.404032,93.611769,69.000128,29.019694,17.547941,-15.1884,0.978276,139.819398,215.865541,277.793274,252.763334,152.493221,95.653171,71.58805,46.132764,72.295325,169.205148,191.373888,154.837445,130.892769,125.972412,94.117227,96.351284,166.422194,202.207257,251.33442,256.193515,131.02509,-68.564694,-124.243387,-138.948537,-95.968404,45.592914,93.139269,50.989262,-102.299518,-176.905472,-287.48041,-292.468607,-185.364996,-119.331322,-43.946322,-16.59603,53.048951,0.043541,-93.537425,-193.739653,-145.73608,6.272961,48.664305,43.557205,-77.366805,-160.857332,-262.309241,-237.448169,-65.456618,18.532412,108.528911,126.619145,135.446333,77.590779,-0.378906,-147.656597,-159.94113,-96.743783,-59.46419,-24.63995,-79.525242,-138.00932,-262.726365,-286.943412,-163.426928,-39.35048,117.500684,103.71773,-10.444506,-127.523721,-178.605788,-226.184651,-199.422881,-27.033414,81.792602,178.609275,92.127673,40.271858,-13.88111,-5.635869,77.900126,129.293656,200.488642,208.085393,163.627486,78.86738,52.460522,105.122023,173.179128,302.238852,347.578624,354.884143,197.528705,82.776608,-108.513137,-140.031799,-68.5608,-12.46341,26.112408,-14.369926,-165.049906,-247.285619,-254.994846,-249.877707,-206.339181,26.486925,160.902755,249.665037,100.931388,20.319855,-36.681825,-2.589595,138.527578,199.11999,256.261973,253.345021,162.043744,5.242288,-64.70076,-126.51708,-96.508984,44.266433,120.324041,229.348525,204.845413,143.097695,45.736671,61.545275,198.496244,258.211364,283.626507,246.925722,100.083963,-9.711936,-18.932366,37.646036,84.113888,200.673521,281.179321,358.864076,175.144773,52.64658,-78.959845,-61.254998,73.488173,138.747313,231.999818,252.529342,184.368447,47.57313,1.036565,-24.486631,-10.621982,50.603758,88.520454,86.305777,-89.803968,-204.445268,-373.675338,-388.299714,-237.714789,-110.541351,90.678722,120.115375,10.585836,-182.196507,-240.957433,-262.795495,-240.285133,-132.063446,-64.271215,-0.950556,-31.18075,-77.018714,-198.657557,-212.442571,-98.274068,-18.048361,86.572695,93.423794,9.438167,-145.614071,-196.023241,-113.443049,-5.28991,175.170233,243.389923,340.86895,271.590665,192.750552,76.778224,55.937423,51.950858,65.783357,162.351412,222.882322,210.896732,8.570717,-68.146496,-42.851256,12.227383,90.871799,121.872428,128.873544,-2.380431,-73.359412,-149.042218,-155.722913,-128.40334,-110.372334,-76.207768,-67.992015,-87.707984,-128.78308,-158.661587,-195.18308,-166.0926,-2.275068,71.020372,20.48329,-179.331291,-242.785539,-263.612561,-227.822626,-99.609553,-41.112063,34.742116,60.305603,111.952666,108.715004,47.39794,-63.141935,-34.342807,166.884926,277.334456,365.50877,217.48258,117.399634,29.838642,53.860769,156.140036,196.228841,206.626084,186.203522,166.611622,157.95063,113.665778,53.712309,112.974698,317.899106,365.534058,296.034445,143.516994,79.912383,54.967128,97.634132,212.515889,262.611189,346.579073,360.218191,267.881145,121.570209,88.11032,116.001151,151.668316,214.726364,245.607779,252.521463,147.639284,94.622834,-3.144713,-31.275105,69.501037,161.427456,242.573065,222.554854,95.46162,-84.097148,-158.939257,-232.371146,-224.991939,-128.855487,-47.430287,70.43592,2.402455,-90.788525,-294.869968,-343.525191,-261.668682,-168.526912,-31.06063,-18.011893,-94.955605,-278.946504,-377.591022,-416.547117,-331.037463,-143.341298,-121.383504,-160.521088,-202.542702,-242.327122,-325.188822,-329.777672,-234.096271,-141.06439,69.433386,123.750941,73.318819,-64.585797,-133.637974,-185.455351,-137.385689,19.178051,67.090793,51.998435,-43.327474,-72.020355,-90.027013,-112.122354,-159.755064,-126.684452,52.121857,103.537599,16.369329,-124.738894,-165.895614,-177.922462,-141.192091,-32.357084,5.462742,11.34126,-32.92403,-68.363638,-145.152132,-153.549027,-73.508926,-7.885244,90.081065,98.893381,44.96639,-29.085642,-65.813882,-88.876305,-40.804234,93.653246,118.684115,55.216367,-79.251485,-155.295219,-304.560713,-337.262249,-245.316631,-141.374983,42.619344,48.617656:-172.331978,-125.955796,-75.531309,-74.25658,-111.854083,-143.775579,-114.528131,-24.134849,-27.973428,-38.124561,-25.705039,-13.288207,34.159687,53.613943,83.146615,122.788428,237.653244,267.125031,232.831758,218.067155,276.775151,465.939469,549.206269,560.448235,358.927831,259.053619,168.179969,141.600965,39.905349,-2.592635,54.282506,148.972101,294.861757,216.386812,120.165141,12.288792,40.310522,157.758975,208.901576,284.514504,271.457545,229.063796,139.862451,123.474782,172.577688,209.896883,212.003083,169.958959,75.68469,101.452514,165.694958,272.71645,281.782578,241.695774,242.140518,330.621143,402.125479,419.743205,405.213326,357.702647,270.267179,262.900503,309.544545,317.784371,152.786505,-102.185113,-149.234306,-96.977477,-49.616215,43.404087,94.647449,168.21622,77.830732,-12.829383,-111.189763,-96.225073,-22.86621,-6.296448,-45.054754,-74.523548,-102.365113,-134.71998,-169.441041,-217.891273,-203.237662,-112.635525,-73.667213,-88.226024,-162.526542,-171.540805,-163.495983,-162.130116,-119.29017,-85.301103,-36.998876,-9.144987,25.382969,-54.178316,-94.614939,-58.671268,-8.532435,48.80238,74.462403,136.078171,75.74269,7.676837,-100.905759,-112.673234,8.182552,106.495909,162.053657,103.664857,-26.448401,-104.415021,-133.241132,-156.556804,-158.857044,-144.936588,-112.772152,-57.327719,-84.270607,-83.830013,-42.960694,-44.545357,-89.525725,-83.896305,11.903099,48.248388,60.604761,104.614879,108.657381,37.24563,28.42495,176.761971,276.519639,331.260837,224.867229,175.193998,120.333078,96.245675,64.564727,65.203303,46.548861,4.423896,-148.733605,-299.897098,-332.166737,-288.766212,-229.91526,-88.903226,-25.814769,23.634882,-55.920495,-90.230676,-35.77247,41.709091,144.23066,122.315124,17.483063,-17.609883,-53.777666,-79.604373,-101.13225,-150.204705,-132.072347,2.048668,76.63633,209.957108,304.314993,310.180012,272.440313,264.850848,278.633174,270.929761,226.179053,202.489126,136.235011,64.699369,26.307576,-22.355299,-6.841651,78.750358,117.481056,144.773981,131.358912,116.092922,44.398654,9.400251,42.053605,105.374852,223.415547,234.362047,151.196109,97.969708,105.939496,96.888812,47.331561,-92.622148,-125.35119,-89.033494,-61.130862,-88.663842,-224.865631,-279.330291,-214.469012,-116.119193,20.616725,4.570002,-108.374506,-134.775509,-128.431819,-92.359874,-48.401132,6.454508,-2.01962,-13.197977,31.093648,45.218202,-36.088199,-109.453398,-170.078206,-157.970401,-157.916821,-167.626024,-139.740541,-76.245671,-57.739318,-34.407307,-12.80857,44.29796,73.845779,154.933852,256.372658,288.762008,223.149423,139.52857,30.069427,43.418088,156.779597,194.590597,154.84008,98.844616,86.267835,78.667052,110.964908,210.886699,229.11555,138.291939,-54.18517,-114.230898,-112.48371,-105.509402,-155.019494,-183.990251,-219.956633,-239.902576,-257.517767,-229.550499,-230.374818,-230.789926,-190.866348,-85.141818,-85.748195,-220.308175,-320.826715,-314.805599,-308.133608,-327.498127,-315.665005,-268.352097,-139.861571,-81.370462,-32.974776,-58.487076,-85.01243,-132.20378,-121.033499,-58.750568,-44.424417,-11.875033,84.313181,103.973859,22.081236,-20.396525,26.758421,101.8207,232.713977,234.686519,105.649009,-8.936523,-25.696415,19.499616,68.655164,62.808495,-3.054512,-82.944654,-59.485078,-75.231721,-189.009929,-212.333969,-82.054263,12.434368,141.378702,190.494081,229.463657,181.738301,156.826685,135.769244,136.820398,123.24844,122.567993,192.893033,227.972071,187.832514,72.983461,49.174235,100.584311,149.136166,232.869184,244.90872,182.571053,86.673043,45.152656,-14.266146,-25.515924,-22.418679,-2.364657,82.864974,92.577328,41.670925,-117.650828,-175.796742,-134.564132,-80.504779,-83.465596,-120.524094,-175.844753,-262.909594,-312.00018,-308.471832,-251.356397,-185.548984,-207.932003,-252.330392,-236.650452,-243.733125,-306.484177,-326.757665,-288.574266,-240.769164,-138.707595,-105.710155,-101.782644,-94.382436,-73.481023,-97.845724,-127.386002,-60.545479,30.379149,151.502963,99.240117,48.115873,-40.417118,-80.386787,-119.750725,-86.855446,60.201532,97.555789,16.789703,-93.896179,-123.82889,-107.647388,-40.550104,96.632988,78.79242,-118.878516,-182.920339,-99.559082,73.131708,70.729235,-37.687761,-63.011085,0.194778,44.357691,41.818619,-91.993351,-165.401068,-175.868867,-112.506688,-24.45234,-46.937687,-188.257353,-296.507847,-296.896069,-272.783274,-263.939078,-204.381591,-160.78788,-44.026803,9.863149:9.294601,-51.187227,-69.529934,-81.765586,-90.003191,-107.00556,-95.010148,-4.223203,48.8683,20.823404,-83.750548,-101.541696,-23.04828,26.781713,100.135035,147.227137,261.468181,281.814414,245.691635,218.117886,252.005866,370.603721,444.864602,522.871663,359.413298,250.685158,167.93353,155.509233,41.135986,-26.326315,-23.101462,50.372315,210.863231,210.332931,139.306462,45.549567,75.534205,160.67727,165.454017,154.381018,182.322164,183.214304,84.185096,18.22065,-25.10142,-20.847283,-35.068196,-29.66808,26.422565,36.003577,26.523252,50.364674,87.504781,148.735288,141.687481,91.287857,180.00456,257.212304,283.862855,236.486423,162.722023,157.104508,182.076743,184.107215,88.059244,-97.79886,-172.082121,-218.024792,-215.770359,-245.412482,-241.554079,-111.477012,14.173299,4.138873,-140.896145,-207.052522,-204.051561,-160.680395,-70.945951,-33.596423,-25.853667,-152.764891,-234.628765,-327.770422,-311.906418,-153.585895,-59.754182,-8.216444,-124.227399,-153.245116,-110.456243,-87.463216,-63.672871,-56.55527,-47.12073,-45.23244,-85.009597,-151.025285,-167.305903,-161.465206,-155.71687,-136.815533,-93.391353,12.042805,-2.832456,-28.852269,-64.728726,-79.712789,-31.049943,51.0538,206.305427,217.311717,115.087802,5.403867,-33.652593,-47.469261,-8.55105,80.791119,96.761612,87.993397,106.652873,120.524978,91.796217,53.89935,29.449864,70.281685,187.074189,202.700356,124.000821,73.838077,70.772981,37.413489,31.935696,126.472578,194.13878,208.306645,105.09848,86.649602,146.632483,173.448626,154.196463,123.632595,-13.77589,-123.691509,-294.547952,-333.891306,-354.176283,-409.355858,-375.548451,-143.676062,-27.460846,21.811909,-144.092261,-209.143453,-166.572502,-95.651531,-35.526829,-65.623418,-131.520972,-143.876414,-185.594675,-248.769144,-260.85975,-225.536312,-180.824219,-89.212617,-55.028017,59.658139,229.479871,278.872388,290.870533,280.394307,269.486775,271.686895,276.252157,261.697881,200.766489,163.13828,150.675366,120.824916,120.972925,172.811862,205.531382,261.293192,278.505554,250.787918,137.958993,100.190404,154.785123,237.338401,380.863595,371.376018,216.114202,161.114796,179.922423,136.348679,54.977531,-71.184755,-63.330409,-33.408666,-134.013432,-173.103477,-220.989868,-249.458661,-197.145355,-114.95867,-4.422986,-10.382056,-82.792644,-106.076791,-87.683598,-23.656653,7.200087,8.294226,-7.758875,9.555225,22.148601,7.674637,-35.564919,-66.030686,-154.765958,-194.249745,-175.769777,-132.778308,-98.883006,-63.927278,-22.29943,-1.57445,-10.358127,79.267541,174.310867,306.228102,310.51654,309.758994,313.260181,302.594715,279.886904,288.290121,321.317216,324.06806,291.408859,224.26205,197.86656,182.160524,189.697941,220.441729,223.14908,140.459408,-7.605885,-40.606971,-53.037068,-82.220103,-132.18819,-122.271306,-123.38042,-180.29766,-303.214917,-270.519814,-256.686893,-304.864305,-307.195129,-206.343703,-146.960192,-92.588496,-90.350488,-103.859123,-207.574149,-272.640477,-289.041612,-224.17656,-32.505037,44.209768,96.632525,19.262505,-62.959074,-191.151206,-183.91589,-92.516267,-46.759686,41.496373,84.360222,70.420829,-29.99947,-82.841587,-63.574956,5.915934,137.7631,163.484478,134.397318,60.748037,39.376542,75.487246,103.133981,86.544347,66.779018,55.129979,16.083655,-4.630919,-18.278491,-0.636866,87.682429,134.783676,236.462715,299.353627,364.320941,279.070951,217.855322,176.896315,205.134645,244.722711,235.627009,216.355461,158.739497,93.520368,-35.288167,-59.451707,-4.613625,60.841529,204.123237,243.185122,226.825769,217.548211,206.764785,88.470967,7.325533,-109.102299,-127.886833,-115.274875,-103.340096,-109.512382,-149.04804,-159.000538,-112.352649,-73.586149,-53.492568,-75.241946,-134.009305,-273.711804,-359.125177,-378.5298,-318.319008,-239.486379,-240.049904,-262.759632,-263.730887,-250.91481,-221.011233,-203.074016,-160.448321,-126.716756,16.043925,81.772113,45.146598,-91.960041,-134.577603,-167.010592,-148.281071,-9.43583,82.969299,174.20964,113.065716,78.731119,-3.032671,-75.793353,-162.068686,-129.955133,-17.249996,5.121361,-69.097703,-198.983087,-226.14834,-155.638752,-63.275476,134.848131,188.338948,135.630476,8.272689,21.853647,111.029444,84.982329,-44.513254,-63.69623,-18.29759,-4.657399,-3.684314,-54.148871,-137.453357,-315.112429,-322.474294,-205.013116,-173.414211,-224.102313,-215.294736,-158.719242,-104.95168,-135.427172,-190.368238,-181.6794,-107.369267,-83.09179:-66.870825,-81.066497,-104.643612,-150.347928,-169.26259,-169.960003,-145.759516,-86.985232,-56.629218,-54.319061,-73.048114,-59.383273,61.501526,118.84912,163.846811,172.194804,179.259443,158.42646,121.325787,77.240701,116.410876,247.427779,297.133783,339.747535,258.600521,183.618949,50.249646,-4.125816,-103.067062,-123.783874,-16.656906,102.732775,235.936655,45.837236,-57.385451,-52.274796,25.619172,158.390288,184.297694,141.520918,29.582402,9.927498,72.735133,139.029366,301.724268,347.672525,291.526582,212.814433,75.221052,51.245797,67.046278,132.65185,173.205375,229.97172,259.827311,310.043267,276.541536,255.810111,226.952366,214.123621,267.639108,326.578598,368.657465,317.7862,101.552316,-96.737476,-149.025174,-176.038675,-160.703504,-71.055638,-4.835095,46.286153,-66.744455,-139.21672,-245.170236,-242.599883,-125.466216,-74.073898,-44.649876,-35.055861,-8.394747,-68.395849,-137.450285,-180.154316,-106.121236,61.134777,75.26329,-3.291239,-108.640124,-153.067965,-187.564061,-167.457094,-66.009831,-17.184738,36.988129,77.60764,208.211141,218.057819,152.011084,9.016653,-15.029307,68.493478,131.415919,108.934341,-43.842887,-87.517396,-82.755017,-46.198191,12.663298,10.378709,19.150245,33.525279,-44.94864,-224.782484,-284.265993,-282.194556,-232.614065,-119.543846,-65.582964,17.900759,-20.080894,-57.537462,-157.879667,-205.604005,-126.711025,-33.298785,55.994848,59.319892,59.061864,51.567189,47.485878,58.51552,90.38248,237.202648,319.788177,321.323003,182.04816,163.704817,132.90487,69.456112,-37.962813,-37.997235,-3.528247,-32.533031,-184.255208,-278.77299,-302.645884,-287.303282,-200.322805,44.75517,109.641045,100.886332,67.397062,74.719934,104.16325,130.836516,193.899288,188.443818,123.858706,107.934735,78.172753,-28.275415,-81.8763,-140.527381,-121.102602,44.220679,153.848136,273.523703,234.482874,202.840566,137.199784,114.443118,166.930835,217.816216,225.018294,188.306299,125.799585,114.872654,109.455534,107.236747,150.992717,291.927633,329.719289,305.884346,199.4202,130.921582,40.357528,68.115732,212.860234,236.623094,213.245177,226.949671,197.280593,72.808556,57.032666,80.573303,65.253532,-5.431387,-29.919758,-47.721579,-100.902513,-138.857519,-159.998777,-131.720176,-65.993962,-43.019448,27.711592,38.514834,-66.108953,-135.462839,-109.434925,13.901517,58.385254,4.532184,-36.403737,16.590496,97.857075,79.085914,-62.101533,-119.323275,-64.097912,9.989525,86.492767,82.104029,40.702783,-22.696317,-51.778612,-22.42096,42.097101,184.630513,245.237901,321.833064,288.831676,239.398649,100.754011,22.060895,-36.451684,15.285758,152.079005,159.066189,57.534814,-4.312186,-1.323183,40.045548,84.598098,166.595651,159.02037,67.544519,-65.023882,-145.23387,-240.397362,-221.948009,-138.540828,-131.400603,-197.328134,-231.261698,-229.620808,-180.356991,-177.882142,-168.062002,-125.366063,-15.737275,8.26202,-71.411836,-264.391524,-331.603966,-315.386195,-270.672675,-258.475513,-275.337231,-203.647832,-130.519554,-54.274701,-42.230196,-45.58091,-82.98257,-80.837629,13.457888,85.679721,189.195931,132.824802,74.329974,20.413894,24.239694,24.758068,34.009765,123.997158,173.221152,171.785706,89.772669,54.221829,36.361873,62.315017,120.140481,133.531281,165.499322,217.789932,200.999192,58.728965,16.120903,83.678012,123.491944,137.138937,158.838951,220.571448,167.838725,121.55512,47.390055,30.010111,73.087261,128.87482,194.871346,89.100158,35.602777,-4.887357,-18.662451,15.155246,74.767097,200.611767,241.481387,201.658528,12.560371,-55.078349,-89.278391,-113.971661,-195.107854,-176.86175,4.114652,100.464646,47.326021,-179.583466,-252.795031,-199.072392,-136.966167,-116.654489,-152.210207,-217.689543,-299.382953,-341.57596,-311.163926,-252.716136,-228.974287,-279.401488,-340.832328,-294.945066,-278.742598,-289.209978,-282.752117,-182.814281,-120.778212,-54.419131,-40.270895,-39.07096,-72.513713,-93.352471,-105.503435,-91.099924,-55.218674,-36.20722,-13.66691,-17.376757,-18.265347,-71.699406,-133.548805,-198.551875,-149.909135,15.781196,39.460766,-50.094186,-104.274966,-123.014878,-168.860916,-143.818919,-17.776066,19.59383,-63.487773,-221.845091,-228.006611,-140.442946,-113.292851,-90.601873,-62.235276,6.639472,28.288819,53.899632,-1.764342,-46.887436,3.551849,84.974094,134.227495,94.486298,-1.383796,-79.417417,-91.155135,-108.704433,-156.423906,-250.225835,-229.47876,-97.401448,-58.638561:left
-161.522945,-74.616189,-37.629225,-51.467911,-121.87356,-309.062698,-348.823954,-258.812886,-124.792627,-78.319138,-61.514214,-107.404239,-252.342503,-313.137432,-319.814708,-248.076036,-65.22275,-32.1042,-76.66732,-175.772866,-204.652523,-227.901966,-217.126673,-162.317675,-119.133929,-66.223518,56.419156,49.801697,-89.564363,-159.790037,-168.875917,-106.719974,7.039793,27.506416,-4.337072,-179.893126,-288.581066,-404.402968,-392.325918,-301.538184,-211.773339,-183.436806,-167.02126,-136.568331,26.194345,103.558477,135.156815,113.402313,120.194428,193.754683,192.435447,96.16159,39.523319,-36.670745,-30.56676,71.480302,179.947131,228.390274,244.289355,187.466969,33.17399,-29.887423,-77.221266,-55.305025,-31.118772,-95.114903,-122.885362,-148.434632,-158.031589,-180.78594,-178.400748,-139.288862,-85.006328,-65.082037,-109.108651,-152.258047,-163.687059,-134.711924,-59.577975,-20.989521,14.559281,-7.493746,-19.519871,-63.68466,-88.049829,-80.223899,-46.454692,22.571319,22.010962,2.3522,-30.076636,-37.25577,-88.423099,-123.191462,-60.852137,17.630343,55.443384,54.441449,115.287133,200.82854,191.068095,167.614506,180.72209,212.509644,235.25436,285.999888,443.839743,506.627718,505.823614,430.594411,278.728695,270.025479,352.676538,427.672371,428.054003,321.943784,235.917908,104.65462,86.810054,120.524759,168.750663,198.562953,259.692913,267.610503,238.091685,216.512356,194.045171,193.89301,188.913723,191.699905,190.416449,138.5203,82.724967,-44.716271,-70.279917,-23.169283,14.549919,33.940014,159.314871,243.548759,343.970386,344.031049,313.610283,323.377439,384.544111,405.478917,380.643221,302.949229,269.483821,183.909154,127.028831,42.792818,62.632002,113.659681,188.105071,173.31507,95.366016,66.133477,29.320943,31.438891,110.131255,206.923843,218.745991,179.83787,137.763458,-6.725792,-74.017736,-89.32093,33.328319,112.145171,193.027781,184.12535,138.050124,91.977,-43.576115,-66.69257,13.315935,76.778528,69.230288,23.67814,2.186765,-63.500374,-96.565837,-86.086218,-24.881443,-18.804427,-72.00027,-103.686106,-143.279308,-171.430438,-215.614102,-199.535683,-157.531307,-188.861643,-193.577517,-138.926698,-112.341521,-145.075726,-189.813141,-219.024628,-92.800791,5.61336,143.818394,158.188574,94.527639,28.112812,-76.089756,-78.304472,-37.550841,-22.319219,-14.177562,25.207508,35.21048,-43.476729,-103.967984,-118.482302,-7.079534,43.215061,39.644739,-2.912847,-79.009559,-111.745269,-145.249606,-130.388335,-122.476941,-143.5587,-116.617023,-61.23126,-85.368919,-223.753342,-279.805374,-297.741387,-226.79897,-134.962669,44.326239,62.009297,-29.871962,-101.743245,-155.332197,-123.502412,-93.386893,-115.35465,-108.032527,-102.800627,-119.194221,-185.704021,-214.686373,-172.424567,-34.320587,18.65559,12.136261,-44.934532,-194.218182,-250.132041,-225.680455,-150.925092,-30.119734,-29.803334,-49.075337,-59.608763,-44.440575,-35.865397,-51.46808,-85.133847,-80.402797,-50.687862,-14.294337,-37.615675,-120.658776,-164.973136,-257.347293,-287.607869,-277.82081,-189.591437,-148.29548,-116.931108,-119.866389,-176.919959,-216.437059,-221.315719,-167.066883,-166.618454,-218.647817,-237.190611,-229.735078,-232.583978,-282.969259,-295.130247,-246.472325,-191.026642,-193.117222,-223.024097,-233.045326,-273.296728,-288.546691,-231.194178,-111.9302,-51.700423,9.96173,-29.505217,-226.423491,-307.736756,-282.93377,-189.790221,41.684452,193.333342,194.103631,69.338916,1.981857,-57.858346,-61.30608,-51.665326,-31.945744,-9.54842,43.219948,55.568621,2.839893,-59.185057,-129.229329,-100.113301,8.211505,36.027667,23.022128,-7.456764,-16.0893,-36.867547,-62.687183,-143.166804,-211.329435,-221.678167,-252.339551,-311.138285,-472.115333,-534.388865,-593.5638,-597.442368,-567.533927,-428.028015,-332.707733,-240.746424,-289.276786,-545.1287,-654.349474,-622.377172,-362.022109,-228.037263,-100.222756,-144.931185,-365.828398,-442.024667,-395.16122,-324.796366,-242.852362,-175.247679,-138.201001,-144.298991,-182.088562,-266.143796,-278.856583,-205.176281,-100.497293,-49.622277,34.390475,44.431971,18.039024,10.616909,42.57511,75.782584,112.262396,78.81334,58.893235,-7.097004,-74.666391,-240.103452,-289.397745,-232.61203,-105.388416,-77.33457,-52.13217,-22.215984,20.614175,-14.799286,-89.216043,-58.700894,74.313672,159.622572,147.945385,45.283432,18.36787,91.887309,155.296814,202.307731,172.703022,172.080923,160.917316,134.882694,58.949391,6.03628,-46.097343,3.893469:3.17424,93.434202,61.38804,-63.965732,-122.203558,-226.849805,-235.261025,-119.952439,-32.56627,-10.691251,13.054761,-22.21267,-162.958327,-220.194615,-256.534719,-230.678223,-117.465458,-104.654775,-173.378294,-292.60238,-292.549863,-231.719161,-193.319406,-99.14468,9.94078,61.474007,108.857606,84.797369,-57.320045,-134.815532,-141.733253,-73.788338,32.392062,9.091788,-46.857911,-190.250946,-239.411769,-271.569769,-263.258348,-160.930393,22.422965,56.19786,-43.794246,-69.91814,57.381913,118.730128,101.752746,77.02141,89.19852,90.929811,58.182616,-18.535735,-44.72316,-67.169247,-45.305091,35.024023,127.58349,193.866634,224.309911,135.876344,-124.524581,-206.730141,-191.032073,-130.697414,-6.05229,65.775152,50.260665,-87.153508,-168.155506,-257.028063,-249.53253,-150.967534,-17.832375,32.482012,44.706644,5.291939,-85.937913,-117.86624,-127.373037,-98.652603,-57.524439,-86.085015,-99.090793,-120.211942,-144.899317,-191.147603,-179.077086,-85.364065,-5.534392,-8.71877,-81.070119,-106.181765,-94.939468,-75.973829,3.276874,48.530536,111.277426,200.701318,227.967496,197.591642,173.126385,153.710345,153.749858,181.422485,293.934311,379.044755,473.160081,453.040926,357.583933,323.307482,332.047302,348.056578,344.627205,345.061429,340.126801,246.247989,145.431579,-36.341647,-49.690964,74.849095,230.061889,279.517261,350.110288,368.90129,296.604201,224.591116,154.082834,164.92624,218.853497,253.032107,233.955219,138.571225,92.008256,46.497598,67.834736,146.900039,135.926648,124.984084,192.440158,244.888115,291.407714,271.005503,184.620186,168.354551,227.497262,298.070981,290.93574,140.729169,32.004831,-97.552452,-82.53769,48.506179,112.460092,119.74975,163.843423,178.651347,117.296476,50.67589,-51.485538,-52.332552,41.37152,141.892822,161.144396,132.047414,75.766815,-77.842432,-113.566743,-49.496016,58.645842,88.526283,62.276514,19.875606,-63.698037,-106.586657,-181.521075,-175.508153,-45.527957,58.54666,33.51572,-105.292334,-155.490623,-160.310211,-133.988872,-61.577605,6.498746,26.197031,29.428988,14.389783,-54.554546,-106.778957,-156.899257,-124.661876,-27.470305,-7.300865,-31.177916,-94.009529,-120.844827,-210.118384,-276.369582,-339.226232,-157.396233,-14.870109,119.401219,73.189336,-96.107279,-149.555241,-150.326023,-130.783731,-99.869008,-16.607302,19.372823,28.217175,18.086665,-50.534476,-97.767509,-101.003894,37.648722,93.578309,9.503716,-97.280742,-213.684491,-201.170813,-126.29983,-106.492958,-140.69486,-152.156237,-140.910643,-151.374694,-177.059171,-274.104816,-320.66161,-321.30966,-216.949614,-140.167111,6.527962,23.986895,-138.698282,-263.489725,-318.025893,-217.668393,-4.516879,4.457333,-42.327159,-157.055789,-203.52231,-233.18004,-210.947703,-127.399177,-42.234896,-16.462101,-38.302526,-84.349472,-235.280461,-313.029453,-326.828447,-251.694946,-73.558722,22.92502,20.022289,-34.521711,-39.571145,-28.678286,-43.111264,-49.9039,65.543931,120.047731,81.691098,12.119925,-114.579483,-156.918276,-189.182627,-200.348324,-220.614659,-137.42191,-73.011356,4.307087,-6.806578,-81.134185,-82.226192,-14.483248,-45.458393,-111.697945,-227.331203,-233.355593,-187.823039,-183.563281,-229.560324,-243.944929,-145.580311,71.422304,128.186609,32.1396,-73.514384,-232.498137,-246.342359,-137.197986,29.065814,88.301622,56.889921,-44.23922,-246.855054,-276.649519,-173.42404,-90.663064,18.248784,61.659719,66.259527,25.610367,-14.34288,-87.627363,-94.232088,-61.013034,-50.268201,-22.634322,68.951343,72.216792,-63.164636,-158.772472,-229.728926,-181.402945,-23.96656,96.964795,122.875717,97.774402,63.630759,16.722491,24.719299,28.834487,-78.97739,-125.694268,-179.388281,-222.268885,-373.790739,-469.682634,-571.950507,-539.741697,-388.56336,-241.040394,-196.685209,-200.826369,-237.093316,-352.365605,-406.874216,-407.960082,-285.385756,-229.118879,-162.614095,-159.402414,-249.661945,-327.349908,-392.164204,-336.170481,-165.293337,-64.073845,-33.773181,-35.572256,-92.584768,-253.113269,-286.217039,-221.767559,-133.662809,-109.101617,-112.786359,-150.710264,-244.069064,-267.954589,-250.7701,-222.999601,-159.652966,-78.920702,-61.748953,-139.415697,-206.815573,-305.589609,-339.249154,-368.091104,-312.991937,-262.01367,-167.973319,-157.789418,-224.485894,-265.311256,-283.86389,-260.91211,-154.174807,-0.748178,21.380862,-83.382549,-124.210299,-72.223173,-32.337625,1.671515,37.339384,50.031101,56.13799,51.48558,-31.63742,-101.562573,-107.625344,-22.025035:31.755378,85.756855,36.34445,-122.207828,-157.445915,-144.184943,-131.318465,-101.708848,-48.256663,-8.780132,54.241863,39.007136,-90.779199,-160.581021,-216.525441,-195.926372,-114.210747,-76.607362,-90.770188,-173.291334,-220.670389,-271.798534,-251.717952,-115.153447,36.456838,92.938227,139.695887,105.83781,-37.989739,-91.941416,-79.837254,-30.945907,45.491007,-0.848648,-44.760293,-95.181073,-130.357345,-234.478259,-249.290832,-190.589748,-110.620438,-85.201218,-110.36954,-135.928761,-113.178458,-64.118214,35.084013,49.691026,29.030931,33.615657,8.832035,-96.831542,-121.973063,-107.059202,-91.784422,-38.335129,91.261795,150.28341,74.908988,-38.419115,-170.996857,-167.723599,-130.798868,-118.764596,-82.413597,12.119875,41.481596,-30.060671,-100.811746,-197.484588,-204.17886,-147.460311,-64.511514,-33.941551,-49.673638,-96.215601,-178.290602,-180.247725,-122.560805,-99.619677,-90.625627,-83.158322,-74.158838,-52.890622,-71.563241,-177.587498,-204.918073,-146.853994,-54.104384,-11.033679,36.826424,24.479913,-45.372444,-69.409176,-34.160527,5.498615,99.064748,187.790796,175.797329,49.13655,-5.9904,-3.882688,58.573214,232.332811,385.540362,457.319635,524.709276,502.04966,402.852038,343.17586,239.346926,220.84932,291.913599,434.659126,448.320084,293.923052,193.724958,94.801678,96.286202,166.735684,291.38522,337.464351,354.927609,342.334318,252.1311,173.953538,46.586023,12.703328,9.637633,76.484114,95.959994,93.724127,77.12195,16.973239,-3.443895,26.598035,147.340461,202.199678,204.539678,175.733141,187.571626,225.580062,268.728045,265.834321,286.076774,334.593962,311.531568,178.16101,112.633666,5.77206,-28.270198,-25.834577,42.378403,92.270085,125.360808,86.875232,-0.427387,-20.246728,-14.443516,9.1187,59.07772,48.667962,32.696272,17.596085,11.6626,-15.780123,-28.071915,-11.487571,73.759039,105.517749,70.332376,17.939016,-100.960443,-146.700379,-167.593288,-139.925085,-9.904113,110.852616,99.53822,-26.624581,-70.458061,-61.811007,-41.589637,-3.459862,79.388391,112.743982,66.556133,19.147876,-25.056726,-56.794167,-140.819882,-137.373915,-20.777061,61.668392,48.780405,-14.818285,-57.283289,-173.299643,-205.786101,-158.007855,-20.650979,50.186597,72.51066,21.195796,-93.239773,-124.146164,-86.699358,-40.985566,6.154747,47.460351,77.808478,117.862582,106.199854,-0.37955,-52.734619,-32.108554,76.100045,95.810159,42.511524,-2.25334,-75.42658,-99.447612,-102.531485,-77.186872,-1.701002,57.867717,58.652463,-39.464293,-114.375813,-194.284106,-187.763147,-153.475057,-91.513276,-32.266724,37.216376,5.29699,-138.201923,-190.773728,-201.935811,-174.713808,-41.801506,119.445504,131.344899,4.6004,-83.278459,-211.156651,-235.208365,-196.382698,-53.589785,1.113028,-50.189355,-108.762855,-170.334984,-188.860475,-175.004098,-136.201968,-75.072162,-42.732707,-34.148419,-44.319657,-63.372778,-110.877842,-112.965933,-33.25807,132.78318,202.986945,185.332944,100.496443,-92.263812,-142.777172,-126.390884,-117.479353,-118.91866,-11.921186,36.985555,-11.823816,-77.218043,-134.796807,-117.105151,-75.036373,-64.390992,-61.988102,-74.748576,-80.167759,-80.346762,-104.732512,-156.021574,-125.600991,37.666483,160.190989,157.873729,16.987907,-87.845095,-188.077945,-143.59452,28.343052,160.832525,194.601935,135.137624,45.950032,-120.545726,-148.831943,-92.728345,-56.268496,-20.129483,46.360332,71.945765,-3.938855,-82.274994,-123.240618,-77.584089,-48.967552,-67.089733,-15.199681,105.698299,99.860455,-55.40793,-143.154009,-198.544184,-164.360143,-49.642121,37.762835,44.29802,-29.036157,-81.530839,-124.988812,-106.873376,-85.14997,-142.267212,-161.614855,-158.1235,-176.496713,-343.349008,-447.322973,-493.76241,-445.227587,-325.905046,-202.175534,-171.212015,-195.520485,-229.389817,-314.505312,-343.69743,-317.22903,-188.376929,-126.827437,-124.699086,-189.082848,-347.967961,-391.063818,-340.996569,-273.899801,-140.55499,-52.359731,-69.380381,-213.492035,-276.168334,-317.948995,-306.585809,-215.982532,-78.226583,-25.305163,-22.920194,-72.790083,-176.244943,-205.496299,-229.353603,-226.792503,-171.710519,-80.511791,-67.961843,-137.838387,-199.807675,-321.861601,-363.513755,-359.166282,-267.120755,-246.935753,-293.31206,-317.336179,-328.045517,-337.253552,-360.142512,-354.499489,-238.47658,-37.510599,4.841943,-52.578259,-89.954771,-109.043853,-102.347031,-47.150769,34.818833,58.045843,72.823824,63.554483,-34.00307,-114.986916,-187.685194,-138.894993:-155.978152,-103.709946,-117.275859,-234.786377,-292.895442,-349.63892,-355.161016,-329.152084,-233.290843,-167.703835,-109.192848,-147.408926,-281.18377,-316.374286,-225.468297,-126.510463,-3.883211,-3.525309,-10.411028,-57.482572,-110.179639,-221.293726,-236.905118,-153.183251,-13.755241,44.075267,80.49396,46.715351,-66.643991,-114.745297,-131.112742,-90.76011,11.91355,38.091986,-6.540085,-222.346082,-344.347985,-471.825042,-458.933568,-340.719223,-200.924979,-160.700009,-184.378037,-195.781933,-105.576512,-42.012047,25.193118,38.711604,86.531613,147.301257,138.141058,75.76538,56.774715,3.829059,-25.410199,-13.380911,100.657834,162.86907,168.118742,102.166623,-88.756276,-174.233497,-198.850606,-135.943385,0.478338,26.698198,-10.23848,-134.927271,-184.516702,-236.610293,-248.762218,-232.087534,-160.291222,-121.018235,-108.496058,-137.832074,-180.136503,-165.406361,-85.167329,-37.527831,66.912358,121.773601,92.145584,-30.844488,-73.536535,-96.498952,-82.854141,-29.305309,-14.860902,-9.963371,3.666479,-18.028697,-108.893565,-143.99803,-151.425979,-132.323925,-51.393825,84.7968,114.862988,63.458392,37.352422,53.573443,100.17148,244.144202,355.868776,403.607758,474.835092,491.913102,515.01076,500.442417,400.113957,371.854934,487.045213,668.075121,678.200982,526.92789,420.398936,262.246842,231.519551,236.308977,250.323635,278.192772,345.017555,332.415002,227.063226,168.064825,59.774651,28.528713,43.372733,90.750348,80.582498,3.582606,-28.202675,-78.290257,-99.201495,-107.600288,-34.316447,48.727553,227.119424,288.642798,355.533356,363.772031,382.820498,414.254338,483.936718,546.100933,548.427077,435.980742,343.251266,137.336028,54.741922,-3.467601,24.593662,68.128611,142.112878,121.360788,-6.2327,-63.990097,-88.922186,-53.984015,13.869708,-21.302678,-47.160587,-44.243808,-43.61961,-118.934483,-159.915504,-130.645822,-3.182215,54.056479,135.967205,166.205279,151.71614,81.28647,-91.047781,-119.327488,0.858411,178.548082,187.305317,48.855969,-20.373332,-72.356,-70.936328,-31.764447,31.038429,51.410633,51.630653,49.368208,57.559813,20.166593,-131.425276,-154.135091,-20.261551,111.260092,88.009017,-83.879058,-148.573244,-162.311958,-148.091209,-156.91581,-123.359356,-37.459546,131.782945,130.526682,-19.56328,-100.42514,-124.929271,-61.483872,75.568122,122.22597,125.416204,117.645582,96.002323,-24.176458,-74.977659,-25.980715,134.879005,196.828808,190.379611,121.043785,-49.977876,-115.095146,-147.528624,-105.697612,12.610637,49.282698,35.617867,10.321027,9.159463,-27.345219,-68.909741,-117.491278,-49.159435,11.880427,98.319521,97.340849,6.54651,-47.55019,-57.342162,-14.96448,63.419866,81.486228,77.89896,61.215325,37.444313,-45.034574,-68.396201,-26.088978,65.997017,100.392751,68.457337,-0.205099,-138.795953,-174.62363,-119.40778,-40.980154,38.251918,2.140544,-2.34585,-18.150233,-49.906716,-125.999473,-138.122721,-61.618428,56.203651,82.242575,50.332014,17.732282,-47.985378,-90.119449,-177.446058,-206.399813,-215.418446,-159.292866,-130.396964,-105.273686,-103.103775,-125.862551,-129.081485,-51.211745,29.763005,25.370109,-56.394179,-103.991387,-140.022185,-126.847938,-112.852491,-115.562427,-18.870232,147.853582,159.605429,29.366365,-57.240399,-174.506128,-175.061391,-53.645322,52.490624,73.378888,83.192281,51.300246,-114.583041,-195.474181,-197.102476,-134.455161,20.65214,162.325784,175.759748,62.377823,-14.038553,-109.251941,-117.478137,-57.301903,28.459348,48.644809,29.176866,1.740833,-70.448985,-116.754463,-190.975103,-199.98248,-151.834014,-68.09835,-43.66301,-67.735392,-111.333633,-174.47714,-172.765704,-198.806831,-326.158333,-366.535387,-363.968186,-376.058185,-482.744746,-559.131442,-674.912806,-665.314563,-509.869882,-318.289885,-252.667458,-242.356094,-301.718087,-469.339728,-521.386721,-488.105487,-348.620738,-285.666212,-245.583644,-277.110442,-391.273211,-433.569257,-380.345807,-294.294963,-178.439123,-177.47426,-174.578066,-150.283503,-160.301935,-244.678906,-262.632396,-148.271458,-15.862492,-3.845728,-16.70818,-17.157955,-35.445361,-48.717029,7.012003,66.030342,110.434398,89.380274,80.342633,-16.033946,-100.668817,-222.541926,-247.367085,-292.750819,-294.682867,-244.451231,-128.388232,-112.380944,-136.267988,-147.664419,-110.671883,-45.511537,99.456939,164.107324,175.234116,161.690279,126.464675,24.596278,11.775932,110.141885,210.208062,215.574557,160.880738,126.863015,50.214614,2.344076,-29.98827,10.116071:17.992361,53.791928,-7.937638,-203.0957,-269.008299,-344.101696,-355.634338,-254.175108,-95.254713,-86.443213,-204.088997,-260.059312,-306.343639,-314.578457,-251.466406,-156.870934,55.687067,83.075782,18.396812,-117.882201,-164.49001,-255.086349,-272.95934,-174.246893,12.24999,103.401709,188.349499,153.839354,6.842121,-57.182737,-115.379137,-112.991647,-52.798813,15.59262,-5.789513,-184.429567,-289.695343,-413.193584,-420.03439,-333.30476,-165.772857,-98.931245,-72.669297,-106.656317,-175.948783,-163.404947,-25.464954,48.7645,130.663795,152.109739,121.618121,-16.059692,-73.472414,-76.310116,-33.076606,41.479006,94.597316,108.549016,0.358529,-96.674517,-217.889688,-230.509599,-183.68558,-135.477819,-28.381943,56.076713,52.244135,-72.068588,-147.050007,-246.044272,-268.851739,-243.803703,-146.751524,-99.348292,-66.377525,-80.102309,-130.788887,-145.32755,-86.787185,-21.570498,105.985085,174.282015,173.773532,106.56814,49.345343,-71.710231,-108.79215,-103.073373,-17.299608,29.814812,29.694653,-23.402523,-154.9177,-198.181967,-195.381161,-156.594905,-38.436837,57.07203,69.748603,12.399516,-25.492727,-9.07531,37.923637,125.810467,284.058746,399.960698,508.012461,486.414631,451.576082,445.256186,432.673819,469.301723,645.089094,729.586026,690.348962,539.527072,460.409145,321.136318,277.580646,267.593843,300.650869,307.568434,285.508265,258.784027,171.218997,108.922477,-12.136826,-45.213461,18.557272,166.863836,156.11741,-36.457494,-114.889018,-155.496269,-154.917401,-130.028933,10.527229,125.455428,275.57839,264.830377,211.27718,240.736545,387.60311,447.389261,515.720106,595.130484,594.9149,419.907478,277.343434,4.322393,-91.49555,-122.278975,51.537554,140.501424,157.736563,103.510083,-30.602499,-105.388093,-158.912753,-92.666489,65.400349,28.611819,-26.436226,-100.595747,-124.900207,-152.702392,-144.435879,-94.808708,-11.473756,50.544671,165.631177,186.75266,87.237852,-16.62103,-129.449494,-89.514642,89.26735,231.418296,232.680121,74.022631,-34.668838,-151.611214,-130.190677,-8.509174,71.208693,70.886755,12.883495,-3.835171,-19.690772,-64.154049,-166.906059,-157.240823,-18.156731,86.382456,76.238295,-30.261302,-93.999993,-188.072915,-193.76421,-121.209811,-24.477566,31.609744,107.245244,92.66481,-7.151052,-49.780111,-58.38345,-36.477774,18.738635,97.332987,120.919443,72.310315,11.394363,-87.42728,-75.062794,79.329222,177.887841,183.821347,180.939312,149.628676,-12.395581,-102.340183,-153.056894,-94.850476,65.616317,127.708969,127.178186,60.705895,-6.058974,-118.122343,-130.403825,-82.191303,30.491075,91.426283,124.492504,98.935754,25.475115,-22.407433,-93.755239,-78.018697,77.103574,252.522338,286.560877,245.751085,183.212166,9.771194,-54.261299,-21.239778,153.706094,204.306835,108.120619,1.636509,-147.019351,-160.869562,-116.733866,-93.457266,-38.363984,55.311615,69.956398,-11.716403,-85.883359,-203.016846,-203.60152,-98.093446,45.581044,94.077658,87.72208,53.225424,-40.118372,-102.230705,-167.9822,-153.048443,-104.199824,-71.122945,-65.597843,-99.980132,-121.16916,-116.610963,-93.3436,-29.938864,53.973599,88.934164,97.118683,71.644406,-33.507121,-82.990989,-64.305984,-18.427131,98.491875,242.893425,254.169467,105.075368,2.477499,-134.138405,-147.813631,-34.767821,190.706927,271.600527,253.797083,168.810242,-27.915026,-90.641704,-72.03796,-21.349885,71.176953,166.0562,183.037153,84.647125,-1.713506,-109.566483,-106.293153,-9.466424,89.647835,111.623691,123.918231,106.900762,-7.844977,-76.01165,-116.004064,-92.755654,-55.343301,-72.635435,-91.671764,-107.304848,-117.259825,-201.136499,-251.895842,-276.713052,-206.151755,-169.073918,-165.698501,-212.770404,-388.53648,-494.285522,-611.58175,-574.304427,-358.720872,-184.306591,-155.180238,-144.707684,-169.506392,-345.952033,-445.666416,-495.768175,-303.183839,-167.890478,-72.74643,-138.478812,-320.410382,-375.637899,-358.587326,-303.540323,-205.025729,-154.752949,-144.341534,-183.970931,-237.378214,-310.308943,-283.781281,-121.814814,35.396121,72.286442,51.740637,2.097947,-161.987848,-233.708188,-191.55242,-113.526718,-44.779009,-45.603701,-55.153559,-126.611532,-185.752833,-346.310518,-420.969485,-462.293026,-324.350768,-233.77558,-189.137793,-240.552064,-372.43676,-411.91079,-336.729647,-231.417903,-42.301714,79.121491,109.547799,44.484389,-27.656193,-121.21942,-122.313903,-65.781035,2.919398,22.957482,5.37237,-24.622025,-94.561826,-134.278344,-150.49695,-96.161002:-279.766175,-231.513233,-200.065279,-207.298549,-257.395588,-433.045325,-497.314968,-406.914497,-168.400033,-82.798979,-44.540281,-96.617926,-237.324782,-261.735249,-197.662597,-151.753611,-77.489999,17.667906,61.344064,84.980353,41.384524,-108.687531,-135.337919,-46.434897,15.229423,26.881283,75.276235,80.818637,-15.806535,-83.249274,-127.430836,-96.59693,8.231904,59.350806,15.857641,-208.19375,-329.771494,-481.613142,-499.608457,-418.568975,-282.393105,-237.558592,-217.000591,-206.208742,-88.77028,-2.833513,115.885655,137.545589,150.251514,215.98553,254.740092,248.132668,200.575742,100.67487,86.604793,89.718689,90.146722,121.556402,171.235278,149.808764,53.108154,2.248027,-52.753209,-39.791882,38.51668,89.598259,69.810225,-50.825501,-112.059001,-206.795069,-248.251241,-260.607588,-147.974447,-96.409352,-132.438433,-194.432052,-237.430577,-211.689551,-111.262608,-28.872434,119.329374,108.81456,76.145055,48.111575,55.620638,27.977032,-18.078835,-60.51917,-3.463653,29.937165,49.522714,19.563444,-97.537533,-160.850986,-175.315086,-99.985363,49.94648,58.822419,38.333536,-11.31786,-17.06655,53.821185,114.504478,210.229297,287.193947,347.427365,458.13012,481.813736,477.046169,447.354439,375.534856,389.3238,516.145508,578.293845,565.959397,469.522845,393.404371,251.151604,202.978039,164.029509,162.569077,157.852948,156.422077,167.051153,158.04388,121.707827,49.487078,36.275118,53.550171,103.299097,99.717341,-1.400922,-72.422665,-182.475814,-197.718083,-132.115737,-55.196382,-21.473413,100.510546,177.152913,303.063614,343.255804,394.37219,428.713077,517.641902,534.99439,496.871979,391.860153,353.219014,247.181343,150.911971,-39.943332,-45.670461,2.763744,57.348804,52.586041,-16.631203,-75.514724,-103.753219,-47.222463,31.767378,-23.523359,-43.592281,-31.97212,-43.23152,-148.404356,-201.476644,-203.945295,-77.533849,13.790753,191.044518,251.093329,268.33848,199.891997,-8.914062,-45.373678,86.371049,209.644126,208.367297,131.986676,67.323192,-63.465805,-80.990681,-37.426409,-44.945426,-71.070229,-146.811996,-179.824202,-209.082592,-239.230101,-333.697326,-338.081392,-225.266523,-116.169813,-103.266547,-156.610762,-185.1114,-207.166481,-226.724421,-218.799772,-35.860008,50.573493,48.684296,-7.662787,-111.788633,-146.161617,-85.021453,2.89689,73.162273,8.997076,23.799393,121.260035,108.649416,-97.900909,-187.148281,-134.050323,26.513736,61.850008,39.74756,13.363984,17.880096,17.679948,-47.149432,-62.809962,-9.734765,62.977475,76.252008,38.692574,12.606793,-18.252183,-20.030168,26.450834,51.390997,42.010856,85.406158,140.663398,162.88464,100.829256,-2.285909,4.382382,43.979161,58.461522,63.677447,52.208008,34.783034,0.746223,-0.134038,66.017793,156.10083,169.071813,104.077607,51.121902,-37.067177,-70.082522,-44.578829,12.716644,69.346807,40.044952,4.473697,-91.24951,-96.79735,-20.106675,11.797619,19.81014,-2.171871,-2.097754,4.006346,-5.735571,-92.221585,-170.574494,-314.813945,-341.881136,-316.885838,-249.451719,-209.581335,-149.968559,-139.649515,-171.059907,-193.283296,-137.921676,30.053259,93.171578,65.970659,-9.545126,-97.198268,-89.473019,-76.679509,-78.887171,-61.781636,7.662203,55.28708,72.446085,5.116727,-198.832852,-242.060095,-113.811961,37.551802,47.848156,8.777843,-22.9737,-113.063321,-152.637198,-142.704244,-84.131324,72.428627,190.855611,200.034097,104.490984,44.063842,-36.068076,-46.932732,2.646406,57.188437,59.752724,-5.973852,-44.866498,-32.749625,-1.987486,24.773052,30.332324,63.991634,91.24892,76.898755,-31.455679,-103.580968,-210.136153,-245.435767,-311.772773,-330.260563,-306.68457,-269.845449,-299.918774,-418.898057,-485.8539,-637.675292,-676.224171,-584.443518,-343.834319,-224.356843,-175.16267,-270.788185,-510.480352,-561.09696,-515.873876,-449.673962,-399.268491,-260.827206,-248.076946,-380.073427,-447.603554,-460.401723,-416.295277,-246.262071,-43.581628,-16.036722,-161.786948,-263.795105,-329.092119,-271.130724,-75.392958,26.065647,32.152094,50.570777,67.450468,102.700988,118.159115,120.685592,127.820822,166.342413,94.853911,21.688596,-85.606671,-114.519986,-183.828402,-217.320934,-190.946415,-119.473673,-98.063155,-5.447519,40.447715,7.034397,-45.789297,-44.439299,30.367914,186.755003,201.268188,149.826441,-5.324825,-63.146958,-61.440703,-3.70442,122.91497,64.03397,-16.117493,-52.537411,4.40818,84.877157,62.904254,22.07516,54.523845:-49.810608,-77.299874,-114.67378,-237.430785,-288.807161,-351.964807,-361.481849,-295.630764,-154.087406,-95.923982,-102.341869,-161.451191,-283.815882,-308.639457,-201.884027,-82.778661,100.734037,107.863143,76.724513,-8.984946,-69.033493,-208.022163,-225.781218,-56.863201,173.135781,229.666899,199.249695,131.354323,-21.660093,-74.95282,-91.411239,-65.614922,-0.01077,53.191865,37.557497,-139.800491,-271.912858,-486.818426,-517.911984,-427.151054,-283.08237,-219.665845,-169.213869,-173.587388,-118.887222,-66.975507,17.697188,67.313596,206.833037,281.735865,244.138655,65.141538,-18.318615,-80.541655,-51.768183,85.818826,205.850008,217.185271,137.981852,80.175829,-24.759347,-80.357664,-117.772579,-61.672832,107.445055,153.916655,98.220293,-70.861795,-133.235783,-224.239544,-262.949008,-241.872056,-41.139337,50.000834,17.074704,-75.279083,-205.641798,-217.19076,-112.244401,3.060251,243.920702,296.225372,236.172659,55.452567,-32.243119,-158.565794,-163.335299,-33.024417,102.491124,107.689091,-10.773363,-96.027865,-225.453765,-253.702047,-205.980078,-138.68088,2.507961,95.670181,98.433014,11.062282,-34.855896,-59.06792,-35.900121,81.647677,280.712475,397.437453,561.621682,578.39727,528.244708,477.899189,393.094471,422.561406,629.339689,776.700592,772.395944,608.215679,482.840542,322.985365,317.591099,347.59822,344.909386,342.582207,298.798832,242.393725,98.704355,30.106247,-40.014718,-14.745275,116.350328,184.126672,153.545554,14.627162,-56.114685,-139.577378,-136.353628,-80.566066,14.316948,114.307045,334.885148,373.971375,282.34823,240.791797,340.612965,435.464452,564.822264,620.551157,598.366642,424.786637,304.752775,70.532207,-20.055646,-56.138856,90.44049,148.979277,95.834171,16.158499,-101.896803,-134.637224,-171.261546,-155.332982,-43.730237,31.602057,-11.158029,-213.273296,-294.691203,-357.473708,-346.982728,-214.218226,-20.803384,55.400175,146.527527,156.39423,89.748117,24.231081,-69.546928,-63.730718,26.788316,147.476174,172.27083,65.557201,-36.069449,-197.105832,-226.990061,-167.800648,15.024664,75.052038,-18.3524,-121.331076,-252.131768,-280.979294,-313.909784,-302.388663,-172.851128,-9.994142,-5.838474,-175.674386,-280.550915,-361.324788,-316.328132,-178.545019,-133.540861,-117.237784,-64.959803,-60.510755,-145.112291,-216.03064,-252.263008,-187.234052,-17.38828,68.946059,74.54287,40.497039,0.315021,-153.719212,-212.482322,-128.063252,90.462022,160.874383,126.621302,34.37519,-134.883483,-169.029078,-140.964419,-88.012391,41.97008,138.401266,159.87176,120.918957,66.759439,-40.874736,-60.564088,-28.110781,60.051929,116.011047,174.002832,165.717695,81.191866,5.250451,-78.350163,-31.524842,177.448362,359.805787,390.296394,285.941291,171.765884,-40.660914,-65.666898,69.571881,221.2949,239.441752,119.589293,17.267638,-104.761539,-112.340519,-57.171887,-0.0599,112.285741,147.613803,109.690292,-67.472644,-161.649421,-256.724519,-231.300687,-63.922206,59.141543,72.776921,23.156053,-44.51324,-234.03641,-317.245469,-356.909286,-314.045179,-222.139727,-184.570178,-174.152547,-169.690263,-181.700491,-219.11301,-216.04251,-132.216769,24.136482,110.838341,130.220455,26.82858,-189.118203,-208.03445,-86.461744,-7.289533,102.594194,193.602433,225.850133,164.242285,58.07088,-189.958213,-234.030583,-56.262574,164.922752,198.595152,143.660394,61.681714,-162.874887,-239.254927,-195.201066,-105.402347,67.544944,193.121934,210.366719,105.763569,3.12223,-185.339489,-203.499104,-67.325358,115.443151,153.556796,62.174451,-16.747206,-110.595838,-138.476374,-160.622726,-128.020316,5.859908,85.384365,57.220571,-90.230026,-161.785852,-250.717731,-257.974477,-223.996784,-201.750941,-184.336952,-163.263509,-206.016354,-413.373916,-527.153444,-650.703665,-630.809427,-447.090672,-233.713236,-175.847173,-196.02553,-267.700058,-452.869757,-498.824144,-427.153596,-261.230524,-176.223469,-65.97553,-86.400344,-250.207043,-324.658791,-349.062339,-303.70683,-163.655311,-21.588673,5.632124,-97.530387,-192.073988,-306.534996,-274.625438,-53.943903,137.127033,160.97,103.201384,54.898034,-43.175213,-72.873388,-30.870426,23.96365,92.559388,106.81166,101.034732,-0.2568,-101.192782,-315.225674,-369.822602,-303.260987,-133.853357,-71.724693,-46.115345,-74.304064,-145.595822,-184.261794,-213.268419,-164.260995,4.751418,121.892992,134.534368,35.277521,-63.587254,-237.746326,-240.011469,-64.243199,81.691233,93.347644,59.435694,30.115781,-84.798628,-150.608433,-147.702068,-71.426512:-197.197343,-258.196677,-244.285033,-193.206933,-192.245293,-299.517766,-338.713898,-179.152396,98.096665,173.020944,190.714944,162.05109,89.982066,49.516198,-22.805061,-20.80371,65.612487,148.28721,159.080638,104.233781,59.939736,-27.015376,-61.4513,-54.118684,7.664566,39.960496,102.749367,105.976146,11.337346,-47.640709,-49.714855,14.452721,156.810378,147.498507,86.06789,-67.371405,-143.822101,-297.285646,-358.800595,-355.138615,-206.486549,-144.007591,-151.217877,-186.816674,-104.319587,10.968868,166.856606,184.463065,195.616276,230.045997,250.687674,283.497713,295.168596,263.817469,230.648474,233.195732,328.919314,385.806956,411.831297,365.302212,277.35553,252.026603,202.154136,196.876042,195.984636,180.965786,175.236152,110.902738,69.390313,-10.169053,-62.639366,-150.382252,-138.138528,-112.467097,-146.351027,-214.265381,-304.464498,-287.067672,-154.276084,-46.71924,149.186784,139.042209,74.926424,-16.912124,-40.464089,-103.640549,-123.344886,-71.511464,8.851967,28.974157,44.047459,24.146271,-54.494675,-75.240363,-38.59087,-7.350101,8.110086,5.001133,-5.52124,-64.899057,-83.77474,-53.069336,-9.101791,54.914579,42.362105,68.835588,233.745498,305.36208,293.990716,227.953111,97.50521,83.758488,170.290011,278.135467,290.22815,235.70413,204.257563,158.686063,140.348043,91.919929,77.105743,111.822045,179.604715,163.59002,83.782757,72.959163,111.355667,110.029589,18.305588,-10.579041,18.52597,32.070361,-18.304445,-167.2821,-200.531664,-118.839495,11.158367,57.033407,164.105841,222.383734,267.156021,245.332289,195.280599,195.611106,257.146645,301.698937,265.864259,161.61967,150.092684,156.02312,122.657669,5.321372,-32.802168,-4.225983,64.071054,65.465673,-16.569843,-75.218137,-112.564486,-79.916072,-32.953854,-36.92307,-16.265409,36.535828,34.402176,-2.524035,-14.235187,13.00637,91.775393,126.842518,193.352998,233.855098,283.5508,252.634807,121.694496,90.625483,148.336999,243.978345,253.959673,204.166673,177.04914,82.046707,-0.234138,-127.321606,-147.817303,-157.392766,-196.212823,-197.850901,-146.735968,-133.15953,-197.770439,-253.392931,-358.176493,-400.60894,-391.222043,-325.737787,-286.059809,-285.493859,-301.106643,-201.740658,-35.60045,4.20444,-18.822119,-66.021333,-139.371404,-143.607567,-88.507996,-38.050605,-4.768303,-97.158344,-116.933706,-52.974837,-36.332861,-129.961725,-186.776865,-191.771939,-89.42047,-50.227935,-98.650264,-152.00017,-128.505466,-59.344882,29.1461,28.975403,7.736849,8.012591,18.675268,95.430852,122.200946,18.702433,-60.160409,-91.250096,-9.377783,38.121933,99.400022,98.480855,65.602783,54.295987,73.035048,93.83716,95.164388,106.031807,154.12921,238.941243,220.802006,107.353806,82.283926,141.180378,206.385735,225.385553,232.408735,210.056843,164.397579,156.278406,129.117478,109.131766,107.888164,100.183206,52.600757,-93.414999,-139.985423,-115.311619,-58.678838,55.380001,54.04206,20.129473,-30.315019,-50.55471,-128.887051,-187.201956,-267.250605,-274.230633,-275.558732,-290.843959,-298.961759,-305.387975,-298.121278,-260.995738,-203.062821,24.121544,183.508395,191.954535,145.309885,114.070605,50.045622,24.416972,30.385047,54.114818,70.668093,97.677052,131.25234,141.546277,92.805276,-50.081803,-97.661362,-94.722759,-52.603945,-31.112427,51.20153,80.208235,6.297343,-81.228695,-135.503925,-60.14438,104.058449,169.797298,178.134444,74.278413,4.187388,-16.382044,3.448836,-18.555454,-37.429731,-4.513237,38.282962,16.536754,-32.292266,-37.85055,-22.048908,8.09506,110.912437,168.259756,134.504384,-31.764056,-104.87567,-185.167005,-219.01008,-229.113762,-125.023485,-89.449466,-95.757612,-117.803936,-207.764626,-278.649668,-402.59347,-426.609548,-370.578689,-133.733312,6.930244,72.813667,-26.874473,-250.40098,-288.438285,-272.816323,-222.479652,-154.779342,-39.924637,-69.509471,-221.785135,-263.260915,-263.808579,-251.575844,-190.474575,-90.330107,-86.149039,-212.254406,-293.443015,-364.845108,-329.573066,-152.889336,-35.886454,-26.834112,4.440573,41.003442,119.595976,146.496712,136.935272,99.772458,20.613404,-18.135282,-35.585986,-54.774637,-65.869242,-162.194254,-209.399997,-173.459317,-81.777477,-52.091978,6.649727,29.416533,-15.087815,-69.924291,-99.985577,-55.663173,76.151571,99.353078,24.653792,-224.841771,-314.114601,-304.21095,-245.789833,-163.266073,-149.399255,-144.983699,-119.507111,-118.240188,-155.9283,-175.484718,-157.377106,-109.483012:-270.642761,-234.686577,-210.203466,-232.864051,-290.584293,-448.145116,-476.263062,-329.36294,-123.461581,-64.736463,-32.110555,-44.824067,-73.786546,-89.73655,-156.03902,-182.671201,-127.082713,-14.497933,-9.057508,-60.954942,-83.752867,-135.286086,-156.546442,-131.824909,-74.552064,-66.304562,-89.359301,-107.031992,-148.647514,-166.201816,-98.248519,-15.30017,97.897798,104.236418,67.582072,-100.139398,-200.618537,-361.018294,-390.468209,-308.906651,-209.078065,-199.783903,-170.521392,-98.730148,137.67576,212.212744,148.485012,86.566052,91.509974,164.274928,166.140286,144.083699,156.61626,179.415473,158.539592,122.182679,201.455237,265.893796,314.024714,285.52895,213.577154,185.450028,126.19539,97.887273,47.899811,17.167049,0.992748,-57.32191,-69.001041,-34.614654,-16.657129,-13.107405,8.81333,29.649039,-27.780636,-125.235842,-291.902196,-294.270516,-165.616176,-66.792659,103.335674,145.208028,141.835196,106.244977,66.734737,-26.504049,-56.298171,-19.50313,56.108889,68.801971,76.508494,61.254388,-53.37309,-115.089156,-107.886189,-47.279697,84.680145,166.43407,172.61257,117.041878,73.58243,33.745513,62.222568,140.359961,176.416723,215.096078,335.829664,390.665879,445.995777,421.3907,259.572569,186.935792,200.632164,327.145014,344.241694,252.811873,194.849894,89.910128,36.444267,-10.59998,57.462917,121.475816,213.924986,211.957596,196.432024,216.742646,245.802629,209.474796,84.260323,95.878779,118.275122,31.250034,-44.998599,-144.635698,-161.185747,-135.023816,-82.681005,-45.365434,55.119372,106.476067,180.350303,190.863802,207.299486,235.898767,280.122091,268.585585,247.825324,224.179879,243.973427,249.024694,202.624743,94.172374,61.535776,82.877915,144.010616,145.723464,91.375166,64.213783,83.723692,127.775589,159.68688,127.119101,128.336543,159.286737,181.278272,172.778575,126.825777,43.149902,93.933045,173.432739,316.13483,331.03105,284.690641,245.784123,153.352878,129.011566,148.986459,194.981866,210.499749,202.209463,177.990891,105.209438,59.40222,-43.662181,-144.00936,-174.085599,-167.687727,-154.348542,-157.397153,-186.841353,-284.238289,-310.042411,-295.118288,-284.003681,-296.578618,-307.478518,-266.846542,-130.406463,-97.545724,-130.205397,-83.824824,-1.61062,94.551702,75.065093,45.740823,48.92373,17.754032,-6.62718,-43.510262,-45.565697,-26.028995,-8.877297,-32.651953,-130.403373,-181.804577,-197.234777,-67.602977,3.077019,78.275989,86.667741,62.143828,25.646665,-37.526785,-43.154473,-46.916525,-41.154448,-24.214694,-10.561087,-22.895365,-51.423287,-53.819423,-56.310656,-69.112933,-41.616764,26.548137,25.981103,-43.469317,-93.301283,-93.33987,-39.806853,-26.778853,-128.077893,-128.463623,-55.279454,-46.823833,-126.421076,-156.600924,-47.97641,142.52256,186.285966,152.550554,111.37325,66.298858,60.504384,63.870233,73.735211,89.603056,87.185208,74.196009,46.182339,53.449421,60.828588,42.060094,24.093356,74.054729,103.245355,87.608182,56.066988,19.59973,-28.436222,-212.498537,-266.002166,-246.1884,-245.674613,-252.530278,-189.575849,-141.945699,-138.904101,-161.958524,-122.022549,-15.133158,16.823455,18.603264,1.11204,-34.095903,-49.546059,-108.022098,-141.379388,-112.478829,-5.458741,-6.900558,-108.817137,-145.161831,-173.622525,-183.743492,-147.722703,-30.50894,27.313387,100.63862,100.161935,-4.008042,-75.420592,-104.959447,-43.438236,159.597258,320.388384,316.59624,142.936083,44.590595,-57.789983,-68.142108,-53.855056,-18.438213,11.381733,69.022987,60.271563,-29.764174,-54.448363,12.00325,76.05963,151.142151,106.257645,60.376607,-10.70222,-31.775828,-85.234622,-112.201107,-164.695261,-233.695954,-241.084047,-215.487291,-216.458041,-285.296009,-362.182654,-534.033678,-568.717417,-496.799928,-294.008163,-183.242276,-141.740263,-251.50925,-555.981522,-650.652741,-646.764944,-446.190611,-304.746364,-91.734359,-95.00779,-282.946324,-365.397011,-389.360593,-373.326816,-348.42113,-225.188878,-150.988048,-118.218752,-157.792663,-244.334042,-240.744484,-138.604509,-54.572191,-23.783758,60.107977,86.872858,66.630641,40.418559,33.650631,63.808006,126.170956,124.560581,88.405204,-10.003198,-58.152414,-189.898746,-246.235734,-209.611007,-70.192134,-27.346251,44.509926,95.122475,155.363138,141.023623,137.104179,176.725315,195.535578,85.32408,22.239003,-63.627887,-58.992408,46.203015,116.648395,185.494205,101.453174,31.796747,-57.414093,-29.425569,96.258486,104.854932,60.671697,78.200623:-183.166016,-216.516282,-215.331919,-203.200269,-205.710114,-255.388662,-272.484069,-170.203813,40.581203,118.184762,118.329911,43.318644,-138.123173,-184.51633,-122.173773,-43.064484,58.233889,32.775628,15.237617,4.682597,3.042237,-29.700646,-55.939711,-56.926037,7.798501,63.728933,149.933122,114.657422,-104.204566,-199.324175,-162.918598,-51.158692,116.588789,69.922986,-13.210452,-153.573653,-180.411456,-259.490157,-330.278905,-401.607561,-294.010309,-220.787627,-140.823282,-128.076259,-116.704628,-97.904581,13.153925,80.874594,176.271687,248.916732,252.400002,161.369166,113.396498,101.489774,137.179443,184.662137,94.10239,78.583709,178.61847,206.234232,102.400682,30.78059,30.381926,93.428075,182.245048,199.220002,178.31746,14.343575,-90.357094,-234.507496,-264.850899,-231.463073,-143.185062,-118.46652,-126.544607,-139.859583,-170.335742,-190.144895,-118.648614,6.447502,240.369093,199.10781,106.206733,-38.260146,-51.915274,-60.756898,-98.85032,-141.040437,-3.329428,71.530102,46.729201,-33.034634,-156.892437,-189.209313,-220.703503,-210.454203,-166.353212,-85.671258,-38.50176,-28.091178,-58.119178,-73.433428,-39.017528,59.241982,134.554405,186.821704,307.352618,338.008625,327.335688,290.422406,204.467483,204.870201,299.542546,402.542163,418.023153,351.095623,304.20444,267.425637,265.240656,215.700135,172.96711,204.537929,254.349734,206.897272,69.720379,55.669449,101.368642,100.130911,29.932542,7.475589,12.019932,-56.909983,-118.578622,-205.927274,-206.291686,-82.098753,91.260579,145.605756,228.524429,265.645084,291.839185,282.512765,297.60737,336.610784,399.982629,379.978246,332.515528,210.884519,168.875228,85.878422,33.86444,-21.471928,37.572539,93.182168,113.048641,60.908032,5.873528,17.449252,10.257728,0.636996,-13.873878,-48.558795,-53.367352,-76.244481,-115.168729,-177.333945,-167.382452,-67.385798,65.165636,115.022002,181.964086,215.549211,272.035328,252.159799,91.419654,20.552726,9.207032,92.945864,152.111197,206.837904,161.36468,-16.803339,-91.715427,-117.755422,-42.660828,-31.115769,-99.026148,-156.148291,-259.113287,-299.077601,-332.183485,-305.751293,-231.674374,-237.048004,-254.081491,-255.120987,-226.340749,-195.485345,-203.693924,-162.920615,-94.887456,-83.326062,-85.021669,-81.493473,-55.121392,-55.9386,-79.658814,-72.654284,-38.2333,7.067684,40.548831,59.305143,15.231393,-145.865141,-198.616337,-139.105271,-17.167236,2.53942,-40.616675,-74.230694,-50.072208,6.962558,63.656234,44.831896,43.428932,174.950543,242.820065,305.763556,304.613454,203.651817,120.737347,41.92901,128.252845,187.040404,216.692669,197.170173,186.720809,183.049671,146.382796,154.442053,252.79786,339.268621,345.723603,302.75812,278.714561,206.270988,149.951539,118.385448,259.762919,320.536847,251.339142,146.437265,-13.445419,-38.797347,3.495094,46.149117,90.754461,108.963711,91.424663,-59.336802,-133.235272,-184.622665,-181.50613,-105.124405,0.812922,1.014232,-103.361223,-159.966152,-243.345283,-287.355436,-315.415363,-270.379312,-172.819185,-198.970315,-238.555529,-284.835359,-268.208521,-195.771947,-162.206899,-93.746767,11.672167,85.06167,166.460059,122.850098,-58.245015,-103.158968,-8.14084,73.391724,149.833003,220.198531,267.386122,198.160439,70.068311,-149.296509,-163.291388,-73.324599,-49.184439,-44.348049,31.941436,61.21066,-11.663617,-84.230301,-137.563389,-120.211684,-62.05195,91.987018,147.717938,73.12928,-0.149332,-66.306718,-56.559787,-8.083109,27.734344,55.196947,78.733304,50.039066,-9.497915,-18.674265,-1.017551,27.439836,63.518908,49.676211,23.75268,-132.009118,-219.959245,-276.105398,-253.515406,-203.186955,-202.394591,-168.039568,-26.843322,-17.209642,-211.903937,-344.87724,-481.967629,-457.04143,-317.372054,-162.587631,-68.046597,59.869916,14.98944,-236.599192,-328.964913,-337.156038,-224.206433,-138.610818,4.257852,-4.580561,-138.599232,-192.568448,-242.784401,-249.425367,-165.055322,-41.653204,-53.604563,-214.853894,-316.233992,-443.167034,-405.234726,-138.230297,44.048568,57.851072,57.27831,64.430542,76.233333,68.486383,9.593662,-13.69054,59.200928,143.256098,81.91696,-93.966904,-101.643467,-77.775038,-111.409289,-161.296239,-92.493481,-25.099317,60.320788,31.078702,-69.395172,-80.98734,-63.918597,-53.708248,25.497433,129.505488,120.27756,-2.373241,-55.492803,-121.341663,-138.163505,-96.899215,-13.066637,30.109759,65.930856,29.678085,-72.364011,-90.341591,-67.697849,-46.474177:left
-38.774117,113.397795,176.805489,251.586147,260.736232,263.23571,256.046187,241.530586,277.684328,272.021635,162.670616,101.15743,32.010629,22.636971,31.962152,33.933687,27.15095,-20.419249,-59.047407,-141.087633,-204.401046,-349.795288,-383.558181,-302.544228,-142.086526,-105.60991,-98.66084,-114.746964,-228.498423,-285.262327,-251.262096,-177.800828,-32.919881,14.541342,8.662752,16.881353,24.833039,-26.847308,-63.179603,-66.408451,-45.238704,-56.050205,-95.893963,-119.487301,-176.014525,-186.886438,-123.660265,-48.443144,148.688665,239.515362,212.463001,102.167814,50.392815,-32.65122,-52.345247,13.236141,163.830728,201.396376,166.762195,135.506991,115.097325,119.603782,114.03576,111.010858,167.679885,245.955581,240.92119,149.851028,102.23552,60.891803,50.118078,-19.989228,-90.042096,-73.443159,41.556125,74.685607,25.593619,-18.252603,-52.328336,-43.93651,-26.59662,-48.414892,-75.169214,-151.864673,-184.762855,-178.817677,-142.219717,-97.083663,-148.660947,-177.447053,-136.492021,-75.55614,-23.946638,-30.670771,44.834544,126.587694,245.372332,212.45689,168.514386,105.70641,69.401549,-39.550339,-100.972759,-225.078158,-280.680816,-270.453251,-219.836348,-210.394064,-251.221475,-259.463,-165.042848,-88.123559,-3.764851,-119.086562,-219.66125,-344.984268,-358.165482,-344.300795,-328.277335,-241.238608,-78.043625,-9.088072,50.909739,27.152617,-96.626851,-125.307935,-52.878831,-18.201538,-46.721022,-104.48865,-118.397221,-163.649315,-198.941744,-200.034096,-152.167855,-35.110957,49.555292,62.2974,26.372788,-2.890219,-54.713491,-64.057603,-27.378214,9.839502,67.399468,6.161183,-49.591151,-96.720475,-93.729666,-73.967158,-40.071263,68.213542,67.936793,6.992578,-131.627164,-177.396429,-212.265342,-207.81073,-172.249395,-144.489556,-55.323837,42.353715,71.692989,58.720313,13.486004,-34.687084,11.448817,202.497648,344.985608,334.483679,222.017366,173.776137,41.212362,-50.486094,-158.014979,-158.453498,-103.602603,-76.784628,-105.54014,-205.84298,-230.353657,-126.925063,-25.844937,103.436971,46.021144,-44.637203,-210.089975,-226.050257,-173.608532,-137.24153,-36.838163,-3.578324,-26.891435,-45.355647,-20.270348,27.286037,15.381483,-26.209273,-17.179998,28.484364,-18.552316,-75.909546,-197.007381,-260.219717,-378.977872,-402.177822,-330.396828,-267.529979,-201.352201,-245.9335,-288.708912,-317.297916,-288.858411,-188.760146,-123.641118,30.739686,140.997199,161.303424,144.736366,111.513773,61.111454,90.624885,218.002051,263.360021,272.501263,117.359648,18.603936,-33.376614,-8.702996,-6.393343,-26.082678,-66.471518,-92.729944,-93.259878,-125.909625,-173.506093,-249.801891,-238.740607,-171.173743,-163.920783,-201.823278,-222.88436,-228.285429,-263.102092,-276.955658,-221.656532,-159.864212,-61.447495,-47.403,-64.89517,-102.440364,-103.475131,-129.722554,-162.614707,-130.641274,-58.220096,56.890704,11.581882,-48.403276,-138.479461,-157.164907,-129.311298,-78.79367,49.462723,160.862775,193.646915,156.016388,97.586471,37.922777,62.958793,137.559371,149.427508,146.928583,144.226596,127.648906,62.162144,30.914586,57.942541,94.131821,78.119441,57.027013,82.905183,96.870329,59.709984,-23.646604,-33.279717,-1.840667,8.696675,-5.163886,-39.819993,-64.73057,-129.015683,-158.237303,-138.33513,-101.783901,-75.948188,-68.546725,-62.399718,-88.757694,-132.108232,-222.051245,-223.678405,-176.176961,-160.740861,-98.93336,2.67258,38.421128,46.926279,19.935001,-39.553581,-52.330599,-24.171055,60.025226,79.685485,23.097605,-8.401502,41.054851,107.736299,175.054037,153.731407,145.242569,202.542303,187.968344,93.703576,55.140741,50.488223,98.180947,247.13326,350.111895,367.573237,321.428249,264.753315,156.871433,138.21242,218.153065,294.194748,357.604924,190.145959,88.427432,5.775407,-2.327254,-49.229649,-73.246073,-37.409194,78.40101,117.231857,110.775795,73.675219,31.435462,62.38088,151.280737,162.028197,124.493375,106.61898,129.553733,188.256287,200.155622,232.887215,271.290146,332.0705,276.625578,192.982863,-28.361309,-111.497907,-122.481391,-41.477228,179.588413,252.497127,298.17706,265.805171,230.056541,166.266811,147.300401,117.934061,96.38556,46.397219,70.622934,105.757165,173.815094,176.267429,74.126516,21.446587,2.530142,10.181189,36.699975,78.45385,77.083143,-10.216805,-66.730609,-92.430357,-69.570623,-27.279078,-49.079634,-101.030494,-229.068879,-278.438406,-288.347405,-233.88202,-91.434038,-35.194446:16.258897,84.248192,118.162766,175.383399,177.972818,138.635953,117.147238,108.878026,150.957147,147.176726,43.574601,-25.970111,-113.15901,-113.642509,-84.019023,-82.771259,-49.178359,-12.44939,-48.214784,-231.000484,-342.252556,-465.075421,-457.674496,-373.422851,-229.3034,-148.180428,-106.058272,-176.145361,-361.984916,-379.750186,-217.983814,-125.003159,-53.639655,-56.079501,-70.641611,-100.950174,-106.106624,-95.663249,-82.86407,-53.405087,-14.097718,-9.404722,-61.950267,-115.524486,-187.466569,-155.010141,12.32482,84.933437,141.55098,154.468656,150.147325,35.627983,-48.99172,-90.090918,-46.793294,57.058181,138.005293,145.145433,81.903138,43.19883,5.462425,22.075918,119.671555,163.559087,190.530559,168.151506,137.421594,-0.776304,-97.99946,-201.627818,-168.247138,-57.028292,-65.584613,-96.166353,-114.597969,-79.44039,-1.093489,-8.034556,-40.578571,-15.853385,41.27764,-47.559277,-106.474173,-111.148242,-82.035951,-34.696231,-10.379144,8.153682,-55.794524,-114.312868,-203.452574,-199.97644,-105.234785,-26.934128,130.987807,175.428031,200.42368,148.729049,86.247247,-42.793066,-74.448337,-64.738284,-53.60473,-72.164237,-114.762175,-146.877601,-238.811953,-278.697325,-309.209586,-303.084696,-264.848075,-215.17506,-77.567456,-150.372767,-269.922067,-430.067607,-434.565414,-340.330544,-270.632702,-133.430511,-16.800883,2.843541,-34.204342,-60.668608,-78.014319,-47.696897,26.426655,10.301681,-79.87234,-49.32893,-16.327975,-87.33636,-155.655667,-171.80686,-124.864462,-40.355583,-20.584621,-27.614226,-44.795219,-43.873727,-43.563377,-51.450919,-31.923161,-4.205908,-20.383634,-120.699008,-142.280512,-97.093465,-52.872957,14.144048,26.169861,45.596353,36.074149,-9.737203,-112.061652,-134.193577,-146.047658,-144.8338,-103.015462,-70.638748,-60.437025,-135.590792,-153.337212,-114.08987,-92.108821,-11.375509,80.649047,293.692582,366.161372,302.279443,77.125327,-16.675674,-135.317385,-153.722708,-107.756766,-79.939193,-66.562119,-103.445106,-161.131181,-271.711464,-254.982272,-109.566151,-60.059143,-40.780598,-14.27206,-15.476567,-107.635413,-181.906716,-286.745566,-277.727922,-148.2993,-100.102983,-139.885753,-195.240408,-175.584696,-135.864751,-154.638474,-198.128079,-180.298995,-87.164495,-58.420902,-90.477289,-170.986511,-186.561827,-188.97086,-194.931432,-189.180206,-159.721946,-93.96617,-122.68502,-168.752423,-250.698893,-250.023301,-115.690981,-16.780799,142.657024,236.468002,243.458385,156.177995,81.414128,11.115993,74.526702,301.604914,369.78779,303.52895,93.879512,4.024056,-103.024083,-119.962736,-110.965384,-110.108939,-148.076945,-206.58687,-231.176674,-268.22875,-288.807237,-334.585383,-342.038184,-292.159357,-245.399957,-167.72305,-155.488947,-179.444825,-280.829642,-304.801224,-165.235991,-59.070845,13.943171,-15.471212,-20.637764,-59.659722,-94.68573,-104.779008,-61.61625,38.34035,67.475729,127.658266,108.393872,38.428546,-99.767614,-132.550338,-124.366931,-78.12216,98.60441,248.590167,249.28692,160.021487,131.980289,148.804833,155.810597,133.679897,144.807085,201.224914,156.058187,123.308072,86.970723,50.969929,6.404535,31.935857,98.295547,149.395479,165.82117,138.725033,98.133101,0.815583,-27.826153,19.321292,79.722283,138.928095,32.144294,-33.727716,-76.385873,-77.507746,-100.590255,-100.982222,-30.799884,20.631958,-12.924258,-124.682411,-165.025592,-173.699923,-136.868306,-71.181409,-60.809313,-0.527453,74.644358,72.478159,-17.877818,-82.643042,-132.814223,-91.673268,51.551761,107.972415,91.817706,71.370478,70.596713,78.340695,117.123373,234.383737,273.517068,283.896961,185.627271,127.725682,67.515136,63.462309,132.651396,196.452288,279.841755,303.729891,333.423794,400.278274,386.487359,280.404019,247.716632,299.323236,363.473177,438.547795,309.594286,188.846745,6.645198,-6.983,40.472779,50.792807,81.239102,168.34361,188.975214,146.447342,111.410406,117.333419,163.73799,224.98829,202.99664,97.183172,16.349039,15.151831,96.610109,144.752446,221.887039,268.467875,309.529183,200.343531,130.435684,21.400004,-17.759076,-45.856642,-29.50696,69.371167,147.832632,280.723594,258.907835,206.428503,113.98187,93.109618,123.862421,166.55914,210.489162,136.368913,90.592912,55.720765,46.020331,25.479466,28.741721,13.922205,0.576463,28.668427,34.867282,-9.665168,-127.352139,-136.27061,-15.943661,33.361398,-7.309767,-105.769618,-135.141549,-128.053645,-119.088743,-169.457105,-184.281559,-50.256131,66.112299:80.735473,84.44633,68.292603,79.326102,96.974956,59.039522,16.22218,26.52383,130.511023,127.652215,20.628811,-35.238856,-148.48926,-198.442013,-176.558525,-116.189953,-64.065232,-116.056538,-144.749125,-302.818712,-437.941009,-559.411062,-501.14151,-311.787292,-143.030123,-100.222077,-163.415216,-248.981033,-376.210225,-361.738677,-260.088221,-242.387115,-261.164401,-213.963098,-158.020686,-81.237168,-76.901467,-60.42609,-35.951282,-8.108417,-53.0991,-100.731569,-206.837716,-237.888041,-208.02577,-159.048112,-75.271565,-48.49389,15.115109,44.026033,31.241526,1.155089,-7.485221,-50.708201,-91.254423,-103.063434,18.049223,32.937269,-82.494599,-144.308839,-157.54504,-100.078943,72.206698,128.918137,131.784738,44.270723,-15.392061,-152.711273,-203.473515,-188.502414,-152.69535,-120.808752,-119.423064,-124.227254,-110.378916,-94.255055,-87.790307,-83.343971,-52.825759,-41.021051,-27.096416,-51.69115,-73.803134,-55.745286,-7.237327,72.231146,58.710398,-27.159129,-52.471108,-38.123448,13.079268,20.088725,-46.584461,-65.857646,59.973871,171.65434,311.891706,247.243201,164.649941,17.901959,-13.093219,-20.490319,-25.075428,-42.859837,-65.781325,-109.56036,-279.781123,-348.228942,-293.087048,-191.776472,-71.283314,-78.462319,-100.136398,-143.929006,-207.601712,-334.101546,-353.2855,-300.981096,-252.322177,-139.86973,-46.840851,-48.066371,-125.191494,-142.729188,-83.419368,-40.834462,-19.414542,-28.902641,-19.525534,-4.954837,-14.711029,-102.718169,-167.572138,-222.417886,-189.652711,-61.33424,22.760534,11.541391,-100.621584,-168.866252,-233.985405,-193.666873,-34.271938,1.508088,-79.788211,-177.466706,-185.643978,-163.592837,-140.1927,-68.712946,-51.301264,-59.703399,-74.503564,-109.972847,-202.231158,-217.747989,-183.449654,-141.908871,-13.45476,47.605145,60.519309,-73.084332,-141.255126,-187.691248,-153.650861,20.698342,127.11744,261.435984,242.009776,188.043224,57.169359,-5.911884,-98.383146,-109.10914,-68.674367,-38.716648,-41.125006,-140.744235,-184.601455,-214.667374,-205.250377,-142.563406,-96.562565,-2.162725,14.137699,-37.13239,-168.900994,-203.00764,-211.562481,-205.279373,-183.303272,-170.589434,-164.028609,-215.042653,-236.996014,-223.41834,-220.204539,-262.223734,-256.759909,-126.545793,-71.667695,-121.924827,-209.291989,-214.500717,-201.666074,-190.205196,-160.721518,-139.185305,-63.364635,-19.733917,-36.820089,-80.082175,-71.718757,3.647107,53.355409,190.907967,274.663749,235.044341,112.650806,86.369858,105.26906,143.897443,245.436621,282.533873,245.0479,67.992524,-8.251278,-96.29395,-123.710352,-145.046636,-133.90813,-102.380243,-169.523776,-229.582554,-290.844087,-296.0092,-278.551174,-245.08712,-167.660599,-136.870715,-87.691411,-88.334436,-110.332015,-179.358275,-195.801926,-105.924992,-27.903875,80.269204,115.142305,110.809835,65.462309,21.539494,-64.012926,-66.986147,22.48151,85.206052,173.981692,144.198927,84.096777,-24.549731,-33.262538,50.608638,117.796647,218.132572,274.591409,296.076606,278.129348,230.205274,147.192748,158.576146,226.159071,234.730059,206.782496,168.646339,151.787101,71.119158,17.231889,31.86084,104.688209,209.626032,175.560234,134.028688,79.509812,73.82543,92.516453,115.848396,152.813873,158.174989,143.888021,86.801021,55.745654,14.920083,-0.996344,-29.566555,-37.300306,-2.116121,66.934192,56.355739,-35.881685,-77.750899,-127.345753,-120.590702,-53.079295,-30.041337,-24.553158,-2.783622,1.385317,-49.310489,-82.32773,-89.952753,-67.859297,2.058599,57.196898,43.378359,-30.279607,-51.770127,-38.48114,-12.45628,45.571193,82.384323,196.173133,208.283052,134.167882,-11.846899,1.86303,163.125097,218.302447,219.518838,235.133988,256.417625,266.161625,251.303129,208.751267,194.660311,248.001597,326.615137,416.073521,243.700154,120.302152,-32.199231,-40.029904,24.390571,72.006695,173.484197,167.800187,116.249064,57.098383,57.970865,33.684034,23.832321,86.828662,130.577633,99.271253,-8.968844,-0.212561,91.421769,105.818887,91.55051,114.757275,210.701161,210.578721,156.87646,41.740453,15.841471,44.76976,82.667749,163.58858,215.89009,324.288141,304.965896,232.773927,52.386281,2.908168,70.565682,148.86812,220.30288,122.140734,51.205238,-50.630741,-86.11821,-154.962445,-174.781321,-130.202836,-64.00384,62.820668,29.550208,-40.678229,-143.642336,-118.835712,78.199349,170.108626,185.97792,44.356502,-35.326902,-160.843396,-201.949241,-210.509431,-164.386568,-25.157347,30.213011:-5.517074,79.642706,108.856914,149.619872,142.361678,104.096437,103.515131,152.858661,198.315341,179.854472,86.452061,38.748371,-71.700108,-118.298839,-122.801997,-93.103499,-36.496337,-31.253418,-57.064703,-194.633997,-294.598008,-431.989659,-428.720962,-267.608991,-51.83538,-6.037842,-76.309961,-161.147811,-337.21184,-376.339995,-325.089908,-276.123839,-174.803177,-93.037928,-83.674252,-118.854187,-142.284675,-156.497883,-153.153211,-163.178463,-202.23695,-232.430487,-285.032395,-291.943479,-271.00117,-234.843824,-113.230265,-60.895389,5.851453,33.070533,27.490282,20.330339,29.094346,39.974954,26.636035,-6.76881,27.103196,39.264411,-20.584949,-60.041151,-66.109317,-18.461699,128.795794,183.955021,235.225732,237.782918,215.355999,114.34886,46.517905,-58.088959,-79.384948,-64.208988,-20.828514,-20.668837,-49.317724,-53.630908,-51.926633,-52.852313,-49.280649,-41.477771,-35.10759,-112.817992,-151.579633,-172.053169,-172.099539,-127.608952,-94.266825,-109.392912,-163.043148,-150.718402,-46.441452,6.709948,29.531295,23.294291,97.158734,169.815532,257.265644,203.849157,150.674991,27.567806,-35.169516,-93.485547,-98.542952,-154.939715,-206.207291,-194.703943,-184.243816,-200.483304,-171.538331,-121.110145,-60.154225,-53.693396,-10.242891,-21.539256,-83.917945,-178.017961,-177.683888,-153.575009,-139.088763,-59.043954,99.506776,161.778651,138.279826,78.265739,11.808084,4.307259,-52.832105,-102.224906,-167.465429,-147.853358,-142.465548,-221.887244,-289.283612,-330.827762,-273.943708,-113.799973,-35.286941,-21.636812,-36.384539,-66.704753,-110.694369,-101.43787,-69.151055,-75.896745,-119.945555,-138.221254,-140.805514,-155.464216,-155.820775,-107.232207,-58.187175,41.671759,0.126984,-76.092342,-203.295638,-232.520098,-237.898905,-205.097066,-79.426127,-21.111683,17.984928,-14.331189,-22.664851,-45.011667,-63.405301,4.319649,112.973402,357.21429,397.741428,317.788674,156.55708,125.356254,67.068133,11.345845,-81.886275,-88.228576,-61.413322,-82.257443,-96.447237,-101.659088,-118.338216,-157.070893,-150.253195,-114.337866,-60.485056,-33.300381,-81.868603,-148.269425,-204.137655,-171.524738,-88.842477,-76.29672,-81.742463,-79.304332,-73.711088,-57.595284,-54.584123,-19.359384,15.272301,60.031834,66.098053,50.481258,-3.693039,-35.207877,-124.001927,-164.435152,-162.268069,-116.587769,-24.043677,-53.681562,-84.492328,-120.705454,-136.241234,-100.308081,-27.426922,162.351034,260.398722,237.626427,115.341891,63.312131,11.626499,32.603981,161.470432,207.461808,161.332845,23.037154,-26.026825,-57.720545,-61.624145,-58.812698,-41.811652,-41.062674,-140.707117,-191.894046,-262.535292,-288.301296,-311.185804,-302.316247,-261.155428,-246.765872,-240.563559,-207.19419,-182.67128,-207.077977,-245.599456,-203.980151,-124.598917,-17.686446,29.274123,59.547343,44.710129,-5.277845,-53.493768,-29.631919,28.422832,47.243222,99.461925,107.082491,65.3345,-31.236733,-46.225929,10.974339,65.078878,185.021927,252.172504,253.881716,252.809201,248.411551,195.715404,176.632576,219.26698,257.393219,282.249237,180.348063,114.464548,72.519209,85.879858,121.083446,146.657933,205.8286,218.516927,189.805391,99.839486,69.210042,51.655691,49.318036,27.325483,27.010849,80.528849,50.508119,-11.916081,-75.499859,-65.183393,-48.126162,-60.403819,-105.176771,-84.861692,-47.850567,-2.067322,-25.908763,-153.536213,-207.233066,-211.161654,-172.987292,-72.294844,-23.419536,-32.190022,-81.634,-106.950786,-141.994399,-149.412331,-117.786071,-47.408611,-47.235879,-120.432427,-146.015628,-128.976769,-88.987112,21.224906,71.579421,132.742193,61.751789,-4.76772,-119.207756,-157.504434,-162.285268,-124.819821,-19.677317,99.226635,164.151936,171.970031,89.128135,-52.995542,-30.598909,177.666309,280.808607,302.421692,103.928568,-0.447744,-112.918555,-120.486592,-90.881156,-76.880401,-48.817292,4.02754,36.201635,39.488166,-14.282234,-115.910513,-103.940615,8.674774,65.955658,108.056786,53.758909,38.758401,66.557152,89.184747,118.554352,126.97395,150.758085,155.643703,109.21886,-62.248195,-112.609409,-67.682648,-15.743654,97.745777,165.726014,273.855468,268.535238,229.450623,149.683962,116.393402,65.754901,53.684903,43.771858,41.608352,40.303655,55.35552,60.476375,25.176108,5.447151,9.774115,11.866181,-7.120326,2.894856,11.619753,-3.325406,-19.048673,26.350131,96.757327,218.588479,175.960097,90.793806,-59.246965,-75.591705,-59.222104,-56.746739,-34.246696,7.451387:170.480842,312.44345,306.603331,166.185986,107.886597,108.34627,142.627631,196.081904,173.553251,131.836267,60.767554,35.830603,-65.81048,-127.859387,-167.879953,-133.968207,-20.938531,-12.199946,-61.922227,-213.549308,-283.545477,-313.290124,-274.38021,-148.365999,-0.181504,47.829779,6.284186,-87.47059,-289.989591,-309.682261,-176.211031,-111.272091,-113.368581,-187.961193,-192.061108,-150.847562,-128.180769,-67.76352,-49.810931,-109.325363,-238.67498,-293.871439,-309.626002,-265.884966,-163.614374,-121.809306,-47.939942,-12.858155,38.514732,35.377574,7.047722,-88.110867,-130.295794,-135.316143,-88.230413,47.369579,115.300317,83.504316,-56.555813,-111.659117,-100.297265,-15.537024,199.097573,250.557575,192.27169,89.216237,70.863648,4.737006,-65.173742,-143.75064,-119.297612,-22.356237,1.979442,-20.615121,-72.033312,-91.27219,-100.047368,-87.61006,-80.136974,-82.63272,-75.422107,-134.572416,-174.267366,-218.37358,-228.144862,-164.480523,-87.909753,19.678493,5.164697,-15.326245,-72.85982,-116.915817,-141.749081,-77.10889,128.334214,208.631306,299.478019,261.266792,182.531635,18.516831,-9.392347,23.746384,34.092343,16.668157,-69.610715,-148.990757,-265.194902,-272.868158,-231.079284,-182.040599,-38.837133,7.203824,-10.272426,-60.129211,-73.373653,-119.705913,-145.451138,-126.414473,-95.093812,-24.743397,126.279274,188.201009,149.362337,75.826224,-25.779583,-39.083379,-62.502436,-72.375157,-63.497896,-78.996671,-85.875523,-109.80154,-160.604942,-274.212624,-269.023845,-125.436359,-20.384878,-41.75794,-173.546364,-233.422646,-269.490103,-234.888712,-153.44927,-142.369454,-130.161397,-157.650026,-199.878772,-288.248053,-300.002598,-209.753366,-139.929827,-57.895247,-117.311707,-177.206105,-238.366755,-232.124198,-183.145415,-138.202395,-48.269047,-30.005815,-45.064331,-108.147422,-123.869899,-89.724772,-66.790987,20.39266,115.339897,325.029548,328.581708,248.895121,90.551656,41.040981,-22.80883,-45.422395,-61.846843,-29.145982,64.527462,-51.647734,-160.936416,-263.309885,-241.634682,-128.7432,-65.983402,30.574278,34.21093,-18.642684,-169.964907,-215.563603,-185.243413,-138.245104,-92.605654,-85.132663,-61.147296,-96.324431,-108.714412,-95.723265,-102.381727,-115.992528,-88.625042,23.265978,70.361456,55.561562,29.011679,19.724688,-43.641721,-74.576746,-32.070077,26.906821,84.764279,-3.057574,-66.221373,-145.677234,-138.109351,-21.481262,58.033608,193.813851,246.941631,215.054087,77.456685,25.986924,30.340564,74.098113,155.797785,169.504614,134.47704,23.014806,-39.317624,-156.218521,-203.792143,-202.558867,-163.047135,-92.236491,-52.56381,-61.609727,-161.452098,-245.418553,-373.131041,-346.594471,-167.50884,-97.20592,-57.915086,-99.615535,-118.417284,-167.301707,-199.554291,-166.211962,-78.937023,88.531859,71.408589,25.390335,-34.618264,-38.979704,-45.418813,-62.840178,-65.214139,-25.730884,58.65379,17.327818,-41.259947,-162.880452,-195.865762,-118.828249,-13.176575,210.674276,319.37572,304.447071,193.80684,140.645198,95.471337,108.630266,165.760281,187.53969,184.095703,114.753887,71.064917,-3.003655,-16.5791,38.796115,90.642126,185.626404,185.948003,126.795663,0.83738,-28.64534,-19.974067,7.805663,67.156489,101.206668,156.105563,82.261236,18.057542,-75.525202,-102.265535,-121.973759,-111.206005,-22.576318,51.95762,27.853486,-71.336406,-112.288166,-150.362886,-122.015308,17.940041,83.469792,111.129838,50.112131,28.349454,-27.693332,-58.989631,-40.019523,-4.35621,31.442291,36.939353,33.738873,-47.327085,-128.722014,-207.867391,-154.701581,-10.10757,29.125515,99.588123,90.623552,30.802938,-105.398264,-140.605503,-98.499838,-46.132463,51.932836,137.520709,174.41066,181.075538,118.989543,-29.300156,-21.519298,175.971872,282.389834,308.495081,118.330818,52.964119,29.834888,8.885858,-73.434178,-71.892488,58.691723,131.365062,112.551868,53.122532,18.406557,-21.069284,-1.119419,61.058386,83.046656,100.855365,88.734549,92.52895,119.318922,134.766006,188.286318,237.841889,335.517119,276.853189,181.296147,-1.367663,-46.847593,-20.758409,45.409593,198.443181,250.295181,267.978737,204.598484,168.008741,71.159594,21.561985,1.176854,15.29541,27.046644,3.962249,-19.646323,-30.985967,-26.433637,-66.808891,-105.743389,-123.749561,-67.467175,87.665559,55.944892,-5.27915,-84.348906,-97.620202,-18.579904,70.574131,186.304762,106.745879,38.794834,-41.326299,-70.495649,-117.479603,-101.253524,1.700912,65.806748:34.531044,135.756358,135.457518,126.232026,129.913683,154.941266,180.834122,242.814854,287.591608,271.754497,137.24023,78.092637,17.009372,-22.272538,-73.876375,-57.354656,13.56011,8.117167,-32.876436,-124.387419,-160.318106,-188.643976,-171.491342,-103.399376,-48.526039,-38.341875,-71.374907,-109.763806,-193.049452,-212.716717,-191.580078,-168.890537,-90.845951,-3.616275,22.225538,25.439824,-26.924387,-186.758044,-210.768787,-134.817098,-83.619287,-82.093809,-140.946186,-203.460299,-280.19297,-244.141641,-91.138204,-49.985716,-82.81814,-112.367943,-91.729048,-52.850386,-59.847948,-79.276239,-60.446286,37.567745,91.002213,61.481181,-55.217775,-94.41472,-75.891761,-28.06926,63.275392,86.056537,163.803852,297.513853,329.756621,270.079555,196.539208,76.777204,58.981199,28.419004,-13.423355,-10.32254,-4.695111,-9.701369,-2.772834,3.757256,-37.118597,-94.140098,-197.936109,-229.007989,-230.816016,-230.779539,-231.877456,-184.884711,-123.346265,-22.669034,-38.749731,-54.894321,-29.906731,-5.288614,2.271379,4.293575,68.59612,124.144865,204.712212,170.427431,163.842001,202.485771,163.028633,-64.991048,-156.597381,-170.58528,-127.898987,-139.396587,-179.550011,-174.766851,-88.452751,-29.674896,42.426711,60.383383,88.392303,20.217567,-41.298275,-118.266933,-133.151758,-115.617169,-77.626945,27.143269,144.170372,180.102257,162.48072,115.059751,-4.735978,-39.013072,-28.686759,-23.277532,-86.843264,-203.129396,-227.53811,-203.791877,-198.718563,-174.811846,-122.132504,23.568901,93.39346,73.214608,-31.816144,-82.140022,-109.498595,-81.636847,-34.277929,-45.008259,-67.616727,-86.746887,-131.765989,-184.302526,-152.989117,-47.684247,-0.881695,81.333592,108.466868,69.507135,-83.356395,-149.752331,-193.058014,-176.628998,-94.826315,-42.527694,67.953896,171.844127,186.039927,100.721188,40.724589,38.88074,101.858372,230.58698,273.100199,260.842263,213.930405,185.825882,62.617555,-24.257206,-94.10911,-62.577233,-18.22857,-52.19032,-89.128325,-170.259426,-164.502895,-34.486717,36.041198,97.666056,102.14888,81.554009,18.402358,19.983331,81.29066,98.08654,114.04261,136.441544,186.637079,186.592155,172.075142,164.160595,167.981782,169.543375,170.435854,194.18488,227.28887,210.411609,67.686172,-39.417464,-196.084536,-202.423012,-131.761437,-125.869204,-200.794208,-237.239981,-229.341228,-197.443656,-182.936085,-148.214581,-115.841172,-0.64356,120.60669,127.687363,61.332496,45.037389,105.025163,175.734748,314.914513,335.975793,278.8749,163.767966,103.722988,76.545829,97.494843,91.02605,79.680039,101.103376,62.879179,4.565532,-86.614434,-104.480403,-138.190995,-148.858485,-89.313655,-44.271787,-103.541204,-287.856818,-310.160359,-238.315039,-219.870209,-207.911243,-176.852381,-92.653396,-48.027255,-42.782961,-33.645048,-23.611888,-33.251396,-54.161394,-64.583641,-44.600942,-7.911548,-39.357895,-47.867251,-34.279149,-67.334519,-155.968715,-124.001577,49.671967,100.813209,80.818309,62.961267,55.010582,6.66732,1.261931,25.588849,7.280952,-38.188921,11.864139,32.713587,17.305739,-10.584696,-40.134128,-15.581777,67.853919,88.565419,64.058722,-12.645614,-40.463318,-51.804882,-50.618482,-48.255998,-23.67059,53.827096,22.379946,-33.869332,-99.927308,-76.548212,17.21221,33.555406,-12.266414,-7.9066,24.570727,63.362075,30.50422,-135.11165,-182.954758,-103.712164,-34.578272,42.518082,8.680859,-37.258038,-122.326418,-147.909295,-135.282889,-106.490536,-48.612652,-40.261452,-62.785484,-98.27596,-104.663475,-86.569688,-55.476435,1.290375,16.495124,60.982292,119.009481,138.698204,110.53719,65.801655,6.118564,-8.227731,-12.144644,141.506768,232.991245,198.675449,79.296391,-112.281005,-117.338726,30.812351,124.104921,165.326579,-14.790894,-99.155682,-136.814312,-126.398953,-143.172725,-153.692048,-101.20431,-1.906545,22.836963,0.813177,-33.682296,-39.636709,19.511145,158.830813,181.944021,177.244405,198.076562,206.308124,215.366747,214.862859,201.769084,190.016221,126.896965,73.023102,62.859991,-3.850283,-38.598792,5.282483,88.369944,271.637588,321.580843,303.913272,184.183616,135.49757,108.854637,99.82801,73.368466,63.858123,13.949335,-38.999595,-23.933081,70.397251,102.31693,91.436464,72.538079,21.85058,-6.558069,4.02838,107.585076,127.198283,25.386818,-34.697557,2.019377,68.477239,125.590223,82.970957,48.366523,-19.892801,-59.117568,-149.654429,-172.456277,-132.203554,-80.140075:122.138061,227.619448,216.309079,148.360098,118.808104,116.58991,141.140988,177.015495,130.070582,83.88258,4.963758,-15.951033,-44.016885,-64.840527,-99.405956,-84.373815,3.221011,14.968673,-40.047323,-218.8764,-289.42063,-259.487638,-173.62112,-19.16617,54.872897,58.924096,-34.22086,-120.794546,-274.346637,-295.896058,-183.20198,-91.722005,-7.826179,-58.574448,-78.408863,-72.707974,-83.642546,-153.040478,-170.038655,-168.176041,-206.02168,-224.124723,-227.029222,-224.439052,-222.0179,-191.104385,-44.88662,7.531258,-20.469318,-53.381036,-26.153947,2.958289,-22.807574,-36.185693,2.363939,84.737945,83.202016,47.950901,-47.847958,-87.657875,-82.654352,-16.174409,181.483639,263.327928,345.845178,317.680722,268.405152,144.604295,94.840364,76.248586,102.692842,159.734946,134.033603,87.015519,-14.799632,-52.590435,-85.694913,-75.759353,-30.387964,-21.415143,-57.911931,-168.177298,-219.547326,-245.270506,-221.534811,-133.647357,-103.976099,-93.826003,-35.68544,-2.552625,0.762423,-25.822156,-77.957252,-60.850384,56.488308,122.542505,216.377074,152.073716,75.299929,-26.25197,-48.252712,-66.205609,-55.676151,-34.779031,-106.155958,-176.349698,-264.189823,-242.980905,-107.095222,-28.41126,83.361613,108.99622,109.239204,7.641367,-55.97302,-74.9278,-38.389292,9.860568,26.737194,113.023257,248.756188,298.628325,254.977911,157.973691,-31.439418,-55.648595,2.090676,16.0269,-37.348311,-136.023989,-182.709911,-256.261546,-281.303902,-242.104606,-167.590485,-5.654218,55.502663,14.967805,-147.524071,-187.076069,-123.403098,-75.791203,-55.109571,-72.006778,-96.192904,-140.524018,-186.529358,-265.024677,-259.487386,-146.402302,-86.691108,-47.5024,-72.294738,-103.328199,-174.435425,-191.670355,-192.225903,-170.660634,-53.619916,16.145241,75.851206,41.594065,26.167784,4.591949,-1.024643,76.590722,162.722641,317.973169,304.276956,215.233306,37.665223,9.513331,0.08297,-21.606578,-68.334221,-51.99286,24.078181,-69.860471,-151.109512,-191.88173,-162.523345,-86.237933,-43.865388,30.388918,28.458369,-3.669527,-85.634474,-126.727556,-190.255562,-184.358284,-76.311218,-3.456945,82.728203,22.560272,-4.321342,44.676817,73.221973,87.009921,95.83237,121.453705,113.861831,98.333865,71.467194,41.012668,-64.543272,-92.242835,-41.710333,-11.858899,-44.576383,-122.551076,-142.801511,-131.209722,-97.15803,6.524289,54.010811,135.075329,186.861025,156.962061,29.230313,-2.030667,41.673716,113.228795,282.395026,296.133414,149.260956,41.65546,35.095465,-23.503345,-67.907185,-30.199851,31.60596,55.794393,-30.603019,-78.434707,-157.490681,-180.344481,-220.099836,-230.938821,-210.379631,-199.597644,-217.649835,-306.812333,-356.187173,-394.324939,-370.581746,-243.296477,-176.480208,-103.687058,-91.787285,-102.942299,-105.063429,-88.965271,-91.86266,-101.21908,-87.691605,-97.034982,-148.631326,-112.938937,-82.308332,-93.754512,-130.627563,-160.197764,-118.904541,54.569387,168.993351,149.878257,21.222737,-37.98543,-86.63254,-78.259836,-16.481917,29.353033,99.622202,52.631085,-3.034879,-78.565049,-72.27366,-4.062061,30.028157,69.405956,52.279159,8.34345,-115.65094,-170.729663,-222.509946,-200.534358,-95.117504,-35.322949,59.415332,63.101371,42.93176,27.323762,30.768204,32.291523,37.215284,64.469748,63.858194,35.196862,-19.066308,-30.85703,-69.494534,-81.981935,-30.739547,21.184835,104.946002,121.170857,116.679525,70.392255,28.928586,7.484721,36.163522,82.998997,33.870571,-14.888591,-81.004755,-103.573163,-133.747139,-105.743479,25.222484,89.010629,168.565593,90.13297,5.192394,-102.33815,-104.825724,-32.810214,21.65959,154.843386,249.878187,223.550769,69.821911,2.153842,-34.765992,10.383299,217.334624,329.668063,392.6356,192.854116,75.82812,-29.703776,-25.093577,14.995394,38.916205,116.157219,163.266345,135.236649,43.238514,9.824666,-22.817581,1.381264,149.140382,219.602227,244.932334,184.012187,175.240585,195.616276,197.929994,229.698955,273.396188,333.054651,279.398129,217.559219,86.124011,57.140102,105.069958,162.149422,314.164211,395.612796,477.473287,375.501968,291.408315,150.976792,107.923754,101.978199,112.369264,78.637119,2.991861,-28.949755,-24.417512,6.884815,41.518328,42.311222,65.694812,89.940138,96.116087,4.649039,-28.409665,-10.179927,10.828736,48.49625,80.250349,155.052071,149.197013,89.902877,-73.544597,-129.836962,-158.144191,-142.260575,-61.81057,1.580361:47.53892,149.798833,129.045991,94.51116,99.78781,151.581042,226.063602,401.645118,415.34862,381.774894,318.210549,281.156526,220.743376,219.560773,241.533696,229.453715,147.799332,100.694245,100.033356,67.299994,33.863009,-17.290775,-26.926225,2.401767,118.378743,175.750475,196.274246,167.402494,85.755651,49.188519,33.358132,49.842863,62.489703,44.176146,55.415634,91.972458,70.30551,-34.864416,-55.002029,18.570454,87.267571,78.243441,15.276359,-14.788412,-89.747827,-143.751885,-199.031614,-168.191066,-42.292664,-8.045759,-43.167767,-129.053653,-162.082243,-167.294917,-124.936297,-8.322434,40.11529,2.178358,-139.349536,-169.588642,-135.965224,-114.106284,-29.31405,61.416567,264.658185,341.949784,341.661586,290.659872,230.212506,145.67101,159.13135,192.048547,150.329187,117.919757,98.725698,135.69461,205.61505,175.815471,8.458211,-63.928059,-111.012842,-102.007067,-93.526258,-73.867565,-73.809737,-94.582285,-106.671386,-119.28779,-38.476258,32.699461,113.312808,101.433127,46.469768,42.846211,111.335456,148.832157,163.343347,172.845474,180.735102,125.788455,66.076711,3.200422,19.70525,32.773146,-77.385538,-119.541457,-65.48902,-15.406443,-15.53193,-42.560815,-18.074622,20.83056,42.872764,-72.799968,-168.763654,-333.073485,-382.850647,-390.543292,-334.142418,-161.626053,-49.368693,-28.491814,-16.612099,-30.193004,-107.342987,-140.524974,-121.738729,-104.592021,-175.049256,-283.039032,-282.843819,-226.410865,-230.819756,-253.494869,-208.330117,-24.198078,115.087154,149.347004,151.121374,107.815543,-27.90982,-85.992199,-156.89352,-168.222569,-152.258172,-192.211122,-227.419212,-175.268626,-120.785607,-116.325177,-134.012063,-85.366658,-9.772079,-23.919736,-104.244306,-125.296654,-121.264172,-105.824324,-53.789687,-32.817915,-2.293436,83.898922,130.330407,126.61919,79.041305,19.306538,43.962343,142.436737,172.279215,169.048389,159.683798,138.307519,9.019977,-77.517984,-203.814258,-234.712759,-225.869043,-207.635806,-222.867323,-250.964854,-224.72634,-32.828407,98.311002,254.721219,211.775523,172.83341,185.785417,236.303974,316.769369,326.278193,357.864226,387.211358,392.555064,366.725488,385.303909,446.802223,455.731972,431.258089,416.603339,388.348281,318.33695,260.757245,138.487643,81.472069,-27.007366,-69.43369,-138.448272,-162.58394,-137.091215,-117.134482,-139.395824,-164.417653,-156.881958,-118.960936,-91.474594,-78.438011,-93.132121,-65.382256,17.588943,35.266823,42.652358,100.210997,328.744191,402.000962,364.099346,210.491819,140.035749,137.838755,220.343429,426.056629,479.504674,432.723197,302.127731,243.623656,148.486488,133.545425,184.831824,211.879228,194.471872,160.131209,98.701629,64.453464,36.072098,-63.977612,-110.36967,-104.913468,-64.850293,-37.999392,-100.776816,-141.853231,-185.067339,-167.128604,-125.649061,-144.059677,-211.404307,-207.066161,-102.48186,-96.114725,-167.552402,-259.204819,-234.897257,-137.075998,-104.620859,-112.838814,-194.567537,-236.602018,-276.802973,-265.897199,-250.918657,-258.875451,-215.036693,-188.215412,-223.262348,-235.469967,-211.666347,-182.829319,-177.817725,-151.519818,-128.259353,-63.690446,-20.76767,-36.093866,-150.404592,-220.259539,-250.605201,-206.626885,-146.986892,-156.915796,-132.217624,0.550076,42.096611,27.947757,-1.294965,-8.249655,34.716941,115.797617,109.937674,121.3911,171.304419,152.476512,36.336407,11.98449,32.618243,16.273356,-71.935199,-145.607821,-153.29754,-91.46814,-53.444582,-27.742511,-13.206371,52.675798,67.456584,41.600417,-10.736707,-8.750389,42.009458,69.3971,100.832705,101.64182,98.794612,114.890148,126.166183,104.291855,47.844086,-53.925595,-61.659629,-46.299428,-1.281833,19.493724,-22.778053,-88.905538,-220.768981,-239.584424,-160.542552,-103.151268,-81.041946,-182.703068,-211.183717,-150.123988,-110.112915,-160.136303,-221.485372,-209.764889,-79.836709,-84.87323,-214.789605,-233.03921,-65.580528,61.911826,183.39779,157.389096,93.850536,123.056959,160.537221,224.266941,220.133814,164.305133,142.788328,131.753202,103.046803,51.930315,-89.447156,-133.69602,-92.340587,-11.137409,169.540517,228.867474,301.323679,286.13679,229.745049,113.376817,83.269316,57.469332,36.683569,-42.783151,-70.019919,-27.14018,126.227624,187.21305,205.965923,182.204408,112.761548,68.979948,35.495004,88.206023,85.664398,-14.510533,-68.483913,-72.048435,-29.035976,61.84267,109.327423,83.0919,-87.460244,-176.61853,-255.303526,-260.463287,-230.471345,-197.177332:-45.666241,50.861738,60.784096,59.099261,82.508724,172.571109,217.019791,309.968407,409.168153,407.755528,288.407305,232.935935,190.242892,179.380183,171.272177,174.453678,157.880108,79.5917,32.719156,-49.932528,-96.535762,-188.54534,-218.68864,-213.663995,-75.07629,1.898823,26.854315,-23.450525,-155.094375,-186.075196,-111.526834,-38.733218,88.839802,151.043894,163.484693,155.491423,106.492184,-23.796339,-37.404521,19.591227,59.447068,72.377494,63.403861,21.930618,-132.165653,-203.05001,-184.114872,-92.976681,88.8145,93.943348,40.987677,-40.430126,-49.628308,-70.075109,-81.093138,-21.139032,103.338169,130.789891,79.374608,15.326074,-117.381329,-140.47955,-52.695368,23.237089,114.387209,106.563743,118.74619,174.286478,161.6682,38.598115,-20.237388,-50.247184,-5.207259,3.575521,9.705941,31.783939,64.772695,50.019032,-11.163459,-46.202718,-117.921709,-137.57713,-138.653339,-150.826939,-152.016677,-150.332132,-154.501485,-159.473902,-126.890126,-90.728125,43.238188,120.387128,154.18586,118.301297,128.145225,194.516048,308.168813,284.238942,248.056691,173.462599,128.958021,47.400758,19.167361,-25.431821,-66.043578,-89.11675,-122.521196,-134.169647,-164.104215,-155.634788,-41.703801,14.958018,-13.132687,-168.17867,-240.700036,-313.097675,-325.697248,-378.987749,-415.274869,-375.210823,-165.887713,-88.149651,-46.191223,-49.112626,-59.604403,-50.372731,5.627553,13.925753,-82.091372,-218.32954,-254.771274,-315.933741,-347.915276,-319.21493,-240.136286,-55.117336,22.70287,32.161199,70.644712,89.383173,40.587757,-6.91291,-16.342953,16.885211,60.05889,-14.75212,-88.67411,-147.100953,-117.000938,-64.00224,-53.609561,-24.65241,-31.302317,-87.289041,-254.513666,-297.439898,-251.217122,-214.077183,-181.288031,-145.413827,30.813267,163.483608,163.366495,103.643082,69.414105,20.354434,16.56838,65.967249,153.409237,174.089303,133.214708,72.704161,-91.267102,-152.688905,-165.931426,-129.738801,-54.079325,-96.763265,-168.007191,-267.781288,-234.157353,2.513066,131.89344,218.516683,120.62422,86.869849,138.013166,209.535654,294.096075,262.447713,147.553679,118.471314,96.340104,108.025138,159.907635,265.670938,260.172093,183.49357,159.404179,135.600902,92.418851,58.397966,-25.10124,-73.291431,-199.326388,-267.963462,-318.986446,-273.21144,-138.630602,-194.609306,-271.150083,-284.965693,-226.933929,-170.438692,-186.283277,-172.711987,-31.95495,22.279447,13.628666,-16.079502,13.162951,103.307954,306.481401,349.209829,309.258011,145.633366,46.403843,-61.260714,-58.752937,51.257037,148.384262,251.443182,100.354662,8.543325,-36.062553,-3.857228,48.960406,50.488669,28.338208,22.025246,23.248124,-16.376279,-48.148295,-108.078759,-143.381546,-188.552964,-169.06211,-96.399037,-109.385478,-131.512895,-129.184924,-116.539431,-148.413296,-191.223451,-200.036148,-132.336944,12.487912,-81.855508,-187.445064,-276.996198,-254.416125,-185.876098,-138.541721,-16.318007,27.654234,12.782284,-34.215724,-65.853816,-122.959669,-119.480507,-37.861067,8.044266,44.705622,26.948169,21.811164,6.959366,-22.897304,-61.044033,-50.443056,-44.623188,-46.582017,-35.994732,-45.986833,-61.477456,-81.458209,-100.230676,-133.632628,-116.714878,-56.546987,-115.286398,-164.397657,-182.708334,-172.31869,-171.904531,-164.64428,-111.375006,-23.441018,17.92135,4.507952,-58.353429,-151.764599,-135.739235,-67.918419,-73.673799,-149.727715,-110.606176,-32.35778,65.130734,58.223231,53.929574,84.684869,169.573787,180.039793,133.818675,4.030136,-32.9256,-24.571591,4.416657,100.387636,160.162051,257.137642,249.116418,197.16627,87.255599,64.039943,90.025801,106.686912,119.474676,239.658968,303.33103,230.757103,121.011877,-32.583736,-45.057753,4.122917,27.707482,19.165847,-79.096456,-122.236309,-115.476762,-100.417123,-96.85346,-97.785964,-112.179491,-79.199786,-24.934501,44.753078,15.388163,-66.215971,-42.095352,63.980928,65.791717,-4.215144,35.885585,103.432243,214.357785,218.147971,146.449083,126.352604,171.564347,175.266725,102.83052,-94.250304,-144.091891,-100.16677,-17.805442,183.5869,250.131681,274.945614,193.918861,141.569369,101.96791,114.53044,132.271416,121.45379,64.720288,48.543271,78.244127,194.402507,236.030539,190.413751,137.171124,66.756797,36.139011,7.590803,104.389866,155.213563,116.066504,46.175004,-35.86317,-41.785109,-34.00105,7.04085,-0.442459,-146.077153,-231.752773,-257.400123,-201.40756,-101.838311,-88.590627:51.161674,216.064697,204.978558,131.313469,129.476145,175.934312,183.085988,185.419836,191.823197,160.460279,85.8732,76.558945,16.19152,-40.148822,-27.584227,40.47234,85.628932,-7.845238,-43.62699,-82.238146,-102.204044,-115.152138,-79.791965,52.418942,152.508826,147.303921,32.327284,-20.833684,-58.478578,-44.828876,8.16178,7.891949,-39.142435,-28.054344,-5.289854,-17.531704,-60.954085,-131.77108,-128.472569,-71.558078,-51.139349,-78.333943,-107.287617,-84.003802,-97.006923,-150.122997,-170.222123,-110.326285,-6.310224,-26.27443,-36.962357,3.851478,25.523751,7.861222,-14.158825,6.470356,90.009968,98.640497,47.514864,22.344619,1.927687,8.527592,116.305632,213.789273,349.957035,289.122988,245.307314,257.905224,262.023667,190.472797,144.214942,58.203949,9.136851,-4.531869,-25.748954,-23.408952,30.53939,66.851329,60.184998,10.124814,-91.037516,-115.181376,-106.63488,-102.930885,-131.682224,-182.645945,-155.729972,-52.023397,-18.330007,-15.32751,36.475452,59.946929,13.028914,-18.54429,31.77287,99.893293,233.069288,222.917809,168.680753,110.433779,88.160821,-28.978526,-67.751842,-9.094039,17.331958,-17.737147,-40.872297,-12.338346,15.232621,9.003915,13.5156,14.027526,11.468,17.658522,11.993167,-44.285385,-81.457616,-76.406586,-26.421733,112.808845,254.517245,281.70112,192.509627,115.040902,29.200057,39.245482,73.666345,48.485933,-100.255188,-251.520329,-254.230409,-112.732345,-69.082193,-138.67455,-166.724974,-56.80633,142.147941,165.476421,2.746705,-86.904312,-118.582524,-99.058569,-77.463224,-56.292995,-3.138943,-77.94199,-141.462433,-164.095849,-137.633446,-123.751337,-123.244037,-71.60643,-49.943122,-78.523152,-105.068181,-80.772904,-43.464033,-34.981887,-1.630705,15.687638,106.265722,239.960498,237.286183,140.081547,120.89242,152.464576,172.311226,194.574018,213.631644,225.368044,203.947088,153.211867,-28.624866,-131.322036,-255.593288,-256.435058,-158.264196,-88.271161,-99.170716,-144.134224,-141.763248,-38.383079,34.708222,95.365536,106.731715,132.890707,155.351637,139.418756,107.979243,108.992667,140.767936,167.89674,243.789375,281.17482,282.280251,286.370916,281.718192,275.396766,283.688792,265.772396,187.532015,163.682583,131.201078,78.992475,-100.460741,-161.581166,-116.304522,-64.729011,-28.64932,-44.272506,-71.427809,-104.200176,-76.825599,-1.868328,5.127506,5.445177,49.548261,66.45155,90.439701,93.871195,87.194349,124.047968,290.785272,354.583436,360.173689,270.190119,233.480799,210.56646,190.783932,138.627119,155.051508,230.522138,208.432279,167.99458,87.667655,52.898674,-15.777798,-48.237031,-103.494173,-121.349699,-137.193104,-196.101782,-234.82374,-266.298341,-268.348652,-233.255927,-173.569014,-50.845711,-72.228086,-113.55224,-146.287419,-140.146792,-160.511181,-188.350239,-216.654697,-204.003734,-165.731804,-161.442767,-152.778103,-128.090204,-144.901924,-166.348984,-118.217873,-7.911124,-23.703312,-64.477986,-163.755679,-192.294775,-184.302569,-160.96842,-110.083676,-106.108182,-111.955477,-46.755333,-23.265365,-58.257026,-91.144584,-104.757477,-81.562683,-10.032207,29.59352,2.869789,-102.343332,-120.944638,-72.171614,-64.371327,-121.423288,-139.070391,-80.897672,30.707532,55.828922,8.137642,-25.785617,18.526321,78.066382,95.86558,32.019442,47.437511,112.963551,103.317913,14.235041,-4.848728,15.067708,10.841319,-5.728387,8.775765,18.50392,29.991256,14.996293,-53.085316,-83.279927,-84.00868,-3.994858,19.2071,-36.298886,-65.743929,-14.768063,15.306384,-34.146253,-59.583409,11.800743,94.665568,90.847595,49.767069,26.644918,-5.96427,-3.872506,9.411507,16.794519,7.790344,-57.009247,-106.545985,-184.858901,-170.836468,-19.327327,58.782524,51.997217,-134.451165,-187.006272,-116.983248,-66.865661,-72.251239,-102.222352,-111.644201,-42.937361,-26.467156,-82.024983,-122.79134,-109.627665,-34.859317,158.106788,198.480919,136.042832,87.523682,111.285611,213.264373,247.521836,236.874874,216.173955,171.644842,108.679849,79.949976,44.961132,31.854693,11.420027,48.748133,234.992217,304.490432,337.565199,330.584289,279.834004,97.037377,30.410646,10.437265,12.983275,-11.178089,49.434223,90.632613,101.062221,87.731369,36.573201,-9.257878,-77.008695,-80.322245,-45.942743,-28.047978,-32.910739,-36.075975,-50.20959,-106.244237,-106.137503,-25.642524,60.972638,56.962228,-111.508104,-217.273736,-284.62309,-252.025584,-156.069779,-110.985324:left
-206.964368,-162.759667,-63.317436,132.731595,142.47505,25.887461,-17.337304,0.997095,-2.005519,-0.651251,154.360921,278.139475,429.323418,418.843856,278.219928,194.117302,67.900885,96.859541,162.493086,268.116037,300.248283,355.705995,362.246862,232.983897,1.223095,-38.847854,62.954323,146.473566,284.617336,298.515394,136.996426,-8.609095,-243.565413,-216.817708,-116.123902,83.074643,111.366068,-13.617319,-119.03528,-253.478516,-239.245226,-218.020985,-175.553055,-131.670595,-59.037137,-92.064525,-220.932935,-231.901563,-144.801459,-7.955205,57.897354,82.13445,36.454921,-92.491021,-138.159763,-113.168611,-18.052518,8.201941,10.2165,5.06096,-5.191861,-42.733979,-151.969003,-166.571249,-157.136777,-247.205821,-299.30608,-281.96395,-223.842291,-179.919379,-203.175708,-211.099994,-140.276703,-80.111677,56.326726,112.190946,182.261703,178.833845,96.289094,55.71058,2.158358,-25.10873,4.571323,152.664239,230.18547,281.136733,234.995231,93.674105,42.491676,62.732262,149.66657,175.330773,142.154178,97.861371,-1.218321,-47.094963,-112.709957,-118.491393,-107.048575,-73.993724,-66.431064,-139.398338,-211.121146,-305.040084,-307.293992,-293.228689,-218.642129,-157.557455,3.976316,92.684467,199.911476,180.740699,12.671114,-85.755939,-63.155471,29.040847,70.738299,82.17172,54.123101,14.930468,39.622341,98.516305,243.127233,239.011779,72.729889,2.650975,-61.997693,-106.154627,-168.447883,-26.1575,71.355431,182.082011,197.87635,156.917605,119.418421,87.943826,123.183194,150.263308,173.492122,174.210394,223.743765,248.830796,184.246757,107.162898,-14.829551,55.825014,137.24708,240.977743,261.714203,226.210276,156.225394,-6.755274,-78.120891,-53.276336,62.530467,89.995756,20.896639,-46.831919,-168.875771,-213.050091,-265.53877,-215.420277,-166.584852,-85.332565,-38.733816,49.366781,63.876466,31.508247,-33.236007,-41.381915,10.05861,48.442992,118.272784,117.708248,11.783127,-47.33616,-112.538699,-117.580941,-95.713149,3.872254,77.174287,147.219656,118.549481,31.731714,-59.34671,-93.554415,-62.758805,-22.093039,-6.301076,-42.500132,-136.551546,-151.187786,-122.784637,-145.304892,-156.743863,-71.023686,8.782453,66.062339,16.443153,-90.7976,-51.185905,6.118563,104.931861,114.908364,36.595355,-17.417377,-93.031837,-118.267327,-129.910525,-1.647196,109.806242,262.432448,274.420911,219.893862,167.343381,63.480003,-19.755439,-57.03396,-107.446432,-106.231524,27.262369,126.099126,188.704352,163.900911,133.145816,112.001773,101.41146,127.084521,137.70054,47.148983,-28.73981,-119.504113,-147.266453,-130.564115,-4.61411,73.743023,174.846701,172.58788,56.3132,-5.819545,-16.337515,60.416109,73.740336,38.635806,32.830756,65.943303,78.614498,74.336868,53.511579,45.648212,6.714849,-0.474493,100.936603,160.245069,106.865104,5.422009,-136.691621,-48.812375,8.659391,-17.76263,-64.865929,-94.385422,-86.354715,-67.424305,0.128018,63.123653,157.784037,157.382193,149.205032,176.165607,249.846263,280.493519,307.895216,329.891332,360.395349,397.593939,389.469024,384.679126,398.804985,365.72076,259.739569,260.599185,338.771397,352.47644,294.31497,239.136147,133.294242,101.188535,63.913729,125.348721,204.678999,328.777956,348.20071,336.34541,307.667603,192.750291,95.106304,96.005589,174.918515,216.050153,224.507935,187.269936,59.220851,-15.554553,-114.601515,-83.068548,-41.468241,49.558452,93.518209,87.596533,33.231317,-58.866089,-74.739358,-43.716491,69.249413,103.423492,81.947354,39.723866,-74.049039,-134.284735,-231.45807,-210.409219,-143.560017,-8.508979,20.936148,30.477879,36.386132,20.310802,-32.9486,-0.534245,183.482607,242.883475,217.943619,185.973235,154.015518,137.3368,105.406418,139.267232,161.658344,212.752051,260.9924,311.074994,281.448469,192.650278,171.538725,201.502283,296.057752,328.479759,350.509707,343.620755,273.704292,214.712127,89.912069,38.810981,56.232687,162.07869,237.198744,318.664976,300.140199,181.266344,12.913518,-32.887434,7.46684,56.367801,115.046626,111.414743,99.136385,109.545924,103.221723,112.264485,160.0026,206.537781,171.686607,63.176836,16.719881,-15.24382,38.133932,90.53218,181.598866,175.981957,57.52473,-15.98341,-94.305875,-99.536697,-129.442259,-171.373389,-161.613359,-111.811556,-101.023706,-111.002512,-119.869939,-140.021733,-134.132961,-102.101768,12.460917,86.954307,222.933347,261.152786,257.295609,205.885845:-229.397338,-129.515159,-14.127419,202.05922,261.450353,252.220239,192.96644,47.1483,-24.028421,11.388026,223.437228,329.321386,334.829768,257.361583,199.84175,229.509605,202.908657,124.758664,154.043194,339.770112,424.1711,428.05112,361.699919,187.468504,39.876769,10.409653,81.103806,153.969128,192.731548,130.096508,-9.892255,-47.585764,-133.545481,-180.788713,-136.305144,30.09206,74.527083,-48.185645,-158.975145,-263.074224,-240.096316,-210.186758,-116.276732,-65.245041,21.725582,41.247217,25.749518,17.964208,48.83046,164.024447,222.167035,244.176521,207.907203,62.072789,-29.183232,-123.991162,-34.874225,22.79949,23.924758,-20.760319,-97.666345,-121.742917,-159.98274,-182.439172,-203.092424,-109.563321,-66.969413,-91.258232,-122.575732,-140.863927,-144.184122,-218.819487,-292.965294,-247.211073,-65.605823,-13.664133,-12.830193,-35.118105,-80.384699,-101.465966,-161.728667,-88.879294,19.983138,197.567243,224.912905,155.869219,82.672001,-28.850273,-46.528193,-32.496394,-13.463173,-26.19135,-63.102016,-75.230695,-117.657309,-164.306926,-282.503118,-310.109746,-286.892248,-209.477154,-169.396631,-161.871369,-184.688558,-212.324176,-260.233946,-287.661933,-259.884049,-185.239385,-2.918137,42.76335,36.353027,17.129044,-45.989389,-76.783262,-50.35673,-12.387772,-18.904131,-21.671065,-15.789321,-32.176144,-35.149654,15.369299,133.477823,129.717009,41.009524,3.779774,-76.508554,-129.437399,-148.334683,19.968277,100.371318,142.494841,112.729158,19.00845,-8.805065,-44.721714,-75.092254,-57.170674,20.772073,58.722029,103.41111,104.437455,45.333986,-19.202828,-163.964472,-129.460367,-28.121391,149.459166,153.048724,38.832581,-3.400676,-43.379952,-68.623802,-37.990141,42.103737,34.814167,-69.491054,-129.968207,-180.411687,-198.765787,-333.967201,-310.017618,-178.039306,31.213076,49.208339,18.374392,4.266778,-12.346494,-13.6881,3.877186,30.88723,37.644604,71.019052,57.37745,-102.60276,-215.472847,-344.40473,-242.921134,-191.178128,-178.943277,-169.481726,-117.333942,-105.929841,-139.996885,-183.54146,-181.925053,-149.476497,-114.43686,-39.697819,-65.535337,-228.484926,-281.906237,-299.659068,-318.969118,-299.618805,-137.763935,-40.283583,55.799826,56.273833,6.036549,-54.680029,-26.362884,125.947591,160.886817,62.447171,-14.956338,-127.531148,-174.215313,-189.368329,24.717896,153.035965,247.944987,199.896466,10.682865,-71.897643,-154.314211,-204.148644,-221.299764,-195.21971,-154.465312,-52.430603,-11.393408,14.898829,-4.103125,-75.808175,-146.110743,-163.858984,-97.46003,-35.492204,-17.610033,-71.551385,-166.659935,-144.850147,-87.898538,42.220497,96.860213,194.145111,206.814202,101.364467,13.320258,-83.140871,27.282048,111.683828,221.641671,241.298716,189.570579,132.155398,54.825133,49.31401,65.043036,87.170175,88.775953,128.370021,152.884975,101.822244,22.057229,-78.544332,53.490336,122.558416,112.261999,87.182833,80.034351,49.626374,-78.216918,-45.531796,38.844003,143.455366,150.662326,171.029585,191.659868,225.19894,223.623492,184.466606,229.956376,311.089517,462.738788,472.643758,389.447953,356.278543,338.796643,282.999746,253.957173,282.603758,323.982859,328.330864,259.698315,85.607499,53.045604,100.901229,200.608452,268.014064,368.188572,366.192956,316.962088,297.797989,193.124476,34.235123,20.909488,125.377866,184.496178,205.411446,156.806865,-7.683705,-91.986191,-181.18855,-74.170684,12.434609,114.121614,127.430727,130.344927,128.481576,63.585322,-45.502622,-39.696543,73.406751,116.429851,140.617572,136.042083,54.001468,-40.65707,-256.836749,-267.319938,-175.057465,52.797783,124.124515,114.942977,61.318187,-60.300565,-75.57497,8.334895,251.382858,315.737184,247.781352,179.291773,124.042887,109.832869,24.088636,12.214125,84.035562,262.586077,302.566452,233.140546,159.622896,82.480105,167.903625,234.125392,344.794085,395.485563,457.283088,439.110112,331.126193,270.772631,196.488619,238.131559,270.417278,332.64625,374.10791,421.943828,400.457268,254.659262,69.549279,35.743061,116.223398,171.784542,185.70951,164.785484,142.468982,108.019246,-0.748303,78.655741,164.550056,238.495362,234.300468,194.883196,173.360038,158.154812,119.132891,137.789943,318.08771,374.544015,225.424554,94.896771,-26.412113,-39.156909,-151.596386,-226.410218,-156.3812,52.153177,96.566686,55.168617,16.043162,-22.795755,39.843114,101.111144,194.637731,222.743991,311.401584,347.319045,267.731192,186.40305:-177.645615,-138.456807,-61.238435,141.365544,221.44769,267.860159,237.24433,95.026132,-9.983012,32.455877,268.361083,374.894689,417.381374,362.770536,227.379438,177.393741,117.587097,171.43621,248.549947,385.726851,402.526011,344.447514,282.279849,130.498593,71.510785,88.487104,92.137266,58.225073,10.084655,13.507849,-9.514087,-78.422054,-274.309238,-321.988945,-265.364908,-116.026375,-92.094676,-178.016913,-237.985674,-326.947096,-372.50616,-355.799874,-241.806681,-169.815345,-70.036087,-54.663739,-49.137739,-35.037446,32.641937,126.388868,172.394601,227.116251,210.914375,96.110283,42.280839,2.84247,1.441088,-4.167825,-49.738933,-86.356913,-137.714593,-142.336267,-137.357882,-135.072511,-102.848651,-48.435556,-39.080618,-25.407019,-14.618401,-89.333236,-178.351747,-307.795705,-290.800239,-240.841953,-102.020451,-37.845299,15.822812,0.888541,-61.920062,-95.192174,-128.883547,-5.790624,110.960307,278.938243,285.97545,199.299306,156.937085,111.867095,13.654391,-19.778431,24.968261,48.055848,-18.278497,-83.902749,-163.446102,-175.623399,-229.966754,-315.312851,-336.733244,-289.935013,-240.263083,-200.135924,-213.318901,-273.059689,-333.950596,-328.251939,-238.368926,-176.928541,-90.904083,-74.641095,-48.952203,-43.2109,-99.16775,-102.369142,-50.540859,11.604276,-6.751605,-39.423316,-32.263628,-61.764298,-101.775665,-66.30044,60.061393,92.976045,19.974282,-60.287852,-173.09672,-188.256162,-197.913308,-212.335955,-199.096752,-123.795001,-90.790147,-106.064136,-158.218502,-282.988188,-251.957154,-161.820985,2.026962,35.517403,53.05442,52.699313,-4.441208,-77.669491,-237.092187,-212.307541,-138.418303,-22.943747,-1.744671,14.852134,24.476273,-7.373669,-130.054871,-161.027623,-88.00537,-22.519409,-1.560865,-72.76642,-245.099703,-291.069938,-265.689587,-117.517802,-53.754269,-10.927411,-21.917849,-61.314363,-68.948101,-85.418214,-111.768626,-98.83102,-62.040302,-61.35452,-93.595739,-127.620909,-206.953577,-243.874447,-325.706259,-363.692089,-342.044876,-227.063495,-144.343864,-27.815774,-45.992247,-203.58361,-282.768788,-240.234917,-92.005819,-51.751473,-92.615522,-151.866646,-245.201374,-246.590031,-214.243359,-231.888825,-221.252714,-74.41069,27.451999,132.285452,115.768678,5.24932,-13.427101,47.262158,162.976786,160.433482,43.540528,-34.004722,-162.127911,-198.478582,-195.815806,-76.794929,5.682944,115.981452,118.794317,-2.976582,-114.799611,-315.03159,-340.865234,-294.773808,-180.308785,-136.062355,-73.222859,-62.836346,-83.345881,-86.810826,-70.550983,-101.442957,-124.906247,-88.752657,-41.821839,-37.297857,-91.326616,-200.248551,-214.02845,-155.039135,53.9022,140.323421,191.046099,162.671681,65.042497,22.494827,-5.430482,56.624401,114.732069,248.856557,295.697174,248.156608,158.241496,7.768287,25.502897,75.856359,133.024698,126.240831,140.196191,165.844927,150.826289,94.969496,-34.828765,-52.282125,-18.598446,63.464178,97.018817,136.75175,129.511233,32.282547,9.209946,86.148805,271.993636,320.579898,344.257041,332.065949,276.066761,250.090155,232.861978,305.499077,361.122609,412.460355,412.305514,409.74356,405.06312,345.473363,270.085262,271.982891,341.478788,353.492066,269.682465,217.405025,169.210798,159.584606,151.715133,233.046409,310.776033,447.903782,464.442218,350.501635,254.770889,89.447938,31.476233,58.479941,152.003399,185.276943,185.996394,153.10215,50.481606,-1.78181,-33.499154,84.310414,159.88966,246.575692,240.134578,167.890592,150.289635,128.12142,32.653281,17.198634,102.993939,160.981966,194.524923,149.722145,-25.658757,-124.556894,-233.436735,-112.738058,-19.055587,49.699007,38.862803,62.355225,94.554349,73.547682,-59.064866,-70.537723,98.251401,193.980022,180.273892,94.389545,-1.643274,4.329644,-8.914944,-42.164252,-12.106213,153.6014,230.707882,216.833583,144.317456,44.576082,122.205064,191.834431,280.529425,308.804597,378.373155,395.802195,303.102221,205.623249,110.140628,233.423975,287.896883,313.806643,317.510117,305.696984,272.022746,167.587699,125.514195,144.836695,193.65887,217.62002,232.673125,203.116005,134.374342,112.193121,84.553353,129.626549,167.708636,212.296026,240.906403,311.211304,308.475582,236.043066,226.016089,272.133691,389.21083,396.894697,244.984209,132.159337,-9.81264,-32.529541,-78.270736,-127.602978,-119.558441,-40.249029,-0.595495,18.200901,5.777828,-7.332818,28.184707,54.472273,131.183762,195.75482,315.782714,325.07811,237.761917,162.601223:-297.456608,-225.446368,-101.555846,187.641572,258.502206,176.337011,89.842275,-11.269854,10.890212,65.227589,229.290807,316.434331,431.840144,413.440888,250.794523,185.678816,131.7035,145.597927,191.667469,295.968203,329.576416,354.816303,336.485153,243.876589,148.796748,122.333517,128.097424,146.400296,156.239264,129.319118,-22.439279,-132.671934,-286.914919,-260.557728,-206.437639,-92.872103,-72.821512,-196.709076,-307.254815,-408.269053,-342.188772,-318.470494,-287.440128,-259.10562,-223.15388,-245.45339,-315.08206,-311.177568,-209.489341,-62.209556,-2.314169,77.327367,103.933197,86.100865,37.89332,-55.472627,-83.417985,-64.874846,-9.438846,-1.624158,2.44016,5.505479,-63.95551,-129.269435,-190.365281,-130.418708,-114.940504,-152.040538,-172.022924,-192.839699,-183.168303,-116.687898,-65.453204,-46.223963,15.533598,58.578073,100.573398,83.907818,38.039265,23.194634,4.54436,105.708078,197.301165,303.099457,294.260052,186.134663,122.167787,56.211807,37.254318,37.084823,63.539738,74.756435,89.392481,90.073798,24.537314,-49.787904,-227.652468,-268.438918,-224.804864,-180.908802,-200.689684,-266.92581,-323.002602,-463.168597,-469.994762,-399.626228,-241.492161,-200.517543,-152.361354,-110.800168,-22.504072,3.339571,2.69132,-25.079705,-18.837844,9.768864,12.115707,-8.925571,-14.62767,-7.068265,-3.972701,11.791486,56.460873,54.377307,-7.640791,-53.725707,-161.853048,-205.716932,-217.252568,-135.800595,-77.715976,17.408493,43.186475,34.85703,-0.579552,-64.777565,-60.897959,-42.924028,4.152744,35.532735,110.490638,124.616089,52.004778,5.745996,3.406376,94.260728,127.629748,129.913068,129.048931,104.703103,51.152547,-71.033082,-103.424624,-71.463786,29.107161,50.724919,23.176929,-6.771307,-117.137638,-196.277042,-302.691147,-241.00903,-176.490453,-70.868243,-34.758098,-13.887878,-24.641193,-52.068599,-53.94777,-26.375394,33.475563,37.375986,4.346492,-35.878043,-140.826973,-167.503874,-153.924846,-144.099805,-146.124382,-101.005696,-54.310106,14.633482,4.276169,-112.206132,-192.610417,-171.185607,-73.623171,-42.820885,-63.959023,-104.718584,-157.305106,-154.073849,-153.53367,-153.740886,-130.975841,-11.599052,70.211301,149.132037,127.302513,35.670433,5.08977,48.104079,150.97542,158.708122,123.323165,77.462884,-99.354334,-175.953859,-180.01543,-9.997195,96.419431,231.858743,229.737371,89.788869,2.566832,-65.342154,-49.429472,-45.513822,-41.078225,-29.406866,70.351015,124.9057,107.171687,69.589695,51.892356,39.179553,28.137838,18.887379,0.607259,-82.331427,-114.773592,-126.433398,-140.434935,-124.544322,1.261366,65.395379,102.073244,86.923338,43.633621,19.976587,-34.897456,-32.890435,13.262038,121.904512,143.178878,74.875433,8.050289,-68.166255,-0.105661,57.589853,96.815587,81.406813,102.914804,128.537528,96.280572,34.526782,-115.852575,-126.452604,-62.51687,60.49371,88.592332,92.799486,84.665767,74.921333,123.288004,179.617619,264.802284,262.047231,248.685784,273.023238,370.505443,412.988719,413.955781,427.082902,480.565534,565.11841,563.112522,514.16783,485.094463,394.990733,281.815363,270.565407,336.970162,360.674612,313.575425,253.176996,138.363945,121.154954,169.995784,243.5074,273.364105,314.633704,326.504778,313.802437,284.537335,178.574713,47.642176,27.012777,115.45292,183.865483,260.466153,243.484581,79.071986,-21.748063,-79.910064,73.294242,143.958335,155.950556,141.511571,161.147115,158.57296,56.206521,-37.288768,-24.026778,82.263142,125.290502,145.291834,127.263062,-1.101807,-117.685686,-351.251069,-347.904171,-255.066204,-78.688815,-33.78679,12.369485,20.966653,-39.769924,-94.973911,-39.840409,154.69322,208.293877,185.471688,149.042855,77.931147,31.398674,-62.089895,-56.155585,-25.32746,42.491769,69.151302,56.354189,19.44478,-33.305153,-7.102614,44.12117,217.3298,297.361112,350.609623,328.490827,227.200341,157.245775,37.986312,61.771108,117.515818,246.213715,317.091301,374.618839,318.313544,126.869721,76.261727,115.668136,160.203571,146.19948,153.949098,187.768985,202.837831,162.057412,91.718965,175.868693,249.278065,316.064822,301.372511,210.415355,153.117777,106.866725,145.244735,185.877339,263.698001,253.312417,128.038806,62.521249,16.011396,12.295333,-69.01208,-148.05999,-114.06731,4.579791,24.698969,-24.518698,-56.131648,-68.330376,-53.45077,-18.204822,128.336189,195.192982,249.78846,234.396547,87.516455,-10.767485:-332.679003,-182.736533,-35.990056,213.927523,263.079137,209.379547,143.910232,12.657216,-40.759316,2.619327,202.536145,299.408581,390.427457,373.733448,261.360883,216.665501,182.949645,177.483169,178.244986,187.934876,209.295645,267.555329,266.650429,162.588121,70.827187,83.85059,140.82696,128.951135,17.003271,-43.447249,-125.471182,-176.07797,-307.589342,-315.09225,-258.72355,-140.330559,-121.875964,-218.091217,-300.391,-370.55168,-339.882229,-338.97415,-319.636698,-267.245575,-147.80687,-149.737553,-269.90219,-310.749155,-242.333506,-32.597415,68.656984,187.040896,200.087274,137.992573,87.645756,22.897395,26.112659,49.385097,93.427414,103.501972,102.626034,81.557848,-7.697733,-50.204708,-74.226665,-90.043355,-110.00443,-78.361186,-35.2271,-49.097472,-106.27105,-167.533959,-83.615937,-32.872354,-6.952726,11.49903,90.177995,84.885142,10.320915,3.986699,79.26632,187.907063,228.989122,315.373788,347.618526,303.157233,245.71984,124.947398,-5.746756,-19.114835,117.619828,190.88558,172.056946,106.231281,7.999532,-25.700199,-124.535734,-192.759124,-197.749713,-162.200882,-138.183386,-179.181085,-244.049903,-370.388492,-433.983468,-420.778404,-319.023038,-246.355797,-106.712576,-65.669878,-27.877597,-20.123608,-19.701421,39.424326,70.950143,13.292201,-34.034221,-22.091417,1.323623,-29.738645,-55.989199,-14.24039,97.986719,113.918909,40.597666,-28.901891,-194.888514,-275.620565,-360.896951,-275.880073,-188.959711,-64.743525,-67.387023,-153.438676,-192.312956,-229.993905,-261.414701,-254.976492,-148.56862,-74.923573,31.076565,57.586942,76.611787,76.378506,62.806868,40.698641,32.307228,61.70254,101.994773,117.003035,62.25179,-92.987714,-143.377799,-98.096292,9.145936,14.792668,-37.934711,-62.09404,-108.763913,-163.804841,-290.479653,-239.941348,-176.998269,-84.082902,-54.282998,-26.222814,-24.973859,-43.028711,-65.320592,-70.02031,-62.913541,-43.147517,-36.518181,-78.906247,-205.559544,-261.327979,-317.367037,-271.728677,-232.588751,-143.286011,-85.120685,-32.022578,-69.719899,-214.578462,-280.085147,-221.277209,-17.500337,37.982972,6.779007,-41.907524,-139.786887,-173.307174,-161.362429,-60.598185,-16.449252,76.9094,143.622536,200.015529,160.774858,45.488161,24.4271,80.429599,207.140753,212.256339,117.574979,43.809252,-116.202233,-164.744136,-116.350266,54.827446,133.208577,221.549547,206.452877,21.452706,-98.17939,-185.249104,-74.50725,-23.585305,41.661508,83.419911,154.197263,155.266858,102.075596,61.997183,-33.74106,-74.676187,-74.156821,-66.757277,-56.018106,-55.549342,-88.922431,-202.526734,-240.918401,-182.174925,15.852429,101.94306,181.354253,162.45703,11.101714,-89.357768,-191.803387,-60.277669,48.325711,189.199518,186.361098,70.823921,11.496806,-34.327501,0.512859,48.09199,148.047855,173.864844,154.042064,102.809286,-24.837891,-62.149587,-64.202377,-15.830405,14.63592,115.986718,177.88194,222.821737,197.971775,81.97576,-11.186343,19.113168,204.535067,306.71127,435.7288,441.435409,393.105093,382.983177,385.162095,407.608634,427.474455,458.0515,470.991694,476.88407,452.90588,347.236827,294.182339,338.81313,470.535497,489.375554,434.594044,396.73549,316.216772,274.588982,264.08333,411.511906,484.72568,516.074553,491.501028,401.538633,328.604093,130.8273,-12.752101,-3.476785,132.599377,200.103936,239.022149,197.531418,32.281286,-37.527247,-35.936202,120.411488,190.609773,228.200386,220.755145,192.726948,162.901929,55.787125,-34.369699,-11.940536,148.827672,211.479719,195.170178,132.827904,-35.760908,-124.027947,-260.764851,-228.663039,-142.273636,37.745291,92.695879,127.877352,108.324237,-5.456072,-78.758466,-39.238728,102.755308,141.580296,144.352068,125.715484,36.375058,-36.717602,-159.84222,-137.129616,-88.71047,17.72853,55.292958,66.646049,60.216232,47.496066,17.99475,32.483642,160.006075,231.135328,271.836744,229.825023,84.808375,16.483258,-17.653972,124.197684,200.136842,253.285218,238.082691,185.080637,157.632633,73.330222,9.955025,32.186444,142.31831,193.438949,209.894249,169.669663,58.092536,-2.595412,-55.295079,125.575049,248.957659,347.737577,309.308093,186.578395,144.754783,96.032031,116.14006,174.137657,313.780467,343.213435,251.101398,140.580692,-83.680782,-153.763003,-202.946238,-140.67181,-79.641471,19.65829,29.380374,-33.831997,-77.282928,-102.793584,-59.488238,-30.002418,60.403844,134.366804,256.225524,251.165585,115.234759,15.852633:-219.766318,-215.487882,-125.21937,64.364963,86.947597,40.432363,17.12662,-0.642713,10.129902,41.143338,150.730821,201.838011,258.110928,252.11849,180.343494,141.555242,121.058345,174.709208,192.875989,194.328651,208.926675,263.646016,264.668828,153.38048,17.340044,19.756676,126.286435,176.058405,233.274505,224.914148,78.127684,-39.629162,-205.07577,-123.484948,-39.917339,-2.643795,-63.059905,-248.088815,-339.982865,-439.129454,-417.155138,-393.048244,-321.462829,-266.066457,-212.112728,-259.626867,-402.767259,-425.970637,-317.703365,-99.565059,-17.602214,78.264784,111.599467,107.185406,71.150526,23.077403,21.114022,33.427721,75.536334,70.050614,6.971801,-18.560378,-59.406108,-91.018863,-177.040745,-218.77621,-225.454746,-214.396162,-172.999033,-125.731908,-165.184786,-246.045079,-176.009603,-83.657456,98.246406,128.641331,126.604569,145.761814,183.780919,174.522478,142.988229,215.465269,266.191631,268.274751,252.081169,246.857573,215.04299,128.751396,125.738186,134.623133,180.991842,211.777023,237.855286,233.895402,182.938273,130.248016,-15.618458,-100.386151,-83.87229,-44.025104,-66.018521,-186.012797,-269.849406,-410.02746,-392.687649,-335.391137,-189.896458,-112.000016,-4.963105,12.835222,42.234627,68.127656,84.767687,35.281615,7.22096,8.941896,60.269735,173.467921,172.246807,68.408869,40.618561,81.96631,142.075311,125.216804,56.431626,11.297217,-151.39569,-227.048075,-201.962034,-16.267547,53.018199,94.852259,91.475447,55.039712,20.281632,-2.434025,68.289543,104.708896,140.791232,142.015683,165.962044,191.312334,194.484362,176.965294,187.722348,262.739489,295.179483,283.331203,250.337943,166.346704,98.035427,-50.690001,-105.283909,-82.941462,48.949101,115.175016,146.27491,103.37219,-110.937921,-238.353972,-328.779388,-220.665976,-160.702279,-63.43842,-34.778821,-47.247573,-58.008729,-19.860664,52.446446,104.433591,200.878573,197.292866,67.169841,-17.459504,-66.925362,-26.343617,6.044143,-29.950699,2.048665,166.661231,247.818398,258.671641,181.221836,-17.859619,-118.444968,-86.823667,64.828832,103.337606,57.294261,3.001722,-107.246966,-138.80178,-161.527896,-153.849554,-133.523487,-73.598286,-49.380343,-48.362129,-52.58586,-47.945361,-90.368845,-89.7236,13.989212,74.276729,111.813067,77.967261,-33.429993,-69.382069,-66.328018,43.099172,129.216339,230.099834,223.319285,184.349124,178.709218,169.624182,86.670286,41.790572,23.040835,58.544853,226.949146,314.767961,313.680729,241.091551,183.171863,242.594396,239.341631,168.655579,135.961944,51.240159,-14.079142,-107.987327,-85.038614,-51.895804,45.664788,102.943826,181.269725,188.939673,110.486964,37.825867,-78.91717,-72.986312,-32.051536,59.863047,78.409604,7.193415,-41.861943,-44.000246,17.264282,17.932128,-18.083338,-4.521918,78.067357,98.824132,72.688554,30.885472,-96.687958,-96.585368,-27.315628,56.888513,44.623567,7.975068,1.851639,-9.680142,31.78923,81.466177,155.152454,170.085935,212.341404,234.238612,242.886478,249.745056,292.411881,310.265865,321.030225,388.975047,426.470143,429.553975,404.1514,324.62705,195.273135,176.625611,239.729901,249.435233,172.180538,116.957346,49.656981,58.394732,141.451331,236.832772,271.928996,291.963279,288.872815,280.764839,263.212169,163.053431,27.14366,10.644615,113.482332,168.549476,174.359488,134.623326,33.128388,1.0219,9.800367,45.26564,40.974966,30.698,62.862459,177.479216,190.326268,35.480098,-117.062111,-78.831881,131.588283,196.092869,156.178942,79.060726,-128.295693,-229.94913,-350.246674,-278.571304,-171.713093,45.643846,107.945762,116.944967,69.892827,-66.342494,-121.536797,-73.722219,146.201188,231.383176,177.159262,73.375232,-83.287632,-96.509024,-46.619304,45.181226,111.682797,218.040172,213.230902,80.882812,10.457507,-36.577768,21.29575,76.242127,136.703492,113.118222,76.600939,87.605575,38.51104,-40.450501,-172.55349,-81.887314,1.771151,59.414037,59.367935,84.556747,71.991542,-49.695668,-145.86769,-136.91031,-53.897007,-13.051138,56.160514,88.856857,113.276161,90.371852,41.953803,181.824803,294.901492,335.577843,239.78896,18.786812,-37.492803,-40.29222,4.574335,29.290349,82.861806,97.14987,27.104211,-55.788433,-184.122746,-189.179047,-140.007765,-151.495973,-168.210799,-175.121267,-171.162142,-148.954274,-138.396308,-163.38618,-216.125224,-197.855805,-70.992761,-19.492757,33.628691,52.477496,40.353767,-7.954669:-277.806574,-223.314679,-113.788798,149.861072,218.217811,139.687377,45.75443,-79.151198,-70.223274,-10.095553,199.83508,318.656542,465.976996,438.088672,211.798697,109.593363,78.15674,169.513047,192.174781,175.447667,167.790682,169.095335,159.303697,68.277164,-11.332572,21.489247,125.469709,138.98722,93.155967,33.264638,-142.536744,-226.415301,-311.110763,-216.924892,-128.028595,-30.33622,-73.40201,-283.477098,-364.452592,-380.081211,-364.709798,-368.753139,-286.046314,-210.105355,-160.442393,-234.11011,-480.449608,-543.100914,-423.192062,-139.868834,11.119735,258.032898,308.828082,229.000598,136.384352,-29.990656,-25.034844,64.808907,229.142909,233.48071,156.749773,104.008137,-48.590472,-134.320082,-243.326531,-228.99329,-202.176741,-159.985949,-137.074894,-93.708091,-97.303551,-166.2157,-169.131659,-96.487328,105.679516,184.096049,246.682103,227.708924,135.952026,99.321521,92.213136,184.676683,242.052055,297.085783,285.375881,174.375783,101.580856,38.225271,106.555737,172.188935,299.224109,312.473097,238.884596,197.722148,102.354777,31.935571,-81.464617,-80.343955,-70.731363,-92.170837,-113.15087,-190.580416,-265.905262,-406.336439,-384.527511,-322.828511,-174.043712,-107.989337,-1.493745,29.120912,9.914128,-9.21003,38.110414,160.14442,184.76895,133.223536,104.552334,55.274954,17.768412,-42.932106,-34.917597,7.381303,115.041049,139.637081,86.564214,3.947118,-197.618862,-261.665668,-272.834756,-157.984465,-77.292724,13.758586,-2.520025,-114.928842,-167.072062,-151.743889,-40.148573,7.327895,82.706702,107.900474,141.941421,146.859044,77.106618,24.821168,43.165977,196.685454,240.845831,247.3747,249.129517,186.313494,98.37569,-72.915504,-110.862743,-59.083035,112.431399,157.240464,79.30261,-3.831427,-160.00225,-231.71138,-329.555909,-279.740255,-205.861773,-25.044051,31.617959,11.99233,-13.67315,-33.509739,-64.474626,-38.43701,81.537894,94.010167,-24.598872,-106.336839,-223.381893,-251.451562,-256.22783,-151.776077,-55.763286,113.705112,150.265673,109.028254,38.760289,-119.332795,-129.657537,-76.052242,31.617359,66.805463,55.064024,1.543754,-89.347263,-104.76748,-135.596177,-100.504906,-20.176211,163.275656,187.532248,97.401461,61.899745,36.787332,-6.921621,28.686655,205.245582,250.703683,174.696128,101.053627,-46.806391,-116.516153,-140.663545,77.049834,203.147274,342.496746,354.442919,232.382975,121.781339,4.470833,8.799372,8.332951,83.674877,169.254142,291.40355,271.941222,128.492072,77.927896,97.911343,179.053343,182.29038,108.528237,71.277614,-1.183874,-50.21825,-123.661835,-109.732288,-68.933369,51.323688,110.191414,145.999467,103.971327,-46.697159,-128.004863,-235.893992,-98.899164,39.05787,187.881307,152.899856,-56.898602,-157.998628,-214.962557,-113.320754,-38.346602,75.930324,96.061787,95.588585,84.298403,17.285122,-46.466408,-153.397559,-61.511951,23.292244,117.059351,125.689544,69.365269,13.967241,-47.574996,35.958078,117.490269,266.35421,308.639834,345.56167,343.852371,328.212542,336.077818,386.430087,461.015854,486.427482,492.168541,489.365721,459.780943,414.924491,300.243143,259.278202,300.569482,454.865564,505.409809,479.134334,404.524476,183.176815,108.425759,164.379527,329.754592,382.446954,434.733128,451.184241,433.726741,378.742147,207.969501,69.641951,60.789663,170.596889,244.654169,271.33287,183.837199,-59.178573,-118.456236,-75.913178,54.048422,130.168353,276.519288,322.261662,277.20285,192.845912,5.925199,-48.641656,11.953329,199.391817,258.996035,275.696319,233.825286,18.902643,-124.382162,-291.413733,-173.066622,-68.081164,71.691469,102.821151,95.424906,57.938255,-15.580375,3.051816,58.696829,226.996328,295.551562,277.080308,187.331652,-36.350538,-126.130709,-208.720079,-117.291745,-26.907461,106.573116,112.531426,8.045919,-66.069688,-135.409222,-48.561638,26.10086,144.439639,165.961554,147.174202,114.860957,-2.772129,-76.941334,-157.231617,-31.14608,63.949128,163.521931,159.579699,88.713441,35.711881,-111.646118,-190.56253,-139.919876,44.940157,110.915766,148.130756,135.36764,72.806005,18.545996,-92.315219,3.065276,135.528974,317.581551,297.261131,79.837098,-48.424558,-174.377737,-75.3931,34.913793,208.498653,221.437895,135.6061,59.432271,-92.277726,-137.325234,-172.0504,-160.577496,-141.844673,-106.291456,-99.138585,-120.325576,-145.806731,-191.635189,-200.292406,-167.573218,5.128126,112.462213,201.180997,143.99784,-55.927288,-127.217558:89.976677,96.083182,131.169862,188.18195,206.893815,220.773636,199.935121,65.817038,-91.876842,-96.303249,37.740849,91.661348,79.131752,46.43838,-4.91554,-21.426491,-43.47747,-53.211529,-49.935364,-69.324768,-85.55927,-53.73991,-33.219835,-109.739753,-262.395588,-285.089331,-161.736169,-78.74341,-3.55054,11.797776,41.684259,45.855924,39.691758,59.014657,98.402621,187.293884,178.21787,5.087715,-101.816421,-208.640418,-161.166951,-110.782532,-20.136476,3.240398,-31.996094,-73.809747,-75.433362,-21.458003,71.349299,98.366556,134.724623,250.456422,287.871361,279.687782,253.667586,238.834733,268.120671,278.541524,262.670998,212.672212,82.161025,53.740647,33.895556,-9.247787,-170.721787,-238.802547,-197.756621,-108.952057,-115.707182,-222.353477,-273.283817,-250.908136,-106.990042,-18.973072,142.030674,183.606991,183.034816,164.145455,154.488465,178.552214,269.260274,364.912986,380.194908,350.519352,343.922388,320.991405,266.853579,156.633416,163.079502,200.732574,261.792812,242.931843,147.540661,110.335919,71.733137,56.807825,-10.897456,-76.298456,-77.312589,-42.340915,-20.629421,-33.296366,-79.711851,-131.685343,-25.61723,54.089896,181.466179,208.469747,197.159934,189.060608,250.544668,311.249658,369.406104,297.2629,266.751206,300.936343,346.676054,411.865647,410.630074,314.582168,180.638407,168.636326,220.969454,208.542881,35.818116,-85.231427,-253.610217,-264.352895,-175.15503,-48.460634,-9.731176,12.905197,25.045131,26.459479,-10.962173,-74.637554,-25.375025,8.927687,56.651239,74.024692,113.748997,138.857105,181.827197,194.348154,211.383636,299.586956,358.887641,372.845381,312.517326,139.979143,65.02991,-74.534392,-228.513667,-241.561699,-91.658987,-9.844017,20.087125,-36.270303,-237.538719,-323.368518,-353.768977,-249.370247,-203.747277,-180.23,-166.350561,-81.037655,-34.13527,29.64027,74.882512,98.328962,165.241262,211.178827,258.129704,227.234148,137.14111,120.518902,88.491896,54.718636,83.671518,195.275135,252.885544,307.233389,257.782383,71.034432,26.066338,60.882311,79.641907,38.20702,-72.577404,-135.427771,-266.752024,-299.332763,-290.249793,-260.505121,-243.225175,-192.809103,-158.325079,-124.644225,-146.053624,-194.051575,-139.081762,-61.931221,127.243884,178.674232,182.203729,165.29942,110.495402,103.687741,173.62016,208.501289,207.718,258.895087,288.77972,260.023497,235.395754,268.23213,250.903144,201.102426,141.401165,146.91392,216.88611,262.10891,276.74891,239.293775,184.786646,226.617216,254.27102,219.07503,160.664085,62.252852,27.320663,-25.002672,-47.11246,-66.805646,-47.411874,26.99835,178.002884,206.080622,190.952661,158.675213,54.518548,-4.648405,15.213835,59.420766,46.422823,-41.07259,-84.943334,-63.554958,54.545009,71.925524,17.602304,16.652894,126.046653,152.551315,33.356405,-45.605066,-114.747238,-120.585941,-108.32108,-49.249171,-23.926046,-12.626269,-16.965408,-18.344202,64.587123,140.794593,211.238528,177.57626,125.212393,135.36647,135.164617,130.741152,163.430047,151.953815,115.5427,70.298216,76.948802,77.64429,50.550716,-33.374116,-89.035985,-59.219121,87.02424,135.690933,160.279602,142.915132,2.719802,-73.529071,-93.740801,11.909845,83.641698,192.362922,201.075113,98.602129,0.598875,-164.797214,-141.013319,-73.991934,71.603647,119.26324,120.38878,72.167121,-66.528618,-115.352373,-126.136914,-76.71296,-55.85993,-9.128413,45.144937,176.055707,187.222239,54.571935,-97.935607,-95.77782,60.999017,130.609333,104.182925,39.119848,-46.608395,-60.60625,-123.345729,-213.953267,-209.775792,-99.517639,-41.909923,12.409558,20.893419,14.419691,-69.299218,-87.237278,36.445877,126.239394,121.355722,0.075078,-236.54664,-242.215637,-85.269773,45.672992,77.023468,34.214992,-41.180087,-152.874484,-142.991106,-50.39198,-20.434075,-52.983087,-154.397997,-187.040798,-170.226289,-161.74543,-239.70917,-281.596822,-308.494197,-327.396991,-332.762465,-302.629182,-245.197834,-108.494606,-98.651656,-162.815612,-170.492176,-174.592598,-223.055329,-227.288289,-142.051512,-98.877312,-135.776193,-191.024071,-200.887034,-37.450171,43.857632,56.094684,-17.856826,-218.821436,-304.980179,-409.282772,-365.592217,-275.147857,-95.412155,-71.908541,-151.012844,-209.192041,-255.60034,-237.075173,-196.748823,-189.389116,-194.229213,-192.811879,-184.896454,-223.797992,-269.830214,-325.910347,-318.632872,-302.429062,-253.5867,-211.132025,-59.919205,13.774663,26.812491,-29.538227:13.249465,3.595851,50.930633,129.04972,137.725961,107.309747,54.348685,-72.362537,-131.865715,-119.826687,26.992082,126.306458,235.568278,226.667833,137.775412,91.700091,28.572459,8.099161,7.395298,57.155973,119.996948,194.129315,165.182635,53.360891,-8.545335,-4.055747,55.112925,110.189618,249.709929,283.447268,211.250823,145.989064,67.16285,123.604441,190.664922,271.34631,241.82173,66.564325,-32.67456,-142.693969,-127.403222,-105.556783,-66.170596,-47.571223,-39.269205,-59.835009,-81.138956,-55.625748,-8.838291,-2.426721,21.061284,111.020375,144.417334,115.886159,67.855107,-23.04184,-39.282333,8.091182,133.948227,142.410361,43.221852,-15.8885,-96.262885,-116.134133,-170.380436,-247.147531,-252.649988,-205.267732,-194.114048,-233.37323,-246.309282,-200.367128,-132.770823,-83.122808,50.656072,115.235266,251.199371,301.759272,269.901158,196.794427,71.666005,143.856317,235.880926,320.330687,304.996766,314.984341,332.972663,242.34651,82.846382,84.761677,188.608445,188.051557,74.377979,54.594401,142.786873,166.999882,68.306479,-15.418129,-1.139305,78.459086,116.29995,91.68261,28.441018,-39.753074,20.450868,54.504697,89.692967,101.195842,168.2637,226.544405,297.219732,274.866975,137.99218,33.047555,29.815039,114.068556,194.128823,341.12092,351.741146,241.952396,167.59772,194.326569,295.781868,312.213122,207.144223,98.384713,-115.675819,-160.787427,-118.328036,-72.721403,-49.19683,76.809611,152.104835,195.482845,163.316502,110.307283,120.366764,141.381105,192.905201,199.659463,159.24783,132.241771,117.014289,118.640956,91.865539,142.585986,201.216318,235.638125,209.594631,155.562453,115.659187,-19.098995,-145.162735,-149.190402,-28.606082,33.471119,60.370677,13.023304,-157.817388,-218.419007,-232.923586,-179.633099,-143.559206,-85.872489,-63.419952,-46.004591,-48.755762,-32.779445,14.690653,57.801857,166.451495,198.879541,227.008992,234.611391,210.019218,184.630437,117.906778,47.136131,39.223243,109.488718,178.558022,297.325731,313.660259,237.081198,47.1105,-26.265589,-31.013751,11.173405,79.695882,74.030839,20.737663,9.768914,-26.604125,-104.831069,-110.007231,-35.784908,7.005831,5.434848,-44.714209,-112.91266,-4.243293,88.273588,207.947339,211.650503,147.386766,100.458508,51.183304,66.972146,116.181596,161.07807,208.528888,305.430656,308.942863,195.211419,133.227467,134.533351,138.935438,77.492983,-49.934991,-46.004114,115.307942,208.760861,272.608473,256.794205,235.793623,191.587428,150.127701,113.032416,112.492847,59.126596,8.070547,-94.155248,-190.713015,-207.115567,-128.352275,-59.145314,67.18764,103.782877,90.602671,60.277327,-3.987353,-75.154576,-86.221649,-40.861355,-8.664824,12.023757,5.678182,14.912463,-7.531071,-36.155126,-71.371496,-59.843849,49.356425,98.376556,48.860051,-21.711609,-97.800086,-21.869211,8.701899,-56.645346,-97.099083,-83.534895,-60.217735,-11.239535,56.298706,91.858622,178.667779,214.319159,213.200097,190.865234,194.815455,232.047307,271.119936,198.804773,173.390371,193.28757,224.944102,244.798413,201.338257,59.842072,14.862853,83.296952,278.322325,303.805264,203.570539,144.00373,40.156621,-24.823184,-124.019897,-65.627831,-2.315763,59.371998,65.380182,96.39994,84.973908,-55.51666,-147.535574,-113.902017,17.725051,66.36422,71.654862,15.544027,-116.021726,-127.988692,-86.0721,-41.381814,-11.110352,13.572335,6.576116,-11.76094,-39.882568,-134.119734,-184.900988,-178.148144,-89.065955,-13.4197,69.370939,26.907723,-134.748112,-190.70766,-233.012872,-157.675883,-91.067387,-35.7264,-50.008226,-72.862712,-53.865015,5.810724,-32.77525,-47.546128,25.216579,59.845141,44.374691,13.268759,-80.164749,-133.57539,-176.624346,-89.391816,-21.618425,67.410684,60.354309,-31.397441,-67.432565,-61.225139,-57.445458,-69.394634,-67.863327,-49.541909,11.945171,41.802562,13.626389,-47.282956,-140.736701,-133.483265,-126.619636,-94.445914,-36.243927,82.423181,85.810549,-42.409778,-237.554001,-282.337324,-218.79089,-168.478759,-127.950054,-110.601774,-29.350959,-3.277149,-47.1688,-37.209787,21.627692,82.72871,39.912183,-118.549815,-195.018473,-296.947929,-275.741715,-201.867377,-20.414212,3.35408,-125.734799,-200.74208,-265.064492,-284.537325,-321.140801,-257.908633,-194.762106,-105.434712,-100.626042,-187.526179,-255.776031,-352.040268,-376.393427,-335.302733,-158.359516,-73.21857,57.876999,102.829565,104.892546,64.402339:-142.472509,-93.830369,-11.018087,148.16177,166.059178,103.672436,84.661615,127.733652,142.845393,143.713397,248.436479,318.732028,328.357942,257.279662,75.306454,23.536019,32.406141,73.906749,85.347747,89.205819,80.792342,59.310518,60.194865,69.097148,13.751021,-8.260044,-0.099238,17.494747,74.844929,83.715631,-4.458761,-77.881537,-206.082602,-215.040614,-170.185723,-114.154581,-127.274244,-227.097932,-297.351193,-376.08143,-362.765152,-345.577358,-305.036112,-283.955447,-248.289918,-236.638201,-227.394752,-235.88463,-271.051635,-179.244324,-67.745862,139.031012,183.591262,120.658734,69.705402,82.903698,139.747513,165.183241,235.5304,235.816427,135.209016,78.6097,21.775744,-11.401616,-177.844606,-299.079061,-275.382712,-165.785213,-139.553508,-159.24334,-190.193286,-237.287737,-170.607436,-76.878831,166.907924,248.8182,245.291336,189.548281,94.779635,87.134047,124.48122,187.420587,248.798139,351.111909,322.866888,161.053187,114.914255,138.919195,183.517672,200.80935,200.242746,187.107906,207.112453,232.118124,229.318719,172.434493,-39.508886,-119.165024,-68.617338,1.923109,-25.16516,-158.603904,-231.521257,-280.542687,-210.883692,-167.238971,-53.354591,10.80196,81.916777,90.058328,135.283098,173.846227,190.219032,168.495932,192.479018,265.537423,284.47939,280.069124,263.488434,207.716822,108.872246,89.219823,117.952887,94.22621,-40.87091,-97.808823,-180.072547,-214.713485,-214.996329,-98.147244,-23.865781,71.574171,73.606498,-11.498189,-68.414071,-102.399085,-13.426942,53.225473,124.707415,95.886999,16.196084,18.294876,109.789814,169.637674,190.174177,165.525351,213.240352,322.330766,309.028246,177.593415,115.305309,34.219977,17.462603,48.436455,156.874803,191.795811,145.1813,49.965949,-206.43423,-280.863215,-265.104104,-180.862288,-116.014719,29.240417,60.45775,11.85222,-17.67287,20.991425,91.714096,109.414693,125.441252,117.907133,43.611305,-24.817367,-134.017919,-130.07403,-47.537269,36.693173,94.4452,238.254541,287.148755,261.57786,200.928162,65.448328,-10.678998,4.567242,64.630366,50.268234,-48.465205,-89.79621,-152.831265,-180.770172,-180.568814,-120.853306,-98.107011,-45.059659,0.584107,40.999439,-13.268851,-169.189345,-155.346908,-76.696554,111.459547,160.782984,171.481506,171.522816,139.990663,105.761022,74.883926,172.496138,259.4785,370.44776,339.685117,174.542385,149.921327,257.34358,266.117973,220.70611,183.544089,202.21067,249.472361,234.879916,118.780788,94.03461,165.213957,200.679514,204.207441,184.807898,146.214744,19.386155,-55.962608,-154.886988,-126.62903,-83.050668,1.968862,46.404841,173.775378,211.718331,114.415644,22.051866,-111.202072,-124.700357,-85.247148,16.694537,35.955601,-32.089666,-73.438796,-61.023847,-13.061247,5.005073,15.092153,5.852638,42.457276,75.752004,37.430821,-26.715765,-123.502095,-115.424267,-91.384726,-71.858851,-61.684438,-36.239636,-48.568385,-74.209856,-31.74553,2.363514,76.546353,106.137022,143.224228,148.908854,122.50014,122.694597,222.486201,343.426973,353.426834,285.461737,274.6827,315.117902,281.108042,52.060243,-49.300101,30.197381,232.874658,277.728303,265.445028,223.006233,117.084598,84.264284,105.048229,252.011826,312.078889,283.003527,234.731739,169.908468,143.016665,91.99855,81.327512,80.355627,95.882283,127.72704,182.331638,154.304469,2.968033,-57.102005,-96.453439,-73.385662,-33.776798,87.747042,141.286864,173.311638,158.10849,95.627971,-2.040077,-15.626809,66.855892,108.084355,98.068426,45.47514,-89.614909,-121.976467,-99.19728,-35.445325,8.699694,61.286459,50.147144,15.118982,25.551977,60.325614,19.945644,23.845819,104.005034,126.239843,87.042333,22.230601,-137.630971,-157.125577,-65.089387,-8.746781,3.263466,22.816414,7.420446,-95.252263,-141.251341,-127.080522,-83.59489,-71.481672,-36.888416,-31.702981,-60.174931,-90.909044,-185.482953,-241.247124,-321.785387,-237.244799,-143.563157,-48.814866,-64.342006,-86.521775,-86.293257,-139.085578,-166.453747,-139.203396,-90.664401,-75.395794,28.058667,84.249583,2.851625,-99.993865,-141.457344,52.32404,141.191246,198.718462,175.809956,41.972142,-57.006188,-201.59601,-154.018483,-66.682263,70.739761,54.21295,-69.620181,-103.712442,-105.914684,-112.096644,-134.393841,-108.584759,-103.313907,-155.081874,-170.096863,-148.58331,-155.004579,-230.56401,-308.477306,-300.164592,-148.823709,-60.10096,14.956954,9.150772,-50.290078,-101.977456:left
96.756154,21.945569,-5.9469,-23.719698,-15.744578,26.030319,55.083651,74.506391,31.243336,16.739596,-13.179087,-27.207247,-3.427772,15.739819,33.387696,39.17591,8.774514,-68.72787,-75.975376,-5.94535,30.761562,64.284066,59.427343,-49.380748,-154.309486,-148.029511,-114.96268,-94.591281,10.693447,62.713713,67.198042,51.494629,96.349952,133.199805,110.372458,108.833115,163.963629,273.111145,281.049597,216.984033,162.464659,148.654235,90.626063,48.196068,-28.553952,-61.252101,-64.24606,-39.165333,-73.73016,-180.633933,-201.006766,-154.665568,-109.671386,-35.706595,-3.931412,10.985878,-105.560451,-153.216885,-114.825172,-48.684281,78.563083,97.28213,11.484524,-46.243148,-52.522307,63.613431,98.834073,80.043769,66.058518,90.144414,103.832342,30.053396,-124.02626,-165.075732,-144.873746,-106.992452,-29.98292,-5.181571,11.982872,-12.340643,-161.799037,-305.714946,-329.296748,-300.173373,-264.923207,-164.363267,-99.358101,-2.842454,-25.730539,-51.71816,-94.945783,-111.680724,-121.849974,-132.203315,-195.160922,-214.9751,-173.189993,-99.428008,-85.81991,-97.885882,-83.481568,25.509028,87.264602,104.326485,-14.981834,-73.16082,-145.041309,-157.288339,-113.332565,-58.889583,20.236297,7.275051,-45.748002,-46.968085,-59.514934,-75.715948,-56.017914,-33.389265,-66.987726,-155.896569,-136.831439,-125.526835,-232.309127,-308.027889,-295.983644,-216.236204,-93.890412,-78.792045,-70.08346,-43.833161,-49.655913,-98.952387,-116.916378,-112.441393,-82.619636,22.206248,47.353752,-2.83701,-144.375859,-196.080978,-245.785887,-244.606022,-172.912019,-128.906158,-112.764484,-143.293776,-149.582297,-147.59848,-136.781581,-80.916366,-34.541943,53.543925,55.847406,32.563647,-5.989363,0.606683,123.167338,210.225561,278.644736,247.070669,155.92532,121.493465,114.856413,124.811668,149.731197,216.017327,246.720164,242.848863,104.201389,18.183465,-102.938946,-122.640887,-103.471062,-85.944331,-31.180242,9.300088,76.64059,37.58499,-34.282281,-190.663128,-239.432756,-254.525908,-235.167034,-193.259451,-157.562468,-148.239327,-141.326935,-120.067117,-36.666137,5.026815,20.373366,-18.583806,-101.768134,-121.811665,-130.760476,-136.23121,-115.956495,-33.098977,7.248771,7.356818,-59.089781,-64.025518,-20.771867,-8.893588,-63.057188,-112.008318,-143.968052,-127.005561,-109.378986,-116.891936,-131.280805,-133.712502,-100.855877,-9.956095,28.321571,29.83786,-70.931088,-117.447685,-165.290038,-167.330687,-143.344054,-124.12794,-70.237255,-57.828066,-117.622105,-224.071242,-261.726489,-261.74664,-235.350209,-198.71868,-201.368945,-280.97527,-408.549525,-458.260623,-504.955303,-467.818057,-280.804929,-191.958792,-82.469525,-47.263233,-4.01526,3.159417,-18.387219,-62.358152,-60.972626,-38.377802,-25.421915,-20.336821,-87.630493,-143.482917,-220.467519,-183.579741,21.844816,86.967385,49.404519,7.51974,-31.496637,-62.259717,-91.452922,-132.109833,-138.703731,-182.327291,-214.806511,-246.02996,-222.336673,-210.104055,-208.551121,-182.830959,-43.034074,6.344593,8.125524,12.006494,43.904305,77.312094,96.490346,116.522072,136.264506,275.285566,370.419021,411.147822,191.664116,77.612231,4.637031,34.39665,91.212602,90.503995,86.699057,92.994599,92.910641,119.195058,154.071264,225.379111,240.707667,264.465755,305.884245,378.64973,303.667313,259.326384,221.468109,198.311029,139.189336,120.416929,116.056825,112.121302,50.767248,-5.306712,-12.619826,-4.907374,12.5718,61.584893,82.578306,110.762394,143.829682,162.939025,172.469233,171.288066,200.973239,227.972207,262.888154,247.046679,179.647769,146.609745,124.994872,78.538866,86.454446,135.869263,157.601759,229.583568,292.791518,281.850567,205.375435,197.388534,264.086559,285.743531,292.768501,302.887627,283.810496,182.592331,147.009775,138.956726,137.690247,123.728618,123.359313,64.153957,-149.313263,-277.47335,-442.789303,-452.193391,-361.75113,-302.276834,-216.1532,-181.821119,-108.950284,-48.826631,-29.804713,-6.010017,2.715915,24.381595,58.453564,187.116165,229.996084,171.358563,-14.639593,-62.068956,-6.359617,39.880048,71.592733,66.1431,66.437683,91.112485,100.547633,124.355032,137.849055,141.630768,141.936399,157.228518,158.542954,155.390255,123.12218,79.844707,-29.936813,-71.000621,-96.401604,-89.194965,-69.71162,-94.881289,-125.621038,-169.230563,-169.915344,-135.081911,-110.824476,-104.218976,-156.925415,-194.334229,-263.270114,-260.004239,-146.737155,-71.650854,53.659109,104.179805:114.770037,-15.816828,-29.259642,74.604079,123.845061,108.48699,71.540014,23.568692,-3.990041,-29.849105,-102.895327,-122.217939,-87.478535,-40.12743,65.542957,83.633256,23.667398,-56.340013,-71.818205,-35.276372,0.120544,43.524529,39.228788,-22.703153,-106.430919,-154.369994,-194.720052,-139.537492,33.048147,69.806509,39.870585,13.156579,-28.070009,-0.010377,22.969783,76.418362,128.236407,228.590008,242.698863,206.630821,154.848193,124.220776,41.367501,-0.106521,9.401115,72.675085,176.815825,161.778805,7.949644,-86.075448,-68.336405,1.483695,32.086036,87.284767,105.152076,97.913545,60.836663,38.186524,6.621674,39.823008,190.611044,236.3597,181.61461,110.98122,8.095955,56.933862,120.263286,182.731113,131.385017,-35.04545,-51.0508,5.845247,-98.630153,-181.702588,-213.908084,-160.487477,-27.777312,30.389942,99.870633,72.599813,-153.355063,-399.937478,-432.200585,-350.58553,-281.571029,-130.362639,-75.141574,-55.54202,-63.601184,-62.884325,-100.420637,-99.79741,1.669876,44.995549,31.179806,-6.596922,-103.794089,-211.730091,-246.410735,-208.891507,-154.266534,-52.410402,-8.971786,12.03229,-70.877059,-104.906765,-142.586392,-156.4522,-158.11046,-145.295235,-95.013872,-69.530634,-83.983749,-162.411622,-179.486052,-146.556801,-128.828048,-116.16628,-111.523071,-134.40216,-186.534901,-205.225114,-243.917608,-266.547849,-256.299338,-202.066499,-108.207392,-104.525439,-111.880343,-167.174856,-210.203329,-221.378641,-187.262,-96.252975,-58.666256,-67.474104,-146.001189,-172.578863,-214.607353,-231.434266,-238.570185,-218.482494,-150.615138,-137.598743,-161.163516,-221.627179,-269.579847,-266.037209,-188.55722,-17.062489,27.632953,43.94753,30.456173,17.788518,7.095036,32.980618,166.125175,250.090122,344.499057,317.880125,165.595961,13.66959,-25.888171,64.078031,156.87121,253.747431,256.311778,236.592547,144.632805,62.676396,-73.13783,-88.314843,-47.078283,-28.317108,21.929004,68.239279,138.134202,43.032825,-49.134911,-127.78692,-111.057973,-120.733156,-147.217691,-126.954031,-56.611216,-69.064886,-147.408999,-142.020899,-48.801471,-19.232185,-49.183359,-88.55687,-154.972586,-195.396387,-198.398058,-157.214873,-126.952172,-72.575648,-55.661419,-69.347481,-118.267583,-135.765522,-148.714888,-138.92369,-119.09897,-131.939772,-163.634021,-146.653038,-82.62087,-151.679069,-226.154943,-251.075861,-184.851841,-44.765704,-21.6806,-78.425099,-173.419547,-209.75557,-277.969326,-297.669547,-266.847228,-223.356728,-117.564164,-95.21901,-153.037975,-234.886735,-263.655649,-249.200747,-211.196187,-201.4782,-243.549566,-331.881169,-362.197319,-381.27466,-422.98524,-388.404133,-208.503743,-133.047872,-31.86897,27.693834,100.710068,-21.745943,-100.723085,-104.811617,-60.584787,-42.081606,-62.317052,-83.238026,-114.278914,-174.255079,-310.540006,-321.050546,-221.095101,-153.987102,-50.813376,-44.870779,-142.310747,-270.955549,-328.56323,-348.291094,-292.500819,-196.400014,-211.99414,-294.299744,-295.541363,-301.892145,-370.2433,-376.179363,-244.068506,-142.361023,2.200306,32.068067,64.847634,35.728478,-25.2523,-113.784511,-91.276687,65.517353,162.097439,276.82486,184.413704,89.598201,-46.751107,-52.808382,-13.383213,-17.886183,-42.084935,-22.671045,66.683153,118.306423,113.991831,150.655345,223.659348,374.451305,399.25773,359.272256,289.347845,240.191876,83.239212,11.595684,3.927087,68.659132,221.749614,255.640314,192.041491,68.671121,28.07863,-10.014341,-10.712259,34.431448,68.28257,113.335357,153.945343,163.155541,125.103719,120.02575,202.386501,258.162848,327.784865,330.292288,280.553701,168.807768,107.095282,87.761385,139.459404,238.189263,245.447973,241.872526,293.637067,285.951014,184.858031,189.302896,393.90375,490.50728,500.991209,439.241587,257.927662,124.379178,118.580565,170.748119,187.117142,192.0069,199.706566,151.052624,-59.288766,-161.258546,-254.234262,-247.349294,-134.991942,-49.081015,70.685829,79.763925,49.560584,30.349095,21.157696,22.335706,56.664863,184.421622,230.326552,206.006311,140.155913,122.305232,60.938423,28.339799,45.22556,92.137475,173.738966,171.702047,101.10397,115.629172,174.49376,300.783058,337.277077,327.378586,298.711463,263.67922,245.349779,223.886822,146.505858,87.320202,-31.365035,-46.404077,0.584443,-10.948998,-123.459312,-190.741173,-210.68373,-238.952816,-231.80299,-190.999158,-187.567034,-244.407355,-276.103533,-262.297082,-211.642727,-172.772357,-77.156745,-23.589689,74.522664,93.421918:-50.941909,-159.846221,-161.037804,-81.914403,-32.803464,-7.39598,-22.385228,-23.719564,-35.98038,-72.624594,-137.527276,-120.821621,16.335976,94.893209,130.227316,75.810031,-15.755484,-77.807962,-129.789899,-141.288818,-73.513637,81.865159,103.640385,38.220914,-28.626292,-64.063627,-95.497891,-52.972904,68.519851,90.015306,85.367769,98.587294,107.111093,-0.035717,-51.401569,-8.684945,76.491977,237.240508,267.142675,215.29428,136.423287,105.240246,46.477592,33.831964,48.370489,61.165589,99.37756,117.200904,72.992749,-54.91121,-74.260465,44.482344,128.248723,217.526095,228.19421,229.740733,208.82047,184.911497,162.252651,191.131913,261.71013,260.266315,207.288561,176.864657,140.358488,148.919008,153.409929,155.143197,162.535219,160.750201,142.701308,126.589431,133.126432,105.239087,44.307276,69.751299,192.711316,232.832867,203.647347,132.843247,-58.721271,-243.278129,-307.388662,-267.496203,-178.852988,-54.01783,-44.633779,-68.397813,-101.95815,-126.820001,-166.318645,-145.472098,-49.468042,-14.126505,4.841838,-18.952171,-139.054918,-266.350606,-279.267946,-185.514652,-134.055205,-98.393944,-86.086143,-48.656914,-97.400574,-155.590005,-251.520098,-276.761658,-265.335556,-211.160283,-90.188122,-91.017614,-178.319147,-210.705625,-196.051564,-108.726009,-49.363457,43.798953,45.439572,-77.314619,-169.525546,-173.607137,-198.675935,-198.359572,-91.126509,-26.135436,-7.360844,-35.052905,-38.812887,-51.869684,-90.736439,-127.910329,-120.636101,-95.310285,-69.891052,-61.362416,-154.242434,-203.656314,-292.114642,-317.278257,-283.069624,-229.001489,-159.327796,-180.737731,-257.716961,-312.78048,-323.021549,-279.870414,-243.858586,-139.429593,-60.126577,34.722329,-47.395853,-108.540841,-130.223982,-61.355282,142.60534,209.340157,233.759623,217.592827,155.360818,52.009592,7.298375,29.395398,108.924524,278.563781,292.325178,176.074894,78.169961,55.629665,18.528133,9.088612,0.955273,-4.160304,20.668124,44.083636,36.682266,-34.269737,-68.550753,-120.67045,-154.448274,-216.913102,-200.87023,-104.662929,-110.323583,-162.868759,-255.823161,-255.658518,-187.828954,-150.306747,-115.130223,-136.087432,-222.694376,-282.197175,-281.994551,-204.68906,-159.829461,-101.936967,-67.509397,-18.651911,-76.496397,-127.807547,-210.351427,-211.4236,-129.945923,-88.207218,-70.222948,-82.225473,-88.138548,-110.137928,-145.625734,-182.483957,-160.634856,-68.644449,-35.52282,-60.497502,-145.610902,-192.349777,-250.325771,-223.275099,-104.51901,-57.538638,12.788217,29.516242,-55.723476,-228.918886,-263.950098,-200.040253,-153.636095,-123.387107,-133.999119,-185.581252,-246.266686,-257.937961,-231.180202,-199.842788,-136.405292,-92.089874,47.58464,101.648179,72.226947,-59.565902,-100.98677,-98.216536,-86.34106,-79.820581,-69.517569,-78.238169,-202.752218,-282.234376,-343.078829,-295.398536,-166.573702,-136.261303,-111.984134,-118.017864,-163.782077,-204.316056,-238.304018,-290.492936,-295.922298,-295.498747,-291.276657,-297.403254,-295.004793,-269.379099,-214.333389,-194.735859,-144.564496,-106.029825,-45.405705,-48.971018,-70.784588,-71.989095,-93.546883,-123.612698,-89.059332,52.512533,103.663033,69.645813,-87.265687,-144.741523,-147.830821,-116.170842,-87.750785,-100.165032,-89.542231,-42.428966,32.280768,-22.899621,-42.36352,33.082584,91.042173,172.07626,200.910669,223.60481,223.611155,224.314651,143.969799,66.437367,-42.498675,-45.847914,40.328046,89.935495,79.627377,-29.661048,-68.40823,-94.155882,-76.077228,40.864007,88.620989,57.989033,70.957971,113.65074,142.283653,151.841646,233.855578,279.340675,286.485048,254.771139,198.7092,84.965443,7.097021,-42.159488,-5.521564,103.43136,150.976753,193.407075,191.378709,181.530715,166.843183,194.374008,294.514343,321.980529,290.638606,244.525519,157.504023,101.593649,70.696905,46.857066,68.783238,128.302306,155.328022,169.906503,39.217762,-55.046069,-200.399941,-233.370946,-178.984506,-87.033321,108.709995,133.900061,32.719428,-46.825157,-39.464482,37.699132,91.411557,191.315834,226.28206,237.06097,127.969957,49.969334,-61.107725,-67.29353,1.513887,38.730868,74.953239,80.61824,93.13378,128.732358,144.544963,197.306731,249.717777,334.834808,333.345895,271.329851,220.668195,188.876913,98.07538,62.692779,19.317011,10.47864,18.984182,1.669274,-132.365906,-277.998838,-321.129216,-339.37629,-321.058292,-289.398517,-297.07209,-349.643544,-396.87316,-426.592613,-458.630605,-397.435579,-123.503717,9.400936,127.833817,106.959002:136.99465,44.689258,24.525959,58.570078,77.712516,67.705477,58.887144,52.544275,-4.584472,-49.719846,-99.119138,-68.223133,74.917496,128.428065,154.988914,140.420866,78.930454,18.099802,-15.181907,-54.474666,-23.761158,93.087385,114.146346,48.182845,1.77399,-0.549553,-17.627045,5.835459,132.566529,164.428746,147.536025,161.417532,225.187519,142.102244,68.288886,76.125919,148.041954,244.599324,265.455585,265.429343,175.53924,122.553147,30.351517,17.551104,97.623562,137.213293,123.982508,100.03229,40.419053,-87.86213,-130.40685,-59.58246,15.677684,95.071553,96.439445,69.876364,48.848051,61.23231,119.452523,152.066948,199.211069,207.224139,166.681899,118.940197,56.762668,87.928003,104.166501,123.792277,135.677635,139.632498,135.065566,126.11989,89.654377,79.986251,125.195973,149.033314,151.456001,149.155752,117.369751,54.029709,-145.583614,-304.440861,-332.353799,-273.021718,-212.475555,-63.202103,4.52611,-21.346561,-147.909562,-151.389893,-117.911331,-117.236645,-71.748007,-39.85961,-105.553361,-192.168741,-277.58288,-228.653202,-212.911132,-166.427505,-118.218783,-40.472175,-24.907521,-18.583077,-34.739105,-53.159721,-124.252295,-160.709052,-163.202954,-135.946123,-108.227752,-122.977822,-170.718444,-187.476702,-190.693011,-167.386007,-120.881027,-22.117771,-19.333549,-95.837267,-141.777719,-154.391445,-215.414581,-231.84327,-154.178662,-83.88644,-13.05321,-20.312665,-8.643742,22.334305,-9.848532,-142.790007,-182.873659,-131.290811,-63.735808,25.900587,-35.217718,-90.353929,-171.713227,-194.206769,-212.906686,-217.40712,-196.056339,-165.055942,-149.259956,-261.014288,-319.29559,-325.177225,-276.590493,-138.028915,-61.187169,30.171936,-42.373805,-101.539638,-147.741327,-104.484578,91.341236,190.303897,303.863042,293.41669,145.808194,18.473185,8.15567,74.26346,119.705287,195.2619,222.004025,209.664353,85.846492,-4.676449,-127.712604,-117.859873,-53.244685,-52.137438,-60.254874,-46.843273,-11.368068,-46.105953,-92.902077,-159.667283,-184.536428,-235.878759,-242.27416,-238.498442,-218.034168,-183.655427,-125.730414,-119.194272,-95.616266,-54.581511,3.699369,-33.962665,-198.78178,-275.215441,-256.637411,-153.716027,-92.32935,-25.892624,-40.144827,-101.056743,-79.786112,-56.886765,-64.75136,-65.28514,-21.259818,-5.602889,3.539775,0.402317,-43.550796,-93.776196,-90.358721,-17.488816,7.833261,-9.795711,-21.502833,-44.483242,-80.358266,-89.60706,-111.066854,-122.628678,-103.062909,-73.232385,-14.320873,-1.718524,-30.56369,-119.260667,-172.002479,-210.065601,-179.453259,-119.820845,-121.262392,-171.296945,-277.644922,-336.323251,-373.297714,-336.254343,-223.134469,-159.651994,-10.779503,40.049013,37.592929,16.248128,19.924534,34.482108,33.249244,9.626051,12.348535,10.738468,-75.960158,-109.894296,-101.133033,-72.674797,-3.176092,28.431375,30.804003,-16.123152,-111.997004,-127.510409,-150.566704,-236.232523,-262.768044,-252.309166,-230.273255,-196.71489,-162.359095,-133.83011,-68.040908,-33.992836,3.18805,9.953034,77.51916,125.061172,119.777754,7.054159,-42.254033,-63.61818,-16.115318,166.091564,242.276788,225.268218,53.072077,-13.253167,-45.158349,-15.035512,63.590294,69.585965,-6.186642,-65.810766,-135.904892,-93.394606,-62.20725,16.041585,86.42631,251.326281,294.509697,234.537228,131.133783,123.913512,129.833387,109.545687,45.385283,17.435894,-1.815831,4.729354,-10.921346,-73.889262,-106.009122,-120.627969,-92.116272,-24.510441,2.184863,47.436517,16.744005,-17.980487,-12.123621,36.554176,142.732506,180.85276,187.169813,141.190389,41.66296,-20.022888,-71.944451,-124.62055,-85.350662,23.773957,62.007295,110.558364,100.811522,86.031671,96.869963,121.935864,166.479392,182.306685,207.797204,195.723606,89.788454,18.767871,33.382732,77.658057,79.761872,79.589204,88.894515,45.836719,-87.290589,-151.214393,-288.570395,-336.407703,-249.541261,-127.76192,43.903252,34.588857,-47.217207,-48.18617,-54.373302,-91.823199,-72.59481,40.908019,83.397882,90.279355,23.498372,-22.310766,-85.441514,-82.597381,-42.54361,-31.608545,27.67735,101.148095,239.222543,212.814715,154.022448,138.192137,210.147125,319.052957,294.885508,186.312512,120.07783,93.94348,49.916885,44.520518,34.461513,3.341185,-84.765751,-129.018831,-213.149428,-244.166547,-250.763045,-277.429221,-285.765878,-243.114074,-202.371048,-191.480459,-269.594409,-291.089434,-252.572913,-203.01939,-88.829607,-34.539078,60.117132,99.946629:-7.092008,-88.994069,-123.415576,-113.520836,-60.532374,53.763033,75.428929,28.830674,-93.870303,-167.325687,-223.207724,-171.485618,-4.655924,54.614682,79.830161,59.767314,-6.272893,-101.960147,-131.802647,-78.010748,-26.126398,22.360924,32.161732,58.084542,23.887069,-30.175469,-131.029226,-129.988383,-29.428539,38.900944,143.991674,154.896375,84.51993,-69.887324,-137.400119,-114.109234,-29.712186,170.584422,243.028156,201.709392,18.858022,-45.156845,-102.164985,-84.036014,29.145759,88.949519,159.677725,142.914173,-7.835773,-185.227874,-213.918239,-53.527636,81.121881,212.098542,184.498134,112.041457,157.884376,184.104152,183.402899,185.572055,209.539109,207.993795,160.66579,117.106522,33.971077,-21.466499,-48.967282,-14.892114,64.361673,218.903225,248.946014,212.186923,119.260325,92.897861,115.684026,150.960109,226.158544,264.177084,289.919292,235.036988,30.329724,-167.246187,-223.964493,-156.124801,-63.982202,67.450868,81.734384,12.850534,-81.671923,-115.579651,-185.879048,-189.555262,-53.814734,37.212114,49.382353,-50.957183,-269.737828,-289.141501,-252.199416,-195.817763,-177.019167,-115.34264,-59.906893,24.044467,-64.187775,-145.36931,-216.693983,-193.443593,-124.460006,-90.256249,-13.208123,3.773915,-81.288656,-237.83901,-241.424733,-45.106385,56.567223,112.73058,100.280653,30.927591,-90.367352,-121.905742,-110.439032,-108.704143,-85.095308,-25.094903,107.529778,119.334617,43.187417,-7.07467,-17.603653,-76.647935,-102.461552,-39.74701,37.989567,111.080825,-2.252472,-69.525633,-132.734783,-140.03076,-158.510367,-148.736208,-54.536014,-29.803502,-145.086359,-326.145044,-361.697527,-290.629865,-206.957128,-33.374947,24.403824,52.949163,-25.13239,-73.312524,-60.421318,18.016409,195.858512,247.328568,272.053624,250.890881,158.414606,58.949783,42.594233,100.795218,151.634044,236.990549,252.202416,209.469734,76.134668,-13.431749,-78.814978,-15.849795,117.194868,116.894838,71.593994,67.151218,37.9328,-85.741355,-154.008698,-194.375838,-163.814316,-55.6287,4.353399,57.154979,-29.595326,-104.734181,-217.676674,-207.154129,-81.677034,-26.323718,7.798414,-16.513297,-122.294768,-191.421557,-196.288161,-113.96999,-42.496178,39.884903,52.183818,81.081966,59.315969,11.402095,-70.554538,-55.21042,55.652043,99.402189,127.932785,118.808733,52.251068,-23.729281,-40.477733,-20.816316,6.037815,52.282277,43.055016,-68.291029,-186.787155,-218.751482,-179.744966,-88.759179,123.472504,179.557992,195.845314,186.917707,120.153419,-54.31283,-127.828917,-115.067075,-56.560852,21.788934,25.926502,-31.501054,-169.821941,-229.365733,-248.58579,-214.761236,-117.628669,-48.762616,111.104704,144.958532,60.473881,-64.681547,-85.410761,-49.206521,-19.312595,41.482754,73.241013,53.395382,-115.443302,-172.987688,-146.535889,-114.10204,-88.558317,-73.972019,-13.172715,9.109453,-22.90775,-118.462362,-172.106131,-241.61359,-233.572617,-164.736678,-140.823302,-149.584504,-154.829533,-139.042485,-70.603918,-1.787104,153.763041,196.681341,183.771517,145.362417,96.120301,67.347618,30.456541,-11.360376,13.92516,128.585706,193.142523,248.328942,112.549172,21.213933,-47.73041,-25.703848,32.825832,39.632664,5.683872,-12.475667,-33.273347,-82.867409,-80.552679,61.957774,141.797553,198.411955,198.380449,188.426367,202.521853,217.395207,186.192082,138.376798,70.329955,63.935313,62.74198,52.435774,-37.60508,-196.553928,-245.12444,-205.063121,-137.092988,-15.881576,1.033767,-31.237493,-32.016203,-10.368075,35.324831,58.277879,126.846402,178.164702,241.00594,204.928847,51.012469,-58.040246,-93.48321,-104.158558,-63.738238,49.076266,82.501432,80.213076,51.641551,46.982875,56.917746,75.840184,124.578483,138.81133,149.886499,137.109972,60.249012,45.670902,69.805639,79.002533,69.795647,95.845824,121.984157,100.059025,-24.759524,-110.038246,-280.263072,-311.518182,-213.457278,-135.325424,-57.217464,-69.228019,-146.717097,-228.377856,-237.054757,-115.292586,-25.631483,85.722519,109.544789,57.849767,-123.613866,-206.949985,-275.492958,-252.58309,-161.454723,-120.572409,-19.856251,42.873751,116.035053,53.097953,21.454885,121.203235,212.856403,270.025667,216.576694,36.500031,-46.787217,-47.95077,-80.158856,-109.967449,-136.441082,-124.135497,-127.121165,-185.05086,-353.684173,-413.515065,-406.062757,-418.125467,-427.586598,-357.453105,-301.454528,-287.536276,-402.649057,-468.575962,-491.73974,-415.948487,-159.094819,-36.946943,86.980072,86.018021:140.60594,50.292742,26.285776,18.796793,34.726284,50.190408,45.166011,68.860337,88.85752,84.306886,80.12605,93.688283,138.339636,134.611407,84.508815,69.613438,58.112749,60.389907,59.429046,27.390336,14.448171,55.133169,74.89522,-23.004335,-150.365881,-143.006981,-78.954445,-59.74873,8.306184,57.852071,121.967278,138.321007,153.295194,98.678436,45.96324,16.2078,67.683865,209.407736,267.63782,315.604648,236.118707,181.893313,120.212264,86.096392,-54.789212,-113.976065,-140.139825,-163.839405,-317.120134,-474.860565,-495.56424,-364.623721,-251.851972,-128.793931,-146.189799,-233.947129,-255.170325,-238.77842,-219.950812,-202.879031,-90.282664,-36.442139,-68.204827,-121.8332,-131.479719,-67.699682,-75.936887,-95.197724,-53.771512,57.506969,67.80053,2.599836,-20.839983,-15.178553,-11.745819,12.135922,109.297933,140.402043,120.310683,73.755948,-67.128183,-212.020553,-268.218068,-284.612861,-232.200564,-66.713239,3.141231,6.268609,-99.544884,-121.264564,-106.374166,-88.442493,-67.128946,-103.463528,-264.366939,-309.09382,-229.22188,-183.702634,-217.420885,-164.216944,-57.564199,72.370809,54.179224,-25.603543,-123.141658,-198.067708,-336.223529,-352.648979,-263.193483,-199.560838,-117.495364,-99.450818,-108.878301,-163.561386,-184.936883,-112.247251,-16.473868,98.819599,73.048811,-25.420448,-78.368972,-89.548505,-73.452622,-62.975754,-66.043696,-66.985074,-57.022765,-38.699927,78.365595,243.427299,263.355119,148.318624,70.794114,9.911868,42.193958,139.003656,133.981178,111.484698,74.737825,38.12729,-46.680125,-52.772751,4.763185,17.386139,-43.921641,-125.934026,-159.778433,-197.937515,-190.530754,-94.837613,-21.461085,52.941349,29.109186,7.22526,-71.36074,-79.185773,128.244976,279.919439,385.392274,322.790598,150.315681,67.404635,44.902246,23.771785,41.27767,109.902643,142.791678,160.320754,46.915368,-38.989061,-173.014308,-204.815347,-219.300509,-199.234364,-106.258088,-70.038813,-63.239127,-97.249644,-119.659371,-168.350347,-208.508049,-266.092216,-238.78758,-149.78369,-156.114421,-153.176779,-54.897982,15.499445,137.927705,169.208987,117.328932,53.077984,-14.979248,-5.150044,-20.07617,4.505789,74.475221,161.747667,130.214646,27.922557,27.703891,64.552865,149.735697,194.907918,232.626096,184.735658,55.707274,29.54948,0.172739,-92.224666,-131.797605,-59.062224,31.16647,145.310234,145.584658,59.217652,-9.888151,-14.20337,-21.697367,-20.818393,23.867619,68.808865,134.067609,109.287388,29.126023,27.570726,2.436729,-74.740202,-80.021594,-53.170683,-58.284942,-136.737384,-244.377526,-277.362599,-268.020517,-223.364065,-111.596638,-68.386234,-8.274184,15.138977,29.479225,-10.062707,-33.096845,-50.270318,-34.591837,12.289376,18.25486,16.521449,14.378044,-18.266417,-81.864227,-47.847973,126.417775,194.076344,214.51269,177.219525,70.072935,-19.028254,-57.299551,-52.760658,-8.032058,47.263552,13.42088,-144.046395,-167.97018,-104.983525,29.380775,88.011509,190.509325,198.379967,112.507725,78.56782,96.225098,85.483651,48.222113,28.289198,84.01605,262.514848,313.392612,219.389219,-5.58181,-61.512864,-11.431397,39.516292,74.42001,59.876605,52.495404,53.778876,13.56789,11.20177,36.338555,101.209606,129.423564,186.893706,233.99587,338.076705,358.575651,341.293739,259.122507,202.734758,128.112839,105.705369,42.019684,5.669533,-18.681204,-3.865625,-15.817944,-44.283695,-27.819444,44.03924,60.559988,13.808688,1.873302,35.166744,82.573947,78.708216,44.44815,43.279428,86.450749,91.219185,45.249466,-3.110323,-23.750353,-25.809551,2.014338,65.825293,90.862296,121.69006,71.872865,23.437603,-30.213163,-20.789622,-10.089563,-32.984778,-52.525252,-17.782073,64.449473,42.85145,10.847279,-2.263968,18.079784,62.18659,67.110315,-1.82923,-172.111317,-272.417517,-464.576927,-516.758377,-444.22343,-349.196206,-220.726972,-223.938429,-274.601956,-252.138711,-214.378043,-127.576354,-93.255938,-93.118439,-118.029374,-140.018595,-88.849252,-55.705974,-78.65205,-131.206882,-172.562076,-140.586346,-62.908049,-37.055514,8.174072,8.270937,-11.074942,22.547681,59.088299,-14.281538,-110.330259,-225.827588,-192.275945,-162.684058,-138.867291,-138.294682,-156.928966,-175.96625,-182.673235,-170.98235,-165.98299,-203.717198,-229.164045,-268.227664,-269.687111,-223.085883,-189.201357,-154.589986,-183.08048,-203.253899,-190.737615,-144.996392,-46.341219,-10.938488,76.145835,120.138356:67.757082,-78.168433,-94.322219,-35.463979,-4.065412,47.455524,70.163855,45.473643,-88.558646,-148.27005,-147.800456,-67.516452,136.790495,189.419132,165.43349,107.122893,-34.011644,-85.74505,-87.821884,-97.890692,-82.618881,33.539149,86.726974,47.523141,-67.66166,-95.567196,-111.393507,-92.907683,0.398832,56.418309,144.96816,151.331268,84.153775,-44.315369,-114.146415,-116.018641,-35.268927,110.432232,141.897776,165.526154,118.533433,62.058808,-46.08242,-70.228682,-45.66272,-14.606196,1.649701,-43.462167,-204.916455,-349.635196,-384.057101,-256.688591,-103.131138,121.864212,116.215166,-27.343567,-98.739283,-93.864463,-65.399264,-44.729625,30.352678,70.590033,70.162351,14.654761,-110.838503,-142.324714,-152.659132,-130.125024,-58.071151,113.94742,156.110363,137.651183,102.700301,123.47001,210.485729,228.399523,208.071437,204.272671,176.330596,117.053927,-56.907501,-193.502541,-227.066825,-184.699412,-106.868088,83.719654,148.495303,144.097094,11.932823,-63.273104,-151.280543,-142.267501,-78.221592,-58.764763,-97.410391,-162.053428,-274.878816,-266.038606,-235.842017,-131.1067,-68.492524,38.431552,87.107318,125.969407,-10.433483,-111.441936,-214.866024,-194.682168,-92.619218,-48.570553,-26.183561,-55.031839,-136.558354,-213.515405,-237.808159,-131.3304,-8.940447,166.133223,177.969858,107.854767,-0.29474,-42.634175,-75.938993,-56.276612,48.955261,104.186514,125.547381,93.624285,72.930955,124.04903,117.133377,35.051093,3.77665,31.399906,90.213482,195.394226,124.513887,45.505155,-70.637826,-84.374477,-48.549833,-28.442787,-20.692169,-35.483722,-98.826766,-147.602194,-153.858032,-133.05521,-107.120004,-34.053063,10.350612,79.78691,75.84939,47.05877,-20.538525,-2.181225,222.638636,357.606054,468.206336,438.869709,278.859022,112.613847,79.35987,127.333518,183.72552,286.501043,310.61309,246.140688,29.493116,-76.624463,-139.776413,-86.15472,44.430842,53.284188,-3.013962,-25.868475,-60.300809,-101.93808,-120.584587,-132.860572,-135.82025,-139.5278,-113.038758,-30.87879,-60.779197,-113.609494,-121.699869,-43.219668,153.211453,211.383751,222.336682,180.541261,37.184799,-68.228589,-89.266413,-36.837026,37.222876,145.935332,133.848695,26.346708,2.074356,37.402596,102.783197,126.738506,164.651868,166.990211,149.683312,119.865922,-31.846497,-174.154316,-166.966751,-12.65933,70.837092,145.316851,130.904023,11.103081,-98.34122,-104.177345,-38.402829,16.416426,136.311362,192.441947,244.391774,211.288254,86.339444,-15.580074,-68.46353,-113.418356,-79.583169,-9.266652,-19.15503,-104.549603,-208.145811,-260.947487,-322.963656,-287.865505,-95.846655,-17.673758,-6.141099,-30.684293,-48.052145,-68.094676,-77.457727,-34.817674,11.912873,83.652239,92.736065,41.178956,-100.547804,-158.643228,-134.430669,-57.067438,111.524801,165.894825,193.580353,176.099117,110.097748,-9.937902,-83.899852,-183.29101,-193.656335,-145.22791,-102.040533,-70.061966,-94.789215,-86.147751,1.543486,84.907405,258.972035,295.582213,236.921018,194.844254,168.68742,99.914736,47.653388,59.168402,124.476424,233.297176,247.400112,195.768219,84.286177,40.014409,2.462208,4.346251,31.280062,44.669078,61.576494,61.310594,31.44699,-21.925482,-34.313861,55.783043,149.227505,315.701954,352.404769,318.218022,254.675612,242.290144,219.000023,200.30279,175.216646,170.701263,145.118755,103.283098,-36.26421,-148.638955,-166.762092,-106.472993,-38.070124,82.594402,102.675964,54.786838,3.293766,12.748118,59.5265,82.07831,135.519641,166.503062,169.904453,114.948206,-15.582084,-53.228412,-64.192768,-50.168654,9.823562,153.959415,171.104212,75.990119,-40.471456,-76.55722,-102.386175,-89.825509,-54.50591,-41.439921,8.40735,42.886681,82.174469,70.219736,61.666323,84.341226,114.929099,147.493424,138.676586,72.709094,-80.454331,-173.956309,-327.108127,-349.373517,-272.847211,-205.431794,-87.252874,-67.092412,-126.038865,-213.263887,-228.851359,-181.718154,-144.589091,-74.553782,-37.980896,-39.004795,-161.462775,-234.099197,-334.000399,-331.340536,-228.860141,-174.122215,-99.534568,-58.937875,-3.310076,-45.166474,-62.119516,-8.077892,28.3424,-3.585572,-80.952463,-256.621173,-307.361188,-295.150211,-280.890689,-267.105879,-189.186508,-153.268914,-177.605414,-233.74845,-335.895312,-401.065729,-429.62982,-432.887193,-390.415088,-231.084294,-152.857925,-148.671038,-346.729473,-422.320551,-378.04793,-285.052463,-109.777051,-54.713127,-24.069285,-45.16748:-20.273603,-3.573448,-3.856535,-81.17661,-132.227153,-138.198014,-68.893061,95.274108,90.57793,53.342672,53.839802,91.042937,176.58579,218.809075,259.526386,224.841233,78.804203,28.805803,54.199572,84.442055,79.040824,85.311073,80.403997,-21.99755,-118.17866,-123.818774,-127.497054,-119.931064,-24.703097,17.385529,22.21819,23.025653,63.784985,56.799245,6.646955,-77.167536,-49.921438,110.487903,171.585113,157.687205,99.191234,97.210028,49.178126,-35.10445,-274.313342,-371.902936,-426.612012,-427.396885,-547.699487,-679.924629,-651.205395,-478.925995,-409.502547,-355.798947,-357.138224,-444.071578,-572.936112,-571.749248,-498.763796,-484.090448,-452.98051,-411.918782,-324.77844,-291.722184,-261.348389,-295.391991,-310.339286,-268.048717,-212.528419,-111.231394,-82.872477,-53.27961,-45.619354,-36.234384,13.778551,44.72979,97.842182,121.790221,125.836155,81.421012,-33.919289,-91.493954,-128.676304,-224.685278,-236.920642,-117.087132,1.334712,252.953999,275.221062,182.09993,14.778395,10.348212,117.146558,154.482414,121.747962,84.979119,26.17334,13.182111,20.52392,63.621182,105.917999,142.368203,103.81968,8.485825,-49.58287,-104.941814,-219.246855,-211.518532,-98.408821,-58.433266,-36.311496,-39.137295,-63.57276,-90.684854,-110.155115,-89.286183,-16.267692,169.276259,220.445623,164.1579,60.005781,66.747641,151.234285,189.910542,256.237048,292.047926,340.766998,327.843289,262.009185,340.453326,419.672151,448.571963,395.963012,333.857063,354.959956,422.185804,461.584682,483.313749,497.422534,475.580869,374.841178,305.033268,235.123956,239.848483,212.480229,122.286137,59.07626,-68.569186,-93.489766,-7.033107,79.532369,148.998565,66.383025,47.887601,0.829527,-31.145752,101.389195,236.029922,340.192509,300.818309,190.106421,109.16016,83.161727,51.012157,58.482279,148.061962,202.872025,217.604906,58.370981,-55.14743,-254.924112,-294.952343,-234.180722,-185.11453,-109.548549,-60.191262,51.226232,84.534903,76.309235,77.625161,79.375951,30.301456,3.668598,17.33893,85.42868,124.156762,188.646649,228.026994,373.883295,437.629526,414.537426,356.260239,285.182892,285.905185,266.156213,183.785946,166.79969,177.212977,173.310103,201.947208,331.268076,382.805714,389.34399,383.122215,386.890747,349.139134,215.087878,167.940519,61.212817,-93.94226,-126.389216,-19.685346,83.339984,192.197067,167.979148,82.319921,77.40601,83.116665,61.096763,72.843508,177.106019,213.70088,184.709138,147.581516,108.353279,91.305862,60.837367,45.977655,89.173046,134.275503,99.977588,-9.987366,-91.732184,-114.406473,-145.402458,-139.269296,-66.950732,-38.82047,-15.213451,1.390432,19.509091,-6.546053,-28.000854,-28.963693,-10.372936,-14.277773,-29.663234,-50.36412,-64.630081,-56.167068,-26.654135,-8.076967,68.333727,117.599336,177.301956,171.021517,130.79741,96.821317,67.428348,33.377138,55.59883,170.417925,218.578962,175.201591,104.607114,142.537643,255.049807,278.206455,284.243607,273.16952,207.951977,177.431415,181.09509,206.022165,199.402771,198.8028,219.136373,221.845302,186.63823,95.51966,15.825528,8.200122,45.963234,56.757945,39.698616,22.86758,-2.020251,-8.20101,-2.261666,48.286557,74.501583,100.018675,110.276388,161.264233,209.397283,292.54196,255.42181,220.735975,171.041017,154.590241,169.351106,188.472419,183.790809,152.9582,81.394783,68.27359,74.427611,73.072244,69.459764,103.942907,131.832084,89.828946,-33.659075,-52.098921,-48.674494,-53.785472,-28.798794,-15.129327,-49.907857,-79.828719,-90.867171,-46.144589,-50.585038,-120.871889,-128.031083,-50.121126,-6.060744,13.753545,-39.272371,-59.207281,-101.549703,-125.178392,-127.633228,-118.357187,-135.232058,-148.857315,-124.58059,-28.010975,5.029932,-17.677049,-53.723534,-107.779428,-113.856442,-120.170445,-207.157116,-283.444028,-430.40936,-458.812807,-446.579438,-441.753891,-414.638516,-402.397813,-444.958147,-458.804362,-413.834492,-318.327962,-311.943146,-358.073565,-384.244978,-452.511637,-515.858033,-513.488719,-483.586342,-489.657243,-495.609224,-448.405469,-280.510854,-224.34786,-213.096539,-209.378527,-207.455326,-254.996228,-312.344619,-467.823354,-535.592462,-618.946733,-615.980111,-579.873916,-469.594188,-400.639341,-280.097108,-259.369129,-285.671306,-288.524316,-208.506211,-119.95369,-124.866656,-208.055363,-230.67449,-177.115634,-141.080496,-135.582789,-120.305431,-77.936867,0.774391,18.427488,41.943824,41.947609,8.272755,1.684478:-44.005872,-112.047611,-126.735324,-84.113894,-47.545429,-25.671125,-22.139152,20.323711,51.415246,59.900976,61.094675,59.639687,99.006865,119.854818,92.431527,48.389942,-36.670072,-18.799802,17.033718,13.712615,-27.716559,-57.160527,-26.798829,-7.891712,-125.252668,-176.586403,-197.036676,-155.331401,45.020792,133.787142,124.517173,77.407604,77.253757,128.497153,135.152743,159.343284,180.5137,211.483475,215.225652,174.70793,133.402385,111.621962,-19.913144,-115.602185,-287.31879,-342.847664,-362.360999,-342.705098,-328.537091,-350.766286,-353.441704,-308.027158,-257.27671,-154.919814,-133.285746,-165.178929,-220.606573,-236.952278,-273.772034,-273.312156,-185.725636,-142.703032,-141.754252,-146.487463,-75.732066,-20.862842,-42.396503,-90.529995,-78.629528,-48.363973,-64.669932,-137.725546,-175.12183,-167.32294,-118.55201,-86.454846,-38.762477,-25.29998,29.153268,74.565289,84.027283,-103.7564,-207.089223,-300.147331,-281.38234,-138.162723,-41.159966,136.372018,176.054958,129.497513,23.308764,2.796811,-15.81584,-38.204396,-51.577574,-25.010366,25.036559,-3.7439,-21.737138,-1.371884,32.275787,89.020714,93.387409,82.750402,21.935041,-49.50153,-134.302826,-100.925366,30.288591,70.281692,55.584444,22.477984,-20.529956,-21.256923,-19.565751,50.688172,116.136198,172.831387,146.045356,73.536761,62.738191,53.982977,-3.302994,-21.518644,40.87181,89.128726,117.920944,120.774781,168.004476,247.426109,274.226113,249.767583,195.460485,105.681891,127.441909,251.062009,266.705305,225.085547,112.130399,66.430032,30.635218,24.300322,19.060086,24.654383,36.899385,47.463078,31.384609,-50.123026,-56.054989,75.383268,149.529288,143.445068,12.607533,-40.487718,-97.836194,-92.905836,-7.888321,40.4368,113.765221,144.40115,145.098028,40.812292,-17.675337,-32.973423,19.113824,124.532795,150.172996,178.743135,128.37466,27.459356,-246.972051,-318.29507,-264.89923,-204.889973,-87.521483,-22.767617,76.675629,94.923644,85.152326,47.452258,5.399448,-98.64302,-115.214792,-80.554512,-52.804824,-27.676196,61.057178,101.937079,172.07295,206.236151,206.779682,159.70921,92.886943,146.944978,152.311513,75.76054,56.95111,139.243417,191.219823,191.086448,145.100245,152.755869,160.958336,141.654894,99.299313,89.405782,89.834716,75.178731,-14.46653,-94.759685,-117.424132,-91.951926,-46.318334,14.953932,31.787001,48.966375,19.055003,10.99697,-10.941106,-23.595483,23.196204,82.109139,156.072347,128.462776,-9.831077,-126.592116,-172.249951,-181.604728,-132.674137,-68.911677,-80.536704,-130.524471,-223.200152,-279.22563,-292.736926,-235.283554,-79.851595,-18.614085,46.376194,54.060274,42.801693,98.871542,151.794782,204.37425,193.171512,179.906517,202.421565,193.463143,61.650127,13.729043,12.591327,50.257369,137.898123,154.088831,162.217891,179.336009,205.957331,166.754602,128.522171,92.475178,106.004174,111.57472,85.218751,12.107338,-15.895633,5.136308,52.077214,54.096591,51.84014,56.693812,79.265068,90.814427,117.222203,165.506213,171.947397,188.506986,236.807608,347.421857,355.580471,240.870426,101.577357,99.012139,155.919485,156.131925,90.91147,51.484305,11.745193,9.522565,27.919253,106.964837,145.033835,143.061091,124.133121,189.419465,266.385233,323.774243,267.349081,251.145095,203.34039,170.700265,160.378354,178.038516,194.597068,153.866069,-23.726789,-66.575792,-37.845726,-47.947321,-75.160843,-77.149902,-50.801866,-16.36288,-14.505845,1.638698,24.410149,17.738018,13.009568,25.578085,12.400295,-43.611287,-129.248416,-70.019086,-69.376914,-155.869476,-152.188931,5.653561,84.407592,119.702206,94.123023,83.381744,22.624313,-11.88399,-53.512716,-54.202685,38.754052,112.059308,162.625862,86.776264,48.805078,2.557671,-4.036642,1.577223,-11.748626,-103.193899,-226.740909,-313.974668,-530.74095,-594.295358,-569.659746,-531.852873,-476.751055,-447.610473,-361.631099,-257.016338,-225.402337,-247.913389,-285.679986,-281.662852,-223.468082,-136.162648,-157.652782,-170.127868,-213.660384,-245.169382,-251.4036,-226.040998,-145.516357,-93.977124,-9.87331,-10.839228,-43.066863,-94.538603,-103.954213,-111.11857,-122.537317,-188.014563,-175.848691,-122.130968,-69.011438,-86.372319,-123.207481,-121.056745,-80.442308,-61.077454,-59.957822,-95.523476,-132.466797,-245.373427,-288.38027,-257.692505,-200.506318,-117.700775,-69.68242,-33.576677,52.09237,83.709447,108.070473,106.548687,84.241798,67.269948:86.444961,58.985153,27.638208,35.655688,68.953111,59.421111,39.159818,64.5532,81.413813,72.743214,80.099164,119.688527,240.162157,256.90567,157.63326,88.962811,16.952862,39.515651,53.974624,77.307946,107.553333,154.603916,135.981969,53.953354,5.602643,-16.280578,-71.186408,-61.183277,39.295554,77.266442,113.897736,132.493143,119.396547,8.391733,-48.607268,-25.995225,47.453737,155.111783,181.074427,199.063308,155.767313,120.574361,1.931932,-77.088278,-186.487837,-200.072372,-224.129211,-257.26254,-349.987024,-494.215226,-529.965733,-378.722102,-239.316902,-88.947729,-119.45808,-262.206338,-336.697481,-333.750279,-296.615765,-257.017335,-113.808087,-80.004579,-188.789378,-251.783563,-247.742398,-173.272442,-154.24042,-132.000272,-91.594521,53.134992,112.733916,82.448232,-23.606163,-0.73225,121.146773,145.988721,146.181402,153.549438,157.170246,115.382595,-50.118477,-151.220216,-167.587358,-154.783274,-116.330891,-18.029359,33.557895,116.202093,69.541856,0.482388,-119.106924,-130.025613,-76.532685,-46.11751,-27.036211,-58.884255,-199.80924,-259.876844,-201.17547,19.609485,95.980196,87.211337,49.688679,-8.73908,-90.920942,-142.590469,-205.332093,-188.306951,-97.808632,-56.097664,3.495894,5.384769,-81.248339,-179.482412,-193.254216,-116.711461,-31.492911,117.392084,152.599922,156.459142,63.145771,18.667502,16.894428,31.707702,64.716373,105.160995,182.989324,175.407859,117.224285,149.999247,180.529422,215.67816,220.452811,215.476597,234.371879,308.004516,298.050876,271.812324,256.39454,249.049063,173.410024,132.706307,88.885485,51.083612,-46.629612,-36.665003,-39.997096,-136.021431,-148.214727,-41.037407,5.524382,1.023247,-20.488383,9.777378,96.923501,124.381657,230.409098,307.040751,360.881259,328.739165,223.663082,157.407317,136.017718,75.864699,56.213211,48.242059,53.303791,54.046017,-60.084521,-143.526758,-207.958655,-170.495175,-113.827382,-151.925897,-222.960936,-184.394613,-54.405926,-70.562075,-113.916618,-134.43672,-112.188311,-95.04812,-98.554533,-97.602562,-59.37403,2.941415,147.261566,207.383953,343.24328,390.217061,318.128879,216.082938,80.032943,102.905116,91.571444,55.470061,88.122398,137.430945,105.963047,69.655581,161.613374,195.762152,181.435394,187.260626,272.251207,280.524458,163.201727,87.329093,-21.874956,-76.348142,-78.819035,-24.240914,26.814748,118.394016,126.746251,50.818838,-57.950972,-73.554933,-8.466036,49.359758,186.608709,245.430536,255.290642,195.7936,58.033708,53.584747,74.255983,83.318077,88.38329,84.173405,61.096417,6.849106,-65.125934,-105.002079,-153.706564,-155.089078,-113.834763,-77.457407,-9.403338,-0.570801,-42.787303,-58.272898,-36.846447,-21.168803,-55.387218,-135.533611,-124.313422,-43.410802,-56.750059,-89.262176,-104.976225,-48.655835,135.680024,178.399129,160.62393,164.579777,177.386196,110.895011,71.444135,-15.524479,-51.380697,-36.826716,-8.540855,-4.682215,-42.768337,-42.537114,37.536117,114.579204,244.606416,250.939209,159.212843,98.760006,39.996479,75.085047,79.78932,42.266553,30.690926,59.816161,87.151971,118.290394,102.860441,87.850285,84.083205,85.095199,10.109646,-47.132552,-32.314197,38.03882,133.460187,82.267104,56.34605,100.988527,145.481914,257.274759,325.079789,333.497673,182.111447,156.6286,203.112674,214.548474,197.282736,179.689593,154.586913,147.439456,68.032399,-55.875396,-82.972798,-38.748219,41.248583,205.480509,206.548097,48.151349,-29.148479,22.3763,109.579451,81.928803,-21.198837,-43.32436,-39.392974,-55.870156,-124.449579,-87.146837,-49.038948,-19.77035,4.411385,84.664563,98.919978,46.900976,-10.732815,-32.521438,-114.430199,-157.937946,-193.879369,-202.76815,-224.043326,-212.006546,-112.892133,-3.390816,8.473138,-20.27322,-20.496006,9.979126,23.031066,23.053819,-60.293596,-125.491272,-232.717895,-246.757547,-200.33591,-178.34809,-164.360408,-170.65566,-205.927755,-250.963326,-278.278151,-306.400817,-315.011604,-337.004168,-326.722128,-258.941202,-212.706739,-225.915436,-273.005294,-272.091395,-238.936184,-225.92831,-170.950464,-113.754044,2.18181,-34.2724,-107.450528,-171.240606,-154.445636,-189.453389,-252.215169,-372.958058,-415.130276,-398.696907,-322.330483,-288.386037,-252.661377,-246.272189,-222.131508,-204.748898,-186.742061,-156.00302,-144.404842,-151.07858,-151.492289,-92.240027,-46.532919,-26.362334,-90.264498,-112.900255,-89.120269,-43.586473,30.734483,25.985509,1.680527,21.867335:left
-55.62411,-0.815148,53.187964,136.890816,145.404799,60.025875,-20.028508,-143.461908,-110.930666,-55.559937,4.714807,1.777826,2.730572,20.901968,91.197649,116.255722,124.409647,202.159632,267.694896,365.851023,364.21614,284.617479,260.561926,240.406234,197.094835,196.469997,190.555038,156.888995,79.177197,58.886882,61.51818,71.532194,76.758843,57.134931,38.183118,43.51564,66.14094,61.560306,25.617351,-84.209684,-139.068889,-120.006365,-60.733365,-43.754564,-25.762749,-27.064902,-76.167502,-130.389515,-239.508583,-187.474794,-108.485602,21.848974,50.321604,41.817396,9.318903,-94.19476,-160.620111,-152.686378,-109.935692,-101.716391,-109.792337,-105.358789,-41.488799,-16.724357,-31.347251,37.825818,111.002546,207.348352,195.569133,56.617955,-27.267295,-133.025894,-161.372688,-144.83002,-82.68781,-64.162953,-48.556289,-31.400682,-3.156663,-31.492869,-129.288874,-67.258318,15.376221,152.206923,187.951064,211.855887,199.616049,111.794889,59.895472,94.527348,204.100735,225.66422,182.007486,149.464598,102.853923,71.547961,-19.657633,-125.956877,-163.000643,-162.85431,-152.381737,-163.345734,-168.550196,-192.717783,-242.018367,-229.112584,-112.330562,-32.793623,99.614712,110.593177,7.118699,-63.496517,-133.698586,-115.442578,-99.517797,-51.441262,-20.776873,54.018045,104.876331,179.937264,90.954078,13.099547,-3.955387,73.415433,228.745814,243.049394,165.135749,99.20514,-18.388072,-13.194605,14.436903,32.670328,14.869557,-44.881281,-62.924946,-107.110609,-163.076047,-145.956074,-104.916189,-131.459903,-235.655965,-273.838052,-269.286229,-259.735931,-332.84231,-412.718268,-398.566198,-276.589087,-221.332732,-228.787316,-255.986156,-267.077487,-308.234704,-348.640264,-369.534887,-308.903275,-103.463678,-39.173868,-70.064871,-114.147146,-120.666198,-66.936929,-44.053109,64.024916,134.352252,160.396044,102.912252,-74.013463,-178.506834,-154.667142,-38.672528,-2.824709,-21.645389,-47.780518,-38.561132,-28.339894,-99.557663,-206.945654,-218.738997,-145.071403,-106.624533,-103.305337,-121.997688,-204.208341,-300.744326,-302.702557,-246.054534,-199.341925,-74.306122,-30.884909,-20.442315,-45.145015,-161.106402,-290.790857,-310.751533,-267.725939,-262.488606,-331.087735,-352.414862,-343.275926,-305.227968,-258.719509,-177.577086,-157.604556,-143.149621,-159.879683,-203.212993,-199.819925,-156.195253,-134.943632,-132.103054,-90.098004,-53.534339,-33.723404,-65.525985,-151.856596,-195.403159,-201.251792,-222.814966,-248.155728,-299.867344,-285.846609,-148.108747,-93.240259,-150.030507,-268.466354,-276.518626,-177.649582,-102.904922,-44.035718,-79.351455,-166.979595,-198.777853,-200.248081,-177.86446,-178.085125,-271.269949,-339.441097,-368.094987,-323.341358,-235.020683,-222.330058,-239.227624,-246.750808,-234.249366,-233.376335,-240.699891,-231.004166,-206.636859,-209.713714,-224.048338,-207.442131,-131.514308,-90.734521,-48.433437,-59.834201,-62.911604,23.074951,57.414453,81.49628,78.289528,55.52035,28.315002,-95.547384,-112.382655,-18.14585,164.541195,182.537461,156.21318,161.654995,172.727129,137.964334,46.676401,101.098531,153.122986,149.388059,111.096277,93.555858,112.222761,78.669853,-14.413066,-11.907127,99.005648,155.058288,126.995791,54.645857,-52.241659,-75.401623,-112.827241,-121.29144,-90.94526,37.496422,81.742958,43.560704,10.552839,17.308989,53.2998,57.619984,28.669597,12.940911,26.277278,31.945525,-45.509646,-112.653063,-151.012403,-24.836405,31.777018,55.969526,40.086905,-11.718867,-28.645485,16.699559,87.085324,76.39316,-6.207879,-18.930133,50.69277,93.467073,79.425805,21.909169,-60.928042,18.172154,89.081108,190.182727,197.499424,121.527445,59.932623,-49.918754,-78.417604,-60.13089,-5.9575,19.083816,41.98559,32.212704,-2.507754,-28.319039,-93.507966,-129.394985,-142.73844,-130.430845,-93.208173,25.296747,97.147085,151.462697,42.187831,-11.309135,-73.844111,-90.288191,-103.723314,-108.644454,-102.962076,-93.567642,-89.815871,-85.353733,-61.686854,13.848025,27.422949,6.082824,19.412181,94.314632,124.541571,106.864315,15.836687,-22.17285,-26.71987,-10.659555,-24.584367,-66.12704,-125.705838,-95.248692,-57.448812,81.26422,150.382719,195.844395,180.485931,124.890333,148.187348,182.341113,164.425827,136.280695,140.207688,132.557391,69.267196,60.401578,123.709403,217.216299,248.169519,267.318724,249.86036,166.955772,119.87716,10.479815,-32.084347,30.268563,264.827226,363.080495,382.731464,316.200548,184.246152,145.579804:15.211652,84.429107,132.871415,246.211252,281.784358,220.634914,136.840344,-19.528436,-10.937314,52.838673,127.211818,109.505825,70.323433,90.608579,157.469678,148.267119,117.540987,244.308409,317.851234,322.456073,230.933136,15.932013,-9.902055,68.651932,69.805808,41.845741,47.859839,70.549354,28.098123,-43.504292,-165.007538,-176.730612,-106.458158,24.891685,78.330125,124.234304,128.270245,137.387352,133.998231,42.224282,-96.698869,-111.764313,-41.833579,-13.792115,-16.450085,-25.99256,-71.887129,-122.465852,-222.504497,-201.922471,-142.349021,-74.001624,-92.930551,-123.037467,-130.495558,-237.009983,-329.116045,-312.593286,-232.739792,-190.845049,-136.903595,-134.814609,-132.391427,-143.765181,-176.847007,-48.146635,55.076751,155.457106,131.786114,9.780185,-62.768786,-191.102014,-192.374343,-144.997157,-62.107653,-52.791461,-75.680345,-72.385194,-47.986341,-60.999411,-75.094711,27.085719,80.693228,120.929679,132.977806,174.578479,176.961694,106.91649,8.480682,-6.52834,77.058244,144.553426,217.112271,206.012162,84.754386,-25.819054,-212.633981,-189.48567,-145.582796,-115.098211,-131.788637,-173.528507,-181.311923,-227.487257,-320.850277,-310.758403,-111.683016,-0.484099,50.177657,12.29153,-59.118787,-92.77972,-169.023866,-175.740725,-168.200025,-159.004844,-135.914675,-63.305684,-34.835386,-32.270091,-66.628569,-61.968415,69.064557,177.358703,278.773748,251.262195,148.9868,84.618524,-0.174749,90.495091,157.003736,148.267577,72.84964,-65.638384,-95.419316,-98.492111,-88.050975,-95.820224,-101.990394,-79.636991,-69.156473,-116.567883,-244.444269,-283.524974,-295.993112,-268.055889,-249.768245,-206.328024,-199.619416,-243.101213,-276.07787,-343.468235,-390.049291,-395.101286,-362.701619,-309.354911,-147.154067,-90.867223,-109.751793,-168.450356,-243.591393,-138.937101,-63.270132,35.288228,59.996279,79.882658,69.280629,31.197315,39.296229,41.314416,46.937206,81.686203,116.520216,73.887011,-8.292302,-15.289448,-16.177037,13.137943,44.875966,59.656499,12.560286,-107.797917,-129.069758,-95.744423,-13.800097,20.397005,3.478225,-22.676735,-5.516605,24.191157,20.826959,-24.174128,-132.555895,-201.639037,-218.379611,-231.546126,-245.734705,-278.699989,-276.678307,-275.677981,-308.249132,-287.705879,-177.610021,-144.822205,-191.108739,-246.981356,-345.578258,-362.444332,-295.988505,-189.225793,-158.296967,-114.413186,-97.920055,-126.44842,-185.024159,-325.5093,-299.017715,-251.076095,-270.215135,-311.400349,-331.779118,-318.503879,-288.784631,-277.257783,-268.875968,-268.667456,-245.714751,-139.387512,-101.125309,-146.962632,-196.169912,-203.552094,-128.733188,-105.99712,-123.158738,-153.02201,-218.266813,-248.212301,-299.952442,-316.069894,-293.660092,-233.952765,-208.881705,-128.664328,-92.264781,-119.917974,-171.020162,-232.525972,-187.839753,-165.442736,-177.986593,-184.242958,-159.230386,-134.446893,-91.534301,-94.459128,-83.8668,41.168667,93.070946,86.768843,57.427192,11.439921,-21.403143,-107.85486,-85.660162,-36.977955,40.369105,70.565821,138.556074,161.651038,105.109931,18.502026,-85.787068,38.524145,102.484259,120.603821,114.697311,143.985045,145.962754,95.162044,75.906257,85.508687,155.43307,199.780055,173.23606,109.705875,19.489882,-6.083178,-45.220571,3.782891,48.133202,99.640005,108.833802,140.584591,152.608067,119.457098,95.249593,95.872471,48.20918,25.535879,77.312197,117.302458,112.308914,65.220046,-46.317118,-11.29823,71.260997,223.526357,226.72708,98.188429,40.670857,35.780785,108.605719,115.311791,25.343131,-14.206376,37.878087,102.430236,130.559542,69.126729,-34.08444,18.828819,48.374382,91.109582,122.463535,121.137877,62.128353,-87.902597,-172.267792,-161.306597,-41.277422,5.809096,-21.111767,-62.534335,-115.798047,-130.444568,-136.944555,-140.156553,-149.937632,-126.844235,-74.02176,28.46246,38.364545,35.543917,76.577887,74.175418,21.87537,3.204843,-61.701318,-128.171971,-252.196569,-266.746624,-151.260485,18.841727,43.404195,32.41738,28.452081,-11.298151,-31.617232,-21.01258,22.202628,43.700349,86.867082,105.938875,104.066778,70.656814,-30.147205,-61.413067,-27.719503,51.053533,83.916678,167.366058,208.017913,231.378377,201.77705,90.513833,73.40043,120.577609,203.850971,202.919061,112.037602,50.103632,-3.020391,0.390851,44.90904,191.153896,266.526322,304.891056,264.624706,147.595108,95.171985,5.253093,-1.603197,42.211074,148.612857,196.354844,231.54253,178.232243,4.669346,-33.859183:82.74893,162.38059,183.811132,181.19188,183.435934,186.68245,174.487473,92.797788,-9.416806,-16.556875,88.839759,163.087045,224.659099,208.478361,139.819248,103.30948,94.315159,199.469913,250.594641,207.02054,110.080088,-60.88508,-86.549823,-53.181743,56.014294,109.914702,77.936302,7.591031,-80.166877,-85.723261,-121.191438,-165.014569,-182.084919,-14.536245,77.143456,143.74117,120.447797,53.627095,30.395799,-42.225762,-81.069206,-56.406382,-20.167971,-31.586037,-58.05993,-72.883099,-166.516665,-231.196588,-263.911739,-149.875286,-107.3323,-131.679712,-167.249905,-177.80639,-157.45049,-169.628831,-232.975012,-242.492935,-202.157342,-170.964931,-158.334552,-154.497971,-90.468982,-74.531175,-106.731896,-44.015905,42.178036,173.083889,158.907189,4.196375,-89.581175,-228.298497,-193.399938,-130.426357,-66.175336,-65.360668,-52.708147,-35.432382,-16.740385,-37.575603,-58.577717,43.913115,79.372318,51.90508,35.113514,68.151621,80.469965,12.148989,-25.225414,15.963792,106.691839,113.609872,87.097384,69.605881,-65.115908,-186.438714,-308.332048,-184.811133,-108.770218,-38.005259,-55.845664,-150.875905,-216.772151,-349.202359,-323.608915,-254.455585,-112.324054,-39.979238,101.78779,134.962,46.84246,-51.07456,-168.825626,-136.899663,-131.083404,-149.934007,-143.19548,-76.952906,-46.066723,-49.714646,-78.004036,-69.52109,24.397277,93.254291,164.026186,156.218141,137.692971,121.363417,49.411451,36.092662,56.807908,98.297963,89.936761,-39.364338,-137.91463,-247.220979,-120.455137,-30.808609,48.590515,48.402039,15.086747,-9.720099,-68.493888,-111.730485,-207.642951,-213.258627,-169.507615,-93.227624,-99.722582,-191.449525,-261.930397,-380.218117,-348.023087,-315.049566,-300.211716,-289.378999,-231.767315,-221.064854,-269.93775,-297.579159,-276.853248,-193.214088,-156.671592,-55.794463,-3.650735,21.805234,10.890044,10.138038,31.949102,46.848617,93.184207,124.437858,132.293661,96.654689,19.296427,-4.678397,23.655197,156.842108,206.430602,203.867189,156.863771,28.844713,-17.465924,-30.184981,29.821774,31.294075,-40.185174,-47.646592,35.385619,62.844867,-3.829559,-73.402593,-151.426137,-119.239076,-116.709733,-170.983921,-198.043858,-203.789396,-194.894259,-221.603824,-263.296749,-248.506184,-170.838042,-143.045424,-181.137636,-231.471732,-320.346663,-349.83295,-300.182796,-118.161576,-72.00906,-139.737207,-187.663709,-167.746549,-131.178239,-154.600201,-242.142532,-261.703361,-215.587845,-168.538242,-171.06101,-224.643436,-287.21704,-282.360447,-269.887325,-227.511981,-165.389624,-8.737821,28.634069,-27.591788,-89.970988,-170.93819,-121.374415,-74.729743,-30.697808,-40.606873,-111.058672,-154.227801,-179.177088,-155.664795,-95.573086,-48.888695,-18.725442,69.956197,104.846871,75.353478,16.969379,-73.643241,-43.529744,-17.759929,0.301277,2.218935,-8.059752,-10.802854,1.319763,7.438484,45.637574,119.341451,161.776429,201.205553,167.145065,57.268454,8.858317,-80.66003,-83.11615,-44.275509,70.919356,134.920216,190.341835,173.938008,116.570242,68.494151,-52.305703,-28.64354,54.880091,211.669802,229.464692,174.459836,144.507142,104.522241,67.845487,70.738816,134.336869,176.99452,230.463112,225.350558,146.210745,96.574603,54.817847,120.387867,178.618066,233.936839,214.790016,193.287889,198.864301,173.544373,201.272155,239.945176,298.638662,320.727876,301.237386,253.655121,172.901818,149.077369,111.006873,121.609793,152.921939,232.229357,237.802658,144.000688,87.779856,39.349442,70.708628,91.003135,112.52505,125.713223,153.896127,152.147423,64.903682,-7.092424,-32.007734,93.508749,116.187658,76.964277,70.620713,86.879884,66.387413,-34.807457,-114.601484,-116.190621,-39.091115,-5.374669,-42.875892,-84.62952,-126.002551,-125.421562,-113.11647,-139.046967,-137.223698,-41.27164,-1.079552,-10.430044,-11.327577,70.461965,155.996418,150.539942,79.697538,59.126854,29.51618,-12.603623,-170.027228,-250.672765,-228.923859,0.989021,77.923966,82.182242,39.99999,-47.258588,-72.007816,-76.941409,-28.821289,4.090028,71.066686,85.80058,43.067323,14.191731,-27.050903,-50.66455,-46.712465,55.829653,108.578542,181.091999,200.660728,187.430508,141.82629,9.684648,-11.12012,33.41508,127.115744,142.407415,103.612854,70.186308,26.762934,22.359936,59.960501,137.438413,180.268698,239.902107,234.802232,187.946726,167.769274,110.499822,62.750708,75.802017,183.981091,245.160477,255.929713,210.062087,112.153062,71.634597:-62.063747,55.808442,90.994822,68.407214,36.582708,-42.808928,-86.947021,-171.029872,-206.362676,-193.947596,-160.139294,-132.864263,-31.440729,17.250882,81.813048,83.832317,34.512779,77.406135,135.609721,206.052773,197.911539,176.245051,192.098511,226.430935,222.500669,217.166126,196.303614,187.6504,145.00614,84.211977,-69.530082,-117.764174,-125.641524,-80.052656,-53.669894,4.918611,24.37964,11.614626,-17.408233,-96.037871,-150.81157,-142.999089,-75.977583,-55.165084,-93.389085,-135.155238,-180.27862,-194.984825,-253.678165,-226.110666,-169.606752,-45.036361,-2.872679,-10.979374,-43.673817,-85.14603,-107.086091,-125.243445,-151.499897,-143.552147,-124.717472,-135.783898,-175.089921,-201.076015,-211.400178,-80.882486,-13.182978,47.975801,43.256302,-35.436731,-97.065006,-222.67874,-277.704804,-251.611284,-138.590254,-88.430906,-40.249926,-42.314001,-64.289372,-77.092987,-83.824617,13.861589,90.747543,239.268033,288.981341,300.992026,265.280505,166.778065,124.730706,128.480918,171.097044,192.175181,182.911498,148.156734,21.814618,-51.41677,-138.35866,-164.273656,-174.136867,-136.048622,-106.020987,-110.185081,-137.406841,-191.41952,-170.825416,-142.208731,-77.089264,-22.04492,93.380565,106.513558,32.828095,-15.326586,-49.603817,-5.758794,-3.308805,-55.605125,-61.523767,37.064178,112.926339,161.708727,9.8507,-59.148201,-17.955227,66.859531,203.342573,241.70905,254.385653,195.177612,41.08893,38.601264,54.944074,33.82449,-8.964986,-124.509467,-168.049828,-230.554645,-229.73449,-177.597125,-51.3567,-19.045728,-25.489788,-45.204308,-86.835786,-128.762078,-246.424533,-249.414345,-204.708764,-113.103703,-95.654831,-141.142597,-176.001455,-232.480748,-279.492442,-292.197522,-263.003444,-214.968367,-95.58893,-55.228462,-76.183815,-126.961822,-159.943507,-54.512205,-14.803368,37.348102,74.745492,120.657083,106.398378,30.824533,-6.776452,18.05535,108.754671,127.884876,81.013107,55.14928,34.456591,6.366062,-60.966481,-21.076336,14.691604,59.744728,63.615751,25.312912,-8.086965,-75.224412,-83.377611,-62.123001,-38.68759,-47.508476,-69.896054,-79.809828,-114.967311,-143.451191,-179.910391,-191.996361,-221.863881,-289.346004,-304.940867,-302.991851,-288.133094,-266.662449,-225.853223,-155.510043,2.273104,19.742816,-78.419018,-138.903993,-210.938979,-228.677599,-158.005265,32.754478,86.095814,52.068841,19.821266,29.241727,31.53274,-60.468534,-136.974049,-139.61228,-120.900451,-109.185194,-134.239399,-169.054376,-179.636997,-154.037914,-124.770875,-120.425229,-107.020026,-21.598817,23.459491,22.734966,1.123971,-21.33509,-15.913598,11.415789,46.805193,14.898361,-122.307989,-176.111728,-198.602994,-189.507972,-145.12871,-66.356225,-37.537796,36.416567,81.869292,89.180778,53.513247,10.142958,53.136463,78.427503,61.63177,32.021926,9.959995,26.730048,60.369394,55.314476,66.359955,178.863574,223.397635,215.247275,173.714449,61.153635,17.469126,-10.674325,-10.813358,-6.033788,71.964974,153.175557,251.398129,213.597412,79.25978,43.936738,32.550082,43.496949,70.2218,205.413366,257.041849,204.452229,161.503516,148.694849,109.73692,87.650863,144.701127,192.869605,174.64659,133.082767,106.344316,97.944852,43.590246,85.141657,153.870261,245.177081,234.028686,166.411349,141.216519,103.672397,132.781506,160.869492,160.301573,148.850736,143.313961,131.001067,60.454226,19.859118,5.164734,52.59995,75.061168,154.736309,181.410008,71.401343,-20.301268,-83.382577,9.826322,57.636552,48.293024,6.070709,-22.399856,2.794938,6.181017,-46.406506,-156.928801,-131.319202,-87.984146,-18.997046,-10.70885,-70.039759,-105.933876,-90.958868,-61.010651,-86.770676,-108.240711,-65.000526,-8.958949,-42.367486,-113.869313,-117.864547,-98.987193,-109.258215,-142.245027,-171.534912,-133.379828,-11.638424,34.914852,61.218715,33.368984,9.010235,-46.681108,-55.533889,-49.765293,-72.703088,-196.686542,-258.745535,-245.649805,-100.200898,-48.991953,-1.176342,0.787469,-41.654948,-66.612867,-96.782103,-59.068764,-26.05042,2.068791,5.151763,9.173621,2.81728,-4.821118,7.62369,58.725987,87.035373,86.5847,91.361772,95.201642,104.404546,111.447472,67.078852,-6.084437,13.698855,127.833061,163.281799,127.626254,86.905143,53.321719,52.827545,66.02633,143.972585,189.3806,239.369088,239.138107,176.155376,118.338766,15.72516,50.539065,115.924339,215.586508,232.384671,218.580653,191.499495,124.7752,102.538064:22.159939,-29.82828,-16.969583,109.749348,138.68811,1.397473,-94.450614,-170.761457,-178.23698,-183.469108,-121.190327,-54.886768,22.464692,26.149334,36.906623,27.184641,-28.504019,-34.317248,1.039539,125.891788,165.727501,146.73174,113.961948,51.533882,109.368525,190.962342,305.206194,298.218136,178.843212,101.765962,-44.099872,-125.690004,-224.296729,-101.917737,-10.834464,87.724588,98.844327,56.155685,-8.819006,-157.734798,-160.500599,-114.73376,-26.013934,-8.035415,-72.588254,-137.285087,-230.138426,-260.302461,-289.646678,-216.064136,-155.176273,-40.306762,-5.263813,7.485858,-3.57618,-22.053959,-17.555657,-11.023477,-1.509711,-14.685992,-100.739384,-158.222064,-238.753189,-256.501982,-217.366285,-20.934237,82.227593,157.878866,126.660826,-2.615092,-80.843878,-221.889634,-227.151895,-168.612424,-54.144868,-26.898819,3.693894,7.255781,-49.199693,-87.875091,-64.793216,98.84584,182.779798,256.135543,241.292082,163.805458,124.796739,82.759685,92.201316,105.106387,168.650905,209.73021,190.511694,115.043906,-71.296308,-139.116534,-154.929854,-88.03016,-76.236846,-67.814557,-64.497273,-82.512208,-109.22072,-222.504285,-273.269478,-223.17022,-48.544863,35.736307,121.360172,102.798705,-0.415703,-37.183099,-25.081407,32.975355,39.849424,15.709102,5.078057,18.93411,45.768647,58.275388,-20.897933,-16.959466,152.828129,255.992583,293.240396,235.31875,83.647808,1.650347,-80.059909,26.546601,80.881694,91.950365,57.038885,-44.059682,-88.943349,-155.244643,-95.150605,-3.278408,144.125695,149.225296,47.374964,-11.037806,-48.343841,-46.942245,-72.717167,-76.167594,-47.763325,30.629049,45.517164,-2.010855,-56.878983,-191.974562,-232.542138,-211.661808,-153.928085,-126.872685,-107.461354,-120.803437,-153.296672,-159.622502,-140.293571,-56.699943,-2.064724,103.525334,148.340695,183.108123,140.222216,-23.178602,-40.832049,18.058697,136.470296,155.780232,137.536561,134.769652,108.503879,60.699507,9.174297,96.653412,139.840343,181.208301,175.316097,79.330587,5.026295,-105.765821,-101.480444,-75.470414,-29.227994,-3.292799,34.517276,8.366553,-163.874345,-258.571234,-331.340582,-281.401858,-252.748623,-232.346644,-235.868345,-235.321652,-240.115859,-285.041597,-295.315696,-254.452455,-128.748048,-95.129247,-143.333989,-190.589725,-256.203386,-267.961965,-157.645416,77.297817,131.757712,47.562585,-14.196319,-32.06495,-35.466429,-111.083801,-152.585444,-143.084316,-99.094512,-84.094958,-92.402914,-101.692869,-145.064152,-201.285705,-299.212172,-213.945684,-118.364141,34.866915,50.378103,-10.470032,-49.910728,-110.641879,-68.778172,-7.399888,59.327222,34.113187,-94.003558,-146.061596,-138.045644,-115.711128,-93.125901,-28.957408,14.885216,126.94288,187.558292,202.202254,128.667815,-20.201451,30.888735,69.579857,75.794904,74.551294,67.667277,46.7816,-0.748257,-14.388958,10.714069,86.909415,116.207919,143.303504,122.783325,31.780294,1.127869,-37.094014,-68.428598,-47.017559,108.907547,200.822022,217.707204,139.87184,11.783812,-8.736652,-9.530257,31.466115,76.250083,215.719847,258.143016,176.098504,100.366932,56.986527,146.612401,192.902432,232.987781,234.162719,221.12286,200.789371,124.049516,89.87208,106.846387,202.667324,240.861273,294.063915,302.943238,229.391761,172.619947,185.299087,326.698241,353.597961,330.084563,315.612781,240.148166,188.447866,125.429343,104.958178,100.180996,190.948583,254.127326,315.76758,291.360641,165.672619,82.904443,-45.731261,-3.469815,56.537969,149.258399,161.162852,66.90378,-14.319583,-126.193687,-147.826934,-150.825501,-166.826624,-170.126196,-94.798097,-62.603298,-113.53009,-156.064702,-168.424119,-104.744802,-71.593795,21.800769,66.60427,19.925778,-48.60961,-122.162329,-130.072445,-116.48158,-79.313901,-79.944042,-115.18006,-122.5611,-63.62123,-16.216555,29.177994,9.746219,-8.973936,14.490049,60.586461,61.822597,-16.910503,-219.042297,-277.866033,-237.163569,-88.267996,-17.754185,61.280587,25.357374,-140.913303,-187.160646,-159.001665,-112.394762,-123.561519,-141.630955,-97.092387,27.547221,39.892907,-13.603833,-29.062408,-5.276228,29.332298,42.819654,84.749485,114.578234,128.700314,94.176837,22.560409,12.845473,17.921808,71.882261,106.731963,78.704844,21.782839,-62.495653,-64.850451,31.744237,145.501781,155.653238,125.313277,112.041653,87.040925,58.532339,-56.137907,-90.584855,-14.218204,204.894491,265.74397,257.838847,209.673777,35.70216,-36.478651:-144.852633,3.555888,83.796412,70.570515,-4.528283,-169.048401,-218.633593,-245.577035,-229.436857,-203.56793,-140.61613,-116.491004,-96.050052,-83.816096,-7.610773,26.058716,27.635956,48.008156,82.23301,152.831621,177.879048,232.975881,268.698141,268.099978,221.665999,255.314608,351.224953,361.034623,324.222808,272.636453,97.078578,7.795726,-80.807934,-12.234458,44.724788,119.168104,129.041467,66.425685,-4.679866,-167.116077,-247.765874,-234.642159,-177.390998,-156.534315,-128.802643,-112.156327,-96.897948,-137.747989,-247.903853,-138.7811,-30.310309,96.230194,105.633821,113.647259,155.895297,252.882099,172.272835,104.210695,35.552642,22.694463,0.349582,-2.714454,42.392118,82.302032,118.940598,101.791286,99.454824,105.647882,90.943352,26.15711,1.327921,-104.238154,-302.762601,-339.310318,-228.451531,-167.830104,-191.038948,-231.561039,-240.281232,-231.347979,-208.239933,-81.997379,-12.158208,88.974782,134.127806,199.187186,205.397481,149.463205,114.020762,154.561094,254.497337,256.681903,173.314203,128.311447,67.821284,30.597799,-40.745511,-40.530178,-37.256488,-67.124735,-92.64979,-99.608582,-76.034512,-91.644621,-138.623309,-97.808185,26.777235,52.169894,53.473283,44.83155,46.618012,57.80101,16.896427,-60.084886,-59.713505,11.053594,53.157488,130.204907,175.562892,218.687833,84.773895,-3.387474,-54.491633,-16.955547,84.492721,118.626827,110.392382,58.051911,-56.791526,-39.480663,-24.153504,-62.368374,-86.463419,-116.451423,-137.449869,-187.084939,-199.485353,-178.562438,-124.432254,-120.181252,-183.99221,-227.845953,-252.023294,-246.070421,-283.942927,-275.7819,-214.428827,-96.16545,-73.611806,-50.259884,-25.847947,3.403494,-72.578428,-126.102415,-148.767551,-94.123932,31.150574,44.546849,19.038447,6.368898,-7.24645,56.520069,99.618198,149.660274,156.496719,142.517363,122.73263,36.918849,-58.304468,-78.208001,-67.190202,-31.962818,42.068104,28.023934,-102.753521,-177.472898,-227.361781,-165.378036,-147.916843,-97.901056,-60.104722,-72.025603,-131.894374,-273.427201,-330.354122,-308.981196,-219.493363,-195.259363,-237.01669,-266.660888,-240.963885,-204.172389,-211.442978,-303.059826,-317.919081,-264.474052,-252.327407,-305.471636,-324.205975,-325.440532,-314.41261,-280.900253,-153.393128,-83.785854,-73.472018,-151.398711,-254.442196,-212.576435,-51.945003,29.274051,51.445099,124.057551,148.780273,109.130062,72.045453,37.758896,50.198621,46.785238,34.061652,63.395954,143.383642,150.692254,126.915912,114.668968,85.186545,14.166109,-17.287712,-8.387787,-1.334149,-15.671889,-7.506735,-19.319541,-112.059211,-130.143068,-112.884369,-119.099637,-207.664203,-259.202363,-257.769054,-218.448862,-159.02543,-121.250852,-98.239852,-64.009113,-63.04479,-72.290096,-76.863343,-85.157702,-19.904329,43.798661,143.709831,169.644892,177.819077,168.318152,185.125161,205.051508,221.542644,238.067332,240.744029,215.491372,201.513609,176.194044,144.013394,42.773347,33.250975,63.301848,120.349095,166.950438,232.052067,182.351864,20.16949,9.126923,140.266435,252.234793,246.906756,187.625463,166.221005,125.252504,102.504526,66.889413,67.119287,64.800841,51.434469,66.236323,73.973828,39.758798,-4.211037,-3.927768,-26.120161,21.31977,81.111642,157.568787,167.965761,149.703706,122.897923,81.908632,67.246105,58.637806,66.11228,89.564919,127.833295,108.358439,-50.704409,-148.248415,-180.016621,51.551983,156.281045,165.658126,98.244254,-23.940135,-41.772542,-12.662942,16.562597,9.586219,-40.552882,-59.060528,-55.408943,-57.453138,-111.039517,-151.251507,-207.718462,-160.633867,-102.55417,-0.38603,3.6357,-89.49555,-125.988887,-103.485957,-104.565322,-128.190055,-120.121909,-63.029264,93.345342,124.590204,37.307808,-32.555747,-95.392132,-72.108692,-70.999457,-80.229384,-70.260759,-4.47925,50.56224,132.49381,104.155513,64.678493,-21.151852,-48.23998,-80.105183,-101.924198,-136.902309,-133.766311,-88.575563,-65.819926,-59.344831,-2.970514,14.104316,-10.834241,-4.381296,57.202326,40.338642,-3.151778,-78.954427,-94.342309,-112.396687,-113.753964,-77.006975,-51.437818,-49.380008,-131.273996,-158.558994,-90.908108,-20.684813,61.105642,52.354514,-13.075379,-25.818596,-12.604202,25.966887,56.235578,112.46422,124.881524,108.238739,85.323893,90.46169,178.203214,212.161624,229.643517,201.257787,85.156258,35.687257,-22.777043,19.155485,100.470945,257.241904,293.393083,270.725336,212.155988,82.247917,44.980568:-134.324767,-82.491131,-25.964306,47.394388,28.184439,-134.055279,-240.869486,-380.461199,-325.206992,-246.026466,-106.732672,-69.151464,-59.72511,-62.67584,-23.307257,-16.270255,-62.75243,-11.924664,64.229051,204.096065,227.739322,184.71898,151.391592,122.125461,222.92869,303.539314,386.870775,374.785593,292.055211,225.1638,15.986764,-91.008677,-157.268813,-69.451349,-17.4022,86.085289,110.366513,38.356773,-33.511495,-152.259937,-136.951799,-98.29191,-82.712368,-90.651543,-90.008684,-106.305606,-201.71545,-262.142249,-308.890233,-187.112134,-101.134592,29.672255,64.580651,92.631745,97.733739,93.050454,79.923153,79.101054,75.122368,63.795048,-8.587067,-63.808963,-135.274783,-146.710239,-132.019088,-42.1808,-5.422626,14.649691,29.292351,34.244953,-17.695008,-184.208935,-225.410429,-193.301075,-120.108969,-82.155418,-53.959737,-86.358423,-166.981164,-177.698688,-111.05111,57.583714,153.256333,287.441456,302.973868,250.31915,217.216356,148.326362,92.467366,127.329817,278.959146,314.350634,226.842671,148.445125,5.799236,-62.891415,-149.762124,-123.751281,-95.410795,-40.41086,-22.459382,-36.822025,-84.264186,-232.552364,-249.909113,-186.36423,-50.368311,5.354615,90.804372,82.834184,-18.503871,-51.085541,-1.186294,124.77966,163.056427,168.191331,146.665233,83.7263,62.66324,58.697861,46.597731,39.019847,99.830865,168.173307,258.711589,247.55627,142.344668,59.537778,-86.73303,-29.924882,46.210727,99.25299,48.532746,-100.703253,-154.752765,-218.353535,-173.430289,-99.16974,29.321416,59.912591,61.199477,34.75032,-16.348568,-49.570607,-142.335205,-107.35052,-25.597146,142.502622,159.57193,41.184662,-22.457197,-83.141048,-115.412373,-115.570802,-52.90326,-1.298701,26.1919,-26.980068,-153.235105,-163.776567,-80.29052,36.592422,94.14408,199.202095,217.415662,146.475876,92.525338,12.589863,-3.201968,32.677386,157.975488,205.952333,181.391635,126.507475,17.88985,-35.713153,-105.099959,-63.899722,-26.660578,2.934503,-13.56664,-46.937587,-58.816035,-146.515733,-222.613379,-204.469624,-107.400823,-64.738439,-99.235724,-185.351686,-337.979887,-352.024163,-298.226016,-267.33383,-270.633623,-260.114978,-250.15863,-268.842888,-285.092277,-310.0838,-303.704067,-260.777554,-157.905965,-134.21033,-139.214143,-155.623691,-195.11853,-209.859269,-163.332551,-4.067857,65.109,121.536854,109.94127,68.027755,58.231299,-1.101146,-64.772312,-33.154905,104.382148,148.933584,120.363303,73.131446,26.960567,15.388962,-29.997597,-1.630554,32.428555,84.792076,80.769397,-21.154586,-84.777327,-143.188193,-95.620367,-49.60969,-30.051606,-67.465199,-145.807489,-178.44062,-262.894886,-295.705506,-239.393875,-67.857822,-14.999441,16.553078,25.223536,12.374473,-23.283697,-101.783536,-83.30786,-42.628636,47.909037,88.200749,104.173281,78.663431,39.827478,42.915739,110.923496,259.938184,308.747611,250.964452,182.119444,116.913124,103.735737,-17.355453,-100.018374,-58.851317,91.537285,155.447666,163.494468,103.957063,-11.407812,-34.796348,-17.645066,75.142343,133.098717,221.986514,223.916279,140.88419,94.756661,43.168381,46.484611,76.763565,135.618297,130.044014,49.527718,17.757735,21.892676,28.509928,31.43622,94.97911,148.959198,227.385039,227.35637,131.919559,63.584722,-5.837996,79.78754,147.949357,201.340469,174.249825,47.409282,-19.367906,-72.064761,-69.487594,-39.815741,81.266414,151.958189,213.213863,181.221023,22.730461,-58.079486,-129.991286,-36.872881,37.175393,90.193068,56.296305,-38.937925,-69.025481,-120.106218,-162.005732,-220.341802,-163.086769,-117.685982,-48.666543,-48.86416,-139.984395,-193.57474,-227.408487,-155.826978,-112.334369,-46.959063,-19.234396,-8.807317,-33.223971,-74.720715,-83.957174,-104.423706,-82.410469,-48.471671,40.920657,83.775861,114.11179,94.824289,47.031175,76.246135,103.482436,100.762808,72.135283,-13.594843,-77.817969,-203.458145,-230.527675,-215.694535,-124.547005,-53.440505,58.857313,55.1992,-68.081118,-139.838088,-219.954063,-158.296515,-93.269759,-5.237273,7.408494,-13.740202,-33.937091,-57.802517,-72.361217,-95.495322,-31.837858,15.569856,59.805337,24.170109,-105.88325,-127.698399,-88.462222,-108.719533,-114.938407,11.701427,111.113879,135.973519,37.91703,-159.002629,-179.513337,-75.80738,45.431079,83.832933,153.864768,164.271944,46.018093,-59.545687,-180.061764,-26.558052,101.609427,217.975507,182.339302,52.847036,0.469385,-72.738197,-96.686247:-132.475743,-34.092267,-31.268475,-151.680712,-213.739877,-319.164443,-365.958909,-349.555276,-169.12884,-83.953611,10.807837,35.749479,16.897213,-25.627811,-58.560868,-34.830665,9.712579,44.068473,70.246353,151.115041,186.631588,201.556144,214.343847,279.312842,371.147916,417.880474,391.277687,325.863796,260.312459,277.146183,303.809101,277.893959,177.315242,111.344984,94.746788,84.895139,81.934501,56.041635,49.786944,38.370332,-12.482726,-10.727403,91.485829,150.191294,143.136377,78.484982,-47.970837,-93.879097,-141.445239,-0.77578,142.471957,394.495508,438.061832,432.272689,447.680877,469.836403,357.853954,303.586375,304.049805,323.933811,332.825758,336.417421,362.150907,351.734355,237.207615,134.30297,113.342969,107.060104,119.724563,112.842583,59.153287,-114.478368,-209.052678,-203.710962,-187.235354,-191.562008,-229.279372,-274.465476,-335.082988,-313.612423,-202.261558,-90.905756,-54.685577,-12.864957,14.910574,97.024254,121.097322,82.403318,9.974019,12.769116,87.387256,106.826507,40.253171,-4.373951,-1.400397,31.72098,112.546919,186.495486,176.879584,58.105962,3.81754,3.690141,47.409677,118.384405,84.634555,42.614087,0.814672,29.107877,104.030079,95.801668,27.515488,11.156912,14.793447,20.396229,21.461504,49.572339,82.819378,152.932581,167.399468,108.168444,3.610287,-26.001155,-56.811062,-60.852036,-38.422857,-20.193453,-0.639223,-26.397748,-132.801834,-154.194345,-146.185157,-147.761273,-140.605254,-115.44031,-113.624625,-152.23385,-190.427966,-182.656549,-175.739283,-219.230703,-359.447179,-393.943357,-336.747289,-298.379279,-300.018704,-275.573679,-224.654325,-121.704009,-84.101657,-5.260372,33.078637,50.465275,6.766738,-18.612089,-46.900464,-34.664288,3.137809,-3.019812,-73.583221,-121.684049,-172.360984,-105.020558,-63.665877,-40.251434,-40.943529,16.844095,57.310712,-9.637185,-219.374205,-267.992227,-224.467286,-201.390422,-219.777912,-238.868218,-305.685044,-357.436263,-411.352326,-344.943506,-299.499139,-251.773476,-251.173622,-255.964582,-256.675555,-303.943064,-363.767743,-366.723676,-371.175586,-375.066855,-352.560373,-326.23195,-261.194354,-251.459902,-292.364179,-300.159096,-293.82193,-330.833766,-367.946757,-438.346499,-461.984822,-485.839373,-497.485157,-477.084352,-392.030007,-358.922732,-356.510732,-386.380776,-413.693034,-373.112689,-239.373647,-129.080735,-86.261186,-39.970165,-44.432966,-24.262904,40.138101,160.882651,137.683114,101.021523,44.96931,45.384872,93.09076,131.114032,240.569332,278.878921,237.124084,93.193735,36.976782,48.362241,97.305369,151.120027,126.320713,7.19217,-118.205982,-154.738497,-158.695987,-158.083442,-218.296225,-252.632134,-236.239094,-193.471853,-59.935184,82.304987,80.502129,-28.261732,-55.436287,-59.864752,-78.99809,-154.301743,-183.620981,-127.382257,68.95768,137.005083,190.381838,219.803183,281.921996,277.578673,209.961414,170.796736,170.408757,153.783553,139.276109,126.933759,102.46217,-42.044174,-136.475793,-115.539348,-66.616833,-61.128687,-37.0144,-30.644062,-44.526092,-49.239688,-33.272725,48.84823,76.634417,21.546877,-36.047296,-139.329725,-163.730103,-138.103591,-113.343018,-108.917838,-81.878126,-71.082329,-79.239145,-89.126806,-112.989241,-121.482008,-63.671097,50.293182,79.706115,107.330879,117.512276,116.317207,125.597404,155.392862,95.048882,48.934407,-1.698439,2.073023,-4.113035,-51.497246,-173.599006,-203.123161,-152.863379,13.972391,69.811264,86.499657,103.973772,160.305011,141.525027,-6.519431,-60.514281,-4.949307,79.264865,58.919383,7.321411,22.201399,67.009825,39.586826,-75.603266,-40.583303,33.43878,115.913165,77.705326,-79.40727,-116.424537,-62.386314,-18.470152,-23.471984,-3.320485,53.413401,206.904032,241.16793,198.230243,164.280459,106.684829,65.762734,80.869055,200.251086,259.907478,276.161721,259.354532,263.75907,230.89979,189.871784,154.837121,169.851236,184.720638,156.844934,88.814832,77.8873,72.378413,86.519348,107.23565,149.86199,154.922912,137.449552,127.91266,64.926506,3.181855,13.517779,13.845482,-36.942193,-158.559891,-164.276692,-74.070916,-41.676575,-78.084514,-203.546643,-260.066705,-231.114093,-153.113197,-59.097475,-69.88931,-117.649918,-106.547356,-75.391094,10.244472,62.285409,130.56765,125.644536,101.239056,100.397377,113.013453,176.037754,228.750723,311.187427,283.892296,98.098243,12.902008,-65.489484,-47.815535,-5.981457,88.989993,118.294868,109.905072,69.594628,-19.353499,-19.018041:-209.017157,-91.54006,14.927262,93.10974,58.138526,-56.264649,-119.869881,-264.832261,-227.264657,-102.667349,91.276835,97.730827,27.977281,2.12447,21.998384,50.84495,92.690541,163.120308,222.839682,333.000071,350.236206,320.631224,316.008035,319.684689,261.091804,231.120379,193.887474,197.51084,260.87266,283.893559,225.180373,155.284212,94.523345,153.847901,140.102441,37.235927,11.149039,43.135356,72.175687,68.895169,-22.98304,-45.800212,15.880579,66.051263,112.009557,100.941429,27.773244,-30.399383,-116.934462,4.203262,110.11924,235.004029,244.526461,241.122833,250.763267,249.746755,155.116397,112.876924,162.977002,222.17444,226.290279,183.679765,198.823354,239.647691,222.854648,149.606522,123.283664,93.306494,101.400721,146.249624,135.449931,-50.612313,-233.402449,-227.271423,-134.940607,-109.047541,-144.449637,-201.749038,-287.682178,-290.199499,-249.834594,-172.633177,-143.510555,-98.944808,-65.746347,-9.417964,0.487388,-13.498599,-4.595068,24.24188,66.212337,77.318073,95.083345,83.882353,32.958945,24.481796,64.721996,68.145212,46.950036,14.746739,-6.106285,-37.07963,-19.949782,29.345603,4.504291,-34.818956,-65.073414,-15.701571,109.082871,109.988933,35.704968,25.358229,27.375373,-43.468131,-70.665891,-15.91539,38.125034,100.292113,118.567844,130.209649,36.805184,-19.567137,-61.600064,-39.901771,42.337743,61.990218,39.968409,6.515216,-72.312281,-64.790786,-65.082289,-113.601627,-116.948233,-93.756948,-104.443475,-183.801378,-246.723629,-229.334532,-167.695549,-184.445915,-327.051707,-392.868621,-387.747273,-347.39651,-321.670113,-346.429046,-342.322861,-268.147609,-220.266995,-166.204124,-148.244039,-117.272876,-172.521062,-223.300519,-256.623018,-207.374775,-51.706463,-18.82118,-78.603892,-129.166848,-196.165485,-184.238046,-160.183868,-108.31406,-83.832569,-33.316603,-30.169006,-175.320399,-368.582892,-367.949599,-219.18819,-157.796172,-181.099109,-246.157265,-348.404173,-371.46035,-384.707212,-334.205056,-297.131918,-245.566306,-236.335339,-223.10578,-211.592802,-235.562055,-314.126412,-332.834061,-336.181445,-328.267878,-274.783855,-236.536175,-183.082873,-186.332708,-283.93496,-415.836401,-442.874825,-417.880787,-406.446781,-456.913105,-484.846568,-465.767319,-431.214252,-417.425293,-355.960848,-312.43176,-240.008949,-221.966704,-199.696905,-195.074571,-210.485346,-188.496595,-145.391912,-24.069882,17.017685,-10.481374,-41.716685,-31.840535,-40.826697,-92.123541,-151.328579,-115.377739,-9.125906,36.043641,150.123722,192.359293,139.121997,-16.175254,-46.021083,70.449626,155.192087,173.409809,110.011277,-32.301481,-130.773194,-148.622558,-131.848252,-118.148493,-142.704666,-195.324199,-252.264402,-206.263202,-71.945654,-43.040593,-72.647071,-147.924287,-179.735246,-214.064976,-188.296737,-88.958318,-83.566264,-105.534406,-90.738887,-50.096258,44.140706,78.299657,106.310208,104.708499,76.218353,7.131639,-19.009271,46.159577,119.7188,169.989825,114.617377,-60.830692,-102.45848,-35.512789,112.445368,127.065815,112.032553,126.539629,160.598626,155.790882,113.314112,75.998261,69.413574,71.644797,51.152944,-30.912571,-46.760218,-10.047729,23.776976,21.41598,43.723437,92.382079,163.851998,143.455794,29.547269,-26.114628,-82.846137,-42.628021,11.768415,122.016237,138.423838,113.683682,128.274995,200.147853,165.816767,113.447376,30.660253,45.281619,129.987454,103.716205,-72.377136,-123.206599,-56.546788,64.992056,71.99101,29.085798,34.42555,94.272238,107.147789,91.708736,78.479488,48.296608,-47.100277,-53.644711,49.995161,109.543821,134.761128,98.156817,34.726004,124.488343,190.845289,212.119849,167.260146,88.151015,76.446455,65.063218,86.809575,109.85807,120.913282,136.717375,257.683184,307.697752,259.400302,172.382364,-32.866893,-135.786848,-114.458612,70.209499,181.909586,312.956449,334.722646,293.491007,165.496723,116.092423,67.796765,47.694995,-1.281051,-16.240716,-30.504115,-51.219404,-105.516212,-81.455157,-41.462039,42.251116,60.704929,29.500148,20.881832,62.462898,67.167337,43.976301,-17.826315,-42.38217,-40.699594,-18.048641,-9.17199,-41.143257,-135.504779,-214.405202,-214.049223,-66.567402,39.657867,141.642798,130.762718,73.367789,54.765283,75.876035,139.533988,165.704113,203.156671,208.161814,176.048126,149.53518,147.470449,227.629263,264.335435,307.997151,299.399465,177.644053,97.748274,-2.122798,12.00273,56.102049,166.970079,214.17636,256.424783,260.809624,236.360984,180.000597:-153.138314,74.972163,116.496148,7.700798,-76.092825,-214.855878,-253.573991,-259.562064,-217.012774,-181.261417,-136.870317,-144.50998,-166.409452,-161.315647,-113.408927,-84.206756,-38.686132,12.267655,33.767074,86.151387,129.220951,194.846559,218.651642,291.487777,357.476253,392.106168,437.407482,435.223418,420.92938,407.903134,320.310432,238.286807,70.128657,22.794978,47.984162,132.627934,139.53127,23.275671,-50.194028,-92.834443,21.733652,76.964129,50.212448,2.565886,-14.058898,12.111282,14.325295,-37.985893,-165.01745,-96.280643,-9.69255,106.367145,143.063715,245.527751,296.095088,293.597713,213.411513,198.787999,213.756745,213.192238,138.749658,86.95626,88.471868,134.292593,179.158665,144.900852,117.132476,85.832491,102.010459,95.546375,6.241666,-263.83444,-311.738562,-239.266642,-169.751842,-211.71219,-288.467064,-274.717011,-217.058731,-210.594458,-191.988475,-103.688789,-49.127655,74.224115,143.766087,234.138869,226.988856,124.220398,88.867158,119.685419,169.674643,173.021492,112.115404,51.669296,-19.106478,-10.084357,34.794946,81.349066,103.151049,90.342936,51.831196,-14.067533,-22.203971,-50.156782,-81.374569,-51.723313,43.982023,74.966957,72.632011,28.96705,-29.235383,8.649859,83.182518,-39.794198,-105.169237,1.580081,128.302818,178.433022,98.739743,-23.972795,-68.313914,-81.361622,-64.816109,-33.156736,22.463849,23.784129,8.757274,1.340642,-20.349588,1.309113,8.478478,-2.952155,-7.550754,-62.10084,-103.679943,-150.145237,-170.697194,-179.687675,-180.967019,-162.844967,-110.639462,-103.664817,-126.436782,-140.07901,-160.266336,-113.494721,-55.279076,84.175963,136.740174,151.364525,129.156854,75.620891,-18.961004,-59.440151,-7.978625,68.765936,117.888589,71.333563,-10.339183,-28.555886,-57.433038,8.073638,68.896112,149.051031,148.337227,50.232729,-9.311192,-48.158662,-62.735646,-61.553048,24.961492,76.371055,31.430224,-68.060853,-240.764622,-261.461967,-197.080761,-155.408847,-173.508221,-212.892655,-200.644048,-117.035518,-84.746038,-136.49966,-269.390351,-281.447079,-201.12211,-175.315465,-208.378784,-235.309894,-262.979895,-270.01646,-230.538555,-123.172225,-121.192142,-248.123818,-326.145994,-393.436326,-380.203688,-351.257499,-341.086244,-334.244887,-306.263234,-272.576965,-233.703301,-246.568688,-257.723423,-235.990698,-133.619602,26.97555,81.058963,91.177968,84.025928,113.90111,135.407576,114.590248,49.503685,53.891925,136.638448,184.974535,257.853628,286.969861,319.902447,302.804777,214.274773,141.237099,112.328536,73.05256,57.854266,10.508138,-6.138863,-42.725457,-125.524811,-140.96638,-119.597821,-121.747682,-165.014086,-207.521512,-294.351013,-291.135928,-152.630974,1.039768,-1.521633,-106.278303,-125.308869,-66.774559,-32.25371,-77.73092,-196.025672,-155.966708,121.833105,241.80928,269.844673,228.614063,201.348168,212.820774,226.102018,242.481334,250.374267,228.411002,191.200196,87.736078,45.385112,-33.728033,-88.277948,-65.789743,49.760752,106.567511,136.930871,98.04636,7.917869,-0.676168,40.727918,61.604356,41.805357,0.017347,-2.522645,-27.271288,-52.23327,-85.888832,-114.539389,-112.660989,-46.950891,-5.067654,19.379819,6.842158,4.990028,22.233056,60.491883,108.388188,128.157281,151.648909,163.587699,135.76232,80.62442,3.10835,80.325865,117.145544,82.94172,38.009758,-30.239817,-45.105292,-57.462747,-71.465321,-61.149897,63.871347,111.732695,127.764166,108.474957,9.400832,-45.132999,-104.918419,-99.382313,-84.204925,-76.079325,-69.582996,-43.645787,-69.393637,-187.629288,-219.525124,-221.309103,-190.703942,-145.593518,-41.300253,-48.981001,-171.156203,-207.434018,-188.566768,-88.688956,-30.681803,-16.942883,-43.43607,-58.821345,-43.291608,19.255642,43.836022,40.948894,29.43636,35.294259,67.163719,99.859947,181.969809,207.795041,225.918841,199.423637,163.484719,99.139943,83.943406,60.169186,48.15887,50.244877,44.700859,-35.561482,-54.136678,-11.71473,109.548054,145.793832,86.352322,19.566829,-88.064942,-100.116008,-61.197603,-3.072185,-16.777361,-72.604273,-91.440739,-108.339326,-104.047002,-91.400427,-94.934366,-110.267802,-168.606067,-177.584955,-130.727227,-119.703633,-128.976467,-81.95032,-81.128654,-148.583192,-136.391741,25.779464,80.410582,11.138202,-57.470708,-94.194938,21.365217,95.59475,142.185273,86.419517,-36.983309,-29.982837,64.160546,69.531366,38.168744,39.482842,89.621953,114.733092,47.823801,-54.871402,-49.142622:left
-2.550352,28.53365,17.194805,-21.383422,-14.468223,13.700839,6.70094,-33.52284,-91.438819,-138.21529,-235.593976,-264.400103,-212.399577,-123.177332,87.464483,160.27619,193.232181,171.948191,172.021523,104.675322,48.265137,73.219073,168.840312,353.056795,348.683916,325.505195,354.029974,355.390325,218.093651,124.765365,47.004748,51.023923,-21.345274,-190.085369,-226.12524,-112.267165,4.486338,139.110308,126.506707,96.760655,121.120671,120.770316,89.26724,73.442701,83.586129,120.274764,251.565596,310.412449,284.358523,151.694754,124.843692,115.254178,99.488987,87.38257,102.234188,155.483534,212.075195,235.907234,243.636148,214.178723,159.791878,155.531565,127.4045,87.975206,4.251878,-23.229154,-24.09628,-56.673394,-87.965239,-95.51759,-56.624572,46.328445,55.365249,-0.761908,-170.728823,-225.683497,-186.64474,-138.350453,-99.092146,-76.697602,39.708033,105.71004,67.732849,-74.475387,-116.609047,-111.745212,-103.019592,-131.390623,-185.052141,-216.500069,-308.506862,-349.803894,-338.719857,-280.787806,-103.156471,-26.883733,-18.429408,-72.783682,-70.762624,-106.137127,-134.21176,-81.947357,-37.380945,-63.261484,-98.899571,-69.710673,-48.359633,-98.777456,-173.840856,-148.898549,-64.486172,-34.3341,-2.847756,26.795428,29.126569,-55.830191,-89.881435,3.238849,94.591892,178.587805,98.067865,73.242799,69.230187,49.206318,29.906249,54.322415,104.420233,95.091316,-15.414286,-112.163228,-134.489877,-185.349235,-197.587321,-152.278311,-110.668244,-29.030063,22.404791,31.356677,9.266114,-21.467496,-69.255278,-60.769897,30.973912,94.6303,134.076999,48.265422,10.793862,-21.898777,-7.477519,82.41233,120.2611,139.808434,126.417957,125.755213,150.113271,153.176152,100.147431,73.30018,84.778859,93.921532,41.868202,3.059995,37.126458,161.268458,203.631284,172.037975,119.608723,51.200986,23.540712,18.367349,14.155079,-0.761887,-65.394774,-109.348009,-116.962553,-47.457167,81.478458,36.387786,12.397904,54.936148,102.093653,148.299463,130.765871,86.794991,17.947901,-57.383333,-224.972828,-257.349884,-173.502148,-123.283631,-103.836386,-93.735418,-42.289999,-53.296966,-88.188977,-109.16319,-57.875022,52.941165,51.479328,3.751774,-63.388968,-116.990251,-147.686785,-91.902415,81.365603,138.370886,171.433459,185.979915,177.908248,22.342199,-66.993399,-149.275098,-162.759077,-244.454185,-298.156875,-299.565023,-223.968062,-229.252513,-314.397884,-350.044828,-345.649649,-319.461558,-246.341527,-187.616967,-82.350951,-135.141268,-217.491848,-355.538652,-349.876272,-225.310489,-163.02156,-61.722327,43.104001,76.677352,55.047854,11.163425,-30.863665,-8.322496,17.89737,-15.386687,-62.815565,68.086142,102.793683,-50.982529,-128.772832,-114.44547,-99.394519,-118.843547,-77.610533,-54.32609,-55.421974,-78.861227,-134.244528,-128.461223,-42.524765,-8.155595,2.540878,-7.479119,-28.362612,-73.845859,-60.449022,20.931289,65.894439,153.27989,130.892448,58.721293,-97.086087,-129.638342,-52.168307,21.203346,91.84565,96.146665,145.807325,171.26282,118.39148,-36.843736,-47.420261,81.30212,129.261823,100.205751,58.910285,82.195937,121.16181,92.021086,38.420399,65.756368,191.700781,224.343657,142.441782,71.019247,61.947385,-35.52608,-96.84885,-90.014263,-15.657763,139.7896,158.580192,149.299288,120.767587,88.033026,73.002961,107.852469,180.084237,197.269532,158.542534,24.541073,-24.008748,-54.978267,-72.001619,-91.471505,-53.177192,93.099533,184.02167,188.42769,131.106966,97.198868,103.006444,131.959459,184.883266,200.811872,169.505632,86.823078,41.726644,-70.902658,-122.100833,-167.890621,-157.711224,-77.347205,-4.524794,-26.853613,-187.370589,-268.929588,-330.529885,-301.77218,-161.434104,-103.44641,-103.164118,-40.291033,28.427407,-3.570397,-93.72014,-141.265896,-67.947741,71.061726,11.041236,-69.522572,-194.035642,-194.738168,-67.49468,20.472868,180.519148,239.003442,288.495908,259.527136,201.856835,42.90779,-4.46401,-19.683677,-5.765722,40.606292,-5.172123,-58.396139,-137.528735,-172.438035,-213.939779,-172.348735,24.931721,99.156342,84.84517,25.742525,29.281136,6.200809,-65.026503,-239.060881,-255.348516,-138.453698,-151.893486,-229.775263,-306.61354,-281.634558,-174.125432,-121.06427,-38.029037,0.899941,46.088879,87.785215,102.16114,92.444856,102.660139,177.143744,215.6875,249.204106,242.907437,235.624627,157.352666,82.66117,-0.349671,29.047669,145.191889,204.265034:73.331715,107.853749,76.031372,-21.039796,-32.570795,-0.857183,-3.525732,8.325002,90.257922,85.637938,-78.755973,-157.935202,-103.236503,7.377528,222.890737,282.298937,270.77848,184.664301,152.402476,99.94114,99.112826,208.453126,289.668281,390.626613,337.700937,287.884547,301.8793,336.766746,275.936727,221.857376,225.382121,234.866671,134.448136,6.490567,-25.869776,-22.374169,12.916296,74.020533,88.070816,150.517759,229.245672,223.834577,117.705941,57.489735,44.019112,114.145258,325.849654,389.101452,331.259287,195.416051,158.904797,99.691097,62.613105,42.711886,61.152358,102.203209,156.69151,190.813239,183.029107,123.607274,26.755692,41.676204,125.645899,114.678113,-42.559234,-161.32267,-180.252094,-150.764639,-115.093834,-104.528264,-118.853831,-62.447458,-25.041864,-79.13533,-230.765589,-265.458983,-218.988402,-180.190068,-114.489789,-76.350861,-41.401118,-83.24115,-122.592316,-195.023815,-209.125196,-225.816241,-234.466118,-228.324387,-220.225929,-237.34372,-288.205837,-292.426018,-288.69822,-286.356176,-163.746436,-62.788147,7.192385,-41.248498,-51.184202,-70.894865,-74.797451,-27.303672,6.030922,9.894709,-7.664046,0.592724,-47.051699,-115.887165,-165.679067,-91.161171,92.622481,113.648728,43.793832,-39.725991,-92.331695,-173.761737,-143.471869,44.750929,141.016395,257.746552,213.138534,144.260398,35.48094,31.848737,78.606977,63.65594,9.988005,42.816824,91.084054,-64.723496,-159.901768,-234.082438,-202.692068,-92.328228,-56.640133,-41.378795,-22.524834,-11.333833,-61.197671,-114.219702,-131.604803,-86.958919,4.659677,30.430683,-1.63982,-141.312841,-210.798145,-274.465507,-240.98975,-50.492062,52.014089,136.382954,68.78432,16.390854,-69.579006,-86.302598,-57.081475,-16.246431,96.318902,131.769367,99.825171,52.190706,45.110166,85.464963,138.391914,182.657506,145.40611,80.722359,34.052672,-27.542871,-187.17637,-226.106541,-135.666454,-55.095013,38.909956,56.54292,46.227872,-14.728403,-46.831352,-74.368371,-38.991275,90.863401,127.07682,75.20484,-91.420091,-170.423499,-267.63551,-286.642099,-228.346918,-157.300098,-46.47602,-33.632428,-49.103083,-118.172753,-168.924196,-201.756218,-168.37002,-93.297713,-60.179718,18.64151,-51.781532,-132.496019,-185.562833,-145.53431,-41.314546,-5.203718,69.502806,120.143853,151.259975,-3.110206,-113.078746,-306.082287,-383.150258,-468.52444,-453.251855,-386.933394,-411.867499,-424.042351,-392.641276,-373.003614,-338.086861,-303.215978,-208.828423,-183.302992,-193.619022,-213.991587,-248.395909,-373.325932,-398.720753,-296.676113,-225.990079,-163.500154,-121.514875,-93.793834,-106.413163,-135.025417,-102.747316,-39.7456,32.375267,8.064382,-31.422635,65.413328,101.260258,88.824658,74.988569,55.97653,56.276909,74.069202,49.973878,56.823742,125.743129,133.420814,62.491087,37.51861,127.92179,207.217389,212.798702,42.644625,-9.248022,32.734418,93.205726,149.378641,144.325235,176.355835,231.067071,220.849597,119.104186,48.73311,-23.525058,19.417189,190.089069,239.501195,226.569278,223.848384,222.937271,121.387396,67.416496,106.753248,146.660739,98.074566,3.903746,4.97792,82.904235,125.938349,192.721211,215.068301,230.469449,216.658086,147.46342,131.375036,126.702408,44.897586,10.661459,62.156509,131.651027,241.436273,202.597539,146.246617,92.448287,133.946974,276.036781,318.448008,308.091489,276.169555,208.803139,102.960289,32.410269,-43.408863,-23.852192,83.911521,146.40201,256.844355,341.731385,361.991867,304.584951,253.970381,262.756505,318.297771,389.740682,385.996192,337.235007,236.435507,159.989016,-15.956333,-83.288747,-83.440969,-16.809639,128.038149,118.318202,26.998559,-214.014757,-271.79171,-206.467902,-144.767286,-75.654329,-76.365478,-101.293969,-63.159975,-39.469849,-35.016678,-57.229045,-107.043118,-89.626748,46.805985,106.724058,58.325461,-88.099436,-121.458992,-80.796112,-35.182779,106.56748,186.602616,270.629682,243.986839,187.763176,48.019033,25.943612,61.433921,62.926181,16.249109,-78.026008,-132.259477,-180.745002,-176.951312,-185.288584,-175.587652,-75.972024,-47.556963,-96.483131,-95.319609,-85.722624,-173.29011,-237.442059,-287.322227,-280.663654,-221.088439,-203.597681,-236.254905,-235.960557,-190.320161,-127.579202,-117.319916,-47.44556,14.74412,90.488929,71.20524,46.156219,36.140106,78.72843,209.19076,248.769026,214.647015,142.02434,138.111749,130.216308,122.189607,172.671185,215.691928,219.971109,193.906059:152.961304,100.651614,69.834717,73.979721,103.465279,122.923521,105.284088,75.489041,23.314214,-41.049558,-188.755085,-208.659615,-55.360651,76.276756,265.24053,270.812747,173.757083,173.988032,195.019844,158.631317,135.062927,202.44587,281.825553,430.445963,462.629991,387.702253,169.110517,137.084693,253.387262,309.568832,314.011286,285.757339,194.672927,96.189476,51.478656,-12.455129,-6.412463,62.611556,95.833756,162.928865,179.939279,153.352248,105.445841,90.944291,66.550222,99.307197,289.898814,354.843903,266.356112,163.103136,165.50244,109.656671,34.421554,-34.995713,8.561765,163.841189,269.531573,273.755013,170.732909,103.193546,26.016193,22.728784,149.426127,224.921114,134.82351,-151.669838,-246.186722,-206.241751,-112.782636,-40.989959,-80.106257,-108.490635,-60.049676,-90.077298,-271.053534,-347.184311,-325.018606,-244.282673,-57.376172,-1.014566,-24.124403,-78.705899,-89.248509,-103.409711,-84.876576,-21.088575,-9.71151,-1.94339,-3.274624,-47.637875,-196.44573,-223.15635,-132.945769,-70.741135,60.903223,126.772475,164.996626,103.964348,78.171919,50.953693,28.248077,-0.666666,38.790563,169.06385,170.721215,115.331415,-61.976904,-133.701852,-47.876945,77.579272,184.451483,142.292867,44.101781,-29.610186,-84.375816,-169.77177,-149.114204,29.177887,137.341233,230.959885,128.42872,71.416744,20.196764,1.7327,-49.763828,-52.295369,34.257073,79.664442,40.587308,-117.416996,-179.542122,-209.702028,-180.567712,-81.075908,-26.245277,33.844801,17.798419,4.47242,-79.464402,-134.337,-124.955413,-83.359681,-26.514814,0.549936,9.038689,-114.672971,-190.686484,-230.792306,-180.024862,-43.448954,-5.632332,-11.953943,-13.509476,-2.299494,-31.296704,-63.509327,-70.949044,-35.969216,59.79033,93.762826,88.31794,44.201898,24.48516,-4.196614,39.907753,253.410478,306.916058,191.830551,8.90232,-71.042169,-161.26104,-151.843653,-53.991932,11.471116,80.855482,76.794828,93.171376,91.812064,38.791697,-12.286942,41.723161,162.281793,184.756543,165.99617,26.668334,-72.119003,-208.971694,-211.339411,-124.410797,-82.643888,-25.558353,-16.1915,-76.901588,-167.057019,-213.704497,-295.742459,-296.576165,-222.614311,-168.876957,-84.627868,-169.184074,-254.509296,-358.593514,-334.941124,-160.13891,-75.742801,-19.067049,-29.405922,-67.355924,-139.337026,-197.053306,-353.300011,-432.038486,-471.033894,-420.572948,-329.588536,-343.914323,-357.813391,-393.273705,-430.229104,-474.772576,-451.375375,-344.134015,-284.294976,-236.844154,-325.168355,-380.561336,-409.36096,-351.217307,-186.903862,-161.739606,-223.222712,-230.90598,-196.898306,-201.730858,-250.006447,-246.897857,-172.276827,-79.497084,-89.521346,-45.628205,82.073014,101.58967,64.949704,61.778054,103.707154,120.086897,92.158465,27.776624,28.015004,110.501053,138.234769,79.472606,50.026651,157.441446,262.667144,346.855577,223.213191,159.266666,112.264722,124.841508,211.726399,268.688691,328.655895,264.607227,205.067707,107.403336,79.77097,95.301249,143.498375,239.588769,241.784159,167.62973,183.459037,213.06101,197.407935,183.468491,190.383069,184.846974,153.560687,139.81798,132.91861,132.592341,152.910569,191.941483,192.894469,208.945426,232.078794,223.727777,150.675545,97.828346,-34.483987,-51.023597,80.373461,167.437429,227.994407,133.331677,73.892222,20.058355,60.885204,273.83458,375.577605,375.912568,290.087471,176.880339,153.822077,104.515076,-13.046992,-25.082042,90.105794,184.323322,266.701322,205.583344,177.611885,109.978934,90.610791,173.757854,237.97516,298.397432,305.317708,308.92073,203.800168,83.235422,-120.015908,-112.619482,48.04157,82.823482,5.860912,23.146596,42.252994,-112.255316,-228.837006,-280.284423,-198.427167,-1.023735,43.340497,16.371414,-69.675928,-111.060333,-99.004634,-38.564203,71.166073,98.444498,150.844842,188.66868,160.924129,69.280044,59.632356,68.984941,61.618166,127.695334,215.636676,362.22546,339.618021,259.206255,52.193776,-19.566347,-45.810796,-10.714217,50.921419,-65.052922,-148.239428,-208.333733,-216.900314,-237.036422,-199.401035,-61.443229,-40.002277,-103.335268,-141.665205,-154.317453,-180.652489,-176.308946,-183.215718,-222.63852,-267.688374,-165.416757,-119.277796,-97.472539,-85.375167,-42.838865,-53.98873,-67.106229,-13.989383,100.257583,118.829897,113.663688,120.445773,151.28107,196.708027,185.249814,166.850968,186.174043,174.333282,86.143473,62.262032,116.504834,143.411263,159.73401,177.655614:104.978305,101.610266,31.168242,-92.387247,-76.381956,36.426253,70.628597,80.035282,50.426887,8.470144,-137.280576,-184.785995,-104.805731,-9.266307,174.037102,236.845961,264.239565,246.16859,230.410232,129.203626,97.355846,196.510291,281.91323,381.748436,335.901465,288.39323,240.08466,222.565475,175.129957,162.561814,124.962252,83.113559,-27.789629,-94.132922,-104.657157,-116.581002,-102.085444,-37.87574,0.333158,127.726047,191.67628,153.323053,49.008808,13.12698,9.100128,75.519879,287.60157,346.490897,299.0801,200.119356,170.489089,139.293497,124.657735,83.729289,85.174028,206.26263,321.031822,301.433044,194.38462,178.576652,241.304937,271.398246,268.51774,239.815854,129.829038,-30.926378,-110.288776,-165.88921,-131.34226,-64.54269,-58.043231,-7.780099,15.288166,-57.678448,-298.112252,-372.647507,-316.712451,-223.536084,-59.151566,-25.13176,-25.313023,-21.119853,-25.243967,-32.044928,-6.088755,35.776714,10.95511,-52.05293,-53.665449,-70.718863,-210.882376,-286.527579,-263.855531,-183.297393,-28.679865,33.428575,90.200816,12.51789,-28.392399,-53.03657,-52.274175,-12.910323,32.85319,86.97345,53.660373,43.556868,12.662584,-19.432759,-31.189665,-17.051875,-35.606389,-44.126804,-9.240314,29.685827,26.35833,-23.329118,-28.849694,46.477941,102.756632,171.580712,91.729099,22.602853,-53.62325,-46.680505,22.377271,37.986033,-19.557449,-45.600833,-34.123727,-86.952263,-148.795659,-222.872271,-216.486597,-131.667814,-57.07856,82.075975,80.012917,27.014607,-111.654407,-153.96124,-120.017281,-67.76239,61.05691,123.1836,148.541171,73.93791,38.652981,-34.589365,-58.054962,7.110646,76.396552,143.361654,92.705284,62.141039,45.092108,43.029773,-13.460612,-51.59479,-28.317761,34.553587,111.835075,110.975083,100.262794,30.903045,17.809032,105.644887,148.899954,113.932736,-17.156191,-60.384587,-53.889658,-27.354063,21.772826,29.979174,38.262942,76.237989,158.880512,64.780567,-8.872797,-17.489245,55.44825,174.825654,176.698002,140.62617,40.907654,-53.106578,-195.396034,-201.808803,-146.262729,-113.37017,-37.07545,-3.337352,-19.004159,-123.809298,-168.823112,-197.221225,-173.694764,-96.263692,-65.221109,-58.196149,-159.098621,-202.035417,-197.844821,-173.884965,-101.850873,-56.954148,29.618412,65.764659,78.055108,-27.376253,-109.486224,-244.277575,-268.062916,-257.416142,-244.613867,-214.303116,-226.845582,-253.828028,-324.485512,-356.897104,-359.3248,-320.873974,-203.949056,-153.66423,-139.393963,-206.935704,-235.96393,-289.028025,-314.820833,-295.987275,-246.049662,-155.284237,-115.710998,-88.23111,-31.54381,-21.587926,-3.753154,16.580101,22.530459,5.669464,42.161073,160.873276,158.931213,-6.94301,-68.463318,-2.776056,63.508097,74.887952,-17.787257,-26.997423,25.427219,43.313233,18.548446,1.593702,51.12091,94.335718,73.675441,7.527282,14.866423,62.986175,70.142289,60.078221,90.130033,240.386203,284.95595,223.713009,45.411678,-26.496516,-79.474687,-36.583226,135.467816,179.974964,103.352072,76.138032,93.67633,20.022518,-24.302225,49.500435,128.00377,191.433635,123.246186,88.793751,88.086836,100.428364,109.478905,125.285216,193.378751,207.950507,140.638332,58.802368,20.903956,-56.988904,-62.806147,4.242143,57.298651,165.519737,169.544417,126.478289,63.736783,80.380517,195.003828,244.289006,203.182823,140.206141,119.114432,126.84253,50.958667,-132.58949,-165.224419,-128.293812,-91.140345,-29.326331,3.280518,28.134034,38.296928,14.478183,31.179813,69.430454,85.279035,63.023512,36.247049,2.742035,-54.193527,-212.236785,-254.748929,-201.284916,-160.135308,-160.645677,-160.37235,-155.851017,-220.515154,-265.904732,-291.850598,-265.59029,-149.059692,-92.716619,-102.064874,-144.386312,-110.749636,-39.304805,-57.440952,-141.226509,-144.788802,-49.67999,35.718021,33.73199,-31.544356,-49.491254,-18.89463,-0.20807,74.053888,139.697947,225.76226,192.636269,130.431753,-14.826817,-49.966833,-38.094176,-13.537,47.180651,0.995697,-80.353878,-189.503957,-171.666744,-83.651266,-60.666064,-59.260684,-64.546376,-65.281416,-12.408258,23.859303,-21.190007,-103.628938,-191.720004,-165.821297,-104.20888,-125.00254,-142.893458,-142.060218,-136.459911,-122.673414,-101.769176,4.394664,78.895441,138.760141,113.043495,111.731997,77.584388,56.237903,108.698177,170.740149,242.898978,213.669563,197.320143,143.702057,105.52672,118.943487,174.160846,284.514297,319.807012:158.999337,121.641915,77.430754,-20.607567,-24.099833,23.980817,50.802505,112.965815,74.810066,-4.170955,-167.433639,-175.440829,7.124209,128.89967,294.675086,333.059734,319.889027,224.32153,160.812943,41.372478,31.36256,175.15835,285.97059,410.223705,328.975293,247.20858,72.392467,16.067181,72.597296,155.467429,247.419763,222.96484,81.115744,-73.13007,-130.981806,-145.787089,-97.410782,11.518496,46.631474,98.893115,76.255012,31.543921,-43.541826,-43.92004,41.51499,126.680268,329.759199,388.588609,330.856082,190.412432,156.693498,117.770963,91.252396,73.629725,104.829011,228.444007,282.924236,262.712066,194.494316,174.590518,194.547297,225.187567,299.67135,310.266881,173.331923,-61.286621,-148.355916,-182.949463,-120.187015,37.528908,72.08699,48.481513,-34.981229,-94.94968,-234.871216,-271.43919,-187.789456,-91.79449,69.766025,101.93719,90.962777,51.728568,20.923939,-16.37419,24.250004,143.242974,151.98093,131.613174,121.424182,62.928878,-154.22828,-230.810557,-184.54384,-96.824845,84.602101,149.299155,153.361483,87.83234,77.324099,22.059522,-34.37086,-49.547872,25.498964,146.970901,84.745823,41.023317,-46.65815,-84.782254,-33.650172,25.067229,15.139434,-33.597169,-74.6497,-72.840675,-93.870089,-169.35188,-185.136767,-85.148742,23.305242,139.872999,-70.688083,-191.62348,-210.527631,-149.317062,-91.591724,-92.966713,-25.18084,27.14803,-10.143236,-181.126526,-230.737189,-193.558141,-140.464625,-51.539866,-8.16258,77.541008,106.721208,81.219126,-66.10408,-135.45698,-113.542312,-42.688714,93.890266,148.360934,197.485129,85.366638,6.687145,-58.06854,-40.816222,39.992979,94.475599,146.483722,54.25567,9.253135,-14.574895,-11.390329,-22.768197,-40.454955,-13.251002,46.790872,127.967856,103.503679,77.037349,38.331737,55.701609,184.491352,256.011395,295.591735,154.26695,33.544308,-145.219568,-137.498654,-0.14642,45.22258,81.293201,121.852393,204.189743,93.847962,-22.909284,-121.361322,-50.332465,143.852274,189.729782,183.639494,126.372827,93.083977,27.563526,1.336637,-42.95445,-57.920342,-20.871762,11.155517,-5.895214,-113.686127,-161.299392,-158.274545,-126.190111,-105.079648,-87.96252,22.666104,9.139877,-84.490623,-277.736416,-302.058695,-181.011431,-88.361986,59.74734,97.396173,62.818129,-55.417878,-110.875966,-175.374344,-167.856998,-78.145013,-26.219775,-5.291747,-89.847058,-145.613073,-286.214462,-344.79409,-337.139996,-287.862047,-210.346275,-188.871396,-187.448603,-271.353752,-318.864438,-348.691083,-316.674133,-210.814475,-164.354996,-78.939206,-64.604746,-89.508808,-123.89027,-111.674644,-21.496026,30.517504,68.297788,52.757786,42.346579,93.190362,98.956581,64.514704,48.263098,58.346258,89.494236,118.674508,61.90503,37.513146,-10.525725,-34.489018,10.045566,78.712944,206.950852,229.919822,156.120862,42.884876,10.288119,8.887098,52.007609,171.751069,222.194576,297.325975,266.378817,200.999498,17.798239,-68.966492,-114.914876,-48.814526,181.178852,262.997612,200.837183,11.279527,-48.56104,-79.481872,-59.543311,36.580207,109.842031,209.297252,164.906799,119.472662,36.816289,29.063855,152.580339,254.319105,375.395933,369.182038,307.807698,233.194048,153.141757,9.491912,19.096076,144.216964,202.655665,265.911436,219.451795,150.642097,43.122306,67.628353,255.559792,336.50825,340.210064,298.612855,211.522389,65.901927,-23.229259,-130.048465,-110.819112,45.480379,129.40313,190.418703,111.584588,60.024468,-3.012254,4.534914,63.353487,73.798673,62.202685,72.901485,105.1696,2.370729,-103.83992,-217.433153,-174.19382,-26.44406,-4.97957,-84.539038,-123.352691,-113.384717,-173.610802,-234.921119,-267.830265,-214.76144,-33.552899,31.958143,18.039474,-47.843981,-58.198797,-38.589338,-8.071587,68.447447,112.154349,175.296489,119.029791,62.001452,-53.924433,-86.115696,-49.948796,-8.525766,87.961682,143.015784,203.036815,120.926136,36.589126,-75.520192,-82.549357,-77.097419,-61.912582,-3.311219,-86.368848,-182.389545,-306.36283,-299.290854,-171.909935,-94.716101,-15.204759,-7.087329,-4.082821,-17.921366,-51.004458,-171.320632,-203.608791,-145.508468,-108.890913,-88.388485,-64.890066,-73.638609,-140.664404,-155.057091,-111.668173,-87.917468,-24.549646,32.289554,85.24772,37.642406,13.606435,-54.277989,-75.673266,22.02236,101.938443,153.704646,123.967413,113.531092,44.860246,-3.435996,-8.591217,38.057283,155.204269,202.263988:110.427514,80.810214,39.829001,-0.341286,10.01685,48.046331,43.722177,-9.915501,-66.638242,-101.474109,-183.319085,-204.521138,-132.398961,-42.479352,155.715228,237.918633,339.371682,310.940809,225.53266,-2.185361,-36.975053,129.557548,248.059564,371.528172,266.463593,180.621537,102.568013,107.169768,103.141192,68.002756,-31.914351,-67.875847,-156.833402,-261.468254,-276.690689,-202.345886,-108.240828,62.394734,70.18028,35.328552,73.872303,75.592808,18.058688,-2.386839,63.931707,158.619162,365.866051,406.339562,297.947729,189.539133,205.726345,228.547075,189.474312,132.589938,185.983361,377.365823,441.810493,438.132958,387.190735,338.090095,244.68169,214.293279,204.153595,207.088632,125.88503,-11.521134,-44.492831,-47.054708,-30.215643,25.471576,53.23823,40.573127,-85.983117,-141.357343,-190.866837,-199.062421,-186.308639,-144.341788,39.691436,139.887502,202.351128,123.987754,88.989941,15.31231,-11.366052,12.378801,36.969536,55.693304,29.121013,2.157705,-65.988134,-99.028089,-101.939348,-48.258113,136.829503,207.580362,206.176401,133.167137,101.702456,27.852782,-10.911313,-39.182076,-23.119924,-8.600454,-60.877267,-64.912858,-12.283994,-9.93339,-97.804402,-133.388139,-82.45033,-19.659307,35.877748,-13.839934,-40.374561,-102.3076,-104.231426,22.717606,99.786758,119.794249,-33.553248,-63.812929,50.770673,83.439848,-22.204291,-76.902535,-40.987828,8.08401,26.119182,-16.933333,-40.95132,-77.687735,-59.625628,29.931387,60.183875,79.968208,61.484202,22.862274,-84.675523,-102.292175,0.338348,80.854787,204.397562,258.662441,321.54962,247.063556,197.724693,129.64114,112.061068,153.207291,207.265767,259.386883,176.991777,136.125944,101.290582,91.36068,79.131705,62.469213,37.889233,67.040347,149.769012,185.192557,174.001163,72.519081,34.420371,80.283405,117.844702,111.529938,37.270382,17.916278,63.09681,101.982168,150.178866,157.809407,179.266147,208.233182,225.732389,141.149146,113.220413,140.735028,184.251676,241.476293,228.709986,154.000766,54.666913,8.576823,-23.12332,-6.321013,40.87113,49.247268,48.083503,59.418145,64.818221,5.970098,-26.801561,-74.825542,-67.972857,41.879975,113.070989,146.551333,-47.565756,-160.088264,-204.986144,-126.298834,114.075133,210.426469,271.170583,258.078064,197.610473,123.688025,97.116852,37.651903,5.132945,-34.081611,-45.570422,-48.725235,-45.089815,-55.838049,-107.803577,-153.521645,-212.055348,-194.569566,-94.738929,-38.492578,-6.525241,-84.835334,-117.945863,-166.007767,-185.907124,-152.121826,-86.28719,53.954896,110.05492,106.474044,81.175232,69.216534,32.446798,15.384319,5.762306,7.452523,57.759982,133.306823,107.629201,-84.800223,-157.366272,-105.743246,-47.732703,-49.072433,-143.248324,-177.428774,-201.208995,-200.151719,-196.075972,-195.974301,-196.80927,-192.683758,-174.429069,-158.258468,-133.283558,-74.343735,-75.091283,-80.448697,-26.286354,149.995519,160.507171,69.020995,-129.769407,-161.820642,-90.884412,-33.149962,69.73343,105.866499,81.669956,-72.664344,-158.200579,-244.648084,-189.377417,76.45693,160.043416,111.113435,-2.837632,-34.049977,-47.317261,-25.789214,66.828842,113.132775,162.503281,148.38663,45.982475,-48.490725,-88.666172,-151.77674,-152.573496,-104.884345,-70.708212,26.687444,130.365721,156.163738,118.544527,74.552609,73.971976,130.410154,220.962272,220.972892,148.289923,20.148569,-49.745437,-179.127866,-222.449537,-192.80292,-127.899465,-28.820519,-13.876603,-18.915871,-39.208287,-44.006656,-21.313475,-16.42302,-47.555978,-45.926684,13.285467,-39.554975,-120.724137,-270.66946,-308.884521,-274.539709,-210.837848,-69.852453,8.687588,-14.209628,-193.349239,-285.654285,-312.304596,-242.007595,-91.660203,-71.396966,-84.655472,-2.279179,46.327226,46.122777,12.250644,-35.341326,-37.678843,-17.54809,-8.976598,-34.82508,-119.468569,-130.146241,-58.646588,-9.960523,72.913213,97.918591,70.902983,40.08298,57.110304,63.634602,29.017929,-35.832168,-25.099957,29.213146,-66.034993,-128.45703,-149.644987,-147.452068,-149.70585,-103.347313,75.975591,126.135656,69.055547,45.161285,59.21448,-40.603281,-130.923455,-184.759065,-140.600409,-81.066158,-200.125052,-275.007134,-326.194586,-319.921755,-259.781847,-206.223292,-114.060371,-73.643249,4.677471,7.457279,-36.194655,-104.121405,-56.968567,118.091813,143.938065,52.2659,23.004003,46.512775,27.038219,-8.263759,-7.539961,41.64947,166.793479,202.118416:229.128898,88.984006,1.12794,-79.023385,-55.946706,36.167982,86.067449,121.995414,8.458464,-55.307039,-107.174314,-100.37273,-54.867327,-8.046988,191.041617,307.12342,387.06007,279.225935,208.804794,99.656527,98.620071,206.032343,264.910376,330.007346,297.426487,235.975186,102.171693,53.142751,-12.847024,-16.709212,54.686308,95.667848,37.9531,-172.189869,-240.348111,-232.716848,-189.787403,-79.516989,-3.99743,118.496467,51.508782,-15.449983,-75.194705,-67.040436,-19.015438,27.491639,200.893431,297.053919,361.553007,242.335997,166.61191,68.350902,76.994745,200.775743,264.748169,302.908297,245.479069,225.258746,223.818542,232.590555,295.27762,344.563236,394.973828,373.758348,226.830699,34.300036,-29.334772,-58.627938,-24.164965,77.332734,101.503102,70.82841,-26.306024,-87.686203,-227.138228,-284.201803,-292.177776,-234.318781,-17.125425,88.9141,133.368575,73.697141,60.024447,25.57529,16.294122,61.479597,97.317293,139.334879,85.867516,9.74276,-194.205494,-267.077029,-220.460735,-115.790188,111.59802,191.465769,201.048753,71.069848,18.744629,-18.731416,-10.886785,33.051771,59.329471,72.65172,36.026553,31.807093,15.541563,-32.734713,-115.155366,-83.750695,53.238242,84.123648,10.571285,-88.958142,-113.01388,-124.090735,-93.034085,-2.145115,29.938903,66.245671,-28.944207,-113.697008,-211.370173,-207.896189,-142.204329,-104.400079,-13.553248,31.166254,-7.193406,-149.886629,-172.349704,-84.775939,-3.768023,108.933542,116.567992,120.111645,161.1528,150.247953,-7.094612,-99.605578,-81.968707,29.225251,231.000972,262.172375,223.405931,131.838358,73.037259,-18.885574,-15.476151,102.001603,176.795721,231.11236,152.868529,114.027329,60.031934,23.308923,-47.18452,-42.327914,58.138037,117.196812,161.222904,103.033952,57.442547,-6.110559,9.617779,122.928321,169.831007,180.012985,101.987705,43.567343,-42.554861,-63.640128,-67.627829,-34.554715,91.091906,148.67015,180.357506,103.141244,41.92098,-31.269172,-9.897937,108.629573,175.675855,251.261426,156.750042,70.284278,-39.007065,-33.730775,37.110569,57.973007,72.37408,85.707192,78.726478,9.877135,-26.859166,-67.681015,-52.800363,56.492461,113.894615,123.93225,-15.984354,-87.762321,-150.655293,-141.798186,-61.480339,-1.675922,152.269065,227.365533,237.016877,83.179941,6.039949,-78.506122,-81.214347,-23.980013,30.271597,76.110595,-37.052366,-100.180252,-192.423974,-232.636747,-247.832686,-206.543028,-81.382568,-25.126759,35.509744,-3.247307,-73.459514,-233.992776,-245.866416,-94.956945,0.149768,69.937646,-8.53766,-38.084042,4.157536,54.499797,99.975767,77.160592,31.120803,48.734783,121.131914,72.417451,-12.444663,-150.175153,-128.971235,36.607087,92.897972,58.68515,-86.060647,-145.460587,-189.59417,-177.352217,-116.450029,-106.975364,-159.87963,-179.994904,-187.38483,-197.008435,-192.934696,-185.632898,-169.159876,-49.544413,44.495662,223.108366,234.379556,146.935686,-131.45907,-239.226216,-214.47799,-100.873897,145.841879,207.972644,128.984227,-62.270198,-153.560939,-257.276891,-217.863908,6.827957,116.83988,180.742204,66.015313,9.51087,-39.08484,-33.679864,18.284145,52.782699,151.050074,204.956377,208.404042,31.737229,-67.43341,-160.729935,-139.831412,-0.478744,94.566516,261.847097,238.8374,162.114413,56.600656,70.457796,170.160813,206.481881,225.519529,229.185378,197.329627,81.4309,15.191758,-103.181177,-133.3849,-68.934119,9.718598,99.614949,22.150205,-33.934249,-108.995452,-101.435186,-6.193294,32.179475,66.231029,83.9941,72.427332,-76.100582,-161.806471,-220.657503,-187.473894,-83.776345,-47.752421,-15.844608,-13.169613,-50.585301,-213.296157,-276.853583,-233.101072,-146.706178,30.063466,82.910602,45.215122,-95.351752,-138.995578,-143.878882,-108.933178,7.841278,65.078885,121.883587,64.502124,6.91939,-81.979171,-94.149905,-54.48718,-23.975046,6.409403,0.88026,-11.925368,-1.65316,-32.153712,-156.743336,-183.999172,-100.993576,-32.467441,27.818257,-50.942492,-102.901244,-183.800979,-221.928592,-240.346329,-187.287465,3.483736,83.922636,96.316592,-19.373253,-77.883676,-178.244559,-184.814085,-80.231324,-16.258229,14.917647,-114.629668,-184.749618,-234.641014,-234.381694,-220.963159,-193.243187,-60.36896,23.370185,114.658852,80.448718,16.993378,-122.587512,-129.737358,-8.54778,67.111248,165.201431,123.479547,54.51722,-110.24662,-152.713406,-53.543048,44.014338,191.657544,234.522754:81.039935,21.221389,19.357231,67.602378,88.536132,87.964131,66.936999,34.282918,3.468009,-33.277134,-131.476854,-161.266607,-105.721563,-36.820492,103.858683,174.774619,270.85537,235.456188,206.684526,177.600461,168.389127,158.629527,171.596879,239.673882,194.961448,129.1474,73.592316,78.796862,48.058015,-2.820594,-121.974694,-161.660086,-219.533239,-231.210512,-198.23908,-104.278091,-33.665543,130.921298,165.902834,180.313136,199.804691,174.342708,108.124715,100.459753,106.198574,122.976343,223.465164,276.708553,275.738992,189.500396,167.440445,174.988878,203.16444,289.135034,312.151703,301.019256,324.397662,364.051262,418.269257,388.920307,240.746777,190.44983,195.559732,203.712877,146.063022,64.986422,51.168639,39.399246,30.597722,69.02454,132.643519,219.651443,84.074905,-19.881078,-130.787128,-129.602162,-44.139597,26.490649,141.893913,167.064662,151.437729,93.399801,86.208006,103.909092,106.48042,137.038512,168.252427,182.650405,145.230835,139.119722,142.632403,136.430002,126.72481,147.358298,262.631869,319.298865,305.414413,213.631926,185.2564,107.432994,56.297174,-7.065906,-23.167143,-45.679397,-51.619173,-36.896263,43.00745,62.312321,-15.520209,-54.396384,-30.642444,11.063,92.667862,124.036258,123.356325,104.320631,104.724603,162.578864,189.925889,142.630046,-6.435504,-33.326168,75.99106,123.670982,74.499274,37.28177,87.816501,146.307422,162.595165,138.670464,162.560218,149.035302,98.294183,66.311225,115.100767,210.662259,179.656497,158.423976,170.881471,204.252348,268.575151,265.88312,264.95963,313.252613,425.018094,460.383272,481.092262,509.200221,492.098088,408.033275,366.619432,334.692748,321.128912,301.606749,231.695782,194.891185,180.905917,198.088525,197.268452,175.37117,175.010718,252.313703,270.474716,247.060912,243.813271,270.359376,265.196291,175.172178,59.304099,46.406363,122.628339,152.009923,133.412055,113.835314,110.885232,138.185041,220.90266,248.018589,231.225984,191.654917,192.138195,195.822438,160.243353,77.77046,59.407829,31.045018,-63.033446,-93.060684,-100.177939,-99.31808,-99.094326,-76.643209,-18.791751,-39.734042,-50.19059,29.378599,90.140737,129.247576,117.028764,61.657932,-90.302372,-159.676383,-157.302628,-102.979253,-9.645327,24.323996,131.965129,186.275738,180.4927,73.947875,20.715817,-64.533821,-71.462719,-32.120623,-31.952688,-95.822726,-143.423695,-134.828987,-102.950648,-109.132955,-173.602761,-209.588857,-166.913287,-77.789521,37.606948,-44.346102,-99.711688,-146.987972,-140.50465,-106.130203,-79.781328,17.468258,104.505042,119.226455,114.687893,88.140222,17.22619,10.642665,25.801325,17.001548,2.925884,20.027808,-5.575558,-152.000866,-204.013533,-166.437064,-136.042454,-184.124454,-297.398911,-298.197951,-153.057871,-98.035446,-182.777104,-256.42508,-254.396412,-186.570751,-108.565183,-153.408679,-146.388942,-69.922324,-58.396897,-102.49773,-103.039869,-23.466035,22.388582,10.937173,-77.980271,-152.958842,-271.291477,-276.820305,-206.972441,-155.408919,-59.377854,-80.547811,-148.720444,-249.520633,-227.472909,-117.383272,-97.222415,-143.424604,-195.961551,-203.312677,-213.050832,-222.619732,-204.461357,-177.653995,-123.15766,-99.662983,-120.103062,-251.206902,-304.968893,-338.133709,-337.732883,-307.109155,-246.450225,-40.550311,49.045008,21.064449,-9.875504,26.12622,122.478087,142.877218,138.748403,145.151094,124.692145,-41.256449,-116.981513,-171.052781,-180.848397,-206.188828,-206.104474,-189.189682,-232.668106,-250.084289,-202.312402,-171.397348,-163.100865,-162.120193,-119.11914,-96.130988,-129.581927,-166.236127,-142.875373,-127.34154,-157.924582,-184.223207,-162.12696,-112.938392,-72.768375,-65.064656,-141.331372,-205.132099,-233.254097,-173.596243,-33.36629,-8.257481,4.023988,96.763138,139.364136,128.10275,94.123681,8.816509,-39.553127,-87.737506,-86.53259,-101.852542,-140.521025,-133.154856,-31.368216,29.810747,50.120563,26.044136,29.267899,34.355257,-19.482308,-183.453131,-205.181977,-53.049604,29.983484,27.762404,-88.836242,-117.593195,-93.110039,-65.325274,3.327293,45.950108,131.696994,158.030419,165.247023,196.453119,213.12533,127.454864,33.245049,-80.194988,-66.270613,-15.19401,-103.192858,-171.543632,-232.606186,-222.091669,-162.276173,-128.773595,-77.419643,-49.731052,-4.787992,-35.227448,-44.706581,17.483705,80.228672,169.478286,161.044547,115.539092,96.034175,77.102332,23.552894,5.983409,34.402148,77.544465,148.155426,145.420284:-128.689137,-85.020547,-69.645655,-50.959254,-67.588228,-139.369452,-163.707762,-147.47207,-76.286382,-39.237329,-62.333908,-152.308418,-303.924729,-264.134608,4.574857,125.352514,175.726995,113.796689,107.475636,85.443638,68.962182,120.618516,189.892667,345.511766,335.664438,261.200394,151.316011,119.682246,23.057807,-20.234271,-63.067224,-90.197598,-179.892935,-243.528384,-238.755541,-127.113161,-22.99324,152.351058,169.364605,143.00763,180.728281,195.648343,145.529229,97.586373,61.049791,84.425627,159.074822,179.875386,114.081332,23.502093,34.483258,91.494214,99.852462,67.304611,51.170204,123.288939,246.936473,261.234167,231.801098,219.979266,216.672361,202.994227,88.062517,17.72798,-16.862634,33.956076,34.767113,-20.324369,-39.437077,22.589992,90.437457,133.572864,13.250595,-16.447947,17.249034,24.90877,-11.950168,-39.903322,-45.678522,3.967755,142.095905,185.118948,156.185324,24.153014,-34.56541,-34.875808,8.998356,54.16539,-24.10765,-52.371054,-31.332891,-28.448402,-46.136916,-22.737303,85.817808,128.126251,101.482751,21.012619,16.134152,3.986857,-31.099341,-89.625408,-93.792585,-93.77214,-51.078851,-11.233682,1.879774,-35.045224,-82.563056,-55.08744,54.212317,102.648895,142.388057,112.601258,73.053659,-22.71121,-19.542134,110.751042,168.45258,177.626438,82.46237,42.398658,41.517877,42.911018,29.502182,50.202994,119.002022,121.873068,35.549237,-37.206781,-46.939672,-62.510666,-50.712441,24.169489,54.152486,90.545046,160.054927,183.409511,152.907427,125.993818,126.393298,151.076251,244.506699,321.14923,458.381576,468.39001,457.59252,451.756698,436.108751,351.313329,315.384117,319.764185,280.567711,243.013994,212.071217,192.38706,125.850253,122.146598,197.066326,238.756542,270.64531,284.810363,278.292457,238.89603,245.578402,261.237592,237.425268,202.267214,184.639797,177.682496,188.891237,178.860094,119.486853,99.295384,83.310298,70.36126,40.088279,41.543212,62.165268,145.56088,175.058859,107.840023,36.208829,-30.628935,-11.86944,-24.541032,-142.098204,-212.258034,-256.054986,-231.75334,-175.893944,-155.943235,-118.289458,-83.91993,-68.99096,-13.085499,20.567056,55.499274,60.195707,37.586396,-77.301201,-134.845012,-137.915319,-92.586644,27.268691,70.204717,105.128393,139.82656,225.947748,139.046686,41.287173,-88.713105,-93.578526,-86.490652,-115.039425,-173.872505,-180.377518,-173.025738,-161.750069,-185.826559,-270.057485,-299.3706,-326.477365,-305.612925,-164.615727,-54.293976,-71.253053,-194.048775,-227.398205,-171.076049,-111.173829,-21.931141,-25.876454,-28.366795,-2.446158,-0.054018,11.634058,46.095589,82.789521,37.581156,-99.076304,-115.732758,-111.900905,-195.227571,-243.23877,-255.045919,-243.6057,-236.072432,-211.824978,-198.750046,-192.978743,-187.409588,-135.138983,-98.365552,-84.749484,-103.853388,-95.075746,-67.757417,-92.406826,-155.260984,-151.782451,-104.066335,-75.120535,29.463773,109.564431,86.500241,-77.326975,-175.452185,-275.300564,-252.922631,-109.073279,-34.715921,49.123012,50.628748,6.104661,-126.240433,-135.623399,0.51218,60.094772,28.430682,-66.50376,-58.400779,-2.394405,-13.268041,-25.80079,18.713732,115.946296,103.562149,-29.834927,-135.329022,-175.015309,-251.965092,-253.182198,-143.326621,-79.113756,-28.878389,-29.158289,-17.492356,13.234764,15.961978,24.550414,44.871257,93.898574,101.174558,37.549021,-76.155276,-119.805206,-169.398949,-174.550034,-170.944566,-159.021546,-101.612416,-102.388643,-133.561815,-194.303298,-211.709513,-190.76001,-158.91637,-98.838004,-70.302654,-50.594372,-124.426057,-169.370806,-209.562192,-209.600675,-193.040748,-156.972264,-4.935142,80.855085,31.864014,-179.369418,-271.487809,-308.798847,-275.85818,-230.569435,-206.337736,-90.808981,75.671053,118.815872,4.822225,-92.870841,-124.987504,-77.793701,-14.804795,-64.402987,-124.102641,-183.575795,-157.67678,-69.259702,-37.732064,23.308752,66.453462,116.808406,93.730058,79.118004,29.177813,-7.216778,-40.161541,-24.478668,23.928865,-5.046189,-39.098918,-62.771613,-59.78774,-64.761808,-28.284463,210.907429,318.505199,287.612996,173.508189,156.840376,64.685071,-19.394074,-113.131811,-112.620638,-124.603905,-209.064446,-232.096579,-193.826218,-164.576681,-108.617516,-72.33658,26.209231,80.556988,130.177135,134.608077,150.640093,145.837764,131.300569,209.07261,290.577163,359.871379,274.885867,244.168541,203.864358,149.626851,63.784781,89.150357,187.384909,206.773268:166.124842,202.907081,214.57311,180.413085,116.622943,-35.596169,-56.545819,24.665077,46.852186,10.990819,-71.0894,-111.164638,-129.16915,-65.06291,149.79735,234.529182,293.829076,255.912195,212.932943,140.357902,138.090476,131.590385,104.079691,88.389746,142.367649,148.961091,89.252158,45.153805,14.887005,33.367778,48.692444,16.845647,-113.932155,-202.236179,-198.992867,-157.586617,-134.583718,-47.79284,3.363206,40.524551,-35.706978,-66.878849,-4.921036,51.523837,91.400877,98.314271,190.465147,257.059978,298.840095,218.90272,172.562175,131.121345,166.753093,293.402249,326.836365,308.178126,314.344227,359.342164,411.226025,384.472599,322.511908,313.947328,291.974979,272.292733,210.495409,113.431168,79.858169,76.769629,89.255403,76.034698,50.761792,-5.632917,-62.61113,-81.323569,-132.631962,-187.862884,-235.382492,-175.634931,6.213768,77.326673,166.045589,144.449993,106.039017,35.879948,12.89375,23.486073,51.721998,98.422738,109.010301,94.613524,19.397562,-13.733889,7.599115,49.042427,123.446749,158.42513,210.592291,168.320606,128.549903,47.473429,-10.10887,-92.725843,-77.614795,26.129757,50.152477,27.948554,26.817192,38.51,25.39207,12.90538,8.615644,18.171829,70.788553,112.218875,74.170122,-56.998749,-53.954156,93.120564,145.300772,101.329302,-40.964566,-71.227943,-22.093137,-1.846985,-9.64132,4.666491,70.838269,76.734283,22.010235,-37.882343,-67.981392,-64.89831,5.718989,197.07707,251.273887,266.304514,211.912487,154.302591,37.748399,23.060241,77.65983,129.026261,278.217947,335.58199,300.408779,217.287138,199.795921,152.045683,136.972241,160.013485,178.564523,195.715801,197.563622,189.773252,125.327865,73.281474,37.205713,63.541995,84.200638,76.86101,118.869092,153.871436,131.866274,90.378998,98.987538,127.872564,117.825148,67.269781,-20.20149,-63.929297,-34.9565,17.663677,93.715959,121.640566,141.613244,131.195717,113.680148,89.718298,64.291536,45.331336,77.475703,161.030753,181.440756,178.729623,129.835336,83.620833,-19.446388,-37.670565,22.102418,53.492731,36.604391,14.334276,-13.833995,-50.847401,-62.988426,-69.708618,-65.771106,0.017879,67.917841,158.248814,33.783263,-58.549253,-156.88091,-163.447163,-123.253528,-77.115872,64.613987,129.670181,163.730641,117.38447,75.809512,-2.211013,-4.929954,39.254477,49.557215,11.203391,-15.300454,-14.723563,-69.462112,-116.45888,-101.326125,-34.953456,28.003426,-3.19518,-74.816505,-39.121475,-28.471296,-150.123319,-204.736546,-109.058861,-18.011761,53.768376,45.230679,57.233146,75.304703,57.745409,3.048787,-8.974713,2.688604,22.095812,52.919262,11.946056,-28.303222,-97.272407,-99.542472,-63.52245,-60.840773,-95.986968,-139.892022,-155.914381,-170.070356,-171.878538,-219.510804,-265.882962,-303.969409,-285.685023,-240.275803,-193.330648,-185.906188,-237.772742,-250.232011,-147.051088,-63.35551,40.708957,-16.066913,-98.514581,-286.283279,-332.332413,-250.019786,-168.226937,-62.787015,-52.864131,-105.847229,-238.6004,-318.128815,-378.826552,-325.636026,-117.074568,-16.508292,54.774825,-16.087115,-57.541003,-102.255637,-103.513889,-126.848659,-150.417913,-145.178547,-121.034357,-109.045794,-160.04806,-198.304603,-252.635419,-238.849358,-146.328334,-79.044108,97.132899,165.87074,133.907644,48.368813,42.863501,114.011416,142.62546,166.334439,174.526831,99.006198,-47.68595,-82.123094,-100.115307,-85.409585,-6.1279,5.636573,-83.43186,-144.503617,-127.182859,-79.349793,-76.278463,-112.599454,-125.935079,-75.019388,-27.367402,0.391311,-125.422605,-205.543043,-258.615812,-227.951135,-142.774094,-114.815987,-92.988698,-93.831896,-100.850901,-135.870532,-160.656788,-183.303692,-162.720502,-51.540297,-0.896573,-12.343435,-48.731627,-39.592336,-43.006534,-58.424829,-99.420183,-135.716187,-180.067207,-79.9832,-22.138801,-23.315421,-73.871789,-133.158813,-115.263001,-53.743586,-21.135399,34.960753,3.027457,-62.896748,-179.853037,-151.660537,18.859414,66.534948,28.653051,-100.364425,-149.06504,-127.494806,-89.703154,-46.150121,-24.304625,30.842457,53.727224,101.967175,137.232992,118.353312,5.082805,-48.700397,-54.502993,2.736786,140.38047,70.729319,-35.411314,-139.538231,-105.506486,-27.984322,-31.077739,-51.680638,-19.588158,91.193852,92.092476,53.513083,-8.321746,-14.282644,36.931405,87.998575,156.858094,82.861892,32.395506,14.340707,35.388527,67.312393,73.714813,111.211694,147.98548:left
34.036212,-4.784633,-43.034612,-74.619217,-74.407331,-60.360344,-36.986861,20.940043,-13.814762,-77.036443,-192.356831,-197.333655,-118.588472,-76.633437,-61.740619,-79.851199,-108.026526,-186.487953,-246.201341,-292.473671,-280.124241,-277.607706,-275.775259,-233.9957,-210.8922,-227.830915,-332.973676,-363.153786,-213.555655,-82.570389,27.506095,-23.806857,-189.843847,-286.974073,-302.786847,-247.609926,-199.789645,-157.423288,-141.428533,-41.734413,58.412858,73.816435,76.011923,90.779819,131.717993,141.228276,149.601112,163.09721,226.362062,193.049628,111.793497,0.501763,9.954105,67.520896,85.216444,122.576472,182.210504,196.717526,176.109509,173.298264,221.316205,271.135318,390.790552,397.915526,259.173344,70.90883,-15.090684,-157.603257,-203.811957,-225.538199,-209.350147,-179.916633,-159.502032,-126.695518,4.594184,79.582098,137.702239,120.321112,114.953055,137.175777,155.686547,105.230939,65.320109,-2.6185,-27.632319,-33.156519,6.642279,138.407432,230.952996,218.399839,106.200706,58.131971,9.835511,0.23702,-21.485749,-55.566014,-122.857625,-153.038267,-176.919335,-178.05374,-153.316784,-129.866931,-143.647945,-198.257621,-175.315752,-136.907635,-124.15601,-140.304514,-94.298622,-16.761023,127.624393,145.872297,151.582154,120.639136,37.783967,-137.500089,-154.518054,-48.371023,1.175402,-56.536708,-158.769894,-148.530442,-31.894827,28.403025,73.57898,82.538329,117.600275,107.790187,4.541775,-78.812298,-80.855173,-30.566473,-10.975383,22.817886,64.525103,114.804295,27.727428,-31.143691,-106.720564,-99.064703,-8.776231,42.611933,124.813467,133.611737,80.164835,59.223819,74.130356,77.98758,28.934513,-102.727406,-113.952403,-47.308611,-42.392538,-67.584832,-104.630181,-88.830382,22.600401,84.315662,128.517504,103.810288,22.318682,-75.953224,-133.247326,-166.921804,-121.843645,11.206779,61.335892,93.160596,28.293843,-34.495382,-124.934475,-112.653139,-32.847711,-16.863009,-76.258013,-145.300628,-261.767515,-263.251409,-241.179878,-154.111009,-113.932144,-122.827881,-147.345117,-144.904942,-108.219156,-130.746264,-256.879412,-280.14988,-177.679043,-137.836253,-224.457781,-291.192697,-241.856104,-82.670884,-79.764705,-161.052611,-169.804305,-106.089659,-80.726628,-127.821561,-223.622934,-270.981005,-349.768926,-341.373693,-201.77268,-102.138867,106.334101,182.520127,176.875658,50.032259,-3.139486,-88.570737,-146.05841,-254.114071,-274.178248,-261.561199,-180.219865,-139.298042,-177.053867,-247.151205,-320.184297,-273.90295,-124.660714,-88.153172,-48.267789,-7.788243,-28.608476,-95.226967,-86.331757,50.642296,129.282978,150.766159,20.503589,-46.314212,-76.945252,-22.713711,113.252583,147.866968,164.09062,147.561215,61.519815,-55.848692,-110.418004,-158.491284,-143.369676,-82.11756,-69.357769,-121.070622,-178.121579,-168.978476,-129.593959,-137.871574,-227.70762,-270.525228,-234.321027,-165.952753,-63.931356,-74.09551,-91.060195,-27.41407,53.508651,147.648297,128.017928,61.189442,109.311753,149.130519,151.8691,134.899252,165.997358,223.54288,336.952628,347.817003,293.535148,225.418354,183.650551,106.441942,110.193554,244.317668,317.325514,365.984054,426.146721,459.405152,396.891508,325.585162,263.164964,284.323324,308.717805,283.874275,206.086433,147.025087,128.918542,147.269857,198.251197,326.15597,353.380401,309.9366,248.995345,226.842723,212.037772,250.960289,357.468945,354.555975,234.948066,169.80572,105.987607,73.549455,47.122163,41.402753,67.643886,114.898498,119.15276,91.157672,113.13258,126.237277,102.170004,125.89606,263.257948,314.742594,306.577153,257.387153,167.042028,191.099944,223.08514,282.321872,309.491588,307.314394,288.697122,258.221778,121.63792,-0.677189,-186.59325,-176.272615,-3.486745,71.603652,91.626918,53.522251,-42.674502,-104.676645,-123.433602,-157.361118,-182.733977,-175.070273,-114.634196,-56.985184,-184.158506,-253.854679,-305.033573,-280.453419,-226.328361,-226.397689,-240.072616,-240.05287,-242.890163,-315.892985,-375.825197,-405.516905,-345.794823,-181.203638,-139.822051,-168.040764,-211.314231,-222.433947,-265.163725,-287.154638,-296.922304,-270.732146,-167.873918,-140.093416,-175.738703,-212.360379,-211.616942,-175.357297,-153.966931,-123.104416,-95.347825,-19.753665,-22.788288,-90.372436,-272.709214,-311.600823,-237.206754,-162.100881,-24.422836,21.561813,70.398294,60.253489,46.361361,22.487926,-5.598897,-69.507542,-61.772124,5.582081,-59.191224,-167.549045,-354.874229,-351.392345,-165.1565,-44.777801,98.613981,100.948127:89.869581,-7.234356,-66.044201,-110.329666,-97.669478,-13.832714,41.907252,84.296883,46.343074,9.629703,-87.142799,-109.966693,-92.245508,-80.144947,-40.784107,-15.874485,-23.231136,-111.289297,-153.742408,-177.745384,-142.302041,-4.47258,51.837811,19.927385,-163.274507,-221.703384,-197.139816,-148.433797,-70.154907,-48.972911,-71.567809,-129.188236,-262.133728,-306.393936,-275.190198,-135.16371,-85.201113,-87.337965,-94.039476,-19.434371,126.389848,163.01041,121.87493,104.93167,179.432499,230.665655,234.495103,189.84791,95.338719,4.507132,-42.997102,-55.344828,-15.184637,74.855278,101.896397,106.745877,81.518637,75.757934,107.217217,148.134558,231.207976,272.360821,337.04848,336.568401,281.09841,149.721192,61.524946,-60.884843,-83.694188,-94.765417,-93.640238,-61.464381,-12.038403,-9.294782,7.935555,47.866605,121.108282,161.164679,279.874003,295.507688,178.591065,24.292684,-17.923336,-43.852822,-55.313583,-38.901461,17.000017,159.003904,210.168455,183.352187,55.955235,5.999452,13.561373,54.442026,120.436582,106.604051,2.873896,-105.992212,-146.433346,-183.053377,-184.165338,-126.42278,-93.863283,-156.193763,-257.204846,-256.126374,-185.950222,-144.119329,-95.741977,-64.622008,66.561612,114.115381,76.328922,-59.752682,-134.34772,-199.508562,-164.496529,-42.75269,-22.139707,-112.043936,-141.222193,-86.071778,35.247592,66.206338,120.405835,184.817699,329.074744,336.385152,194.223188,-7.005371,-73.737837,-99.968558,-73.373656,45.078295,104.413399,52.65559,-190.259648,-267.427511,-206.821696,-137.779787,-129.42519,-158.461693,-87.077951,-8.573815,4.249086,-138.968258,-160.063978,-92.77025,-71.04496,-96.574045,-123.560715,-200.474343,-282.677664,-308.631688,-292.459631,-240.408624,-92.611169,-22.264224,59.544721,60.781493,7.492968,-107.60761,-151.460349,-98.355215,-9.99797,168.562551,206.541016,173.667231,101.567167,41.340032,-96.089226,-114.958201,-48.935575,-10.69644,14.629351,-11.671676,-143.233887,-251.368378,-269.632642,-235.913957,-192.808584,-165.861692,-197.850208,-219.081806,-182.086805,-214.33645,-359.796043,-395.279449,-316.668204,-250.077524,-200.919689,-216.090922,-213.48303,-193.156065,-193.52712,-186.723452,-190.520976,-201.501237,-204.598744,-255.581962,-386.739202,-461.842111,-514.276496,-463.823118,-257.635529,-132.059482,46.338869,52.654156,-11.134626,-28.960718,-49.862676,-179.379727,-269.52744,-363.970227,-350.486837,-349.763246,-453.359538,-496.82442,-517.622273,-501.441189,-390.541785,-305.274328,-226.092144,-244.899609,-233.251427,-167.559433,-173.971835,-183.694999,-142.498986,-42.355053,-32.375546,-37.744198,-48.346176,-112.548447,-216.398945,-175.43598,-37.024659,-3.607186,28.297828,42.231241,27.933925,-76.811874,-124.651898,-112.607308,-73.287149,-28.007903,-42.270671,-146.971123,-240.191827,-241.386924,-151.328,-87.699679,-33.513605,-46.437216,-45.814222,-25.565092,-58.542327,-149.423895,-131.03337,58.368507,164.64446,237.565346,192.784774,75.40722,100.189625,126.043433,118.768749,128.154478,242.414703,307.101998,338.283424,317.600923,306.278168,277.696454,224.949456,173.767042,204.654153,278.968992,296.027787,314.186799,302.527267,269.652361,230.809704,243.124104,244.895125,220.293427,158.284312,138.260928,146.441181,169.682871,166.810729,178.779368,208.842058,295.564898,332.778362,313.015736,186.82734,136.22958,136.441198,173.63987,225.141804,228.505431,218.064585,202.256254,133.390546,87.914071,123.523103,227.382105,229.472669,180.535441,194.380497,295.218791,295.680655,241.266311,192.326675,248.457569,414.631054,470.049384,491.02475,462.727069,399.747619,380.978604,386.146963,407.037637,393.016911,288.526296,242.176332,202.127831,110.589787,43.125075,-46.83213,-26.054889,114.958499,155.488144,135.396073,120.285181,85.913844,-9.752236,-51.077707,-33.31535,-9.654763,-41.420982,-65.56051,-61.341036,-83.691719,-123.460634,-172.170078,-149.021917,-73.969928,-76.367934,-139.836466,-150.953313,-132.169235,-185.769431,-225.279067,-216.53455,-176.847187,-85.667753,-56.812328,-77.898661,-142.168204,-186.224249,-257.836094,-232.630335,-88.829939,-31.816785,-6.468758,-16.300085,-38.666676,-86.583912,-84.58384,29.490794,89.518331,119.119983,115.8948,106.209588,13.099827,-62.488501,-156.704873,-154.902944,-98.054479,-55.292325,22.15276,44.073161,91.656312,124.891571,93.747343,-24.090508,-49.203192,24.788828,77.044436,66.670969,-27.71249,-65.79621,-111.132162,-104.953511,-12.93614,67.851986,214.996011,233.763093:-102.741423,-99.986833,-118.996578,-119.790043,-100.787046,-50.241013,-29.65333,-11.367188,12.290598,17.444047,21.04957,29.261026,28.413246,25.227476,57.57815,66.449027,-9.337808,-99.205348,-103.778038,-54.102304,-15.808229,32.144845,22.632948,-31.811468,-67.845345,-69.199347,-54.462498,-49.561741,-19.141686,8.731585,7.702945,-33.92815,-156.446686,-218.352455,-193.500445,-144.742603,-155.571883,-149.102629,-102.12152,11.385611,75.917727,80.910292,53.731467,45.150077,69.509389,84.14507,52.812079,27.180642,42.869219,28.06726,-31.069315,-98.886159,-48.113723,127.515623,172.33757,120.926588,30.371164,29.061259,93.628425,125.56898,185.612543,237.375996,340.63114,339.664513,207.863612,38.428926,-8.222031,-11.469047,-10.948533,-76.935377,-113.84687,-97.299295,-20.250887,-5.47455,43.149936,110.147706,249.035433,288.038342,295.212658,249.339419,29.591742,-206.367502,-229.59174,-65.677622,54.386437,201.28888,207.047311,152.167218,62.903768,28.597612,23.76737,40.77196,80.103883,86.091229,37.982371,0.041673,-54.368747,-150.761057,-195.876599,-193.481414,-174.403797,-153.572435,-155.80962,-206.235625,-258.981394,-270.027343,-254.927752,-216.027237,-102.688491,-45.558934,61.692686,84.355134,33.152322,-61.564625,-89.842,-62.06466,-28.61358,-3.094676,-15.92177,-71.228184,-59.781476,-7.592433,85.984395,105.135713,151.271416,196.831446,249.250008,211.582402,70.133153,-26.009147,-61.008126,-98.597598,-92.353864,-56.153009,-38.183133,-42.821843,-157.307955,-229.832902,-259.750327,-219.52476,-190.95219,-214.162394,-201.339823,-151.71497,-107.233036,-217.797689,-264.716233,-241.79335,-199.415519,-194.401242,-254.153511,-359.850449,-348.396623,-346.841409,-388.543108,-404.289612,-310.841042,-193.628764,-37.710487,-60.357003,-167.151306,-210.827455,-210.376432,-116.082947,-26.41638,103.09972,104.762235,50.94479,23.650086,14.05548,16.38733,29.576576,26.683934,6.637867,-13.830846,-10.680388,-65.380529,-229.745957,-304.913559,-347.142792,-293.671246,-147.085764,-141.361396,-222.244934,-210.01605,-210.353752,-357.921049,-449.763269,-436.204643,-323.238016,-113.038486,-95.089986,-188.715061,-265.478541,-254.782723,-177.283962,-158.114938,-195.787255,-233.164514,-289.481204,-328.821403,-375.766695,-438.463411,-411.783739,-276.851317,-168.627326,55.987334,98.203835,40.619027,-38.953075,-59.24955,-80.375084,-86.599992,-129.35392,-199.959972,-396.635482,-444.493077,-419.353607,-438.208673,-473.430626,-395.123096,-264.929022,-78.625444,-83.774037,-109.586807,-35.566237,-7.656303,17.452945,31.5354,74.350997,86.63031,22.692654,-96.16447,-144.565503,-191.766329,-174.431944,-52.328398,34.589722,114.859437,75.30286,-48.790059,-102.060211,-99.493632,-92.607367,-94.673861,-76.267658,-70.139368,-134.003622,-201.948887,-176.634383,-48.595748,15.097304,93.369019,111.944579,145.06985,149.553056,85.948858,19.509703,32.752831,133.098668,201.335077,305.563319,296.749526,211.647642,231.844005,249.922597,258.120422,267.750025,259.85166,244.97219,284.375737,328.045486,305.583207,133.535156,71.812243,68.71501,111.535525,244.843076,284.310339,201.820611,146.194074,200.935859,332.932492,354.50948,277.925751,205.304738,117.300323,127.067258,140.309922,50.345268,25.472728,107.082114,195.099257,373.717935,423.517969,359.532941,161.805889,93.537986,121.304291,183.406412,278.614657,307.689111,299.642325,259.927582,179.125562,137.023191,167.939426,291.741702,310.002355,283.663435,297.523454,366.316573,331.110975,254.742125,135.745254,151.478838,340.281059,474.843804,571.716154,501.064615,373.538158,379.308256,393.580166,434.548042,438.992511,351.848452,276.441941,147.051097,73.542589,24.270405,-82.216155,-68.771273,127.11931,224.303477,244.097179,178.141676,18.373009,-89.298814,-108.617652,-46.185888,-5.252317,-7.053275,-19.844656,11.996226,6.441781,-76.312935,-265.100736,-248.281955,-19.546166,73.645255,60.272879,-8.380199,-115.135205,-177.144895,-197.738432,-171.734551,-132.255185,-6.639454,56.760926,42.795959,-92.463278,-137.009556,-114.49127,-39.887664,103.524283,124.999599,127.412208,122.109853,31.529842,-102.464298,-109.341126,26.23921,116.830496,206.49675,213.934954,179.315519,3.598767,-83.577213,-97.784305,-51.740823,10.335528,10.97698,-29.812703,-38.941403,48.294831,126.86959,109.660658,82.198006,113.012348,154.886082,90.086553,-143.355992,-129.537054,-52.800434,3.283495,6.5787,69.123298,100.501111,92.918582,63.472832:-54.52505,-61.211054,-123.143494,-213.374543,-217.590033,-182.808817,-148.274083,-58.636829,-4.0389,-19.453716,-113.793835,-157.477015,-162.150178,-109.597505,38.880254,74.884614,16.927315,-110.901824,-153.425666,-138.281057,-94.266281,16.148593,58.725981,28.852162,-62.655389,-86.220776,-143.789518,-168.00282,-109.850897,-40.824244,42.320898,42.024721,21.41154,-64.432475,-136.609952,-177.036502,-129.070047,-40.23653,-28.618603,-21.59136,-5.490314,-14.740795,-29.096235,18.42338,210.966079,287.780183,313.889662,304.079333,316.444399,192.385082,68.053178,-71.229336,-55.109486,35.431137,84.38965,143.599066,94.986758,48.453119,11.661607,39.477678,134.04731,196.299653,314.147021,302.187852,113.951367,-45.846434,-79.224114,-129.696953,-168.978526,-231.858323,-223.837573,-162.379461,-154.499361,-147.097859,-32.824617,48.102114,151.637753,190.428664,266.925196,259.72004,161.404418,74.312727,43.095942,54.6428,119.395188,274.24864,290.384697,180.339187,90.20724,75.908824,39.426184,8.301771,-60.829154,-72.837391,-59.332879,-77.744229,-166.95391,-281.673627,-341.41623,-380.18655,-360.22883,-312.926634,-295.138045,-296.582966,-366.74873,-390.66377,-324.486169,-251.138842,-124.922236,-75.804352,39.28216,93.013862,116.912334,29.61968,3.057181,45.328384,74.812699,64.276265,25.983416,-80.762334,-94.726061,-69.456299,-38.989308,-3.343369,123.344822,163.322279,129.819176,82.381766,25.638878,-8.191723,-35.991765,-75.447213,-78.753343,-51.694794,-17.730078,37.782694,-61.678128,-150.662239,-242.700453,-228.06015,-167.356435,-139.598639,-58.437826,-7.052014,80.923357,82.951948,42.152554,-29.365123,-38.985622,-81.571746,-134.073022,-221.435454,-220.940109,-232.348913,-308.690938,-321.984388,-238.056949,-183.557136,-126.048849,-114.241261,-138.656179,-273.830741,-326.496024,-254.316846,-155.260577,5.282053,30.138203,-15.696029,-69.627001,-69.996696,-57.0983,-61.085564,-116.899443,-151.872769,-127.819857,-73.193893,-29.611236,-147.419754,-221.249217,-276.201149,-259.262162,-228.487264,-211.310361,-123.281781,-98.613712,-161.603221,-328.400783,-359.288418,-310.164759,-271.844348,-216.878707,-188.375802,-96.93911,-58.163862,-89.408334,-118.259851,-64.876598,67.26848,67.672812,-31.877018,-103.273843,-165.217283,-290.737137,-265.919458,-59.321932,48.081063,192.642003,230.688658,257.865565,176.977756,92.897195,-35.710924,-45.798616,6.489738,20.914803,-75.125378,-213.391954,-229.607486,-230.057499,-251.698378,-250.497721,-182.863727,-43.160852,-39.659659,-44.689966,60.967863,86.289474,26.264218,0.720804,103.147574,185.302278,200.039812,115.273384,83.930137,21.601654,26.50541,143.355133,194.916016,152.084928,73.258686,-40.867693,-108.616851,-171.015162,-236.488818,-186.092291,-48.880519,-52.238881,-197.795073,-219.797813,-140.332239,25.940994,64.890128,42.70448,-2.460929,-60.512926,-43.55368,3.911414,-23.709793,-16.137476,99.38183,161.8888,215.460578,213.104181,191.503354,198.707792,200.206385,185.658081,178.800571,178.157813,203.753453,314.134175,362.595225,378.097095,290.685341,229.6475,168.257569,178.689164,249.03894,289.76263,335.06159,348.58244,344.957506,316.715675,302.6186,271.308422,252.597886,230.669398,223.321625,145.226715,-28.386085,-83.699619,-18.248128,76.211988,261.361989,319.099074,318.628772,190.578823,108.063021,43.865845,94.066866,208.275205,221.294582,182.304118,136.741572,37.151838,22.815914,54.90557,147.103374,164.97858,128.837242,124.382104,177.101983,182.700065,134.972892,26.715674,36.62239,200.329582,299.648955,383.525244,349.207705,234.283569,193.983325,210.588482,279.30465,311.86547,329.277478,294.965808,184.468132,130.641382,88.682251,-52.896802,-68.308549,71.798426,160.217424,264.018494,255.974912,103.811764,-74.531878,-103.002954,-33.420906,5.057161,11.181244,-4.469735,-44.000787,-80.808449,-119.129759,-231.273261,-257.561761,-223.634277,-197.564502,-169.203049,-171.035792,-233.84008,-362.186837,-406.633503,-372.113222,-306.854651,-189.374903,-187.215294,-276.144126,-276.439718,-271.495847,-341.688387,-348.05431,-215.623816,-123.817303,-23.138253,-42.022104,-179.4331,-276.247343,-265.052474,-137.770068,-64.40305,21.846644,44.157707,39.421229,-51.041256,-106.974781,-178.527698,-183.927828,-113.178458,-30.050543,114.61256,121.894218,79.625073,55.937516,37.080783,6.863234,10.621598,73.384122,104.775092,74.749389,-11.056719,-45.194721,-97.731445,-107.956208,-64.949654,-14.062992,85.824666,103.986593:-245.376037,-187.36413,-177.087935,-141.473213,-113.640906,-103.459793,-117.253255,-93.592679,-10.287092,-3.787,-34.094799,-23.929984,78.350757,145.97216,191.702344,144.493851,-25.878683,-132.580454,-127.982655,-56.681111,-8.608646,114.395644,156.208254,126.361246,77.151823,69.665741,22.515577,-8.916024,24.729102,93.38718,193.771355,179.879929,47.549491,-136.530371,-206.245909,-192.710945,-131.907528,-78.43073,-109.350444,-173.067882,-154.469444,-145.93464,-147.772337,-108.629733,101.917491,206.644341,230.862101,177.144969,119.028381,58.196787,-3.600471,-56.956788,-19.600921,60.1607,52.129087,-13.585163,-104.716738,-162.279345,-149.950006,-55.396683,153.486127,222.964169,276.53416,239.153533,36.461975,-144.436413,-171.160171,-136.200785,-124.590246,-175.723435,-210.26676,-230.233321,-238.873317,-243.140908,-131.704547,-15.302796,143.499855,160.569636,188.364458,203.072649,116.135118,-56.179217,-78.884658,16.082294,104.245446,275.791956,295.935278,183.095103,55.006295,19.117651,-3.638944,6.057637,41.858777,62.740005,41.564023,-25.040218,-169.774865,-247.958001,-278.777557,-310.018547,-299.213365,-262.459332,-283.705528,-414.659793,-498.726469,-509.512593,-439.55031,-348.754564,-156.27088,-74.639616,37.755622,42.793804,14.769829,25.58795,35.939625,67.18883,85.153557,95.906337,78.853575,-2.866905,-96.575557,-108.758465,-46.75353,-10.887762,43.000815,93.179264,157.524025,116.506394,-36.29868,-113.590832,-105.288172,-41.774886,-18.559333,0.316382,5.80893,-34.137422,-180.769963,-258.59912,-322.707489,-314.168258,-264.31774,-204.979087,-64.854201,-26.972181,-17.205127,-104.088254,-135.419934,-68.299073,-21.87856,-80.970035,-181.507519,-314.638828,-275.396966,-278.765728,-352.315941,-352.52949,-207.381775,-110.33142,-25.095194,-52.943991,-172.035008,-296.492274,-315.800727,-155.598418,-27.927116,106.299184,102.551346,36.008785,-47.976868,-69.474062,-52.420431,-30.414587,-11.130751,-16.61332,-4.257757,28.47975,42.772196,-123.348732,-195.534442,-185.83256,-141.48542,-114.048576,-142.24158,-185.193897,-162.80811,-183.264892,-298.211503,-328.29164,-275.68592,-221.158862,-141.164467,-123.751991,-112.177004,-180.978557,-209.528116,-160.669853,-103.89329,-0.438201,21.024533,-17.62149,-153.295799,-236.211718,-239.860658,-131.237085,92.099663,145.475078,196.133569,205.600665,177.818571,101.254502,61.146347,47.835294,91.661551,164.868957,122.680359,-44.127621,-95.838299,-108.108053,-172.395128,-183.774369,-82.831717,9.692419,103.433885,75.133111,50.808263,151.330679,190.643075,178.345055,150.948244,208.479856,274.417701,254.884003,77.176177,6.16776,-56.945828,-41.340278,53.233654,95.32366,87.358231,47.029756,-58.167011,-212.739575,-249.931736,-149.305503,-69.606124,-12.560136,-33.467479,-108.367556,-122.876564,-78.693754,80.418786,157.85593,216.554554,207.050454,195.170251,203.14389,207.707508,141.594202,128.28707,203.001206,256.001934,347.600676,366.542071,288.732214,217.864791,229.808628,285.982116,305.563011,316.153687,330.186237,350.386415,322.325419,236.455081,186.914769,167.817515,154.621291,179.806909,301.390665,354.955311,338.682057,224.826524,174.2628,166.807834,216.919058,291.401595,266.466789,165.198787,145.870896,114.233631,-23.676808,-83.555493,-46.958104,54.672318,276.571531,323.09459,259.904807,116.948146,37.724114,-12.768736,60.951943,283.821527,361.980559,345.202173,250.611054,70.291351,53.711165,88.647333,170.221504,184.011012,153.321129,141.235754,174.505039,212.274512,190.30625,100.131646,91.984853,224.22111,332.511607,427.405924,379.628678,281.831371,282.976044,272.438952,243.23885,261.534498,328.330867,309.927498,165.57016,37.765896,-33.315035,-133.637405,-93.278015,130.51078,258.878385,441.047143,436.547886,203.83942,-104.143761,-184.736225,-128.723627,-44.252793,60.298374,60.84909,17.853217,-67.051781,-146.4808,-278.537874,-266.677453,-124.176128,-50.298686,-5.423167,-50.086126,-179.191391,-219.04465,-198.487549,-138.694964,-136.312975,-146.567728,-127.15315,-116.989552,-183.84743,-218.554643,-256.846552,-228.019525,-67.922156,18.663488,78.104368,21.718572,-165.557059,-247.430519,-228.949191,-87.553343,5.514947,160.161549,213.909438,163.192599,-103.856223,-199.220416,-163.476233,-83.260597,42.573585,78.830997,96.417917,66.96597,-14.652484,-18.010666,15.557292,90.03152,99.215932,47.438798,-3.112076,-117.96559,-147.190338,-128.562501,-81.358114,-50.683437,11.139618,18.360581,-21.004457,-52.96551:-3.550858,-39.763809,-77.341549,-151.575243,-162.124011,-132.935589,-114.980509,-135.093607,-247.976971,-309.796277,-359.623093,-324.955305,-178.873023,-122.469389,-79.700515,-67.405656,-61.970713,-134.58632,-204.307319,-323.621719,-342.738181,-311.601136,-278.802069,-228.310121,-180.866731,-172.426152,-250.54331,-272.189904,-112.817582,26.049442,170.032961,126.779837,-37.278444,-123.10084,-142.846981,-99.304696,-46.002236,-2.737374,-10.282738,5.347681,31.861809,29.930122,54.427522,103.33063,231.488252,300.58549,435.748611,458.607396,392.375023,281.636424,209.02368,93.255106,100.10525,213.526212,264.252753,269.021981,177.840182,140.770878,123.044693,134.547123,191.217371,226.354986,247.259333,207.314359,27.953654,-145.553624,-173.356947,-147.601255,-154.716776,-206.709324,-213.214716,-236.157593,-284.567718,-268.704692,-118.732964,-21.958801,69.864892,47.922046,-15.2102,-6.512719,62.397025,60.1805,38.927267,13.54576,13.217689,78.90293,131.934364,135.931462,53.820199,23.602709,-46.38566,-73.797303,-72.502447,-61.34125,-119.374386,-206.695736,-382.370519,-455.655114,-462.039998,-412.907102,-359.26825,-260.649166,-252.504325,-295.327973,-276.271976,-263.742072,-280.157189,-261.970059,-122.898281,-20.57736,144.981724,147.489398,53.705319,20.133419,9.985625,-33.05045,-34.018169,51.296317,102.462827,81.77683,-55.309722,-87.542251,-35.956048,16.022581,64.901379,67.582799,104.730679,110.715259,23.997565,-90.853343,-103.361305,-22.06972,16.910389,36.908447,62.078809,136.394607,55.416851,-43.687938,-159.976841,-125.175079,47.994232,120.724438,157.715094,141.324361,156.14977,201.606276,174.29137,90.120583,80.570912,65.79332,18.018762,-109.04152,-114.89852,-98.635422,-134.291729,-145.866706,-98.819798,-83.728253,-71.76182,-56.032142,-83.309365,-238.551388,-317.33592,-338.984419,-269.009738,-64.400457,8.486493,-21.605272,-166.181758,-188.896684,-132.733886,-97.089392,-88.688416,-112.436917,-124.184349,-106.853782,-92.283941,-113.664235,-130.899455,-127.80294,-103.649772,-89.385731,-90.911333,0.636033,75.080122,12.993806,-172.185039,-186.994627,-75.86643,-38.625476,-86.190541,-137.444676,-161.960476,-77.53345,-45.59489,12.12703,56.718,127.609204,128.445568,99.48214,52.898575,-1.300678,-60.318752,-10.62532,175.634669,249.218408,369.012847,434.930259,460.448349,309.51325,239.332473,182.39354,168.733599,75.233902,-3.166015,-62.182244,106.458773,167.11539,50.601331,-54.225277,-112.694678,-60.912873,39.265788,54.476124,65.374243,2.293073,-64.155134,-77.897087,13.111444,244.297326,303.039249,275.164794,232.757462,203.522004,105.168736,93.263917,178.715137,235.253524,257.091369,196.808353,1.820595,-203.998314,-291.417675,-322.695959,-242.385528,-51.305984,-33.430945,-135.794475,-155.480305,-126.624964,-90.694492,-65.72225,-36.566478,-64.917525,-123.473219,-116.307989,-58.06202,-43.264846,-48.054727,58.285439,140.42576,140.556965,86.059331,76.610906,170.547552,188.889897,176.456153,191.047777,306.259755,382.644118,470.273548,463.730556,413.686594,345.956414,264.857764,91.089052,78.062392,228.989989,324.267123,426.418423,474.479489,467.292915,313.1732,221.190486,217.350494,301.205569,427.812154,389.446703,116.568814,-93.85293,-101.906305,30.864787,147.094305,350.740113,374.551575,270.947002,171.354079,148.522623,133.318618,167.505962,251.953226,224.634019,50.141446,-13.643952,-18.626933,-54.237953,-76.292305,-2.269934,33.695565,18.629412,24.488295,97.706671,68.436778,-23.405373,-205.240444,-202.949599,-12.567948,103.084418,192.33364,123.732142,-119.333557,-135.160282,-35.287723,123.070451,134.245561,114.692629,115.437036,124.87275,52.169005,-49.519509,-282.196636,-311.155951,-133.29492,-25.832536,5.687712,-71.883223,-250.536499,-306.788675,-301.004621,-275.754495,-273.111301,-236.527174,-178.617114,-70.072442,-116.785664,-203.456773,-367.602141,-389.377034,-371.108798,-374.288135,-363.443013,-342.886163,-350.628783,-459.333125,-510.923719,-529.318308,-508.314859,-430.605619,-382.548881,-327.234046,-259.597292,-232.327156,-303.827993,-358.370454,-346.853883,-276.47367,-109.514808,-76.005617,-148.10556,-300.216605,-372.170809,-400.781306,-341.506518,-188.281813,-135.472817,-101.770235,-176.59088,-234.684233,-278.314307,-242.309363,-133.010081,-78.601711,43.816138,86.798273,100.896081,28.542658,-18.992818,-63.91132,-63.675461,-26.715156,-12.339266,-57.516048,-128.19028,-176.428758,-299.135235,-312.450098,-181.076818,-91.528383,26.42323,61.803162:-143.237982,-207.624497,-236.153891,-193.362958,-140.136593,-79.893373,-85.278271,-121.540866,-141.375305,-174.852205,-266.896322,-261.244916,-121.081528,-28.972478,119.141872,136.633148,9.860956,-184.67645,-233.613696,-191.863242,-132.970907,-19.897239,17.996757,17.723332,-15.550577,-21.230298,-54.544508,-71.181922,30.166092,162.575477,353.188479,327.208773,150.848922,27.659152,-9.228763,-47.252809,-49.749962,-43.83619,-25.243499,37.937585,-20.656326,-104.325107,-199.503647,-136.27814,163.609969,305.512197,418.542521,402.394599,342.384786,219.521231,127.41072,21.423595,30.4859,96.477706,114.657555,63.652166,-33.285371,-50.90077,-26.248068,13.700611,153.719616,220.945207,247.086487,204.000533,64.202108,-110.471254,-173.594243,-185.787504,-161.1671,-132.25512,-137.555375,-195.376413,-277.153405,-293.728168,-194.129532,-91.001425,90.190167,148.294298,201.769345,196.504832,134.519554,17.133376,-17.217211,57.49886,148.767195,357.434137,423.706556,334.74318,55.266469,-58.18014,-145.209666,-140.955824,-114.555263,-94.919241,-91.932506,-152.418428,-375.550266,-547.60785,-558.958723,-447.634235,-376.491066,-315.909792,-338.245939,-424.728992,-488.220477,-511.332067,-471.648476,-392.926198,-212.300274,-131.914474,15.903551,66.945606,68.355177,-35.609405,-59.670594,22.275864,93.43369,168.110556,137.430562,-6.054132,-94.435753,-113.52013,-124.703618,-99.712815,13.520151,73.625766,105.339783,72.76492,-41.697256,-184.430022,-194.126884,-34.907622,64.37027,177.583192,187.70647,158.52319,88.570145,1.744843,-211.391496,-243.277459,-93.384788,22.42655,149.955501,152.503058,138.54822,123.45462,118.238184,136.206604,135.830918,78.778688,20.266603,-115.243015,-176.118463,-202.139155,-254.190278,-236.071455,-162.207538,-140.632296,-87.778307,-71.477417,-147.980325,-290.285316,-329.250569,-302.229697,-242.492567,-94.388111,-59.4791,-104.932664,-159.944826,-167.822167,-135.248075,-84.696898,6.27842,15.662976,-13.606077,-30.678258,-45.875435,-69.586452,-99.523082,-139.772316,-115.596339,-4.138701,34.395771,37.500121,-36.481859,-132.227903,-327.073674,-332.450117,-162.832688,-72.189227,-53.456581,-102.730773,-119.662626,-55.922408,-49.053932,-19.622655,24.652155,124.201315,153.808603,132.762575,31.034098,-37.142801,-85.372203,-25.143689,156.53225,222.81463,312.46453,346.715745,330.7184,170.965834,104.674771,139.010203,190.219233,154.772709,78.650709,-23.527719,-13.550039,-18.320863,-48.018834,-31.582632,66.27094,112.18541,131.782182,114.439038,95.146264,65.219277,34.397331,52.456342,118.029563,257.469242,270.069426,171.394834,117.963737,116.939112,64.008751,45.006823,126.932108,188.194646,172.435137,86.916025,-71.828406,-146.373974,-175.171717,-155.234429,-99.855378,-28.473681,-63.535595,-224.289018,-238.991423,-160.165018,-0.225259,37.610023,58.111784,74.950496,142.538747,141.935458,2.396493,-126.392495,-109.346661,69.037414,166.0201,263.500829,260.764916,224.517983,226.129391,206.853815,173.826862,225.203329,389.516806,418.467826,358.522253,324.245504,286.486668,215.029311,178.778515,191.086825,231.976013,330.991013,377.513239,388.095268,327.829802,316.370075,285.04429,257.884807,257.49927,289.590502,319.410277,276.849166,61.483407,-186.966055,-245.592238,-168.834469,-58.579525,178.061224,240.610431,181.007583,32.015556,-39.782551,-95.718273,-28.491265,153.367735,174.514592,104.701925,62.372042,-17.057724,-144.693505,-181.788549,-99.497905,-41.737014,-36.844228,-57.059607,-31.275114,8.017356,-16.390082,-123.72557,-144.87325,-1.352125,145.578813,328.548214,286.215753,75.323678,-38.736339,-19.784222,114.810989,178.933404,222.705266,189.455908,50.754737,-81.79267,-139.221388,-179.06631,-111.703722,146.767791,261.223092,357.965825,315.793351,50.630788,-214.155512,-245.060676,-106.321379,-21.478347,51.523664,58.938832,39.766031,-57.380617,-137.177078,-251.227442,-223.415181,-76.85225,-49.655734,-118.529299,-161.842846,-219.109905,-277.549037,-285.841627,-258.051193,-246.578224,-208.177436,-183.331158,-192.440389,-253.162677,-281.77575,-309.893149,-280.382,-97.033766,11.972694,88.246218,36.065756,-157.716077,-345.606646,-384.118668,-291.731016,-192.862802,14.141578,88.098742,65.03275,-116.73123,-176.341009,-158.454833,-104.876714,10.670809,46.3046,39.731529,30.151903,87.471126,109.62066,76.808012,47.288335,64.098968,85.470392,78.574377,19.209141,-84.764847,-138.444073,-191.176706,-162.473876,-17.334561,48.031356,83.596874,62.000934:188.831909,123.622391,82.002713,-21.052282,-88.571284,-240.145265,-283.065617,-272.291764,-281.538722,-336.575491,-447.748101,-413.563066,-176.166046,-78.95031,-15.452766,-16.171639,-64.356236,-145.041178,-167.223412,-164.316299,-190.407713,-352.817509,-419.942825,-386.248003,-303.683971,-331.577275,-416.219388,-372.57257,-86.081033,71.197855,236.181695,236.478347,173.336094,104.41388,68.608524,38.337038,62.595271,128.683919,123.717508,68.528362,69.986215,82.615245,82.724597,90.108442,137.175517,165.693395,294.53341,380.865045,438.505375,344.499398,291.895659,239.999179,248.835435,316.168906,344.092659,328.970419,262.418538,230.625617,178.765401,159.21235,124.127014,101.591076,62.385512,50.587605,-4.633166,-59.156578,-32.218571,66.467146,72.841773,-3.932247,-46.623958,-105.818965,-91.076864,-38.195084,105.573158,160.453385,152.687526,83.417179,-15.142768,6.140336,62.422256,31.994306,33.53501,42.561249,7.961202,-64.205385,-61.997044,-25.879839,2.269256,12.684407,-10.468019,-38.747539,-100.518792,-135.069848,-204.926606,-249.787765,-376.488055,-516.374398,-554.046885,-470.094464,-370.800833,-235.682795,-228.461223,-207.235413,-97.908699,-78.776366,-130.606834,-126.096283,-41.807616,-5.52574,73.381143,119.236986,198.30702,200.598199,158.734956,140.589643,193.189891,258.640172,230.585374,121.980318,39.573205,6.211644,-87.517706,-141.152628,-212.440942,-208.056286,-143.497288,-129.472323,-134.984226,-84.412189,-71.332974,-91.530199,-83.236785,43.594709,147.412191,271.066042,168.694091,78.79387,-55.016312,-63.201482,95.376462,209.395312,259.712051,192.886143,102.408667,130.467669,141.637106,127.806694,104.355637,37.391256,-4.067255,-85.591725,-76.86559,-46.559515,-23.493268,-24.157155,-63.911605,-106.691291,-140.418798,-123.75056,-103.148166,-182.730125,-239.699799,-241.411661,-190.041324,-94.677132,-51.732437,20.606723,-16.628345,-56.3973,-60.204266,-35.184109,-35.978247,-33.687368,103.479544,191.476836,203.533107,17.374707,-64.848338,-80.307797,-46.037441,13.985568,56.721844,169.633045,213.133545,161.249344,-28.719301,-62.062912,54.519472,108.146652,37.406038,-39.432819,-34.249035,151.719273,199.729471,175.198305,165.568365,209.297331,231.282961,251.13444,264.159115,233.046068,146.120031,164.983375,321.917613,392.497615,477.920671,507.889973,480.295468,292.208674,205.869155,204.435482,244.612489,211.633432,164.765787,169.703342,271.02914,295.390719,170.809396,66.648264,-51.863885,-67.287543,-29.719697,11.387951,56.543741,6.493372,-35.428371,-53.169689,-29.195293,37.246437,77.367939,127.764217,143.850404,128.462985,26.615442,-7.071194,15.906033,52.616709,86.563059,36.629111,-142.418452,-207.81048,-200.950261,-157.497873,-111.190314,-41.725413,-43.910187,-93.402262,-119.507717,-90.462271,9.12611,30.537497,-43.788809,-107.692236,-159.258686,-135.019916,-102.715631,-171.126423,-175.286782,-11.206673,78.120659,63.462002,17.622932,55.034639,159.677022,172.428891,131.546028,113.351231,124.746521,162.063269,306.103105,370.369833,369.694023,228.606281,158.107231,133.089396,156.433277,162.684257,165.363714,231.365842,323.880458,334.477743,194.894691,88.90117,36.755629,118.470128,320.780006,333.878253,161.405024,37.037988,29.150069,45.318615,65.916932,122.134097,144.159838,151.607056,133.684451,112.910732,61.493563,60.23828,94.145067,110.711743,146.657884,146.666363,80.002851,-25.118045,-93.805583,-214.983791,-232.29598,-208.785039,-210.883699,-283.602667,-299.223082,-257.153428,-199.55732,-203.955603,-180.147774,-128.475351,-62.784871,-99.830724,-231.885744,-273.215228,-257.224982,-176.878767,-119.942857,-18.32411,9.851798,-34.158168,-213.929951,-322.646947,-454.466655,-430.320037,-258.43117,-190.952628,-187.143815,-225.481172,-289.988136,-370.718949,-430.116162,-467.0965,-420.34238,-270.97847,-203.543883,-154.590196,-226.16582,-275.516534,-383.636688,-421.198775,-403.418276,-369.137587,-285.026614,-249.210765,-263.674816,-314.070425,-311.01268,-251.087206,-215.951001,-163.058781,-128.407978,-61.71114,-78.969777,-116.129475,-194.955766,-217.015944,-194.847125,-145.897738,-15.752468,23.16216,-24.370881,-158.522784,-183.437483,-94.537537,-23.162355,96.978456,137.052001,99.603955,-47.980005,-102.531501,-190.979118,-225.852111,-190.808739,-109.559045,63.77813,75.910486,-43.408789,-137.461821,-174.942931,-265.012148,-278.21358,-193.99826,-141.072211,-158.720844,-272.716141,-288.232162,-262.390828,-261.225501,-232.213489,-177.048318,-54.036085,-19.031566:-4.85911,-18.701785,-6.346317,60.31265,79.212591,39.184033,-0.833218,-66.029083,-196.791692,-314.850961,-451.77899,-391.179258,-154.634072,-73.304597,-64.828058,-124.169619,-228.992532,-269.879644,-318.473312,-473.08093,-517.125738,-441.331122,-374.094863,-337.476609,-376.071555,-393.418325,-383.024403,-316.517862,-108.173476,-27.783465,16.556633,-21.923749,-127.758427,-168.428746,-165.603471,-71.522576,-0.62444,65.932633,60.411547,66.729566,150.193482,175.481733,126.778888,102.044088,107.545335,117.474797,162.078213,195.494725,257.812338,261.157656,243.169564,246.736762,258.458815,274.816847,282.705413,255.371493,220.951683,212.960341,167.406479,149.743234,195.337885,243.467193,300.794727,289.867381,213.171906,108.789854,38.816135,-120.122292,-193.205976,-271.999216,-254.890986,-192.98518,-210.397099,-196.975553,-67.556159,-6.095914,16.264673,4.369641,47.078153,103.381849,205.277962,201.590915,149.236233,-9.347227,-86.841247,-146.127826,-124.944383,-69.197932,51.625527,111.199633,72.304841,17.454122,-18.066423,-15.787179,-75.046932,-151.780126,-276.52208,-279.199986,-277.491214,-245.842908,-189.309981,-62.117009,-35.331285,-55.693928,-71.408044,-78.877722,-99.774119,-75.607788,28.181818,68.498168,98.914729,96.887232,128.291113,183.49412,171.898865,101.254715,66.666803,55.971792,94.730857,124.899851,-16.070674,-96.403451,-127.976201,-73.840432,8.268786,-4.061685,-41.593067,-41.438533,-41.744227,-83.09709,-123.428532,-145.452844,-109.661181,20.982231,108.809933,239.770767,211.524452,140.53113,-13.733188,-28.804613,102.240016,178.145484,228.307098,216.814178,196.605448,196.90208,179.99501,96.615948,32.767208,-63.272775,-48.025364,18.868398,-2.343854,15.598552,120.867098,143.694838,90.421494,60.093094,85.756641,113.396854,70.332598,-94.976487,-170.507603,-177.285495,-127.10489,-82.108288,-78.024346,-12.328712,3.720807,-49.615859,-114.518103,-83.246756,-30.437396,-31.603824,-2.995084,5.107695,-66.496318,-136.666939,-123.356279,-52.734167,-60.448868,-107.296216,-51.545768,138.924645,96.840893,9.07168,-103.523083,-110.896334,-101.360008,-102.546395,-110.120876,-111.076026,-52.232544,69.928595,83.08125,32.892842,43.56699,136.379343,143.953373,20.078214,-93.628509,-106.169434,-100.506264,-81.696935,46.509077,141.965844,293.475807,335.365941,330.28673,213.939582,151.11942,73.845219,42.752969,-54.564139,-81.580472,13.251253,147.702011,154.186755,7.105688,-120.661318,-282.213123,-235.350825,3.883491,64.942763,-5.387478,-109.137986,-108.814291,-25.990756,9.901168,46.682107,68.813135,145.237405,203.863265,161.771049,-15.46745,-55.707231,26.704095,94.826635,184.489064,175.514197,12.920624,-184.031826,-233.965044,-187.738551,-116.439219,-20.677533,-18.784056,-67.019286,-99.091375,-93.840892,-89.762775,-92.167638,-121.698954,-152.954475,-150.479746,-100.819965,-29.630965,-101.786632,-125.579979,41.022302,169.041546,216.779182,154.346662,97.133102,185.859178,228.544623,229.865503,202.623406,170.130059,187.014881,266.976048,304.707608,371.943499,353.009209,292.656457,237.374416,266.937757,330.114604,328.360867,331.270086,437.932778,459.138782,315.08963,218.800979,212.556446,296.501551,417.643414,389.025472,240.972488,136.589131,99.347849,113.896733,180.347904,295.208781,302.353649,261.703203,275.607127,311.365491,368.580427,396.127498,423.032059,389.543192,304.178399,277.222238,194.938059,78.673092,20.102829,-16.742306,22.268918,71.412428,36.670663,-85.661655,-144.652537,-140.780407,-98.299715,-51.664733,88.052556,150.669262,175.860649,110.975411,-118.807556,-231.956638,-212.38254,-80.457206,0.150205,67.715549,36.808424,-80.868208,-193.590509,-249.241809,-331.781737,-326.708628,-225.884151,-178.207668,-169.04971,-208.513862,-312.572488,-398.227716,-453.462921,-503.141551,-454.054027,-274.290717,-201.320633,-179.190368,-251.357084,-280.002222,-356.604135,-398.065296,-427.577419,-424.441728,-388.235412,-369.027514,-369.870088,-389.342892,-410.264886,-441.598113,-416.167564,-248.897707,-149.889846,-90.796072,-115.648832,-98.992539,-130.19956,-213.8126,-396.221277,-396.576088,-202.734881,-146.462806,-237.934806,-263.404798,-220.984263,-176.009339,-180.471215,-166.970595,-144.850833,-107.261602,-45.678215,-41.351826,-201.443691,-308.699857,-339.847498,-250.554246,-27.074876,38.167473,47.083938,-50.493683,-120.476293,-211.938995,-222.436438,-187.608259,-135.186718,-66.529054,-179.868044,-260.462566,-330.507794,-303.174028,-214.314672,-179.750837,-92.426872,-38.933713:131.611387,2.536339,-86.589839,-162.953699,-157.616348,-197.91894,-237.130505,-244.254879,-240.349646,-287.683965,-391.011693,-357.173469,-125.355701,-18.77734,80.049977,78.553073,26.847188,-58.044166,-130.25394,-264.439772,-293.804535,-273.78929,-223.614446,-98.01223,-88.961321,-144.951872,-264.133881,-248.125202,-18.706821,125.021797,276.186383,263.528537,180.10154,158.768452,157.51952,126.522094,106.572686,106.89609,127.035452,170.559429,168.032347,134.3918,57.859471,60.282319,153.686414,225.356393,402.083704,458.521868,395.535216,277.349849,245.049382,214.51173,226.454252,285.61851,295.705197,236.547895,153.108495,112.545542,31.715939,20.382591,61.284278,75.539009,47.615175,18.92455,-35.387403,-91.576287,-103.638007,-88.10016,-85.812435,-120.253098,-158.860904,-224.633582,-117.773917,-43.422392,-0.115327,1.048172,33.967001,45.779188,34.170252,20.403821,46.4684,114.773228,117.670734,106.647009,116.452868,153.276786,178.37062,176.242311,77.324916,31.854126,-32.356923,-42.270917,-1.184517,18.870397,-55.292163,-140.025075,-256.100339,-396.067133,-490.312469,-495.08242,-411.445037,-316.662295,-327.111689,-325.06855,-245.498643,-228.844194,-244.060503,-216.305088,-80.794252,-29.431167,3.160605,7.896534,36.110169,54.438287,49.377667,62.57721,86.986893,155.839435,167.141108,92.555426,31.010519,4.995323,-60.316235,-67.241711,-33.067259,-14.875335,-13.335688,-34.467007,-77.488152,-82.864456,-66.018402,18.153261,83.459563,218.20763,256.386407,247.155715,186.419274,136.768842,-9.003442,-49.15705,55.230122,163.117724,244.529927,176.96355,104.244182,260.808343,287.457903,168.491601,119.292673,132.186418,139.217044,56.981978,-34.413945,-51.077005,-49.332382,-35.141044,-63.588211,-106.480928,-95.873313,-45.07004,-32.337092,-166.975825,-228.856348,-252.489053,-218.755245,-109.902221,-49.914277,12.887641,-1.03096,-7.16666,-9.013345,-13.181307,-25.751141,-14.195798,42.064839,59.266639,75.582824,63.806034,28.498697,-27.516818,-23.540585,36.384945,71.367637,88.352724,45.419731,0.194755,-98.278558,-111.711361,-20.393231,56.199183,118.950063,77.051048,-20.044427,62.056863,128.679588,167.479747,140.863101,95.77718,111.185646,173.265299,195.859205,175.007321,84.181685,73.233874,183.002825,267.467511,428.998787,485.558129,450.049103,269.098268,204.366797,163.257626,163.322632,162.910782,138.853003,77.202334,172.319527,245.02001,226.385866,139.96927,-15.695207,-48.319875,-18.541578,16.684619,20.820207,-74.243227,-119.445103,-84.38982,-0.610321,139.906686,148.483848,87.918839,100.107714,133.853921,147.040497,134.893759,92.029405,70.269377,80.652256,71.950599,-47.013041,-156.370796,-186.897077,-226.111496,-214.994648,-136.159197,-122.308686,-199.057631,-219.1698,-176.962714,-130.654527,-154.403896,-205.515908,-182.924425,-43.257051,7.329335,-51.379322,-153.242251,-126.518074,39.752559,94.898183,65.121085,23.752062,-4.819962,66.420265,103.224135,101.522814,75.423277,77.113104,136.113102,281.012013,314.474212,313.15307,270.192725,244.494008,207.697323,187.450411,202.941214,250.849184,288.908116,197.753098,148.268083,101.233376,109.839023,177.262392,220.006512,257.969831,218.678352,58.682027,-99.460414,-155.781692,-112.161926,-15.081715,144.441832,171.791016,166.952524,64.576006,-10.896244,-87.363788,-62.362789,24.569701,32.167272,-17.333663,-33.548011,-34.557641,-82.951971,-133.714783,-221.878272,-238.697152,-225.833064,-222.275791,-216.397201,-123.844154,-109.72119,-253.186973,-316.168208,-202.426636,-72.612506,40.297679,-9.67824,-101.928308,-79.023943,-79.646418,-89.37071,-57.487925,30.3913,36.274691,-37.536482,-135.312413,-170.335398,-196.122576,-157.047027,27.9981,108.081955,94.026559,3.394738,-197.029485,-294.994808,-317.178462,-282.984732,-230.621806,-154.049904,-130.838071,-53.226263,-26.300533,-104.76213,-369.431999,-437.493644,-356.704427,-280.246161,-180.271414,-153.085962,-160.002207,-286.708384,-353.430628,-354.168984,-293.430746,-198.494101,-198.993255,-190.803032,-98.508489,-106.321178,-239.876277,-271.314312,-168.339196,-72.417445,44.276382,19.087593,-94.994392,-164.20319,-198.718007,-225.173508,-204.145796,-142.236361,-98.018556,4.570081,-11.445355,-72.612999,-171.431422,-177.953561,-152.984308,-124.899403,-5.152407,48.242047,28.96549,-44.864972,-38.938669,3.029163,-9.322255,-36.93621,-12.100085,-0.040385,-113.956224,-157.279201,-161.850665,-129.491952,-38.415233,-0.033745,68.078824,89.126803:left
-88.526604,-108.792424,-91.273141,-44.110079,-71.277509,-211.071048,-255.880495,-243.545739,-257.430781,-314.406057,-444.879084,-480.544074,-524.849616,-541.591239,-481.644694,-401.852735,-196.467253,-38.32613,-28.524161,-115.60984,-166.544941,-191.624259,-172.87784,-169.479621,-168.021884,-133.311018,-55.325745,-37.695111,-35.579061,-21.523029,54.284134,82.022996,110.04842,171.01515,206.393759,232.040341,201.766909,74.289977,22.833022,13.785588,91.590897,126.206161,105.699745,47.001251,-70.594965,-72.780171,27.437964,90.090194,208.41868,232.602546,206.834624,196.969422,213.619632,202.609103,161.708331,22.898689,-14.343459,36.530043,127.227453,142.983051,114.024823,79.249012,57.675787,69.855954,63.198461,-20.394744,-51.098854,-18.800667,-7.023972,-63.702137,-80.467615,6.576002,182.538185,231.103844,198.023614,151.958988,54.001107,18.606894,37.78365,85.150501,183.229851,126.269268,28.943726,-100.552064,-111.404991,-59.822442,18.869984,194.760071,256.069014,256.531225,256.855318,262.955602,223.265255,167.324719,95.995224,108.066162,174.64718,259.497037,290.725077,254.998454,193.867782,116.378328,134.690166,219.803936,231.749394,196.730261,116.716358,82.925938,-29.258559,-82.47886,-87.772897,-90.968614,-130.609526,4.968539,74.031141,-12.840892,-105.030065,-114.191661,-37.757423,45.378745,-54.848529,-111.804903,-134.89907,-110.319884,-92.296634,-106.922593,-80.716321,-32.403638,8.771141,-55.455923,-68.574356,46.242633,122.371557,131.469362,97.881984,100.028714,188.203512,219.762761,189.730363,145.146541,49.447772,-2.155788,-71.216896,-56.274459,47.238891,126.285476,148.399919,151.791826,133.181231,156.520795,206.376943,271.935056,270.65219,243.092706,94.590748,4.003314,-118.587566,-149.654974,-161.391513,-144.740476,-85.296889,-46.011773,-52.970727,-123.329428,-182.236684,-295.2591,-311.54767,-207.557737,-27.683943,12.425667,-0.709883,-7.384266,-15.289171,-8.997748,74.882822,139.034608,278.386738,405.079143,445.307236,439.816008,383.831613,237.541482,187.765227,168.02011,221.008797,209.825596,98.552179,59.372419,2.857635,-47.021513,-118.711241,-115.173083,-63.040116,47.19388,122.329801,190.276168,162.413296,102.568818,89.142326,35.725992,-14.650565,-7.318223,54.177172,51.848892,-61.998879,-92.107484,-24.133623,19.41484,82.212802,132.190549,144.291093,116.56549,65.607586,-48.804475,-74.066561,-32.618783,43.352896,57.001641,18.09975,-35.032462,-164.661196,-197.593522,-123.22094,-67.79877,-53.95362,-84.672458,-98.18132,-110.105006,-96.484527,-43.743022,-14.848389,18.111158,-31.962132,-81.57362,-131.376251,-114.729981,-70.228083,-66.208009,-89.658332,-101.377699,-73.515749,-19.464867,-51.404305,-166.684099,-191.143061,-267.784851,-332.004974,-337.610857,-165.966456,-99.101491,-50.070452,-41.334404,-41.17701,-40.889466,-37.599569,-50.145235,-69.702366,-74.514725,-83.590142,-64.450202,-45.955198,-94.87155,-171.065138,-291.414584,-219.409087,-179.007687,-221.216433,-269.376882,-345.257764,-355.302308,-297.823694,-252.735606,-162.390388,-125.513949,-133.369672,-100.017528,-67.94058,-42.427944,-40.283508,-37.281968,9.89997,39.706527,54.211047,53.213005,36.258171,23.616742,57.586266,86.322571,82.081035,94.219796,140.302557,204.175073,179.1224,56.307962,-1.119796,-81.223982,-102.842738,-94.953832,-52.712093,-18.637316,-24.389755,-85.779836,-195.202401,-173.799758,-33.259143,-75.896592,-117.647859,-12.938792,45.054998,8.167634,-6.901225,69.570501,136.937725,140.620385,138.710901,138.357666,64.138914,-0.313354,-66.407428,-54.765677,4.992769,12.705843,8.017207,31.231169,27.395479,-17.549748,-17.688618,33.842086,112.572056,147.456239,174.896802,166.755365,67.55631,-12.357585,-73.913651,-19.884379,128.391305,74.921188,-28.127443,-176.547186,-178.433327,-169.835444,-204.528884,-256.127482,-120.815705,-36.617544,-36.83497,-90.716291,-135.040946,-116.266516,-45.147433,-15.887104,37.787897,114.364333,134.621059,55.844183,-40.027995,-160.115888,-139.429718,-65.869785,-88.967757,-119.169613,-138.010607,-101.132665,34.766254,71.112656,18.985395,-12.126729,15.965312,63.701601,79.664324,110.678251,98.54821,74.084434,110.457274,193.494313,167.369325,150.606342,135.531297,103.993626,-32.360252,-109.130899,-182.011234,-140.057347,69.792071,179.528459,156.410613,83.935072,79.539195,121.478232,126.27689,70.597794,75.332065,102.046857,96.702923,78.222061,59.192938,71.778958,144.127407,145.121574:-32.061932,-54.666785,-13.70098,-4.120922,-77.273886,-255.186246,-289.994464,-244.405336,-263.57815,-321.391471,-396.664463,-397.929898,-406.100162,-418.407815,-386.924102,-333.456171,-199.364331,-127.780242,-128.459783,-124.108211,-95.955862,-43.754066,-52.395259,-118.398368,-154.389228,-160.683615,-213.494563,-256.699482,-257.614821,-199.987791,-42.397601,22.762649,70.289737,103.503519,146.751639,161.809981,90.666237,-40.982912,-13.276408,131.414358,123.287882,80.945772,48.725436,45.219369,31.765906,56.118133,138.327183,158.721049,193.824847,160.772363,122.022848,146.233343,176.093322,126.471688,88.204427,104.27849,179.174232,198.619583,115.687513,26.921525,-77.12764,-61.095699,38.629834,89.274442,105.394523,6.468868,-30.1854,-30.741441,-36.628189,-88.216697,-80.023686,86.017434,365.087655,423.302653,220.219249,57.34557,-118.513582,-103.725432,89.014048,179.13963,190.138878,89.651891,36.979832,-52.878494,-100.705557,-105.686754,-21.374264,156.839728,162.998728,151.254961,145.866659,92.976058,-102.011834,-143.979615,-38.09011,29.983293,60.263829,32.699253,36.793542,29.027525,-9.036421,-40.599189,10.000846,152.40836,192.310574,151.710667,49.969978,26.742955,-39.46622,-81.976653,-75.049357,-59.783074,-89.188822,-66.998838,-52.001542,-120.945895,-168.584457,-139.629419,-82.444796,-13.7541,-28.773506,-70.387707,-155.537246,-147.078075,-47.906676,-23.036911,-54.117842,-41.75381,75.039126,88.852874,25.195775,-48.858609,-6.354887,119.800889,150.133383,176.111853,237.524698,259.573735,240.646125,209.357183,149.887851,131.384939,157.469031,210.287089,278.480195,214.142764,184.088173,199.13645,214.508508,209.621701,210.93057,268.991901,323.700265,299.411219,144.11098,44.326415,-108.549809,-141.110921,-168.054491,-175.390033,-120.403603,-0.385543,18.629749,-89.558973,-157.987234,-199.548532,-184.768687,-100.308256,61.204725,112.277053,51.254165,-16.424819,-88.003211,-73.554655,38.860293,119.224293,265.198195,280.970499,254.642013,197.765999,142.155154,-10.184514,-47.106774,-15.275764,33.963215,19.653416,-81.483536,-128.550902,-155.813208,-142.748236,-134.95412,-150.123537,-112.465977,30.903291,83.873705,100.241207,75.984052,33.93593,31.796497,54.396374,76.853185,99.528099,160.592703,105.104074,-169.594116,-211.256851,0.567107,113.022058,150.233169,50.63957,21.703147,30.807209,34.484412,-11.555509,-37.925998,-1.795879,65.27533,56.454271,-2.783254,-31.790665,-152.489177,-238.432483,-270.686139,-197.165611,-62.137494,-126.72777,-190.620695,-230.238469,-191.967508,-62.390172,-14.352175,-22.519233,-144.230202,-214.645467,-260.481283,-224.94334,-169.28367,-162.81486,-140.947932,-128.819154,-58.765723,-10.127748,-98.352698,-366.133199,-398.771676,-288.968511,-279.033059,-368.534993,-305.741479,-235.04197,-189.825804,-211.921612,-239.488979,-209.757951,-63.018709,2.182973,18.606092,-67.783786,-109.580601,-143.448113,-150.8417,-169.10357,-182.488968,-193.394375,-138.562432,-140.60286,-263.731819,-329.57483,-320.648174,-264.37885,-216.250003,-219.423776,-116.528642,4.496014,-27.415684,-124.473415,-109.523266,20.09301,87.630551,119.702316,80.438934,75.666278,91.706843,122.842171,153.745985,98.585915,-30.579393,-18.736156,102.668055,155.861148,147.044649,67.665835,2.43E-4,-83.825705,-65.849432,15.628911,46.585024,38.154086,27.559451,42.824336,57.134571,36.33371,16.351662,56.884947,148.700338,86.7547,62.268972,120.981114,144.173933,103.481408,75.398178,124.607679,256.945492,282.045955,253.118948,225.674807,144.80165,104.2674,84.211312,114.992523,192.467556,160.401823,108.795694,-25.137084,-67.584839,10.424122,88.419892,164.409138,202.953139,225.677518,230.949646,223.134448,175.755358,124.248344,36.147113,44.587299,101.10131,37.456279,-17.021278,-119.476195,-149.697803,-142.922389,-136.092878,-96.29584,80.4505,143.014749,54.244839,-45.084874,-129.581606,-84.210297,54.296463,81.423035,90.299646,178.376284,231.773147,198.040266,87.474605,-98.071612,-92.904564,2.142132,-36.838926,-91.388441,-127.887423,-115.636843,-103.683051,-92.005453,-19.001569,17.927693,65.089821,169.69444,235.969288,247.209909,163.631556,2.160703,3.291881,88.058279,71.270669,17.597792,-70.082502,-77.667993,-58.742665,-50.001382,-27.028333,-0.531876,66.17488,104.215927,115.239355,109.283534,82.110223,39.190871,51.047932,135.109122,230.932165,238.724383,152.785016,91.696504,34.037146,71.650292,252.523345,315.773333:-157.897146,-133.813743,-103.48853,-147.437123,-198.719608,-288.363886,-329.095587,-314.096577,-284.323311,-345.01625,-462.500363,-464.735575,-455.230262,-467.58878,-435.068745,-371.817771,-209.359294,-144.995466,-153.542603,-137.197901,-104.218138,-39.951598,-28.047692,-36.239883,-7.910989,3.261339,-78.06097,-159.425482,-252.09218,-221.317642,-45.954585,37.584844,86.423909,76.392123,75.420321,34.87312,-3.676472,-36.876292,-9.311315,72.634965,78.676248,74.620176,113.629093,106.131691,-20.311805,-47.485882,60.946884,115.236413,138.670633,105.276019,91.50626,132.628134,150.547949,56.739716,6.302107,130.889897,293.682568,270.891178,151.025482,117.730828,97.431969,95.942114,114.197944,133.151499,160.773003,120.123661,78.213114,10.026319,-18.284915,-63.708738,-40.671696,145.823345,322.315175,332.581805,220.961986,137.711588,-24.407879,-63.780066,29.442836,129.579701,269.073917,167.572262,34.019569,-194.702613,-219.278778,-88.276966,6.648314,143.88602,202.724651,201.613705,204.834586,205.602709,112.233996,46.993686,30.047553,90.220523,212.665224,176.585427,121.869933,30.563668,-13.337349,-76.770208,-57.564039,90.807092,194.508288,158.090448,7.39229,-38.824584,-71.126459,-77.834516,-80.402474,-86.227095,-84.81875,-50.100039,-55.867653,-114.840487,-122.634941,-53.15143,-7.554668,42.983946,39.794137,0.676464,-148.930142,-194.663015,-107.599461,-30.359179,6.52647,-8.57842,14.144792,43.020685,22.303762,-27.186593,-13.122013,74.32225,96.208562,112.799719,199.672976,220.934625,164.460417,129.693033,151.76052,190.015176,200.887421,185.515952,187.197916,180.731813,154.271679,102.658784,124.345784,248.361039,287.758169,304.712871,278.439888,224.23308,70.831531,-1.813274,-128.747303,-179.661955,-245.578642,-247.570852,-149.999799,-36.340563,-38.587152,-128.130888,-158.303248,-119.125269,-74.073019,34.975057,182.708965,183.829216,-11.971422,-105.758784,-156.222535,-121.169841,8.313234,70.86246,186.99841,241.747112,224.085689,114.518722,27.908872,-63.444308,-22.831039,55.716189,2.068006,-57.410047,-228.075046,-302.10295,-358.139897,-347.374239,-260.68628,-199.993321,-107.682073,-35.407802,0.726846,-41.590913,-129.528991,-226.941352,-167.478458,40.619497,108.220865,121.942043,167.406575,121.592419,-116.186882,-174.615791,-27.133651,98.672819,201.936301,65.557776,-3.943678,-23.488914,-8.490353,-16.848451,-8.733209,119.001954,183.102973,121.398656,-15.741578,-44.901068,-111.418726,-151.957517,-188.980754,-190.893093,-186.373793,-170.371961,-164.962989,-193.562189,-224.950847,-230.19122,-169.450076,-20.392301,-69.246178,-175.711005,-327.721383,-297.156242,-152.049052,-118.649072,-136.058338,-164.350842,-204.805485,-196.287509,-224.363865,-390.877544,-439.516323,-326.147059,-257.379001,-261.863447,-270.339588,-228.97918,-99.89837,-64.394547,-127.766671,-156.689978,-57.431893,12.398904,34.593918,-7.844453,-10.902024,-16.582158,-38.223008,-108.669385,-153.370781,-207.081141,-130.132147,-67.439081,-21.422272,-50.124749,-131.849753,-147.009665,-90.934756,-34.587397,52.572694,45.347992,19.526399,-7.723369,7.175968,69.002934,83.856609,63.537241,83.587187,93.534001,81.706909,91.674336,132.926981,114.70765,59.419471,72.297914,110.183403,122.903691,150.151494,183.346363,134.031979,-32.93659,-55.981389,69.560278,173.890676,150.286002,31.400608,4.061699,56.479353,83.121621,46.971456,27.544038,62.253069,71.209176,62.201522,64.263617,48.434188,-43.381567,-70.49782,34.629286,223.80603,265.359717,155.29817,43.283572,-25.628108,38.477848,88.803253,38.851095,29.97603,120.824275,87.790863,-90.350595,-142.924368,-70.865572,3.55498,96.726373,193.048782,229.323834,145.392276,58.914934,-54.733853,-77.650989,-70.671333,-19.952083,95.531433,-0.354773,-90.78518,-223.683427,-242.770543,-133.156054,-39.879102,69.555416,116.554639,128.407249,49.49122,-14.066864,-34.813783,13.488688,106.43349,147.31554,312.550499,449.991621,433.861288,243.656252,143.459438,111.298409,147.869749,173.149181,105.386207,57.005902,-19.473099,-47.995088,-77.678384,-51.814323,55.651137,91.488582,145.666988,252.596164,281.114796,165.714332,49.975072,11.734974,122.177321,264.282596,111.497257,27.753719,-16.421824,-20.093877,-62.70985,-50.147402,93.83277,160.264903,199.071552,185.962162,160.657119,95.622332,80.837248,106.644449,158.434486,292.481733,285.513349,232.575812,140.873208,141.689071,209.092156,235.08979,305.386178,342.869662:-91.842568,36.680939,57.203219,-62.859489,-150.835129,-282.877856,-321.639128,-338.14025,-362.34273,-407.713637,-489.743453,-514.524388,-559.330552,-562.841826,-483.857154,-412.561293,-225.25508,-64.094684,-50.093065,-124.082645,-153.641673,-121.510283,-92.500073,-71.343729,-16.914772,29.901817,76.329486,53.267917,-33.652357,-50.340379,-5.84628,20.302495,58.560147,126.598819,151.861838,98.585081,11.750245,-143.121557,-143.90627,-17.272618,83.785432,77.584493,-20.014118,-74.529905,-142.697718,-131.66504,-26.105104,13.971252,31.016403,48.431718,68.756713,128.045568,146.060604,129.103816,122.669217,194.300557,329.294917,364.976573,309.209992,268.76613,297.73167,341.578286,363.384813,329.319054,229.061484,107.734426,35.110513,-50.617417,-49.326744,-36.171914,-39.667342,26.963659,244.994351,319.006723,258.530794,176.90821,45.189327,10.464515,33.614829,90.324594,214.866743,170.533748,69.469616,-97.764485,-106.379009,12.943699,107.780387,241.944227,218.307624,183.679186,193.631679,223.06475,220.956736,213.570301,247.967319,255.308746,253.793629,293.613281,297.899045,219.826578,153.050434,98.55265,145.393668,276.20954,261.937628,193.208448,64.949164,45.428109,-4.612961,-71.904279,-174.891356,-168.421797,-84.758747,-41.361863,-59.341004,-117.112038,-130.623753,-122.680325,-99.217677,-21.740694,21.108111,9.166725,-21.273205,-7.629971,45.304884,53.721764,41.209931,31.408899,18.278195,56.719458,64.707227,21.679901,16.970618,90.474229,123.064408,156.335473,266.491118,306.415726,222.299546,126.694917,5.191325,11.049287,65.35792,77.018757,88.603348,112.856434,115.519589,96.147132,97.374507,165.305541,206.078841,261.240879,312.2294,293.682512,165.681218,103.829536,-38.02336,-132.419488,-287.972907,-310.140044,-221.317604,-127.343408,-137.163028,-257.624199,-318.658317,-305.220032,-250.063612,-178.023161,-123.065395,-103.166397,-138.369154,-166.303041,-176.459311,-151.493127,-45.592513,26.450798,169.408664,248.965694,269.976811,277.762176,239.58971,140.529325,134.761161,184.154762,178.659078,134.228021,47.047125,31.005307,-36.303038,-84.341735,-100.164421,-74.389817,-42.309591,-36.598231,-7.007221,50.333347,32.015364,-29.65207,-19.872425,52.455013,122.986296,155.268478,137.583475,63.114285,-93.39178,-95.884153,55.236759,144.996093,225.714763,165.414123,136.565209,139.232498,119.185339,-20.429566,-78.688234,-27.631689,125.960611,151.109213,90.612017,22.734351,-179.749615,-258.439615,-238.334685,-186.072803,-136.703955,-157.75772,-174.432717,-187.050859,-185.894591,-137.308823,-89.28243,-32.792191,-61.842404,-92.339542,-140.371779,-141.326039,-136.051894,-143.349492,-152.577392,-160.714099,-155.797495,-110.182189,-114.846181,-206.751873,-267.9666,-322.904425,-314.634178,-294.865054,-276.742434,-263.702839,-238.458071,-226.43053,-227.079327,-217.594965,-93.335606,-9.372535,81.964177,71.261891,47.116429,30.329969,34.078368,-46.376799,-136.383542,-239.730858,-127.487477,-62.706235,-44.911028,-87.206636,-219.204939,-258.150054,-181.774396,-99.705151,-5.883757,-88.138434,-138.010341,-108.887157,-53.994053,26.313412,33.317016,1.913199,28.404708,66.223468,115.526893,120.095851,99.998091,87.582451,102.335766,127.067716,160.23544,133.821165,112.000522,103.755153,96.271381,29.855412,-17.981283,-111.732117,-93.947754,-40.511197,16.485967,7.02189,-2.321194,0.010467,-51.461876,-96.806491,-125.102898,-96.313343,-81.508405,-39.932159,-36.430381,-82.111082,-83.413163,25.662885,144.045323,164.033069,111.143911,49.75175,-59.620024,-75.577527,-49.309402,-22.998625,45.401646,18.676767,-43.71384,-147.432986,-158.730374,-96.939943,-47.967489,16.656238,81.671099,103.572113,38.149764,-31.466931,-157.978828,-196.338942,-190.921514,-128.221658,48.643326,43.521439,-35.010676,-202.415977,-264.966059,-325.529559,-325.767752,-281.13508,-163.752995,-118.865915,-121.270537,-134.787087,-102.234703,-52.972605,54.350328,87.209537,160.77955,279.594501,309.430853,261.886768,189.462331,27.965026,-12.316148,11.938228,35.345863,22.576155,40.758859,80.909161,120.116525,113.459045,160.159386,206.154154,251.307442,290.53723,307.897305,240.751081,154.799806,54.173394,97.25332,265.823077,347.408728,341.145536,262.80738,207.406913,86.597154,34.996589,32.577376,73.083503,126.642793,154.475825,172.579472,171.779177,141.211983,77.765872,79.695675,153.385107,246.612046,281.352481,296.89249,265.993394,152.591589,116.983015,173.492427,221.590381:-16.623883,29.013555,-23.290991,-201.487265,-260.607304,-327.356818,-377.105476,-423.11787,-407.817402,-442.67935,-557.356361,-610.979052,-654.656008,-610.204161,-404.592657,-301.892003,-192.707442,-148.498348,-127.734898,-114.574016,-119.287246,-132.502571,-136.683844,-32.042738,173.466722,203.677792,116.076188,45.062893,-84.526815,-110.314636,-72.842588,-30.430905,64.244239,87.166664,37.213235,-143.398786,-216.40888,-204.464016,-131.030576,24.572294,92.525766,81.540657,-9.765901,-94.086921,-296.312965,-333.591946,-202.24456,-107.911774,-16.029871,-6.065021,8.689467,57.287371,53.748894,16.013688,64.385564,326.611768,475.137555,463.853647,425.87664,417.850489,338.020421,282.507466,272.536369,303.234953,296.616975,201.222543,159.020672,57.813065,-21.996415,-111.194839,-60.002781,190.043049,404.273172,417.493028,254.269987,141.707716,0.868921,-5.579412,52.100058,89.588308,168.900028,108.451434,1.173105,-169.993687,-170.069175,-24.098775,75.476818,263.260972,361.489562,339.36104,229.170977,168.733421,91.888421,115.029053,199.601421,214.738991,251.862968,249.487689,194.073314,34.064975,-28.005377,-32.62504,32.42473,211.374472,265.188334,204.153105,41.432616,-16.915233,-102.761241,-125.44084,-139.587097,-121.396392,17.690663,97.501684,55.73633,-95.478685,-148.629033,-131.854392,-73.609096,72.130582,125.428373,83.087381,3.792067,19.734989,67.488365,55.732936,1.833892,2.569673,89.87559,162.443493,157.97803,107.478522,68.861045,-9.105661,-14.818585,123.319391,340.243453,362.491559,202.064592,102.322068,-8.94312,-28.488579,-3.411069,55.336607,219.679067,263.436108,210.171492,55.205293,23.532976,118.877085,200.518715,323.594152,364.49837,332.044685,171.727895,64.497118,-128.983445,-180.677693,-214.331772,-212.800496,-132.928707,-72.005796,-110.480931,-268.328222,-334.023459,-325.081764,-251.597725,-60.385837,87.753109,83.306836,-88.825009,-159.354154,-140.998558,-85.127747,36.431577,96.027404,231.160241,285.848318,249.489296,124.295056,68.872712,6.339901,12.645454,112.880045,190.748866,156.09192,-22.695211,-106.042073,-198.111602,-206.606963,-150.56316,-100.223017,-3.464817,26.857959,29.099119,-1.713162,-67.644646,-186.498574,-159.904901,20.70645,149.020848,182.619179,186.709857,110.774153,-121.393043,-158.116362,7.636714,121.507092,225.660065,185.627281,155.981706,110.514541,78.713395,21.674323,22.051598,88.55325,174.465215,193.408586,160.990422,89.91319,-145.478472,-238.233873,-263.626769,-227.813577,-203.195132,-260.223222,-256.739691,-230.454492,-246.511818,-194.982227,-87.553264,80.370142,-30.478968,-112.194335,-147.361517,-126.437187,-136.700427,-166.753522,-185.969361,-158.099999,-72.7563,-59.695352,-79.861004,-172.973258,-251.717176,-346.874581,-320.736254,-163.836482,-69.714564,-103.485139,-209.601642,-234.938007,-250.107011,-220.719219,-56.443198,27.430371,80.865971,24.128216,6.341586,-12.781269,-52.920291,-191.668283,-233.171493,-160.290504,5.785315,45.95605,-25.027435,-95.8699,-203.107449,-215.775919,-134.333914,-55.37777,90.121419,74.611933,21.907025,-57.043735,-61.337229,19.21237,68.737201,95.072065,115.206891,142.506647,153.806407,131.812678,125.987567,158.652243,185.178552,155.385205,138.746113,202.743303,206.239326,147.852795,98.276897,-2.288839,-23.509386,19.627666,126.70382,173.268852,154.99779,91.286815,24.818258,48.61198,76.11782,59.293488,44.335448,30.911531,7.536824,-47.894708,-82.131913,-126.396656,-102.697855,38.309547,195.772155,231.277911,130.743004,31.952549,-77.742638,-71.976053,-34.516283,-7.743335,115.93188,153.692199,80.063596,-114.755683,-156.18415,-60.247881,19.622252,94.208219,143.687344,154.199317,47.38441,-54.921405,-224.044848,-233.947645,-112.097049,-23.230788,142.455923,127.38619,26.271967,-211.82453,-275.976362,-246.693218,-200.824129,-125.182801,-40.28778,-36.059018,-122.343016,-163.168922,-164.967556,-125.993572,-19.478725,35.833637,169.400878,293.144754,312.426963,209.795151,117.394066,24.826906,43.331928,124.643209,158.758682,143.675986,82.189003,42.11074,-23.20931,-14.926823,79.756252,125.351411,185.295413,227.252352,238.775474,182.21375,102.094021,13.14474,56.303489,204.73693,289.649728,284.25606,170.936799,93.611196,5.923927,14.688349,78.131797,100.66811,143.958215,154.863168,119.233509,4.795078,-34.235388,27.023155,111.45761,240.11184,296.967712,317.703865,304.869676,246.398776,93.551673,76.29373,184.27012,242.111896:-164.051637,-66.367357,-34.145065,-106.100099,-175.407839,-262.501848,-254.419695,-197.746678,-221.085223,-268.378501,-384.114666,-437.209371,-506.675501,-500.321987,-387.024509,-297.26721,-113.323722,-41.417806,-75.72083,-196.035285,-213.987902,-149.306743,-118.761451,-77.844652,74.760961,167.998733,182.249009,93.751383,-81.103376,-91.108938,2.665174,24.290495,27.416341,132.964631,182.038074,154.550523,81.521184,-66.870218,-88.054291,-10.901612,107.441817,124.511432,36.055298,-32.458971,-152.223799,-173.851354,-104.178629,-58.738591,-7.470507,29.577354,38.997253,106.306334,168.076883,191.216897,148.429076,120.643381,181.719196,194.998354,189.314877,199.048627,231.962152,236.219765,236.385902,231.980372,180.362154,94.892395,52.067144,-21.098133,-50.443131,-80.819293,-62.018156,47.815065,211.838076,287.578764,302.182629,223.814852,45.852233,28.66401,155.429538,217.265508,204.491853,41.340701,-62.301431,-154.369711,-119.428126,38.636907,126.75241,249.38116,302.606047,302.148643,277.223301,289.314887,335.597627,333.252888,285.528463,275.316548,333.358421,424.161637,434.605984,338.052477,247.812525,132.926783,154.501219,304.978676,413.616134,382.77841,214.885289,163.132964,138.366951,115.725943,12.950259,-40.117109,-36.250747,56.221639,78.759341,44.070989,-9.71137,-73.507325,-55.311703,-15.371004,-8.393647,1.591502,39.578115,57.839102,42.181367,11.692767,-14.770751,2.137341,59.077001,64.632851,49.720051,86.845521,134.372637,161.765311,137.09152,167.663776,329.329627,342.771917,138.581977,8.509674,-116.177319,-120.178897,-144.937924,-173.766252,-130.03293,45.617489,110.875509,100.079507,49.049294,12.587891,51.044019,185.17909,259.427204,223.880456,86.189298,13.684265,-147.464571,-199.600051,-177.873861,-144.716316,-139.423134,-188.746087,-214.157371,-288.39909,-335.996284,-412.211299,-426.997456,-336.087738,-94.377279,-25.50554,-64.775759,-93.318625,-64.208099,-25.227225,58.524809,104.623892,221.813163,297.671889,308.366106,305.347429,286.618427,252.56954,261.343507,271.445771,176.759505,118.820098,83.660153,93.011382,47.930313,-13.63223,-109.001183,-112.572246,-85.116652,-105.363422,-97.316387,-2.959744,32.420499,31.965247,22.94121,22.536083,42.214569,50.321801,46.750877,38.668073,30.057199,37.24864,56.695371,51.732682,13.167441,5.36134,39.771083,119.314089,101.194041,-33.104813,-68.933528,-2.71193,102.896444,124.775924,117.778422,88.425672,-34.108255,-90.55873,-84.164958,-46.635716,-25.62753,-60.392878,-78.388706,-88.59727,-72.651562,-1.147788,30.03184,5.32522,-14.200981,12.637815,4.355086,-44.292735,-135.971115,-153.384211,-140.186826,-132.067872,-101.914523,-20.526664,-3.209326,-70.809469,-139.068821,-274.979112,-311.466022,-325.714156,-281.64602,-240.430122,-179.506336,-163.425771,-110.432594,-65.868758,-14.686871,-13.966949,29.492916,75.937938,69.210005,53.205245,41.89998,-60.465192,-141.678953,-240.344203,-164.213044,-115.911494,-140.458547,-190.877562,-279.891395,-298.568177,-220.487743,-142.386491,-68.783034,-171.107704,-218.313887,-180.56204,-142.421813,-153.775383,-173.897115,-123.687565,28.904004,86.510037,93.465989,82.724716,96.965608,84.87765,24.087301,22.870571,103.765545,172.404394,175.971632,214.456162,255.868965,240.563046,162.363128,-18.84904,-75.007656,-55.685334,-3.675352,12.667408,-15.781243,-67.808648,-155.724126,-138.649068,-28.778218,-92.925738,-160.212981,-157.688271,-127.117744,-146.287186,-146.177735,-10.629832,114.088994,114.516857,58.754812,44.579247,46.237763,37.432493,24.001286,30.247862,35.169637,-0.452789,-26.053566,-65.87398,-84.369579,-100.566403,-86.282757,-12.97295,85.438943,90.533394,-9.893341,-63.266538,-129.861207,-152.451998,-119.764052,-45.363856,123.097069,100.254769,23.717597,-114.260506,-168.135186,-299.053187,-357.04447,-357.306203,-264.584121,-240.927897,-259.503449,-259.861611,-152.693476,-69.000146,38.179217,54.339569,78.775265,127.343851,145.755256,106.511844,31.151593,-113.659798,-113.682684,-32.802415,-41.472877,-55.586018,-26.293256,13.024873,86.275035,94.727916,102.965253,142.444162,253.85771,254.447508,226.251906,202.000455,197.8152,211.582932,242.34508,291.993051,310.8143,322.974968,289.134724,216.435361,-9.686868,-105.730071,-130.963061,-70.591638,82.007704,149.240497,133.821754,75.755701,75.664058,158.501759,197.524863,190.999912,180.085776,186.234618,137.710139,80.398055,-4.512552,11.723364,138.941209,170.799127:-44.043126,20.352642,-0.785449,-88.746447,-143.683176,-270.506855,-315.747901,-310.968374,-277.215499,-309.157661,-440.564996,-497.555941,-557.351404,-552.449441,-430.444134,-313.938016,-65.62051,-0.820591,-52.718324,-191.860824,-228.447059,-202.614631,-151.998587,11.796174,220.639296,268.726812,160.964744,58.472628,-56.787921,-49.299238,11.802616,36.388515,85.368875,117.574714,98.018408,-17.629254,-84.145116,-131.642118,-91.303538,39.67186,138.222166,148.267621,9.827643,-112.302324,-305.588518,-329.986705,-228.489118,-148.673585,-25.256199,-0.198173,-2.517864,44.166745,79.798709,129.509163,163.942292,271.076177,329.782181,336.076668,349.060117,354.151757,355.137489,347.202415,320.643817,316.025987,289.605738,170.953932,101.790695,13.059972,-24.202611,-72.168238,-33.535084,167.33473,315.839339,326.16179,272.51863,212.371184,19.690299,-60.48748,-17.029456,92.501898,271.741831,183.864651,51.971304,-146.465101,-153.105744,-10.545072,110.563238,323.417876,368.305292,348.044485,282.274861,235.063062,162.325961,179.424048,287.293986,334.785739,421.033271,462.032329,422.099931,240.053272,154.32208,133.067136,193.449793,334.152749,384.856325,354.28235,203.523625,109.321112,-49.386004,-76.614614,-14.96659,34.995862,98.011337,96.169994,73.254611,-30.817897,-97.442985,-134.902557,-84.549061,73.369007,179.412802,166.052158,46.745247,6.960671,44.510583,88.947235,110.585257,94.164543,111.827661,167.65743,162.764006,56.299485,10.667481,95.658883,188.331942,313.027851,366.818597,376.193498,295.538756,197.070976,-4.36816,-41.351127,36.667986,105.561909,235.539561,269.90092,222.665124,104.501283,78.748808,84.476268,110.364418,221.900904,308.045769,280.712919,131.374121,55.182746,-93.008741,-162.244902,-225.181003,-202.568384,-115.847891,-120.388087,-167.27065,-304.048572,-362.708678,-370.719064,-313.055982,-129.40567,29.270796,38.961318,-80.946916,-153.837517,-219.014986,-172.998554,40.303177,127.340523,222.774614,294.476125,299.565726,243.329567,201.38287,151.944041,160.115711,193.155302,195.481731,181.355887,94.51558,19.852423,-100.942459,-98.201321,-21.925833,-7.333991,-12.303337,-12.252001,-29.360756,-71.871093,-81.109391,-75.747775,-63.108052,-8.71087,97.352243,147.613472,139.536659,65.205687,-87.195163,-85.251437,61.667452,136.785711,186.233521,138.271202,107.620752,48.441973,8.801621,-87.148497,-103.051319,16.020263,180.827676,188.643166,55.086447,-44.559321,-221.347284,-254.96691,-190.974124,-146.796862,-144.349439,-205.111699,-212.635246,-200.043329,-205.39506,-184.957538,-135.621016,-46.149215,-22.624689,-18.378574,-47.737716,-90.19881,-208.158688,-250.39131,-234.453993,-182.913773,-70.020113,-75.568719,-116.756368,-193.563563,-235.252665,-303.872264,-289.829064,-180.889048,-161.044967,-199.622673,-248.556987,-253.969044,-294.866679,-292.140334,-134.623,-21.927143,105.946627,64.201229,20.904971,-54.969918,-86.742972,-162.938808,-200.119883,-168.371409,-23.362884,10.963234,-67.925591,-147.89297,-282.110269,-297.340087,-183.458496,-95.126237,3.957013,-42.045921,-89.789129,-172.187854,-186.91383,-110.345862,-50.591383,-13.990887,17.567402,57.493728,66.54188,27.438978,-15.845286,6.058583,56.060593,69.345224,141.448402,190.444989,169.391271,105.289922,76.212527,39.280517,44.724722,54.266406,17.903755,5.719868,-19.388854,-27.738581,13.156516,34.995376,-11.821424,-53.340813,-67.053078,-86.934323,-118.714106,-164.134617,-185.664396,-216.565403,-192.522927,-40.617695,134.290504,162.96484,82.675668,20.966698,-45.012392,-44.879862,-25.503321,-17.104209,47.560439,115.808137,92.841189,-41.665927,-105.469095,-123.268467,-66.748012,103.635257,193.460177,160.158017,-24.976104,-112.719256,-202.670981,-203.696361,-88.818746,8.918055,161.231213,109.299874,14.698911,-182.09748,-271.086781,-402.395165,-403.258233,-268.384129,-129.442243,-128.475847,-207.084408,-217.708666,-159.99439,-119.20179,-33.336198,30.50085,225.119582,332.088052,294.657507,106.673347,13.320642,-52.803371,-22.830945,63.306354,104.646992,103.897982,86.809153,94.453458,141.397645,155.879688,157.081639,168.339363,254.178787,298.28776,261.386398,139.45567,80.875893,43.235335,96.375598,286.544869,407.779556,406.321391,272.357789,155.156871,-68.163977,-120.005555,-76.790765,-15.468889,124.505409,171.136818,128.067098,1.029036,-21.028415,50.287873,88.926885,151.188152,288.93185,319.775037,232.230698,150.883887,-7.921059,-28.857674,103.398917,185.059179:-133.303869,-81.552322,-18.144992,65.434794,63.74198,23.253876,15.058028,-3.233584,-49.188449,-53.707496,-40.189122,-55.146054,-128.41267,-154.425798,-179.282301,-195.344426,-166.072685,-108.291789,-154.497758,-343.030961,-403.166562,-379.460441,-318.420051,-194.926251,-111.716115,-77.533642,-76.905764,-115.878329,-181.3667,-174.510017,-92.225306,-52.183308,21.114303,125.510722,158.527882,164.769602,139.523869,75.365216,76.251079,118.073949,165.165998,194.808104,168.512768,98.014773,-61.226486,-100.815791,-34.818606,36.876128,133.892855,147.083617,144.940259,189.578493,220.096419,202.527142,166.064801,111.156989,72.032622,38.094337,-2.160077,34.410948,141.199623,140.702806,57.007567,36.646932,35.623223,-83.064701,-176.005865,-270.773129,-263.474545,-210.810397,-159.301223,-20.706401,85.717449,119.000485,118.323324,78.931054,-40.145962,-65.044827,40.037838,96.597742,43.805788,-101.950676,-146.28488,-176.271584,-181.626858,-113.405268,-11.941601,205.395317,234.586567,164.021575,6.276798,-9.014292,73.477357,110.115811,104.617505,107.561676,211.23522,271.750865,250.37937,200.266605,174.421178,111.312808,103.849542,170.08882,274.184732,301.459947,264.937702,223.869097,192.979079,211.686872,209.388052,150.890999,49.445071,133.045261,187.592157,180.984967,137.773688,114.611888,149.169019,207.82582,193.010173,176.384908,161.756967,153.710018,96.906965,60.088553,23.402865,42.678547,157.322148,190.40406,149.640037,107.743278,118.946767,79.740319,10.973173,-87.990158,12.40603,60.969182,-33.317781,-139.394216,-309.286783,-361.136037,-402.479633,-380.820409,-280.147992,-176.114621,-138.540995,-110.590697,-116.67824,-123.657733,-92.97683,17.957536,19.157742,-20.425939,-67.061516,-85.338792,-122.831907,-109.885526,-60.849805,-54.112012,-42.823569,-77.255539,-122.740666,-188.17992,-208.485936,-256.844961,-260.674938,-176.863911,-59.014538,-37.384418,-85.884241,-106.420761,-23.69165,60.500937,169.97703,181.14344,259.482839,415.44284,453.642638,455.947108,426.592693,298.343391,243.20352,236.604893,266.308623,239.445566,94.221331,18.111474,-77.137906,-114.327773,-205.64494,-255.756861,-257.185675,-77.944632,3.078153,35.288088,-20.771029,-213.076988,-280.295403,-269.673171,-182.986506,-151.445404,-121.82218,-129.455556,-182.784167,-178.79746,-79.773928,-50.403365,-54.655372,-15.851639,22.486428,88.213288,98.666024,85.444802,78.349658,84.666614,176.389286,240.905102,307.485427,303.945888,233.864548,192.754147,233.638647,301.126162,354.228833,254.348207,191.970307,157.174266,182.713084,215.620439,215.178484,206.961357,195.385786,195.384417,182.483498,138.719836,-17.268256,-72.533834,-82.569098,-63.071037,6.420348,57.632608,27.974653,-91.449114,-129.183131,-143.388429,-138.749965,-123.867273,-64.793696,-31.269971,-24.396079,-39.485039,-48.08022,-26.289628,80.350112,133.846501,132.741765,45.786856,28.699447,21.398837,-7.9265,-99.030163,-131.603771,-174.102819,-210.388317,-216.312559,-198.661424,-202.753739,-269.655992,-282.058309,-184.975835,-139.914234,-184.236122,-248.698543,-240.038202,-210.577325,-231.200133,-306.749614,-302.957578,-229.064665,-209.916157,-194.815198,-105.224521,-64.05912,-56.298695,-85.229358,-143.199402,-136.771479,-26.840463,78.902319,94.768554,104.983642,123.307503,147.123915,120.659702,-9.855695,-89.065246,-80.823667,-67.076249,-80.577873,-140.324436,-181.64279,-234.186526,-237.421519,-226.005124,-229.185352,-227.685187,-186.192789,-159.97716,-112.073453,-87.36723,-45.989834,14.237517,50.578492,92.995108,95.032413,61.147388,34.814377,-3.362489,-21.397153,-67.730578,-90.615429,-60.587708,50.183688,54.872975,-62.670437,-104.435019,-56.802991,24.292668,24.612463,-13.621192,-18.214201,-86.257036,-177.43669,-286.715663,-232.513463,9.470483,118.488424,90.28072,-7.744217,-65.86943,-204.299636,-262.456591,-325.940415,-304.424059,-264.721676,-173.217006,-130.434329,-84.689263,-91.359063,-107.167441,-99.17981,-93.742949,-114.800598,-112.91812,-95.221678,-89.95241,-85.546785,-85.241041,-66.003409,-60.172087,-70.398008,-72.501257,-68.618023,-72.075035,-64.01789,-11.781309,14.493413,54.243334,78.929491,71.069347,30.930958,15.10798,21.565624,47.295646,109.32556,162.990726,184.297353,176.827555,130.336061,-35.107844,-107.588882,-135.869159,-109.901485,-64.863636,-75.214737,-81.977717,-45.8668,-7.517807,52.360728,53.028315,29.047689,77.025881,124.129358,161.753295,131.066872,-8.384325,-78.344751,-90.408926,-63.484518:-12.865039,-98.848418,-65.443977,27.118711,20.082096,-58.567479,-85.667865,-84.08324,-29.382712,-38.988378,-154.233491,-212.428967,-290.858337,-303.68201,-237.625311,-196.738999,-142.495324,-65.46664,-66.451697,-179.580165,-247.089926,-298.512819,-269.062628,-186.209715,-134.750592,-99.01181,-20.52893,12.70613,51.093141,46.923983,22.458816,25.78016,102.474764,202.015524,232.322054,252.074463,229.409348,131.073554,97.997918,123.427218,172.163341,165.24305,95.708398,38.113945,-107.897107,-137.738884,-20.806606,66.520176,144.735116,142.623444,141.136371,150.947102,157.574941,145.119643,111.530577,-25.11319,-82.733932,-38.197113,59.713,87.476552,101.199069,76.396828,8.746223,-16.799608,-71.432084,-140.817356,-158.13116,-93.053622,-43.163882,-59.690716,-108.267452,-113.14614,64.036067,163.833483,254.946851,220.662907,34.938461,-25.915563,32.92295,75.610698,48.803159,-68.015284,-125.746278,-170.860212,-174.676609,-149.845274,-93.551792,73.850432,195.194151,189.743949,103.848128,113.354763,194.716589,189.370426,138.338586,148.423948,247.428908,311.324139,295.514438,247.208938,235.962234,205.816659,202.44658,293.71332,375.978818,334.194017,156.60173,109.202962,154.216822,171.219016,66.214213,-6.042193,2.371792,111.161116,110.082258,52.463403,41.953106,56.517032,66.512268,48.38174,-9.477909,-25.299322,-3.396695,19.144552,9.825807,-10.905722,3.570519,31.331863,74.652098,65.366693,42.513621,68.024577,101.607214,79.258437,48.904858,64.941901,159.67546,168.399494,16.947983,-98.512654,-239.402989,-252.302329,-275.197795,-316.553923,-360.668243,-193.370155,-90.89455,-24.096309,-37.053767,-40.711424,-19.035889,35.489894,45.344452,18.065829,-60.851075,-100.54481,-179.77531,-189.246878,-126.508309,-96.162384,-63.092747,-59.732143,-83.768202,-127.05755,-143.043389,-214.866711,-244.231683,-146.653035,75.568366,119.109897,44.652393,4.214471,6.709667,52.359495,197.033034,251.465618,310.477314,379.670443,427.339642,471.864733,428.735196,262.526133,199.036904,173.422478,201.132192,189.480019,93.425123,30.398841,-74.185889,-93.372798,-49.204919,-39.993685,-96.225786,-16.32018,71.770222,108.220375,26.254476,-156.992457,-192.816705,-176.501735,-153.212555,-154.0978,-131.140356,-130.488432,-216.891627,-231.73868,-122.42203,-87.231353,-105.157722,5.115561,87.493676,100.911664,31.506694,-76.260474,-64.875871,31.513505,102.894412,113.831367,113.614889,100.30875,39.164748,26.185995,112.867119,171.845974,200.087018,175.970668,166.088079,107.06422,66.207439,50.703031,77.355702,101.285618,78.396673,83.049055,115.269885,119.71021,67.062753,20.950087,-36.141606,-27.070429,91.132789,162.152909,87.145645,-92.534588,-106.353605,-105.972026,-142.341931,-217.140808,-197.36042,-158.723023,-67.584069,-44.111593,-66.724288,-67.699609,-12.113388,-0.988099,-6.466443,14.507804,-3.426657,-100.60533,-125.0645,-101.873332,-109.362989,-199.577197,-249.50009,-247.980303,-255.0168,-267.690606,-275.326772,-256.034802,-221.875539,-229.49457,-223.932242,-194.422118,-190.514274,-139.446331,-111.12351,-124.927855,-147.344884,-183.932774,-153.973302,-107.969445,-78.72498,-95.817142,-104.233638,-99.772993,-97.449604,-85.804599,-35.756916,-14.844649,-17.252516,-11.779964,-1.064038,-13.988183,-58.328018,-196.02626,-277.78184,-282.395058,-222.600806,-170.51595,-160.963825,-216.171355,-309.525552,-323.499152,-317.299815,-289.122982,-240.750296,-99.20609,-66.168927,-83.646959,-92.067724,-76.969695,3.929811,58.146694,83.095499,54.339669,-17.31351,-41.377061,-40.263683,-42.499282,-93.51681,-108.195175,-78.250304,0.306515,16.351379,4.600944,4.767062,36.93942,32.346996,0.299497,-61.819397,-66.166455,-89.688602,-135.355176,-169.804161,-126.826907,-9.162195,34.463194,4.129135,-76.850807,-106.348864,-197.520005,-246.308,-280.050207,-241.472204,-196.276344,-117.396093,-118.554397,-169.289381,-179.546857,-121.658158,-76.591436,-25.053601,1.263217,8.320767,-52.404012,-128.26363,-263.132763,-271.834074,-210.480663,-187.995419,-183.97868,-129.887301,-92.156367,-58.658741,-52.111876,15.019136,60.42486,126.783307,167.290733,175.875438,165.387329,141.834223,137.378096,187.811864,265.151073,199.860856,160.743912,126.353828,110.909626,-12.763872,-112.899612,-227.684222,-191.980427,12.06731,138.341731,124.947674,51.23544,46.499778,114.273624,149.782819,135.964819,72.975314,82.68889,140.738342,150.233345,109.99136,85.755464,65.760729,38.53414:-161.809622,-21.324487,29.401646,26.112995,-6.360492,-105.288085,-148.61002,-131.510704,-114.399742,-163.014743,-252.953101,-244.213424,-202.171267,-208.285157,-204.713501,-160.27671,-47.547786,-53.892447,-101.168975,-202.706074,-238.866804,-255.432355,-235.152922,-141.540049,22.727432,85.49553,54.166114,-10.04148,-118.175945,-152.036758,-135.880465,-84.021871,29.500717,55.317621,30.609501,-45.08249,-84.899187,-90.606814,-49.993655,21.901492,58.910767,65.550703,27.312439,-26.743546,-209.221731,-278.148918,-217.562488,-127.151621,6.755539,71.348515,100.156028,121.741143,100.246525,91.128392,156.941207,329.563504,310.09966,253.350667,196.5575,205.129172,238.806234,239.770164,211.591442,196.209894,157.321391,21.888676,-62.172059,-123.946661,-124.734994,-173.702077,-178.652921,-42.796151,166.966214,233.579242,237.080106,190.170517,40.721121,-14.984004,44.175548,109.702936,109.355418,-76.543446,-162.609666,-177.818057,-138.684651,-26.005926,77.620447,305.735862,328.982412,281.203101,212.966058,193.238691,163.086644,150.783002,126.078677,147.412265,315.648058,444.824612,415.646444,267.887404,209.744964,192.646166,225.768263,296.234102,363.692584,375.086327,262.51811,180.938995,132.647585,158.679926,186.815181,163.577036,128.91909,214.401781,251.652378,210.208635,145.401411,36.057666,24.529705,63.657743,124.601388,153.904818,210.658663,231.934165,199.00512,152.2269,77.957375,46.278941,-1.272011,70.5261,136.392321,197.56029,183.953315,152.779524,150.415432,173.820953,252.658118,277.374898,214.064327,149.056683,30.73682,-19.822033,-95.810485,-100.254828,0.127224,90.113999,91.288947,105.227533,103.939259,15.734866,-25.180232,29.885243,164.74414,168.357189,45.743776,-17.897023,-85.350833,-94.202667,-92.77807,-96.857308,-74.154469,-29.889028,-62.135073,-205.023506,-260.345109,-269.77347,-220.574221,-73.111174,23.149455,20.378629,-34.812962,-32.018425,26.978698,56.571186,157.364622,218.765212,294.284579,354.824758,372.883836,336.523522,298.270032,238.377279,227.401654,211.852625,144.81518,111.148903,83.689006,67.145659,-30.093772,-78.365849,-90.590995,-97.575525,-174.263848,-157.112792,-95.982397,29.463445,37.633658,-93.503089,-156.793774,-129.17604,-9.161509,38.87701,58.356086,33.827608,6.83114,36.392411,127.746455,131.117193,42.25935,-24.896538,-5.032458,79.686235,75.345097,6.908816,7.629643,102.989655,220.026904,234.718328,198.80002,188.157955,146.803545,91.416216,-22.28956,-37.232452,13.420441,27.21963,12.540531,23.274145,37.115906,6.096031,-9.740535,53.375334,130.277629,96.089755,-85.789603,-153.408235,-178.531952,-166.232183,-153.771467,-157.825741,-134.335992,-95.342956,-104.459013,-112.849905,-103.591549,-118.280462,-121.49963,-86.38587,-138.906815,-218.722663,-305.462125,-250.017452,-87.879252,-68.855632,-79.143525,-40.5582,83.710443,138.293045,149.779608,132.75985,60.197085,-120.146235,-134.673336,-56.497812,-48.852742,-82.126055,-203.626075,-273.669337,-363.359701,-349.7826,-181.933525,-84.418533,-28.558548,-159.440703,-222.118075,-199.677567,-162.652019,-164.240287,-172.611214,-158.662152,-161.013367,-154.281383,-77.037602,-29.942963,4.270175,-8.86574,-69.904653,-93.150737,-39.214197,49.673336,53.319822,61.39152,120.08944,287.60681,291.653483,90.917223,-24.181804,-0.409402,53.672238,38.820495,-64.320455,-104.916294,-125.029091,-136.772734,-149.961126,-160.533341,-193.403483,-234.267891,-235.065471,-238.657516,-234.977663,-162.563973,5.21466,45.291488,-17.550718,-41.707075,-33.115596,-59.337437,-150.453153,-153.633817,-70.170043,-38.033023,-56.275775,-99.33086,-131.128534,-154.745356,-103.276288,14.954766,12.614525,-0.483198,-5.343351,-11.863475,-102.805763,-167.395417,-149.464504,-60.374882,98.523816,112.227918,75.347484,-59.264437,-135.672536,-255.215045,-304.703699,-385.705843,-379.845481,-353.456329,-278.053203,-225.186162,-149.352386,-145.029111,-145.374203,-122.013535,-13.72595,58.261539,36.994404,-52.109275,-88.387426,-101.980914,-73.484059,-16.534164,-27.774709,-24.536404,27.181803,60.900685,85.165351,63.876572,38.808078,76.533482,224.478827,247.90498,192.120007,141.324226,172.437919,229.623741,237.354958,242.807627,250.394271,259.113532,242.167875,179.92641,-32.287198,-105.537484,-105.209007,-100.54023,-145.166372,-123.488479,-75.176105,78.068607,135.317687,94.223022,41.706411,38.850307,185.63068,264.929285,256.458464,162.148475,-22.368677,-52.038639,-14.25811,-6.892084:left
-123.682616,-7.403877,0.47762,-59.204383,-69.278547,17.379853,92.72332,154.65239,117.040051,149.421045,277.994804,313.80194,274.016982,215.286572,97.906,40.262363,-55.734879,-56.972046,-59.058296,-96.330568,-111.820784,-173.70264,-236.572262,-360.042375,-311.342226,-227.27069,-106.667059,-98.226839,-180.699341,-260.671079,-381.581775,-388.032352,-333.344888,-246.876325,-219.72473,-212.456351,-198.533097,-117.196487,-67.921434,27.152017,93.62714,101.974743,102.020519,103.26742,63.336855,10.920535,-101.008287,-136.194044,-147.834821,-104.094779,-100.21693,-119.244187,-101.691177,-28.3859,-23.300291,-102.265562,-141.556766,-135.636599,-151.29877,-167.174351,-165.309279,-151.966438,-130.209205,-145.661019,-234.214876,-242.659706,-208.588823,-105.53662,-35.72573,101.515862,132.944041,49.721868,-92.37268,-103.466595,0.395384,81.236068,192.466919,174.504409,-4.267252,-92.624316,-98.084962,50.839529,98.226835,44.939416,-38.373999,-167.856926,-182.287742,-176.841192,-143.680878,-111.198358,-88.104694,-107.849404,-136.419268,-123.921578,-66.054851,-38.933841,1.964098,42.538673,64.879965,129.440185,152.500244,123.382619,101.390293,97.795379,92.17865,110.325982,222.287265,284.79469,299.724518,236.912775,91.062974,37.868714,-50.116065,-12.967924,57.674102,150.362065,141.558771,83.617758,52.22919,-56.85883,-130.626618,-125.761529,-110.883248,-100.527054,-62.731493,-59.011741,-91.31355,-116.183319,-157.037479,-202.406593,-230.759585,-233.26164,-205.698066,-129.214316,-73.11582,48.652772,127.779327,151.459452,155.004538,157.595313,194.649015,189.980329,102.616141,54.60158,16.509842,35.852191,64.794592,188.306692,243.393051,200.03825,122.52185,34.084167,95.999965,133.932737,187.495624,220.250894,261.668297,270.601469,323.427306,330.83545,206.015688,35.592111,-6.672361,-2.706685,23.431311,129.068152,203.332227,235.60246,89.315744,25.897141,-56.209604,-103.491114,-195.392192,-234.31996,-379.525689,-484.984938,-578.976731,-455.099152,-423.813324,-528.977495,-594.323134,-593.805424,-547.265483,-528.76952,-564.175978,-519.054711,-329.20007,-229.090742,-81.892371,-41.936966,-25.309973,-44.509544,-59.20022,3.978977,47.740389,187.651526,264.700503,307.418627,262.187709,115.477509,72.31568,129.383896,300.399055,367.46037,462.982917,501.657576,483.087724,391.228929,187.87546,267.300199,393.686924,543.508841,520.610571,414.238696,369.940679,232.525574,110.210306,119.129405,162.784182,154.872671,139.926856,135.162264,61.300397,-2.913792,-106.74424,-75.397068,-21.530588,52.063895,44.024988,-37.401318,-82.783981,-200.245757,-302.209144,-294.82322,-240.695052,-232.388841,-212.54626,-195.580915,-211.14125,-264.993503,-428.051356,-530.719435,-552.325956,-593.15296,-632.451832,-696.876478,-674.28511,-552.253453,-467.765531,-441.103214,-376.465357,-329.4801,-226.602987,-196.888938,-233.373752,-291.605791,-377.651741,-320.427802,-261.796797,-167.1603,-142.935835,-129.008335,-119.088574,-107.975852,-148.066357,-148.235428,-46.998718,29.556874,86.117557,53.19728,48.852684,91.636175,92.134685,80.613681,152.400458,357.462519,401.128371,356.34947,325.349893,276.875476,235.664208,201.281134,61.534249,-5.608497,-77.017982,-110.134654,-159.282652,-163.829806,-202.683341,-250.359599,-227.938714,-55.707825,45.49962,117.337725,88.905854,-20.666013,-55.73395,-15.655623,83.676576,128.583616,176.962902,148.176715,39.045998,10.486795,3.451172,5.814264,32.710662,149.545602,208.401557,263.351786,245.744366,158.58675,166.461493,194.972193,152.669051,102.380101,70.128199,92.202377,121.53282,100.544568,71.050221,154.293195,192.798336,213.650057,206.078218,147.248455,95.550252,-20.513336,-45.622268,-15.005609,39.566455,48.556827,30.024915,0.411814,-36.835763,-36.096585,-83.411004,-160.369888,-160.133339,-84.305454,-52.49919,-106.893605,-178.537514,-317.865199,-386.915449,-356.663111,-199.840732,-134.36238,-110.577552,-139.44206,-222.748761,-279.02973,-400.374789,-427.374811,-403.56286,-307.409292,-249.561579,-193.504212,-202.421005,-236.848294,-247.633553,-236.564372,-124.829252,-20.781077,115.70064,91.883157,-31.503287,-53.141188,19.154725,110.532574,152.221864,277.272496,330.534581,310.601871,248.870062,123.969733,72.834877,88.119732,188.400714,255.98615,382.149043,404.135986,302.225462,220.088345,172.682811,210.744431,172.038655,124.738079,195.4279,336.575107,317.141698,183.004891,132.7492,153.662139,204.832145,219.366068,214.535719,172.099528,32.246284,-17.62817:-114.96243,60.571889,106.234955,96.451653,71.085962,25.59066,10.55241,-19.682002,17.192363,70.345823,165.517336,195.154153,175.378306,118.218503,-19.427325,-85.815346,-205.573264,-230.745287,-198.381892,-93.700282,-69.241599,-177.773745,-288.787175,-484.773235,-444.643735,-335.450661,-169.134209,-153.651635,-207.946007,-264.690456,-391.627974,-408.590592,-281.204749,-89.619285,-6.684313,113.070371,132.461829,131.323769,137.784764,156.493091,219.176209,251.958237,241.246898,216.838025,144.668468,81.935037,-30.703104,-38.754794,58.434657,146.946582,126.814978,25.585108,-10.506055,-20.323512,-20.744568,-81.632129,-91.206355,-55.561424,-21.22403,-28.466041,-48.590865,-64.065923,-100.940651,-125.689067,-166.565944,-71.036363,5.085967,83.431408,77.476263,14.899412,-34.229432,-162.68621,-194.048946,-132.236656,56.687933,125.702762,183.20425,175.925572,25.160125,-93.01241,-152.903651,34.388105,76.16992,-23.011755,-88.65829,-168.280804,-203.687982,-227.479528,-126.97376,-79.583854,-95.854346,-136.018223,-155.772268,-128.114661,-103.211711,-134.133864,-184.754196,-96.946663,-27.740175,69.009997,71.815774,-12.522058,-81.000763,-196.286656,-93.979316,46.226423,319.469969,382.495414,290.468686,183.152786,16.361209,-39.453707,-98.023783,-12.636669,62.053342,128.875076,88.882748,-12.301065,-34.579932,-83.855475,-84.826056,-48.560019,20.49502,49.718665,83.402108,64.308458,-12.540193,-56.116297,-145.043468,-173.27958,-150.118531,-19.225143,44.404179,70.442147,40.058091,-48.1929,-28.768399,22.324173,81.119415,87.846973,101.65532,98.990407,21.902207,-48.609083,-126.046222,-22.924116,55.525622,142.915391,146.272952,111.711435,71.929376,-8.993982,64.423126,144.528402,279.71645,328.72308,338.075682,290.519947,204.060755,186.027618,142.553601,80.739572,67.570556,115.801186,157.384699,192.134964,170.503333,62.258605,-20.356807,-34.515713,-39.158634,-35.316997,-77.659297,-149.611412,-331.873914,-401.798201,-475.994595,-461.126185,-418.402372,-341.716143,-349.901582,-432.844752,-475.891962,-547.851185,-493.414633,-409.19095,-212.664204,-109.382813,49.862784,66.974189,1.730331,-29.592378,-35.756593,1.157543,67.423586,286.406217,353.803921,265.936618,155.465361,0.983598,48.220746,105.60269,180.876159,202.395372,242.606556,266.545928,275.318536,239.845702,166.767134,211.438921,246.321133,253.318747,245.035502,275.870375,291.16597,198.637423,20.494677,-12.746854,-2.541632,-12.844317,-59.08473,-84.995585,-171.985558,-220.302074,-261.198062,-210.319547,-170.834988,-146.352818,-173.474983,-260.256483,-311.595924,-433.324595,-417.694203,-339.477593,-196.834719,-169.816975,-182.396329,-197.173439,-260.898213,-322.030568,-400.580979,-373.895467,-397.156208,-525.953795,-566.497327,-565.242348,-556.983753,-499.082127,-326.193532,-270.889045,-265.75675,-234.505665,-121.363026,-113.982245,-205.925601,-255.756041,-277.01555,-225.455139,-188.780613,-37.743023,56.641809,121.543354,83.135624,-40.370144,-104.820164,-77.844847,68.375508,143.034504,151.272745,77.611413,-54.278483,-67.439545,-54.747092,-8.258558,44.459045,176.501133,225.839671,252.61632,235.337901,165.768314,164.527223,202.179758,237.572406,211.558896,119.568537,68.399168,-45.461472,-109.118848,-215.232671,-247.526476,-204.262695,-2.424436,80.155373,68.969802,11.91765,-50.567661,-22.122784,3.187698,83.142054,145.665368,202.367205,163.037587,49.95327,19.360431,13.903474,50.959386,98.152322,253.174429,307.311075,256.38088,185.878046,117.944179,154.026725,155.259542,127.138764,144.662487,199.472446,194.276399,175.567409,196.108792,264.653365,291.038695,280.357349,248.70239,242.480297,254.365617,245.873929,117.978412,26.450501,76.651497,253.984842,271.575182,122.477911,50.415913,8.191958,-13.926606,-81.442141,-78.219511,-61.371671,-16.358834,6.899521,-19.035711,-83.310865,-210.789389,-203.201007,-175.598146,-139.302047,-106.230709,-24.999389,-40.968921,-187.507988,-250.656346,-281.369643,-227.073552,-197.000154,-146.461823,-120.593592,-67.087127,-50.151512,-74.599101,-101.144322,-77.085053,14.663149,65.420203,97.704552,68.796276,41.774764,59.585692,73.942584,114.810065,184.804095,310.198715,295.174407,160.274041,113.073785,69.832284,9.677271,-0.621474,79.788461,145.733727,250.256912,273.304141,248.14415,212.559822,159.807901,154.285229,154.724294,186.992727,222.218027,243.617198,211.3089,140.031664,143.17669,161.666268,223.232543,277.951674,368.084169,352.76923,186.328383,81.327676:-148.229993,3.647647,48.358967,40.490155,19.864595,-0.620607,-0.747303,-11.306576,-30.330336,-25.548545,76.616978,162.230734,213.863989,138.531746,-71.858744,-142.06241,-218.129349,-265.660037,-248.821866,-105.048141,-57.501201,-136.367066,-222.047574,-437.120085,-558.588238,-492.143161,-235.907438,-163.617381,-229.494036,-309.067962,-392.204673,-384.212498,-277.791976,-52.34706,74.662254,233.303171,230.917275,146.360461,125.065599,134.052652,133.036849,136.589477,228.318107,287.739932,240.592713,158.307296,87.176041,92.0521,101.03739,120.089669,122.750924,90.317602,61.912827,5.208245,-44.761372,-199.874477,-188.503824,-102.681763,26.78439,45.853715,38.838859,20.647368,-34.070013,-71.143565,-122.239704,-34.861718,29.546457,116.713328,142.314086,152.250239,118.901417,-40.307588,-141.299723,-117.876227,23.632245,98.357788,141.823432,93.226005,-74.460819,-139.300853,-133.057527,-48.520221,-32.980635,-33.383578,-42.416221,-116.967297,-185.983954,-320.788394,-302.53793,-225.566026,-80.615297,-66.616033,-120.198423,-158.859633,-268.20696,-312.109959,-294.262408,-141.170625,-35.833283,104.670135,81.186532,-100.084859,-182.524032,-255.306682,-159.066924,-49.912286,158.222299,224.764215,240.063452,174.37988,-56.130423,-154.152743,-147.634414,-14.274873,14.241197,-37.529911,-102.890563,-167.017353,-153.969542,-153.884735,-146.821311,-118.760042,-48.161156,-8.543305,38.819387,20.971972,-96.553775,-161.890092,-174.648556,-103.327691,-106.515916,-130.056069,-129.829169,-146.909704,-161.523192,-133.58926,36.202062,124.936462,171.70679,154.754394,147.427767,132.654948,-21.386981,-121.164946,-155.554059,-10.620868,30.132365,14.872516,1.379961,-22.657858,-55.768369,-107.530062,13.41002,98.833254,180.054125,189.534061,207.86749,218.187117,215.886572,193.057967,142.282682,100.307971,89.14507,144.269093,194.029475,250.348299,223.747272,56.906448,-44.497135,-43.131985,-21.882689,2.139283,28.580248,-9.832714,-154.963957,-213.002324,-204.274299,-93.617924,-74.267788,-123.017827,-154.571193,-203.458952,-230.217553,-273.837709,-246.645564,-198.83577,-41.772057,52.664912,165.890141,156.967183,73.105965,51.264643,95.664333,167.206562,214.175535,331.794069,354.212803,273.407872,188.12809,26.241126,34.66501,99.670924,210.270914,213.794777,129.10117,87.904078,55.928561,21.744959,-60.601241,12.369532,78.147372,145.604191,138.419203,88.540508,59.774003,-23.253749,-66.011544,-39.734266,41.389253,53.416858,-12.774676,-68.104124,-172.187848,-217.183301,-250.802707,-209.089901,-184.639604,-149.202604,-150.186472,-190.1463,-240.735175,-385.325108,-348.762048,-259.322192,-135.984265,-123.258653,-142.252275,-157.481616,-224.360427,-276.772398,-322.493042,-293.165793,-295.003841,-340.625382,-379.384189,-431.470226,-403.487305,-265.742544,-149.445192,-125.960505,-93.99792,-67.634333,-84.868447,-131.792433,-200.695345,-218.770252,-222.713777,-175.970311,-128.223539,65.169663,171.943902,199.435812,103.573884,-71.902074,6.539864,83.972455,145.163604,125.656259,45.24922,22.194906,38.645597,40.296321,1.037455,28.735616,74.27282,177.342118,219.241239,252.867454,242.36994,184.41708,164.712208,199.445199,284.093579,262.561591,116.721295,71.301443,36.326303,3.078613,-40.712317,-38.388644,-45.380825,-20.844958,7.311059,31.099664,10.632192,-61.43941,-17.165738,51.460446,145.606166,162.197679,169.236079,148.481847,45.82563,-12.706427,-57.740153,-9.903674,21.363108,106.891018,142.398323,144.269527,124.759296,63.459923,21.678997,23.272536,56.621726,80.313196,100.288126,86.445315,20.31874,-0.828435,73.838045,219.590408,247.16472,180.092211,129.711126,96.15553,79.107336,-64.116768,-98.182672,-10.353931,180.974284,215.346178,137.439613,57.920781,-72.039114,-118.331152,-172.687814,-178.499303,-180.506931,-148.949325,-141.738856,-292.753519,-413.951233,-440.453127,-208.79796,-132.58715,-90.538771,-63.200031,-1.534776,-31.41483,-215.077589,-286.537128,-267.241161,-132.383619,-67.949542,5.01114,5.925348,-22.833215,-38.46031,-66.054801,-13.999908,47.176814,156.234314,185.042312,123.443757,44.520225,-8.4602,41.358334,150.597552,207.451602,248.36832,330.688136,318.687061,231.624437,207.238999,201.295354,255.280546,279.12712,264.617302,243.047028,194.252975,173.87864,154.682177,145.722943,159.683823,227.423108,239.500865,230.781788,235.854447,248.394625,242.282356,218.761257,260.261154,300.049715,330.864745,329.544975,339.19133,336.216695,222.806041,120.129824:-240.337057,-121.458431,-115.315365,-136.392141,-121.877796,-77.780533,-64.556456,-74.770348,-62.228839,-8.667334,140.715043,211.456931,282.887268,256.988922,107.402386,16.560937,-103.768161,-145.952545,-172.696337,-166.081874,-118.912177,-104.773398,-199.76884,-482.670994,-560.557555,-493.950524,-295.785337,-222.239076,-226.288484,-296.645508,-431.525274,-446.226829,-346.747165,-173.842544,-108.222427,-47.146111,-53.371171,-102.504415,-102.713163,-7.554407,151.620003,198.444498,195.159167,182.331853,104.038579,14.077398,-132.802633,-133.202285,-26.037492,63.935946,62.655364,53.260768,67.363391,59.997598,18.69631,-109.665662,-168.499842,-145.039784,-77.385362,-70.138084,-97.246495,-105.388739,-94.972272,-100.911585,-155.354023,-104.392366,-10.747895,180.14005,212.89904,147.864373,98.446676,19.40979,-8.415974,13.692284,143.648857,234.867657,333.237318,298.824984,119.034609,20.818429,-87.999035,-51.336636,-28.219386,-52.773689,-87.582445,-169.571591,-225.00572,-354.001585,-345.930637,-272.005753,-169.430861,-180.953092,-240.814944,-253.243005,-250.315834,-253.518982,-209.807124,4.660561,100.868056,129.926965,107.192929,76.220305,48.291447,-28.156375,28.818523,131.25008,342.877533,388.556843,332.368726,256.773263,52.642469,-53.125811,-147.93406,-77.471433,-28.236376,16.044062,-13.017598,-89.683081,-109.991793,-188.289657,-256.798797,-262.697137,-230.111789,-175.645806,-57.99933,-50.249334,-123.570728,-152.759858,-145.293581,-171.912438,-200.247506,-163.150904,-109.623714,-57.473345,-47.404044,38.498576,160.096486,185.203655,154.189291,134.331996,88.20061,29.434652,-94.979263,-108.293359,-32.351181,49.107568,82.508897,165.868631,178.190842,83.615497,27.510164,22.247486,122.886911,173.748921,256.738748,295.69214,325.081445,299.591908,232.537144,206.492336,141.573392,77.089179,56.816464,86.51166,140.054278,262.250263,302.20751,265.583644,163.632096,146.473796,116.820103,85.568617,-10.271263,-88.503845,-271.356652,-334.9089,-333.718966,-215.991797,-173.527672,-194.20199,-251.887851,-363.882951,-382.756478,-372.098719,-342.125097,-310.418934,-188.425469,-101.247755,58.306501,91.432883,30.644573,-27.111832,-41.226706,66.667507,121.438263,223.65091,245.382246,204.247163,176.348192,110.971008,73.698472,128.113047,300.559511,348.703642,339.978504,318.026773,289.897077,256.332009,181.79826,259.308988,331.644579,376.942343,334.649826,245.42592,213.45809,102.942089,29.742804,40.32849,63.939147,72.061938,143.913962,174.613346,80.397284,-25.641003,-149.482113,-7.933107,99.441697,152.374565,86.753247,-67.290176,-108.637224,-146.695966,-154.81139,-140.109229,-115.456558,-108.480654,-87.18018,-100.850679,-249.825226,-359.554904,-488.005307,-429.966008,-395.91048,-414.470625,-456.647595,-507.809785,-487.18257,-424.424245,-388.468036,-351.627045,-251.581774,-215.01055,-185.167,-176.235595,-154.214985,-153.981079,-177.169542,-193.551667,-169.826551,-23.180978,54.682685,93.478248,63.646276,-15.502666,-38.09851,-17.191935,84.834376,150.415453,179.670031,138.636113,90.156895,93.5324,83.39998,133.416367,204.938474,348.592348,379.322033,354.779356,316.877326,204.46866,144.125597,161.812349,199.779302,182.65038,101.937736,66.511371,21.146226,4.861303,-21.222062,-62.828803,-72.918818,29.055547,98.894105,70.338134,-10.060032,-133.369904,-121.839732,-83.096297,4.98085,61.002893,147.177366,130.381098,3.934619,-50.830108,-84.638793,-72.267248,-50.193979,69.856033,131.346163,132.849639,90.574456,8.904135,-46.113433,-57.68076,-61.05205,-37.444365,57.416214,74.888123,15.548998,-20.646193,-28.651522,41.655893,60.686072,4.3107,-42.667173,-63.053896,-40.827099,-72.90384,-149.840074,-116.662061,11.269797,34.756218,-31.701799,-103.181663,-247.542921,-299.803872,-358.666497,-375.151767,-377.169446,-331.452801,-285.94778,-263.579523,-312.131938,-421.982521,-359.575159,-284.052713,-175.101371,-137.501145,-89.427029,-117.445465,-282.904802,-363.117346,-395.042462,-290.883826,-227.419538,-126.993089,-104.52181,-95.221991,-118.259665,-241.345335,-251.487697,-171.599042,16.566533,85.378239,123.829403,76.711026,-46.526397,-59.730524,20.708317,144.526372,193.77333,254.366636,259.418061,226.582069,211.227165,201.795331,201.215671,213.212878,286.010491,332.093227,411.220432,433.912596,388.140914,319.235656,221.959126,283.570099,305.599071,290.040403,297.482612,328.285939,318.497942,246.362737,214.820742,229.185801,264.163061,284.426861,316.210398,294.357211,150.742466,65.454445:-118.06662,-65.042397,-45.284808,-40.855148,-80.030209,-200.722547,-245.655446,-263.332631,-146.625214,-60.496113,88.577889,144.515678,194.436969,172.063626,7.291031,-109.650342,-229.340942,-206.48387,-215.784009,-228.494147,-213.360161,-224.136356,-287.542661,-527.965295,-598.490879,-498.22092,-284.039078,-254.092752,-300.403299,-328.703718,-382.804791,-419.244743,-402.459827,-151.747179,-1.307548,124.276536,76.061979,-46.942341,-60.997134,-60.278107,-25.439499,23.227607,150.082456,192.787304,110.17208,3.303443,-168.363334,-194.752005,-98.044645,119.793861,200.01504,196.426038,122.775894,-26.946554,-74.172876,-161.609726,-224.466968,-229.600103,-149.121978,-82.015566,-60.200809,-114.457567,-224.040148,-241.641345,-176.696887,-41.533219,18.782718,111.6195,151.706719,171.914113,106.265316,-113.889043,-138.254878,-67.736139,66.007916,111.426088,170.491544,166.377684,32.654692,-77.805665,-195.586294,-131.773681,-98.088607,-69.889155,-77.245115,-149.701165,-208.835746,-330.700428,-299.537261,-222.250416,-117.147785,-113.927195,-153.87095,-196.308559,-324.033947,-358.601878,-232.122333,43.097698,144.392583,189.356232,150.695479,72.681525,52.253913,8.772954,29.77675,103.533979,294.706923,353.87703,320.821911,234.388037,-12.417683,-125.928763,-185.092486,-59.971372,1.676688,49.138103,27.323189,-72.533258,-129.233239,-237.205732,-294.580125,-289.14303,-193.447539,-117.466441,-26.500978,-40.299723,-171.292966,-237.720543,-205.7379,-103.500765,-111.488396,-132.119263,-117.467285,-112.342143,-124.210629,-59.852074,110.641405,150.775323,148.254391,153.642103,137.276791,90.243589,-52.990538,-107.116975,-80.192187,27.059411,74.141216,166.842762,182.448803,65.313211,-26.131908,-86.271306,69.659089,163.680247,258.575585,249.196238,142.408502,93.104082,80.020178,94.667845,130.967483,139.781873,143.037909,223.750276,273.045977,293.916345,266.377909,180.523709,143.736379,143.957289,171.346014,197.554035,155.25741,59.044934,-170.059053,-245.780144,-214.010697,1.663089,77.373711,86.552971,51.160528,-58.724012,-131.74106,-245.35642,-208.783821,-154.125441,-48.177152,14.773259,141.663871,156.340558,50.207021,-18.783242,-14.573256,162.121481,243.928797,307.295369,293.16706,236.03602,191.654454,60.834117,69.797293,155.853404,362.71011,431.660089,426.145469,370.443609,236.326763,180.268821,152.256546,218.713463,269.61419,335.153453,316.594138,220.53232,162.91008,41.916339,40.999163,90.457225,199.734103,245.834532,269.078226,224.531743,55.778176,-30.9207,-91.190899,16.428581,94.657113,218.939653,237.988955,168.611956,78.509175,-128.671011,-108.193021,-24.399396,54.255512,40.232112,38.392123,59.208239,-18.959023,-148.973509,-354.010781,-270.71788,-188.316878,-122.620216,-161.388573,-285.034868,-312.715656,-273.282441,-203.751767,-180.326536,-111.121439,-63.022775,-24.174813,-35.660266,-59.498218,-61.829095,-26.254913,15.510402,46.915562,182.437179,242.665014,233.445591,176.521381,24.709349,-14.347034,32.407122,142.450532,174.729749,174.334306,148.158232,63.234939,8.446403,-46.85603,61.936445,147.712758,277.008766,296.592831,256.436686,214.726447,123.434714,89.461422,104.181794,187.504218,226.572195,181.289103,119.009108,76.621664,97.36917,115.727107,97.390091,105.913984,144.182701,148.770189,104.846324,66.150279,-27.519062,-25.093656,26.340028,93.986661,99.559456,99.09186,72.457187,-48.454858,-110.837413,-159.264118,-69.397512,5.708775,133.164536,150.995048,84.70822,36.204553,-0.409621,37.761016,38.162178,1.814675,15.610725,105.829542,128.783827,67.373727,17.152146,-7.02875,28.583193,32.148971,-6.163152,-36.090928,-78.433016,-94.15354,-154.126342,-123.785119,-35.920172,118.402732,119.403725,-2.040865,-85.319779,-268.350643,-344.04863,-353.080677,-281.595631,-273.994062,-243.722388,-215.902136,-255.977329,-329.575584,-404.790236,-215.967768,-76.096819,72.161205,68.471849,15.314361,-3.895309,-30.702489,-54.761066,-86.243111,-28.390101,24.002111,103.758882,91.548606,-8.684456,-52.766471,-92.202644,-48.690354,-2.291868,97.939596,125.775136,43.602786,-55.342422,-187.535691,-169.294339,-10.677643,141.826606,194.808984,271.992431,281.490244,231.043867,186.166014,130.976464,200.360916,247.497238,279.574039,264.782909,200.802883,170.650561,115.427444,71.229366,-9.730465,28.024142,81.825247,158.334951,155.27559,69.991436,7.421189,-75.326789,11.043791,87.03584,140.756847,139.944569,186.884076,197.790561,65.229573,-54.509494:-204.512365,-115.783579,-90.027922,-114.946817,-129.787415,-57.672749,2.167967,-13.484735,-69.73173,9.920015,264.952817,332.033913,287.927127,227.226986,133.14682,91.956691,14.065704,-40.20813,-62.284059,-59.119029,-39.686498,-36.020025,-68.503488,-207.292181,-297.890119,-258.776331,-85.498811,-31.730264,-99.754835,-201.742574,-368.30029,-388.410167,-348.36107,-241.002785,-193.187658,-194.956612,-227.431129,-298.42133,-319.337607,-272.078076,-162.331482,-139.54235,-163.930067,-176.178059,-153.292501,-136.010489,-166.662347,-198.847508,-193.647583,-150.743245,-143.948405,-124.930441,-108.859259,-75.336832,-69.381937,-112.561471,-157.257164,-146.867977,-85.076723,-72.462681,-159.352241,-236.938842,-333.039716,-343.581353,-341.075783,-264.707948,-186.726083,-31.736242,10.327435,35.988532,42.277177,23.1133,-56.723549,-70.013493,20.48058,105.277543,231.082765,222.401302,69.593656,-23.761856,-143.361774,-90.649264,-13.265978,60.07662,18.652802,-122.469087,-168.330078,-194.009208,-146.585616,-108.805225,-88.551907,-94.838001,-94.824278,-103.745878,-139.507731,-146.701749,-74.16966,149.265792,256.240581,268.603615,187.365049,96.566024,135.012494,199.11273,185.910753,233.649351,400.470685,447.058005,380.487004,283.71161,91.508829,28.676261,-44.319999,-19.842908,25.317275,78.861189,64.432569,8.326608,-8.488626,-50.760735,-112.209629,-137.901062,-160.020226,-130.940126,-39.682546,-40.381703,-135.026952,-174.496298,-176.772945,-168.999458,-176.467494,-129.082013,-88.077283,-80.235528,-63.799606,125.2789,294.329089,307.028029,273.808977,278.339903,328.763872,315.117375,196.906334,139.039177,52.664466,6.784596,19.612793,149.765834,230.494336,208.806758,106.779062,-25.300939,42.485627,85.289183,100.577755,87.882289,61.107712,55.767669,82.254232,79.932018,-8.81671,-24.948147,10.98935,83.684934,119.869286,180.650003,188.223278,162.500182,172.671828,199.942991,197.38504,150.228064,18.961616,-64.635538,-294.586121,-381.424753,-324.716911,-143.530511,-127.932158,-222.282059,-259.927843,-276.751482,-287.592897,-336.252659,-298.688261,-247.859243,-141.663365,-68.649317,58.856958,63.143208,-15.387874,-58.049849,-48.495567,114.849908,191.350184,278.261109,303.008867,300.020028,265.159515,152.846298,109.639229,165.226944,364.122058,438.039496,445.004504,419.132174,430.824902,431.41186,322.73709,290.669393,360.591246,516.272226,543.205445,483.482712,417.717363,255.507868,195.351638,226.735961,275.951761,294.669086,371.351408,382.505001,246.327538,133.655375,8.296175,101.748964,195.632245,387.143089,425.524062,291.085269,182.908802,59.000075,58.196631,85.25197,90.254903,44.347085,-34.595079,-31.282181,-60.973975,-141.418573,-317.571889,-338.697483,-337.557487,-410.928326,-463.884799,-527.763994,-506.307345,-371.874683,-246.697262,-195.138144,-134.076541,-130.240332,-131.384644,-122.888107,-84.31258,-83.941231,-162.348539,-183.027655,-120.712208,78.161806,125.56385,33.362265,-21.529784,-34.121592,13.196097,59.006513,137.522194,144.103578,102.441954,70.302041,46.563373,55.54407,73.358914,131.046378,177.861683,280.324447,323.07072,339.678829,311.307946,229.745965,169.456121,131.047069,-14.213043,-83.934065,-81.171262,-28.327684,7.29211,-40.13523,-138.069395,-53.149084,27.402793,151.904339,176.934385,110.299601,44.988475,-23.512117,7.351447,31.73103,99.702956,142.217352,150.094271,102.963231,10.268105,-27.30991,-100.913236,-59.958841,-3.075941,118.25811,150.046022,66.455048,-23.726993,-131.685527,-107.467261,-77.622774,-32.886961,-28.797925,-28.095653,-8.962563,17.262696,-9.31707,-26.696709,87.978522,106.236534,21.45575,-19.748639,-52.374629,-69.652226,-107.654944,-43.810871,16.435335,49.971808,21.534917,-49.000519,-80.353779,-94.315068,-96.516122,-184.7819,-225.168271,-183.132157,-77.362551,-57.867864,-154.702495,-248.862847,-391.521913,-375.083879,-296.88616,-131.398204,-94.75244,-69.4642,-70.595856,-149.572456,-209.739045,-232.115621,-152.755449,-133.764523,-138.543593,-156.14753,-203.543367,-197.896706,-115.632028,-85.881631,-105.825041,-86.334083,-18.41351,103.543697,111.527764,66.875298,36.316333,-11.063484,37.876755,101.349449,230.270645,257.610656,215.20025,177.286298,122.697576,124.105231,154.745335,219.046203,242.536718,292.88189,295.815482,184.305238,88.925122,0.009134,110.05316,141.578768,123.453216,131.025031,174.883638,177.643964,132.471612,55.978191,11.288516,-3.080728,57.299519,164.344638,136.689037,2.409199,-43.572966:-284.137337,-118.148999,-81.914703,-42.852931,-40.092666,-130.979342,-197.77718,-261.143284,-168.009174,-58.07629,200.244116,308.64093,385.740731,326.080868,83.306207,-40.570433,-153.242144,-86.58497,-47.780163,-15.976054,-23.63811,-120.074551,-223.028738,-462.372636,-538.907837,-493.22639,-310.260648,-224.263954,-197.163176,-248.323006,-367.653542,-419.015035,-423.305308,-194.919668,-68.474146,-2.657191,-64.956969,-243.561246,-301.861404,-297.815336,-145.678388,-44.648227,123.315714,160.130773,67.271559,-32.044939,-178.420095,-208.546158,-183.507168,-33.431373,49.842357,133.326678,109.547178,-35.960121,-111.356246,-211.313968,-206.897798,-167.463253,-55.15422,-18.110099,-94.238457,-190.296067,-320.495375,-320.789273,-243.883153,-68.494385,43.805741,176.790253,169.919464,75.861616,15.573762,-119.749794,-148.606982,-65.021762,200.717037,294.216145,289.93207,206.84424,-22.194552,-123.820257,-198.638426,-99.772289,-19.740205,96.34518,80.977502,-83.258601,-168.873891,-244.930333,-182.064153,-130.107753,-80.959831,-79.324555,-88.478651,-117.119077,-230.598155,-263.682436,-142.908103,161.104375,298.565832,394.655324,334.354518,153.709711,112.026596,82.380753,73.441189,132.746006,346.861767,433.826578,438.117976,343.970564,42.570357,-107.402714,-233.153981,-75.952315,33.191984,176.046125,172.569251,-24.360795,-158.59663,-278.889495,-217.429385,-184.935407,-142.295021,-111.239233,-60.549507,-69.245354,-163.767808,-218.89997,-199.28137,-81.572295,-62.335088,-20.766668,6.250949,-56.451155,-110.134618,-78.454767,74.953368,144.790513,261.610439,306.681254,277.119534,185.164431,-43.237294,-119.093929,-120.829085,7.758314,92.351788,237.022394,248.67186,117.907363,7.673009,-150.092243,-46.899245,63.083099,196.376723,193.726366,116.311721,84.39818,61.837185,50.677091,49.581546,134.891224,169.003964,180.445798,186.475639,191.853609,169.196634,82.748714,60.648331,96.302599,212.281204,255.635296,197.420982,90.282789,-159.720785,-230.350683,-136.846029,57.355094,82.650198,71.980468,67.523666,-61.289115,-192.972468,-349.97604,-224.809297,-132.278429,62.974272,169.948891,237.98891,163.102525,-66.298205,-138.743318,-69.220858,161.443227,254.975393,326.975213,307.281364,247.636721,226.579983,137.970617,91.279558,152.330444,348.197529,413.42368,419.137253,360.079877,175.428066,105.736663,114.848779,254.793149,343.662009,493.151442,498.699304,351.968935,255.535952,142.973038,176.380797,226.783289,327.451845,366.990296,391.708596,359.855731,183.826595,64.737085,-65.900369,62.548563,198.403745,426.525416,430.260255,190.61994,45.894609,-62.353075,18.341804,52.390922,99.146022,150.089255,219.02579,165.874406,-96.491573,-223.89791,-268.237803,-146.858075,-146.464599,-231.525771,-278.889052,-405.099515,-458.600117,-455.569777,-289.145544,-191.497171,-69.780301,-38.244712,-18.423342,-36.176527,-143.404968,-220.207299,-234.597042,-12.586275,91.598069,217.802172,245.063135,207.667653,143.561943,-43.228253,-118.330705,-62.482051,150.739368,234.667905,217.001733,130.266612,-49.687557,-87.7459,-8.948068,169.477219,249.814976,361.996455,361.185484,198.011196,100.845698,29.42397,43.032565,49.466912,107.28382,147.626063,136.556636,93.918554,15.126724,-36.43391,-91.943524,13.322685,60.980458,83.646312,67.855766,14.471541,-2.076657,-38.634045,-20.906389,48.581964,209.350199,244.192358,170.413768,82.566906,-62.240788,-79.646308,-76.710952,-103.886569,-85.452751,7.650881,28.981692,5.084352,-25.856475,-134.251369,-168.186644,-115.663892,28.336697,82.188673,108.210363,79.751681,-16.678193,-68.691452,-102.774256,-36.601657,-7.038902,14.786524,-8.510046,-103.441852,-140.996563,-213.231449,-216.209786,-131.935866,78.315885,117.667893,51.651132,-20.85232,-206.226624,-284.239013,-284.781969,-153.551636,-119.775976,-94.256482,-81.717903,-153.351709,-254.3207,-436.219084,-361.415981,-234.46728,18.439978,96.230723,120.465231,75.583985,-70.693609,-147.901152,-217.21519,-96.168594,-4.040352,124.994793,129.205292,-15.776295,-123.161626,-237.434107,-185.188652,-129.112748,17.835702,94.648691,142.913247,86.201252,-110.876885,-187.406717,-145.587891,85.862037,177.584846,259.268436,264.262576,193.065911,120.399089,15.089001,84.880433,149.388306,249.270855,292.725216,322.663446,275.886735,93.144838,0.975752,-82.580104,16.837597,93.721221,173.744592,152.43795,15.790152,-64.002203,-143.721799,-42.931576,32.897895,133.799917,164.180955,192.070995,169.734943,23.32521,-72.643966:19.679845,-15.030983,-71.957091,-131.689451,-119.946596,-90.89647,-111.008156,-167.652421,-115.126222,-38.555393,140.190359,207.496345,263.031061,251.679044,175.1678,123.396761,48.662784,21.506783,12.052628,21.872963,37.520864,39.800444,17.978821,-44.539654,-63.120445,-48.782897,-4.097744,8.314189,-70.282328,-158.359694,-242.060037,-213.886594,-182.541852,-219.919455,-231.411735,-223.02888,-210.811924,-246.837747,-307.78305,-409.271175,-344.11461,-289.025057,-278.981922,-303.926314,-302.979767,-287.70856,-287.064166,-292.065518,-293.098301,-269.826515,-254.486828,-229.262342,-212.290487,-154.67132,-136.617447,-221.222232,-300.690665,-251.029042,-94.900952,-67.401925,-114.279329,-148.208778,-176.691575,-175.620983,-211.140045,-308.490002,-340.332012,-322.997179,-285.670836,-190.748764,-152.667625,-151.551606,-181.431292,-162.799957,-89.437792,-53.970549,14.79161,26.541284,-57.767361,-119.393139,-163.930746,-103.946984,-27.113335,155.576796,167.951163,-5.099153,-93.290132,-149.850848,-131.839183,-112.475438,-59.972172,-20.129028,52.384743,59.570445,21.762182,-8.645648,7.653313,213.762924,320.647961,348.762225,281.366268,163.364787,159.228344,232.04003,224.200827,191.818466,243.612183,323.327775,382.946918,323.603259,158.804004,97.901699,12.493398,14.568515,41.26009,82.820895,86.605632,59.385835,40.173024,0.242296,-29.305216,-32.807212,-40.31537,-44.289867,-50.829121,-60.924609,-98.763772,-119.075386,-111.585581,-42.526337,-27.665211,-73.265983,-97.768494,-33.092015,47.318884,167.423717,203.508328,231.783699,299.427519,319.859273,354.840601,354.255006,235.64757,134.750929,-9.078623,8.533513,59.954087,157.083239,159.006096,38.711311,-41.457481,-151.737241,-140.562485,-102.593144,-128.73015,-192.796453,-254.339087,-248.571398,-202.002242,-148.00027,-91.398982,-131.462682,-118.383939,-56.80734,-45.166802,-33.756528,-10.008183,54.758527,103.200461,125.830227,123.819976,99.597594,39.390175,-13.92948,-145.252073,-178.829474,-125.765916,-58.228038,-94.402434,-192.094355,-179.105946,-96.051592,-79.580795,-106.204306,-138.968775,-113.376393,-0.698849,26.302331,-43.624854,-107.370179,-154.967817,-133.734747,-112.783982,-94.379087,-41.039153,113.426696,148.328584,62.218549,7.641061,7.058892,78.588401,130.462146,273.081102,339.303035,379.827252,360.948242,321.95928,293.829008,197.7706,173.669411,212.008053,303.671384,329.440093,319.027579,292.237744,198.599088,112.171355,108.969863,127.144256,149.035636,266.401477,317.52827,252.427549,156.751276,46.788201,201.821696,323.379753,448.916293,432.221706,341.771224,302.716487,221.512291,188.412934,196.807617,140.301951,77.998155,31.82543,61.494243,112.30364,90.031544,-31.82563,-154.352247,-198.935265,-240.884463,-251.223067,-253.22506,-207.947117,-33.329625,65.615744,62.649628,17.993084,8.155789,14.892938,-2.110251,-99.675056,-158.832488,-223.29958,-163.515245,-111.694025,-26.085637,-1.468543,6.100123,-8.964458,-68.513549,-110.582735,-93.85313,29.63301,114.077991,175.419529,112.573106,-41.367365,-62.578419,-28.257385,10.781285,44.074102,219.818548,310.579745,287.471815,209.894973,115.1434,63.545172,10.528368,-115.852193,-136.502848,-42.93288,11.465471,-12.61788,-78.847135,-152.522226,-19.040975,75.802958,219.914754,258.720187,259.05285,244.55309,258.688578,274.255065,261.005723,229.232814,218.258212,189.395034,145.463263,13.450352,-26.544498,-31.847839,3.109279,31.134499,76.596576,60.270924,-44.653466,-81.066022,-85.003738,-96.777121,-118.218766,-141.94301,-118.192032,-27.88139,-3.319631,17.430045,46.432917,94.102261,38.606798,-12.467857,-73.875138,-65.534274,-44.066191,-60.918614,-104.248259,-73.067618,-49.681447,-68.301244,-78.413958,-12.423828,36.701661,72.915218,57.190979,39.041131,88.511199,93.965207,78.836443,101.985489,162.099174,146.774334,18.213543,-121.927279,-156.983599,-97.62846,-7.839384,110.722393,86.466138,-5.540522,-22.265982,-42.409056,-96.560965,-115.017073,-97.678243,-72.742446,-47.290392,-60.665363,-119.487347,-160.337283,-154.769257,-49.520559,47.410152,199.577571,193.719045,56.748337,-7.890074,-77.83629,-94.353107,-61.708805,110.640628,205.48211,240.733292,174.023004,8.106284,14.443996,89.436079,187.952842,194.461943,221.358021,226.002685,137.658941,69.482609,23.269447,99.137706,118.187343,72.381302,48.6401,85.329977,115.054821,85.27202,41.486547,43.421882,14.620095,5.672717,75.056542,115.457011,104.925017,66.972023:28.493524,-37.924088,-103.511238,-179.448269,-171.226355,-69.731363,-1.907815,58.891037,61.22052,82.979946,154.940684,177.827415,150.402411,121.612892,108.236683,102.85663,33.272657,-47.571581,-66.854085,-59.652307,-35.719271,35.012333,47.058976,-39.35934,-91.689093,-39.138791,94.66052,104.741864,-7.966373,-90.606893,-158.17538,-132.024226,-93.441878,-137.246316,-164.998176,-198.984312,-217.850226,-266.33214,-271.355502,-260.823341,-243.637382,-212.039869,-181.188492,-194.021963,-224.593084,-243.796126,-316.336713,-366.652897,-411.984304,-357.953764,-343.353873,-338.643811,-320.690645,-255.203405,-229.90977,-234.98821,-248.457257,-235.077908,-229.594335,-264.581312,-344.335532,-337.545783,-255.640467,-239.499665,-295.732424,-368.58158,-399.226511,-394.267445,-319.218897,-105.796949,-48.154531,-84.20688,-112.884878,-84.68045,-44.557846,-24.225924,94.037723,131.791351,4.939383,-111.980625,-204.06263,-44.917398,30.492297,-8.208585,-96.797235,-200.790939,-189.720326,-192.697131,-232.729564,-194.579913,-92.879132,-76.714537,-35.6524,16.290847,124.76201,149.790314,143.931144,183.904214,235.202993,289.6539,256.255796,164.876266,168.759659,191.078509,108.791883,99.690979,232.674922,312.759858,316.742301,241.432372,100.820818,69.713791,34.406746,85.246817,143.551906,198.68257,174.039049,95.749782,71.583954,22.656592,-65.563358,-94.308999,-82.617647,-63.187001,-85.194636,-113.976209,-82.664668,-46.995526,-58.833506,-89.87403,-90.732309,-94.342022,-90.892537,-25.521959,45.42757,172.072981,191.443689,178.126552,164.628419,200.664509,327.657705,345.977723,248.74125,170.432322,23.734189,1.905605,37.017846,128.072816,155.073975,81.594286,-6.452074,-127.212099,-70.192664,-20.179938,-22.032446,-50.457084,-10.795478,59.548762,194.658852,208.203201,95.921124,-41.089919,-71.628071,-22.835574,46.400964,142.500444,153.122798,166.443525,133.449222,84.334427,-62.37984,-131.378749,-163.618684,-156.154627,-259.415426,-358.24611,-441.880556,-334.510433,-318.361581,-427.686192,-481.724313,-462.870802,-402.514942,-321.319297,-355.2677,-360.357454,-274.397697,-199.722806,-70.626487,-46.36268,-75.546169,-101.877742,-94.369049,44.204406,116.719185,177.557758,184.083863,194.918668,191.816099,148.753148,121.489744,165.416744,352.807245,436.237522,468.84323,449.202949,440.656138,423.909499,316.120008,274.629687,327.549915,447.379106,445.154036,339.896576,289.530055,230.651894,181.842276,155.72442,118.625721,126.12504,208.198283,249.890846,215.608711,131.827171,-23.300683,55.138332,148.292438,253.469499,244.017785,188.69861,176.703888,117.370282,-16.440004,-51.923487,-52.898252,-44.100699,16.954836,59.668339,56.998685,-4.693362,-162.369754,-226.287254,-229.695768,-258.375084,-308.071584,-424.893102,-424.085681,-249.002392,-52.546601,-33.727078,-76.08841,-57.774666,17.690886,7.4269,-77.471959,-92.740865,-51.989904,-52.410082,-79.616798,-111.470457,-108.162339,-111.459742,-124.707205,-151.058071,-118.682711,-86.101486,-39.026322,2.631848,73.17116,55.022586,10.092507,13.159465,-6.735903,-3.024855,53.170285,288.25167,400.860165,388.260485,294.219811,177.758439,194.475293,183.97772,60.116298,-14.70873,-129.041726,-171.05114,-191.558933,-180.045491,-162.871226,-81.195495,-13.642135,155.477273,250.203948,357.935276,347.162155,251.31363,193.269006,204.724477,229.685586,215.390028,161.096399,151.852179,199.924543,211.622445,155.810099,150.2735,170.586119,185.505236,188.804697,205.278133,201.502651,132.44707,77.248015,97.391642,137.397922,115.695655,64.753216,74.944074,109.725912,100.58215,103.895942,146.222656,118.349693,43.683985,57.205789,115.435028,109.383671,14.106807,-66.698597,-59.64336,-8.066287,4.795563,-30.790155,-64.719322,-32.536869,33.587768,68.862414,-49.997382,-80.308966,1.922088,55.410843,40.250839,-3.876088,-90.163428,-177.496559,-195.380716,-130.377893,-54.732089,74.952045,87.92463,17.471085,-54.559992,-209.86902,-266.711869,-273.878167,-264.168295,-236.994603,-188.076212,-180.36497,-187.123682,-207.926673,-212.634197,-167.367031,-102.648134,30.446607,56.65835,35.459126,-4.225777,-107.788924,-50.807853,53.453472,219.48172,224.209334,115.666309,73.362103,70.980691,43.018821,20.701677,38.68776,93.451632,218.559398,250.303839,246.246709,212.525134,143.764477,155.806504,148.679305,115.344885,146.909263,235.13596,218.331232,89.178542,-5.368323,-21.206792,-5.893842,23.493894,58.363749,35.921676,-44.953566,-87.071059:-251.332394,-176.739762,-145.502952,-77.203151,-54.806289,-92.024254,-140.801921,-171.782571,-53.01846,17.521439,140.150515,210.738003,322.310243,322.703154,216.493246,136.808819,-6.178875,-72.063691,-76.092894,-47.576341,-48.935584,-146.749083,-212.401928,-309.247745,-384.227824,-376.610182,-230.698101,-153.435812,-162.96816,-235.002151,-324.796624,-337.95966,-389.170419,-312.791843,-225.537339,-172.702825,-223.308411,-312.67427,-291.220661,-205.15301,-232.561893,-257.431636,-252.130924,-224.125614,-138.435427,-123.126874,-213.788382,-260.568964,-183.58301,-10.810909,22.837829,-16.185389,-50.362872,-58.526189,-35.419788,-31.364839,-71.426159,-64.218558,10.216204,42.431731,-22.564003,-115.800805,-247.47999,-260.956038,-271.231111,-235.108523,-181.280388,-90.507949,-85.17148,-111.704541,-115.4444,-147.863951,-194.548346,-148.531285,49.074999,114.859249,90.468783,38.775289,-17.983819,-24.502556,-79.234689,-103.361292,-63.221876,17.488347,4.83051,-67.799809,-63.037819,-6.918269,-11.157758,-17.814421,-11.468968,-10.337819,-57.159389,-94.851073,-98.537214,-62.427023,21.623547,151.559585,236.651649,320.226205,275.834576,164.895545,192.115658,276.032961,206.58744,216.879824,402.403189,478.965676,399.812899,272.492968,48.453241,-11.523529,-30.26009,81.104068,133.295943,142.851595,128.05371,92.64131,38.7883,-125.59917,-151.920597,-115.354344,-110.063816,-128.539699,-110.333262,-78.253126,-29.01535,-54.031815,-145.571191,-63.73422,-3.064282,-1.567246,-37.535563,-43.904888,1.497407,77.99227,149.903057,237.52525,376.239497,356.26574,218.411085,164.19188,110.205152,78.853875,-42.575883,-108.635976,-47.181169,175.64951,210.366381,-4.007434,-143.776235,-223.646013,-116.499895,-60.548817,-22.284136,-35.610863,-102.595383,-164.693351,-250.129797,-232.757541,-158.847071,-102.741348,-55.16828,38.015891,35.955729,-16.277396,-5.218465,47.580141,44.944541,61.10415,115.130343,122.25201,96.752492,52.433215,-102.059693,-165.996899,-137.880306,13.102853,34.449144,-32.847431,-54.042995,-34.833885,-37.859497,-119.161428,-127.892802,-69.401953,46.870565,86.672371,142.507555,125.212068,-19.448829,-87.880161,-103.903282,38.169218,128.601068,216.089855,193.670076,90.708873,61.246088,58.676475,69.295158,101.569402,231.644844,291.31198,298.761517,262.942402,197.531978,143.933636,45.608842,191.725706,296.449095,360.589483,342.201526,283.934972,226.371442,69.810959,55.716375,118.323726,212.936123,224.231899,204.41526,176.267296,110.978137,66.42023,-17.630456,91.424296,211.370366,370.834705,361.450697,220.136253,151.920918,53.34298,-13.650175,2.7876,79.343863,97.658353,107.745861,113.199694,70.531829,-17.707954,-240.803139,-221.480559,-162.574587,-167.4219,-209.098027,-269.96332,-279.741882,-252.636284,-234.639774,-232.07296,-151.10044,-76.372945,19.291274,4.171689,-118.8943,-192.638608,-284.935907,-173.863019,-68.546593,65.278267,70.427009,24.951498,-4.319454,-104.93409,-156.651282,-94.273171,124.004344,190.099913,145.928208,70.396065,-29.101658,-22.342588,36.95498,113.206325,172.771421,307.500169,317.195537,152.301215,61.13268,5.261274,20.092615,25.11814,-24.37348,-59.698189,-40.309218,-22.344861,-83.915371,-122.709652,-87.287329,44.827622,99.65951,145.240115,135.513811,85.834916,69.731818,32.703002,7.410767,40.562611,134.805435,172.33495,198.952517,150.927506,-20.721321,-81.522739,-107.676026,-93.034985,-96.747411,-79.38821,-50.801493,-70.889543,-126.177552,-188.648795,-110.39795,-51.135744,-27.967596,-56.161015,-45.784592,-15.688563,-3.475321,-25.276497,-81.250745,-23.348525,22.318138,-12.315277,-80.247929,-189.037003,-203.279517,-157.144573,-35.017533,1.283877,-24.354427,-19.44596,69.227861,83.837609,-23.365232,-86.301414,-91.983943,-1.898914,39.741146,96.719209,92.317618,-32.310362,-115.717666,-186.212583,-126.599355,-67.151977,63.38409,106.99135,122.390469,101.297383,50.997494,25.231324,-60.697235,-123.347456,-114.167048,-37.451519,-2.283668,4.017748,-14.326068,-67.374294,-98.730266,-72.823,55.382468,127.572079,200.431345,184.663072,76.080763,-2.192631,-117.132425,-49.129942,39.223895,237.01504,294.448963,244.463232,195.858088,207.813639,252.051468,246.083962,213.567325,218.623806,278.985121,275.216823,139.046398,64.57078,24.690448,64.978461,61.573149,24.820947,39.249653,134.852712,159.201114,75.257279,-54.646509,-76.253815,-32.792765,31.191594,176.021903,192.338778,70.175493,-9.247111:left
151.965765,219.839087,205.814895,172.213491,195.049034,283.352117,298.211848,241.390496,186.785321,154.829388,29.49391,-30.490432,-77.928157,-78.550212,-95.946251,-108.905507,-64.713298,58.757383,111.701625,175.917817,166.167682,28.237564,-53.30817,-125.63953,-54.209196,-7.136605,-11.733579,-59.639345,-163.6056,-192.656332,-232.750026,-267.52819,-276.208432,-171.949371,-142.919932,-156.573993,-177.161288,-179.157599,-136.869035,7.590299,116.051388,106.299112,-50.054862,-152.090199,-316.28333,-358.317835,-334.710342,-277.070607,-89.21127,66.312816,59.322915,-62.444927,-97.529165,-52.72957,-2.388467,91.083307,200.68477,254.598157,264.942833,213.365433,61.854909,8.606345,9.797952,43.817707,129.385191,197.396638,218.815788,235.783611,197.418472,15.814124,-53.996151,-22.504302,91.879808,93.488385,-27.100443,-74.470865,-59.952421,-52.29267,-109.16353,-147.389013,-135.514011,14.937621,66.591847,43.957661,16.433599,29.066433,69.700195,150.921753,164.282883,155.359344,181.525221,211.357916,178.720408,130.940065,156.720471,233.641446,362.16437,336.369937,280.234057,224.599967,252.69348,313.428289,301.94659,215.361059,162.304535,160.460229,145.525032,119.826796,16.950477,-48.367886,-77.519196,-15.007442,110.50243,61.531168,4.501413,-57.036622,-55.53264,-61.634792,-83.226332,-107.269387,-69.668627,-42.068691,-24.31355,-28.137696,-40.493159,-45.03898,37.02032,112.173526,180.510143,128.790761,103.832145,59.483133,-3.056723,-191.001944,-220.943628,-13.109904,267.391848,308.109162,249.058389,224.659873,209.987201,200.340584,218.497566,263.805107,395.407798,445.342949,399.851416,267.292773,236.636716,261.965138,296.214034,383.852265,545.793502,613.235668,590.920275,528.092534,369.014035,280.362711,207.910436,250.450292,360.944785,310.760211,211.942244,12.420109,-34.404348,-20.697416,21.088729,132.945288,182.790058,127.179083,-68.439615,-107.248178,-63.948879,-70.029935,-197.521336,-256.544606,-234.725441,-115.111293,-82.040768,-130.221664,-203.55881,-292.30048,-258.292763,-151.739606,-112.505274,-98.200047,-80.588133,-99.74713,-248.628494,-340.868708,-364.54664,-294.674928,-144.963467,-67.233072,-58.452172,-77.777093,-108.407225,-234.650008,-290.418178,-252.943568,-35.586489,77.843623,200.951514,210.539623,177.9186,157.311142,173.605573,228.872122,422.246384,578.165209,564.023594,356.382287,227.532875,112.317591,155.70415,309.718542,359.690651,337.232927,281.862551,262.396923,160.863823,87.259265,36.302926,68.086314,188.396901,276.364724,256.045438,137.102754,86.714591,27.163199,7.059499,-2.143717,86.379697,154.620114,237.242442,228.305244,122.538123,61.712802,-15.036897,-40.775914,-30.785332,50.567738,56.230711,-27.364413,-97.399101,-246.773722,-306.638997,-366.058385,-261.172136,-143.863195,73.429857,107.439867,-1.417172,-57.309913,36.152197,136.026916,228.065848,232.196629,242.377696,261.078362,262.035781,264.257515,282.274893,344.507895,366.652538,354.749596,358.982162,385.783072,354.885527,260.456188,104.84348,137.35735,323.852087,320.292776,241.45915,146.602718,151.064342,136.698498,100.145445,54.949142,79.40053,60.194598,-103.382589,-182.557587,-200.889535,-147.003064,-8.254054,32.429844,72.86706,117.107415,115.417527,70.403133,55.085445,30.343019,-0.236241,-74.373998,-69.237132,-51.199109,-60.825389,-60.367832,-12.994161,3.115625,48.97677,98.810566,213.186897,291.728809,284.572863,180.305099,117.975457,51.366919,67.693211,159.34256,234.361697,252.600853,232.843032,192.12251,30.362271,-72.891853,-171.666714,-139.790621,-53.741484,-96.082348,-148.232428,-216.257474,-239.901354,-306.828912,-304.865603,-182.92017,-86.386089,-85.321923,-141.03499,-180.806231,-304.66652,-377.407368,-413.980038,-379.923507,-362.537033,-445.577957,-496.904522,-562.871452,-552.981152,-449.890233,-390.566587,-284.238788,-110.802303,-52.273719,-143.259327,-236.855438,-348.701067,-363.259561,-314.485841,-262.871397,-176.266,-156.76631,-168.269527,-207.105506,-228.934613,-220.644598,-175.500711,-101.068184,-144.440377,-183.103351,-227.811369,-228.76777,-186.738088,-137.886028,-42.208295,-33.877771,-61.868059,-83.603179,-91.577635,-90.026507,-87.120854,-96.381916,-100.996241,-85.727027,-7.222599,42.055589,100.755306,109.649472,106.271217,110.801775,166.110399,190.923754,148.989921,54.890107,27.450896,-0.323761,-30.633211,-132.366053,-158.589832,-120.927236,-20.841132,29.956098,50.829861,10.516142,-101.811352,-138.728951,-152.700936,-138.765777:57.650545,59.925893,23.864006,-3.725021,-1.867176,5.822317,12.873156,65.240361,158.791796,143.532061,-42.910964,-139.810875,-202.93293,-165.956926,-79.576141,-87.21706,-157.644654,-150.962256,-108.819886,20.08758,60.847098,49.823997,42.680069,89.618491,163.695187,168.4684,110.184838,62.516053,-76.191674,-138.39681,-124.53767,-62.331735,14.449994,-69.161417,-141.173002,-208.848569,-180.295772,-57.908997,-1.677786,116.100104,236.53484,232.102542,81.401504,-0.683993,-129.076685,-181.913344,-183.918582,-104.9752,120.217816,121.85967,26.417935,-104.229644,-98.226113,-19.650983,34.100203,131.018434,169.166453,196.956285,276.549288,285.719815,195.121674,134.920516,86.091621,106.399302,220.696556,294.285799,281.381413,203.090315,146.612059,49.642513,43.938486,69.847061,13.992147,-37.047605,-94.857018,-91.046879,-115.293423,-140.86721,-81.071153,-6.284685,78.981541,56.492453,51.048874,28.698562,-14.754224,-64.004545,-25.047606,114.352677,177.81965,172.333336,168.56203,180.039305,166.055405,137.861206,155.56818,224.177403,340.714866,257.437096,175.98072,106.367403,137.648282,202.374014,179.904592,60.447144,-7.327733,-9.687489,5.866624,-0.441521,-84.659051,-110.153295,17.540988,115.710914,155.689041,30.137967,-26.207421,-123.134217,-180.902675,-218.60143,-162.774072,-36.113591,-59.587818,-120.186748,-192.718879,-144.409193,63.136059,144.649621,192.489138,185.420354,183.789607,153.720728,107.803889,-1.441063,-57.430043,-163.199196,-167.568789,11.115642,186.356334,162.879709,25.718828,8.449515,33.175206,26.399454,15.944889,33.532345,81.372522,64.861267,40.471134,48.757841,85.183227,161.56271,182.517801,202.211488,279.880546,338.011638,383.864984,341.286934,149.72764,49.755664,-21.310246,18.617463,177.17723,240.510075,189.217243,58.373403,32.215925,73.575216,130.699856,244.16675,230.126675,160.862478,7.974987,-35.233118,-108.887693,-147.979353,-158.395553,-151.420953,-208.439901,-275.298777,-268.778154,-231.4649,-257.662806,-344.457302,-329.577826,-195.305654,-109.239278,-107.603614,-159.3448,-210.237958,-348.522032,-399.406759,-353.357777,-271.837148,-149.452592,-112.432241,-102.9623,-112.373696,-140.608645,-213.910576,-220.616849,-136.177951,-7.906341,57.697591,198.109461,252.034588,272.075856,258.972709,279.992098,319.77571,420.403781,509.928069,516.551395,384.744927,278.051804,154.410672,179.814532,353.419313,449.329309,420.210452,330.544352,307.433015,260.909363,235.822464,224.07908,231.633114,275.092464,316.605727,301.128775,215.103314,166.96602,96.84852,75.740636,65.757889,110.606714,128.691338,140.376118,136.886443,80.111408,49.682433,82.576443,131.335944,177.145872,129.027668,111.542727,99.413751,62.45982,-76.080549,-121.770287,-108.51632,-51.199915,-22.33861,53.805982,96.517031,155.333102,182.057937,275.264281,327.003323,394.333502,379.602571,335.914042,255.232169,223.566365,184.459081,222.607661,406.048915,507.377191,496.816814,430.908782,404.599981,380.080351,363.538653,325.853221,343.854619,442.559324,402.328067,330.699836,264.515755,277.434335,293.022126,277.417178,262.995295,247.462284,185.428449,13.714958,-35.658792,-34.226314,4.181918,111.415621,147.231993,195.186365,221.195187,214.511101,213.958831,202.779615,76.266827,-12.043199,-77.094674,-1.497913,25.764657,13.562648,-12.949993,-71.378032,-74.65544,37.058374,123.586647,236.582878,233.145291,191.480353,79.628583,34.817698,-3.304563,8.244891,87.382341,243.25015,322.937521,336.604965,243.080421,-39.689393,-139.203316,-104.740739,-19.026607,18.68098,-73.996542,-85.122641,-110.300306,-170.680154,-298.542213,-285.477372,-99.818811,7.379543,-15.327857,-81.573667,-79.610607,-52.58386,-77.539142,-196.443735,-235.206638,-253.172453,-336.416799,-386.705875,-421.161062,-416.944913,-366.218381,-311.988695,-144.995511,49.602346,93.702129,19.727435,-46.378261,-145.366726,-185.90639,-199.71986,-140.665776,44.36261,77.331172,-0.30937,-172.641421,-199.582818,-117.776052,-53.184155,2.923339,4.161467,-12.840516,-100.115625,-119.520946,-72.369711,-45.133255,-0.240819,26.312704,17.886566,-111.863248,-171.245557,-227.283495,-239.665764,-230.493133,-192.435302,-67.044762,45.220401,79.77582,89.954226,58.926593,-2.931275,35.743249,226.963263,281.16683,247.603749,169.822948,110.668028,-36.833149,-92.490553,-133.511959,-124.66888,-55.219773,30.852184,28.382185,-65.935034,-110.6888,-166.678752,-187.729339,-199.892977,-184.762971:-89.159541,-75.775245,-101.30685,-166.780022,-180.618624,-117.025357,-53.566246,68.014138,151.325515,152.03109,60.825115,-29.065202,-206.5601,-213.9678,-113.324414,-93.611602,-98.352033,-22.123518,30.788092,76.711933,56.234885,13.028742,40.226061,159.471489,216.661778,199.932586,84.738999,13.184568,-108.045132,-142.646138,-107.62449,-58.19194,22.633464,57.914201,34.810492,-82.777122,-119.455184,-38.16244,55.932874,227.254897,313.533973,298.78749,165.641611,68.122939,-144.618919,-205.486474,-119.238201,1.334215,179.046897,75.763269,-14.118067,-63.426179,-47.596519,-10.2909,37.21864,188.619548,283.288459,280.578771,189.239804,127.003123,74.453085,100.656737,137.719791,122.865197,138.265805,231.588848,254.01427,191.552415,136.530487,87.766895,96.037606,126.379365,107.400566,49.566382,-96.045492,-127.494494,-108.176955,-80.386444,-29.268939,-22.841944,-44.829323,-60.91189,-53.798311,-91.665773,-152.498845,-201.52445,-131.679099,90.42077,187.989799,185.059127,126.664859,81.415453,10.000344,9.342638,122.859159,218.245741,314.808253,211.589041,157.584056,148.154895,165.259734,154.490801,115.163736,20.777054,-28.730449,-70.929238,-176.050047,-199.883091,-193.720413,-173.584644,-74.236259,-7.280077,32.089982,-56.791648,-75.871298,-87.628643,-126.549203,-148.999865,-83.981293,-14.804254,-173.339001,-248.625971,-262.36665,-207.109138,-46.752582,10.613008,39.310159,66.015628,194.81036,178.999401,113.035119,24.269096,-1.385694,-34.059943,-11.950671,122.732652,220.745178,192.511659,21.145922,-75.895202,-229.488992,-253.260587,-183.965218,-124.987946,-18.01892,-30.432253,-88.691343,-208.083602,-231.29676,-146.313254,-57.666286,97.016206,179.61315,194.751102,187.993989,171.296742,77.309792,18.347102,-3.160973,31.470127,128.07638,143.773337,89.833522,33.671055,75.497621,202.286193,260.916865,331.05604,247.663673,154.637109,19.360212,-7.881023,-105.563062,-168.822721,-214.688241,-209.975518,-191.481313,-130.751216,-104.43485,-152.695448,-220.9377,-309.547492,-295.629825,-164.675587,-34.234548,-23.35574,-116.402905,-201.402366,-391.61735,-442.383084,-336.495611,-229.926858,-80.099703,-25.681887,-32.758167,-84.441675,-110.303342,-93.62433,-38.463416,68.854214,129.263359,176.81495,283.497337,306.186866,272.704608,255.669535,277.458503,286.185327,281.134617,306.438415,310.00029,250.414318,197.160461,97.957239,71.531388,120.863918,225.404149,216.690191,103.602948,73.838942,92.056549,99.626059,141.567576,203.614966,326.772662,295.899858,243.643625,167.755257,154.159173,160.069974,162.957353,175.24748,180.336819,153.249358,101.798014,112.660527,157.023667,156.414243,147.888197,171.951874,240.715024,245.657902,217.912358,87.001224,3.346993,-75.450964,-61.984924,-22.693463,19.215396,53.289393,97.566543,93.202194,81.923585,111.220048,244.332059,313.937579,395.849061,353.870567,296.525574,192.900495,152.006738,112.307371,143.923731,293.095883,403.816192,398.813222,306.169659,260.405001,197.650538,177.76084,209.730165,274.534628,394.737299,289.810194,183.623301,66.797147,70.941132,82.627992,57.509685,65.324173,187.388847,182.707225,-10.524114,-110.043158,-151.391853,-108.091793,-30.096609,-25.784471,29.576,223.318174,289.571278,237.434906,150.88729,9.730674,-25.276876,-55.654026,-78.712005,-98.295114,-119.643196,-114.061302,-100.350866,-102.736477,-83.67393,-36.523953,98.856791,167.621231,139.24459,-41.269473,-139.875011,-184.380302,-134.838085,-18.047645,86.142047,118.584636,88.276629,31.042201,-96.535181,-132.166621,-102.604784,-48.556305,25.372917,-46.031212,-97.187564,-172.995845,-222.907958,-317.202918,-305.034924,-148.132752,19.66562,43.2511,-19.367594,-53.259124,-95.409591,-114.07386,-110.648416,-91.428536,-109.380936,-218.319535,-248.549184,-240.820439,-236.924173,-210.679871,-179.526843,-65.858297,107.906414,129.46233,3.727191,-57.742167,-96.011879,-112.185049,-157.504226,-128.757139,83.634395,173.706886,119.284901,-4.150134,-38.774782,-66.709004,-55.987176,36.541195,124.872572,106.520693,-7.584873,-37.231045,-12.971588,6.405575,77.958457,145.946852,198.836679,32.200959,-39.939082,-63.543617,-64.891339,-82.91623,-71.99083,6.947592,128.868367,162.367258,122.555336,90.646936,90.259231,114.407086,190.312024,236.117745,293.816181,246.520908,182.353004,20.304201,-50.203647,-106.505796,-82.813909,24.680513,72.505855,52.851896,-36.166547,-87.283808,-162.032246,-183.632584,-187.608464,-153.023571:-68.748664,78.249468,100.98075,108.849857,134.607923,214.28546,237.058427,233.417949,291.262061,313.514024,162.543203,13.515567,-186.420511,-182.583148,-113.78773,-106.207312,-61.617215,44.615887,75.496816,70.996647,31.459596,-100.672261,-154.390995,-170.137055,-71.399619,-32.456715,-79.624802,-152.900812,-319.785262,-365.389653,-311.343877,-246.243755,-123.561307,-43.796835,-38.464564,-60.205402,-51.11154,82.095185,185.262225,314.858403,301.180551,236.729568,12.691309,-111.878019,-325.034911,-370.103256,-261.558652,-154.221151,-21.560978,-47.986879,-74.600243,-118.612575,-154.520915,-195.468369,-154.70023,11.628636,87.145141,54.189691,-31.911519,-30.042758,18.22322,34.583601,39.443511,33.199715,96.299263,232.476973,286.773383,314.508498,261.631871,115.839087,96.197132,156.51896,175.741774,142.690152,30.968757,-16.716078,-62.544186,-68.274503,-59.354721,-49.345909,-13.175164,20.108335,-8.174893,-129.96733,-154.664222,-94.419029,-44.586047,40.791963,84.948731,98.331402,152.657861,186.056678,173.109812,139.198767,159.327953,225.417184,368.926119,386.826236,356.907117,336.935365,341.71567,333.160082,334.443301,328.664555,263.207919,225.563169,126.294854,65.053668,-44.223413,-95.321385,-144.413228,-106.151938,29.225501,47.522525,15.756021,-68.242239,-110.502949,-115.417422,-68.532371,-29.723791,-138.909185,-188.679357,-214.786459,-187.142905,-103.517098,-72.73117,5.193547,69.24556,206.553011,203.910921,133.364785,-10.984663,-55.232025,-90.696599,-66.466072,70.124881,192.955853,209.309469,145.791212,77.673102,-48.331158,-50.761911,64.410926,119.339206,181.65791,253.108551,270.789377,221.642467,184.818431,186.886158,227.805254,326.314966,413.901583,450.543392,466.884474,426.309417,275.85856,216.598188,217.971365,258.891277,324.819814,272.735507,199.016667,88.270526,90.070977,160.207072,195.522745,238.462778,207.315005,118.564824,-137.639436,-214.035066,-254.523143,-278.834367,-377.34299,-405.187815,-294.891056,-131.723931,-144.807927,-308.980687,-367.087869,-326.052847,-254.847024,-131.738271,-63.594063,-61.221262,-151.520401,-218.554642,-353.285822,-403.43031,-380.303721,-307.732854,-125.2856,-30.842747,-38.055974,-57.813832,-55.10791,-93.726833,-129.332111,-103.984866,94.084244,188.727635,268.74859,278.114557,256.476299,223.388454,189.175098,212.480478,337.737628,463.227616,454.349128,267.688773,139.933053,-1.499113,34.983535,198.758614,251.518315,252.708225,251.819536,231.09048,108.28977,39.251806,34.388159,111.130869,304.313192,361.110287,314.144282,155.867674,104.415299,91.150819,96.267469,129.32762,196.985362,206.051559,192.906096,196.69853,172.67009,133.595344,96.60109,104.133169,105.743068,84.907003,73.192874,42.963433,3.776301,-131.396003,-193.69873,-232.213749,-104.448893,-5.438281,145.128109,164.867334,97.364676,84.917124,196.997349,264.48841,340.276239,358.270766,333.554476,258.540016,234.900846,196.624275,181.919633,208.876377,337.986569,397.314094,362.067862,275.761332,114.399788,93.179077,178.888778,239.706203,284.23183,172.803244,86.216786,-18.166471,-31.571135,-43.449065,-48.982924,-40.644785,-16.424885,-33.265299,-96.539734,-109.978414,-135.76912,-156.585221,-149.374092,-96.026893,101.478327,208.081677,182.814852,75.167952,28.804803,-4.689308,-6.845422,-51.243493,-98.281259,-86.281215,-65.409124,-90.516251,-160.085179,-167.03445,-87.005126,-16.15454,106.783209,128.510798,95.732671,-3.435015,-53.615361,-123.049825,-114.582782,-9.795072,50.707944,27.474709,-76.978383,-131.154122,-251.493996,-294.540582,-251.948701,-202.822166,-176.490188,-216.145757,-244.576966,-325.943018,-377.509341,-417.509766,-369.048964,-177.204435,-21.629371,-3.629795,-57.114425,-92.435452,-164.216814,-195.191913,-212.583615,-206.744442,-189.280184,-217.134034,-277.207428,-402.725535,-412.944079,-343.409527,-298.663547,-211.817622,-110.498185,-80.122834,-111.678405,-177.183214,-378.591069,-433.958894,-279.464543,-122.480914,101.036899,69.487939,-2.693431,-102.630885,-109.868185,-80.111815,-66.736002,-42.97016,9.047767,23.293084,-1.125805,-12.978931,26.593514,72.627005,169.146169,189.165512,138.532791,26.434065,-11.038291,14.872092,29.17536,-42.20862,-75.00161,0.42369,159.895358,191.383491,107.459136,47.849799,27.729456,71.246359,209.442156,264.433311,288.672836,216.194393,153.245601,74.375207,81.112393,80.528617,40.842077,-19.981375,37.014342,63.130269,25.655942,-32.858727,-175.101101,-221.558626,-220.138936,-185.054375:-50.025394,-5.916546,-27.60979,-59.825114,-27.510272,107.011572,167.350191,239.250177,308.306903,328.606605,223.537171,94.757641,-145.162517,-184.420477,-105.19323,-30.519321,113.771954,149.730341,115.572657,22.585072,-24.545172,-122.074846,-136.650921,-39.883059,30.762424,-12.650948,-145.701857,-189.141185,-299.453804,-351.523286,-268.136556,-143.764161,108.877289,222.379879,181.322548,-5.63606,-41.604271,132.982254,261.686064,383.413757,392.659835,360.458069,152.520263,10.387456,-217.169925,-255.617971,-142.368545,-34.76458,127.943657,118.025159,72.210944,-27.759283,-80.742435,-137.801239,-104.679464,62.985048,151.66879,119.100283,-17.853862,-75.921172,-118.998022,-105.411495,-33.53632,15.324359,145.259568,270.16173,279.292784,168.446579,110.036667,121.778926,170.836959,247.81249,261.803389,221.059124,47.917306,-39.40549,-116.900175,-88.549693,44.506008,99.937902,99.918598,-16.72683,-63.237197,-133.693427,-174.53669,-159.894557,-59.733034,177.469277,178.360807,118.280556,80.816801,96.877768,57.950928,22.204853,75.717659,164.320053,337.213128,391.945131,360.808395,221.683983,163.689607,173.005825,215.89578,252.934155,218.087903,181.672456,48.749833,-44.223169,-213.093521,-249.28057,-192.932246,-121.321743,2.491447,-7.577798,-45.754325,-129.353406,-171.478821,-160.153211,-89.282828,-13.727856,-105.732594,-153.247455,-210.23397,-224.678759,-197.386731,-144.355607,-17.716849,38.730289,179.863241,205.648502,115.917938,-78.716201,-102.313877,-24.741789,28.302854,134.466887,230.871375,224.294197,79.561032,-14.726245,-119.009689,-93.480382,38.702363,85.903475,131.631897,166.123994,168.510214,97.344407,39.94985,19.036636,74.54872,226.918705,350.751129,399.402105,446.857648,413.627653,222.305486,139.063737,148.131174,210.338356,333.225707,319.210531,237.26879,43.010741,-5.831579,66.380145,159.933299,277.932287,234.484777,186.431301,51.122731,-40.861931,-236.789868,-302.893216,-331.414479,-301.765329,-194.571728,-154.793572,-191.1513,-305.374837,-340.163818,-286.841,-206.89076,-11.431258,148.168669,153.487522,-16.226343,-125.355635,-269.243986,-306.754898,-260.858739,-154.417184,104.664551,177.654014,140.745224,41.910745,2.424856,0.422728,43.245641,178.244518,308.982307,337.803823,335.03884,306.837385,209.91455,192.26787,294.239601,367.624938,449.465359,441.907487,405.722511,255.98941,170.51502,103.720245,127.06126,223.84196,280.866432,262.816268,170.287166,119.067101,28.613485,11.316446,86.964717,164.488916,290.73578,270.021646,218.03373,93.745564,45.603698,43.748819,74.238318,145.69801,204.517751,198.098038,150.912757,151.145266,160.992901,152.607152,194.616022,247.232749,274.329462,173.329608,122.293899,19.973773,-40.142483,-111.107524,-95.775701,16.084796,139.886491,178.468646,182.155568,133.645388,-12.410338,-38.719293,106.693035,232.705819,366.767335,313.250968,274.097245,154.295394,77.302014,29.693883,71.47383,202.478818,322.032786,335.52807,262.063543,205.43811,102.234105,84.068068,119.870547,157.702373,264.018859,204.428843,78.690912,-145.13933,-173.401081,-78.281565,-17.875475,40.193388,39.865485,0.768996,-112.877482,-152.329252,-221.794925,-240.271456,-155.710251,-65.64124,105.145699,142.835655,100.482986,0.960131,-16.008428,5.067177,7.213019,-17.779477,-21.683567,-31.707697,-106.640341,-161.301872,-236.773818,-221.661903,-98.849074,-26.089835,107.173711,149.212922,107.31075,-61.564043,-148.287493,-209.594036,-165.279567,3.585073,76.104958,30.219706,-116.413608,-169.021323,-240.715713,-257.982294,-208.607445,-156.597245,-91.77291,-104.517557,-116.809826,-199.541962,-286.229189,-377.012327,-304.537679,-43.961396,31.958453,-17.584208,-99.928672,-96.125195,-73.967497,-69.783486,-41.230535,-15.272622,12.979897,-97.006501,-201.098116,-302.555901,-251.705184,-86.771592,-48.421218,-33.802968,17.202013,16.081911,-87.799722,-160.911744,-301.329306,-328.471329,-188.442548,-47.06522,163.964767,96.578295,9.239563,-99.549715,-110.127382,-48.301137,5.402608,61.608459,64.701476,64.324033,57.592366,45.223646,14.919077,32.076782,145.000253,190.055905,180.566566,103.146978,64.491092,13.677334,-9.379086,-58.041061,-62.184884,-23.650282,44.87583,46.248106,-57.996217,-105.524639,-71.461184,-4.546753,114.319422,146.484483,190.366415,114.331231,2.488467,-155.237473,-132.62741,-35.603644,-36.973405,-64.53541,-17.837707,-23.12602,-163.359159,-268.321026,-393.730876,-372.023549,-245.26654,-169.526322:29.11953,106.308973,124.128296,140.923192,179.494039,300.259675,332.198975,333.18741,371.124586,365.463054,220.561395,139.653281,76.306162,68.532171,-6.755195,-63.736891,-33.182041,173.702408,228.861382,176.482502,104.903307,-94.233813,-201.146639,-295.275549,-161.963405,-93.691718,-145.20683,-237.898072,-391.406068,-420.129873,-367.378495,-315.659148,-231.446329,-138.13043,-111.474659,-159.411236,-190.260669,-114.237023,-22.002935,110.87148,87.409911,34.92989,-124.305096,-230.096507,-427.201239,-474.391588,-434.550251,-367.421189,-200.192188,-98.791585,-101.196397,-161.810951,-195.488216,-236.303136,-216.924084,-77.455235,45.628335,46.82751,-32.427932,-85.397408,-162.782594,-163.748765,-114.844746,-78.568059,65.669369,199.717711,221.802047,246.015096,228.435679,80.101353,6.495154,-18.922471,77.657778,103.454519,5.422554,-74.869826,-191.396906,-222.191061,-216.260212,-191.361057,-135.881588,-77.223981,-60.211289,-49.911149,-47.119292,-35.329312,-8.83762,110.482989,236.378098,242.624727,151.162848,110.735385,73.749606,63.344626,76.105574,114.330707,260.570084,341.968481,307.767357,199.822709,187.609122,244.72129,264.220311,206.914327,170.613705,193.192022,219.326533,196.605139,50.116844,-53.467254,-138.065052,-89.352587,26.557928,45.643984,42.824882,-5.37808,-58.672321,-87.095425,-23.734875,109.542136,74.606562,22.358201,-60.347037,-80.861515,-81.07039,-71.312797,-34.722846,-1.12955,49.487244,58.439603,66.427303,23.59045,-50.171481,-150.730452,-108.551618,102.198908,255.797009,267.68932,236.964692,227.469332,213.118397,212.570928,255.13298,300.183689,414.601892,455.667213,440.324302,392.267421,356.385846,307.350624,330.491959,446.358369,542.941572,558.095226,494.380983,415.636251,238.374619,207.630536,305.898727,372.858997,455.138439,417.384503,328.483521,123.196932,60.604367,28.041681,63.526991,232.681745,278.3382,180.03259,-66.878992,-93.129773,2.50538,4.415038,-134.945954,-205.440168,-206.121049,-43.313103,3.687221,-55.435939,-96.061022,-60.475233,-15.585639,23.417995,98.894842,150.888992,110.096983,-1.998209,-222.846896,-243.833446,-104.715829,-29.622417,41.306497,103.009216,106.436612,13.671111,-52.334482,-132.74843,-128.373008,-40.221519,97.212716,161.041784,216.496447,199.801528,132.981995,125.558319,210.161462,267.320043,361.649396,435.16224,415.767883,243.145774,160.429489,158.001656,222.772,308.579589,282.932137,273.189042,246.713095,194.572556,-13.759383,-103.762252,-66.196594,32.777854,211.598788,237.227808,188.426482,80.794208,45.39713,-2.193257,-0.167482,71.92225,162.440652,210.600598,270.698383,238.003823,72.577927,9.911564,18.922312,50.880059,82.13562,69.010022,25.768014,-128.750992,-206.393862,-291.604812,-316.050184,-335.630014,-189.856955,-92.400715,33.152442,58.573822,17.38,-7.937851,86.838346,175.709127,284.630313,293.03657,269.271887,257.783679,276.774651,251.043663,195.783521,117.561902,200.203376,252.276919,274.142563,251.790117,153.323113,87.48796,24.5739,67.581925,233.144524,217.647488,115.077431,-83.345079,-125.588303,-131.63642,-120.724342,-103.838903,-109.057171,-131.536193,-242.528628,-279.185565,-231.965695,-190.473807,-128.703857,-83.930063,52.380757,97.860243,43.306073,-71.12906,-56.684109,80.886322,127.708484,72.838425,-39.926288,-52.115694,-42.050728,-63.289779,-148.467453,-166.586435,-59.860989,38.147978,177.602375,168.314113,108.055913,-36.52925,-78.598271,-49.555354,6.324657,92.21355,113.417429,108.639895,52.152438,-10.451456,-203.230079,-292.441766,-307.614499,-229.738032,-80.435567,-95.896062,-137.838434,-223.070942,-252.440538,-238.900212,-195.121648,-55.364946,95.309768,109.150822,-53.86441,-167.107885,-279.146412,-270.297829,-236.489968,-241.674687,-206.435607,-134.71496,-182.343123,-408.570561,-503.905763,-549.654142,-489.303492,-265.674488,-139.387652,-165.373246,-268.983942,-298.146962,-341.260336,-350.149304,-274.748874,-211.965124,-117.220464,-69.941013,-61.41437,-38.346659,-47.463818,-144.578404,-175.191093,-121.189668,-68.529026,-62.570898,-7.308056,32.018505,24.909599,-2.293352,61.463681,137.655622,221.271453,202.028234,178.888763,97.430268,35.380777,-59.582491,-56.027703,51.063276,143.452887,133.423557,60.106604,59.652026,139.445462,167.560205,146.535278,122.741094,124.80141,105.170522,52.106417,-65.893852,-111.313009,-164.330339,-147.218785,-23.403674,93.085683,112.793562,50.275482,-15.586319,-104.889682,-113.462573,-118.606014,-111.163015:-28.460996,48.86488,58.917902,50.698293,54.444083,157.767555,250.255096,395.835036,478.092086,475.009292,266.322377,101.614389,-124.46978,-140.120733,-42.742933,24.656843,164.612778,204.823196,169.887325,73.995243,11.366322,-137.834068,-172.364867,-124.796518,-61.660021,-62.952925,-152.353023,-239.455498,-402.637098,-400.079468,-209.222528,-122.379419,-44.290136,62.003836,92.693345,12.557427,-58.760821,-37.415958,91.613802,368.745861,402.812461,332.152232,91.159027,-62.060185,-330.153859,-362.575713,-184.330984,-56.073987,102.771578,86.037725,17.501082,-178.82881,-267.75396,-292.661144,-215.677664,-6.437628,133.391297,127.108307,-31.919123,-126.162278,-224.297643,-203.636261,-88.866251,-35.794358,94.859668,216.307945,214.622953,90.867091,22.263503,3.104877,44.202348,172.453814,301.138153,284.845862,54.600695,-87.331061,-247.718371,-237.782463,-106.157337,-33.228878,79.915622,58.050158,-27.685771,-195.048934,-215.849975,-108.707151,6.754181,251.525918,361.945107,337.355125,173.097796,90.016474,8.469402,22.897191,151.341453,238.442083,418.747533,491.259767,435.395145,229.472862,158.789511,173.984838,227.507372,319.750729,371.300984,352.773442,166.490834,32.55361,-165.764542,-187.563466,-71.605251,18.5258,116.2931,73.314739,26.970614,-66.12599,-97.930003,-100.992389,-68.489588,35.229166,82.658046,34.404246,-189.114167,-281.310969,-265.682721,-191.519219,-54.924199,0.682834,85.203944,69.209517,31.893382,-79.811228,-152.358888,-212.704226,-140.931912,142.486134,312.741044,296.867584,136.262742,32.289251,-132.643783,-134.980342,82.496099,240.105009,459.228663,497.477037,471.25628,373.183049,312.204016,255.451368,293.55616,455.443161,620.113994,666.497551,577.023253,446.244852,185.905741,135.893311,256.506801,373.097777,550.902026,489.415339,355.236393,55.692722,-23.644313,29.015469,116.195078,298.12215,373.524651,303.880399,17.555584,-95.42183,-178.649671,-206.320183,-296.823421,-309.967219,-171.717578,-3.571916,-7.1209,-160.12301,-241.520347,-261.510829,-188.443419,25.703656,173.425409,173.325689,18.864146,-85.410673,-236.918532,-267.299793,-195.852454,-97.479692,122.528672,159.948789,64.231909,-163.23096,-192.696279,-69.216976,30.440466,198.546261,304.536471,347.658632,325.645456,237.643141,59.520333,47.831946,194.941261,299.155956,464.377094,485.420336,432.695184,236.481922,132.054505,82.703242,144.744423,249.352094,229.384543,215.340502,188.393178,146.343609,1.011574,-45.02519,34.905873,134.81921,319.173352,309.447292,229.193893,70.596884,24.521558,0.901585,40.585095,225.760916,353.399223,338.849522,209.568702,133.373244,27.860665,26.291664,107.778274,151.519,212.836036,187.172151,114.568968,-77.702973,-164.673845,-268.190591,-235.433555,-28.87575,95.093898,99.070372,61.672123,25.162175,-38.812646,-12.352562,184.410032,303.991226,456.379448,412.073342,333.921432,179.327696,137.19439,118.081753,115.843757,139.535072,296.664369,376.209532,352.328304,253.939319,30.618706,-21.757893,59.025182,138.452391,211.647178,79.038954,-38.39295,-206.989528,-234.665377,-210.95326,-163.673707,-45.582522,-2.001264,-44.543735,-205.428804,-261.484962,-318.719458,-337.709117,-275.294575,-167.747164,86.335284,102.35036,2.56868,-198.061621,-231.182442,-139.511923,-57.877845,28.785307,58.194724,70.022789,-55.244042,-184.610819,-350.661946,-328.704101,-116.437679,10.524996,162.893471,113.480959,25.399892,-160.887918,-207.522177,-192.959857,-150.694366,-19.433988,98.675904,107.812357,2.163521,-98.826765,-311.212225,-368.324191,-320.644964,-238.548865,-68.199603,-49.552731,-114.241276,-312.268618,-395.021198,-395.934156,-309.651795,-51.682602,157.194611,149.100164,-56.91393,-132.04797,-102.951466,-56.08409,-24.193173,-25.900519,53.086574,91.917011,-3.280133,-303.219647,-405.679176,-381.169419,-274.146966,-57.634926,0.178349,-44.388893,-265.623868,-398.828457,-535.275499,-487.189796,-219.916742,-89.091917,27.243424,-34.375726,-97.265418,-169.195165,-169.179457,-123.044871,-59.803682,80.691652,113.042338,129.600453,162.578789,113.946071,-45.166052,-48.242249,127.828403,229.79387,326.645789,204.018999,101.986399,-4.039757,-27.774041,-93.046845,-93.185668,35.921035,165.910014,143.652894,-39.251248,-117.497536,-137.633308,-75.130237,120.357025,193.96574,244.00005,167.411836,83.610805,-83.736607,-136.184031,-161.678335,-128.888151,5.528158,95.127152,79.26172,-52.805275,-142.794297,-292.314796,-304.91534,-195.180046,-112.181021:208.070328,255.705121,250.384598,250.043701,276.366736,330.153161,332.988836,316.97581,333.742484,324.517668,236.684434,187.415674,114.717969,87.328097,48.681015,39.522799,94.302302,248.248063,285.483084,186.681533,87.517609,-49.558595,-72.420022,-121.546955,-130.906021,-85.673629,-24.249344,-68.925046,-241.080823,-283.642881,-237.97839,-218.066766,-206.75906,-99.363356,-52.856975,-74.14308,-115.053715,-187.004113,-214.544268,-199.845481,-136.299278,-172.54002,-388.109424,-480.089463,-488.100467,-438.224361,-377.177023,-371.879589,-309.575264,-181.755565,-131.221342,-73.955431,-76.543906,-134.245299,-146.967697,-115.958619,-51.384067,-12.506504,8.241226,-0.566167,4.448971,8.219732,-5.552869,-9.211217,33.365719,105.875521,117.176302,92.63629,69.913966,0.436049,-30.534152,-19.167753,18.431798,-1.609049,-58.439571,-70.073019,-143.475377,-204.893904,-245.934562,-214.690836,-107.023928,-7.494899,3.030963,-28.496992,-41.599382,-74.750791,-94.947389,-101.117296,-48.020973,-18.831191,-22.47851,-50.075725,-97.692059,-111.294886,-144.74455,-157.255874,-60.745527,113.965278,115.273959,-27.854864,-78.206574,-41.402482,0.953332,20.652032,-7.316681,-16.88258,-29.612283,-36.923852,-119.440495,-199.735781,-245.984708,-149.873697,117.978996,212.528912,217.398026,241.314623,233.326849,186.722161,197.621964,234.875837,189.274727,160.99793,137.59951,145.579041,132.345601,97.205957,83.711172,123.553069,167.311832,114.154228,100.500596,104.14245,80.807909,-0.370293,2.011689,114.91866,218.42812,235.629317,260.326369,279.74522,247.572989,199.595085,182.081162,236.721326,411.370506,524.108022,521.13084,447.491258,387.853669,246.788567,212.318701,274.096135,382.235532,406.930562,347.177659,265.621399,117.3999,98.332571,173.938745,231.170582,283.722249,193.049274,87.425119,-102.322809,-104.934815,29.144528,98.313929,210.318087,250.89695,216.15373,106.744045,78.983798,86.311058,87.837462,37.297694,18.700862,103.921142,235.144761,258.147698,253.736415,231.429359,149.914166,134.05212,192.015618,264.191647,270.18145,197.771401,144.811338,87.231556,81.752483,52.846452,24.479818,46.860875,149.091295,136.739836,-18.867706,-94.253214,-162.107599,-167.013192,-163.017507,-104.415399,-54.872285,-13.228804,-30.628241,-78.049388,-93.429237,-105.068802,-88.458924,28.309125,109.96191,81.068098,-27.121656,-73.124843,-117.813834,-88.686927,12.354428,-9.130433,-45.653931,-80.03048,-93.709885,-194.093387,-259.411369,-283.653334,-256.280823,-246.333402,-228.683119,-181.73384,-74.764785,-66.650295,-166.96995,-202.872571,-146.075214,-25.012206,44.087861,105.384994,50.19057,-148.75449,-199.148695,-138.307047,-111.85694,-171.275225,-181.443954,-159.255243,-184.058898,-224.758608,-271.554667,-262.021282,-191.875101,-74.759297,-24.279156,43.263073,73.373477,68.24401,24.749555,-42.120482,-32.804413,63.559657,130.7105,127.408626,149.293033,178.165357,182.011414,163.8727,131.198971,159.744731,210.343441,258.230156,224.295215,56.589683,-57.940483,-151.328901,-69.623548,162.500508,180.595118,125.959177,45.087558,25.007568,-32.451796,-64.120792,-85.987855,-66.321234,-75.619809,-135.307362,-147.716829,-135.120102,-138.828347,-181.269359,-192.703229,-104.482457,10.215056,-11.710629,-157.193837,-187.062415,-88.717914,-36.236922,-65.722045,-105.208787,-90.453588,-112.716202,-142.230795,-142.982174,-135.181979,-126.881628,-93.562179,18.043907,56.386871,18.676,-109.44014,-145.49127,-138.327772,-125.795106,-88.68025,3.991516,38.332115,-12.005381,-83.901023,-244.989335,-305.05059,-313.660253,-263.474131,-115.667355,17.780803,53.539483,16.989617,-46.315378,-113.96643,-65.014444,115.684673,207.558517,201.747331,85.55377,-5.236666,-140.095225,-161.152575,-153.588298,-149.334858,-137.946348,-140.92024,-180.977265,-306.282408,-357.216014,-422.103647,-422.972866,-283.390176,-107.748045,-95.738543,-126.427564,-104.618554,-69.047571,-103.059243,-183.604667,-186.554806,-144.848811,-141.385658,-160.428389,-142.715291,-101.415644,-62.606722,-78.080735,-120.281215,-96.149621,-49.801483,-3.386546,-47.12983,-161.770465,-148.564674,-0.514812,48.942834,70.649529,138.896663,184.632577,223.863248,198.866855,80.116878,27.080987,6.27088,42.962415,61.718896,96.667581,116.28545,134.122484,132.603963,182.496168,222.590029,247.94299,241.757585,225.952703,123.611508,42.413191,-97.003595,-113.793515,-49.172658,39.782847,73.970366,122.658027,139.512002,98.175963,29.713815,-47.100002,-2.677801:275.771842,425.435609,464.230474,475.585066,456.783785,396.480457,376.621757,360.798273,347.47262,339.15302,293.680211,251.845358,149.996808,110.332965,65.221162,50.884793,88.32006,208.077635,262.388154,310.371169,262.845814,11.72863,-127.126039,-289.864799,-243.011115,-177.243849,-77.162972,-50.793349,-82.241159,-145.851504,-263.545322,-293.766802,-286.824314,-171.114013,-131.198951,-159.866708,-179.088021,-150.92413,-126.011451,-82.531436,-48.198817,-57.331666,-144.78696,-204.788557,-306.204502,-339.515822,-364.606366,-335.336195,-140.415561,48.670717,54.649971,-29.143116,-56.794663,-68.461145,-72.200595,-60.498597,18.623211,60.612169,85.747549,70.6642,-1.27976,-32.624482,-25.589332,4.008289,88.461967,148.130534,131.986515,46.64035,1.237882,-78.937414,-102.439302,-117.520628,-72.362592,-46.301849,-79.146846,-110.183798,-112.669943,-116.442502,-189.359864,-221.953135,-184.004992,-78.014184,-37.752147,16.281603,15.019677,-89.670675,-152.16376,-160.829544,-70.234285,-36.729521,9.582061,38.765511,38.677142,-10.617929,-96.83897,-85.555067,40.400551,132.284943,125.431882,80.834126,64.062222,50.432171,55.822047,35.626549,-25.760169,-41.115283,-15.818251,6.050495,-35.465042,-90.999772,-115.064227,-66.080447,61.48787,130.050311,126.782185,64.765503,24.591682,-26.656124,-43.24218,-67.249867,21.012705,76.96651,84.390487,66.441072,45.526589,25.098597,8.448437,55.784193,197.266969,175.885562,132.515757,92.004061,55.225001,-50.900675,-34.57554,182.043139,369.792436,387.016555,308.902238,259.382453,197.389494,186.346337,237.08243,296.575539,413.599081,436.05814,412.59952,360.488244,326.168973,243.939137,240.119871,321.722503,398.443365,424.309427,447.088105,427.947004,286.639902,203.586471,214.234014,291.547933,361.389986,224.047169,126.888667,14.823413,5.457883,-7.526104,-18.464297,39.546948,183.911029,191.166517,38.23827,-19.555601,4.712333,18.205223,-32.867711,-51.822778,22.501222,143.711598,158.784627,83.204586,37.681938,56.120532,109.939115,161.056728,134.961565,135.717928,133.275166,100.76417,-5.10937,-36.978129,-31.751601,-24.361383,-26.900768,-12.210646,-14.613218,-80.470222,-134.166861,-247.216665,-297.098081,-345.9523,-209.983013,-91.091318,40.59774,36.20739,-25.357078,-51.029493,-20.811404,29.148317,160.531836,264.129361,260.142096,140.145498,55.665515,-41.854934,-36.45922,-18.273864,-36.508806,-19.492773,33.076074,10.374447,-157.502662,-228.737622,-221.84283,-203.004206,-224.686543,-138.861893,-65.227296,-16.416242,-60.327896,-164.561114,-168.548283,-108.803951,21.394162,120.407732,218.256302,154.583295,-99.280379,-186.099076,-175.489838,-127.287735,-53.10414,-48.088411,-64.535019,-98.574385,-129.819522,-204.017761,-225.947819,-237.516027,-181.77653,-123.873341,33.230547,97.971461,76.761016,12.73808,-39.532213,-15.179319,33.878968,90.803447,160.945214,319.257347,332.466734,205.062822,149.46918,183.506679,274.627125,284.287698,239.630614,216.243409,161.443512,108.931831,23.870498,48.430472,222.496364,310.014782,286.143762,227.327727,202.342568,83.90244,1.213462,-78.417125,-13.504048,6.114766,-68.152239,-115.742811,-147.529225,-145.848912,-132.02995,-116.935562,-27.714291,58.02601,24.090206,-119.537414,-139.616221,-94.761619,-92.814473,-140.552833,-93.939318,-55.112617,-102.201893,-141.213662,-127.047042,-119.344405,-119.890256,-78.960139,76.803161,148.394494,121.261838,27.784802,-10.850437,-22.495574,12.399459,96.677278,117.884941,82.445556,-25.619761,-57.437017,-132.840572,-194.688891,-226.901928,-175.455525,-62.504357,-30.863615,-27.523549,26.499895,43.833476,-16.724333,-42.119251,-7.194623,51.899787,56.066837,-33.236057,-112.787895,-232.221644,-245.620682,-236.930678,-249.24553,-301.478626,-333.030084,-351.011906,-423.97749,-470.2097,-502.247291,-464.694553,-324.500561,-173.011788,-130.388925,-164.742656,-194.205559,-194.586803,-200.498901,-238.551681,-241.420942,-204.280267,-159.122674,-147.230411,-144.201349,-156.818346,-179.685826,-167.319554,-137.205336,-158.011509,-169.361605,-181.901083,-175.089009,-121.786365,-85.514765,-39.790687,-53.022412,-136.085543,-154.530712,-116.238757,-13.731319,1.709855,-90.387682,-157.493068,-212.977628,-101.584311,-26.037379,20.331306,10.991926,28.47265,45.467539,63.691904,72.579627,87.773904,82.554604,73.516917,42.688155,11.577511,-92.51302,-140.58672,-144.236647,-12.723841,65.224377,159.317772,161.365935,70.898719,2.919088,-76.315374,-61.540498:-41.721619,-40.683213,-22.080837,-11.219179,-4.892567,98.498913,186.910169,320.373756,371.174135,365.475435,221.807459,104.563585,-23.231902,2.554741,66.562169,61.71399,105.086444,251.404422,285.850411,180.193694,82.596453,-85.871929,-142.808152,-177.855622,-95.056615,-53.581352,-115.533926,-196.305236,-297.262906,-283.63047,-187.767416,-159.556102,-120.789864,-55.698991,-50.410221,-77.159968,-84.426304,-78.91236,-48.750574,63.178335,111.080269,57.424448,-155.755797,-241.996316,-333.405327,-358.135392,-311.728446,-234.062928,-108.839144,-125.7277,-144.268054,-151.604217,-172.756856,-220.362419,-196.017994,-66.802975,39.60147,38.033113,-82.243578,-151.782873,-220.056848,-224.516388,-191.106467,-152.474687,-33.301773,95.300086,114.017235,31.789712,-53.586442,-200.936935,-207.788569,-127.238756,-30.298713,9.438702,-24.41009,-99.667462,-256.015699,-298.290516,-240.912296,-167.258558,-69.060591,-71.339093,-92.871031,-116.67104,-107.15419,-40.017008,19.279696,142.337932,188.00203,178.84523,130.950107,99.269329,34.14245,19.602639,61.972035,114.024861,243.928171,272.69159,226.664124,87.045236,18.47493,-44.475636,-13.582054,136.807893,232.072967,211.951238,82.04788,12.630905,-120.659688,-181.420009,-139.198053,-16.00914,168.490214,83.260228,25.173053,-7.614968,-13.864397,-17.941593,10.035845,57.788489,11.888259,-7.023653,-22.439363,-40.946642,-85.206124,-94.078887,-89.265662,-86.29924,-99.078836,-95.319895,-73.433761,-44.565219,-68.150668,-134.593659,-108.031149,80.622497,255.187755,277.509594,200.186649,145.635826,40.657331,7.863109,107.727639,214.779341,357.360343,364.025064,346.677055,355.670415,366.781954,316.157305,282.302292,330.261462,481.618569,521.739786,445.934694,355.873599,172.909731,118.358408,140.949687,199.436233,335.998472,388.889481,349.647039,189.555636,117.126038,66.443572,99.67628,261.680758,358.367158,326.294695,151.678277,71.895511,-4.12184,-30.292981,-91.097801,-105.176116,-26.53517,118.695011,140.061554,68.441181,35.019635,62.343656,99.288085,169.61217,273.693859,293.426452,157.769579,60.460662,-42.237756,-41.892203,14.405118,34.490084,81.455572,112.123845,43.878427,-142.470429,-158.444111,-62.284754,-19.670561,2.515783,43.375238,71.399156,74.046541,61.106008,35.386913,19.266544,35.982634,81.744065,190.823553,201.521334,141.153402,-3.931362,-35.520326,13.401818,77.588806,174.367249,151.831732,108.906008,17.945319,-3.774006,-10.962964,-14.474446,-4.003474,32.896499,155.892948,195.689151,157.675105,17.266644,-49.409646,-105.675742,-88.732386,15.554212,131.955078,147.03884,92.289443,55.025626,-13.846864,-41.36648,-63.113526,-51.284914,17.325309,22.495615,-26.783009,-118.196574,-147.31644,-238.976118,-267.332649,-191.701271,-89.063982,-59.766246,11.451915,51.897605,85.792866,74.151987,74.273875,128.85143,321.319361,352.90205,272.971935,141.838333,129.755306,148.873571,162.067427,221.922816,382.031259,427.52577,284.516499,156.144533,9.011051,-8.361228,13.679467,57.910347,183.286764,199.458567,127.117792,-56.794905,-102.687751,-109.797758,-108.055908,-63.573744,47.583515,45.194958,-97.26128,-147.543343,-174.972719,-181.275348,-144.566424,-107.59902,-32.538601,21.877722,22.206443,-16.008108,-43.751677,-132.057514,-166.302443,-120.966023,11.261404,44.948275,-25.129333,-91.614467,-148.087843,-135.922433,-70.901523,-9.795249,112.60747,7.001051,-111.198214,-218.433415,-189.822787,-118.386731,-99.852098,-56.872428,15.412564,45.838178,-20.256109,-129.76059,-315.330933,-325.606805,-225.657601,-160.012029,-49.406521,-21.995817,-44.644423,-89.57171,-95.554679,-68.56177,-45.626695,8.302663,116.365043,148.392229,73.91952,-3.062007,-127.72213,-143.023269,-74.499424,-36.129152,-10.318909,-35.25142,-83.969219,-203.722866,-250.101505,-316.659009,-307.484518,-171.663712,-80.92255,-125.616448,-301.970496,-345.084429,-340.021421,-332.568987,-237.600768,-134.387171,7.330298,-91.961356,-178.775731,-197.556063,-132.250134,-59.79324,-56.835349,20.757939,96.506326,82.438301,14.230795,-20.495165,-40.386501,-0.373883,135.642955,189.360254,218.92733,170.347096,152.063302,148.802674,135.475405,99.264775,106.852762,113.49833,51.699465,31.192656,15.831392,11.108692,21.909437,60.444179,220.631426,300.409753,338.374653,248.472938,196.702723,84.645228,13.980207,-125.256566,-139.954974,-4.158392,135.433592,134.452635,48.258585,6.11835,-50.61551,-72.571385,-113.841313,-112.975242:left
-217.492951,-204.070921,-142.195859,-19.974474,0.606044,0.964118,8.411374,-3.309739,-48.775547,-48.064268,-32.564393,-41.03781,-71.913037,-81.557742,-119.546146,-164.076086,-219.27178,-164.678757,-139.63239,-112.788035,-85.86947,20.095275,76.411794,102.380463,104.77953,140.617599,140.716376,67.008907,-89.899006,-108.736582,-74.986779,-93.01302,-167.163927,-79.174906,17.704768,180.453695,208.663166,185.580407,163.634668,111.898304,96.175948,110.559833,131.969888,142.337213,211.868017,245.546337,145.454402,-4.862607,-277.956446,-248.003592,-159.576666,-15.221596,7.424026,-13.920272,-21.002421,-34.134101,-11.302767,52.143337,192.334573,213.195478,161.872039,125.831824,59.828942,34.579627,12.903984,16.123352,51.423009,185.693438,222.655266,145.644577,65.491389,-43.710653,33.514693,102.753993,159.650737,159.013436,121.209897,73.558974,-3.189947,0.722657,18.691066,-86.831019,-149.617332,-171.253695,-146.729983,-91.977688,-68.672961,-92.479227,-168.404505,-176.528298,-114.065654,-70.750472,-73.484866,-107.549033,-95.390794,-48.189434,28.2981,55.608578,75.639841,156.064918,203.626157,258.122265,222.636674,3.516468,-105.155217,-48.358378,137.083368,204.128732,278.771264,306.456172,290.578974,224.66346,88.810984,75.177788,84.435047,76.066575,52.603953,-26.012145,-66.045166,-96.606814,19.512919,111.281413,244.581813,282.03608,305.63781,287.841478,204.432973,142.513042,45.3101,66.042768,86.218018,89.756485,102.836374,216.179681,274.88056,239.643948,70.86664,-7.967077,-111.126134,-124.42885,-97.207834,-66.13085,-1.722582,-5.62822,-75.699938,-56.998887,1.411631,120.730769,146.480015,123.124056,86.031167,-16.861434,-64.806251,-83.031449,-153.421885,-152.81069,-78.350305,-67.691795,-150.309987,-229.166197,-328.263768,-210.923736,-148.690827,-164.340358,-199.774327,-176.038995,-115.318468,-50.153544,-177.478572,-253.072526,-237.98172,-161.174645,-108.856531,-174.078495,-295.501832,-279.293542,-141.464503,-12.688578,20.02387,62.435856,89.31369,126.562659,121.90528,46.173737,-42.884536,-29.661345,97.625507,149.063142,124.881914,71.795349,2.090107,-15.56192,-32.369674,-33.879253,-52.617706,-51.040195,-18.863415,-35.691001,-130.364763,-374.758312,-399.151258,-313.222665,-126.66884,-88.417192,-124.427466,-156.970297,-203.820074,-226.239632,-198.326109,-41.815118,9.019753,-34.49612,-93.72799,-157.487062,-153.639415,-144.123231,-86.824813,-20.621888,121.102088,174.43191,204.642111,187.218696,128.302938,85.636384,46.807316,108.971867,115.816008,49.696424,-5.801815,-153.202899,-235.157181,-364.732328,-435.638458,-480.913054,-521.640911,-485.456266,-440.768119,-468.419359,-546.134457,-566.01219,-543.851829,-507.526942,-490.143643,-369.261575,-294.321174,-257.72268,-277.165081,-282.583876,-216.677935,-193.044456,-223.705143,-247.316026,-224.668665,-194.538221,-215.241091,-287.736981,-402.272882,-294.404842,-209.610402,-101.171227,-79.56443,-77.388246,-72.387283,-13.253248,27.888853,18.765076,1.538211,8.289163,16.419147,3.142901,-67.102116,-121.693482,-201.185798,-151.459179,-90.273604,59.465443,120.680578,153.42897,130.9178,64.461134,116.440162,195.300844,270.618853,247.083203,170.192785,127.567842,51.938131,19.906591,-41.034338,-59.661418,-45.860326,48.860646,95.920383,91.619223,71.318936,66.889462,82.633614,85.983872,104.817366,136.374292,182.575529,169.250545,69.492918,-12.708533,-114.814613,17.669824,106.952779,172.791314,152.694395,100.965662,89.45907,69.939143,115.42564,154.097989,141.818173,111.880744,94.987449,85.085544,8.227142,-35.571896,-57.694441,-13.664547,18.382997,93.03018,117.971868,111.34511,85.318933,26.118364,71.063371,137.902146,218.23029,216.583545,178.261057,132.326921,-21.308195,-100.927095,-195.475899,-179.502991,-121.467645,24.86306,54.977854,49.192659,59.888222,63.04068,28.491517,48.361095,154.33266,200.994099,203.058187,163.821225,69.704964,21.594672,-53.804355,-45.618123,-16.113478,47.559213,64.455385,76.836764,68.224235,-9.967989,-5.10197,71.080176,220.525218,242.523093,206.264193,175.033976,98.113565,46.546497,-0.451013,110.884697,193.854395,289.660576,247.381601,62.84045,-1.33203,-73.225778,-85.018527,-58.762419,31.064411,104.620622,273.661785,318.491039,261.359911,172.571668,5.823677,25.14726,88.040602,171.455583,172.49119,154.038311,156.334341,160.856625,119.530376,83.860191,54.566599,109.099294,314.957359,385.152409,346.438125,259.115405:-151.245996,-140.504291,-97.161211,6.008235,28.591825,28.164308,11.436858,-73.6052,-91.873016,-39.97486,57.210641,51.061029,-35.777991,-73.536724,-152.256593,-213.972238,-271.881648,-197.485052,-167.195855,-154.91251,-153.37317,-101.081944,-54.540241,45.588854,182.207023,229.01772,191.164926,131.83577,35.708765,8.214778,-48.861201,-67.021291,0.207915,142.856443,205.159646,242.854657,190.631115,49.064446,19.215687,28.039897,74.396744,97.245228,136.47475,160.09431,136.283591,69.566085,-51.151545,-84.26881,-156.557368,-186.977172,-160.644736,-59.385725,-42.578036,-118.56472,-157.603354,-174.391066,-128.80295,-74.413993,74.533037,129.126713,130.222187,80.478699,-68.748694,-127.192313,-102.215041,53.768161,102.66244,121.416545,119.579138,93.223772,61.557852,16.401962,86.663256,153.791734,223.188665,207.623604,118.386541,55.145153,-30.214971,-33.770904,-34.979249,-42.94381,-22.747154,5.436684,-21.47153,-121.110483,-157.906183,-185.679899,-172.005653,-151.212042,-109.569039,-92.453621,-63.44302,-47.53555,-13.094262,-5.270979,-3.774519,13.839296,53.220805,197.545293,255.310516,266.374257,205.40219,-22.357329,-126.762791,-73.876179,125.375827,208.728868,282.002136,271.625721,191.291221,145.807804,85.791118,84.03689,108.955344,117.187262,53.872428,-84.260735,-84.621024,-4.153213,84.409721,142.657025,254.503244,284.597682,288.780958,269.365872,165.478702,101.352833,62.704289,101.574599,108.0253,93.257057,91.790101,154.403143,195.941677,151.263886,17.753973,-11.092735,-15.000918,-21.273576,-40.629721,-27.565436,25.327038,29.87837,-20.192047,-58.272592,-30.586356,109.563556,161.242816,110.829603,25.58001,-123.986876,-111.622361,-83.398136,-80.040082,-85.306732,-88.84065,-108.572261,-202.530152,-244.02495,-208.143771,-40.432132,34.541559,30.247294,-67.288702,-259.965555,-264.174412,-185.059129,-259.779683,-306.41882,-211.937344,-129.797993,-159.386484,-245.873436,-319.482633,-282.398344,-174.216258,-101.521822,-72.466675,-40.879874,-33.887096,9.274884,23.482686,-31.552036,-54.311384,-12.477347,83.018668,88.606218,-5.136798,-64.238765,-139.5179,-173.938669,-204.960182,-100.130141,-37.128639,16.627567,-5.258179,-98.06434,-144.594603,-257.422175,-361.954196,-360.299768,-178.518141,-59.2008,-10.51016,-85.92062,-256.546943,-285.815097,-183.389968,21.767998,108.848784,152.727154,95.57281,-62.097396,-101.116527,-59.117217,71.442222,117.909661,148.144777,171.480981,218.039533,208.365079,132.333339,76.470646,-25.730683,-52.207033,-45.089955,-26.879172,-25.262148,-84.865196,-165.78416,-345.485756,-418.615298,-448.140504,-495.096302,-476.639824,-437.159722,-458.025525,-534.764029,-550.265492,-476.672121,-399.471909,-391.673433,-303.185344,-237.873558,-236.063941,-294.229777,-387.845264,-359.220913,-316.507332,-268.538595,-281.646667,-322.832141,-314.422523,-278.763519,-305.492427,-403.358111,-356.222183,-285.509448,-153.704099,-120.637324,-107.749623,-122.748086,-182.243111,-173.186698,-151.362231,-103.232772,-65.317133,-23.994303,-47.865998,-144.504061,-175.104929,-162.519664,-81.271289,2.406211,182.647175,215.306353,155.771412,98.300442,17.076352,115.156557,231.502441,450.20884,488.676407,389.218798,313.893309,229.637519,213.548603,203.359147,153.732577,130.080767,170.387537,213.676273,214.563624,165.213213,103.65605,142.220293,158.419785,167.545809,185.384716,227.637651,209.690129,82.207825,11.625711,-39.398416,52.48349,128.662125,249.021697,236.974363,89.78854,27.683528,-30.907582,-18.301725,26.638621,112.433825,128.019364,116.659364,98.49706,6.063636,-75.063317,-174.759798,-67.305412,21.286698,143.560882,151.116294,70.685057,20.424559,-20.3436,19.483272,41.115052,91.997887,129.842897,135.527476,81.786904,-50.709861,-99.742865,-161.551307,-135.637316,-62.389001,106.426934,136.443664,108.013226,72.993474,-41.158907,-67.245763,-8.587739,184.724838,267.030196,286.823558,224.784077,47.354932,-16.157896,-15.366862,41.917217,68.406756,126.007682,128.495485,84.699826,60.192978,2.474179,26.462963,103.465495,284.053013,308.169051,182.731758,115.3733,115.300423,156.871651,220.608417,253.691298,280.756398,335.927018,328.240725,200.131533,101.653967,-42.452947,23.021826,88.354179,122.168553,100.558141,96.363248,122.325017,128.601068,86.074826,2.881775,-1.164688,21.105854,98.92009,134.329056,164.379885,142.65976,15.302945,-21.97548,33.380359,168.22522,232.134744,329.961071,320.192389,166.032407,60.509131:-194.867037,-119.489513,-71.865317,31.737502,49.054832,9.371636,-14.733484,-98.17645,-175.566026,-147.143852,0.207618,58.940981,60.091269,-3.854117,-212.990097,-299.834269,-310.483275,-214.982295,-176.760605,-102.2696,-77.936216,-75.435798,-85.551693,-82.336164,13.762217,78.458408,149.423016,143.99868,65.531035,-3.917667,-155.337135,-186.90299,-88.168773,106.986272,183.856935,188.11997,101.997811,-79.774727,-103.300678,-40.056302,7.574164,6.109862,53.173648,114.210137,189.928409,166.83518,41.152666,-16.559229,-48.693867,-17.691509,-2.793283,9.099467,-11.632165,-73.80327,-92.435128,-143.655074,-143.447008,-80.450921,73.211959,98.063405,21.494404,-45.32688,-197.347566,-261.532233,-252.687842,-95.641244,-23.388176,37.728707,32.100519,41.217412,66.740752,73.831518,66.766767,100.025322,160.622363,152.669058,89.471114,46.913097,-66.099781,-109.653188,-100.179032,-50.754958,-37.303059,-33.173196,-54.308514,-151.779005,-202.847259,-225.685912,-164.057926,-143.228399,-87.87202,-32.203217,47.062527,36.325261,-64.54273,-112.186962,-95.696099,40.020067,100.329586,130.777361,119.874529,129.83165,123.573161,1.580889,-73.579685,-37.362963,90.464018,134.933979,131.337486,113.135931,111.419306,112.458393,76.456201,26.055304,34.862114,58.636894,25.264406,-68.563204,-79.042175,-37.368052,64.370104,142.3719,306.234655,359.632838,352.998624,305.401231,154.51638,76.582091,27.020248,83.827597,110.915722,155.629853,167.682061,161.559967,157.419364,154.98493,126.783234,108.123922,122.694133,149.1587,150.189518,123.894335,54.485788,5.281686,-66.707361,4.624037,75.936178,166.476952,166.062779,112.058449,71.323576,-18.864933,-86.489994,-102.309155,-83.504391,-68.331998,-93.603076,-124.279005,-177.562576,-192.746116,-187.402749,-133.722146,-93.63962,-44.883892,-58.679085,-136.424943,-186.727285,-282.677202,-315.638534,-298.701299,-189.581306,-129.080684,-118.437978,-169.109751,-281.793572,-296.753132,-206.529466,-80.960285,-52.236504,-103.280892,-149.198969,-134.237499,-98.939766,-101.715771,-67.71584,-1.462941,110.772594,114.016512,17.181244,-42.690717,-96.572972,-110.91314,-157.582848,-99.332935,-25.483526,54.421833,31.259624,-37.469765,-60.658036,-148.518452,-215.559674,-178.601919,17.855209,86.238726,-3.503337,-114.879412,-284.68758,-296.273258,-156.753751,-1.2567,54.173672,155.802207,167.310086,44.311497,-39.730737,-92.943562,-16.635581,39.943899,162.575239,205.832652,196.595224,151.620323,57.492086,33.451567,29.085514,36.986204,39.863796,14.645653,-20.066505,-95.435799,-121.172452,-152.688358,-205.707303,-253.396211,-304.545292,-281.594612,-251.792765,-278.432438,-358.634451,-378.485415,-328.874375,-214.002021,-165.354379,-123.614882,-144.087909,-245.071848,-285.891539,-272.520402,-181.298536,-158.999366,-138.661362,-100.321577,-48.731484,-96.364188,-279.076818,-321.918408,-234.807082,-138.567413,-115.971376,-71.684615,-59.316182,-45.383221,-51.199181,-121.406087,-137.894095,-90.724616,45.161324,99.759377,108.852034,53.541042,-82.188229,-108.581334,-48.833083,62.440737,112.015972,188.226132,203.509318,150.713495,92.352388,54.920816,216.509897,301.647074,379.397458,389.793929,389.342703,377.089732,317.167063,277.082303,238.024937,250.772931,269.597338,331.021938,343.162194,277.522817,226.281276,189.828945,294.728079,354.10849,353.882518,317.922972,263.580129,240.557935,175.320564,144.948193,169.324064,246.64713,264.462625,262.744564,236.432699,143.428347,85.926171,-24.453497,-50.067654,-20.815057,73.08927,95.110124,48.789999,-1.365813,-164.321176,-255.618154,-271.447116,-84.373654,-3.514907,70.468789,71.123735,13.355158,-39.033134,-132.382034,-146.278025,-131.342068,-43.411406,5.463579,-7.980821,-56.909846,-167.956516,-231.30333,-312.583032,-217.093615,-109.830942,57.029474,68.923762,2.971609,-27.862027,-12.760886,30.09299,25.88504,78.093927,144.757786,202.062413,162.811433,3.929888,-60.799168,-44.340384,38.551281,64.75908,122.154878,153.839001,215.082377,221.809683,155.77398,134.397562,177.440231,303.294103,337.080024,278.504747,206.387282,74.627388,36.871136,64.25429,218.101783,270.851882,274.715047,265.769982,249.368676,215.113811,90.978115,54.910068,91.268862,149.902461,141.258871,109.093574,111.201448,94.86883,54.948147,-37.546092,-36.67911,20.065972,153.49543,175.3149,98.34385,22.475076,-83.882511,-15.549019,42.503604,139.757432,182.294015,171.996171,105.09511,-44.225963,-82.218856:-165.606565,-126.758697,-81.504632,39.305933,85.516399,77.892133,18.318106,-150.718637,-214.816098,-166.553061,-4.269701,48.927232,30.568353,-31.80773,-180.568892,-233.673519,-261.826437,-236.102087,-213.169831,-133.983754,-102.373273,-85.564108,-80.609113,-34.405246,83.489452,137.64441,157.170957,125.990145,0.929971,-89.966273,-263.367763,-301.109588,-209.776591,-14.089573,46.060972,52.03881,25.661826,-1.164964,2.319208,-35.352189,-109.057571,-98.402945,36.146472,118.819537,236.079063,257.933578,161.611936,44.695842,-128.206317,-59.017456,7.634191,107.091305,135.990483,131.49732,101.572472,26.888025,17.598819,53.429035,141.187367,161.091014,113.180451,45.963159,-105.717375,-145.486497,-104.248478,15.822466,77.874089,132.040873,92.91023,11.40448,22.182288,29.255404,-2.936336,26.212714,135.383846,167.866226,127.674257,64.722206,-33.125337,-45.914029,-71.594439,-113.910056,-116.407855,-102.310671,-111.839265,-162.612524,-182.701888,-197.589982,-171.993084,-148.538886,-67.508885,-9.62131,36.01672,8.347868,-54.941183,-53.903996,49.550763,162.076864,183.843932,201.651587,197.481867,169.802846,145.97685,12.385614,-107.331435,-95.460112,61.763574,177.048188,322.269041,312.086992,220.729643,184.926676,141.96315,99.586564,84.261478,104.139821,127.387794,122.437891,70.909295,-49.703821,46.816316,147.709814,264.339278,286.943802,303.919229,279.520794,175.903575,116.972798,50.170634,117.337541,167.517793,221.172143,219.818029,202.444264,204.005179,188.697772,129.021406,89.865116,15.419233,8.863454,72.49942,104.779015,65.402583,-3.498718,-86.14984,-62.515448,-65.84473,-73.03848,-53.625059,-30.835221,-52.854642,-100.395625,-86.245756,-102.57182,-178.598143,-178.969704,-121.998767,-130.164436,-247.787318,-312.193767,-341.930921,-249.051317,-197.424377,-141.214929,-141.242043,-171.759117,-188.916573,-216.370739,-183.875828,-128.246751,-28.312721,-18.119586,-97.509037,-158.01915,-194.239692,-157.664883,-84.592759,-78.239028,-60.1782,22.359051,52.629871,57.039477,38.802154,-30.151467,-44.933052,-14.744496,65.453062,113.726442,185.13134,171.086478,56.226662,-9.876226,-85.577826,-48.714766,-18.411047,3.813554,0.921193,-17.789508,-45.465122,-145.995651,-161.062163,-111.39247,-0.620779,16.082978,-50.950348,-94.211942,-146.345052,-164.033421,-127.328093,-11.428294,38.062407,108.78095,114.336706,39.228341,-20.722728,-76.302817,54.993918,128.65343,172.957428,187.530492,235.698476,230.401344,138.305426,75.544928,37.982722,88.294613,68.916773,-3.467929,-13.282317,-53.394837,-117.079125,-264.787224,-369.255409,-426.895152,-469.359311,-418.483756,-311.730856,-319.147794,-414.000089,-450.246062,-435.576645,-358.527381,-327.590686,-272.64387,-239.914711,-178.143742,-163.161918,-162.043949,-154.194158,-151.151951,-121.990651,-79.335708,-40.649584,-81.464612,-212.070494,-260.139315,-244.222392,-67.482513,25.998034,128.532104,137.124516,99.565997,69.791343,21.378504,11.165019,25.591181,119.324791,186.050552,226.1824,179.198612,31.768744,-53.806691,-173.914909,-54.173188,55.688252,181.376272,191.151481,171.297398,142.216471,58.507819,107.753858,206.30082,402.808581,444.703107,404.779107,344.572056,197.972535,137.859952,98.39326,105.448135,105.734252,168.122852,223.917506,277.924831,260.710364,194.251964,219.325564,245.012967,219.621748,204.902653,207.979226,191.164484,106.430871,53.558788,-7.437245,66.187187,122.689977,152.2348,116.985349,30.841838,8.51315,-26.527706,-49.478687,-31.093148,36.686294,58.196371,11.195564,-46.037822,-137.818083,-176.687344,-208.551433,-104.666515,-45.10516,-6.473713,-18.027955,-15.442167,-9.649768,-86.494266,-153.912649,-122.98432,-2.051947,33.030276,-19.701534,-91.377509,-219.572477,-259.445048,-321.415169,-308.298046,-234.75666,-63.673831,-43.617688,-110.040459,-134.912839,-128.882197,-88.383168,-69.111099,8.457456,72.817818,152.531792,140.233327,36.397885,-22.485536,-49.592279,18.896294,61.146197,151.723133,164.964329,130.527956,121.811357,92.652484,50.057575,69.144195,193.548791,243.404043,215.646659,178.981169,157.33512,148.890196,151.577633,276.796594,340.543594,354.80969,313.582359,233.145203,198.451727,111.908172,99.810997,116.061401,148.917918,191.298435,310.066407,329.83724,217.393474,117.756253,-11.805796,19.814068,66.626876,141.264875,159.538406,157.618679,125.197308,15.147444,-3.086746,33.774457,109.471079,139.704121,195.768022,217.330004,182.284291,115.595882:-24.74892,-14.12539,7.636479,118.612787,151.098624,100.261406,36.94369,-99.657412,-136.763302,-116.715237,-36.52947,3.971275,2.256282,-40.306822,-153.619036,-204.057793,-239.046553,-199.765471,-152.186082,-26.521501,-4.400313,-64.561612,-97.98078,-77.814199,67.258311,129.504212,176.995592,190.734107,170.809817,108.769453,-85.404711,-172.074027,-197.920617,-22.002534,82.157051,195.729725,180.134141,49.287653,-20.359929,-85.491243,-28.257936,25.56336,159.967742,233.766831,322.054936,308.108096,151.239187,59.452984,5.839124,56.729687,79.20327,143.546785,182.514043,181.392756,108.539472,-86.366626,-112.807963,-66.237197,53.624919,90.256057,33.397971,-34.459393,-162.646025,-223.85635,-277.831559,-150.692077,-46.52978,92.909304,91.231101,42.13561,28.781156,-18.319739,-7.305944,62.936991,162.649926,134.839038,57.676508,58.000532,29.90703,-41.091191,-180.973879,-184.667565,-157.682813,-109.828009,-108.290061,-163.227189,-200.125755,-212.136171,-151.787144,-119.347272,-2.416943,62.570766,63.706593,8.187656,-92.958287,-103.499479,-27.807037,83.775964,137.548961,210.768978,207.545348,143.088301,89.322841,-46.339895,-89.228844,-50.624313,90.74358,160.338289,244.101448,255.47407,202.14243,146.39127,57.001041,11.189902,3.972921,15.584578,25.440963,28.926103,-8.529645,-88.221981,55.450164,172.131926,297.984949,292.206342,239.821722,225.167785,154.880613,77.432971,-23.506204,66.950947,146.146236,236.46523,216.353825,151.943003,154.155218,183.063844,138.997183,83.534435,61.987355,118.418567,192.775868,166.395892,18.558614,-66.60277,-129.214123,-36.527898,29.066764,92.992053,51.104513,-97.079572,-144.887135,-147.297678,-72.378274,-50.901515,-37.437098,-20.832147,-3.810018,-30.800899,-174.035545,-250.386961,-258.631083,-128.487619,-71.521795,-13.513478,-16.765824,-85.956372,-144.114886,-244.483409,-208.114909,-151.685334,-49.749537,-23.646612,-87.169987,-167.400676,-266.427823,-248.5521,-165.581423,-98.573467,-45.48728,40.464476,25.523966,-63.566694,-79.548323,-38.550065,12.560699,25.380053,78.763874,128.803506,175.824712,151.372559,37.478603,-24.859635,-79.587008,-21.204948,28.85776,66.27304,30.56633,-53.627724,-72.560211,-120.93334,-126.252759,-76.716959,73.120581,117.911545,68.166319,6.824527,-117.365481,-165.549471,-184.290236,-84.278449,19.432526,199.88892,198.287906,43.523093,-36.370956,-67.44891,49.740945,94.916726,131.660902,151.113962,165.753963,144.505861,69.552754,22.523949,-27.455842,33.553723,78.674512,125.769345,102.479074,-27.504087,-112.623986,-261.298897,-354.393801,-383.965609,-328.502763,-261.123981,-219.071869,-246.154765,-320.34448,-361.590894,-359.48927,-190.441648,-108.903739,-59.786118,-85.288925,-139.080325,-132.468208,-79.604977,-92.020404,-108.336826,-23.440601,64.809176,119.09624,35.12756,-236.621737,-313.532776,-241.422068,-66.193129,9.625049,126.08955,146.602191,65.185585,-4.14733,-80.547098,-70.591109,-41.270717,97.154361,180.300302,223.995176,178.342369,23.166858,-70.119263,-157.589149,-7.31091,90.980497,182.737383,177.80321,128.706598,86.224783,7.820375,81.281787,171.048544,330.178757,361.728861,337.759482,297.124861,174.782045,122.577747,150.513171,270.026111,301.940013,326.1134,326.436844,301.380401,278.395712,234.993927,249.226001,283.119803,343.226682,341.405196,281.150456,239.201876,100.253756,8.260585,-56.863905,110.134797,205.011098,263.100194,229.611753,110.776438,36.030603,-100.326692,-77.580069,-5.406092,110.786072,104.506085,-14.297062,-76.369243,-168.453799,-210.337393,-195.190099,-15.667177,65.167925,111.059332,72.169994,-83.430863,-159.210276,-212.376644,-158.630615,-117.097948,25.211333,101.514362,97.704222,17.205627,-179.390673,-261.90098,-311.21071,-180.357018,-69.068224,96.324472,90.152904,-10.880701,-42.790799,-49.741455,-15.507748,16.61072,133.70449,194.471848,206.38793,156.331391,8.92177,-62.125203,-109.433766,8.572574,102.907722,232.882004,225.499872,134.540671,97.880312,67.668312,130.617713,202.802608,353.408346,373.913051,289.851816,242.155669,162.650282,110.746502,55.859736,129.379882,180.194558,234.023455,218.03881,154.411257,135.287005,91.552421,89.586521,128.358297,197.293443,201.25042,166.271146,139.104211,39.290585,-36.40748,-152.251665,-90.14057,-4.844852,108.443787,99.197919,8.247674,-37.893403,-94.404921,-83.535369,-41.969006,89.786466,138.111394,138.565554,111.323655,20.738575,-36.839729:-195.408734,-110.632249,-28.541649,93.767908,113.77048,87.801069,63.153897,-15.463919,-72.525684,-53.513495,-39.736879,-86.748357,-204.233295,-239.314707,-253.198812,-253.123379,-292.203329,-304.656511,-251.200955,-60.577738,-9.646829,-67.559456,-96.71337,-43.527848,44.40495,69.903175,63.981036,27.750724,-79.649739,-125.311524,-191.353727,-241.75176,-318.524633,-153.517461,-11.192117,214.263389,257.825178,200.378999,136.359066,5.066863,-60.270536,-40.366779,64.788077,128.586476,230.143707,235.302477,123.274486,27.425809,-142.356067,-170.131949,-110.883411,120.255106,222.14099,246.510594,193.805621,103.581148,99.717668,126.857527,209.203293,235.584164,195.606756,137.241683,37.796806,18.77609,45.291817,112.977858,125.710106,132.122482,144.065027,133.265919,99.745093,24.789167,59.834547,122.938694,233.181351,241.87478,139.800492,74.58708,29.881635,32.872717,0.679163,-76.788679,-116.957232,-171.566493,-181.392655,-170.147397,-144.368352,-72.965342,0.63037,29.784475,59.908691,92.931436,164.938131,153.890941,83.409698,77.055656,133.94741,185.17385,211.318522,297.21267,323.857403,257.533387,174.191107,19.945669,2.238516,37.351316,156.972119,248.029149,393.341358,397.052138,315.873887,256.833389,118.291361,76.310248,113.890919,195.941274,190.492437,68.931577,-25.946558,-160.130104,-24.236073,88.671022,190.09438,204.310195,274.229201,309.338012,235.732615,127.698648,13.462597,137.725661,210.702109,275.975414,275.918006,251.502798,228.719496,139.1355,55.414762,46.981943,2.79679,-62.795124,-159.075513,-141.420319,-41.997869,-10.142529,-2.122209,-92.647437,-169.075868,-205.803951,-154.938312,-78.459883,-82.470452,-103.216732,-58.742532,-51.110539,-130.730901,-168.489253,-133.742694,-90.087503,-95.049601,-179.481771,-363.021225,-253.943078,-132.297024,-0.632724,-13.968908,-68.514275,-59.196299,-45.73648,-104.189401,-99.583609,-16.495084,8.25643,-54.218827,-113.844152,-144.854225,-108.49833,-61.450223,-98.685477,-87.004942,74.462505,191.242945,380.303874,393.286054,194.734274,52.558745,103.788165,272.517107,313.34574,289.417177,256.878223,216.549864,199.796355,145.262698,60.746952,17.931678,32.713944,82.169538,83.445013,5.869652,-148.812123,-114.252283,-62.782905,-19.29368,-23.531589,-61.326442,-93.969321,-154.8975,-186.222567,-203.002203,-100.725412,-58.270774,-70.560012,-113.551711,-154.756924,-129.482599,-64.886815,74.954748,180.541775,294.733569,309.628357,359.316192,370.382547,300.17226,237.097768,151.566039,136.02648,119.488003,100.941101,101.729137,14.608627,-83.653951,-295.539132,-402.394539,-408.491597,-367.624451,-331.218297,-322.089474,-378.903977,-508.095137,-523.844189,-449.632114,-383.917899,-371.011949,-267.373142,-186.060496,-72.853005,-47.98132,-61.885521,-98.732163,-98.114085,-62.060313,-37.038123,1.102228,-6.507943,-116.698994,-185.713048,-183.440536,-31.559138,32.613468,119.033881,141.062159,115.964795,79.781528,36.225485,92.073651,143.424193,246.625727,280.339859,234.850119,162.027512,37.508725,-2.455131,-72.11752,-34.292444,37.420487,158.274434,172.984512,151.701522,128.985333,60.860711,63.278935,119.019905,253.267103,279.131313,192.341196,104.736677,-51.321173,-99.692536,-123.815326,-17.642567,55.951777,147.960142,162.966987,169.870661,169.292771,155.388453,169.67993,190.587637,192.996196,163.134457,64.933942,30.578022,7.102289,-30.963276,-130.811545,-32.926838,71.649719,194.96691,191.777582,106.687559,43.878409,-33.081554,48.615978,116.207692,169.919427,135.306157,15.530685,-27.727612,-83.980927,-107.762854,-103.633258,-54.507572,-34.198569,24.889893,65.989852,93.702655,52.70899,-53.534335,20.47848,89.031198,87.259328,42.417102,-34.657423,-98.73887,-291.858254,-361.33236,-382.82689,-315.029652,-246.517238,-95.638207,-75.933854,-112.010395,-109.249027,-91.939314,-92.824563,-75.896715,-7.149588,24.311167,2.026735,-44.469743,-83.698059,-81.681797,-91.178097,-45.270785,10.126602,118.567856,135.420275,148.984468,167.574545,94.051088,-53.72497,-63.681227,-48.57515,-53.522485,-18.000963,3.70949,-21.368051,-34.786173,68.425176,230.413361,243.961547,176.794253,133.930464,32.180627,-22.774022,-63.463718,65.089373,135.501875,152.345227,134.905065,175.129868,203.685897,149.071894,78.056163,16.145254,116.105625,175.706666,228.768749,209.822739,132.825281,90.484253,-8.045925,-49.283378,-59.836494,-51.917601,24.317247,242.541046,271.945243,93.140612,-36.406048:-55.196982,-12.209667,32.505717,149.137987,188.420899,177.280242,120.108034,-62.784895,-129.248888,-76.920817,54.00095,68.711757,-10.13481,-71.47978,-207.744105,-282.262049,-349.692219,-242.632971,-153.092574,20.482503,69.911281,77.138101,59.01766,39.190137,99.181871,142.210762,198.17285,206.103755,150.195202,77.364046,-128.349161,-219.74656,-235.511216,-38.848246,62.399986,158.320389,164.284564,140.244563,94.723839,-55.250747,-92.324065,-45.125323,105.634442,190.868696,308.568767,299.194896,143.96011,48.559272,-69.562863,-23.900134,66.502316,282.327031,327.554338,218.110826,112.26643,-41.01609,-31.772846,17.249206,137.7427,173.056722,105.383142,6.558395,-188.975593,-241.937504,-226.145491,-84.604753,-2.354469,73.022738,48.463001,-11.734209,-23.572128,-60.266842,-62.080305,-22.248327,94.304789,129.101588,91.228117,49.334535,-40.054578,-91.371904,-124.414028,-95.343272,-94.931876,-73.42801,-50.102637,-14.545449,-1.528924,-17.694423,-38.820596,5.69651,160.892678,212.184342,183.795728,127.750412,46.61699,31.846633,59.419213,195.073093,274.723866,332.551598,297.99373,205.034874,156.674785,-11.964027,-143.967256,-110.311747,140.616647,279.377581,373.475593,310.557347,109.872353,29.855026,-39.079641,24.589837,76.61086,126.629638,105.244223,-11.250878,-72.323159,-124.698938,-17.865358,92.791323,302.657427,355.33444,365.143087,345.153169,234.339645,130.666165,-35.6499,57.897949,174.135195,320.490319,299.713251,180.832217,149.596575,126.222049,58.385525,37.73337,97.269953,151.129638,165.498371,114.973165,-17.833063,-71.432646,-110.06023,-101.688318,-106.583936,-139.562421,-161.450033,-183.225829,-197.76949,-258.574816,-244.605541,-193.807631,-73.544095,-28.233611,-21.665756,-62.881861,-178.11482,-243.804582,-314.408199,-192.28895,-104.073055,-16.775118,-29.717944,-89.314111,-120.24614,-205.946485,-230.03293,-178.358244,20.343786,92.307321,-17.236998,-137.765404,-220.781166,-191.595603,-146.9209,-76.582649,18.6217,217.817916,240.701146,160.234685,126.482479,109.081167,92.105744,88.183101,141.583101,200.664697,299.734434,300.562162,166.254758,63.882566,-73.309956,-46.010198,20.8812,149.923126,160.922061,51.494294,-40.328461,-205.049729,-195.658061,-127.982591,5.993439,49.895302,47.119373,-15.313208,-168.841025,-208.893576,-216.844127,-160.371732,-85.1942,88.538127,100.044805,-47.180906,-124.026225,-129.514568,83.289837,200.615881,312.961469,330.654059,324.371785,285.900018,159.787339,95.400477,49.46742,119.673724,145.091502,107.740582,42.963463,-139.098272,-237.38693,-398.182091,-376.175468,-307.625264,-216.79643,-207.423184,-243.849142,-294.978012,-431.315475,-474.341734,-426.627726,-282.581341,-216.378488,-144.488389,-140.843701,-126.095203,-104.832862,-84.744094,-94.118432,-76.380797,34.472857,84.906014,53.782968,-21.292401,-224.854733,-303.62562,-254.053755,-28.431986,73.21539,215.775059,232.169916,116.459401,21.105544,-83.042123,-12.25316,45.824753,188.983698,267.297382,301.117587,230.162711,-0.59064,-102.327433,-171.375418,-79.790729,-4.488292,144.276886,177.858942,144.207684,99.771919,-16.965009,3.307873,96.13574,262.385549,291.271546,263.974072,215.204488,61.353298,-29.125928,-147.702992,-34.205144,96.406093,278.521016,262.99203,133.577326,104.599562,128.754788,174.245307,205.308173,259.54408,257.044064,172.385448,120.802883,46.721563,5.390759,-44.865478,35.38558,97.195531,161.514217,135.90088,-0.898235,-63.665852,-97.393961,-7.074501,69.550291,205.645834,223.346451,100.076064,-2.058197,-144.752522,-169.72862,-94.116777,87.791899,150.82008,185.638873,173.448002,121.633529,79.424337,-17.943202,-11.446886,35.833219,138.659865,171.561639,106.582458,5.303309,-180.71131,-222.000074,-218.171565,-132.912967,-55.346238,97.589816,109.131624,16.186729,-21.017468,-42.511416,-67.994338,-68.865796,8.093202,63.148685,91.420186,60.732618,-17.889098,-50.262214,-65.574877,22.790679,107.775443,245.102294,234.333325,93.533998,25.583863,-5.581847,76.789917,103.481085,131.451443,158.417736,154.101055,101.161296,-18.983178,-46.677945,-9.909644,86.080071,125.40355,147.992639,122.977979,14.280839,-46.320078,-99.320517,-7.522412,45.865636,80.25285,89.92574,159.270218,186.418957,90.131177,-13.768161,-127.721621,-43.376527,22.640084,81.323831,70.572997,14.221886,-46.56987,-213.299774,-203.414408,-124.881497,21.967484,69.441249,87.708856,52.35591,-61.964515,-110.099056:24.260267,30.239204,66.223788,187.645741,225.830095,166.336383,110.863232,36.236312,-15.936533,-18.971297,13.958347,22.109662,-37.129454,-111.292794,-241.289449,-248.730433,-214.983283,-237.29874,-236.051761,-143.032731,-103.982655,-129.463003,-144.191071,-65.323587,82.427608,110.483887,4.619666,-81.235171,-179.798298,-179.873078,-115.435297,-89.881552,-85.02966,-42.892214,10.964961,178.677749,258.682174,288.736779,229.773269,56.750359,5.674312,53.81427,174.726912,197.169882,184.947551,171.105927,66.561018,-27.955255,-156.214677,-182.209579,-198.033357,-155.723881,-52.826276,219.064336,299.641427,272.352017,170.286948,159.216164,234.200932,279.945757,238.113405,154.560461,40.094021,41.637323,77.725609,106.854178,121.259163,157.849139,195.300496,256.414358,257.297512,210.41537,203.74489,255.808466,333.428519,296.829891,160.334664,128.924997,141.326312,145.717068,96.479132,-21.258128,-76.596573,-102.78766,-66.684691,43.426228,93.780245,154.490147,175.165178,200.162202,273.300644,309.074184,381.541194,408.790644,431.479217,429.49517,371.897379,299.542654,317.09399,418.432812,442.295883,386.277077,316.934772,157.308451,108.778677,156.123558,351.463599,446.663522,504.927811,480.885061,414.910357,339.290499,96.602694,33.378489,81.954057,153.093734,129.596546,-12.746344,-77.241179,-122.421414,-70.14589,-4.502155,121.180435,140.314538,152.660859,190.529919,256.112196,206.83336,10.401581,51.211335,143.752637,235.820277,238.680306,262.142495,257.498171,127.440726,3.408801,-13.922531,-54.056251,-101.785312,-215.635841,-241.611764,-147.058405,-57.330178,49.706707,15.759161,-25.790302,-59.818918,-47.821961,-17.243667,5.980885,91.008266,100.343159,41.69637,-59.706902,-46.368357,11.351525,2.322377,-61.588046,-108.649129,-184.649277,-85.755323,-8.758938,44.202689,33.880218,70.637284,115.554965,149.01867,164.002007,198.963498,221.155244,188.717048,58.985592,-9.225546,-17.477534,28.660606,63.198741,66.370849,91.05266,155.691368,200.639468,310.39403,327.282448,193.847584,86.273263,127.384328,271.109656,325.288426,381.751277,383.915691,329.519335,272.892394,162.334766,140.557953,142.446407,139.812178,143.195183,136.792532,111.20824,3.547308,-68.558694,-42.129524,62.130181,89.282124,55.841402,16.990006,-61.06196,-96.808026,-125.07195,-134.346335,-180.355881,-297.107146,-315.079849,-272.184449,-241.039653,-194.846087,-87.198855,9.586277,200.759207,266.301021,317.788803,306.161474,241.965186,203.155027,186.096614,260.835311,274.657665,226.645738,182.843565,59.636399,-8.720544,-101.857239,-67.192185,-16.358937,30.194803,4.25562,-97.029199,-153.246388,-279.310605,-344.216425,-392.934365,-349.565711,-335.097598,-260.506461,-171.337346,20.614773,54.577282,13.986892,26.276522,38.802529,37.420626,60.754313,110.915476,71.297899,-127.152134,-211.462788,-209.605489,-42.90299,29.150704,95.931513,99.712678,62.215932,33.688037,6.522868,58.67224,94.153009,147.110207,155.71495,84.772658,24.942036,-25.305593,-43.90421,-162.395168,-202.719496,-153.033043,-26.587586,-1.104501,-50.664906,-107.364056,-212.743111,-172.049084,-85.790806,101.061441,124.265828,-44.163009,-156.99523,-241.925677,-234.518688,-224.284392,-157.763242,-92.237227,14.407068,44.535191,107.857817,134.158915,140.396405,88.551024,33.882978,-42.031377,-20.902345,44.77497,40.731301,-3.078469,-28.590606,-82.363914,-41.699559,51.962251,295.196533,349.436327,259.663337,176.422858,50.998968,67.812175,109.212915,140.451703,123.295616,58.415819,24.489509,-42.880295,-82.164021,-89.30967,105.776919,220.070795,298.164012,250.802776,113.20706,87.917745,101.886593,104.64286,136.051147,210.786774,197.303508,79.378323,24.939393,-32.67461,-62.796759,-133.527985,-140.547583,-104.070353,-7.558721,4.052715,-54.7625,-97.479679,-198.223153,-243.244843,-211.594847,-97.978931,-46.699839,-34.816482,-79.808706,-155.362197,-163.033555,-167.613898,-177.488126,-144.473028,6.413852,45.725357,-32.039112,-77.996656,-88.254993,-101.596609,-137.615184,-199.5159,-182.198021,-120.709812,-145.629981,-287.668451,-329.953904,-256.898724,-83.130253,-24.381778,-49.027248,-124.975933,-280.213692,-323.125603,-332.572977,-231.770929,-144.759255,-11.72033,10.041124,14.437619,1.141891,-48.866945,-59.016267,-11.301216,32.248421,38.723576,95.179942,113.71272,15.922873,-52.211287,-115.998141,-159.963508,-166.177721,-98.852916,-59.016546,-44.336894,-36.116458,32.883842,43.12246:-247.202132,-184.776553,-97.915846,26.374753,48.57623,49.264168,32.541861,-48.617883,-137.552865,-159.58153,-159.111827,-139.977691,-121.613391,-148.852163,-220.630272,-228.068348,-202.773197,-219.846228,-231.509035,-214.538492,-205.88372,-183.406278,-149.972432,-83.38023,-44.40483,-9.96356,15.023433,-29.428816,-132.662768,-150.364028,-143.851577,-146.548984,-169.762052,-149.536794,-113.203167,41.812887,135.380441,198.491822,152.054228,12.853477,2.516421,42.045998,84.611602,98.910795,135.233453,128.061185,32.495749,-38.62726,-139.864352,-189.638537,-199.701719,-129.500233,-63.699803,47.085979,84.202819,88.250344,27.29923,25.994658,88.293433,122.111846,161.017568,153.246742,94.139071,79.881688,114.716716,132.903995,127.46006,164.799712,192.363763,142.360119,61.95326,-72.040502,-2.035501,95.535176,212.662052,183.144264,36.345189,-7.515475,31.835473,64.252991,10.545825,-133.589586,-173.148826,-135.765888,-84.634709,-10.848858,-8.757204,-49.774974,-32.38037,-4.145359,5.275831,-10.176997,-1.075818,43.510788,175.578019,223.552917,220.590659,133.518905,113.61663,190.77097,257.057648,303.817391,237.937147,-31.43954,-111.372225,-32.289612,130.776447,200.658158,389.517015,461.783273,421.148623,323.664319,146.881274,109.679732,117.343872,121.020042,90.019234,-26.594668,-62.256348,-39.850134,92.295669,177.977117,233.32212,168.237825,-17.063506,-41.96902,55.378055,79.652992,44.282392,118.871446,157.104304,146.359647,159.474167,256.140704,261.276736,101.631796,-37.687416,-55.046017,-98.701085,-143.453533,-223.129197,-217.67418,-77.287061,10.517915,106.092545,121.729815,131.71167,194.822163,212.836032,162.12421,133.030459,111.469667,36.104187,-21.525218,-90.524806,-93.461635,-76.667678,-62.66213,-66.780046,-121.870803,-237.903034,-174.934414,-116.22187,-41.289014,-13.202516,62.15949,114.863211,168.698802,83.930733,45.265459,74.743401,109.5677,75.517578,21.084444,-42.600399,-52.770953,-70.571179,-52.209421,-7.636078,142.324445,204.14556,240.36819,229.855796,147.193068,99.866734,155.318559,310.778875,341.934146,322.858209,309.863288,257.295614,197.288351,108.246922,105.336763,89.555545,48.893884,39.639185,-0.322269,-56.137475,-226.026694,-261.019549,-184.476229,1.103042,48.004832,3.252852,-53.530964,-92.588166,-78.939221,-97.187711,-155.948295,-168.634176,-193.925746,-234.295617,-309.224918,-300.056257,-240.339837,-201.840075,-157.503165,40.092977,157.087064,274.961456,277.836342,240.296968,201.362299,145.476384,164.475767,170.743313,140.55608,98.509827,4.30815,-25.941973,-113.596851,-184.896607,-183.96579,-183.043494,-184.228279,-206.093648,-245.912382,-335.230318,-353.655224,-319.087327,-277.812206,-253.845755,-139.174634,-95.118458,-110.322165,-117.306851,-77.823104,-48.721914,-45.123462,-39.463948,-30.544672,-16.533059,-24.985064,-64.369601,-83.370997,-96.974987,-92.698955,-94.334284,-47.721371,10.786565,86.718705,78.353937,37.895065,41.378598,65.263038,159.129776,214.754406,214.403243,132.362625,-81.3127,-169.148649,-241.931518,-112.999988,-5.535237,168.440872,192.320705,106.73747,33.809129,-99.568954,-63.188046,29.730287,168.99028,173.767076,83.360238,15.487356,-64.85361,-71.924481,-104.329989,-140.622117,-110.941416,34.052241,77.221863,29.713999,6.530336,40.479938,44.820891,12.189986,-52.594653,-31.998342,86.401496,117.632602,86.183588,47.088068,-6.658604,53.922812,125.649092,250.54761,256.556227,162.5456,110.081944,93.368666,193.148763,238.668477,246.196096,228.548489,188.51811,149.077737,29.922333,-24.609134,-47.895475,39.628994,93.834252,192.849276,219.000571,174.480726,132.277608,91.728291,132.407357,186.758828,282.360256,292.569109,242.20891,200.681339,106.151288,45.547133,-80.006559,-142.248792,-125.168841,-15.057,22.010024,24.792077,24.646598,-5.356922,-87.897418,-88.730796,22.357118,84.208556,89.34564,40.183306,-34.628724,-56.001404,-113.940147,-138.001193,-107.96413,-6.610644,21.219155,36.531342,52.646242,67.856419,47.640965,36.770701,-3.026056,-8.683986,51.095779,77.253717,24.654397,-40.268162,-91.311814,53.548782,122.360813,118.832348,62.493762,-75.259513,-138.818021,-254.515073,-234.613767,-133.115436,138.771122,228.785387,210.301309,149.492965,73.5453,44.423829,-11.292604,19.364317,49.550746,80.966407,84.970578,107.322692,134.638457,161.983381,86.246873,39.950017,30.598145,80.064104,210.712564,250.376535,272.689487,257.897236:37.143875,90.898962,114.115738,124.438192,142.823792,186.091667,159.855504,-6.153974,-115.104074,-104.796159,-26.686035,2.399251,-54.610873,-146.617098,-306.749766,-329.602325,-318.274477,-228.744365,-135.368691,61.362439,106.35521,59.013887,17.72053,-7.931251,39.963708,69.589663,68.449259,46.618257,6.228107,-23.961586,-88.438936,-108.618079,-146.778106,-99.597637,1.037321,231.393791,273.218204,183.39488,118.059062,48.291722,33.629408,36.84309,88.743512,153.344112,286.643146,285.033505,115.127569,6.481028,-104.634291,-60.911072,-25.589585,77.811975,154.079874,243.836941,241.438964,211.023863,188.846117,188.400248,211.431113,228.041186,192.730926,118.192587,-43.340268,-78.628128,-65.737711,-3.319485,44.150136,120.400861,131.078428,140.175169,148.250938,139.450599,131.044992,152.211722,176.466197,158.332482,123.414476,115.399188,69.280237,29.436803,-69.420217,-154.737088,-155.933265,-74.144049,-33.671183,11.238234,45.088527,76.205669,40.43539,79.185078,275.202909,358.889137,366.967556,317.873318,269.500449,269.985514,215.44044,213.913108,291.131061,408.800788,370.647208,201.520085,153.020843,131.707033,121.161409,130.537278,221.931854,292.470062,359.219769,344.217945,259.627735,173.176723,6.735857,27.219281,68.716639,146.124793,163.136538,81.530314,16.003713,-33.784061,66.693704,143.393525,231.649673,248.462855,286.742494,293.024735,261.456589,230.031667,172.16261,123.322179,112.422426,223.525802,300.876736,285.433923,217.409543,89.804113,-43.066176,-89.586274,-82.620936,-51.892899,-60.383987,-111.954807,-172.883046,-150.48656,-80.702645,-75.18296,-97.741422,-134.909994,-135.418688,-114.872895,-110.525868,-116.910266,-124.731418,-143.504299,-156.359932,-122.94085,-40.444836,-16.862797,13.619189,1.891045,-90.318332,-93.831952,-50.499158,5.037229,-6.374114,-28.330266,-19.445054,-34.516512,-66.366712,-41.952731,53.064911,69.338002,-53.361979,-146.918391,-163.358906,-101.68191,-71.23516,-48.845627,35.033549,226.048784,277.043128,326.689516,337.093947,247.41283,118.979799,109.679141,176.1463,222.622696,293.699155,310.689494,297.201018,266.408097,206.713163,177.592877,156.280062,142.456887,167.023747,167.171497,101.147691,-78.560131,-90.491865,-29.869879,105.623909,152.027285,138.041629,69.622636,-96.474164,-146.801689,-139.400496,-121.920743,-145.89054,-130.200952,-80.772018,-59.38498,-102.437744,-123.189013,100.129694,241.13647,352.046981,335.312972,339.400675,353.649858,251.048518,143.915249,78.252936,223.420387,224.675455,118.25791,106.402744,101.629907,48.439797,-129.187932,-230.213085,-218.459556,-110.093354,-53.204315,-102.804702,-212.384871,-386.54149,-414.388027,-427.809319,-417.602476,-391.400937,-252.46445,-157.925938,-51.769948,-48.339226,-53.462752,-13.087184,3.901223,21.016816,28.265681,-42.001577,-123.185946,-240.677666,-235.493778,-93.07053,56.637119,80.320578,78.036936,75.643679,42.757089,-6.593643,-99.546654,-16.698363,62.336423,185.429086,224.708548,163.278999,62.136816,-104.626426,-143.207184,-170.247645,-142.950409,-96.640173,58.263968,93.018973,-16.555445,-88.267271,-144.742208,-108.01859,-47.015114,79.138516,96.052814,33.247981,-33.9222,-218.856327,-292.70136,-268.480925,-139.144807,-104.474831,-34.897256,14.533151,108.16945,142.53162,140.669467,82.834738,79.84562,132.012722,142.399929,77.941913,42.583024,-6.136422,-52.550498,-142.293928,-113.636765,-78.967697,6.410884,50.968653,70.803419,30.611564,-106.165538,-102.713099,-9.361719,172.065635,176.898716,57.598867,-1.233024,-87.342584,-127.985314,-126.851249,17.58064,75.464747,106.186248,94.146883,63.335561,68.174686,55.828739,-9.274816,14.732074,118.568038,110.72789,-28.712233,-92.622745,-152.187025,-182.42681,-261.594116,-279.906141,-238.505221,-86.159041,-27.901646,-7.940049,-32.032596,-128.569887,-181.15433,-150.858149,-60.435798,-31.973561,-19.107611,-47.927547,-141.967348,-161.988016,-110.332885,-31.240516,1.216677,36.077617,23.913425,-1.10737,14.006758,18.525313,-49.450463,-73.750306,-123.65359,-130.041248,-36.260812,-4.536849,-84.655912,-132.865835,-114.279604,2.528206,47.243611,19.603029,-50.504962,-196.947526,-241.000122,-259.510605,-134.287084,-35.141918,45.852965,16.425804,-20.183858,-6.044368,16.832389,-1.704445,-77.080585,-91.548426,-49.337322,80.257893,94.057856,-45.671081,-128.530801,-164.909704,-125.312716,-130.510382,-128.393351,-91.505774,-26.984292,-23.842267,-47.716928,-69.691382:left
67.990781,40.973803,27.953149,4.963629,4.067728,-22.523729,-44.591621,-1.093261,125.631031,120.489329,-76.76886,-167.745076,-104.905049,22.1145,186.459845,153.764875,-45.338028,-218.723056,-253.811744,-179.579421,-90.809275,74.689085,98.602977,-30.09669,-193.161059,-223.168954,-241.043054,-240.462825,-194.02126,-155.48132,-92.134163,-78.809504,-74.884207,-129.502465,-184.640428,-250.246116,-248.044969,-253.998973,-278.386557,-314.116609,-301.03858,-311.321277,-409.589669,-448.838281,-376.60334,-280.623861,-97.505872,-50.270463,-73.821866,-186.185597,-232.104706,-224.040993,-173.243323,-53.455644,-9.834794,-7.843501,-121.758334,-177.46561,-190.916167,-151.281071,-44.263197,9.664324,70.282934,56.7676,-27.452825,-163.505561,-239.544185,-284.52574,-237.959272,-96.991694,-39.383669,-11.457748,-85.216364,-129.076861,-166.146426,-132.278578,0.628375,51.868477,76.544203,49.517081,-58.926711,-221.826575,-311.437844,-321.351644,-220.065016,-41.859495,-42.453984,-164.373178,-220.330536,-224.372997,-276.239254,-305.664468,-306.437386,-261.367646,-91.72976,-38.338992,-70.392873,-86.235086,-71.694154,-30.057409,7.415309,97.364909,106.698091,-17.250665,-175.851555,-218.500215,-271.463971,-263.018405,-103.798015,28.180671,260.931793,286.578438,138.731183,-13.460232,-41.823902,-27.474473,-3.722609,76.0491,132.242389,190.977457,168.53282,148.736588,57.392457,-6.141634,-36.205897,33.277891,199.900312,208.23422,96.394452,-30.395877,-80.556522,-47.41476,30.041183,82.802355,26.707271,-97.473124,-93.654014,-74.434576,-78.191183,-84.618824,-99.313565,-127.792338,-231.577391,-285.845067,-346.971516,-378.131231,-403.157385,-388.583963,-327.731764,-179.594644,-109.406182,2.167837,-33.291636,-100.801689,-177.692258,-141.827071,-0.563812,39.245885,47.171342,48.829462,78.65145,104.4297,95.177629,34.917141,13.54304,95.460423,203.346768,379.80622,364.124728,328.144299,297.943792,304.519072,298.086679,266.682344,199.175173,192.17702,215.579683,212.252205,204.637798,216.057962,217.882275,173.765494,132.161579,-19.125601,-255.174839,-352.204432,-407.282064,-367.06424,-256.647874,-219.464363,-150.02775,-113.917253,-108.485586,-165.929718,-170.432205,-104.953468,-60.236014,-29.940331,-46.799889,-85.372628,-98.173358,-105.110895,-116.952923,-108.358506,-47.743501,-6.73469,29.028475,17.195979,6.101731,36.15733,51.357727,89.01599,110.584577,155.720264,184.723391,168.372036,34.397872,-1.978693,44.638161,102.6603,174.603315,161.585433,123.133699,123.235812,126.765671,114.38981,96.162044,76.67451,107.557677,220.120122,249.509992,216.376757,179.092692,176.09909,151.133552,119.589117,50.487967,50.070834,128.68494,164.046236,183.625072,136.460004,73.50637,-48.504778,-70.18249,-57.81398,-40.864178,-12.306127,-43.191809,-87.500632,-177.974486,-190.977145,-136.692341,-90.717776,-14.409188,10.274685,51.468416,85.040738,102.934851,182.559377,233.852441,265.908791,248.721269,207.735985,152.130837,111.058253,11.884385,-16.221636,60.746428,157.306949,357.356287,413.156014,401.490302,349.099779,333.301079,294.577975,272.121124,216.679684,178.344381,97.676723,63.858801,58.240528,49.533674,55.775492,53.830578,33.286982,22.153778,58.356482,153.373013,143.215709,112.571062,85.815882,88.941742,126.560828,173.615566,267.813503,291.791891,295.779888,284.955867,248.483026,152.665462,137.177587,215.690081,275.196203,322.459004,277.297516,254.618568,230.664017,193.946496,62.124996,17.386728,13.353044,73.80721,81.807251,-3.222254,-35.381423,-4.398117,29.769458,116.104822,144.20148,115.14779,40.130602,4.3559,-29.524835,-25.325865,38.540246,94.573553,143.920343,117.016819,104.153671,10.397178,-60.827605,-104.228248,-64.114691,-7.649901,-40.637314,-146.969503,-141.459029,-101.45312,-20.263,-3.067252,-39.796382,-78.288297,-151.623324,-196.069942,-210.184833,-256.626935,-269.209331,-228.219735,-205.7326,-188.478412,-181.208707,-185.704404,-226.544625,-226.752936,-122.974565,-49.367637,85.827925,143.94162,189.630539,209.012516,234.601111,231.012766,202.651781,210.75099,248.798711,265.523141,217.045882,88.588689,-4.502621,-54.476695,-87.85649,-56.875619,-19.008708,-48.155705,-144.79523,-129.617376,-101.430027,-143.850989,-185.995627,-148.491745,-64.96928,97.876909,135.297237,106.725873,-1.409414,-37.941038,-26.371539,1.576327,52.798288,72.792431,83.93385,33.014953,-28.192236,-111.485574,-54.509758,167.872541,225.45251,200.24656,146.075045:-45.012049,-115.730764,-152.531415,-239.876424,-262.597619,-220.689334,-177.060786,-132.063243,-167.133582,-218.55228,-366.073485,-398.369784,-284.49962,-177.697246,-46.346265,-80.67032,-260.601126,-282.716217,-233.843466,-143.598911,-94.307383,34.479374,68.995738,16.164299,-78.812672,-112.210488,-115.444521,-82.215559,-45.160841,-66.936973,-85.762275,-42.993196,26.265383,-89.714804,-162.239906,-219.892463,-230.592397,-292.739794,-347.096652,-473.467122,-513.168147,-491.621021,-470.766777,-463.955052,-351.075772,-251.285328,-106.984421,-105.195566,-175.076363,-252.074226,-299.430133,-346.119662,-314.068442,-161.314713,-94.395052,-103.484633,-227.581142,-281.372818,-319.86532,-274.10099,-71.110411,14.956697,47.006365,23.887391,-16.94476,-155.089331,-251.818587,-295.348191,-227.024413,-61.462695,-20.192769,-48.00166,-93.550779,-103.240937,-144.896788,-155.652591,-85.550299,-22.824033,60.747872,58.687917,-34.699979,-189.178113,-230.659183,-146.560054,-63.543151,39.282276,61.438143,81.758526,28.373595,-43.984617,-147.557496,-113.220949,23.164782,71.625999,126.304981,104.514009,-51.812842,-184.401035,-201.363889,-146.750615,-82.000567,44.319311,40.795461,-110.249927,-211.478081,-220.838245,-226.995922,-210.308127,-112.285933,-40.498717,90.69434,113.197792,43.714471,-62.854079,-91.3842,-111.471327,-108.664317,-50.201118,-3.911593,54.682095,91.665098,104.040572,80.723637,61.059675,64.939321,93.154994,152.494247,159.542677,89.892689,-59.302895,-100.132165,-43.592017,22.665914,123.719193,125.048864,34.297947,2.461386,27.668052,67.793429,76.454558,80.753708,77.039517,16.274994,-55.341136,-188.814546,-237.734106,-260.021315,-249.807771,-197.196375,-92.272082,-78.514718,-131.786556,-224.415712,-260.701135,-291.450311,-272.518123,-179.703706,-136.934769,-62.310969,-17.153686,69.311913,78.473854,18.072056,-94.940777,-47.06733,189.42581,278.51698,347.029621,322.865496,287.82982,241.352201,230.75421,172.906491,153.699227,199.094141,205.377505,119.72266,88.317472,117.060015,171.88902,179.389125,195.404973,208.209675,155.758521,-36.543726,-131.147254,-208.675838,-181.541852,-79.570427,-49.886169,-37.865939,-39.053734,-70.748008,-112.535305,-97.711438,-22.723864,12.973746,105.040724,157.664964,171.526501,33.233381,-62.813689,-207.772758,-207.68246,-74.504954,3.525028,79.588919,75.459954,27.887706,-1.026477,28.89574,153.375926,184.845068,137.103178,114.39865,115.574131,20.092109,-61.372381,-142.84449,-100.732265,71.475829,127.532431,136.948038,111.898214,49.73994,42.040736,37.480085,-34.331507,-58.243728,36.934318,106.743834,119.37591,45.355941,0.144761,-100.651208,-118.05485,-26.91044,48.190784,77.614231,19.621421,-47.059119,3.781786,-1.813203,-102.755444,-148.304461,-124.638302,-63.928365,44.573909,71.937029,24.127971,-156.195253,-198.227161,-97.799203,-14.432956,46.918597,21.59287,12.566373,107.947674,137.225238,184.284285,229.896463,310.699346,328.327904,296.869654,161.170738,91.011967,24.496773,28.301793,94.171457,160.968832,318.575343,357.622546,288.195722,140.938032,96.916096,126.196275,169.016437,170.867668,136.926541,85.818183,55.708254,19.210261,-49.518349,-35.809443,46.669077,65.695089,32.554673,11.473297,8.170922,-10.809263,-28.37337,-24.470859,4.651428,124.671359,190.677422,250.225035,267.024589,290.149642,338.529879,337.055799,277.244513,258.599491,302.940829,319.775889,279.697178,208.434038,172.196288,175.396324,212.056149,232.739466,220.70695,195.393715,100.137481,47.455247,64.196872,148.024562,300.033505,290.972617,176.583603,154.91929,176.591402,94.081859,21.88266,13.547625,99.739797,299.924895,362.94688,370.698885,246.574988,181.723618,118.544449,110.699961,130.686179,178.372176,262.924683,230.760816,62.506693,-44.578462,-48.523079,17.799872,51.090066,49.808586,20.151649,-56.913227,-104.526616,-97.879943,-64.126713,-55.378408,-23.116294,5.980042,48.732134,49.220586,13.397525,-17.51816,-22.042368,-11.167097,21.88127,199.277328,287.486967,249.158506,135.90779,147.953771,224.356496,266.353085,369.224787,401.441973,336.65603,256.315078,99.592387,-31.936482,-67.948801,-54.214126,-39.62538,-10.983121,18.6485,48.822648,-27.97041,-85.608592,-155.688522,-142.275168,-47.038151,13.121998,128.885893,163.816981,140.803132,-22.138514,-109.286392,-145.670499,-101.534994,-38.398435,-46.271859,-79.711989,-84.637793,-107.006325,-171.497543,-134.117083,113.886243,226.111027,257.2754,193.415303:-83.082901,-138.561872,-167.031475,-234.582149,-252.341744,-202.586157,-177.902618,-233.05234,-304.72723,-323.356606,-363.34838,-349.986204,-191.732517,-101.714039,-94.765379,-161.633348,-206.98516,-89.509513,-54.406992,-63.003224,-57.10226,21.789517,63.2489,64.133585,4.1648,-2.688135,35.601903,50.125891,21.566205,-9.964177,-34.62253,-13.960027,20.439773,-98.358587,-170.489833,-176.841322,-156.460397,-220.217889,-274.337076,-330.505462,-383.243492,-420.848375,-428.006979,-372.734822,-219.651917,-152.655354,-53.275751,-45.685124,-128.073404,-220.563287,-236.089289,-193.854582,-166.655867,-155.406294,-162.078751,-191.23687,-253.948245,-297.706115,-326.038689,-278.940443,-120.870358,-62.528037,-65.536406,-110.691683,-216.85519,-344.630888,-382.611645,-329.882844,-269.370517,-216.973374,-252.995643,-370.36273,-345.991202,-287.617746,-204.83769,-183.514564,-135.080275,-87.237528,34.286982,61.974283,-0.421817,-137.488071,-179.742483,-171.6449,-136.127785,-19.038249,43.866802,108.491448,106.306791,90.490228,60.107197,59.621046,98.663033,135.591063,174.35269,136.5852,-20.061483,-119.659743,-108.539458,8.060184,45.9696,17.921266,-3.139515,-47.696002,-116.017781,-134.787311,-136.371182,-133.714554,-98.194018,-31.995103,150.584683,187.062655,51.021154,-167.867043,-203.851042,-93.26703,-25.431916,-23.067159,-60.672896,-56.222301,30.986272,28.981116,-46.19311,-45.358018,49.618813,78.404339,42.853509,11.849837,-29.326174,-91.087221,-115.367859,-81.857802,-37.971135,24.437013,26.841091,0.204536,14.575333,33.981842,26.82544,8.210358,29.107843,62.299827,35.455818,-42.266457,-215.102647,-282.75759,-277.092141,-218.628543,-158.386105,-19.527331,-0.089593,-135.197659,-328.970466,-375.873919,-340.018059,-277.394746,-170.032391,-148.654498,-139.37607,-129.691533,-64.909859,10.105873,13.747115,5.53277,38.672511,172.28718,235.101605,282.151271,218.68947,176.068361,179.777883,212.427477,189.139946,144.316903,136.478023,155.930093,109.786201,15.117383,8.597675,126.941245,224.474934,360.935574,362.778878,231.02766,42.314545,-26.698806,-75.329549,-61.20949,-32.572839,-32.360622,-33.416756,-35.994692,-87.146184,-148.142172,-136.180392,-65.469419,-35.48735,70.235841,137.421615,138.264848,-0.425351,-60.165449,-136.503242,-142.71583,-60.256982,18.696409,158.569873,182.429654,138.569049,57.482159,45.207155,97.293585,113.670502,85.853956,75.08569,71.488173,39.545575,10.33787,-15.203514,6.292243,80.078384,114.898215,157.576365,151.978079,72.265369,-26.243041,-31.979422,33.454702,59.520092,55.190783,28.085247,-45.053022,-56.427426,-50.406477,-63.159465,-54.594176,12.826994,54.280945,115.74098,112.550632,42.924187,-37.809533,-78.524898,-129.146348,-114.766093,-33.997951,-2.213553,-26.498626,-147.621334,-205.571792,-238.446438,-199.281821,-50.431294,28.822523,119.06028,117.896467,77.124098,70.910407,115.593911,302.155687,368.134249,316.579907,256.280307,188.185704,79.277596,21.239338,16.673041,56.718155,133.733062,185.218768,334.415825,368.250776,288.413294,169.091665,147.432985,178.188308,187.916473,172.252768,164.977673,149.39649,143.716216,115.176577,30.466577,42.483781,155.524766,176.61786,103.023966,71.593724,101.957679,94.502949,48.108546,-9.260427,19.388158,142.321187,173.378573,137.25869,94.248698,87.234321,124.927641,165.829949,212.291001,215.859933,224.77452,224.713756,217.428997,214.189571,205.661699,201.15851,215.659538,220.956107,193.187782,94.301073,-33.749263,-83.622147,-34.682113,78.403074,287.746053,303.852997,195.597351,133.547156,83.089028,77.193922,76.11118,119.899111,157.935076,238.250346,264.109685,181.264655,-21.587885,-72.967267,-35.343251,11.845678,90.908167,125.283013,146.0561,104.266064,-27.28162,-114.624988,-121.969031,-51.258726,-11.646438,27.928691,50.010433,71.095038,-21.737867,-80.320083,-98.421179,-52.945534,66.023105,116.806111,153.675937,123.168253,22.652329,-5.436684,15.524984,101.346996,157.352852,290.252475,353.951922,415.632844,375.512623,311.010446,204.268486,246.426592,450.062312,493.112293,388.868571,309.802863,197.232758,127.68224,113.357126,106.778555,106.928576,133.439573,143.723246,77.495783,-28.707977,-44.486832,-44.006505,-43.734829,29.292613,104.063872,217.130496,223.227289,132.905046,39.590201,39.349283,54.75386,58.236053,97.699402,99.050909,11.052427,-32.560582,-27.650547,-18.404787,3.75115,102.774399,168.968972,285.130211,295.950663:-72.703431,-47.363276,-42.51732,-104.559396,-141.639794,-167.988413,-154.131859,-92.978045,-25.368084,-46.011843,-235.307906,-309.977851,-227.239844,-125.56699,-40.349929,-75.8101,-185.319747,-219.759255,-202.148768,-125.084762,-71.803292,55.171286,94.740674,26.589346,-85.559909,-98.606794,-106.864685,-98.095554,-13.26575,37.8557,58.698427,21.208491,-51.71358,-68.522958,-87.265782,-129.638569,-142.495929,-216.910225,-261.587419,-252.944959,-211.528269,-237.589261,-313.403046,-304.495114,-209.701849,-157.868228,-63.419977,-35.705453,-51.025269,-123.087657,-163.129205,-207.494062,-192.790755,-102.86822,-65.755443,-107.599708,-277.487979,-353.554594,-365.303319,-301.024066,-144.458831,-98.238104,-87.351041,-101.804718,-191.562567,-365.159604,-424.380056,-417.68174,-373.066695,-256.080028,-199.796098,-147.37252,-195.041353,-245.423511,-299.972571,-250.360706,-31.771771,66.068425,122.356637,75.250782,-75.159325,-214.356589,-270.914428,-256.840881,-184.428401,-41.490489,-4.936962,20.041892,57.610074,62.140134,18.344295,3.192172,8.27164,29.607258,111.943508,134.107158,77.219255,-27.401481,-40.326387,42.021165,100.418612,206.910304,244.581818,208.939306,17.98956,-92.233735,-224.610199,-211.368105,-63.520883,26.693261,184.769484,237.302517,210.334977,0.346668,-96.499847,-141.0357,-103.403264,20.049734,75.866031,133.792776,153.723567,112.931283,-99.00824,-190.96031,-169.514201,-75.541198,55.245045,32.232012,-112.46545,-234.237408,-265.513815,-221.031341,-157.000631,-80.183942,-90.942859,-132.950514,-81.55347,-43.240768,-79.662538,-140.347556,-196.380367,-179.393049,-169.63387,-215.249284,-371.530333,-471.821341,-459.532615,-318.657169,-231.491649,-116.948366,-105.461951,-161.008417,-204.745039,-226.97279,-273.366056,-247.096116,-116.187646,-69.305083,-62.417944,-86.124374,-95.696162,-65.376738,-80.518077,-109.233006,-79.463431,49.032568,112.788426,166.482489,123.837227,97.373837,106.429761,135.593803,176.776923,190.662625,199.537239,171.407598,83.783711,72.745311,94.9424,162.725004,209.466789,274.039881,257.733311,108.969414,-110.417648,-209.976208,-302.879956,-272.393286,-144.042115,-103.951505,-95.473211,-107.586665,-158.639184,-175.117672,-146.113472,-83.211544,-61.717307,12.812544,59.361724,52.352769,-94.265989,-164.98015,-228.336702,-209.030777,-85.014916,-5.443509,108.690121,126.376834,110.383386,73.780646,63.54104,95.656186,125.01828,167.019871,180.88427,161.801108,92.068268,68.292583,58.235229,88.68842,215.640741,269.553495,279.454307,237.96123,135.03036,95.909181,85.44008,54.453704,66.078286,194.230266,280.577684,357.989199,241.08962,152.986125,22.223212,7.122704,79.21571,139.555195,229.811049,231.282125,164.467251,89.008923,46.832489,-14.091716,-24.186979,-53.206943,-74.682539,-106.523836,-152.905384,-202.335807,-296.820779,-285.169576,-134.061524,-46.927976,68.261642,92.831571,130.220193,176.797446,181.698395,171.922748,184.880491,263.878527,300.591429,264.579797,108.223703,49.83566,45.060329,77.571473,152.742353,216.940259,394.834342,450.152215,424.519105,341.631395,313.594729,294.045605,300.45938,302.561321,288.254088,226.670487,177.508924,173.792603,172.521244,176.963709,200.90181,205.323425,158.624364,113.134566,77.79518,152.060595,167.918837,138.685369,147.509019,263.855806,318.609798,304.925197,248.072852,247.18216,243.67969,215.429294,148.965734,161.988006,291.730643,336.517555,316.4193,324.165439,335.904864,285.247426,242.918982,191.607612,174.042454,82.494217,-42.082818,-64.853422,-18.243006,40.075777,136.528715,146.073144,116.918036,82.266874,-8.657701,-73.609007,-95.320908,-76.478057,-17.581413,115.213777,130.952196,41.967048,-60.078412,-92.72723,-150.799379,-166.704129,-140.675594,-100.160899,-36.913978,-51.552625,-157.410452,-241.720661,-232.986444,-94.45452,-9.205898,88.420872,102.355484,68.747171,-23.29797,-74.528483,-156.631067,-161.332973,-101.803984,-62.107423,24.013834,40.814296,-26.027056,-69.583462,-41.994183,103.898431,192.299621,316.457775,358.058724,404.290309,382.817294,349.448521,306.889464,331.481696,391.49251,377.234005,302.29115,285.053405,274.455333,220.541525,188.721793,167.889804,180.132091,178.153055,143.912934,69.812343,61.719775,41.942742,-55.778131,-81.697937,0.253735,97.722238,273.356565,294.22693,239.390661,199.744755,177.187365,118.517401,110.079046,162.230128,200.497791,194.495069,110.611919,84.426723,43.420563,42.774402,154.9698,233.087385,289.619186,248.037769:-36.430012,-54.976003,-52.921662,-140.993599,-222.825866,-262.337085,-207.078638,-122.428635,-105.942794,-124.378678,-253.073965,-308.088442,-217.963299,-105.351363,7.701297,-32.044234,-184.537183,-218.610811,-179.817995,-50.436416,24.705364,136.083355,144.77835,95.358941,35.545516,-11.353506,-56.333686,-19.331416,79.516178,95.981032,63.555733,39.429168,-3.154548,-108.047884,-169.337881,-206.36969,-195.143124,-190.015016,-187.472422,-180.149162,-230.703274,-275.062418,-321.006017,-280.816658,-99.77052,-16.926372,49.630633,44.467599,-1.445945,-109.698216,-158.99655,-115.760379,-55.386723,12.759673,34.273072,21.271578,-173.249727,-272.633465,-278.735577,-213.58203,-76.383164,-7.029136,46.926041,-27.494329,-284.797375,-424.081928,-419.590574,-312.764332,-247.459491,-166.630813,-157.475084,-144.763391,-168.221077,-214.75929,-224.199139,-151.068777,11.234343,48.167971,46.417021,31.865831,10.101243,-83.155733,-152.05542,-171.072644,-106.974175,57.267591,113.017984,142.751492,126.549537,109.763351,71.408732,74.097855,146.631111,212.748673,325.290434,309.091826,111.830845,-70.608541,-57.385336,124.066362,200.437055,278.76488,298.273422,257.992992,90.71544,-9.89218,-111.573516,-87.040277,45.517667,127.722207,300.278717,355.963145,322.638706,147.022823,64.795401,-8.711224,1.962283,132.786494,208.970567,201.27152,96.328693,70.082402,31.067618,15.473588,40.523746,81.49481,117.437444,78.222464,-53.957811,-153.5291,-187.570373,-208.093858,-183.285599,-73.62102,-15.978082,39.579559,1.304902,-48.29121,-122.145419,-106.867619,5.611804,48.918351,3.07766,-79.250627,-257.220334,-337.203708,-319.119774,-182.812743,-113.812135,-61.527475,-63.253999,-95.037266,-163.544808,-206.330099,-260.842446,-241.859268,-146.876458,-110.109365,-89.037892,-87.08431,-46.267992,-40.981393,-74.335643,-78.486894,-11.622752,157.656051,183.122304,71.774645,-3.715237,28.120802,118.144263,130.851026,116.315069,137.664566,241.69845,256.912091,152.390317,45.22892,62.123352,215.077947,288.999856,355.513973,342.134733,205.943021,6.355515,-76.043287,-130.138683,-105.993392,-76.939342,-91.740307,-116.493326,-119.700014,-156.547856,-180.485871,-137.071086,18.547234,80.742469,150.886539,158.86194,77.76665,-52.986183,-92.81701,-127.390249,-123.580281,-71.242804,-23.178188,66.890305,86.236944,82.305575,57.109934,53.065226,45.175074,39.626399,128.377507,209.004058,217.234013,47.59957,-10.23988,-14.640402,21.033466,104.224185,156.291787,253.488033,252.802507,158.009059,73.826248,48.271734,35.694561,75.371901,205.597206,230.432047,148.979045,44.710075,10.710793,-26.582796,-10.837323,73.680354,118.617214,183.492746,181.863693,87.719098,-23.143472,-48.321194,-31.952461,-24.08071,-70.397404,-94.192694,-117.041463,-186.32322,-248.998845,-343.439079,-314.024526,-127.937148,-30.915704,88.620523,107.461636,100.731768,73.923179,85.141194,167.727655,211.466133,286.681116,309.140333,262.978932,101.683466,16.565524,-55.885922,-14.690956,172.092937,262.66419,356.1766,361.893933,303.837368,234.747422,237.909944,268.086607,270.725983,272.532777,275.661356,274.095733,206.754962,144.531702,84.423541,117.067761,226.713223,260.164816,237.591901,193.194084,148.284754,185.06998,184.334135,164.901409,191.913657,298.224227,317.886174,271.682473,212.945707,172.46239,123.813379,140.721831,176.75532,174.161277,154.232603,145.482513,146.321286,155.441342,160.723739,216.043245,261.754413,298.791894,244.619623,5.525867,-167.466804,-190.436417,-121.470962,-30.413173,169.682971,236.452278,254.591423,200.30205,45.437628,-26.065987,-33.425371,-38.736724,-24.081046,62.220906,93.281407,3.368562,-192.537637,-247.275324,-257.424521,-241.534957,-186.06684,-142.58887,-80.111606,-93.369905,-188.493853,-263.041249,-264.027828,-201.804603,-148.722171,14.490437,101.534213,140.663382,24.619282,-36.038416,-112.212477,-93.488024,84.323381,166.361703,153.777962,95.400117,-6.963547,-43.032549,-12.73263,121.914283,192.839209,317.43046,370.741661,399.926806,323.568742,266.389985,196.645629,231.721535,381.658036,404.379117,301.126108,243.808368,179.170833,124.094966,117.412376,129.136614,127.17993,133.497979,125.650662,-4.44203,-165.688158,-194.810386,-160.245483,-111.658604,30.175616,116.630389,232.117327,217.84553,88.437059,-10.479776,-23.490767,3.555628,30.348911,82.784609,94.078846,73.680663,12.593689,-30.432571,-121.525915,-137.416845,-11.130754,107.600346,245.927451,226.920161:-92.981597,-48.298482,-12.212207,-12.651155,-44.562881,-90.158707,-79.459975,24.476632,247.153436,316.043697,160.500574,23.220304,-11.855444,91.023564,298.292699,322.010671,144.278482,-148.803765,-229.536637,-158.46154,-37.157184,168.845088,175.299928,32.673373,-84.850263,-127.543144,-226.511923,-245.203608,-160.535255,-86.078247,-2.48627,-25.678467,-145.067828,-221.93087,-224.087262,-184.789711,-181.46249,-252.610882,-283.189916,-226.382916,-123.42626,-130.015978,-218.670485,-226.641041,-119.077731,-50.516969,18.914536,27.552297,62.089211,62.8131,10.730376,-76.939402,-47.190785,136.693524,222.622657,193.779856,-24.023222,-87.355202,-94.877776,-85.031942,-51.743466,-4.674165,94.973847,87.375253,-35.21523,-123.105803,-138.515009,-149.14508,-133.61962,-7.026076,87.331094,159.439267,4.775866,-85.585619,-115.555091,-30.872641,169.072729,209.899724,213.47126,201.295509,95.49598,-135.339458,-228.782012,-196.714123,-90.776552,75.922887,88.337726,44.813829,47.756661,61.168407,45.744715,23.537079,-25.275029,-50.898631,-74.609643,-68.808749,-19.807168,68.364195,95.04199,128.083474,160.613188,249.683484,277.505833,237.417426,75.782155,-35.315205,-232.179644,-246.508516,-81.136007,40.673175,294.47728,375.848573,264.734575,19.648821,-5.028096,84.461326,118.100235,153.496072,181.582802,234.987313,212.423766,157.405446,-6.35131,-75.105843,-83.945443,-29.645855,56.465844,57.42506,17.77759,-96.157864,-177.401959,-231.860627,-186.086149,-79.024696,-52.781805,-60.061311,-102.376484,-103.860719,-102.509087,-122.914437,-191.145994,-222.068472,-260.65114,-280.546932,-330.964548,-369.240511,-386.547455,-376.087288,-320.859878,-130.758182,-33.465524,67.631712,11.372338,-57.762198,-135.757752,-93.595682,54.388954,93.29433,87.32981,60.445346,-4.524798,-19.028253,-23.000534,-65.736259,-77.808808,-19.631011,42.610674,121.575338,142.837574,179.478645,247.386883,246.797672,203.176083,190.236257,202.272546,206.99802,175.628078,112.064568,90.861945,87.066655,92.995728,83.101117,55.181704,-103.841678,-342.88774,-412.283296,-378.580885,-311.442283,-252.278123,-286.523338,-351.594928,-344.927227,-294.437413,-261.3765,-243.437404,-175.074753,-130.964766,-80.140692,-90.607286,-153.993745,-206.018856,-219.683068,-183.522636,-135.895571,-72.328251,-62.686562,-28.279297,-2.908563,46.495682,39.515956,0.247894,-17.835065,43.06519,166.84709,168.606455,91.858784,57.594308,68.945696,121.25018,159.633296,214.212509,216.975386,216.715088,210.272855,158.382407,116.674361,119.384734,174.438562,224.902661,357.329266,418.617312,467.170172,400.455933,339.607617,242.710177,222.794475,188.730063,153.577758,102.795387,112.980477,138.06867,60.19614,-3.605802,-76.25844,-92.960954,-136.123105,-140.804294,-114.589566,-160.196833,-228.023207,-341.718477,-332.994172,-242.338349,-209.43346,-141.150122,-95.038156,-6.179938,79.420413,100.52512,95.228961,88.670007,87.227045,92.185598,93.170583,60.524199,19.824987,-87.296386,-109.077776,-24.492438,66.314822,258.646177,331.443032,373.85538,311.89524,274.795443,214.457386,209.398189,187.67987,127.290117,-20.45093,-82.028619,-69.76619,7.796586,36.957254,41.913069,36.586234,94.398527,156.143331,212.608751,132.626501,89.324367,97.808598,141.231515,243.688472,298.190551,325.395157,191.729256,153.829344,205.725744,229.448836,209.202696,211.767511,303.944058,347.981056,346.145162,309.851612,306.275206,310.014452,280.528041,117.564096,27.721551,-52.747581,7.833324,33.029641,-29.232232,-62.116504,-7.770356,39.66505,77.371155,69.994572,36.64498,-44.557101,-120.311228,-248.275188,-255.082123,-183.452808,-147.534224,-128.697608,-115.13931,-86.956512,-77.78755,-123.753195,-216.415131,-208.561533,-119.538401,-113.844264,-234.929327,-335.643997,-337.041739,-251.518337,-170.838518,-2.631092,31.295998,-51.276241,-150.998222,-170.083289,-197.444038,-190.517581,-151.123819,-164.007066,-203.339553,-176.100295,-105.157931,-130.350345,-116.311481,79.394671,193.952606,282.205246,280.631375,271.731481,241.579532,228.745949,233.816741,241.059268,236.367574,204.197214,67.597909,10.586086,-3.9489,-36.070224,-64.561269,1.176806,60.090196,74.074376,49.290593,15.479963,25.791488,20.313958,-94.624548,-143.675641,-5.218983,140.135652,295.318082,269.648757,123.580609,55.246717,74.257583,136.419567,162.633237,194.781696,198.747951,171.374837,45.554231,-51.710505,-196.265648,-186.26321,-66.23714,-16.161534,79.386193,107.669024:-126.856271,-189.966265,-178.773748,-135.233334,-126.832991,-112.774359,-93.231739,-28.506201,30.952753,20.107646,-91.117929,-131.004223,-49.231219,47.688956,159.698586,122.386359,-72.682597,-211.004166,-208.365239,-89.975758,-13.869165,110.529007,135.651153,39.763839,-151.308798,-190.928747,-115.549854,-48.666263,35.311486,47.402161,34.654262,7.780282,-94.439185,-235.281688,-286.041207,-278.782671,-237.938845,-151.370513,-117.158836,-79.377083,-80.503349,-116.800539,-216.70007,-204.72216,-46.961011,33.758883,100.615759,81.817234,-7.675776,-117.016613,-158.784997,-110.517703,-29.941955,123.206791,165.090574,84.319113,-181.856813,-284.683685,-269.835779,-172.001755,17.392531,72.34712,112.373509,80.724312,-79.552868,-200.170777,-234.250021,-319.261151,-346.917169,-231.169983,-100.127515,38.964775,-108.139992,-205.955005,-232.01063,-137.587603,84.499184,144.530424,162.223343,129.942183,24.864943,-112.310471,-172.659878,-131.911042,-32.519276,139.376735,160.866779,124.940291,118.09292,121.269145,84.475148,59.034385,53.641779,83.021663,183.460167,214.714805,190.463205,120.52399,102.422385,156.597762,213.406584,339.249405,388.556562,326.514171,70.766458,-48.553176,-171.812204,-169.059288,-22.401925,101.847551,326.017978,385.889102,329.113449,93.688383,21.589262,47.638482,88.434972,187.665621,241.886289,275.37359,218.90571,158.675771,-13.157422,-79.9342,-65.995383,15.735084,157.400172,133.519648,-58.314359,-186.648314,-212.919842,-188.444879,-117.189003,50.294585,86.866823,46.235061,-16.870158,-43.634589,-117.011707,-135.267613,-97.065404,-63.698217,-56.461401,-109.118221,-239.978249,-274.855071,-268.586645,-203.595114,-141.248283,-17.51281,26.235536,79.502437,36.918474,-32.121995,-102.347737,-58.22738,44.730351,55.108716,51.894569,56.626716,41.275443,-30.101362,-59.338352,-30.390165,19.136074,113.09631,134.433533,119.268886,71.799419,42.58525,34.009596,75.838989,191.980061,245.184945,306.575147,284.168112,153.003698,63.943149,58.414044,101.140652,139.6401,225.473894,239.208034,62.022133,-293.656743,-393.069369,-328.116052,-228.822303,-73.723932,-46.392002,-63.129652,-92.132752,-174.999029,-213.199353,-198.223056,-98.902651,-22.952864,96.37863,105.514151,9.358734,-146.04428,-210.779394,-266.661499,-243.720571,-120.481949,-37.232379,89.310982,98.737796,26.132237,-56.821785,-53.370617,41.082623,93.310119,171.243576,199.42772,186.897044,55.641193,-10.672109,-33.722579,17.36846,168.273267,230.829985,274.530002,259.09707,196.127646,133.092255,108.820382,87.505421,109.163312,226.456142,285.900567,322.011634,247.525894,182.47127,69.509826,61.439882,142.838704,191.305632,238.768847,212.84895,53.425612,-74.862438,-96.088782,-96.483827,-88.112671,-66.92756,-64.33787,-125.628705,-239.823536,-287.129757,-317.384959,-273.696482,-113.416131,-49.372497,1.748302,-0.18024,-13.983241,-31.245519,-31.890934,24.018922,69.945564,145.576262,162.998208,131.716085,-5.438772,-87.610319,-182.377417,-164.909494,-12.066949,92.820356,270.268928,310.648536,288.538396,216.959971,173.660976,124.056121,156.431231,288.595786,318.976177,236.669708,95.441348,51.976928,46.451697,75.109351,138.483902,156.533852,158.097744,149.803485,157.550311,175.409312,156.702322,124.641499,150.974598,280.968685,332.244175,302.269564,164.339764,105.254157,105.592547,152.827439,203.082696,201.713846,257.263106,308.348152,324.216277,230.760449,183.902569,141.263204,148.360551,174.772329,171.715511,92.948253,-59.374134,-112.923352,-107.963347,-71.121453,24.246686,80.831535,152.217127,133.857371,8.270081,-108.765643,-145.599607,-162.965012,-126.780791,28.744901,82.519818,-13.556061,-182.230946,-223.136916,-261.539064,-257.994518,-200.285471,-164.921079,-138.080558,-160.74765,-235.508949,-286.970195,-298.399701,-212.93481,-96.679201,149.770223,195.703063,100.57458,-3.326914,-18.261385,-41.01346,-45.869991,0.295497,42.391252,88.80764,71.477151,-7.734657,-55.481623,-36.407811,121.300743,235.203249,410.508858,432.999991,312.728307,137.04127,97.255417,129.974458,198.176585,335.179848,348.517691,251.127875,173.37579,43.222335,-25.376451,-19.130961,104.307937,171.650775,187.594295,139.622916,-4.537876,-126.81014,-169.57958,-195.944366,-156.679504,17.400084,120.129347,264.49926,266.589012,130.562156,4.653508,-3.138731,70.262772,131.129675,238.158077,258.441605,177.867043,-10.417662,-85.522587,-133.485762,-102.531963,45.356493,128.031778,200.718015,167.886675:99.407453,83.183144,98.616372,109.012894,77.318661,-8.531345,-4.965047,162.200527,465.392293,583.520403,594.720145,508.811349,366.618215,380.512007,486.168632,479.720652,315.358509,159.416012,122.045671,147.790602,197.317383,237.199532,207.410832,113.540043,15.199464,-17.353274,-50.6708,-65.807595,-91.957111,-104.739331,-137.407501,-166.032858,-230.492766,-275.912163,-308.947493,-320.644839,-270.872535,-214.512698,-244.849857,-216.259899,6.426495,59.90055,-55.031105,-121.485179,-68.980053,0.39986,22.479216,-13.237844,-6.544519,110.60029,161.087932,243.967616,295.07252,410.38965,445.717178,386.819737,210.54957,135.620898,79.117376,91.023966,124.542041,139.531773,178.318866,167.185776,65.288244,-20.372449,-58.996177,-118.484246,-105.233624,50.946247,154.453837,215.13829,113.523843,100.290668,171.952553,217.086348,260.38836,245.847014,157.355875,110.38123,75.323263,62.928226,51.768552,77.384733,106.934423,137.845286,147.120495,122.091177,65.526882,94.008374,200.402939,189.599195,-26.912831,-149.425449,-213.556167,-167.935626,-45.956904,4.02408,-18.562887,-63.294726,-43.663795,39.669121,62.54319,27.777273,-51.209681,-96.944273,-215.073868,-246.770634,-134.863935,-4.209604,248.480653,316.710873,299.399353,157.266898,99.326308,97.913076,132.239253,163.512988,163.335372,129.352608,75.4868,80.290333,59.724277,17.942016,3.443512,48.117,118.322959,107.896667,84.856177,107.344632,75.638932,-76.408014,-131.416409,-125.890487,-106.668456,-112.770321,-87.529194,-38.347915,37.256101,23.4218,-63.887999,-92.44157,-59.975231,-15.699683,36.000918,-31.357787,-90.794107,-115.129313,-43.698929,204.20248,305.670599,300.345405,168.189148,146.3045,159.554064,172.560151,191.77232,182.02085,144.08195,121.748048,49.607369,-5.453796,-8.835889,1.44065,-4.058494,18.662459,75.410136,166.594039,155.792124,163.559742,233.630257,271.53302,245.919101,187.848911,129.707886,126.270196,123.227368,178.685875,159.438614,-36.819368,-126.782242,-149.886645,-122.700642,-170.808543,-360.70354,-418.573734,-398.289932,-359.292001,-308.840716,-295.999719,-253.478132,-253.076219,-308.224984,-278.988298,-241.976667,-211.440686,-227.19051,-279.972699,-272.428973,-165.27771,-86.213394,-92.626088,-138.96497,-134.468082,-50.158761,-9.238689,0.341567,-19.813035,-37.879006,-10.153112,14.873755,46.177533,32.806231,-27.921373,-57.877765,-100.084031,-70.674005,-25.380284,103.721243,170.876856,230.513574,221.201609,225.885593,244.357685,222.89705,122.63175,79.695013,98.036895,170.140352,372.539281,443.526174,448.781069,404.217158,376.527879,265.572166,194.012871,62.447084,24.196597,28.079336,26.260418,-43.104343,-84.027261,-103.95434,-193.508592,-229.832504,-229.669615,-212.034651,-181.121392,-181.374768,-203.340181,-270.112503,-296.866824,-295.359434,-256.785889,-123.450634,-74.362652,-110.947252,-213.861492,-223.193618,-135.785285,-82.473192,-58.633972,-69.220433,-98.2906,-161.332796,-174.554794,-114.258669,-56.923178,53.742393,99.836412,163.52119,168.54023,125.651215,93.395268,88.582493,61.011342,48.493399,27.566861,-18.136746,-173.082712,-250.635845,-246.067072,-194.038661,-161.382643,-85.19187,-26.650895,124.24572,186.205435,251.258168,268.946906,246.76661,157.168491,128.61265,177.846048,235.966811,277.984033,223.907735,225.717978,246.008632,214.597405,124.023817,110.146699,175.256055,220.045903,225.159997,163.972922,127.450365,62.602638,42.317662,14.387741,-13.008696,-134.22732,-182.229559,-148.785414,-169.219689,-232.718339,-294.31683,-275.734923,-187.973578,-133.687316,-95.959892,-225.499702,-323.810379,-471.591876,-494.948458,-450.878322,-408.168493,-349.329291,-274.971365,-223.567087,-217.597513,-282.098986,-389.04579,-371.305743,-292.676157,-313.463558,-427.85059,-410.171988,-373.452717,-312.149185,-264.223168,-162.930372,-148.154007,-187.201797,-215.940724,-207.055919,-165.901093,-152.436121,-156.539839,-161.572007,-118.891417,-78.324717,-65.160495,-145.686589,-175.34846,-125.032131,-60.120671,3.430814,-8.495722,-35.081056,-50.29668,-53.809012,-34.848746,-23.357354,-26.251494,-46.36919,-132.284932,-187.205735,-260.386969,-285.242857,-303.405105,-306.598846,-274.012269,-198.69665,-194.253107,-276.891415,-342.3365,-328.055834,-285.69362,-285.802197,-273.263207,-231.75213,-96.261018,-47.888614,-47.450178,-87.660131,-94.506355,-33.042709,25.943646,88.768163,69.625506,-14.89081,-49.387229,-54.042275,-80.047481,-74.324327,-21.155749,-2.019732,25.76722,34.586707:184.742711,197.664698,216.22563,190.327692,156.118529,102.572916,104.245111,185.809256,358.533714,413.54981,326.095125,244.071939,230.682596,302.100663,414.042694,382.989631,188.038824,66.323744,38.158631,15.105147,52.022769,167.755308,182.256025,70.250872,-52.659417,-64.10764,-76.612337,-92.2762,-80.317813,-57.75939,-13.134174,1.693273,-38.40399,-139.367928,-153.630211,-106.838808,-105.491361,-205.204561,-256.661916,-204.554733,0.021097,31.750225,-147.675132,-244.140974,-228.754561,-159.770178,-61.911344,-44.140879,-9.126905,28.007285,29.076823,62.332051,116.607084,231.231893,259.720752,215.639746,98.368775,56.129748,3.844212,-11.061447,14.643834,57.981485,140.858096,138.611696,26.716253,-109.697497,-156.85306,-159.671757,-100.426336,73.225689,129.00244,109.681192,56.785966,58.042632,80.494126,95.446105,120.093815,117.443978,77.786381,49.064268,-20.704199,-117.523237,-155.805695,-127.068813,-61.985638,56.386655,61.060286,-49.970461,-130.815338,-128.036375,-161.50072,-227.468806,-387.048858,-421.668413,-342.245253,-264.600254,-101.9318,0.909657,-8.565894,-18.051001,53.039599,229.666652,235.606784,46.136908,-136.353187,-157.844797,-156.236579,-152.788831,-73.491853,5.320413,156.552584,201.592887,225.861701,112.558103,14.670461,-51.856781,13.418483,191.745194,229.637569,148.784504,82.559087,98.45154,70.457706,9.701628,-56.356776,-4.984472,194.274856,263.517501,290.952074,189.766939,96.568516,-49.638316,-57.95013,37.67592,86.396198,42.536874,-101.953251,-140.386403,-127.704033,-94.995313,-44.048837,-43.497676,-90.310661,-122.887773,-167.7778,-246.896991,-316.664904,-378.81624,-309.957746,-36.329833,85.639714,183.920968,146.996587,108.038544,55.662557,84.808547,231.6677,287.934837,266.27949,199.196424,91.97045,153.411346,202.887575,212.567652,189.976333,229.26969,301.542495,395.477307,401.484895,425.351498,430.62227,376.604381,235.743457,197.441933,221.768013,246.286044,260.285566,254.12063,199.745841,2.093036,-74.868834,-135.332837,-133.14153,-129.265296,-213.011275,-277.692312,-378.851209,-392.12921,-365.997601,-362.859672,-368.619554,-349.788846,-265.041295,-181.262132,-158.661155,-191.742014,-239.267047,-281.254276,-264.77925,-251.672961,-245.135122,-214.065337,-120.262627,-77.378188,-44.408642,-62.296789,-125.235659,-147.377785,-149.448321,-142.311149,-151.776135,-136.050802,-113.526962,-138.244779,-165.880387,-136.687585,-48.970837,-12.29996,62.307615,104.827454,171.588382,197.449666,262.428335,289.119452,284.800686,258.897007,253.253719,235.358758,251.544662,371.32984,432.231252,477.705867,406.951044,340.014777,223.705311,181.116425,69.280798,23.501862,56.414682,91.837953,59.511473,-6.311871,-23.33025,-83.514044,-138.005125,-224.222512,-214.852637,-106.136325,-29.157067,-48.624337,-187.374797,-238.71927,-228.007309,-212.344977,-194.538252,-173.11694,-102.847015,-23.873078,-3.333841,3.892229,23.699373,89.023992,105.696035,89.977104,19.204793,-30.161781,-80.898797,-49.569566,93.807385,171.313002,294.25661,330.485465,335.795492,255.779304,194.336583,90.565496,61.934209,22.139729,-1.986624,-32.878945,-21.923528,-17.181656,-45.661379,-54.474887,-8.589608,21.963248,57.16714,87.427865,189.560303,211.887158,167.613387,96.99449,120.429385,270.722002,345.39635,357.227335,298.295982,312.536319,333.898077,301.300172,243.837144,262.203054,347.463982,360.602361,285.462546,184.34192,164.018195,179.043133,172.914537,60.937855,-18.362304,-90.035198,-28.88331,-36.42729,-154.795882,-167.339991,-103.434764,-118.159703,-170.043178,-135.494451,-42.354294,-141.962676,-238.963815,-330.557517,-329.770604,-316.832328,-287.658575,-206.751892,-142.584722,-123.013433,-157.52008,-195.831653,-278.716603,-321.263383,-352.297036,-354.927785,-376.301903,-300.501702,-237.112964,-141.525585,-102.25503,-109.610909,-173.109952,-264.902928,-244.163976,-228.709186,-235.260625,-251.618151,-280.719493,-291.127372,-309.637886,-317.120144,-309.203711,-300.687549,-299.243986,-242.879684,-190.480106,-90.899458,-56.302303,-32.699234,0.100296,6.129907,-68.680602,-99.581876,-60.752313,-42.186972,-102.525527,-147.30866,-151.979225,-139.57755,-199.218399,-350.45641,-350.086001,-218.415647,-177.01992,-230.536541,-333.268915,-375.119744,-467.825533,-480.997241,-317.696387,-183.620428,-38.898365,-60.95234,-152.049908,-178.399817,-184.822614,-152.488348,-105.170623,-18.697235,-9.081278,-36.548437,-38.453002,-50.225582,-108.358575,-98.624193,36.809311,107.389262,127.3775,63.697794:-98.976241,-155.372182,-135.372222,-82.715038,-96.91099,-173.6255,-183.503937,-55.540149,161.379399,200.057385,111.982353,84.141569,197.027482,264.818757,228.325081,150.367638,55.532323,31.269982,9.781499,-1.039589,31.111034,129.021686,153.35391,96.88912,-6.020195,-26.962491,-10.123242,20.648925,83.442418,78.098379,-10.383629,-69.938959,-168.439487,-238.326518,-284.590519,-317.067041,-282.091143,-242.67787,-238.465514,-126.907993,-5.300991,-18.971464,-94.029888,-80.615676,25.870296,61.667882,72.60321,61.347652,30.838598,16.381782,22.027424,159.533336,265.463082,369.536905,367.793337,285.715499,97.723365,24.494173,21.735203,51.037361,37.395441,28.453965,114.90455,168.243235,156.269384,28.654316,-29.481947,-80.112343,-75.160689,24.371224,114.783065,161.643443,3.054788,-19.035504,95.941349,155.46001,167.616976,146.275754,136.196196,137.582832,89.587788,15.165511,10.385928,69.607632,109.400308,164.318054,171.42694,136.467862,85.231018,104.527528,155.003156,113.395521,-70.150455,-132.347027,-95.265968,-31.86003,46.872482,13.059282,-36.867637,-84.675078,-32.461502,133.626186,177.480885,143.921647,13.006347,-76.960394,-257.114394,-282.321275,-99.679427,56.895816,310.764078,366.268243,323.372535,196.247655,150.603148,113.804247,111.639734,146.634496,170.716615,128.182837,56.864755,49.472147,-55.010722,-140.786329,-167.208998,-99.737199,19.531823,25.36815,-0.814216,-23.409014,-78.441411,-231.217883,-252.781399,-166.126847,-131.930373,-142.305448,-108.94149,-86.598788,-115.034056,-134.346755,-124.052919,-123.953152,-176.969831,-192.153118,-132.322926,-98.292162,-139.254057,-225.331756,-195.302719,21.868838,131.210155,174.149084,74.754022,45.114268,68.747316,104.314594,112.277951,85.574358,78.085952,77.595429,-24.51213,-125.899005,-133.102855,-124.043275,-118.394522,-90.5615,-71.803929,-15.300742,60.178933,92.342008,158.554101,188.924223,193.158374,173.130479,143.926294,125.278182,100.1477,101.084098,71.857539,-1.385853,-13.29791,-26.642938,-50.807115,-166.013686,-330.211227,-380.667094,-342.068766,-278.912175,-231.76586,-256.578983,-288.371115,-288.937642,-274.082564,-192.234897,-169.382844,-160.38392,-122.500583,8.560711,55.344865,37.090088,-33.269607,-59.851328,-133.703852,-153.636745,-73.016197,6.373401,88.363298,54.363522,-39.500777,-31.701865,-13.279436,18.659906,41.403115,125.347318,172.210141,155.118684,56.080679,39.284894,35.554761,49.867773,108.367276,132.587993,206.855574,255.183059,277.014417,188.280492,146.611386,127.967682,148.063432,249.615971,322.909627,389.691277,314.396124,264.529461,189.231792,166.467921,123.365975,112.283291,158.842856,172.677904,46.901805,-131.99329,-159.002755,-87.071063,-63.957643,-171.772293,-231.679607,-170.830273,-93.056339,-130.633844,-224.245938,-224.736803,-167.567992,-140.888076,-67.87512,1.402696,105.742028,33.741754,-36.65062,-165.182341,-186.016016,-86.421391,-2.117652,67.25831,-23.948234,-60.42945,-34.740794,-0.143087,27.455847,29.913183,95.174963,152.443494,226.493981,227.747435,205.51872,168.689305,170.317356,151.065284,115.12815,-5.548445,-119.741369,-135.467353,-118.796784,-109.474512,-56.34883,5.881439,133.20197,140.45886,64.318412,81.466751,98.83297,64.503349,61.868786,199.318481,313.687788,386.849125,231.585203,191.204081,189.087371,180.504077,170.988499,180.73853,213.433489,223.924555,206.932662,158.254096,149.823711,207.339914,222.98264,110.563401,27.323512,-72.405694,-118.137341,-134.805427,-157.909834,-145.427227,-57.841984,-13.283922,44.682193,64.247102,43.801464,-130.450421,-252.858762,-364.692727,-310.926476,-149.289198,-116.997116,-142.97933,-169.473672,-179.735898,-216.135967,-207.458073,-120.977307,-95.00174,-135.071276,-188.822044,-313.438948,-324.415364,-284.302104,-189.810014,-134.117942,-69.90408,-85.811688,-99.051922,-38.120367,-40.50533,-146.995581,-186.564192,-143.51028,-87.444263,23.504325,51.697906,43.064761,43.243525,62.264733,124.319984,165.385775,256.661951,279.858248,249.096396,218.411585,203.186489,135.287621,104.677498,111.117417,130.636256,81.303956,12.123025,-72.521834,-75.321683,-87.972219,-50.092528,12.15457,57.35869,4.319552,-167.122168,-222.432714,-177.215648,-126.009524,-143.923541,-112.276468,-46.073497,84.67755,113.270376,102.919046,88.949782,91.295196,121.508482,152.218663,172.010006,134.138767,37.811102,32.838904,27.818683,-54.392294,-87.298231,-71.192353,-30.271334,105.697328,162.343704:left
108.11749,27.316152,-36.862322,-115.243101,-140.201965,-118.92023,-39.403996,172.311835,264.30362,252.753836,247.686345,277.787308,246.472972,167.53276,76.831136,99.997408,185.746435,250.679139,251.406903,83.763345,-57.31388,-205.428272,-189.424871,-141.858733,-104.91086,-80.712675,-72.853255,-83.278367,-73.022314,-31.933503,96.568997,144.101454,182.890143,195.30929,189.881257,118.331273,39.374412,-115.67662,-154.127809,-152.08225,-59.052984,-28.356505,-13.442519,11.70281,35.976279,20.73883,112.357013,229.789747,371.953909,253.212816,165.892676,74.231586,61.866249,49.131852,29.919974,-7.353712,53.055498,91.231055,136.471045,134.718534,8.137039,-73.248603,-71.622669,-11.094092,52.035444,52.690667,67.974344,90.657749,68.289063,41.484155,81.036118,184.771371,223.24844,231.005921,214.631604,190.985789,154.805773,161.515782,230.336628,253.412769,175.645065,29.110738,-2.727677,-16.444004,-30.599311,-26.83147,12.458906,104.991219,99.484349,55.371827,-21.914669,-40.440542,-83.148832,-97.484706,-101.870699,-99.738766,-39.818547,12.863538,-16.913087,-94.781046,-104.994672,-80.855917,-62.3862,-65.99216,-112.342438,-128.419524,-150.218058,-167.621289,-202.719367,-183.488987,-69.961757,-20.617332,65.431696,138.620258,136.85939,71.836179,24.856238,-44.468088,-50.220525,-21.29416,28.082469,55.702271,94.733849,89.562615,47.498615,42.182755,87.784621,122.6421,173.829886,205.79649,207.05345,85.614247,-38.057386,-256.777213,-294.038585,-205.909263,-68.038624,-58.460439,-138.835303,-183.315415,-211.1706,-172.404666,-22.577187,61.99956,286.766,441.905764,404.63551,176.956163,73.046599,10.143211,37.3678,49.064334,-81.248649,-146.213251,-163.519309,-130.033792,-85.999421,-87.387184,-102.353572,-100.572538,-65.855293,-54.391974,-68.642149,-94.332785,-110.520894,-187.078889,-241.061942,-314.92973,-253.706646,-209.049238,-204.232078,-221.619738,-220.840233,-189.646405,-85.718536,-34.259094,62.280474,111.35305,89.733921,-63.751456,-169.048328,-298.022994,-295.377964,-210.257007,-76.771618,-15.382844,23.699018,-7.61671,-82.650352,-69.450836,61.583132,121.864986,174.642374,213.170711,228.193088,192.595631,143.400016,46.092264,21.370561,35.424734,61.676808,23.579367,-150.638324,-233.164292,-342.615099,-376.777705,-361.72187,-297.425414,-91.728966,31.157482,22.86122,-18.364759,-30.540199,-52.437745,-38.465475,90.21909,246.273972,284.87073,307.001112,291.424764,149.573673,64.53112,70.12579,173.853854,397.651111,384.435859,320.573982,255.238513,230.978938,121.344407,68.557515,70.137303,219.045271,295.493013,351.503442,312.642688,136.472733,62.781787,-15.055335,-68.615974,-188.349011,-239.01884,-280.100916,-375.686189,-372.515301,-286.688894,-248.130833,-163.421092,-38.579239,-6.367682,-82.962832,-162.98527,-236.245978,-211.311868,-174.779768,-186.884585,-166.940048,-64.700796,-18.4231,20.668493,27.94052,71.793901,81.694263,43.08718,44.774165,78.643291,173.31342,202.503995,158.300184,95.810839,5.280623,23.24125,147.451216,166.864704,138.632308,113.043221,95.467445,48.909227,53.264689,65.439042,40.235067,54.934117,107.013588,101.298642,-7.055982,-70.48011,-72.716468,-17.638405,78.747582,46.319561,-25.013682,-188.135636,-243.196642,-276.563599,-258.166547,-187.930401,-113.344737,-78.424895,-25.675675,-13.604338,-25.444576,-32.785988,-44.845863,-78.264564,-163.468952,-145.849487,-119.721363,-155.78523,-234.325352,-380.428541,-370.9749,-186.674581,-93.828216,-170.764633,-387.349422,-415.086791,-328.543234,-280.660181,-215.674674,-191.315972,-149.795137,-147.947975,-164.999873,-183.698531,-177.127781,-123.750808,-94.192941,-87.3832,-87.823426,-78.88051,-87.747095,-110.605746,-137.219346,-135.687807,-159.013587,-180.238317,-203.755151,-238.560566,-254.173616,-261.734196,-272.988809,-250.161238,-178.818769,-13.428226,-1.696121,-46.874403,-125.256545,-139.038603,-178.215608,-209.179233,-224.34688,-202.443858,-148.22605,-98.370171,-78.663611,-108.790237,-168.371526,-265.980146,-248.741388,-114.987751,-47.557107,-73.280251,-136.411726,-129.73267,-96.768044,-95.537587,-83.207524,-62.823074,-1.936854,117.642565,185.916452,237.882665,221.249481,202.481298,213.071979,225.663852,186.567379,134.063389,19.715771,-4.072141,-32.910545,-71.057986,-149.562631,-163.386248,-158.506249,-195.962678,-210.890072,-160.237036,-139.842229,-209.386809,-252.123225,-232.846867,-148.873767,-105.358634,-23.415212,-13.996479,-54.458496,-53.306741,27.888799,65.204072:192.722491,52.463263,-11.906853,-53.41626,-47.607641,5.938802,61.360036,222.849029,347.011144,337.139263,254.519639,242.300566,246.726465,230.543273,190.016238,175.016825,129.609319,118.521861,123.985592,6.926271,-104.585507,-204.400068,-182.660836,-141.783703,-119.978813,-95.051126,-58.42678,-59.270496,-42.963575,-21.148654,49.526957,125.504994,293.020997,256.885105,190.540604,89.704249,36.444725,-89.631574,-136.77931,-153.498271,-94.057481,-82.703496,-89.344941,-76.094604,-20.292785,17.902281,139.612479,207.760707,252.491009,143.960538,74.070197,-45.7121,-88.485565,-80.824834,-34.453265,35.466077,-2.414591,-39.690846,-37.154318,2.503551,9.114397,-35.386125,-58.792361,-5.983938,146.382079,199.520886,187.485996,193.012378,206.88456,209.480382,206.575831,265.141394,411.607996,453.034834,350.363213,212.623855,3.833908,36.221747,228.715397,264.827432,206.400556,134.001928,103.555651,34.140304,-10.104895,-53.506187,-19.198788,107.637316,175.707015,162.492901,76.056443,38.815603,21.684931,18.759723,-36.963928,-59.69139,-30.57746,-20.802013,-49.859621,-127.861061,-163.196673,-187.37021,-176.807359,-164.825322,-205.447714,-243.791358,-304.511944,-305.320016,-250.505029,-227.817525,-201.94092,-164.956743,-63.824579,-16.259429,-2.793569,-45.416482,-118.668244,-201.8652,-153.353313,-9.22745,24.050082,40.437964,131.499905,160.008196,124.164441,92.038553,76.918192,95.381062,135.908294,95.87069,39.447375,-126.455778,-223.892983,-360.43408,-372.964627,-273.886856,-151.487506,-147.244199,-181.859218,-194.342125,-208.599816,-183.234631,-58.680932,24.601568,209.90985,254.426133,199.396522,50.565083,-2.372822,-46.370322,-55.452119,-82.890211,-147.000993,-198.476175,-269.392217,-264.915752,-206.575005,-172.428104,-140.631017,-159.160363,-235.670677,-263.804563,-261.983067,-281.596112,-301.697432,-326.299615,-322.048855,-263.520296,-176.835662,-166.069927,-248.657262,-311.326663,-377.510306,-341.28116,-169.665585,-97.919798,-23.005192,-35.776445,-93.770271,-234.233198,-251.778736,-189.520349,-167.183175,-168.256112,-184.554882,-207.149929,-256.307863,-258.910159,-201.553842,-147.520002,-52.968533,-39.680785,-42.214703,-6.320968,7.97758,-19.496603,-39.007936,-44.971233,-44.546037,-41.977322,-49.727566,-98.141572,-301.152912,-413.2652,-551.620475,-552.792678,-409.66286,-293.81099,-127.76423,-186.368539,-239.886016,-234.22345,-186.280985,-68.510784,-12.479644,78.850263,149.51485,167.243396,149.581368,132.941476,108.644217,101.093012,112.524296,127.519891,140.770768,104.371904,86.318144,99.174919,125.207493,162.780282,159.73259,137.225415,179.063727,229.187744,319.694226,315.336491,166.957942,75.414608,-37.222803,-66.749029,-105.071456,-186.941326,-235.478762,-276.499165,-251.758779,-129.192733,-79.708254,-30.436239,14.813795,3.772064,-84.461726,-126.750791,-161.548055,-162.384922,-155.748936,-138.706444,-85.064776,-82.223322,-98.462867,-85.289634,-41.906635,39.487179,47.094636,67.591096,133.782742,136.040987,63.15684,20.779747,-9.715987,-6.086978,-22.315005,-10.135934,142.531013,204.399179,141.560499,29.425832,27.211784,-2.690746,-55.22125,-67.024127,87.308003,136.030339,109.195532,74.55313,17.379465,-10.727211,-3.479056,74.012349,257.817194,208.458836,125.551387,21.987457,14.374731,5.378255,-3.282181,61.269587,171.337917,199.192155,234.004472,241.70644,198.529105,151.523772,86.144359,85.897182,99.609507,32.554596,-50.323915,-222.514455,-268.404262,-276.141191,-259.052703,-153.991895,-53.602018,-114.490204,-342.841882,-388.391365,-314.404108,-253.643756,-164.051456,-125.388869,-62.864919,-113.532796,-154.588775,-151.577498,-121.875153,-81.375423,-68.591153,-40.974733,-18.5835,-11.339692,8.599707,11.504135,-46.40731,-103.439363,-182.955272,-159.869696,-47.308032,-65.736218,-105.232008,-105.847928,-97.003122,-139.021061,-147.216373,-64.122559,72.593722,107.433408,0.421133,-109.138026,-216.307715,-182.130589,-58.447842,-16.230216,-13.715524,-101.575268,-129.079744,-105.723566,-93.186388,-109.491051,-114.344128,-87.438559,-30.914309,-5.188791,31.886853,42.579871,26.066573,8.730785,20.883807,44.53871,92.41648,189.010011,243.749091,251.900874,212.529456,174.732018,180.410519,166.493283,148.709797,160.902323,135.571605,64.77311,-77.001163,-75.03596,29.040271,67.168909,74.564134,-1.191079,-63.383292,-180.271483,-188.956245,-71.466392,-5.921603,26.325205,41.264302,62.20678,60.74531,29.601822,-5.169369,42.434492,233.90718,318.762378:178.614499,96.768103,21.24821,-97.551669,-123.030702,-38.985457,49.599103,169.590846,192.872817,191.708788,187.837939,190.868626,218.048239,245.453397,280.561224,269.501673,213.155176,129.270082,72.753171,-77.231388,-143.278221,-153.912749,-126.459109,-90.226995,-40.762906,-38.568236,-95.747592,-114.211099,-91.021418,-55.80827,79.099043,167.363758,265.143119,217.164852,181.457644,118.336249,88.614101,26.436276,-12.69949,-44.800431,35.541453,65.73813,55.760364,54.903927,87.039325,94.583185,119.835441,156.620851,227.657774,168.037315,75.311163,-109.602446,-152.250369,-138.480034,-120.813212,-128.686149,-128.363766,-99.916434,-59.072761,-78.837475,-135.331489,-130.041734,-31.562997,30.590837,86.788991,93.168087,110.945094,124.198889,116.469383,154.202014,190.04848,244.173469,326.54288,361.20508,291.324034,174.442895,-53.581262,-66.818285,128.488177,230.357888,221.324018,44.414843,-15.074766,-63.65992,-80.702516,-51.641738,6.815328,142.082632,212.9951,190.996283,82.875757,53.902683,88.441815,109.242306,54.836846,-8.858189,-125.191371,-169.895893,-159.909122,-122.102135,-128.323089,-184.878938,-198.099894,-177.360317,-155.33005,-151.425681,-179.155842,-219.33591,-290.373596,-286.125,-194.577109,-122.694244,-19.429077,-82.908592,-123.560892,-143.1303,-151.952825,-149.063317,-105.493506,13.977362,33.276723,19.744628,78.565042,121.595217,120.449675,106.789917,62.305442,7.400261,-75.669662,-74.942098,-97.362956,-243.214561,-330.984976,-421.592757,-412.130963,-301.571793,-185.938041,-178.200991,-223.997502,-233.090268,-197.451424,-172.342036,-113.893639,-59.027027,72.794147,63.002146,10.184045,-55.703187,-61.30306,-82.410749,-120.800827,-193.618508,-175.985741,-168.063213,-167.946387,-169.565139,-232.46134,-273.706627,-286.402435,-279.367444,-280.82523,-289.683709,-308.754133,-383.750219,-416.354926,-386.892391,-345.133044,-321.405265,-326.073201,-317.073481,-326.684944,-353.41499,-380.974766,-346.125533,-210.926799,-159.373,-149.14701,-190.646849,-220.012007,-305.706286,-329.424846,-266.112954,-211.512337,-157.000664,-131.564069,-122.5372,-162.83608,-194.25217,-160.843513,-101.007687,-40.526113,-52.017463,-47.244827,5.947664,2.837543,-53.725603,-77.497397,-131.906275,-164.029499,-185.87724,-161.365634,-152.080715,-198.561382,-282.782604,-498.896996,-534.863935,-388.819023,-280.790412,-156.75309,-178.005482,-207.319001,-252.904115,-261.858733,-205.474217,-139.476206,26.177743,156.070512,180.420176,193.794207,186.572431,106.272401,66.883257,120.676541,200.872086,273.467485,173.220074,146.49994,172.298967,176.815495,145.695876,116.115778,71.520784,141.853883,198.93078,260.861636,252.008888,180.237321,153.653853,116.034936,66.991508,-77.58461,-152.881894,-132.224729,-66.630374,-69.367776,-110.189848,-99.498082,30.842383,106.478897,71.06142,6.702823,14.271498,36.179441,29.438459,11.20123,23.323548,91.519871,91.867788,48.560081,-43.837031,-63.737122,1.742513,76.566993,199.370553,208.81598,174.298538,89.869098,57.592949,18.104053,7.646872,7.570868,33.97283,129.88286,149.665988,125.86628,84.704793,66.909782,14.723713,-3.948785,49.879843,204.360066,246.640363,197.101205,146.033804,105.649611,137.242988,274.728642,356.003027,475.749994,430.339475,358.250238,247.528542,238.780777,279.523925,285.10038,238.649489,259.047052,310.887093,426.613914,446.936806,330.608266,235.83593,140.404344,140.777642,139.922378,44.433235,-37.917117,-165.656351,-185.888961,-167.921231,-151.587625,-94.463827,-69.721393,-123.887667,-265.018604,-279.269784,-188.004006,-131.483639,-88.840553,-100.237829,-105.754004,-93.422724,-116.661939,-196.730088,-202.229494,-90.481768,-13.297279,65.213757,-12.933631,-72.354498,-120.70686,-129.567252,-184.810749,-208.405112,-172.797901,-113.153887,-12.343558,-52.586806,-89.105644,-138.907456,-173.394416,-225.997184,-206.624439,-109.488149,-69.823006,-72.633214,-126.427778,-200.387469,-327.995298,-302.708459,-124.586559,-47.393189,-9.110729,-114.92239,-182.54902,-276.549884,-289.219893,-230.194621,-176.213144,-101.29341,-87.815777,-106.381875,-171.935943,-172.466419,-71.726785,-7.464381,59.972448,70.715415,113.918449,121.59716,106.031387,114.610799,142.492606,242.877494,309.313657,373.958343,293.530853,235.432748,100.520112,33.266054,0.228348,49.139214,166.710425,176.470852,82.74706,-38.287209,-69.771872,-53.416922,-13.615634,88.878112,141.417579,199.360998,129.979001,98.383256,132.412829,147.932971,135.234453,154.851577,251.990832,299.68608:180.512264,63.062166,-21.774361,-78.302678,-65.558611,-13.932804,29.169758,124.2644,162.351402,154.506537,176.104294,212.424169,215.355946,183.92093,174.423609,201.183264,255.666847,250.174498,205.255321,37.111303,-43.394201,-96.524309,-100.424014,-130.653024,-117.126323,-107.300381,-135.654067,-152.248156,-121.424529,-74.038892,51.933364,111.727842,165.26455,141.025504,139.006064,94.962725,13.434393,-146.057017,-156.677615,-47.363918,85.234171,116.955111,171.998349,216.730111,247.122303,225.241167,240.379591,283.816585,332.469059,256.484462,180.821502,34.540884,-3.107794,-26.501262,-56.451847,-129.334082,-67.946026,-17.208148,14.82251,-11.729317,-91.683344,-92.199603,-13.878541,18.048379,44.887918,42.934114,50.04816,75.51681,49.645641,-20.445537,4.776677,180.463942,307.084796,296.788438,218.859114,200.157672,224.416687,241.059124,227.217129,221.882837,244.106325,166.32001,96.780836,23.652707,19.480577,53.692196,101.344998,216.001382,242.765229,207.660949,105.870973,62.431421,-15.440544,-58.83782,-155.929379,-184.828462,-133.848322,-42.089401,-50.978423,-165.356472,-211.109767,-186.560152,-140.290401,-53.191755,-10.991433,-19.646344,-45.117292,-58.301017,-127.092753,-138.547302,-17.30328,60.712491,94.498452,38.715909,47.626318,87.986268,46.781752,-69.41385,-64.890873,13.226463,43.839144,36.618732,45.370551,67.738895,83.133039,71.709626,42.518379,35.76143,76.39409,113.877558,74.208743,-145.723669,-277.250517,-408.535001,-388.295908,-255.955726,-167.101603,-183.150677,-228.609461,-214.105742,-167.23414,-148.150371,-83.430081,-38.754263,81.982278,215.719473,239.172471,136.487623,36.703926,-117.4191,-146.950008,-137.642506,-149.726139,-187.82572,-227.069658,-209.254297,-201.387005,-232.602048,-307.83852,-334.466677,-327.352515,-232.663694,-206.281351,-259.855341,-298.135487,-292.512971,-260.540678,-258.285264,-333.288517,-341.723555,-265.895914,-234.61541,-299.151718,-327.761841,-221.084658,-147.735075,-81.915445,-75.09314,-113.517966,-246.879757,-283.27075,-220.460488,-161.85548,-116.40694,-101.71626,-85.085185,-95.84049,-132.966634,-198.309788,-175.205997,-44.678878,5.978555,70.936942,100.964638,88.143297,49.097968,34.493007,-5.210647,-23.2721,-3.482709,29.081057,4.156244,-138.583344,-231.474078,-372.883042,-391.758637,-327.853781,-269.385236,-140.357192,-47.534671,-33.816742,-88.057716,-127.315925,-80.76398,4.550811,179.989578,325.66832,372.716239,364.70526,305.503867,154.221186,123.100726,164.52691,198.725455,276.931793,301.140619,270.421835,203.117776,178.140208,124.241085,98.848016,118.900746,236.650838,269.682337,232.879051,178.734923,70.168236,50.451174,16.960523,-51.308382,-205.009767,-225.298145,-206.61481,-185.389719,-187.452959,-177.022789,-155.618036,-83.108613,-17.531743,-9.254177,-19.956601,-24.449185,-15.066056,-2.039794,15.249969,16.762397,58.038948,150.765475,185.203864,184.21388,151.916282,107.574201,112.200637,161.673398,292.865235,346.083578,306.795351,247.494718,173.712111,155.436876,109.20867,99.271617,134.906256,140.65654,145.676012,189.461664,174.254961,62.729216,31.411212,76.318712,189.720636,235.246731,214.240465,151.654172,23.237131,-4.115704,70.787447,164.43174,347.765877,317.152155,224.010313,61.089824,26.820898,30.427925,46.474479,95.491449,187.131873,231.253705,290.254404,297.320453,243.592304,200.067925,94.249096,26.90598,-40.55803,-27.804572,-53.047116,-143.731414,-167.358472,-160.945254,-147.212283,-68.75446,0.038542,-34.818236,-179.871281,-232.80769,-278.554011,-281.90171,-252.964982,-224.119646,-178.004564,-229.682976,-277.076338,-315.982695,-304.600698,-243.712362,-208.140929,-200.470541,-296.937644,-334.941011,-314.169694,-289.664896,-277.929505,-276.802873,-264.785166,-244.675729,-191.357496,-271.857873,-357.289002,-496.065007,-530.137291,-496.590163,-420.863747,-240.985225,-206.549561,-247.611983,-332.219976,-369.227193,-459.442691,-472.73524,-397.55949,-343.98733,-293.946621,-333.719963,-348.142697,-368.587734,-388.250007,-390.204195,-352.027798,-217.314038,-120.316587,-122.604078,-166.668795,-176.241451,-172.374676,-156.892151,-81.127514,-35.995045,39.898348,140.168416,199.043457,211.468505,148.672394,77.592771,129.175331,283.662455,258.090003,170.8244,34.88628,28.232993,26.131318,-1.84578,-46.340593,-41.90343,-42.295011,-133.670032,-174.133518,-178.766083,-168.142071,-115.296748,-57.753179,-0.961551,-83.294235,-93.988376,18.750703,52.398201,-25.593701,-30.408618,165.374096,275.555316:150.657356,71.876416,27.190794,-37.424209,-70.456514,-68.300228,16.252413,262.016596,298.008077,225.955094,111.320854,89.10904,31.892648,33.71828,165.828605,233.349163,237.706492,97.538187,4.220299,-185.075158,-237.7561,-188.516239,-154.844216,-187.953339,-178.810099,-153.761773,-186.333254,-229.262546,-255.497415,-232.83094,-146.382846,-83.612729,54.218766,124.136151,129.894796,84.994486,33.222927,-36.135637,-25.583508,57.826797,181.969479,229.477604,250.530667,220.069864,97.524135,55.724468,122.532059,197.021538,264.031354,177.101237,110.414808,9.213535,-30.650424,-107.657446,-135.333162,-172.054706,-184.670436,-183.926561,-222.876925,-254.074562,-265.819175,-248.554326,-196.358295,-152.735922,-40.302199,-20.136576,-40.08392,-85.599937,-110.205992,-84.762926,-16.686914,179.901826,317.765105,307.6229,169.215893,91.886751,27.961098,65.223881,219.88459,285.790732,309.560157,188.876259,111.086887,12.708367,2.800444,61.294166,124.078953,265.303403,249.050694,139.925678,-92.2147,-122.409733,-23.511756,18.670148,-36.956531,-80.407657,-74.860607,-91.048046,-127.384511,-185.687348,-197.023488,-162.197271,-127.831909,-71.020078,-33.275534,-21.533789,-16.969266,-32.986235,-80.293343,-82.251206,-30.653314,20.519585,128.430074,112.066754,67.798755,-18.441187,-55.008426,-62.975311,-25.490102,38.726763,8.652952,-20.921951,-10.975082,10.939321,-3.776811,-17.194977,2.65914,29.963437,92.389407,49.655614,-32.791577,-255.3885,-343.17976,-373.675394,-323.935749,-170.117987,-93.18834,-117.70749,-194.963141,-209.078596,-201.31783,-193.540417,-151.759397,-93.340065,64.645682,119.737783,106.5815,-32.798873,-142.431805,-217.310998,-176.23012,-108.491518,-105.257295,-120.252678,-162.833502,-193.547342,-304.539056,-352.798442,-327.267046,-269.241425,-164.048293,-137.739691,-174.92188,-312.72025,-351.864312,-310.883263,-273.725346,-250.200331,-297.708362,-342.001672,-427.135525,-445.666656,-409.583529,-351.884882,-185.278511,-116.748422,-62.896203,-102.354754,-164.530477,-330.086861,-365.564942,-247.974059,-156.857434,-115.435535,-207.205631,-229.759221,-247.057764,-280.698574,-323.246692,-266.226779,-49.014798,34.822967,73.746859,-6.891003,-43.534873,-95.046146,-118.650363,-126.258094,-98.84431,-18.324807,22.373401,3.412691,-112.710064,-198.719435,-359.246184,-369.574459,-246.423693,-178.474399,-89.540876,-33.107009,-23.821043,-97.758688,-161.34489,-131.09883,-9.900273,218.022225,242.175571,223.751239,220.798522,214.797798,159.095398,142.483487,188.434726,244.251458,350.974198,322.43171,261.267253,151.117108,126.765774,111.516412,91.76421,73.4019,191.573307,239.405621,199.449742,135.256003,-5.215531,-55.568919,-80.486479,-66.234732,-57.310124,-107.064545,-112.99966,-60.106587,-41.772196,-57.428241,-61.014428,-2.007908,58.060262,52.646798,4.206783,-22.952759,-36.647975,-3.489053,89.024914,126.067821,196.441931,226.690292,194.197608,61.292607,19.582091,82.634886,167.530814,349.426712,423.72035,397.461502,288.463368,226.333395,116.1245,91.897818,94.32667,99.03156,120.002106,144.322916,142.464191,85.167773,32.131684,-38.443646,-34.314448,30.245526,120.122909,164.646133,207.193173,172.730313,39.721525,18.539838,118.739532,195.181647,329.146488,367.23985,325.734468,179.367416,129.205627,129.18625,145.610689,201.101252,319.183945,353.810173,337.544987,307.307411,238.824347,214.28895,159.300695,117.101812,63.413774,43.14606,8.40374,-77.581981,-104.700552,-127.918796,-111.425832,0.608326,56.005598,25.832179,-32.393302,-40.6149,-63.84964,-85.057885,-147.665677,-173.857657,-173.674693,-163.475152,-179.578607,-245.641393,-270.957262,-236.000888,-179.251519,-94.33771,-135.52556,-170.556863,-240.694716,-285.373018,-293.945637,-250.160611,-214.291402,-219.224918,-158.497889,-149.712627,-217.549093,-375.919363,-407.997737,-360.767717,-304.212335,-158.07984,-82.710374,-104.545483,-187.682453,-230.354595,-283.097492,-264.047785,-171.60942,-126.848582,-90.130815,-197.529468,-278.570959,-405.660378,-413.486266,-278.498214,-192.588666,-82.452004,-40.345361,-49.00226,-66.052038,-68.984035,-89.133304,-82.941467,-14.743625,37.084575,166.130982,263.247175,276.462583,197.877607,130.845203,121.195576,194.504816,341.870625,317.686978,236.993979,57.476755,-11.738545,-93.372451,-82.714905,17.171599,44.246575,-13.009016,-90.558256,-108.968102,-158.379343,-165.395449,-37.826405,45.939554,53.614122,-46.16748,-45.572836,-8.073544,-31.743705,-78.305449,-32.687648,145.05369,205.141548:82.279849,99.980786,77.4287,-53.895747,-122.354637,-99.65847,-17.219565,93.243338,125.919275,152.036078,225.343715,279.517431,324.286445,283.662576,223.187662,243.903331,311.970329,283.433839,216.237649,72.512111,17.668717,-71.420024,-98.264034,-124.31461,-123.108426,-109.448188,-72.483082,-55.954584,-42.084448,-34.633763,19.51859,62.527361,141.351865,164.495118,155.080888,118.354991,68.552255,-80.574058,-119.419135,-49.628691,39.698501,38.950892,52.820543,90.965643,149.072207,153.755213,174.12595,197.004628,220.921763,191.729065,179.382351,130.298262,60.77939,-40.905748,-24.884483,0.665712,-70.341084,-90.076741,-68.727115,-69.259099,-142.093221,-189.404653,-248.408623,-250.897679,-179.583444,-73.614554,-46.754389,-59.645074,-97.925139,-153.669561,-134.610378,-28.447525,110.56258,161.324817,147.419742,111.817187,123.921942,181.25892,301.45231,314.597729,210.155304,58.588227,7.935392,-35.551713,-44.848898,-51.484362,-31.971069,47.569503,19.014374,-54.120529,-149.766943,-160.998968,-222.088942,-256.928339,-264.017123,-247.205122,-152.446603,-29.324955,-26.977943,-137.794202,-182.919406,-125.247806,-52.994734,2.067034,-13.252361,-3.05856,-21.144317,-61.513701,-108.707689,-83.536772,18.506033,58.591326,106.806153,96.342745,81.657765,81.919021,70.356669,16.200146,9.865811,24.12132,34.62166,54.351161,59.171625,23.878147,-43.34568,-38.423563,30.80687,59.869032,88.251687,143.296408,153.775329,-13.147551,-164.5603,-328.62676,-305.457494,-191.221896,-112.217974,-120.902381,-176.701498,-161.827987,-93.621212,-100.335243,-159.873277,-130.712707,131.671058,318.851772,271.308749,57.377294,-27.877487,-119.132273,-134.644938,-139.872504,-197.065493,-245.299401,-219.142612,-147.502476,-137.455221,-207.764888,-263.393422,-227.375062,-156.381116,-109.021307,-73.055122,-47.632918,-86.65962,-172.420985,-179.910768,-212.721409,-306.774225,-315.193337,-227.957562,-189.969051,-231.611311,-274.702755,-251.387552,-175.026474,-9.653145,6.134718,-44.170131,-167.758576,-208.906752,-206.070525,-179.605612,-99.753004,47.259913,93.240476,28.712734,-47.392335,-158.99902,-149.828242,-11.447987,51.84332,78.793485,81.602125,104.724293,97.634747,53.668137,30.247033,66.756768,89.639094,27.423929,-0.336146,-62.422384,-109.233315,-227.323037,-278.769862,-354.718947,-356.654087,-172.20964,66.415435,89.453439,18.718137,6.488045,92.931456,150.849318,234.997377,354.804725,411.654396,451.692925,417.802202,233.620812,141.948805,128.597162,208.903589,399.507619,384.483684,304.373561,166.094397,106.310189,-7.839771,-20.54508,40.362201,123.27184,160.370422,196.95833,187.559391,116.922226,83.001321,22.299692,-40.715769,-210.347344,-371.354524,-457.241186,-560.166481,-534.692698,-387.046596,-315.966988,-220.44068,-172.944416,-146.832726,-80.502696,-64.864267,-47.087133,-17.322708,22.284439,-1.372219,-31.379153,69.335061,115.462199,132.199087,125.439757,119.190661,117.905102,131.465531,179.23287,196.552294,208.177351,218.24153,221.869944,202.66658,163.9308,157.836076,155.564778,141.783106,130.612892,142.329849,138.301427,29.732968,-28.842256,-28.764479,20.550068,7.69624,-31.148777,-39.404537,-162.324319,-274.54292,-331.173994,-235.522957,-10.078441,16.447775,-44.996981,-186.008429,-239.665831,-286.607028,-251.437643,-130.820648,-100.296987,-102.840497,-93.813667,-74.236441,-15.626485,4.96828,-27.516286,-88.839485,-205.327308,-200.294302,-163.635229,-127.4672,-163.623447,-256.988982,-227.870415,-23.879674,16.606099,-65.249364,-208.019706,-216.822574,-193.691981,-200.191714,-238.147413,-242.946187,-193.309285,-184.619407,-219.708075,-284.531457,-308.887845,-326.062755,-287.143122,-189.947033,-195.235344,-207.405474,-208.700078,-221.937807,-277.338305,-273.408733,-190.904423,-176.718444,-238.674444,-247.586916,-238.119108,-328.92556,-401.876903,-343.960451,-201.011097,22.762548,-44.013301,-111.101119,-125.908474,-103.12363,-149.948302,-193.495637,-209.209363,-195.256563,-157.670327,-101.140521,-94.827866,-187.640865,-255.425302,-302.652759,-268.907967,-141.313243,-23.072598,-12.721298,-104.06927,-159.067734,-194.90438,-179.704911,-131.676133,-99.224759,30.46306,242.14761,320.905155,294.756237,227.737526,210.091544,270.440401,374.720395,330.095467,249.254736,113.356506,110.919734,129.966181,92.361814,-37.487051,-90.02384,-145.243857,-195.605778,-218.09731,-175.145058,-117.232061,-46.549683,-56.332072,-114.371044,-123.733861,-99.99171,-44.474078,-38.00815,-94.547043,-118.034539,-46.04443,22.267221:111.657644,141.414582,69.503019,-128.381116,-161.21227,-30.972582,65.137938,164.71811,178.248111,168.940316,125.34173,105.955493,68.170771,60.491923,115.452874,154.25341,154.976731,79.37803,36.269778,-84.673175,-146.349299,-191.235539,-186.232226,-173.836417,-142.054125,-146.278965,-198.125091,-197.847574,-145.40487,-117.454272,-26.772916,34.239729,100.171292,64.829066,37.083376,13.242607,18.590656,15.543312,-4.606662,-5.308755,135.819295,209.86905,211.760727,152.787931,75.292452,86.704157,147.044813,174.917373,215.044064,134.687533,50.071755,-82.911001,-104.123752,-100.638134,-118.309215,-154.541651,-118.008961,-131.317073,-222.220492,-246.649568,-225.635349,-206.079591,-178.983725,-155.856786,-76.746441,-19.213492,-10.234023,-59.195625,-98.653086,-70.133194,6.226429,180.493832,282.552593,291.664893,233.02703,187.606565,133.607365,142.139544,236.611063,299.858249,349.476614,260.075343,206.727348,109.199879,57.347963,61.458639,137.845659,281.774485,239.149283,156.163643,-1.055134,-43.996442,-95.058231,-110.887183,-117.644912,-118.201305,-93.894906,-62.097234,-79.638431,-158.816244,-182.748811,-120.00557,-52.368336,27.614467,10.459343,-13.474599,-33.012233,-21.307735,-19.590288,-13.138509,101.920402,175.112419,253.294904,211.813797,149.030287,16.584149,-31.50647,-47.447923,-11.30767,80.424794,82.41923,41.024855,-18.720651,-17.690603,-29.481805,-55.074235,-67.411538,-33.100192,62.762797,58.619425,0.652743,-182.467072,-269.596083,-339.459088,-324.901801,-230.641039,-111.994008,-105.227454,-162.029248,-164.799254,-125.43598,-118.592769,-115.283204,-84.560516,92.551458,277.468831,279.705861,86.239649,-42.332506,-146.986926,-108.636864,-7.052868,-8.825634,-50.790446,-130.600312,-152.693003,-214.102936,-249.897273,-254.877109,-203.52311,-52.36991,-48.320546,-117.553424,-259.887056,-289.301855,-233.823354,-166.088333,-101.224689,-213.534141,-274.335242,-299.295532,-277.3102,-264.678315,-275.519615,-248.591647,-206.734833,-112.218578,-75.523456,-101.800676,-216.583756,-257.720728,-181.4725,-85.737106,46.762934,45.819125,10.260391,-108.305316,-165.533913,-174.787493,-114.953757,6.545832,30.964131,70.622548,85.457289,63.931586,19.324272,-2.434526,-44.365366,-32.006442,85.126034,143.653261,97.056805,-54.836747,-118.407077,-224.683235,-254.78262,-192.047904,-119.591126,-20.833491,7.272717,14.755469,-17.895439,-42.328272,-0.869952,67.681089,242.58013,414.618089,448.699322,374.570095,304.720772,199.097179,182.934887,193.081829,216.651341,323.178301,358.372826,320.605496,214.310754,146.701485,-0.063691,-47.3974,-19.169505,87.700328,105.727705,92.386183,75.126904,25.067408,14.439847,1.972498,-31.971834,-104.748605,-145.002515,-198.788973,-352.678341,-388.189112,-287.102445,-198.125291,-99.29508,-108.500645,-107.314305,-39.08984,-19.007735,-64.144034,-71.606147,-17.115502,1.737949,29.689977,88.299139,108.305589,108.17173,97.986725,102.408107,121.456365,206.054323,329.577692,338.08477,202.076277,118.370526,54.088598,61.673014,43.617694,29.161309,60.810966,75.876814,63.903272,36.393383,1.762214,-97.235381,-108.336338,-5.135652,100.570589,102.562366,12.349585,-60.561602,-202.118154,-229.824049,-126.098855,-25.098329,141.97185,156.341194,84.192842,-146.99965,-237.584464,-253.606511,-191.635537,-24.491094,116.098991,148.887179,149.314592,141.894961,111.935128,85.227106,20.951987,-10.514111,-25.68463,-26.082922,-57.91898,-142.191075,-156.068157,-118.69031,-87.082634,12.856774,106.003847,99.392158,-10.073448,-67.906997,-103.002846,-78.739447,-46.651872,-59.757157,-64.102306,-70.474755,-117.088108,-278.285393,-345.706791,-336.499129,-276.986144,-180.949346,-188.471601,-207.365012,-232.147149,-257.333939,-298.358517,-277.082582,-205.26231,-178.741036,-128.782683,-166.620082,-229.998078,-375.094941,-415.010537,-339.043445,-246.161768,-89.854842,-32.000304,-50.968392,-167.501074,-235.719457,-326.489702,-315.972522,-202.91205,-161.612714,-170.662375,-228.049992,-271.168947,-395.489848,-426.105811,-314.658883,-208.528178,-51.459663,-38.282967,-55.18,-82.305293,-113.307383,-210.321982,-231.334961,-140.311599,-38.235496,166.406269,256.351491,259.286816,170.536219,104.866631,114.451139,196.86126,336.682269,262.459902,165.176819,68.782452,84.087459,66.326288,24.524974,-47.899701,-75.976936,-108.958142,-135.035659,-154.878631,-173.618346,-166.768328,-116.958063,-87.759885,-71.245643,-61.344709,-52.518107,-91.518611,-145.508017,-186.883303,-112.00403,142.191724,225.837178:-96.578701,-58.387839,-43.007676,-49.740102,-80.76088,-113.880382,-90.989066,-12.471734,68.10249,101.574442,125.957373,116.20191,68.960776,53.72667,104.306607,166.229523,288.087653,273.709919,218.169012,162.753691,164.129606,116.596838,69.247772,6.508718,66.542546,112.64817,122.460079,99.272999,108.886986,154.057837,233.670743,242.842962,263.503749,277.327312,252.598361,186.64915,135.311367,21.403006,8.847202,50.599389,97.485338,116.500558,153.670979,181.367238,206.819712,214.772435,276.941252,294.266176,247.26466,192.597825,177.444733,100.067329,19.799694,-119.221398,-129.212367,-88.470994,-115.592341,-154.127235,-175.981159,-150.299685,-156.896617,-200.473653,-264.23126,-273.276389,-223.446552,-88.213692,-39.973323,-69.667377,-144.553919,-268.253183,-278.086655,-248.907919,-173.369538,-141.208208,-123.311505,-112.102655,-44.001718,23.962672,180.287816,200.315305,106.759076,54.33024,66.439805,109.916512,122.897224,122.09886,101.033109,-14.165144,-124.095416,-142.475501,-150.500565,-146.781493,-105.34591,-77.440445,-38.163452,-19.398825,67.106444,140.669224,127.766621,3.295547,-72.479411,-105.024894,-49.759675,83.63004,104.83511,76.750915,35.824293,44.938299,126.642323,183.988604,225.37233,199.971381,186.115386,253.440496,274.299482,235.56179,183.815876,106.708182,94.675948,44.736376,-12.138077,-6.149926,18.984038,7.137785,-32.016245,-28.894336,-13.698118,-20.7819,4.528917,63.999787,62.214659,6.515191,-45.556903,-169.54319,-210.222538,-255.640803,-239.258699,-187.416997,-45.08576,-8.602258,-97.632968,-171.0798,-193.766097,-124.680367,98.782988,213.735223,190.950516,65.399834,-1.412929,-72.683059,-66.198774,-42.46893,-96.470654,-149.13186,-208.641444,-199.438663,-205.134987,-231.317725,-212.384415,-171.47284,-130.411532,-100.835727,-62.635138,6.978805,-2.619755,-65.075324,-89.106242,-174.385537,-236.33031,-226.18055,-160.065152,-113.344788,-59.682559,-69.157893,-89.523778,-65.231667,32.18146,43.918034,19.529879,-81.266668,-169.367608,-232.79047,-160.270704,-15.074171,-16.713232,-41.89373,-116.228734,-157.438356,-161.101272,-101.163151,33.489986,46.941,7.420566,66.30747,118.870593,125.350112,70.233515,-8.938917,19.881422,137.474285,142.825461,101.679419,-16.97562,-98.685557,-262.281334,-296.100513,-261.623574,-235.512967,-199.34923,-110.078339,-51.977856,-1.528917,0.412037,63.029888,119.310445,177.50671,172.134206,185.925961,256.117187,278.455766,210.481608,144.051233,117.621072,180.466506,355.849214,366.335581,282.162051,101.432328,53.936526,69.114439,110.070984,115.709964,22.297295,5.992388,84.818206,140.924149,121.896469,39.487504,-124.706839,-179.641552,-260.165367,-334.311714,-384.434659,-479.007432,-498.401332,-476.523975,-430.629971,-245.751615,-82.842663,-75.712384,-140.229175,-145.894202,-84.520511,-55.650845,-59.754017,-89.465646,-123.736885,-102.407975,-81.348881,-13.925933,11.503964,4.652165,-21.046617,-76.235339,-27.607089,23.771621,90.152071,130.240027,222.577384,226.084366,166.406275,158.698394,197.483502,138.511823,88.090907,87.66458,102.92147,44.928708,4.080688,-19.694473,-10.218243,-5.772792,23.584578,12.714466,-155.080426,-243.206407,-247.280531,-194.575829,-51.421044,49.279577,16.808635,-173.72836,-283.687595,-388.345263,-347.797939,-226.232995,-224.256588,-240.323858,-189.610671,-105.087959,40.003373,23.992076,-128.991154,-188.299376,-208.745704,-139.671265,-100.561742,-94.38776,-150.171456,-290.222999,-296.268643,-148.449715,-29.227446,-40.185591,-94.548593,-98.169693,-88.220234,-85.404523,-96.605306,-111.385207,-103.474439,-94.454521,-130.840032,-192.728367,-183.56846,-106.375683,-43.804072,45.928935,18.383376,0.109463,-25.544994,-48.978102,-58.122464,-12.127436,79.268364,75.655865,36.575662,38.043836,36.807906,-8.442353,-34.797017,31.619814,125.865695,249.850003,186.725393,127.433868,54.506599,56.803136,85.199939,69.551995,-15.662327,-44.333661,-24.575529,51.050578,49.613864,-94.735676,-186.707416,-227.372091,-161.408934,-1.430117,32.28851,-7.136669,-117.328784,-156.399545,-216.706131,-248.536783,-270.883511,-234.354687,-68.15482,74.318043,99.943686,97.793969,85.721108,119.881898,179.579612,250.838067,205.21212,190.472924,212.603193,208.592931,98.466671,9.369606,-140.234135,-168.097711,-154.024769,-167.742166,-183.130294,-193.958499,-189.595145,-135.796168,-95.362125,-68.446429,-114.144786,-135.018504,-117.248796,-80.308785,-13.57162,5.625356,12.435251,-2.271396:-86.200538,-17.732764,-34.935606,-137.641312,-187.624764,-192.855734,-146.884298,-21.044205,124.074485,179.84367,212.260485,198.942627,137.255153,108.540865,86.576302,82.749452,114.571462,181.662862,169.677853,39.689853,-37.763034,-141.892626,-161.614608,-132.608262,-3.042236,62.92222,92.889503,66.556078,19.426701,30.158769,103.94829,133.857335,167.305204,137.786034,98.978091,19.031188,-46.22463,-220.236339,-258.741227,-162.411429,-19.028647,8.178766,50.495545,95.333635,139.978894,129.932733,197.297503,280.47743,353.043118,273.704783,223.781756,113.931459,66.296006,40.087589,52.149415,37.410124,-17.668917,-15.884175,32.672063,37.1368,-57.637356,-123.802589,-147.367885,-99.311683,2.258341,15.800095,-12.162364,-105.668884,-147.019314,-165.29194,-156.870709,-166.309863,-141.469377,-106.080616,-46.087109,-33.288184,-20.008046,13.771955,150.89096,196.179872,144.990388,42.817574,23.560114,22.264759,11.550903,-17.812991,-20.249761,-23.793811,-39.681287,-42.030456,-40.790253,-50.956894,-83.718818,-85.240854,-49.237907,-4.849222,149.468405,246.462719,226.868101,106.50684,41.599864,-12.648769,14.412731,79.05168,55.716567,40.61243,40.188895,35.139607,23.784406,45.423278,107.770421,120.989552,162.557773,210.99535,209.209182,191.291935,167.647437,58.973202,0.267281,-66.571238,-47.657325,-28.512537,-42.064943,-73.24015,-113.860332,-91.169789,3.434671,45.143306,139.384184,221.050111,225.66645,116.954366,3.910416,-196.83056,-235.119303,-231.670428,-164.245045,-115.924817,-68.965466,-90.461604,-171.471039,-168.537565,-25.379042,72.674422,244.462578,326.872758,320.854716,198.514749,97.479168,-17.924543,3.998047,64.729568,6.336364,-33.544202,-17.783651,25.37045,22.594333,-26.217491,-55.690897,-23.771694,11.911315,-21.602387,-18.800842,8.776249,-11.358274,-88.655028,-124.657187,-197.033811,-169.231999,-113.386626,-14.16225,17.009878,19.281762,-3.379302,4.921685,45.307837,123.49672,102.57092,51.742528,-82.024951,-135.283289,-143.30574,-100.637857,5.098742,109.656511,159.403348,138.153445,74.541211,30.797981,88.04531,240.027703,269.911489,249.216345,243.744687,245.645511,202.211257,168.31514,153.116563,172.187608,167.381946,84.352694,59.539525,20.726072,-43.893929,-260.447502,-337.081897,-290.932713,-195.868048,-12.598577,94.975169,119.604237,88.540335,50.887087,58.925291,96.301183,114.42846,136.695833,174.855288,268.402692,313.664359,295.974176,228.587374,164.336863,212.302981,377.637561,382.651359,298.678712,124.920262,88.818405,91.884421,91.638565,62.868676,83.630299,131.674023,246.969371,267.947613,165.729248,83.492846,-29.221134,-83.101866,-222.793599,-346.661748,-395.082773,-445.77138,-448.38876,-396.393193,-333.133084,-144.978621,15.314726,22.978968,-51.560263,-74.11989,-61.38037,-46.777859,-81.053147,-132.370537,-156.660971,-37.227217,16.97709,64.276719,75.069587,97.824582,99.69573,64.347652,40.120946,65.316569,217.559466,309.381636,367.995286,327.972091,222.1881,187.039636,185.637438,231.211992,239.699179,251.81778,243.983597,155.469577,107.239807,66.42822,12.547308,-18.87746,-19.786981,-13.273549,-85.761347,-147.577579,-194.464253,-168.681603,-91.812017,-67.78249,-104.831047,-237.538264,-289.639044,-321.422358,-315.531897,-299.392953,-270.729433,-257.551938,-185.300816,-107.952891,0.068014,-10.147794,-101.112974,-157.721872,-204.775431,-106.409466,-63.586332,-84.282259,-153.027337,-334.168195,-357.765139,-207.361079,-85.100401,-109.852734,-222.782899,-246.795179,-196.49194,-147.807806,-127.788204,-170.047484,-191.930453,-125.417764,-128.017764,-167.91783,-166.509101,-100.553231,-67.902961,-68.041231,-43.013494,-10.163222,-7.201913,-36.947227,-42.484675,4.744556,76.606804,53.495,-16.395353,-19.692267,-19.02578,-23.97859,-22.006573,8.401633,23.22354,38.482879,72.734177,72.855102,45.425847,45.377487,48.282569,30.764506,-39.360659,-75.352956,-78.942718,-9.963773,0.443739,-75.514857,-148.388296,-269.254512,-265.412497,-120.83635,-54.398812,-111.631117,-223.812274,-216.120015,-195.833792,-229.070974,-266.755734,-218.465532,-58.802974,41.650063,70.576344,96.296561,90.185104,96.705671,128.697762,160.459483,63.843442,19.655248,0.834815,1.674712,-57.464017,-122.734709,-262.150568,-311.599497,-318.102857,-258.171949,-245.325002,-217.647788,-196.797078,-181.376246,-186.381014,-208.109047,-199.363053,-167.33898,-94.265678,-81.565494,-116.28165,-144.776763,-170.678039,-159.979685:57.868734,66.050831,79.76184,88.003414,54.977709,6.112985,25.509486,87.800353,91.097958,79.25688,90.144141,97.933671,61.582601,44.903766,92.866772,158.32523,306.158703,246.396844,133.87215,28.327345,55.790051,66.725716,34.033096,-26.919699,-46.827757,-57.698751,-81.373017,-68.560513,16.385118,64.270006,128.112772,155.198653,241.810676,286.045735,253.350359,116.317491,45.120017,0.830585,38.447006,91.426871,39.554228,23.373476,88.662107,142.260606,182.95054,184.352794,176.682868,142.966127,76.635961,104.899518,125.7942,88.430431,29.112246,-68.909932,-95.067703,-137.263803,-153.277713,-149.704865,-159.956651,-176.140512,-227.691794,-259.771428,-258.471253,-207.902823,-76.126028,-40.19476,-62.7229,-134.255657,-169.525684,-178.612447,-127.16226,41.464679,139.276904,125.208582,34.293245,7.117495,58.643662,120.313415,193.166183,183.830205,173.119329,208.988836,186.096703,129.35556,154.507226,246.142367,244.40174,96.343416,-74.477325,-131.344101,-179.060093,-151.983963,-85.535367,-100.953014,-165.372665,-145.027157,24.646892,97.83778,40.336583,-115.877176,-139.120188,-35.99918,30.109659,65.771857,75.409649,103.090934,153.576895,155.619616,141.892237,165.478215,263.198138,296.447667,341.40856,342.749929,294.512293,125.672601,42.34136,11.469589,65.90853,128.113088,47.335881,9.682381,-3.330987,-4.876508,-45.156637,-76.359966,-138.837211,-160.295903,-131.876063,-3.776887,63.656711,55.580703,-39.620231,-231.327345,-271.749479,-260.168978,-177.653466,-145.109205,-117.429986,-93.258399,-53.017684,-63.880698,-74.816501,-44.380382,69.287339,171.479808,191.325143,165.729945,111.417534,-42.922794,-92.82515,-102.383758,-64.136625,-57.811024,-52.882566,-40.88675,-85.685732,-148.235968,-215.088192,-187.609234,-58.39845,-17.203329,-38.617045,-62.825389,-83.600217,-151.623673,-159.719702,-147.48958,-160.720007,-169.235962,-168.417899,-145.122045,-129.638995,-156.399462,-134.707073,-71.517302,21.664628,31.115887,20.28147,-29.552149,-70.714587,-129.776679,-119.45271,-29.402297,96.386696,130.369767,33.443277,-66.677836,-139.251237,-71.742903,105.940787,138.217371,143.787866,148.642794,129.002406,77.958514,52.828019,32.152842,55.373003,130.694387,156.07083,127.180737,1.88922,-64.154697,-146.285203,-149.069558,-107.139198,-107.215522,-173.132345,-135.951107,-63.148591,33.765682,44.556682,93.465861,139.80113,223.501833,282.471492,300.656084,313.739387,296.94856,217.616216,206.709378,300.939876,352.799603,353.350845,245.410864,211.185987,210.184343,196.826153,90.71859,34.212698,38.498175,138.071515,128.453042,21.675307,9.887232,61.98278,60.212698,-33.236334,-85.245234,-122.206568,-226.031583,-340.175781,-506.085243,-516.364898,-430.106644,-353.124246,-226.356194,-170.309068,-132.282895,-39.056746,-21.132591,-38.168851,-31.777058,-28.894908,-55.737585,-72.281943,-19.381854,13.790666,71.968555,71.078807,31.439107,25.703437,44.711283,88.561428,94.317966,77.491591,96.135392,158.765731,174.12372,153.802746,106.223553,24.108332,67.366172,91.559041,53.623061,-10.874361,-132.641336,-138.345559,-70.015313,-8.720186,14.767339,-4.756902,-61.240272,-206.554155,-246.007681,-188.078342,-124.237704,-33.161281,-18.194772,-45.751227,-134.559537,-170.663999,-183.63748,-155.465385,-80.901245,-68.571317,-85.658523,-54.542568,12.377145,94.653806,64.975641,-51.033301,-102.923216,-165.827046,-163.916741,-158.878616,-164.615928,-158.666279,-98.811425,-69.848674,-70.696274,-85.027276,-83.299449,-95.227216,-102.113505,-84.468733,-81.319098,-127.65875,-136.801091,-68.271482,-46.344651,-72.448751,-165.105465,-226.97852,-269.081361,-220.849208,-131.650517,-179.713685,-207.289686,-192.024271,-164.510826,-104.598633,-74.126683,-42.735903,-63.27234,-149.056138,-196.154169,-203.443996,-216.110879,-220.403841,-174.798507,-134.27992,-99.034939,-126.861796,-169.999163,-241.498283,-210.156449,-96.305891,-101.173681,-222.114674,-274.099403,-279.421831,-138.677221,-66.993352,-119.820232,-239.303087,-364.248781,-295.854115,-80.174487,40.887584,47.876422,-67.39254,-145.290954,-239.850863,-254.850428,-200.515132,-130.586211,2.976144,60.575943,77.751023,106.9238,118.34206,117.791648,101.723083,101.437121,157.870475,143.307342,57.341277,47.180241,36.78229,-11.78794,-175.984601,-249.487578,-284.247388,-220.043473,-190.729561,-129.062452,-88.515254,-7.137742,14.167312,-30.379608,-118.879666,-124.720797,-28.447237,31.861592,48.503864,27.584784,47.61583,78.496308:left
-6.487855,104.874373,165.870431,210.072309,207.086015,178.777464,118.528907,-95.971048,-220.238321,-219.170025,-130.65896,-68.052198,0.289116,6.695694,0.657703,-34.118764,-160.735335,-195.235323,-148.641473,-2.377831,53.606328,76.796605,45.898269,-33.148322,-7.229347,22.056433,80.650251,137.559763,187.501983,103.071851,-202.398906,-297.54924,-221.859306,-63.198073,-43.201887,-114.034662,-170.537031,-211.334313,-207.292244,-250.556007,-242.783272,-177.366585,-47.954574,-16.773976,22.591721,23.76611,-23.141238,-52.578238,-96.242522,-66.327232,-9.315485,134.577933,173.733668,149.855382,100.101513,-39.117535,-83.126815,-64.479417,-29.753028,-17.005426,-29.608316,-64.89113,-166.505483,-213.647134,-215.064797,-130.991097,-97.672675,-42.414887,-39.200332,-120.971704,-171.981514,-214.074512,-216.244298,-213.107162,-125.514218,-40.966975,66.9514,63.328394,-0.054568,-52.59634,-186.210374,-245.881989,-187.616062,27.987829,62.910777,-98.326768,-221.047153,-411.973554,-422.325179,-341.724082,-116.958953,-55.234577,-94.139703,-123.350462,-104.543418,-103.820515,-143.973251,-63.445722,21.56633,110.033009,88.923455,-23.621425,-99.392023,-202.677416,-103.43879,-31.163327,57.100899,82.722562,58.714295,25.662832,-5.186458,-20.952444,-45.564819,86.613962,205.066794,308.757869,249.84232,82.296244,50.865187,109.289301,220.532363,246.816362,248.405189,251.098635,203.543098,132.745859,-26.751871,-80.265922,-63.414863,84.395633,152.080917,240.441276,260.704529,247.169611,219.914045,128.733898,33.402369,13.995922,38.102108,74.228493,138.938182,136.01306,75.541235,42.784987,3.530603,20.253504,49.362406,139.11937,180.198747,185.355417,128.261644,-63.117497,-134.17579,-97.170118,76.352444,190.478191,303.5607,271.716545,167.041397,144.29549,171.298765,227.956416,236.315633,173.606612,104.446875,-32.505299,-85.447738,-182.969173,-150.553469,-86.745078,-15.957342,4.329248,93.650045,146.382813,200.909036,189.752595,120.116795,76.943542,104.561538,267.922033,343.358738,314.786535,209.781254,-33.638406,-87.473922,-19.056214,166.253049,224.495123,211.768336,190.677812,229.738591,249.819997,195.354693,159.534481,202.60522,270.839397,245.391418,134.182103,70.38015,-83.132965,-158.479824,-115.3807,32.471444,73.446292,102.861643,128.345697,139.346058,82.485652,-47.73315,-33.693347,-6.389867,10.635401,5.172124,-36.396008,-105.53411,-285.708977,-272.670273,-206.035131,-50.619259,28.20162,85.778255,30.326015,-122.324908,-144.856369,-91.174996,-12.279071,10.031504,-10.414358,-38.24191,-105.661001,-144.591326,-142.424515,38.054641,128.328506,221.443096,225.759824,118.809255,43.848403,-28.404119,-34.45051,-21.589452,4.506336,10.709993,-15.048074,-49.799248,-84.649598,-59.145311,17.631354,95.412484,154.772588,282.281298,300.108988,190.430624,120.650505,70.807455,60.60252,-8.119388,-34.101601,-2.848631,74.826643,81.649749,-11.292992,-94.620816,-229.853362,-186.060431,-117.285247,-35.974069,-37.405331,-20.801677,22.962267,69.959388,37.216657,3.206891,168.058292,240.192338,178.170158,94.997485,9.845056,-16.726037,-117.407536,-52.59914,37.037035,77.980475,37.317286,-59.696022,-139.63203,-325.917283,-377.133398,-404.016459,-400.17051,-361.697118,-235.976917,-203.393092,-218.239011,-244.463535,-275.827682,-157.614498,-72.115462,-9.284254,-28.706497,-119.581405,-194.77402,-352.594373,-387.569345,-338.654698,-266.768281,-239.056976,-171.244936,-165.415679,-228.383112,-265.034582,-327.479058,-286.772582,-217.723786,-107.485915,-107.940905,-185.476536,-214.576353,-222.241528,-213.100038,-150.164335,-80.043426,-60.913279,5.117793,43.759277,34.818234,-35.547483,-221.525031,-191.593573,-74.279421,141.170282,180.364548,157.962124,137.648488,97.623429,44.217525,-88.514672,-67.294331,-19.490914,-3.43601,-48.841013,-120.106291,-113.011946,-96.11574,-81.500165,-53.84243,-7.197416,-8.467638,-54.725395,-65.152978,-40.423213,-67.133264,-272.526026,-446.847467,-419.122788,-156.664295,-22.523807,61.760638,12.05157,-157.845987,-223.072181,-207.724627,-128.653222,-74.050242,25.419229,62.07979,58.764995,22.980799,-25.035447,-39.617509,-35.584679,-7.993549,0.762618,30.974928,57.717274,87.139877,88.4401,85.662512,59.143656,69.295388,133.077281,123.398604,23.402376,-7.297038,17.724835,103.524998,146.33887,181.655322,183.074609,214.324967,224.801522,194.976837,194.12512,221.531027,337.353322,414.085027,467.117142,396.385062,165.623949,107.351138:27.727705,187.563722,173.847011,78.883721,52.00973,-1.19426,-54.892891,-157.179949,-149.584457,-95.143413,62.759429,112.0488,47.642536,-31.68557,-91.530235,-70.229277,-73.612625,-109.95259,-74.402187,26.676017,20.808531,-48.939508,-54.259697,-8.818646,41.124165,42.746323,70.049919,126.39428,188.860735,124.822015,-147.223039,-251.240265,-192.192452,61.443348,117.838805,2.604849,-77.109617,-102.897991,-95.918054,-152.858284,-153.029712,-104.740863,13.939007,57.334492,75.972695,52.847166,-26.451964,-59.589008,-45.511278,36.217048,61.61373,111.251523,146.675813,130.92356,47.122178,-122.856722,-106.028371,-82.620026,-52.054002,-6.533684,46.810513,-7.445133,-186.500745,-228.412743,-172.802821,-118.314615,-118.52503,-67.719688,-31.592423,-69.732189,-127.969965,-178.859602,-132.76216,-117.899904,-83.724006,-31.830581,69.855171,62.982047,-67.669015,-130.87395,-137.706957,-78.176606,-32.285822,73.144148,73.949311,-42.944773,-109.089285,-192.573308,-198.222383,-164.638006,-47.525815,-5.88879,-43.337977,-105.161097,-231.636209,-270.695522,-199.587499,45.782139,135.062415,125.679621,57.15338,-99.976689,-181.667502,-313.561201,-275.203347,-220.588134,-127.934544,-83.403749,-40.839039,-67.824652,-191.976651,-225.910943,-126.146488,62.827445,142.379319,189.727271,153.193182,65.564386,22.202742,-9.413064,164.071951,260.180418,296.21858,252.125566,162.934941,129.397262,7.593663,-79.798329,-86.285307,213.924807,340.248752,351.58964,268.246585,34.5458,-63.850989,-100.548072,-17.733333,7.734588,74.899178,134.371171,181.030013,127.931171,-31.79985,-64.246137,34.493596,223.136851,294.033575,327.685406,306.900064,252.265995,206.606154,71.824441,-23.484859,-18.769269,135.105326,237.882079,293.539394,241.070592,130.690582,123.192693,181.187041,207.164958,216.582572,187.276495,98.263687,-141.523444,-209.741841,-201.978937,-84.891072,-10.451879,76.732339,82.437863,86.231604,93.080706,102.353554,98.06541,66.961493,107.775527,203.516504,405.02649,421.242044,320.982438,264.094755,140.678111,43.204966,84.128057,300.932119,355.098137,243.253652,158.849703,114.775392,152.922882,238.306103,255.627603,271.222783,292.712209,253.141226,87.796057,2.189231,-114.392369,-136.731642,-104.148074,33.904772,98.04052,98.337024,56.827517,33.846112,46.854305,52.315678,38.148589,27.213431,28.106058,54.00493,56.884867,-28.355678,-255.683717,-247.044658,-179.852075,-41.608596,37.280875,126.901665,87.415866,-31.606251,-35.361728,20.91391,42.894725,40.375941,26.789069,18.726724,-31.485561,-85.557359,-176.089521,-90.520417,0.752606,124.692081,107.792248,-22.066163,-51.048499,-43.031245,-68.563915,-164.126442,-148.814287,-76.071635,10.820324,-36.265617,-154.104118,-142.766666,-20.36252,88.685921,143.654045,242.415621,239.586941,108.289383,32.662077,-53.877835,-74.539298,-62.607009,32.117481,70.677723,71.726874,49.436214,-37.73533,-104.951357,-192.134244,-127.468412,-62.987792,12.99287,-5.634093,-48.175243,-24.770114,17.36558,4.918842,-9.964175,31.187635,50.336997,50.267194,33.856336,3.64844,-22.791006,-103.212511,-99.252384,-85.372109,-101.202306,-104.793214,-127.931104,-195.970842,-372.573309,-389.381392,-272.073395,-156.880701,-114.461995,-64.509298,-60.438191,-79.90635,-106.964072,-139.681249,-65.448953,-17.941554,32.448286,43.945645,-22.318403,-136.343172,-355.718426,-368.553796,-233.918284,-87.872395,-50.816752,-92.012847,-150.851982,-220.772822,-219.821955,-218.034239,-216.751175,-177.360245,-77.957148,-73.712525,-128.23312,-146.422431,-164.456252,-168.055523,-119.473053,-22.613664,11.294616,47.260753,53.978748,49.710462,30.219143,-61.681402,-43.701541,62.340673,295.233902,337.129167,232.885076,143.4832,41.331615,28.706622,19.298976,45.784322,78.684563,87.367897,31.021036,-106.159664,-135.046516,-109.944833,-65.342637,-62.236969,-13.715151,29.941606,-29.195371,-109.512409,-165.844058,-160.489737,-167.604922,-167.844582,-172.527637,-134.282266,-66.130456,27.108529,-25.982704,-221.369065,-197.596968,-126.750948,-55.901313,-47.097176,-10.336668,18.05368,23.548777,-20.346201,-70.283761,22.88795,72.265616,89.040102,55.750604,4.074338,20.390216,86.018155,81.105662,64.463058,85.307051,123.682487,166.682306,128.28916,-82.208499,-168.319575,-62.460303,202.42972,238.045886,124.870549,92.443466,181.822417,218.949977,177.433885,155.942788,185.901326,301.054685,365.0072,434.378665,401.709133,195.960031,106.72583:-0.844672,110.868761,141.177695,150.038655,120.564358,-10.424577,-94.699206,-198.642822,-143.553893,-67.605226,117.693761,181.184548,152.916567,89.511274,12.730491,-5.915964,-68.778964,-39.83648,34.68115,141.358128,141.091308,119.539736,104.207001,92.969317,148.393011,141.85364,86.610875,88.877489,104.607822,63.361735,-117.797299,-171.731609,-38.414008,164.885764,171.055689,81.983089,54.305632,20.063938,5.396673,43.989207,94.935593,78.762641,58.340492,113.72007,265.49833,253.850266,79.605909,36.175269,109.286357,167.378226,149.707538,87.352442,91.034931,145.522989,111.451292,-102.170967,-176.491998,-135.583385,-30.609282,12.912401,26.371222,-16.627603,-154.422095,-200.864164,-144.458337,-87.39791,-130.486419,-153.13152,-95.527352,-71.280961,-119.3595,-94.171371,-7.752288,-37.317311,-115.487573,-106.195148,-34.607773,-26.617195,-115.21288,-140.142141,-28.343731,61.602175,46.64106,-12.26805,-50.103129,-112.766571,-110.613464,-101.326374,-165.899514,-184.27903,-117.816367,-68.265133,-66.885537,-125.750763,-269.521693,-307.873062,-264.50866,-61.653536,48.428671,70.509629,-35.616037,-298.781711,-388.293197,-430.463958,-300.339236,-245.020734,-217.262751,-185.996599,-88.169351,-93.977007,-229.534411,-270.432448,-171.185566,27.395998,106.50442,138.203704,91.680415,-29.180859,-85.689594,-98.056999,157.017774,295.668441,366.26309,311.96117,176.7917,113.276508,-46.309474,-97.882846,-9.629042,173.140473,227.417241,277.838376,280.697951,157.057567,35.215558,-107.626346,3.484822,78.877717,152.499805,159.273582,120.346563,65.849722,-48.628511,-50.733746,66.957139,190.672502,239.50156,284.903606,259.860958,124.202129,56.328932,60.497171,179.844199,225.959452,304.760583,344.757265,380.012943,357.268958,273.232931,248.255206,248.797568,241.656109,228.799949,171.995027,113.897287,14.97873,-12.007354,-102.380077,-107.660397,-33.745024,95.254181,101.941812,29.608125,-17.003999,-35.317475,6.963986,141.917059,284.131452,350.317643,427.630557,425.850125,339.356036,263.17566,140.952391,184.483318,270.41261,420.014848,410.251502,309.330726,280.241981,205.823236,175.207653,257.020164,366.126885,362.028669,283.338978,226.201783,57.723489,-47.167975,-178.443763,-95.84815,-7.141791,109.406792,101.370518,3.069023,-27.85165,-5.152234,-2.10232,-25.79534,52.041569,81.132491,17.252633,-11.806805,13.974683,-5.309018,-153.476687,-197.690897,-157.439009,-33.044116,32.088855,126.157987,133.801343,55.834667,11.970695,13.948176,26.909247,12.954128,-3.989776,-6.41714,-47.655913,-94.450543,-180.414101,-122.395386,-30.417466,99.545232,72.188655,-58.907636,-90.178758,-132.895854,-162.257938,-167.553166,-89.802584,-29.727624,9.961476,-54.603375,-199.667373,-205.847644,-100.94977,92.633776,193.069959,279.626971,241.221447,105.571,53.391056,-46.7075,-91.955271,-99.414462,-7.791204,57.011377,132.306401,134.373636,118.547405,93.774281,19.776705,35.941191,74.468795,82.765454,43.981141,-20.732858,-27.855103,-61.952501,-95.269007,-98.076479,-28.787141,-11.905999,-63.192518,-102.222749,-94.59464,-79.140856,-105.339145,-122.711552,-151.69866,-194.757597,-156.797604,-102.122431,-164.929203,-399.58999,-475.562006,-426.011076,-236.687424,-150.40299,-56.10851,-40.929729,-22.315468,-27.804536,-46.28484,-5.975934,11.578544,2.982407,-17.619007,-50.515534,-56.207056,-93.377322,-112.619794,-98.819172,-84.024676,-94.279086,-157.135762,-190.888905,-210.093024,-219.077363,-278.007853,-249.386224,-178.197685,-85.059189,-120.424438,-253.594332,-288.453869,-283.626292,-243.823698,-66.280354,90.858395,124.556405,147.420187,127.849971,6.982393,-59.762562,-115.783462,-69.260396,-4.291597,195.884147,269.82969,244.719318,177.744494,41.166544,-25.914449,-129.958258,-63.339354,9.73889,22.796903,-65.550207,-267.028644,-306.443253,-254.037722,-213.790079,-239.552156,-183.267376,-78.514414,-15.614152,-97.316852,-216.793807,-186.782141,-85.696585,-90.930596,-104.184879,-100.369939,-99.701169,-123.896744,-121.1844,-26.569427,34.895027,14.135878,-31.243328,-22.997746,28.923393,39.329383,-22.383366,-58.279912,-1.041595,122.309994,146.694205,137.423414,111.598985,7.353482,-25.012254,14.679703,-16.111456,-50.6021,-1.20161,63.765222,97.5273,30.866694,-168.844513,-215.192624,-115.203926,42.675115,73.364377,86.190014,116.811714,183.394452,153.608636,60.497802,152.971119,221.622943,331.664112,379.738943,427.52434,401.645973,208.674104,109.847364:14.214679,191.136831,205.506159,158.62232,160.17978,170.090693,120.180551,-74.822847,-128.134385,-77.003668,23.484638,41.062337,14.44929,-13.509549,-23.431084,-1.621673,28.075767,23.928505,38.801491,113.692849,138.919124,110.405588,72.191972,27.725916,70.94822,84.344297,57.670127,36.458087,-37.534835,-103.02954,-270.214166,-323.94774,-226.76738,-36.65202,-18.753066,-88.664353,-112.179716,-83.216868,-44.305076,22.611154,6.583934,-9.372943,42.637894,106.798779,214.211194,222.230909,155.316936,115.15945,77.741256,64.102689,74.746784,140.114024,154.252509,68.887489,-25.625099,-209.35118,-197.533893,-151.28078,-106.465772,-83.72176,-35.516556,-39.383158,-115.616863,-171.455316,-209.937133,-169.013468,-151.939038,-77.951147,-48.342042,-127.80453,-193.955321,-213.119164,-164.441945,-157.40824,-115.990018,-71.300447,-32.361947,-56.856409,-145.074489,-170.618991,-132.480168,-91.343855,-66.426689,19.320935,13.028778,-162.592368,-263.979754,-339.580606,-243.5516,-187.391293,-137.797156,-130.797102,-129.81843,-133.61964,-155.443757,-182.563751,-217.55316,-68.672516,44.368472,110.714784,47.455405,-149.261564,-246.472669,-346.244197,-241.571518,-165.063805,-54.10988,-2.801364,55.482208,34.789245,-74.045738,-134.785105,-189.692602,-70.921389,30.307369,146.45238,130.562594,29.643554,-11.298097,10.641921,164.155449,234.330242,309.896507,311.610706,198.736994,97.610454,-71.412864,-96.859944,7.342541,180.604323,232.141221,271.350502,254.051317,91.050942,-10.934478,-82.60675,-33.288776,-26.992623,-20.107278,16.04034,94.590626,92.543231,-7.726175,-59.121876,-9.371105,178.325326,228.566923,195.292997,164.157577,131.773525,105.38435,52.03336,69.558606,91.452214,205.185759,299.027187,425.638334,423.089427,322.741895,267.320403,251.059374,320.148166,326.762098,232.238587,157.299809,74.43377,63.15512,-17.857212,-105.341279,-87.852786,45.08296,107.231002,136.71199,123.117772,85.640858,69.254693,93.567701,171.704103,224.17974,350.392159,384.276202,310.792009,229.925078,88.197522,42.496593,93.717471,282.885358,328.424653,281.270057,255.469604,236.315159,225.143699,196.726056,157.000198,160.044377,225.168956,234.847191,98.621204,-19.722352,-186.521868,-159.976284,-92.315085,39.53657,64.462851,56.159202,53.258436,35.994015,5.240828,-39.147179,13.271807,35.419509,14.99778,-2.753312,-21.787393,-63.611165,-227.074659,-263.470295,-219.039759,-65.944697,39.260374,177.301753,165.727609,76.295498,56.562425,73.715295,73.743939,60.579104,33.296714,25.283335,8.521476,-6.004855,0.921896,118.400322,174.853424,157.068315,104.960171,39.188587,21.322936,-59.205938,-110.204506,-136.695768,-36.0435,33.529467,63.767258,-16.47166,-147.730512,-108.090697,27.202766,88.05491,141.245072,289.404011,324.249324,261.90518,193.028952,70.73936,41.172528,16.398314,28.025648,73.130762,144.782462,118.773191,-18.012289,-74.582949,-100.616226,-68.161489,-35.964985,67.153433,88.827098,27.634448,-8.591023,-80.19712,-112.811165,-69.635024,27.746265,36.831041,-0.633471,-22.955525,-49.328628,-71.996926,-138.579273,-91.995273,-50.672689,-46.28661,-64.251691,-137.57169,-225.023709,-431.816803,-479.373805,-411.755984,-266.19017,-199.603155,-118.50649,-126.472282,-194.958252,-227.190239,-256.794993,-187.078234,-137.08983,-82.149119,-81.291877,-167.998937,-251.724701,-371.631664,-361.464011,-240.300175,-177.765798,-193.225106,-275.771136,-321.870298,-368.577736,-367.48922,-366.855768,-382.801652,-367.965614,-298.041219,-283.742319,-330.845748,-370.386151,-424.153302,-409.523702,-280.542559,-171.580365,-154.086022,-117.133933,-87.443629,-70.191005,-103.108254,-195.958585,-184.043264,-122.654964,44.871646,103.396731,121.035249,87.797475,-54.67612,-132.888562,-180.577505,-75.605244,-14.569326,16.830467,-29.402749,-169.881723,-215.474493,-239.852865,-227.519996,-199.080529,-61.941106,2.254097,-41.044089,-127.215136,-242.127377,-245.947485,-229.014184,-242.677206,-239.106957,-132.458791,-52.155285,4.384652,-33.177391,-127.549504,-101.756621,-48.708277,59.72095,97.695749,101.697439,79.449682,46.048147,19.78642,-38.364289,33.217026,96.502463,146.20535,126.834102,63.419495,41.935308,9.019945,-37.948428,-37.59876,59.803774,132.127063,165.198122,96.63692,-93.796782,-139.827468,-59.972435,91.145524,134.787341,192.572252,244.409446,321.580903,279.772704,119.506864,138.598972,209.376654,381.739584,460.798935,505.649733,450.545978,265.395483,213.378866:38.536513,154.826882,184.432748,154.956964,114.398128,13.436756,-69.376041,-245.051753,-185.393841,-51.98915,225.531334,281.967487,153.665271,43.58117,-17.572445,26.666604,66.614687,50.672588,85.486801,146.060905,118.011729,15.466088,-13.099684,0.145387,51.735232,63.463166,84.584829,89.288535,-1.211122,-90.752114,-248.120982,-267.159101,-128.160213,31.805235,51.690931,48.334161,44.754165,11.138018,7.491396,90.715359,164.543719,181.838528,249.996028,284.365987,280.057064,241.190892,151.647667,123.451949,101.455804,128.530793,153.172387,165.155621,146.367132,33.945403,-82.57707,-305.317142,-244.141832,-161.37917,-81.994808,-63.630272,-42.648884,-66.573569,-159.334288,-190.843507,-170.644836,-120.268765,-107.265209,-49.913123,-26.443613,-87.083402,-142.047943,-186.136601,-141.942664,-98.89649,9.923374,46.251585,45.506306,13.954606,-160.873634,-249.966609,-161.285022,86.981218,135.338407,101.919212,44.850635,-148.359047,-257.798144,-366.07111,-281.424529,-214.915048,-95.678316,-66.904206,-145.642475,-229.822117,-337.32265,-338.685025,-293.254415,-189.75783,-104.519214,33.526546,28.431088,-162.933669,-286.104349,-380.632149,-271.033797,-209.82521,-116.406194,-61.911975,52.031973,66.363209,-80.029675,-186.410204,-218.846759,-37.152299,42.42901,96.378375,92.577687,45.134403,3.651093,8.722539,157.792852,219.632534,281.542372,289.826469,233.336155,156.96463,-39.549688,-84.806193,33.877726,215.706261,260.234127,231.622861,162.327318,-20.63369,-102.450125,-183.675043,-146.536855,-97.407463,47.235967,116.27145,131.858282,65.194391,-123.985061,-181.583777,-105.981658,97.058978,153.140847,140.526781,112.493603,64.646322,45.466742,50.928015,107.033382,155.713716,299.472644,354.201835,373.661888,365.944647,321.773307,288.759839,301.520887,343.09448,320.296816,202.064037,126.580269,20.010906,-6.482762,-58.007263,-85.454123,-63.467855,69.588893,133.710366,105.561889,33.596613,-65.237195,-61.499192,63.63655,290.965862,392.392541,476.590916,462.058413,358.783169,268.834346,89.554071,75.752423,156.085693,374.437856,400.093401,278.652976,217.180347,118.423355,89.524245,147.232146,237.675875,255.067025,259.075296,231.217665,46.465039,-81.653372,-207.823169,-63.204598,51.358005,178.268075,152.21763,5.511524,-49.855175,-77.906203,-82.278359,-76.233442,43.542583,93.303771,41.525515,-12.10145,-59.987082,-93.266593,-218.032674,-240.866803,-190.602177,-47.558127,19.082977,108.741361,103.007442,-55.779457,-137.746794,-101.342418,37.462649,78.273179,115.348923,101.955495,13.079568,-41.272915,-118.997968,-38.663351,50.322767,115.254266,64.706306,-34.86825,-55.368919,-174.092933,-258.363375,-243.208967,-61.263708,-7.577758,-25.876216,-94.13521,-233.178216,-248.616483,-179.15526,-42.907833,46.394672,200.662447,203.873984,63.111341,-18.740988,-111.653787,-108.245218,-5.72083,78.65128,88.955454,53.306682,3.779037,-115.30372,-152.653898,-135.173979,-54.079143,-20.499066,21.687727,20.391081,-65.104301,-128.158824,-220.976725,-239.253143,-188.152503,-42.184922,33.301586,38.005323,-38.642628,-169.154134,-200.787634,-208.559216,-114.243359,-93.660846,-174.191438,-222.160502,-245.649747,-251.688512,-336.631039,-371.07142,-291.127704,-149.185913,-96.261606,-20.16692,5.594101,-4.666179,-67.605558,-164.982913,-42.221045,29.106782,50.213618,18.587065,-51.415047,-77.208722,-152.27765,-203.545895,-216.454396,-89.907134,-42.246214,-103.508191,-183.097604,-292.219891,-323.915628,-360.108949,-286.633276,-228.893911,-141.555122,-130.370696,-205.821016,-266.853324,-336.859554,-310.725916,-126.774217,53.840109,113.698473,159.490603,137.377027,44.187932,-11.166402,-55.653511,40.002466,96.939817,163.491705,178.648703,206.520265,205.589788,85.291616,-17.277153,-77.812635,152.940437,272.459769,268.758856,140.541903,-144.926743,-233.009365,-285.834105,-225.836603,-182.571397,-49.91004,19.142774,4.752099,-73.863487,-230.297991,-267.854065,-241.657933,-135.98219,-75.492721,25.841333,34.801072,-86.521726,-154.929217,-94.68851,97.042982,140.162967,135.733541,131.839976,137.06799,125.034953,35.308497,-24.459153,-64.273888,72.65342,153.756817,176.943872,123.19427,-13.633258,-63.799103,-101.858405,-73.644893,-26.649573,84.511877,108.807471,74.855778,18.835104,-157.52063,-211.938406,-113.520975,100.391942,165.566861,185.647477,173.266148,132.94211,86.642976,-5.212667,68.626671,153.342753,308.997246,359.839648,374.214909,325.784868,128.751425,45.829246:51.857314,125.368395,163.425154,251.393637,290.995582,276.063874,184.323697,-94.926476,-178.46828,-140.650971,-75.441884,-70.138527,-91.065726,-92.946257,-51.069489,-27.363679,2.518179,35.142323,52.719645,86.77881,101.311298,124.003034,112.247391,12.749901,-18.567405,10.115197,46.987474,44.295506,-23.665482,-110.546313,-353.749087,-436.755597,-356.689266,-82.420084,-1.047741,-47.256451,-102.042545,-81.012573,-23.138242,32.554465,7.120855,5.015596,64.340677,111.626055,166.54668,164.518579,117.151579,95.890527,152.260208,226.232195,212.422066,168.964576,147.25603,54.698747,3.058863,-63.044521,-74.278803,-82.036134,-90.437797,-77.22929,-111.191252,-165.181218,-223.092669,-216.099356,-189.859513,-180.579723,-149.858709,41.804252,134.242138,88.455997,-26.532837,-210.895559,-228.56945,-195.783621,-71.364759,2.277221,72.942354,50.372862,-46.129782,-91.724027,-163.345257,-178.053443,-119.263074,48.878292,43.576344,-177.913713,-303.462591,-449.787533,-362.224019,-257.498334,-102.158704,-82.068457,-139.943063,-177.67654,-165.120972,-121.27421,-29.776707,77.525593,157.551376,267.705341,226.679945,-17.019929,-134.949689,-204.123961,-13.959256,109.029505,240.863066,247.475891,176.730878,125.823758,47.501284,5.031774,-79.003089,-34.435998,57.101071,236.12266,245.89803,84.493726,-16.476979,-51.495648,139.591116,206.199319,206.243613,191.314833,143.412741,95.558783,-5.697593,-38.79394,-5.601684,132.512985,186.763911,238.324152,245.168848,189.855105,128.912234,21.243794,-50.013447,-80.476702,-72.540447,-21.106557,77.788457,75.002708,-30.833123,-85.583527,-105.659951,-91.976266,-82.107799,-5.195558,13.079286,-75.707261,-139.235063,-190.158809,-116.932764,-38.528635,190.911408,295.759953,348.603014,316.090823,242.925702,205.042093,157.338545,166.235194,170.234876,164.546396,147.259547,82.019269,24.32996,-171.186604,-252.813245,-193.380801,-25.92609,28.958531,95.962296,116.346853,68.29103,5.359386,-23.668742,86.945784,138.771785,234.938856,277.578907,236.44127,118.659444,-193.541485,-278.998989,-182.967427,91.215028,157.921111,116.903822,78.668936,49.986458,48.156121,59.409131,64.569931,52.915029,67.131888,92.623786,46.899313,-41.358844,-172.844916,-106.785369,-54.916181,21.602449,67.929183,159.15533,168.967824,74.424716,2.676631,-49.053199,-31.477771,-50.568225,-139.694593,-176.192429,-145.593257,-130.291344,-268.20784,-388.444193,-348.321905,-136.926044,-21.431545,80.637657,38.694489,-113.377912,-153.277408,-133.990487,-78.877118,-59.122155,-50.58709,-66.04559,-65.775295,-29.982491,7.976313,72.129396,154.333614,231.706111,187.644669,28.610088,-51.724846,-161.297117,-174.227634,-96.419344,35.000831,54.909191,-32.878729,-103.923936,-146.220393,-99.092522,-0.458605,66.155125,112.183199,201.215632,224.713287,222.193072,206.098611,129.321576,67.423126,-28.975056,-27.374392,-12.077401,-8.293812,-24.087243,-100.617694,-174.113728,-307.371364,-209.926193,-100.68212,-16.065447,-63.341101,-134.900714,-106.829296,-34.863725,-33.861307,-37.290701,32.52493,70.140817,66.004542,22.057109,-89.514141,-141.205903,-199.979323,-72.223393,21.140109,66.244966,31.506553,-57.134722,-119.116549,-265.093423,-307.576798,-313.676439,-308.625051,-280.254285,-161.071,-129.553151,-202.878188,-266.762607,-305.99016,-166.592157,-67.786373,19.10015,-10.553834,-128.457076,-184.891205,-250.291498,-261.38892,-241.801538,-119.431097,-44.373428,-7.261256,-53.041148,-133.201803,-138.556021,-131.492317,-80.248646,-32.203808,7.933378,-29.318551,-168.343677,-219.227901,-185.93328,-131.117876,-96.671605,-112.580524,-82.484322,48.655122,112.839221,182.314372,176.75905,58.395316,-52.634724,-1.109217,233.356828,282.089778,192.470935,164.610714,170.612539,121.498065,-18.576402,12.771565,84.496279,201.383867,186.898255,33.002907,-40.272497,-97.474433,-58.95676,-27.657765,52.760084,102.072463,106.068639,40.981276,-81.969612,-124.420175,-254.475733,-318.138586,-253.930071,29.930633,155.294751,175.823119,101.767199,28.2499,143.880437,198.381838,245.083224,254.231401,214.953165,175.72688,132.601737,106.849438,-8.144406,-63.261467,-38.444904,23.687815,45.35947,112.557618,129.155885,56.781705,35.223946,80.911039,134.039363,111.097279,40.927566,25.452692,28.068442,19.664816,-25.798678,23.196281,101.900151,231.191575,225.063404,88.295155,10.767586,-76.342468,-31.282674,48.201989,245.773186,314.512823,320.843027,254.294236,63.623036,-0.468914:25.985477,119.201042,172.487355,284.579406,314.324817,255.229636,139.223335,-155.345693,-184.502056,-87.631331,109.081203,132.854991,10.775723,-75.914743,-176.29876,-176.06881,-97.252964,57.797414,151.315304,241.50171,204.914703,52.00671,-20.865734,-96.051342,-19.331021,36.844344,65.427248,35.934852,-107.645046,-205.860896,-361.743778,-389.138617,-269.744342,-56.739943,4.227658,51.135764,44.914459,-27.066244,-59.005993,-48.078429,58.504592,109.473664,196.732261,239.686026,222.953591,153.051655,34.931948,34.500669,124.732807,224.365105,273.394563,328.558532,288.93649,46.067469,-126.107246,-339.776341,-188.919481,-68.294231,15.73131,-21.126909,-130.224376,-178.829445,-265.635956,-280.031574,-164.486361,20.676845,72.467209,119.255879,122.787509,28.702688,-57.241866,-174.702045,-156.009251,-104.260367,37.562914,78.325444,12.686769,-66.319107,-203.504926,-235.530762,-210.425942,-111.614578,-46.571414,49.079086,26.613201,-150.445801,-268.402619,-453.587003,-341.39851,-201.20323,-15.710534,-11.557885,-85.264858,-101.164944,-120.807153,-192.002311,-328.276154,-134.458601,31.345646,181.566747,115.337895,-168.08586,-302.439226,-395.961464,-171.316057,-12.89391,179.74722,214.643748,228.457183,192.226817,10.147052,-99.624541,-195.769419,-56.971289,47.393731,177.638649,161.013943,10.489137,-58.806739,-62.227996,99.106412,188.336686,298.257768,299.11771,191.415094,98.824123,-99.720904,-152.836628,-51.132779,185.715664,247.112224,208.14474,153.968051,12.761445,-84.502208,-224.896679,-145.814042,-58.390766,76.608805,99.795441,39.032476,-27.452875,-126.851795,-117.253723,11.192408,106.02839,117.1853,100.047344,71.701942,-44.464864,-119.932544,-168.699468,25.685871,171.806313,421.688029,488.746685,473.867998,408.220359,234.630985,166.001575,186.32135,357.504528,412.495114,378.076371,300.865068,109.534965,21.3057,-134.968234,-193.417238,-135.556962,108.108842,200.953508,161.45924,64.662415,-102.834967,-149.706641,-142.868091,73.315085,223.781632,390.401329,368.837877,175.182048,41.171447,-168.315981,-138.406129,-13.863636,276.185775,323.918038,186.375147,90.239631,11.346829,24.901427,68.815981,93.734448,114.030657,143.665556,123.236712,-7.35818,-108.052797,-246.641305,-124.902527,-18.838684,122.495773,146.30246,87.671671,23.108043,-97.440943,-141.056018,-141.290152,-20.862695,36.259145,40.650805,-16.985871,-169.784811,-250.361236,-400.235656,-397.499254,-318.126011,-87.621782,10.917037,58.733806,4.511198,-151.360418,-193.220094,-123.680539,39.173813,105.896264,155.151258,128.495269,19.888961,-37.897288,-100.513204,16.321803,128.744044,208.061254,132.482208,-41.899525,-83.012329,-152.42189,-184.964481,-122.404956,31.493739,66.527252,35.236082,-24.096348,-174.268111,-223.860612,-230.095007,-85.703171,23.915444,178.04995,179.527067,54.373724,-17.70604,-123.905163,-165.528192,-146.972523,-29.711579,4.143232,2.864541,-21.832424,-118.798745,-189.25275,-285.616692,-217.773131,-140.164681,-30.226389,-28.880851,-67.519419,-81.498474,-156.23013,-207.037444,-165.869218,40.137248,112.3609,84.864943,-0.728367,-183.922239,-236.45565,-245.549877,-139.861572,-62.366817,52.305544,54.656796,-77.248165,-170.543189,-287.366764,-299.293988,-255.024179,-118.461666,-22.522779,88.06207,51.145612,-158.057392,-249.243602,-257.743154,-126.602176,-71.817139,-14.655321,-14.015787,-110.415003,-192.77757,-307.703504,-322.008103,-242.208695,-24.621513,61.976227,25.381622,-76.694469,-263.337609,-306.074985,-295.736947,-213.770112,-150.765068,-18.88983,-5.367131,-143.085939,-239.85021,-320.213306,-294.722827,-166.704232,-6.936293,67.377528,175.277601,172.09101,39.543348,-46.245253,-96.098446,78.973562,171.393097,281.476665,315.050641,307.6497,256.990539,102.837859,27.334324,19.627857,227.761937,322.494419,336.275204,242.801972,-12.688783,-95.373961,-117.940337,-48.779481,-7.035688,110.118434,167.348936,150.769635,68.698508,-125.934466,-191.767522,-190.004328,-25.080979,69.565228,213.543574,239.332786,149.695368,56.481022,-65.38296,45.157382,146.553395,286.893029,302.734077,214.662904,134.905376,13.288704,-17.453973,-41.682159,3.48741,65.349334,185.445771,177.696289,17.341261,-68.546568,-151.355678,-102.242037,-20.185357,169.303569,205.912419,94.312964,-17.884798,-243.119301,-304.925562,-221.054848,51.660732,178.564659,260.240542,223.098667,114.358435,49.021172,-71.7845,-18.894519,72.130159,291.569302,386.411744,418.855992,331.491291,66.031283,-23.229034:13.061495,74.883198,143.533162,191.391139,131.908153,-8.691092,-52.868237,-172.669454,-302.045072,-317.47184,-225.33907,-162.245411,-144.402267,-180.148365,-204.188477,-185.932716,-136.057537,-54.977129,10.862727,140.415614,142.173201,6.556712,-54.680963,-49.247168,-17.739549,-35.113648,-55.618031,-46.121117,-82.459657,-143.783251,-292.606625,-345.429051,-285.078313,-60.21093,10.318627,16.033441,24.58441,171.785426,244.068091,188.946622,35.109548,39.961473,192.54139,253.71371,260.00876,239.818206,214.853893,210.799233,236.901709,255.810847,235.352347,231.905092,267.060763,282.109902,232.643096,101.253859,20.880419,-8.11212,-44.611324,-39.329054,-50.152788,-79.701452,-96.132982,-66.041083,24.519837,85.940341,111.084893,170.062048,179.279919,133.701715,104.042916,59.561167,45.727826,55.833004,75.534275,93.963815,175.362938,201.972921,135.090908,39.809863,-177.877237,-244.418809,-203.2999,-78.555731,-54.289736,-153.529688,-241.772514,-341.177441,-241.96001,-144.626695,10.449618,45.872926,61.069835,53.207722,31.592312,18.150686,-5.541744,63.912868,139.905125,233.875801,217.3877,146.196714,125.768088,100.399249,147.847593,207.593168,269.625507,253.026301,210.245143,205.785542,164.780279,92.557661,-84.601909,-90.86543,-18.09502,102.789958,82.37898,-77.025574,-143.901017,-174.014785,-100.700561,-37.887815,109.961057,149.398051,102.367741,67.580585,35.082322,6.990715,-27.367862,54.97181,113.593422,180.520229,161.907298,64.258245,34.220746,32.306725,1.022931,-31.494708,-17.893779,38.106382,147.419514,165.228292,91.652072,12.171551,-126.763386,-196.028068,-223.183526,-271.119133,-285.823052,-280.234895,-276.644944,-297.006505,-252.181931,-180.746327,3.346502,81.832939,149.19205,153.052497,154.576408,141.399231,96.341842,114.045771,148.163881,168.48883,115.615945,-43.299565,-99.52605,-221.948684,-366.884548,-376.402903,-209.569749,-74.715644,121.063231,136.282177,24.319661,-60.104163,-168.994107,-114.997256,-32.277463,103.287635,95.912187,-62.636102,-188.414116,-449.658731,-484.223563,-373.407639,-100.064307,-33.65234,-65.934071,-102.057528,-99.012199,-74.204821,-44.807606,-10.509423,29.10637,87.357697,68.006789,-21.852285,-59.333161,-111.470252,-48.203582,10.805902,57.391752,73.556779,128.874282,101.631367,-57.035427,-94.190084,-45.666002,-40.014471,-77.090233,-150.965161,-177.244447,-269.130912,-343.367711,-478.59381,-500.404321,-457.287072,-293.472108,-220.442803,-190.025057,-228.204665,-331.853651,-353.042349,-276.934818,-118.414509,-71.918456,-124.49439,-185.233168,-215.254666,-185.988976,-116.466637,-20.719964,23.490638,67.830075,67.838831,47.93089,30.858731,-32.953725,-52.794532,8.917315,101.642551,112.092041,77.917649,47.426279,19.017677,27.631074,-3.779181,-47.002405,-13.090033,123.556524,167.635282,164.072062,146.578084,117.363795,95.936698,49.937972,44.294237,40.429574,34.249249,49.024506,35.683618,-41.266311,-231.499609,-234.515908,-199.796949,-181.15779,-179.342074,-129.686713,-95.25559,-62.114278,-66.171083,-71.400639,-6.583747,40.900605,92.897669,75.13558,-18.579087,-72.933122,-148.035174,-46.137149,37.718423,95.501016,73.185835,16.857435,-11.343172,-82.956118,-129.399223,-233.634289,-269.98725,-241.186901,-149.2912,-116.580925,-106.204288,-136.129153,-223.723169,-140.868217,-35.338107,133.591421,160.385907,72.204533,-9.446914,-102.292103,-98.953598,-34.193056,100.598787,166.422128,179.444248,124.126914,28.80589,26.366429,64.090173,108.935031,133.949783,162.889084,143.473415,44.803205,13.463527,29.297634,38.224368,19.590724,6.862842,34.091789,165.818,211.038195,153.863849,99.75889,63.606802,100.457786,125.500199,170.910549,191.829396,201.139876,189.99124,154.858538,117.843706,59.14721,124.881193,174.793585,209.839671,188.984484,111.701825,51.87649,-63.32277,10.910797,85.614742,139.605774,126.353579,71.882376,41.215994,6.727709,-8.803819,-69.421152,-89.607617,-59.618307,72.211519,144.644321,165.611321,108.908921,33.854449,166.631888,254.819878,341.056334,358.488371,371.956184,350.898213,228.673651,140.323657,1.455983,-26.430485,-23.33736,-31.247406,-21.044228,80.371937,128.65062,122.917456,85.021711,82.39586,93.490236,120.378956,196.754516,194.610485,75.432958,-11.084241,-134.710037,-93.397402,-29.865937,68.447866,61.594046,-54.712719,-119.749048,-221.742175,-255.064178,-221.142741,-95.148108,-30.454522,9.980726,-50.646035,-259.637748,-331.173704:-0.818715,127.108922,213.579683,265.397006,210.46374,67.337062,22.221928,-65.203761,-193.514164,-236.524437,-159.599817,-65.71862,25.191597,10.782425,-46.178659,-82.328523,-132.57179,-108.970864,-75.502071,23.615216,59.383332,35.402998,-9.494079,-56.447982,11.567524,36.415322,64.305364,102.005597,134.170888,78.908395,-131.712268,-210.886314,-179.231021,-49.068376,-43.157405,-147.349175,-173.520992,-70.992802,-28.796089,-102.989139,-134.620554,-95.360492,1.229067,48.742012,98.976097,103.37342,140.197419,159.1072,138.392423,89.243906,82.921862,138.249102,177.289205,200.063293,171.655712,55.015573,-26.683173,-24.663541,42.296386,77.993773,92.621553,69.825434,-2.597878,-36.516063,-59.494241,-42.769329,-8.773504,131.201683,166.409177,36.474914,-71.630544,-203.040738,-193.601438,-145.09874,5.866036,97.031218,261.310166,286.679161,138.254819,-3.827462,-206.647031,-151.099811,-57.70515,83.065251,73.246933,-62.014398,-143.42335,-278.842607,-296.27738,-249.494919,-95.987106,-25.235234,17.109292,-15.394959,-132.546107,-174.817732,-118.408957,34.862141,83.054968,144.161143,168.938983,148.062658,98.512906,12.969956,52.104813,99.766467,169.258399,173.045933,122.983325,106.644528,116.600833,92.280586,-26.131833,-37.369746,32.546829,155.098525,114.510803,-110.858566,-179.537706,-105.883328,68.893372,117.27084,105.926385,77.813546,40.541098,31.927159,-28.653621,-89.637188,-115.572684,47.827358,127.838735,228.182247,247.652237,211.181921,170.565891,86.232528,22.508545,16.291171,70.185001,118.044491,183.536838,174.836756,87.810195,38.789014,-9.085997,-82.29163,-147.21674,-196.027807,-144.338018,10.118279,15.091601,-163.139435,-208.089419,-143.749467,-28.897605,21.946668,131.26846,147.522407,67.600716,20.090108,51.894874,122.705271,103.850884,40.576351,38.793057,36.500389,-26.046059,-225.167062,-213.589004,-140.277523,-58.967778,-41.253404,45.225859,102.828358,133.663128,82.429622,-31.349438,-8.297501,42.278895,152.942836,174.914351,106.591303,20.788868,-213.766684,-303.851956,-232.386489,2.523561,66.998957,57.973236,74.779267,195.41703,216.466348,131.934082,83.53956,111.405997,168.84858,157.329067,87.928254,51.639508,-11.943724,-3.812174,38.406217,127.047294,139.547646,120.660808,129.48345,128.138869,72.437385,-57.416651,-126.435705,-163.22899,-167.50694,-127.098214,-115.683167,-189.88801,-379.596167,-349.816742,-272.331484,-133.598199,-78.080149,-47.138174,-86.512037,-192.776632,-243.050069,-335.339253,-274.080161,-205.8587,-201.541745,-239.834967,-208.496155,-165.30874,-135.054927,-62.457529,-1.126112,125.629251,166.399911,72.56424,-39.140558,-163.1183,-145.440278,-37.620002,81.799777,131.275612,149.928024,118.856464,91.249374,113.148147,149.285348,138.6285,145.761965,230.237395,282.034861,300.082926,265.971736,188.095429,156.482788,118.035127,126.933331,144.155261,186.651468,183.194806,103.993085,47.319921,-103.861717,-226.010804,-203.933187,-17.831306,75.525577,177.684396,192.139874,121.988913,51.229924,-4.73017,83.299109,125.882965,147.585234,127.777538,24.2454,-76.191988,-278.66893,-146.4188,11.815857,160.11848,117.250133,-69.609095,-163.701838,-273.329898,-282.831028,-291.682674,-378.354527,-405.830967,-320.055085,-248.892431,-197.006054,-228.815445,-338.602201,-269.52324,-144.019471,98.854582,149.686022,51.263737,-71.366949,-270.41515,-296.484186,-264.072368,-213.072124,-164.663584,-57.156661,-57.71261,-169.11311,-230.971664,-290.733288,-204.620004,-130.026167,-53.194246,-72.596953,-153.769988,-180.890564,-198.257833,-189.978838,-147.715876,-138.171367,-129.993836,-43.297656,0.306799,40.031584,32.117236,-86.549329,-153.97566,-103.300785,42.491114,81.400043,82.269749,72.578307,69.701269,58.536566,1.679363,0.660858,44.383626,145.237646,136.715423,-5.126197,-60.78733,-64.959581,-0.986918,40.278045,74.090072,34.422929,-90.395227,-121.123801,-161.409009,-213.138716,-315.681125,-359.427484,-357.151823,-208.550365,-90.156288,13.996847,-28.270595,-130.887344,-108.664974,-83.67859,2.971225,69.140875,178.023022,201.711587,147.520737,83.197376,20.015342,37.587162,35.494415,47.303467,73.920506,145.47176,172.658815,212.381949,243.802621,237.61898,200.196684,182.652477,144.920499,127.65342,101.453767,74.786869,4.358984,-6.634718,16.61402,95.503243,124.36659,93.990297,46.645531,-14.02989,-13.008175,12.124491,152.651523,253.475931,358.58591,305.398656,70.494684,-13.283958:36.478694,184.226439,260.941619,352.531223,346.77838,234.333312,146.67155,-54.085494,-158.562545,-136.693938,-23.639353,-3.716882,-81.71165,-130.122014,-125.334504,-81.769949,-57.600599,-121.029179,-107.739577,23.161288,66.382158,26.853235,-4.652936,-25.817505,-83.620817,-106.598871,-67.364535,-51.102378,-162.933715,-261.450117,-373.972636,-362.632695,-264.677039,-151.858665,-94.68004,-3.540217,26.76953,86.40471,108.132041,114.909034,152.164198,184.739626,230.704538,235.303951,160.178084,97.620906,36.561959,40.680373,100.929475,206.929548,235.611504,261.550973,261.529128,136.384462,21.58682,-124.535543,-77.427353,-48.483326,-71.679206,-110.08454,-200.982714,-231.544874,-192.191789,-133.904726,-19.337572,43.160434,66.299245,172.224428,228.492763,214.112775,155.879077,38.198829,-20.005094,-4.364893,81.413597,106.00511,67.393081,17.916558,-87.532409,-125.770873,-139.486266,-109.321588,-90.257537,-24.746304,-21.137112,-146.527955,-245.681408,-359.591494,-187.541283,-52.88978,77.067979,70.722208,35.61948,16.714052,-41.961643,-63.270796,-10.453254,107.994003,139.88704,152.921425,135.255125,49.212427,2.551909,-55.531456,-28.735341,19.159889,162.94713,221.959944,210.495322,160.756924,58.890498,5.558205,-87.226794,-105.240463,-67.811171,32.298924,35.28656,-76.409218,-133.47308,-154.768849,-96.747525,-33.970441,179.246419,260.30109,193.844227,98.503647,-25.468946,-48.261673,17.059101,173.753937,219.321693,237.307708,197.307239,0.918552,-82.641701,-69.175063,29.297201,47.260774,65.344249,84.273444,72.266182,29.29119,-63.352786,-95.414167,-99.519809,-62.057595,-65.319266,-103.180464,-123.582151,-198.21332,-250.26957,-259.929649,-48.191787,55.702039,131.504209,159.059697,257.57464,281.478122,179.667799,83.801565,15.343114,88.187171,112.075659,169.558451,196.257524,131.993508,15.740628,-251.775014,-267.327014,-189.648465,-49.659916,-1.922284,42.187368,3.845336,-154.811958,-189.007492,-51.851567,127.819072,168.031826,174.785816,136.219083,11.992817,-54.079994,-235.770996,-337.439926,-277.292437,-92.566167,-66.724149,-107.466379,-107.331587,-87.584428,-98.149506,-88.4646,34.35421,99.066273,121.008683,75.894955,-43.461887,-101.048252,-165.327326,-49.59536,43.672687,144.726615,150.590552,86.165075,17.202553,-85.460416,-74.258796,4.551968,-21.568038,-42.147437,-12.761067,-27.091199,-197.859748,-287.333918,-337.280473,-273.213866,-248.184743,-221.190158,-198.158489,-152.702951,-157.131966,-222.699866,-232.96593,-89.029417,71.454558,81.191888,27.53598,-2.823836,-5.714426,37.192269,121.846718,141.098722,162.227662,243.442641,253.408207,151.566743,93.478741,26.852945,4.91787,37.363621,127.161282,155.206773,175.481065,144.337938,18.113342,-19.211488,1.471171,45.178664,33.121485,-3.3241,31.97999,157.813364,160.177557,13.253029,-59.036706,-60.324312,4.945219,3.192457,-11.363809,-4.170504,-24.896861,-75.091571,-188.47217,-203.763093,-181.423747,-134.988109,-102.636583,-29.934274,-9.712271,-28.731563,-61.932042,-60.071913,71.262496,128.291319,117.459268,23.067289,-218.0043,-267.985418,-180.462184,28.052056,122.802822,172.73884,124.597887,-24.928868,-87.647267,-160.413369,-179.171245,-181.695332,-154.849461,-119.67739,5.277114,30.887196,-83.615714,-178.439716,-286.983691,-138.526306,-23.841164,53.402699,27.066195,-59.950982,-118.485585,-214.244014,-218.643182,-143.382754,-16.167602,53.571368,102.164045,53.214394,-105.01018,-154.715146,-131.341416,12.768774,71.842584,42.156452,-22.192715,-129.681422,-156.691197,-174.442185,-174.155401,-107.54358,23.523149,70.333666,129.349215,133.91118,31.170911,-43.893865,-75.985042,57.042023,119.645924,184.340859,186.140429,140.217862,119.084299,76.362912,46.189015,14.962701,68.79743,137.946184,278.556624,285.753794,161.271308,66.091542,-122.475323,-162.482305,-101.671327,61.465953,113.27631,128.691311,102.885765,-12.73532,-95.515247,-167.996092,-45.55021,19.033477,126.240636,184.138935,235.818411,200.419571,80.285032,122.179272,196.864233,289.153441,299.627419,280.171503,245.847159,139.092718,76.126241,-7.901872,-11.45418,-17.626992,-69.904999,-96.85691,-69.695438,-20.249692,6.994485,-26.232061,-0.785552,87.33262,112.901826,86.358065,39.162178,-50.657126,-70.768623,-45.826075,-3.75728,2.179113,32.413804,54.080191,28.241839,-34.070486,-173.204998,-167.386194,-108.727846,74.037441,174.516276,261.163021,207.755828,-38.95901,-143.609211:left
136.390678,125.763513,158.683645,234.353605,253.691195,300.683627,349.875966,500.917904,556.335823,464.678555,160.769966,52.225617,-46.309757,-83.515896,-177.791515,-208.540466,-209.493325,-256.3358,-297.149587,-346.469109,-354.134045,-322.846273,-286.75231,-231.415778,-174.930714,-136.601823,-126.483288,-178.027828,-285.312153,-298.288227,-314.741933,-328.195902,-268.952654,-181.940723,-181.778541,-210.986889,-203.182484,-164.058189,-151.361959,-102.723645,-33.716571,-21.934442,-45.903675,-72.447499,-105.288298,-87.299971,-28.468065,-12.056028,57.659136,152.945823,169.998392,177.148744,180.412801,176.973592,181.274667,221.94567,203.845786,142.838064,12.661825,-6.603555,47.829809,80.397949,95.649638,96.951196,136.515311,182.809075,201.145661,228.900643,224.578621,188.139374,177.039349,217.086166,295.623679,305.339553,283.885855,271.432642,264.237617,281.009919,329.744046,356.016189,415.305263,411.458648,395.615036,370.169591,347.465045,311.335362,306.746618,294.283057,327.975703,362.274702,325.404882,236.464957,104.324463,114.911308,213.009086,276.05669,367.512378,208.889347,56.719806,-137.590383,-137.906089,0.802905,87.155544,198.545037,268.459914,280.044107,276.065662,288.015582,262.766303,190.08801,38.02828,29.321843,119.375047,106.611072,42.521271,-43.235424,-44.159449,-84.10975,-119.675148,-42.653058,161.224908,210.417184,193.806036,155.245187,16.213991,-59.947674,-103.012447,-52.049836,119.876775,182.294736,140.012095,43.897501,49.629479,158.438891,211.250807,265.026345,356.915415,427.812791,486.433007,432.601248,219.16223,136.231712,138.678935,210.923543,366.583508,385.706583,345.921844,228.289115,179.699743,168.72486,195.431497,270.994302,375.25665,400.273132,314.386221,238.637237,121.558928,81.25085,43.790931,67.220904,223.402891,326.258385,266.038231,2.329037,-94.464136,-110.449678,-78.225436,-28.295804,-11.854097,-49.487032,-202.008502,-259.521905,-261.170014,-231.072937,-187.536797,-156.177429,-39.558142,2.119882,-33.680029,-134.954793,-186.705768,-294.017796,-333.375,-311.155411,-209.479794,-192.045163,-223.060383,-265.965489,-409.698938,-466.130374,-499.343083,-505.24878,-496.449114,-420.804251,-385.835217,-412.639312,-453.000551,-409.776846,-321.742607,-184.976481,-145.915972,-139.996549,-143.68372,-155.048576,-203.268141,-215.950003,-173.626348,-136.832628,-59.724258,26.345763,66.265855,74.367308,3.52253,-175.299013,-189.812148,-79.032581,-2.093274,6.116805,-8.779832,-35.210145,-108.54609,-138.094982,-147.654346,-129.16754,-108.834256,-164.779248,-187.783726,-170.508164,-159.395647,-223.432998,-282.894111,-294.397591,-103.624068,-25.574498,-36.525771,-98.771217,-243.908495,-292.691624,-315.783974,-297.225346,-220.586343,-216.644917,-243.909386,-208.81471,-147.11606,-54.70207,-43.350733,-75.734321,-112.775293,-119.842212,-139.783168,-183.43212,-339.742776,-385.161047,-341.670079,-297.186988,-214.134389,-197.39121,-235.734687,-328.237278,-357.67241,-367.568697,-336.257629,-191.730827,-129.844772,-202.975056,-365.611052,-378.648584,-343.868559,-332.214512,-343.299873,-355.350865,-355.180957,-396.328938,-432.275164,-419.604459,-371.625875,-294.733127,-276.255094,-215.805365,-132.355429,-121.043431,-126.55936,-116.973914,-125.226213,-144.633803,-145.074415,-128.639836,-85.742192,-37.369101,-20.19246,-25.873405,-31.883079,29.599674,85.5298,208.936093,322.601516,328.910308,282.783617,272.859314,241.688559,219.38212,214.435528,214.751879,164.437844,78.737989,62.970841,71.013205,50.098435,-40.237611,-71.097883,-29.105632,61.864611,58.033278,-19.247265,-64.494197,-129.74408,-119.883763,-59.413207,-51.958647,-65.753941,-67.684356,-61.79629,-42.552827,-53.620657,-141.589639,-191.602212,-166.035457,12.781862,69.996279,115.407372,134.398752,123.61243,105.592014,127.693071,143.305518,114.488158,72.568668,55.150988,-35.938602,-107.094102,-190.171932,-173.8509,-57.754708,41.472061,62.562837,43.9687,-17.474757,-165.174921,-167.693547,-34.296954,13.134803,-24.552046,-73.618232,-59.419391,-35.611625,-47.55762,-77.39964,-85.262132,-100.958778,-119.624398,-122.420155,-75.158151,-39.374782,-25.957905,-30.633063,30.245584,96.538657,227.169831,267.319608,247.608454,118.226603,45.009756,7.83667,14.269221,0.261526,70.265484,159.915585,338.145748,354.279037,220.389563,146.418313,107.982348,130.932264,183.018222,204.082432,215.732438,190.637355,147.048368,123.445759,170.918054,284.467334,274.905414,231.000818,165.214846,139.228013,62.342579,52.145664,144.45129,221.593033:124.958473,124.838284,166.827849,210.015795,184.417917,164.013671,202.753468,300.509107,305.06105,259.502463,112.676003,41.949972,-46.556949,-61.736231,-84.410022,-113.94645,-162.213096,-189.009445,-220.36342,-267.42978,-260.451321,-225.368108,-206.467639,-113.623764,-51.550281,-75.044471,-162.8195,-201.965923,-224.990668,-213.582032,-192.375547,-168.590232,-96.914809,-112.852465,-136.537967,-134.251204,-121.630608,-103.669639,-85.843365,-18.990742,42.658308,51.356897,-8.055195,-56.217706,-51.908785,3.334523,75.607479,70.90819,58.106424,71.034419,69.950037,104.349196,161.634377,260.78068,261.270877,208.264646,162.659066,147.11372,130.978246,112.517311,54.246633,39.609901,49.631877,72.801098,157.871766,194.12933,175.232433,160.074098,172.404332,175.291764,183.517528,298.284447,417.723726,417.597442,287.20668,190.858873,124.004459,179.525118,325.845069,379.00176,427.251762,352.004159,300.295226,278.778458,309.965733,380.929428,375.63774,298.175986,280.427216,302.198744,305.549463,250.436591,126.352982,110.865874,179.716066,251.178641,336.537838,169.530809,45.412416,-77.14377,-75.075688,-13.486089,48.525871,213.116918,272.301656,231.952509,165.762123,178.449002,185.237931,136.055925,29.92078,39.886813,160.435091,153.639578,68.214522,-62.505304,-37.301874,62.066474,58.53828,22.001815,106.004443,152.506763,117.005926,32.288234,-114.998579,-120.187897,-26.103376,46.18384,190.12858,215.614679,175.577329,67.346548,53.99125,197.876898,310.261843,425.69771,444.009866,490.938117,555.739044,471.898821,182.247513,127.14261,233.222769,311.84545,415.088269,374.432624,299.981822,153.744465,131.692567,184.829471,205.291337,211.272828,298.882003,337.249974,276.197897,204.140166,123.823005,118.005678,106.072013,114.651693,187.006622,207.307531,164.335349,4.103728,-63.880305,-97.86831,-68.973884,53.345487,83.897358,5.233742,-176.283061,-218.891291,-288.599706,-318.193835,-218.003682,-102.071724,12.245388,-49.659585,-67.89431,-111.228983,-152.878923,-186.285281,-159.415117,-48.803657,-1.749497,-43.429496,-144.875113,-168.789614,-196.911103,-220.997798,-315.626294,-362.594252,-357.835207,-250.59312,-205.195309,-196.604378,-215.727297,-187.312281,-137.704123,-40.91659,5.557864,-10.071015,-82.995638,-108.344399,-156.465142,-178.258707,-166.367263,-136.984604,-97.687243,-94.814643,-98.695776,-180.601284,-243.911193,-276.600937,-240.101987,-146.672056,-110.280593,-123.84651,-194.437325,-227.017718,-171.396793,-80.726761,68.23332,81.654342,-5.937688,-147.12454,-202.207527,-278.229197,-296.26972,-300.41617,-295.735919,-242.831225,-154.302154,-137.8218,-168.967396,-183.398819,-166.155125,-158.44307,-164.851001,-151.024989,-102.128475,-88.904495,-86.144881,-138.210583,-207.864368,-235.741173,-153.310775,-20.456352,-82.813111,-135.329431,-180.84896,-196.530139,-259.213587,-261.987972,-183.587302,-141.837598,-102.326722,-130.333937,-153.083134,-194.797291,-212.436987,-222.131574,-204.206621,-93.281337,-15.503464,-63.923359,-201.070547,-208.583284,-163.693223,-158.07838,-153.08057,-132.520187,-134.633475,-299.349129,-374.145891,-320.494041,-237.795421,-186.362358,-213.302461,-200.361243,-133.197253,-143.672837,-219.128655,-232.145543,-152.606873,-81.312406,1.415,-25.938046,-104.030185,-60.540599,-59.612672,-176.179593,-219.523395,-118.802525,-8.197635,167.51846,209.329486,186.407704,100.09525,57.387292,22.660333,50.453259,179.716013,239.379908,223.514051,83.742536,38.50054,-18.491573,-38.673046,-4.484237,31.709171,61.311932,96.837969,139.825547,168.906198,99.765632,-75.895024,-74.561306,56.324152,86.53517,22.652309,-73.826233,-66.457852,47.506625,62.127411,-68.54826,-129.741351,-57.422474,118.716921,160.858347,166.700731,149.978216,141.200932,173.260301,267.037676,291.400595,279.638696,234.249263,196.304156,62.271083,-14.174268,-82.384654,-57.104652,57.906188,127.613945,122.034647,62.869327,12.218013,-101.752299,-126.342693,-77.164758,-26.298455,53.775071,41.907869,13.670954,-22.263747,-26.473831,-75.867478,-126.53475,-150.986695,-43.893666,-21.282341,-75.102108,-114.257073,-140.948649,-121.780581,-66.862786,-9.911131,178.241217,202.065421,120.568859,-52.675694,-75.33731,-24.808573,-4.393326,50.516914,189.496946,241.091326,237.488257,211.368247,209.261668,239.112892,300.253737,308.952033,264.929004,210.305578,215.933816,229.696585,209.518807,191.38421,213.587364,275.113629,287.703309,252.214163,138.130279,80.978164,-27.971437,-44.511351,65.895379,160.083432:-55.049506,14.334729,65.925914,54.616839,-5.188421,-20.325903,66.458119,275.738958,268.826577,175.905273,-11.352775,-39.317565,-9.00221,-21.563087,-152.103195,-206.299689,-165.845775,-144.452182,-198.844978,-313.061225,-337.636255,-330.523044,-290.832484,-142.496689,-98.12824,-138.656668,-226.402481,-250.927823,-211.567298,-168.563819,-165.586148,-175.345336,-124.842343,-54.875653,-37.259647,-58.219697,-75.870928,-77.660001,-65.649121,-33.691005,-1.084969,-6.708831,-109.795901,-179.214896,-184.453179,-107.500843,28.808468,40.284617,-28.117721,-138.647596,-162.679186,-129.295561,-96.415646,-22.196223,-0.061506,-27.371247,-63.577303,-45.838312,15.735042,17.195698,-37.696594,-53.390368,-45.24483,-46.398375,-39.726236,-20.508639,-25.831141,-12.084988,33.689744,166.806118,233.961971,397.86877,541.95965,536.913337,351.102736,224.568739,92.237933,124.460213,324.967628,430.721944,471.57546,261.263789,158.515477,132.598632,210.894922,371.068222,385.181977,337.020114,246.963176,203.929669,199.623893,210.761419,228.072484,256.8921,323.335904,344.753286,333.078402,159.774043,59.941374,3.656701,22.232067,61.943717,101.166894,231.201038,283.027835,252.132494,150.105232,110.634817,100.762978,111.214539,87.135378,67.188076,82.984218,106.048164,73.324912,-60.064331,-90.852914,9.054022,99.339388,249.486648,305.780703,286.03169,169.156841,108.674659,55.647063,64.420564,108.193555,134.067,213.792837,280.411097,278.810421,194.873496,157.144893,251.838315,363.99602,523.219229,608.743183,645.240338,575.410707,448.330504,203.960379,168.179106,238.56463,309.481415,414.409645,317.143365,232.483542,102.753221,88.183649,168.75865,197.913388,165.641889,174.398282,210.386766,228.519286,191.722779,108.592083,81.965047,55.977922,60.244854,52.933033,-31.902418,-69.803755,-109.070087,-111.939178,-53.751937,-4.726198,31.122232,-57.899149,-105.716865,-119.744277,-110.437637,-112.416035,-102.257544,-26.663607,40.068327,144.365416,45.781582,-34.955674,-114.86415,-117.866014,-90.939237,-76.083192,-53.122185,-6.266149,14.975302,3.900302,-33.610028,-127.563481,-176.876196,-270.275022,-286.500623,-239.204317,-197.589466,-183.488064,-151.522029,-143.068787,-72.93255,-3.617011,86.836179,82.226103,74.666346,45.254815,6.05715,-72.666291,-70.911726,-14.998948,-5.419452,-18.510301,-14.374071,-36.706635,-163.209232,-204.582841,-154.051412,-114.88235,-102.816528,-117.583827,-112.696437,-119.15697,-146.207152,-183.784733,-157.511864,-18.652163,51.480161,52.216123,-57.257605,-80.396393,-110.690612,-139.467224,-207.206789,-218.944097,-137.551867,-66.196402,-76.460795,-112.486771,-133.211038,-188.5432,-203.779859,-159.676732,-97.532563,8.828356,-13.660412,-63.658236,-177.792397,-211.500778,-215.127996,-200.095926,-130.033329,-39.763963,-19.520652,-29.588394,-66.075355,-151.410563,-140.680561,-46.46677,-27.808796,-74.127407,-147.425585,-159.589844,-132.034002,-110.934754,-86.803432,-73.276938,45.039463,195.590465,173.698849,13.614168,-13.07323,76.043783,118.2062,83.764494,46.510751,10.263851,-63.729607,-114.440691,-180.358195,-182.134304,-157.546522,-153.484793,-124.277738,-100.023547,-112.544319,-153.438765,-187.628846,-190.626624,-110.402067,34.876547,19.434572,-55.571987,-89.7043,-149.049403,-249.981887,-211.779558,-59.749667,-17.451518,37.391579,110.48189,116.496826,64.848183,57.817146,134.655836,176.326496,201.8119,200.060828,167.274736,129.31067,111.894507,14.109221,-38.440191,3.121319,91.970196,222.343627,187.986006,155.055209,118.412438,93.052715,1.26619,-40.913965,-28.614766,31.91268,107.868588,-52.469496,-133.487514,-73.619546,5.594114,38.854951,9.154343,4.290303,119.728232,194.202,253.721468,208.155096,120.826821,143.496832,226.36028,241.320208,236.458221,227.97966,217.189024,147.818574,107.84114,92.653338,121.650228,179.683986,120.563088,75.389902,51.110161,43.874536,6.870076,2.917716,13.721256,29.401518,122.894789,168.963212,107.23994,-93.14902,-138.838527,-80.157656,-35.993669,5.803108,11.932432,2.607959,-36.648673,-62.584098,-129.122524,-146.467074,-71.664633,19.377033,180.921106,181.458724,128.129073,-25.237265,-65.693775,-10.710048,40.908135,139.493969,255.815258,295.366015,248.373096,183.489651,170.500626,236.056989,342.474878,340.877295,266.044329,285.851119,327.936509,271.402111,205.595192,236.925401,297.875164,319.689122,244.802891,175.756064,28.390734,-3.271679,7.223873,42.362601,157.372257,200.301057:-102.813768,-88.0699,-17.475134,103.569825,133.201859,256.766138,353.603298,502.603639,510.768546,435.613137,176.077823,53.258754,-120.054762,-179.103925,-268.758583,-284.185163,-200.588049,-131.488757,-158.04642,-312.532029,-400.664958,-449.386443,-401.282174,-248.672611,-177.888621,-205.630678,-304.344699,-341.320914,-357.435017,-353.195517,-341.818239,-300.584498,-191.732867,-204.730869,-203.232768,-97.791686,-50.765821,-18.747725,-9.024769,41.882925,98.059138,73.489771,-67.285154,-141.942122,-196.25763,-158.958918,-68.558529,-54.38604,-12.990841,84.492939,108.919251,73.573861,52.634716,35.368422,8.108959,-63.623623,-79.13865,-59.034459,-19.894151,-44.107059,-102.214955,-70.11325,46.428583,71.635327,77.022751,103.954,133.727446,172.909717,154.995455,120.506329,150.348412,290.309627,344.421591,307.627234,224.028548,188.519568,110.644225,104.890714,220.970152,300.477937,366.161705,311.986386,294.218841,314.69403,319.52102,273.059001,245.480017,268.440095,318.060132,309.67374,271.172735,260.001332,266.54172,284.933986,349.55724,407.817192,515.991813,384.745271,247.278402,54.47544,33.411271,118.432078,194.931584,316.857012,341.619934,319.781874,276.551274,268.184932,202.444501,131.962554,24.429024,35.436845,124.718443,70.801575,-6.410864,-97.502955,-96.023334,-56.194679,-27.66808,49.972276,151.91621,192.00904,211.381818,184.803598,56.538223,-16.53282,-70.014497,-26.554537,145.351966,227.603207,209.555994,152.411547,147.681496,235.859901,310.792528,412.359053,480.275159,520.976285,529.304123,466.21872,273.190324,203.243534,185.055851,224.527283,320.302693,361.840511,352.501362,249.861711,192.799375,179.808362,207.787844,248.981252,253.688788,264.753332,297.972883,268.27247,72.573226,-22.905782,-28.761498,48.058907,161.462263,79.56206,7.071139,-116.649659,-152.789298,-153.087626,-119.835758,-17.855819,-23.161374,-87.755329,-190.345451,-194.502309,-169.463642,-161.849671,-141.133817,-103.901837,17.176264,29.944492,-5.159916,-93.50474,-148.025124,-214.82787,-204.601689,-108.651227,-49.28477,-75.637781,-173.677,-234.531095,-365.410715,-393.863834,-369.926877,-357.099234,-357.495038,-314.147178,-277.307502,-286.208214,-323.60408,-280.145222,-189.691972,-43.12238,-41.520593,-72.525124,-104.197614,-89.073227,-76.344942,-103.334593,-131.715067,-100.77729,-31.784653,11.31124,47.144835,39.949378,-25.610199,-106.828786,-92.260264,-71.69995,-47.827809,-17.613529,21.85379,32.607136,70.944884,96.88156,152.667378,179.551107,183.620526,81.176471,5.38464,-132.676269,-174.341299,-207.108351,-204.174343,-123.122486,22.473959,49.181008,9.165433,-20.281002,-102.513922,-156.066558,-218.335716,-200.496595,-109.462352,-62.590745,-62.099044,-73.743591,-77.095076,-67.95488,-54.174451,-4.852627,38.271348,17.859484,-109.415718,-179.485905,-249.898949,-238.589983,-166.3444,-107.202702,28.748519,-4.52822,-83.360954,-206.227846,-228.584722,-211.090486,-158.564602,39.22188,154.795254,108.351096,-57.592351,-79.240356,25.224143,72.807861,21.565247,-31.819259,-65.984047,-159.488642,-249.383847,-334.734152,-299.464026,-216.317241,-215.301786,-178.248106,-45.428175,-30.041902,-147.464348,-200.607603,-155.138388,-78.718336,27.566477,28.191999,0.607271,-30.867941,-69.54489,-119.91662,-91.653629,31.342408,86.106181,200.889581,345.449497,372.924933,298.059892,237.845786,192.082222,218.732237,285.433788,299.486249,277.288258,157.925153,106.999417,82.56428,69.21673,41.919952,60.830858,112.773206,105.659048,96.645989,56.158339,-10.800444,-205.536509,-252.108391,-179.246264,-120.459746,-90.156369,-204.782959,-251.676213,-206.179849,-170.666792,-200.618039,-231.255902,-183.888447,-6.244702,53.854743,54.394402,27.277928,-2.881887,5.874072,61.038685,93.470878,86.269288,-11.869883,-30.21112,-34.050215,-70.426932,-143.289577,-113.174954,72.053304,193.690618,176.340332,51.738915,-11.940704,-50.861229,-13.530791,60.481214,54.66384,36.812115,60.332794,45.192679,-69.289264,-138.239527,-217.639505,-217.421486,-132.018486,5.776777,26.345247,-26.251116,-32.120457,38.403753,81.173494,129.360345,137.886745,152.921201,125.176021,73.373196,-32.089942,-42.501617,28.357298,76.042384,150.609157,256.3557,322.253727,393.166384,372.116243,275.443443,256.091759,280.023508,284.21052,284.44728,343.376618,385.747849,378.049705,319.303987,259.710644,296.572295,419.612726,430.886592,363.381485,195.773591,138.147989,68.927611,58.171852,88.741664,121.804781:-247.380886,-289.802106,-260.767536,-138.114987,-65.207299,107.596091,202.397983,351.815407,340.512088,269.106028,88.180231,15.409994,-88.209324,-140.397882,-231.039291,-216.43919,-91.637271,-144.025473,-235.941861,-390.459457,-429.332059,-405.508555,-331.747424,-114.282195,-84.031093,-173.05977,-331.155354,-366.898628,-419.965861,-416.587432,-277.30836,-171.60471,-59.06867,-89.59796,-85.415456,-35.823255,-23.73717,-29.051523,-23.604261,57.83457,90.518579,29.717541,-110.638606,-147.891391,-152.436192,-120.706697,-72.701792,-79.133943,-89.528698,-74.165977,-52.144892,5.477712,-5.915937,-96.151188,-112.631193,-83.562955,-127.624354,-163.313415,-169.023238,-155.13513,-131.446627,-98.160424,4.164153,37.316237,68.194335,117.990246,142.40324,161.528331,161.848715,184.604059,212.808875,296.316679,346.203073,331.027912,235.662732,160.40002,33.856029,34.273541,189.01446,297.690643,376.718325,236.503233,172.15275,153.372214,182.251709,202.267082,185.84354,225.884512,257.834833,212.302476,76.680517,34.143424,103.444144,203.447535,376.852328,430.524109,447.17341,234.444124,95.487193,-67.988255,-78.861189,9.615902,99.70389,332.267607,415.528272,345.457862,143.089981,75.874156,67.324198,111.792159,162.704333,155.573572,116.052563,9.816249,-46.418883,-79.578435,-45.15959,65.276835,96.58859,133.23224,250.927804,293.58786,240.025284,165.059622,6.059235,-44.746049,-2.23294,87.7149,256.913775,257.754558,210.962541,127.989259,134.443595,300.940296,425.743371,576.771462,554.183496,510.916074,372.220463,267.491677,66.746435,27.72651,90.618812,162.22673,294.566357,345.862007,344.612044,234.114513,150.326846,127.662587,194.746835,279.222711,218.338117,198.194429,160.849806,99.059693,-22.647221,-32.204616,28.276975,51.301711,3.473176,-101.993054,-140.435154,-204.847073,-227.38467,-175.33373,-100.547424,28.150556,-12.34598,-84.237182,-203.600198,-220.689385,-160.411581,-98.454542,39.033631,108.860311,187.051357,76.845198,-17.83569,-172.997564,-214.533779,-176.382317,-101.339447,46.533369,64.393377,26.309196,-31.246524,-30.954602,-83.543129,-156.950338,-266.482706,-259.809882,-163.319843,-109.724557,-151.125788,-318.514423,-359.102212,-228.501295,-110.029155,37.504058,43.500696,12.073742,-64.562696,-68.216653,-36.27748,-49.130967,-87.833708,-64.264892,31.237339,130.741573,169.628068,77.290083,-33.328007,-106.236312,-47.86543,45.253182,14.474468,-1.929011,0.310723,-2.012159,0.24769,19.965223,67.101393,95.982031,145.115583,76.100305,-5.81258,-178.958668,-225.655976,-210.476437,-170.423736,-47.374786,39.322828,21.540479,-64.692083,-99.730127,-146.38925,-147.707445,-75.626965,-15.483937,36.094476,-20.471223,-37.257598,-27.130455,-16.812938,4.995505,22.692246,70.446542,70.621234,49.101022,-17.464508,-82.594595,-190.886127,-162.722925,0.754175,63.818385,63.586324,-93.240873,-170.753261,-222.314798,-211.554423,-181.211706,-149.800802,34.956266,251.25861,254.282146,122.163659,80.803854,86.097206,95.707374,90.445371,106.030806,159.324737,36.023429,-76.301146,-211.788211,-211.014075,-140.16187,-100.065139,-0.035826,55.917025,13.573371,-141.764801,-200.093141,-210.406556,-158.328887,-45.828328,-26.690029,-35.915929,-135.009127,-219.72789,-288.481025,-227.691536,-39.397966,24.685911,134.736193,254.835897,276.64181,204.048382,129.620275,35.295974,56.951648,182.904007,238.42211,253.430375,145.80756,94.125588,37.637253,25.418176,77.429346,140.214614,209.359624,200.786827,187.367221,66.858078,-32.725363,-188.949266,-222.6545,-204.278464,-147.324025,-20.937981,-107.430204,-186.944352,-217.753279,-178.728587,-92.568817,-71.512179,-37.320706,29.444282,44.480466,20.516297,-8.744843,-42.7209,-32.759955,12.826778,41.815127,75.733115,3.257369,-46.438841,-49.39181,1.431778,107.628493,146.237312,218.703899,229.413883,208.576081,167.118874,118.563222,-1.024451,-8.842662,56.860367,103.849236,218.232816,220.575299,154.316122,-22.836369,-80.885474,-32.060845,59.479963,194.984951,163.107387,113.463362,8.812785,-27.847529,-60.670526,-42.912701,74.967486,126.949617,138.787183,89.738782,39.362636,-102.174618,-131.499309,-18.74159,83.660233,247.409654,269.090735,247.69647,240.070643,255.558996,287.150128,306.063961,328.716492,314.469309,257.547094,271.558267,306.911877,312.561381,281.36851,292.564549,341.473406,397.296997,297.665057,204.291414,76.389152,72.236702,102.130585,117.760524,178.841724,212.455212:67.00391,84.431107,142.012239,254.217878,279.209832,370.638029,469.704824,658.112385,625.477159,507.506439,215.908561,104.951613,-29.894949,-69.885782,-132.616162,-146.247301,-110.885346,-144.378718,-209.154566,-355.620875,-409.908405,-394.64856,-332.129693,-233.609506,-224.911215,-245.688833,-308.716767,-326.282656,-334.249149,-362.460936,-447.126449,-434.712886,-310.981273,-258.066586,-254.118527,-231.57239,-214.793166,-162.380056,-126.280633,-54.565873,18.577451,50.411073,54.783368,-7.513692,-221.607664,-305.455064,-330.425431,-268.617604,-32.831614,120.054856,103.112342,26.337785,20.327004,68.363728,100.791027,117.249511,37.610526,-29.982763,-152.144658,-186.751433,-168.396784,-95.245007,76.201713,105.802637,66.880959,72.573463,125.051408,227.617855,218.803371,138.996591,131.137132,203.612008,294.205489,301.275761,221.406719,178.375672,171.934719,195.294884,260.556597,304.03035,388.329689,401.822905,395.344195,367.049962,317.713007,226.165644,241.303739,356.438881,399.2963,365.30636,259.159922,210.757623,166.649065,200.601731,355.82198,431.801874,476.241488,289.868255,163.038883,18.870814,21.278394,143.912463,225.735226,338.084011,394.435588,407.733766,383.633064,357.064742,284.857837,225.417912,76.889283,31.516704,53.818459,61.906232,27.606097,-26.432488,-26.978932,-16.710976,-20.803924,12.461504,171.208556,219.369286,141.607217,73.958243,-39.684016,-91.948265,-137.836369,-112.013876,20.833215,98.828387,73.832818,-7.725386,-12.539286,80.114053,153.766325,274.736045,326.253069,339.86485,333.113651,288.828326,138.561236,85.251095,79.642362,114.887695,221.507917,252.263001,211.420464,96.159901,71.192354,129.342137,174.167656,211.665202,265.231564,278.177064,193.154219,129.706706,41.913131,28.245895,71.060779,117.527245,227.212573,215.615308,113.406245,-161.281655,-240.436438,-175.516685,-87.657854,-7.782292,-60.604576,-106.832301,-208.239291,-239.140926,-230.625908,-198.039404,-86.008326,-28.839957,-54.075861,-206.503263,-202.580798,-38.907766,-4.176092,-133.411765,-204.884435,-196.208203,-109.689906,-86.045243,-137.910167,-229.381425,-457.597156,-511.840874,-447.4093,-403.024131,-407.203946,-376.34858,-327.678404,-348.681669,-406.40854,-360.139718,-251.827971,-108.720427,-122.548238,-134.318254,-153.255058,-162.724075,-130.578288,-103.149846,-93.857032,-72.145409,72.885916,181.650056,188.792707,117.747944,50.913678,-54.634495,-53.581849,70.790979,158.03885,130.794265,66.000259,60.502783,55.912867,64.740894,116.566242,141.050216,157.109998,49.306681,-48.027755,-194.50183,-222.175279,-227.891401,-220.277758,-181.559711,-87.321864,-38.386307,-5.819017,-39.731425,-188.042858,-252.907256,-276.891601,-245.361563,-156.536635,-135.199895,-139.321193,-124.435569,-113.368659,-55.174589,-16.204026,-8.91722,-35.31191,-50.64718,-156.498732,-237.196284,-357.731583,-374.20685,-330.479269,-274.138092,-124.162271,-115.569282,-180.852152,-299.815861,-330.285525,-322.842006,-263.286571,-95.0309,-60.520032,-107.466257,-177.545208,-169.009476,-138.640625,-144.752109,-197.077611,-204.83338,-149.717715,-153.020606,-177.833845,-168.415174,-134.396261,-79.282761,-87.52075,-144.833769,-101.770295,-56.439032,-62.347909,-100.428083,-124.012777,-94.015785,-10.124331,13.276096,24.985691,36.104916,54.491967,78.266818,61.412763,47.91202,94.410743,275.816456,412.354245,411.852012,349.893922,328.333221,304.315921,301.776181,284.068246,256.490485,180.954588,51.742734,9.722081,28.407926,37.661964,32.646247,49.481265,84.326148,35.527379,-5.325777,-64.997054,-106.912971,-192.377659,-175.964642,-76.616908,-55.017659,-43.189791,-30.416492,-40.73538,-121.96229,-185.272566,-274.276691,-270.499676,-169.516049,-35.751066,19.817065,61.425595,36.167584,-36.667377,-39.617549,24.557569,52.319028,36.945804,-47.705933,-90.691161,-189.013096,-244.365079,-311.324395,-307.651984,-182.467611,2.689901,41.701693,-8.480672,-82.119655,-218.034723,-213.239405,-109.885251,-82.193032,-90.617627,-75.10953,-49.07651,-71.531627,-134.156139,-200.686712,-165.095794,-54.989782,9.631248,6.05432,-72.246574,-93.422905,-13.415061,59.538792,176.036103,210.018676,241.060055,217.161022,183.153945,47.059441,-19.42888,-5.214784,37.369055,29.574157,63.885183,142.676806,267.789283,273.742497,234.998432,221.2397,191.841198,181.245047,226.478052,303.51671,313.812467,259.067754,226.278734,228.025005,250.084742,281.317647,303.529321,304.932049,251.917402,195.967543,68.113838,32.240453,95.440489,180.452714:-112.858563,-192.796626,-179.323243,-50.504455,1.247833,96.3142,186.281623,427.466631,517.689467,440.146419,118.971927,-40.296063,-189.110225,-180.664716,-115.079057,-88.654951,-88.586337,-173.185649,-227.863899,-357.689177,-420.128999,-408.485281,-318.116561,-98.783382,-57.531681,-134.748428,-336.173358,-406.343485,-433.017537,-383.038182,-259.594786,-223.569797,-176.42441,-140.649593,-123.373219,-102.041593,-123.544292,-183.583773,-147.213719,75.447305,159.625091,99.396852,-65.734415,-142.353742,-227.27131,-202.963575,-84.505023,-35.684366,16.682503,24.196724,9.838055,-50.49521,-80.709027,-110.204144,-115.1404,-99.717584,-53.662932,-51.997895,-98.156453,-121.892341,-150.797235,-136.539193,-1.115518,87.809703,214.035613,244.640793,238.873015,216.709711,207.970333,226.332075,254.939435,343.435847,382.780428,347.35459,251.94411,209.411845,116.287164,108.803678,267.414791,384.678286,466.271772,311.445522,254.84693,264.207194,268.628238,202.595467,174.572295,225.709585,312.740101,323.802298,268.769356,212.337187,152.145414,183.64622,331.079384,425.398979,555.451584,380.918151,198.902298,-82.464751,-106.022183,67.77682,182.926323,323.26989,404.58568,426.041572,366.659853,282.489112,114.285012,86.208972,122.161986,130.83881,70.39868,-29.026069,-84.38521,-172.551956,-161.885355,-49.344661,-1.894621,75.154415,197.295908,221.98131,154.385023,109.603575,36.309269,1.269574,-35.514584,-5.535493,119.766933,135.291309,98.017623,18.420938,6.513266,97.507989,195.165172,386.840297,425.108903,379.263472,261.491439,204.855945,75.867898,51.888041,159.233527,245.958774,363.700946,311.000028,241.402613,139.818833,135.982733,230.73999,292.233371,311.764007,267.869761,275.240358,256.509722,182.620457,-28.554229,-87.695126,9.016788,126.746293,254.157546,111.257925,-5.698386,-250.979209,-337.589246,-288.80672,-176.169971,16.856793,20.579189,-39.09057,-223.337053,-307.194757,-337.650819,-266.952594,-23.666782,80.182046,115.261031,-6.646731,-46.347274,-92.648079,-132.571094,-174.145593,-148.401311,-50.852989,-46.806171,-94.200611,-164.815587,-188.123781,-293.397774,-327.554694,-247.364181,-196.565654,-213.582755,-244.898675,-246.939622,-334.110636,-378.654735,-256.434138,-102.815295,105.224357,30.194169,-28.935364,-66.022845,-77.954979,-139.351007,-167.005358,-147.270032,-75.075596,118.636101,184.786917,165.631826,57.996119,-17.83603,-75.832572,-24.141416,122.509921,171.440897,156.397521,102.146871,71.720735,19.067483,23.922779,136.437638,213.872592,262.232527,107.554603,-12.543485,-201.605212,-228.100759,-184.167986,-148.338799,-46.320373,80.968229,100.250107,-13.756808,-112.700679,-237.860922,-227.601626,-100.567338,-32.757654,0.702518,-67.742101,-84.019902,-40.893428,-0.357337,66.824616,88.356181,128.052215,127.261845,80.108348,-120.834677,-235.061946,-301.505543,-228.046522,-44.813387,0.413281,30.415421,-14.068976,-83.379867,-254.498503,-306.403285,-301.583111,-255.99772,-67.199829,77.468064,56.91822,-9.559394,7.591296,55.088511,54.557089,21.063653,10.217465,23.051603,-79.408221,-189.969566,-319.370845,-281.365062,-107.92541,-51.034306,-10.422333,22.787049,17.415962,-64.417038,-108.974684,-143.533491,-136.170468,-81.391484,-41.128137,-7.143418,-104.561656,-166.502182,-206.637768,-178.035164,-44.710158,48.890097,267.955509,432.346722,424.214515,222.462622,117.596889,95.259182,149.617082,212.187807,224.383461,276.137752,219.83087,146.448257,22.305669,-21.728117,-32.398303,33.544615,229.680295,246.088654,164.497351,-57.338186,-169.003611,-316.284815,-305.552822,-167.562458,-113.844285,-119.535898,-220.579382,-256.427364,-290.029419,-320.948388,-336.520952,-280.791976,-105.075741,-1.152661,-15.469311,-114.063976,-156.179459,-171.694984,-141.124707,-54.742319,-26.874244,-45.721614,-140.701673,-174.389086,-193.490775,-195.357073,-166.751579,-126.456048,13.62987,131.121165,122.795707,29.862601,-13.449509,-81.404432,-79.693845,54.741685,132.248614,175.618309,137.835666,106.444204,-3.392341,-61.452645,-95.974695,-67.72115,19.444568,58.815087,38.299142,-27.396357,-44.212375,-46.154536,-18.365666,118.976052,186.353183,162.039855,-9.880717,-72.147271,-133.094808,-144.581722,-72.552447,15.781155,191.567382,255.220115,249.632061,201.666015,170.050682,183.206957,236.244587,285.922628,265.601537,263.589773,294.556966,273.027463,191.628153,169.242151,200.478549,256.095195,422.506869,451.873749,363.134106,173.744293,124.759624,50.684158,40.662764,153.49421,230.518377:191.697889,146.87429,148.804694,185.979163,205.249391,299.4133,391.052992,560.173367,522.533871,423.73602,236.634178,186.278566,116.86063,93.935418,110.179605,152.328637,270.017522,229.36793,132.11163,-26.367036,-47.21361,-40.533616,-59.344274,-121.002756,-68.803281,-42.011559,-117.501219,-184.874868,-228.973163,-210.720228,-237.318063,-282.084817,-287.412743,-243.192376,-261.5359,-289.566052,-271.59183,-201.579813,-145.971841,2.987641,99.75605,105.41397,51.903839,19.892892,-18.578787,-37.901029,-85.548964,-97.464092,-67.559426,-8.961402,0.887901,0.184635,22.906288,124.91534,161.474342,116.557357,-19.231028,-85.941433,-131.539427,-92.623167,-0.846661,5.873629,-14.798307,3.643511,75.490323,109.281299,158.72079,310.762088,329.932885,250.978465,231.610586,288.402483,367.053896,388.259331,393.064885,385.516625,375.697518,381.189929,419.950149,435.402357,412.345889,406.233799,436.935946,465.224842,417.895509,273.571254,238.729954,254.182332,277.294789,260.575363,154.291973,75.507288,-64.342297,-79.69748,44.23688,141.323073,259.291402,163.22271,56.794928,-101.02895,-98.485845,55.286434,125.592095,112.544847,56.694215,71.691721,151.9415,174.959646,110.694322,49.871384,-37.225143,-51.153683,-24.082015,-46.027174,-108.174618,-216.050378,-211.334218,-151.297916,-150.100945,-183.743721,-129.691783,-92.981685,-44.40598,-14.907576,-12.38802,-76.815051,-248.334884,-271.631465,-138.983581,37.326958,87.979601,52.043873,-24.433055,-94.04199,-52.263633,29.150029,48.440089,74.547998,144.640556,152.97683,123.407046,134.006016,194.555681,188.516456,115.031843,44.640831,2.117352,-68.795121,-68.543858,9.459011,39.193534,11.470177,51.180837,100.779422,62.790925,-31.423483,-176.705301,-171.06559,-93.65034,-63.63784,29.62336,102.587633,61.138638,-125.547441,-200.80109,-196.036965,-133.777449,-17.895221,49.755941,41.58854,-44.822027,-63.841359,-45.593775,-52.737,-76.007459,-38.671615,86.166461,81.394251,71.969955,162.758688,201.398761,148.193253,94.200735,23.958294,-0.141314,-34.115468,-155.268553,-206.060045,-298.912114,-360.410154,-450.686906,-446.846251,-318.436688,-172.415269,-147.29946,-134.837943,-100.380751,53.306386,126.217169,145.600963,42.637983,-18.69036,-73.348624,-39.704189,59.162004,77.982408,72.288884,90.807127,243.281639,380.483183,384.908644,308.757215,250.344056,213.548723,251.398249,269.462603,173.270171,137.807671,77.228931,5.074587,-208.041921,-271.263127,-244.822913,-207.794057,-149.677191,-147.50384,-188.455707,-308.295755,-350.261907,-337.528081,-300.265841,-215.472384,-86.553582,-29.791511,-1.83989,-35.611144,-178.252343,-251.264608,-351.128475,-381.564643,-335.583326,-230.300282,-221.725694,-172.937014,-89.552449,79.428399,106.872855,53.567411,11.118814,10.646547,-54.613805,-139.618977,-297.85289,-304.617828,-199.631818,-141.529244,-68.038357,-123.097731,-201.296794,-368.547358,-434.443963,-462.924619,-414.933917,-261.120064,-151.903385,-151.761037,-158.691082,-118.033568,-57.516549,-98.005609,-227.93901,-224.66469,-96.629246,-81.291398,-98.361406,-32.820147,2.372241,-35.457827,-64.872425,-79.121341,-92.574605,-113.332451,-168.525603,-193.979529,-240.956766,-267.221057,-313.169302,-298.444352,-140.406028,-41.481493,-70.006062,-141.417833,-134.974528,-74.807985,-45.35035,58.141021,196.419414,210.039032,143.742876,130.591693,167.324158,183.661144,167.331994,130.831876,20.620393,-82.568313,-93.495696,-37.200894,-23.177871,-86.140117,-147.921127,-213.829078,-118.584401,-85.880341,-123.639175,-158.37221,-186.748306,-164.8803,-100.169891,-74.61927,24.719151,89.480652,50.078057,-84.581308,-128.154678,-153.922597,-145.883108,-102.351296,-80.576275,-78.905565,-46.443893,-33.121364,-49.541732,-43.379101,26.139856,40.107909,-47.403671,-163.561353,-182.799774,-164.407235,-157.286922,-190.494442,-221.75129,-219.855834,-154.615439,-157.600348,-206.887441,-238.280098,-294.1866,-290.040076,-240.748391,-227.936684,-239.10686,-222.362809,-178.938774,-98.695691,-114.611387,-206.565879,-208.039828,-117.795577,-80.353007,-101.722128,-148.837581,-142.864465,-56.201207,20.290476,196.057794,262.067351,304.091329,217.581334,145.296281,-12.519695,-72.941841,-39.758558,42.29994,205.052086,304.295813,307.597183,277.702765,278.762461,268.730991,234.860143,115.098702,61.388956,62.788077,161.502466,189.865762,155.243643,115.018932,68.546997,65.351964,54.842709,29.236861,10.508361,8.142877,37.528715,75.257655,56.739026,-16.991371,-41.906147:261.034921,207.279256,220.622293,242.388678,235.699204,224.618713,261.07333,453.689923,550.802852,477.480246,269.092664,221.690191,158.559153,105.173293,31.712966,28.993405,39.584921,-12.405589,-43.325226,-85.448084,-124.087114,-223.551854,-252.612072,-238.615115,-144.231852,-97.134339,-48.482234,-53.340311,-140.349823,-211.458769,-331.878086,-324.57349,-166.254814,-117.186544,-165.850725,-235.303275,-222.787062,-180.552804,-182.603793,-177.338169,-74.211605,-19.535769,53.315091,79.669593,55.010485,-21.45969,-191.838249,-192.586828,17.506195,161.331408,142.287995,90.672508,88.630651,85.311819,87.079754,136.406061,161.641195,113.578758,-16.916897,-34.609806,15.931276,51.101087,74.117138,62.292179,88.648463,160.614142,193.611211,266.713652,278.256767,237.533097,218.406402,267.120832,364.767503,356.112985,272.267024,264.363434,334.068441,362.218882,330.559158,293.193827,287.827556,418.441833,487.664287,467.499305,373.786523,216.753515,213.019781,279.51404,238.39684,174.044113,74.393108,36.677502,-53.485392,-61.601585,64.766023,149.403185,201.407468,63.291941,-25.187064,-126.456272,-132.526248,-90.647182,-61.466142,13.646834,134.521294,172.518844,176.778121,174.588028,148.910513,108.49701,52.971654,77.757581,169.160423,132.810505,76.379801,-22.160239,-72.183593,-160.667645,-163.342909,-96.783184,-9.969032,32.569086,82.003553,74.438152,-13.392453,-73.799238,-145.351155,-141.388656,-35.922293,119.802323,142.195209,70.731924,43.214146,69.891883,83.355028,84.326135,146.720254,183.617926,204.224031,195.449823,196.620036,211.408676,210.613947,209.759332,282.766724,298.818094,236.712583,86.137762,61.712083,119.734696,137.172871,112.110783,169.104999,219.831911,229.450836,166.365223,-29.515539,-86.386593,-17.84412,73.02161,285.29531,381.503153,309.892708,10.845782,-111.682422,-160.973469,-121.505866,-45.944495,-49.560491,-88.651311,-148.633738,-151.096612,-149.888986,-140.748269,-82.876497,-34.656637,69.86582,88.927533,63.960427,-12.236107,-56.827068,-125.160772,-150.865559,-206.725188,-214.770004,-205.84598,-223.771952,-261.885117,-370.564579,-400.408894,-368.935016,-357.475362,-394.964884,-341.680823,-280.620885,-251.846678,-280.261979,-260.035861,-206.276874,-119.710687,-102.867167,-116.608253,-133.694857,-124.544941,-107.953174,-111.181862,-110.022849,-69.198617,107.150602,207.254819,207.806214,164.569981,102.872444,-9.5194,5.53986,96.886089,74.893805,39.260315,-15.80702,-53.900325,-152.582613,-191.766574,-227.864332,-215.847342,-147.770518,-137.18524,-173.799895,-316.016612,-383.219444,-382.507607,-327.659172,-208.110819,-101.813287,-83.217521,-119.785333,-152.101365,-220.395574,-250.501271,-304.324037,-320.389957,-327.461114,-337.550798,-299.812212,-138.457423,-90.987785,-99.249288,-100.89138,-53.905084,3.339343,-3.587488,-156.301552,-259.672554,-362.509335,-364.700198,-381.817623,-389.028121,-298.092717,-205.3148,-237.165678,-373.242778,-414.308971,-423.074551,-393.486766,-233.871553,-185.683287,-273.069325,-373.839329,-328.484527,-282.026813,-332.988461,-479.112332,-515.61716,-467.201822,-370.004711,-319.125078,-223.876299,-206.450542,-181.810145,-139.032626,-87.073991,-169.467576,-208.513437,-168.900486,-115.401483,-91.908487,-122.8855,-188.531246,-198.154231,-142.167197,-67.631097,-45.469324,-47.012523,-63.437813,-51.030979,-8.671734,118.386292,162.730155,141.660198,184.246982,244.912544,249.029023,181.766991,59.890145,48.569087,56.241615,-41.255994,-86.068214,-65.712744,-59.640166,-180.914306,-252.966542,-236.462004,-137.707837,-136.362186,-181.698779,-205.111731,-234.761601,-217.567699,-111.520946,-56.339628,-3.704928,2.371315,13.713317,19.694266,-0.647911,-76.935185,-115.529228,-110.783531,-28.302095,-0.373135,61.66931,108.573543,153.459773,143.215816,131.017944,124.629262,60.87125,-22.567921,-51.651032,-112.102517,-144.78623,-167.769281,-167.890699,-170.370926,-128.710704,-106.582662,-112.211735,-158.032566,-293.173708,-309.769116,-226.657805,-206.981666,-230.362693,-157.583549,-77.443447,15.371427,-22.504856,-184.325456,-246.775803,-278.477874,-185.700045,-140.197588,-128.994409,-139.845919,-137.747652,-106.36997,36.283315,127.136609,238.407226,200.354142,166.334714,44.811986,-57.445121,-164.998776,-130.483516,-26.964833,51.235522,117.046285,308.726338,363.468041,239.520416,116.416772,8.947048,41.044568,80.621753,2.962167,-15.139115,-25.383668,-46.996708,-25.818694,27.695845,68.992315,16.716721,6.441924,24.988057,27.029395,-12.805103,-20.222127,23.130053,53.511698:25.291158,11.933425,31.650569,152.650558,208.473426,284.827841,348.236647,529.03843,548.760064,436.971685,142.370147,51.14989,-46.962386,-82.898982,-73.801267,-34.273735,4.90652,-70.187461,-123.163099,-224.626317,-291.230691,-370.615109,-325.988464,-133.49296,-71.47444,-123.8477,-254.707952,-298.637668,-353.404292,-353.764317,-300.472593,-265.694725,-194.11653,-165.322587,-179.541825,-211.364828,-224.535932,-207.114181,-134.623882,71.526089,102.88328,36.848045,-96.306394,-129.751516,-168.974556,-190.193454,-191.618831,-151.073736,-27.853639,38.627321,37.024067,-8.705124,-31.36266,-17.522739,-13.92633,-73.937954,-63.575858,-52.049803,-124.514521,-165.377697,-160.341529,-118.80552,41.146506,125.660802,180.479596,180.502276,222.28277,334.34103,346.665604,279.911688,246.331828,277.776763,369.315043,357.064105,285.089834,284.717652,277.005068,245.140568,244.599214,290.32671,349.168946,313.602381,320.895067,395.510822,393.582551,258.174041,183.539782,154.840839,196.85899,188.640553,139.842864,107.340813,11.289187,-7.78716,62.024479,121.306069,257.575108,254.319445,159.148173,-12.331017,-8.01523,115.535533,167.521297,222.994879,272.443039,273.984859,231.507026,218.568986,240.432834,254.816488,201.88983,150.81565,91.657469,14.784971,-50.618236,-139.467589,-132.345344,-40.941256,8.505442,52.772453,62.609821,50.12925,4.024389,-4.665329,-37.825355,-75.238139,-137.954648,-138.748168,-70.850912,8.202315,35.389841,34.882662,12.249642,50.025801,134.807669,270.825471,206.624336,161.556732,205.152828,241.14301,181.008587,140.611173,162.908943,194.585985,240.54287,216.368792,156.324256,7.13748,-8.796109,114.951158,183.269824,216.613841,194.241083,169.736429,66.04396,12.282855,-47.459616,-54.395144,-25.699658,0.228916,16.820276,-56.156116,-110.664023,-229.419555,-285.375893,-274.049285,-187.545703,-20.669888,-42.753108,-121.762796,-253.475477,-241.012677,-166.247193,-158.997734,-141.112692,-105.631886,-21.171719,12.225617,18.47406,38.401091,45.30161,18.538192,-16.191764,-61.772415,-75.697835,-102.017471,-133.349156,-122.145239,-155.755409,-190.362798,-186.243694,-175.966375,-197.63502,-179.75082,-161.465784,-218.382527,-280.181108,-255.453544,-154.911761,28.104196,73.043203,51.3922,-27.622496,-47.01181,8.016681,50.150783,77.640911,77.742848,143.928807,250.982373,279.235273,246.724874,184.919584,114.859358,148.115121,227.899709,186.860789,133.632136,17.252118,-53.06045,-203.866317,-224.479319,-98.983824,-12.749696,37.21302,-52.309433,-105.009014,-210.909789,-236.430825,-192.105142,-178.970833,-215.684143,-112.591831,-33.047648,-9.061508,-64.321035,-197.188638,-233.985633,-257.872919,-245.876516,-139.030887,-71.500123,-82.037334,-55.963044,-3.668669,64.926118,49.883602,-6.602171,21.154785,5.302542,-177.778893,-257.674012,-223.860241,-157.519214,-112.796911,-128.087077,-107.693368,-126.859956,-195.434499,-304.659162,-307.570913,-267.347249,-252.968382,-214.986437,-116.980056,-83.919168,-107.008072,-129.877107,-132.451953,-127.374583,-153.235379,-158.569116,-89.854667,-69.723693,-101.999608,-97.019079,-57.124766,-55.913742,-101.194423,-145.01757,-85.105046,-76.968495,-123.239813,-142.233879,-187.294797,-210.483642,-201.77684,-169.041968,-83.358649,-113.941336,-164.400916,-185.314778,-146.634901,-33.453529,26.800082,155.118661,273.028266,291.653166,235.370189,199.399025,176.73874,186.433645,191.685297,173.275021,95.588898,-25.431161,-50.653201,2.19838,24.158426,-5.315982,-27.433972,6.17068,73.945524,56.866129,-57.85262,-111.541832,-179.324573,-195.910684,-162.477604,-115.321873,-32.725286,-39.683684,-72.433116,-157.791779,-198.083479,-229.775189,-219.820461,-171.839441,-105.896469,-90.97556,-106.875406,-124.817988,-156.57411,-159.227527,-142.80521,-134.192945,-130.160801,-151.167476,-162.973313,-184.558911,-172.512495,-91.88982,-75.191715,-115.551508,-95.264386,-68.16515,-55.287423,-76.009349,-137.892321,-137.552742,-45.185504,-1.484288,-0.757279,-22.432231,-11.846843,-46.897841,-119.182255,-215.358585,-169.794845,18.17962,64.987196,26.254614,1.538257,45.674003,121.380635,128.605063,179.154067,229.882224,282.595095,194.439486,117.295451,-18.152728,-48.601578,-16.240041,17.904317,59.459459,129.632156,186.254605,270.914077,263.476026,182.615273,152.608364,117.291866,125.887074,241.963726,303.921534,279.347438,233.180537,227.712808,211.441038,208.233874,261.580927,310.122486,280.635304,167.023856,115.043156,29.553763,13.875043,42.854519,62.069656:left
-194.785126,-198.646255,-207.607286,-177.355689,-109.150193,64.006189,105.154156,25.529934,-81.600576,-79.745891,-22.130727,0.048809,24.199768,40.461544,87.986392,94.317953,22.455246,-60.017732,-65.83715,-28.991174,15.618607,142.039334,176.214917,111.442778,-48.236959,-134.739096,-232.384518,-210.311334,-85.190588,-15.037024,63.784961,38.930766,-72.444312,-198.283257,-247.880981,-186.863634,-108.324296,-66.283492,-111.307475,-187.708844,-123.103922,-76.199139,-79.77115,-112.520578,-123.846493,-89.298073,-13.003945,-5.041286,-11.072446,7.266272,1.512073,0.834491,33.105571,150.245923,211.645803,243.890178,146.02637,102.949873,74.183111,67.78021,86.461362,126.762876,209.072574,207.848844,81.562592,-101.125576,-139.951479,-93.408122,-68.735153,-92.938285,-134.266162,-261.867074,-332.578234,-323.197562,-289.839539,-281.933115,-229.704224,-150.279657,81.387821,148.390868,60.381511,-95.915403,-120.484273,-72.534426,-33.250059,-11.592882,-28.00186,-52.519346,-108.827076,-185.655053,-325.63822,-332.226948,-277.439113,-259.995027,-213.18511,-163.952711,-70.942094,-48.941316,-54.648862,-75.887889,-92.739057,-52.453205,29.576721,176.808839,138.749412,66.01299,-54.697423,-65.744766,-6.941693,36.434727,59.280259,13.026294,-108.800583,-142.389759,-130.692427,-32.695475,36.886671,101.731956,89.9843,46.389603,20.343083,4.569649,-26.891218,-28.316164,35.585075,103.463692,213.952003,209.245043,156.629842,156.933538,107.25402,-14.819281,20.086445,261.649702,358.772336,340.358464,192.606206,153.912659,194.972226,238.153489,283.415866,301.877049,317.683186,285.870321,196.287778,165.303878,148.186038,63.566698,11.399863,-53.213122,-67.807412,-74.43039,18.92224,71.996687,57.667748,29.647632,45.541596,87.056335,211.707886,263.066273,260.66321,139.922948,87.032263,89.668877,146.562612,275.304076,302.863607,259.258276,174.057969,149.038121,155.128151,182.831454,262.324125,320.928312,439.127642,443.742877,317.660824,143.222617,78.135822,93.473399,166.869975,266.690144,248.665758,148.628679,147.238879,174.653007,170.637113,154.152003,175.006042,205.397059,270.378529,294.481991,273.702286,240.049351,277.692433,411.554291,460.329325,525.034842,550.747117,538.415636,366.023414,255.44542,111.966287,80.365785,60.789372,72.003812,91.299622,65.323552,-7.100556,-14.837141,-4.92939,9.659342,17.251193,82.639061,117.913485,101.907986,-23.38925,-116.023719,-215.290361,-178.64948,-49.869599,-3.019442,76.291715,109.071627,116.806048,19.190287,-41.883603,-44.395088,27.549832,189.153913,220.602678,187.359724,186.500321,187.462424,99.092575,51.98164,57.764157,88.988377,103.916442,79.591435,38.508764,-7.542575,-60.638278,-146.334957,-117.419265,91.330141,191.775526,188.250088,-24.63396,-109.768974,-139.110425,-85.348563,96.472061,177.276987,238.32658,205.851382,44.43164,-89.19412,-84.155185,29.455064,73.69396,113.138869,130.229595,98.168978,46.727302,88.168911,176.261434,160.413749,164.600103,227.392917,283.912177,235.608481,137.2331,160.75641,179.533748,135.626483,80.797942,16.977526,24.730277,80.476832,151.051418,157.515025,115.649178,120.805548,235.19311,307.138907,373.121085,344.335194,212.339381,134.818341,131.007274,178.373412,214.748564,200.238701,119.736429,-81.658711,-97.630459,-55.59428,-15.695053,-1.71092,58.054467,89.796686,139.501269,150.103073,138.324606,97.127981,50.404515,-69.960235,-104.023604,-85.200166,-62.802667,-80.199451,-159.69786,-203.550042,-225.355083,-185.703575,-132.145636,-146.13772,-195.769385,-231.524185,-349.475448,-453.022952,-431.863564,-228.040112,-118.122964,-9.521998,-1.43502,-10.451756,-132.025332,-249.725436,-373.976788,-333.013151,-246.294975,-259.103108,-288.060236,-274.708936,-239.088152,-218.938593,-234.997324,-330.939262,-356.181721,-257.73196,-177.63653,-131.138314,-195.847413,-208.433675,-199.129277,-181.365003,-123.473137,-107.209248,-62.970235,-20.002492,-2.183298,-39.850193,-12.636692,42.888663,33.524974,47.01712,76.626281,67.84799,38.693629,14.804004,-128.797585,-190.455494,-226.349846,-248.427519,-309.767066,-321.624783,-233.618748,-46.077733,6.790731,22.281666,19.762599,-6.015007,-20.610651,29.803355,101.028463,85.181168,29.95433,26.432525,-35.250389,-101.971975,-154.705613,-121.895875,-43.591917,-6.62299,13.641279,51.21562,72.700582,114.638536,98.325442,22.077407,-7.039801,-35.788043,-140.01649,-161.085873,-72.974624,-20.332818,-7.455415,-15.686905:-99.22923,-225.391525,-288.672808,-255.528466,-142.625045,127.956757,194.546818,83.439831,-168.508951,-231.914584,-137.109825,-39.038167,76.384491,100.179038,138.79438,133.602112,26.735671,-91.128524,-85.146226,70.459133,161.116994,233.031782,209.784935,125.794088,91.093243,52.704891,-127.364669,-203.549354,-186.403285,-104.90309,23.51142,3.134103,-123.363661,-210.926304,-225.320726,-184.134049,-149.990021,-71.23146,-36.727318,-38.218539,-83.080648,-120.147977,-225.172896,-237.049044,-126.487121,-41.503073,93.212643,111.199026,82.671041,96.487006,97.563339,55.83401,52.450042,132.314176,181.848357,213.71187,167.444358,130.670532,98.78568,114.568585,178.159151,209.011609,235.620806,225.296174,93.900949,-143.19533,-195.078589,-131.106987,-93.281521,-94.173368,-129.783722,-273.425238,-429.386041,-455.407713,-386.42648,-335.396527,-223.437158,-139.240138,32.015268,80.883925,66.515319,-44.748247,-98.602955,-130.339216,-108.49203,-63.625347,-56.610842,-57.543419,-108.372384,-173.262258,-270.981285,-271.46974,-252.490491,-241.563533,-190.767945,-152.724966,-52.287191,-0.252694,-0.880986,-30.336622,-54.580627,0.979614,84.333521,147.050245,-24.284936,-148.212482,-280.939907,-246.781451,-102.833847,-41.56855,51.394127,59.359885,-48.879237,-182.904965,-190.44589,-118.745918,-88.267116,-14.141063,43.661704,120.147225,81.599341,39.35031,29.344915,74.131062,136.579681,112.719833,37.616022,43.511572,111.228536,65.906944,-5.301562,-10.490451,103.366903,338.789546,355.310356,225.108089,154.006242,167.845184,211.731911,235.747035,297.731477,314.133932,248.059455,188.268949,124.97902,102.205856,62.957864,-35.344672,-45.937757,-4.682682,-21.41211,-133.529704,-96.471501,-50.611896,-74.743991,-87.972428,-10.071336,53.057307,160.80761,177.7026,151.042547,143.177221,154.160768,158.513004,171.464348,321.690714,408.661161,361.62489,127.587713,56.610614,73.318477,130.682353,262.620282,321.214188,385.290527,365.643812,214.126001,48.070406,22.425428,145.680409,255.837365,354.987082,303.913992,128.011759,66.906316,86.692903,146.445622,175.837198,219.309591,215.336694,154.929356,113.838537,74.319193,134.758133,178.72152,285.28685,358.132101,494.9898,525.120287,483.343322,290.179643,163.815636,6.651639,5.109177,104.390637,161.760114,171.435033,110.729185,-0.213521,-1.500009,6.836902,19.954109,21.743873,46.003035,60.35756,34.37766,-25.193021,-75.870494,-187.825235,-186.28907,-30.901602,53.078863,112.498067,113.702898,104.553996,-11.984738,-78.06241,-8.633666,109.31273,252.368194,224.319349,68.871827,12.984975,16.186292,-14.275461,-25.111625,6.754729,35.493409,77.078675,85.685527,73.833243,-72.045982,-178.030202,-164.997449,-10.990507,259.007484,260.138887,135.735581,68.230192,41.983595,32.78407,83.469333,229.827818,265.255278,244.518595,196.668677,68.766643,51.567948,90.298009,174.95371,203.410152,211.942526,184.735095,78.374052,84.295448,172.53326,284.474107,265.967533,288.268038,347.682406,408.458798,396.752024,338.129163,237.382362,196.95444,146.244385,118.193687,132.874164,180.181573,244.010095,256.676788,221.574757,112.9147,139.447635,408.022277,537.66321,563.126985,480.96332,299.155792,187.323708,158.104294,190.723124,241.456071,256.159329,178.551,-0.195428,-41.763795,-53.204287,-81.953473,-47.422583,101.0665,148.419792,150.410233,124.919025,60.047145,61.322258,90.859148,101.763708,72.615368,22.338313,7.035763,-19.888515,-68.812131,-134.703899,-231.989199,-202.582727,-109.566382,-105.469404,-156.876963,-187.637588,-245.415061,-283.100512,-249.756291,-65.027843,21.501832,83.871761,83.352964,84.592848,-34.27769,-157.862133,-298.865009,-255.188782,-100.423449,-65.439797,-73.452868,-82.92001,-73.894024,-74.995612,-119.546499,-253.810321,-260.963905,-118.858636,-78.050547,-173.303246,-191.296105,-152.778129,-161.114009,-162.150392,-26.702853,44.768032,112.676894,136.4631,88.343571,-47.802966,-31.834126,111.662022,137.947555,144.961511,159.518868,105.168915,-10.427817,-45.49377,-148.899021,-203.6883,-225.486386,-206.356455,-143.164088,-118.013746,-84.593851,-2.870688,32.948224,57.309326,68.721068,74.896949,57.8865,32.752714,47.276391,39.176382,-15.788399,-35.034262,-69.173265,-61.587321,72.901989,128.703729,65.609446,-60.719932,-59.488317,23.941591,47.554739,31.912721,7.483584,-25.360003,-83.148306,-141.340655,-194.443292,-171.120782,-87.808487,-49.183316,-42.353239,-97.365782:-95.252515,-205.892514,-178.723261,-86.397292,-61.976507,47.793274,108.281478,22.229506,-233.101206,-301.509317,-216.355548,-105.406305,76.39463,114.571351,123.046059,124.149067,90.471515,-44.548766,-75.373052,37.287772,112.75024,166.021177,161.4636,129.365388,33.965424,-59.980364,-261.719805,-293.889351,-187.867773,-99.258837,14.106763,11.280827,-67.134145,-137.649539,-146.92504,-129.558254,-120.253782,-88.557429,-67.410589,-59.595855,-114.942297,-157.683592,-225.655512,-208.398469,-33.494675,67.11766,136.320779,106.653595,48.238518,82.004694,93.057819,25.354041,-2.423637,85.809401,173.413681,256.512506,183.542367,140.71346,91.471912,89.446592,144.75043,167.872679,95.44896,36.172605,15.689803,-43.00223,-114.150179,-149.829077,-111.528067,-67.421914,-103.837545,-328.836856,-600.149805,-647.869533,-521.943146,-443.103144,-348.365505,-274.246413,-141.294964,-127.076696,-142.31023,-172.866578,-182.963832,-155.246149,-136.685771,-163.886412,-195.389285,-191.147801,-119.441713,-128.937512,-197.395728,-183.329783,-83.114814,-65.344779,-118.454513,-126.936222,-53.548829,-6.124905,19.667838,73.153274,47.697857,4.858916,42.187977,78.563559,-100.235002,-234.886709,-351.51826,-286.139384,-85.767304,-20.370104,12.559585,-18.575306,-137.80128,-210.409253,-198.473466,-124.161859,-106.630508,-95.361089,-60.056202,9.750468,-38.620184,-74.60658,-51.038721,1.599025,70.960955,60.806514,16.996117,20.760681,58.4396,25.485135,-16.937885,-29.019568,42.214349,268.063735,329.033379,255.597861,144.741376,119.220818,121.314689,151.156454,212.132962,235.058775,278.052065,263.093731,134.844058,3.949611,-56.831763,-127.70261,-94.335301,10.798028,-1.105828,-113.411402,-130.501988,-131.886418,-173.09297,-144.423419,45.076689,154.108036,302.994954,303.336275,173.557621,137.157517,198.776215,334.896834,383.197499,489.11516,505.025574,363.059828,158.478507,89.720724,98.410056,186.503786,367.614774,380.656462,306.481497,283.195096,222.196109,78.246738,35.977944,138.200774,246.88942,347.971784,300.851977,197.337268,223.47308,214.766417,141.408883,136.929821,202.225082,217.741344,176.796637,160.593304,159.817358,132.946254,160.894961,319.1737,373.147917,383.15226,379.805784,357.552885,206.592984,113.909665,83.075179,134.769456,233.444252,253.870342,193.323983,126.466205,37.088547,42.480728,54.626799,42.041475,25.20149,65.860431,97.412737,51.324179,-41.190079,-67.364196,-116.710968,-125.80059,9.224093,125.84307,196.332927,153.304755,115.633968,98.596507,69.808912,125.3422,215.693435,321.361827,289.839008,165.987546,104.89548,92.007666,97.446232,98.71325,64.346396,57.787434,72.893101,71.005237,67.270011,-18.279908,-97.685324,-44.600689,119.851878,391.937846,391.004097,231.509755,116.482853,94.987361,97.147125,119.310851,210.152965,266.585593,344.944965,337.997322,238.875682,167.879165,185.811922,286.975839,324.178225,329.044914,307.799291,247.940338,227.655659,246.253144,286.264754,298.50073,364.895009,416.448925,449.568785,415.661963,336.312255,257.164229,199.29685,115.417329,124.954958,245.30808,297.071148,304.235418,276.119523,230.168523,144.683378,186.272718,396.291371,473.613411,467.45047,411.650291,311.312534,233.769684,177.790011,110.430401,145.831653,299.447036,311.642444,95.072853,-49.163697,-9.874142,77.804623,75.510414,57.565903,67.967097,96.667188,101.659651,82.377948,40.331834,35.591932,75.978018,98.468503,95.710743,54.929782,-76.681077,-138.967713,-155.109957,-195.353695,-192.655668,-134.263398,-104.406587,-141.399779,-215.487441,-280.933951,-170.792905,-143.430948,-141.268816,-114.480869,-9.929806,48.367511,121.131658,-31.393015,-184.337827,-351.847892,-308.232419,-124.144053,-65.920771,-112.737161,-192.014318,-208.071429,-29.909073,-10.828598,-108.613131,-122.513134,-37.370741,-29.504517,-157.596453,-207.855441,-176.758624,-129.041862,-110.212414,-59.893338,-44.711622,5.908457,54.408445,66.534528,-90.882949,-129.733774,-26.286619,66.498737,201.572668,203.089608,80.4113,-39.091423,-76.006249,-132.781317,-135.82285,-96.455994,-80.601274,-96.840463,-102.397799,-43.881824,-39.378624,-56.209669,1.477098,54.37504,105.834317,101.237893,44.68108,13.87011,26.434029,23.462526,-7.937818,-76.048799,-58.060076,124.460598,182.55289,63.258333,-72.195494,-75.717638,-50.572794,-51.270539,-75.179698,-96.272787,-139.536088,-162.544509,-167.953634,-154.918024,-138.570584,-79.389674,-31.703088,38.391883,28.020572:-172.269397,-234.488361,-230.083345,-146.248684,-79.307799,61.369041,89.961046,-6.616835,-118.602682,-133.060119,-101.330848,-53.158704,66.030026,114.187977,154.549422,141.933763,63.061452,-65.977166,-106.61471,-23.881796,79.950895,238.413229,236.237446,83.324284,-66.824878,-134.882561,-267.016603,-267.271993,-127.270155,-62.172074,-72.674399,-125.217994,-148.141555,-126.213876,-160.709127,-161.343032,-86.082727,44.308004,29.876602,-112.556626,-175.911048,-172.689389,-214.435357,-233.978362,-161.094819,-95.555943,-20.12359,-1.618271,50.944561,50.017701,16.003829,-2.199818,37.109575,126.006081,149.378618,172.768097,190.360757,187.158385,131.096198,86.348991,69.611948,124.943156,230.199936,218.574725,111.376739,35.809318,32.750194,65.879125,65.477542,22.565699,-2.203626,-117.07848,-304.413833,-355.933068,-314.316772,-264.484327,-185.53728,-120.077108,62.199515,98.52347,12.828773,-64.717036,-83.761187,-90.888968,-58.359766,24.345022,19.324955,-94.882881,-183.008423,-217.14968,-282.626316,-278.720172,-214.878173,-178.208556,-81.478347,-33.49137,-8.753655,-55.154027,-75.592198,-100.620816,-116.28638,-75.284706,5.276686,124.553475,-11.853299,-131.944924,-227.204934,-182.596314,-53.919839,-10.626723,-2.22801,-44.570336,-152.941291,-224.912389,-251.273476,-245.433377,-208.51403,-89.6637,-27.712536,26.600862,-22.904252,-44.631309,-18.742035,13.56848,57.004656,66.831484,80.46359,78.920185,82.822834,74.468974,40.985303,73.05396,167.569036,352.298349,375.258355,274.233367,163.215023,140.038355,169.343584,214.232779,280.247219,295.009248,301.141671,271.806689,185.252452,156.88457,141.019319,73.644466,47.12554,19.430992,-15.085403,-71.384565,32.483292,74.072949,14.894271,-6.630889,129.567327,259.160268,440.740733,418.402024,254.00367,204.872332,219.754896,274.331977,325.070863,452.39977,476.6994,397.903777,277.053282,215.972531,155.992547,194.09683,357.9845,442.488401,513.300019,475.972371,320.145078,106.745076,16.968374,71.332236,190.851051,335.04698,320.979312,251.492872,238.087754,226.552751,209.065444,233.973751,289.557566,284.024586,227.311014,197.200986,177.824099,240.384809,279.269565,324.842151,347.420951,441.277509,491.680357,482.425427,296.89519,206.273438,149.75511,171.02286,225.73284,228.075848,196.922361,184.656326,136.142436,29.951458,-15.209379,-26.802671,3.192864,55.299105,47.737244,13.868828,-4.614323,-45.516305,-133.266593,-117.256814,44.368484,124.90779,157.543867,130.793831,108.295592,108.98537,106.206412,160.941979,216.298905,337.639032,388.523822,382.221668,252.05113,204.438342,192.938165,205.729449,179.059414,142.072765,96.538332,96.815346,109.304388,62.505666,25.557129,63.570155,148.605506,325.442809,370.19554,313.656657,157.883113,109.735204,99.731084,121.030021,179.527557,207.597348,252.872867,238.705856,124.487416,61.39535,81.095856,175.714996,222.941519,277.088011,273.271928,215.365917,190.79572,207.804657,240.710082,252.06575,332.152453,384.726588,392.362954,348.420568,269.484833,247.09167,231.453909,182.944119,183.683004,241.620988,243.784158,176.049902,168.574579,163.846175,142.327869,172.521762,308.75783,378.483063,445.827368,414.834307,235.115312,98.615765,90.495267,132.743296,166.730184,219.784551,182.534582,-41.56271,-162.737209,-133.45382,-41.415492,-17.819796,16.143606,37.253228,21.93653,-24.079615,-92.08866,-75.792806,-79.693456,-150.270447,-187.326026,-204.019655,-202.423286,-211.30246,-203.324725,-214.983016,-285.561013,-317.804569,-330.172758,-313.498684,-320.321714,-359.287642,-396.842553,-368.403378,-361.25133,-291.053362,-210.791755,-51.03967,-18.570848,-68.253671,-198.429763,-278.706988,-364.517704,-336.666922,-282.846117,-317.90782,-398.910381,-389.750099,-312.64329,-240.668015,-242.418312,-324.577053,-352.107113,-308.256361,-276.173832,-302.281302,-366.224002,-372.685742,-336.948238,-284.09881,-154.361332,-116.441341,-91.938622,-81.64348,-91.022072,-164.316828,-159.492374,-11.721948,67.185806,140.978301,138.725154,73.433279,13.67993,-24.865573,-152.668217,-197.248176,-206.048842,-196.048288,-155.263703,-123.336403,-21.766454,71.229027,79.817524,77.211395,86.080408,113.536942,127.715679,111.836419,49.774061,25.299273,-7.044578,-26.010501,-109.32217,-135.159338,-25.91354,56.273807,66.580306,-56.886037,-94.534583,-89.110634,-65.624861,-13.283666,3.977855,0.516985,-69.535941,-124.099826,-217.277362,-242.394206,-210.204669,-145.998975,-3.237462,28.60005:-183.85315,-249.700554,-210.415097,-75.471136,-35.422177,36.795547,87.56128,78.061136,-127.337951,-216.109157,-199.614731,-98.604149,139.770726,219.029531,247.334907,209.488508,91.458641,-46.954387,-91.392897,-12.407897,95.216815,254.661467,254.082438,103.716275,-82.206405,-155.685539,-266.831165,-275.707449,-170.167963,-89.096034,18.97108,24.421685,-49.605244,-150.772186,-160.599067,-79.090393,-12.077089,88.345496,86.695141,-21.198017,-167.242636,-245.463219,-349.484018,-295.577536,-0.994451,116.995839,149.710727,102.052705,12.12304,-2.623091,2.714641,28.508357,62.414812,151.121579,179.801644,180.375644,124.924506,109.259235,128.219487,146.933431,175.684174,173.446567,114.823135,93.177975,125.616554,121.07994,86.915602,61.457998,83.549177,121.630105,99.256352,-68.815256,-273.515255,-332.11139,-321.321817,-275.224368,-158.502629,-74.83705,66.499281,77.86361,11.086519,-85.896518,-121.130829,-76.035018,6.767667,129.211063,101.171993,-36.584247,-69.484069,-94.349607,-204.528267,-220.742196,-98.453494,-5.311512,79.487607,53.045939,-14.090658,-10.611846,-19.609787,-75.869969,-83.426048,17.722061,99.340375,123.456877,-102.158235,-209.59746,-203.496036,-125.392082,-12.729737,22.94955,50.11702,-0.4527,-180.502095,-273.705796,-262.883076,-180.044281,-148.414185,-106.578019,-73.379771,-75.866685,-195.596036,-208.276401,-101.514846,-43.443529,1.248327,7.771382,35.424613,53.606402,91.706661,53.593263,19.434798,95.399754,204.027936,377.848378,374.323942,211.578828,80.531108,63.5878,137.453708,199.590111,236.899233,241.455736,297.990487,289.486803,122.351858,-64.346408,-99.034803,-57.179045,-10.125954,46.218418,25.38845,-78.039119,-103.404883,-91.866312,-60.94131,6.810801,288.817883,428.253668,486.453146,417.901175,284.578637,235.445394,240.422201,330.06057,394.479797,481.215163,465.169954,303.308852,151.355443,116.524101,158.648743,244.641847,463.430611,533.482259,489.95587,396.09898,198.742013,26.394543,-13.735669,113.087637,227.141257,334.833999,308.21995,219.005784,149.69002,101.253966,62.1528,122.446187,346.602668,420.420471,370.880867,292.037732,199.579845,195.034845,208.298196,281.568481,320.872364,344.357084,325.440662,244.624114,146.10787,98.553889,77.740164,117.70946,229.142804,273.858997,255.932927,175.603246,-18.392672,-91.666051,-67.051584,9.797887,47.968684,134.313739,131.396593,-11.469811,-123.502658,-137.474879,-127.621122,-95.936332,68.87227,164.874372,173.195195,90.49168,6.706283,78.494881,100.760017,146.926764,222.774794,433.03102,486.16489,410.825853,233.021303,160.569471,100.018465,108.078554,148.072404,152.300067,98.675854,67.876218,56.317458,-2.805329,-39.741751,64.887197,200.463052,415.400337,428.587513,277.752701,54.139633,-7.249863,52.731895,126.642578,242.0875,301.450844,416.703821,411.291571,256.257099,128.012596,120.47381,196.242213,254.463099,337.273632,346.872819,311.064936,210.316308,162.576466,184.933783,257.800358,434.36999,504.548237,550.81289,514.545818,394.643811,253.995115,166.043669,58.649253,82.009204,216.828017,260.343875,254.627983,205.306657,162.140797,103.172428,129.389502,258.200484,328.7899,427.933996,429.989249,292.668574,84.975841,45.922453,132.07763,202.09629,251.057068,189.200281,-35.136652,-110.096831,-79.58667,-38.283854,-32.831898,39.457014,105.793977,154.219738,102.964269,-31.816976,-89.864596,-105.325185,-131.74936,-131.348799,-109.724205,-115.554612,-168.778689,-223.281793,-247.928962,-276.616654,-268.830377,-201.525043,-149.406128,-123.734179,-183.750316,-285.855209,-265.671905,-267.303136,-230.126566,-146.664629,32.520379,56.466062,-17.801489,-150.814476,-245.755381,-398.567731,-379.031305,-208.480663,-150.942935,-182.144089,-241.202526,-281.99335,-208.277315,-200.325724,-268.819175,-294.173272,-219.078785,-165.136206,-203.029824,-324.748684,-363.044614,-353.957654,-295.211954,-127.550606,-51.159996,4.004478,-25.436142,-112.505837,-168.231162,-170.357667,-81.96862,3.732179,159.754943,182.566832,90.820588,-64.580587,-135.337798,-226.55717,-227.245413,-177.874724,-146.892534,-85.526132,-68.695932,-56.583033,-93.472013,-106.044839,-36.749264,5.001874,38.517961,56.520718,63.710409,-66.617817,-150.154303,-216.625456,-208.443989,-181.883503,-137.187429,21.349643,61.656844,-20.201626,-142.457826,-150.581971,-79.081261,-33.559634,38.300876,33.127213,-65.041739,-187.180725,-252.385182,-312.431872,-278.253127,-123.904384,-45.625986,46.488433,61.818364:-185.267802,-168.174121,-120.351234,35.247016,114.409714,212.572825,215.644608,122.027826,24.908214,13.624683,70.436796,122.465348,165.714446,154.265216,139.028112,119.835879,11.962068,-105.574929,-127.350835,-37.644429,68.116397,292.7869,330.659832,159.991565,-64.557554,-120.693584,-193.906885,-199.973509,-69.897087,26.041439,70.025406,-3.38397,-166.023394,-208.860105,-190.664176,-100.05975,-61.86001,-51.269997,-69.556217,-133.660174,-176.005896,-171.911231,-153.690469,-147.07046,-126.861398,-118.745795,-124.062532,-122.812965,-48.518947,38.101946,43.603574,46.807791,67.806737,121.485976,144.176457,155.717528,118.873807,93.159993,5.248877,-39.900924,-34.727771,12.541361,116.576417,159.86275,193.937325,128.707897,114.466463,181.593168,200.202562,119.368389,54.547493,-31.634753,-56.781689,-77.78384,-129.486117,-113.945442,48.557548,165.50191,307.279094,281.478883,99.381682,-22.562921,-28.881661,59.626829,132.240935,133.918989,27.21769,-199.717828,-246.964122,-246.696327,-269.055033,-273.090554,-245.753725,-206.098069,-108.825812,-96.535699,-143.544263,-143.149318,-100.479056,-13.501561,-12.238594,-21.681472,17.069574,145.900001,173.828499,120.263212,32.907355,47.066197,124.004517,159.471319,183.699881,147.898994,0.838598,-93.817314,-93.463302,-49.546511,-25.46087,6.710998,-2.562997,-45.564316,-30.360747,-31.745341,-104.437426,-124.700457,-29.841043,40.056233,101.219581,110.53586,151.547358,193.251303,177.581239,142.732156,167.279273,264.357918,294.946373,266.377916,175.978481,139.369361,144.077061,187.923262,279.304744,306.327301,326.044871,307.156238,251.409123,257.90614,261.090679,255.587376,245.357537,162.410697,97.037183,24.758894,127.231447,183.54188,186.083975,186.141897,274.961193,323.518194,378.430829,395.358674,398.003807,284.23743,204.526424,188.286926,250.696715,374.198804,408.886954,407.482769,318.001168,267.817412,230.386765,240.071317,314.712415,400.506946,538.673444,498.341185,249.584275,31.70154,-31.539791,-14.224833,47.102761,118.587674,105.293881,55.081096,51.720444,63.912899,131.21039,189.552354,271.658133,277.83851,274.521766,282.482066,305.837649,274.511232,261.04423,313.314085,350.007082,393.672404,411.419574,404.152131,305.361348,250.835438,170.000637,141.978031,133.756506,143.257697,119.379867,80.342844,-14.640148,-121.78311,-166.889225,-191.347961,-176.066457,-95.787205,-52.006745,-50.276061,-157.179253,-236.656541,-353.612441,-320.794472,-76.838467,35.769217,65.101512,13.27374,-43.414793,-38.83776,-45.597293,21.542097,115.309252,304.807375,339.775525,287.443125,264.709518,268.306713,241.37365,240.922308,259.150703,236.203788,143.939276,99.56221,2.169256,-112.964735,-133.566699,-20.251406,64.8097,141.862596,137.128987,66.086713,-64.743503,-95.304636,-24.306011,48.656527,139.660903,138.755013,91.47101,38.408365,-106.574309,-109.222366,-30.655087,130.815454,152.451622,95.992428,66.938649,65.605651,66.771771,42.335585,10.892158,41.863917,201.694509,279.083068,268.920235,180.745324,29.363873,94.752514,142.159183,121.44947,71.632699,-54.930624,-106.222662,-71.409779,89.872375,126.386588,113.382957,134.160928,250.204311,302.279815,351.158012,336.647708,222.615462,124.339284,119.952992,160.695889,192.852726,240.715517,202.362894,-9.434666,-97.632308,-44.3253,56.691906,46.285501,2.46265,34.691432,156.083206,161.617677,73.401841,84.554895,106.088142,31.049644,-41.346518,-113.736401,-116.208817,-108.367097,-63.030364,-27.0014,-14.959456,-51.549107,-135.093693,-142.999777,-118.499525,-142.364279,-240.45477,-241.09673,-216.491505,-145.349455,-72.611776,112.83484,165.241004,119.022797,-65.944675,-180.437361,-298.98408,-270.115981,-226.622331,-270.613879,-373.61848,-399.61138,-411.185018,-333.000001,-308.535886,-320.198502,-291.046873,-175.19951,-152.061,-199.40358,-312.544245,-370.144049,-366.349976,-283.24067,-100.575027,-79.677315,-150.945358,-180.813269,-211.483263,-238.392472,-202.417251,-42.169196,3.542982,-13.605871,-44.10291,-132.48336,-175.949857,-190.51653,-256.4705,-252.477385,-196.253719,-220.172932,-307.637464,-303.239307,-212.432114,-161.624123,-152.174047,-96.947541,-67.944668,-69.094641,-81.744357,-75.61499,-62.703614,-88.847423,-169.804834,-187.03187,-207.796547,-214.022202,-151.008573,-103.694564,-62.433059,-47.780919,-39.106218,-42.584279,-40.746303,-6.826243,-0.313657,-30.167682,-61.505754,-83.018424,-131.953033,-117.507966,-16.438059,24.834523,82.979026,111.386538:-194.047821,-208.103591,-141.862449,34.324076,99.374286,170.599893,175.890255,105.047311,0.89585,-22.547489,-2.435016,29.384774,135.538667,200.507998,236.961109,178.831604,6.696071,-133.084208,-154.575583,-12.231123,126.347966,391.043846,438.362169,269.130956,9.18268,-98.107182,-265.413367,-266.98627,-58.322075,76.220696,165.871346,102.776641,-64.147527,-170.149043,-185.446794,-66.408537,43.327094,205.760808,214.766422,60.462082,-155.052009,-214.869709,-210.16264,-150.240614,-15.191049,17.303779,29.89529,34.706093,38.718255,-24.130167,-82.038815,-121.125754,-48.032462,173.808301,221.092854,129.044696,44.303239,58.826902,91.566181,81.767068,73.573657,110.615706,209.645992,221.367119,178.962336,156.693893,159.444071,200.649529,236.83669,249.551342,205.423617,66.145718,-90.941663,-164.518641,-189.456168,-121.441493,66.174178,148.231158,234.818882,223.025762,102.061073,-90.187216,-150.048871,-62.778388,43.169261,169.162559,143.468968,-50.879593,-225.901338,-264.828317,-270.717484,-227.936026,-42.851652,45.644871,73.015537,28.643353,-62.704487,-85.347736,-42.638526,69.810236,82.536049,72.788487,83.664196,81.100221,-15.416457,-81.846262,-133.582887,-93.217052,58.679097,131.816872,161.683102,92.497372,-94.947889,-173.854219,-177.192999,-136.293364,-88.618555,-1.487178,-7.71551,-82.131448,-72.550018,-47.560396,-20.610997,-5.626682,30.5685,59.329722,171.771584,211.865376,175.328356,87.442293,76.505451,194.8873,295.097416,443.090999,458.916667,358.486105,203.048633,152.266425,170.199936,220.9717,298.754508,335.231704,393.922827,359.793719,152.236754,-1.108224,-4.974418,72.356996,119.441399,148.324322,114.323704,45.875666,89.568202,105.76642,88.792586,103.419761,217.632538,318.153387,521.312624,529.833776,346.06742,202.808578,202.474024,282.414909,337.801855,473.375431,518.153183,422.425475,199.633069,139.246588,198.248207,292.156002,495.308873,576.410335,604.054847,522.001089,221.088655,-92.388344,-175.436293,-76.117178,60.916329,230.781979,216.465506,136.917234,155.123997,165.597398,162.922411,198.170294,319.433706,349.73236,328.253677,292.753718,194.234912,111.625969,116.635268,220.397175,278.982121,342.017925,343.051957,298.343456,192.418018,136.685558,119.56246,142.990067,180.263105,195.478604,150.536038,69.69398,-102.840119,-162.418824,-154.281102,-94.320367,-55.105587,-12.528588,-30.351209,-142.975661,-254.922415,-276.143368,-242.832452,-193.870189,-37.3075,57.889806,139.009226,91.598026,-26.948743,-51.575153,-46.7931,40.303065,133.518347,333.397759,385.125182,345.552471,206.369113,126.147907,58.796322,103.03825,200.751058,196.265522,119.589522,74.900003,-23.672275,-104.209234,-95.071881,64.232663,163.216053,246.195052,217.05298,73.797495,-47.019243,-69.318493,-59.526915,-15.351193,175.128333,268.510796,275.091228,179.833766,-32.826059,-87.651745,-38.266203,136.144991,194.008716,185.607437,144.079574,91.432924,103.741971,90.557909,56.216447,92.196042,266.366664,336.755754,319.541827,254.631128,169.230046,178.613432,163.75791,102.64987,102.459901,146.615403,130.013959,20.601732,19.181479,41.184664,41.141053,55.422179,189.733877,295.618634,470.244264,475.226949,293.268245,86.416019,67.899859,201.201462,286.289773,339.721967,272.226572,4.784977,-164.708423,-144.474282,5.235333,47.08709,32.943537,47.10356,134.485685,131.202023,7.633731,-107.075635,-153.683236,-192.542509,-159.209251,-75.741747,-88.585036,-207.767815,-272.610631,-279.629206,-267.025459,-229.236507,-133.174853,-112.831973,-174.407356,-249.752144,-337.893446,-272.01791,-239.828764,-160.977777,-91.023988,30.525624,50.754235,38.070982,-62.274653,-165.914232,-322.852809,-301.800939,-158.789513,-130.554135,-204.269771,-257.273292,-300.223686,-323.228544,-348.125157,-329.35783,-269.501886,-131.438974,-94.73025,-152.091177,-335.536445,-414.159978,-417.379733,-339.561676,-167.544031,-127.848563,-126.365159,-143.407378,-224.010655,-288.008989,-253.136029,-65.259527,38.173997,146.353188,124.709501,-22.154008,-141.038107,-188.068418,-260.892995,-240.074729,-154.526825,-154.103309,-179.053269,-153.972035,-76.875013,-132.004341,-176.563537,-161.492045,-97.33876,56.046504,79.475154,-49.748767,-221.669094,-262.986448,-270.594191,-246.712813,-180.208365,-144.07563,-62.951198,-36.911606,-70.614671,-170.229441,-179.019115,-82.709275,-12.069555,100.345485,102.085552,-27.507798,-188.050362,-263.132408,-342.439984,-291.491121,-64.017693,25.889933,72.735388,59.769916:-249.499714,-191.225267,-118.251547,53.588352,119.226265,150.298183,126.570028,57.177692,110.035217,188.74953,231.112596,169.559199,63.057601,74.495562,153.549573,148.985034,38.16281,-74.215864,-110.423853,-75.911865,-3.186119,144.047283,184.667707,173.612315,63.619998,-11.279161,-156.04152,-168.570488,-16.668456,84.484351,162.236227,114.69064,-64.393476,-217.216331,-259.649415,-193.911695,-96.380191,53.107131,61.829575,-18.641191,-75.387472,-53.916484,38.7604,74.330238,78.91209,49.828891,-23.144556,-31.257279,13.776147,2.705293,-36.308618,-85.1808,-84.42584,-47.732399,-18.743132,-0.337351,-59.09554,-88.944201,-108.011725,-90.167622,-44.321089,-55.928018,-106.876663,-99.701695,-44.49434,-16.789946,23.490412,153.901697,169.447855,86.325453,69.090883,137.140585,143.614129,92.601366,23.668146,46.09664,140.626664,176.371915,197.285178,193.542971,158.687159,34.751495,-45.956972,-73.487081,19.097614,222.164136,232.701486,77.127687,-118.484615,-175.854168,-161.043917,-129.212032,-155.150368,-186.871806,-162.486677,-126.702728,-83.600291,-48.266543,-23.409831,21.99325,35.994381,77.497042,118.640363,230.774206,299.56327,269.016384,171.370959,183.984735,280.840713,304.567307,327.824814,344.931746,328.691765,178.126167,90.936892,70.107112,112.925974,100.997795,51.163591,-13.668747,-10.735623,-12.180524,-88.678207,-143.471673,-145.113855,-82.076156,58.24247,109.374616,180.359666,181.594051,136.770304,2.738919,-37.253634,2.426128,55.785988,89.427948,-3.527408,-44.949153,-6.797026,75.969254,225.805284,236.686384,203.757557,212.665747,261.725574,253.009177,232.891532,230.173944,235.661061,163.682707,90.185059,44.542649,163.374749,200.208824,228.726614,262.674812,324.409056,335.164672,386.843499,420.657004,405.082588,307.75038,260.040387,200.186229,204.176032,263.929672,278.077884,283.397046,360.403604,392.915287,380.68115,359.466241,393.307375,453.3229,535.400926,518.786512,383.561449,125.386599,-12.949273,-134.245395,-121.142232,-117.070616,-140.810749,-145.118082,-12.944576,82.608964,245.354767,309.049197,405.324635,431.059905,431.969307,417.688886,391.020385,321.988222,268.616697,197.404374,200.156076,265.248692,297.503202,285.416399,193.77511,167.388401,141.632552,112.710792,74.427713,93.505786,109.921444,62.444585,-68.013344,-186.846659,-250.465347,-324.268952,-314.82791,-247.175632,-224.408231,-201.467639,-188.000294,-226.215618,-305.472319,-243.797637,27.871534,116.14016,116.536013,79.48201,63.732613,91.936359,78.379748,74.928265,112.406063,227.746899,291.670204,364.534333,318.173802,282.966961,245.333443,248.399739,265.112653,248.482822,149.881215,85.244302,-23.739488,-94.586946,-157.28068,-280.818426,-262.165656,-89.124523,-37.94766,-101.630679,-119.579656,-67.265049,-4.888766,-17.695158,-31.6117,-11.539157,5.453846,-39.418647,-162.932046,-143.849596,-95.158235,10.032026,70.444858,149.260796,127.90986,19.67685,-40.868031,-69.798513,-124.916391,-124.749038,-82.145617,-53.158497,-29.789669,-53.382476,-135.908272,-198.496114,-194.463559,-151.714422,-165.951044,-233.418623,-229.243887,-178.400056,-196.95618,-212.526202,-127.18025,-15.417413,191.847706,230.481068,198.512005,146.310077,17.502686,-23.986153,-10.85245,31.442531,64.991081,156.317988,176.39871,63.998008,-34.008287,-2.504056,49.850147,29.282168,-9.375935,6.494303,116.843595,183.369028,225.170188,157.753476,128.715622,98.543358,69.22033,-5.597058,-18.060939,11.816911,105.629532,149.79327,133.623064,87.888538,44.807507,70.99585,111.489456,85.781606,50.511866,46.500992,-4.391818,-98.411109,-82.204999,53.602014,122.783758,115.754407,-93.809301,-191.188329,-252.108201,-242.337784,-257.509146,-286.870544,-339.456037,-355.436839,-320.152057,-261.599591,-267.944145,-215.617364,-116.423399,56.187704,52.384602,-77.784104,-141.183189,-152.162781,-244.269808,-309.083502,-360.897654,-335.872811,-232.488934,-190.648259,-205.120074,-281.681205,-281.708421,-153.61798,-61.348048,32.58444,12.908505,-98.437931,-177.123726,-189.047607,-161.049931,-121.318184,-120.912503,-194.124127,-329.549461,-329.082262,-293.876327,-377.941437,-408.861238,-280.054764,-173.110133,-120.239762,-174.910962,-263.464211,-203.181113,-163.599348,-167.782176,-188.64786,-175.190281,-128.166541,-17.000046,17.057755,82.68768,150.875405,168.141162,229.050907,276.554652,312.787639,284.94039,205.465963,185.357037,184.456332,184.693452,206.375087,244.972701,231.489034,194.698799,191.651178:-171.93898,-93.198491,-65.558289,8.338891,66.531086,132.894375,121.600452,54.654058,61.98944,98.036859,104.994322,75.956324,47.610975,47.646864,24.424472,6.654963,5.8832,13.931931,-19.249589,-101.834688,-81.233288,78.315583,140.797806,137.964636,-8.737432,-114.249917,-258.475361,-249.793126,-61.381912,79.41423,194.698955,86.647644,-215.365305,-269.487944,-236.861909,-124.080429,-59.431332,-5.109898,-31.438288,-100.095341,-23.449922,46.737888,107.814897,92.892078,30.411524,-4.949987,-63.606805,-71.668359,-19.815399,5.705373,-29.365359,-88.126067,-74.919173,32.548767,97.998874,108.329986,21.054513,19.824163,78.919714,106.344957,141.958185,142.498345,110.794909,93.445871,33.744416,-45.219277,-27.934027,74.432707,68.192892,-65.632846,-96.115969,-13.391194,28.958165,4.676419,-51.690782,-69.458639,-33.627682,41.517661,181.074645,161.258235,11.700397,-32.854809,-32.002682,-55.013669,-63.565866,-18.113202,23.870497,42.144505,-63.214428,-119.303195,-172.60182,-190.873325,-245.545058,-261.589817,-221.677683,-171.892815,-82.661451,-86.367556,-101.061858,-83.236961,-58.057512,44.207387,131.691031,305.293632,322.077825,257.530825,169.669808,199.250658,270.155357,255.723069,191.002613,191.109712,252.381356,191.70862,117.028448,73.19659,107.495448,112.381873,66.094575,45.163804,161.318805,166.923612,-1.326001,-86.876636,-68.266298,8.498029,115.168682,118.981466,115.306811,110.630724,57.226389,-50.917638,-31.982985,132.794023,201.275921,153.668945,14.796918,9.692318,113.268912,165.787025,218.443934,244.461264,279.076904,266.872702,268.138956,309.190162,281.97262,173.816146,146.411291,147.314859,155.380372,172.607075,213.735173,232.750184,230.229521,222.926116,200.862681,192.305472,245.267137,283.435146,303.523691,251.820173,205.304664,148.427248,162.136937,221.726558,225.281098,210.267994,276.301758,290.558043,216.345205,174.910706,196.273332,268.149257,432.950587,457.163653,347.360762,148.005352,80.417101,99.641201,139.603771,146.388532,114.875776,61.149365,108.281115,157.740829,226.340811,245.023564,305.3047,339.609679,339.498146,309.047767,295.34391,349.002883,362.928392,381.31971,404.666722,461.157038,476.192343,456.409391,298.390684,191.240862,60.393968,41.320878,24.315163,8.358986,-32.216458,-59.602054,-95.960896,-58.760124,-45.319737,-126.57756,-195.682981,-195.693866,-113.851787,29.888588,-74.759574,-197.395426,-317.685573,-266.393863,-89.561635,-16.617203,81.349209,93.069916,71.847709,51.888788,23.657949,-21.189171,7.058127,124.229725,154.809247,146.472256,190.588994,215.458414,175.154899,156.989013,210.01127,229.840773,196.179023,180.622686,156.752614,-5.285656,-118.568967,-194.033929,-142.055307,10.419352,73.525892,94.173541,-14.015287,-49.993555,-6.460786,55.337223,135.464084,125.490302,54.930953,20.65269,-43.769665,-129.778613,-153.646723,-107.952385,-69.169989,-26.843646,-14.940822,-35.068941,-105.802969,-104.095901,-32.819312,-21.066124,-50.560972,-43.245753,10.30491,12.395582,-45.827623,-91.440098,-95.464978,-92.472338,-97.647881,-108.91593,-104.312071,-70.402126,-43.458231,-48.863533,-26.983223,33.949486,182.243742,223.943173,244.576811,228.638515,131.474309,56.701226,76.776726,161.180923,177.27769,158.640885,114.274593,-57.095434,-98.923626,-61.931158,-24.299658,5.80022,123.419778,157.827385,130.649305,99.542409,120.758115,223.671211,216.218457,82.754781,24.571963,-17.040271,-25.551819,-63.840962,-99.603689,-123.881074,-197.64365,-204.617272,-118.787422,-82.758021,-132.339116,-192.904196,-287.425169,-324.25377,-324.969172,-258.221138,-198.850616,-74.168576,-27.125237,-64.374138,-277.205372,-365.531101,-369.206967,-320.421134,-343.18779,-417.54591,-462.268979,-408.508666,-325.148544,-339.792168,-347.174752,-342.888205,-319.354409,-205.67825,-146.767549,-128.598781,-231.6353,-292.97225,-346.650912,-323.997341,-262.220407,-248.968176,-202.573691,-152.330362,-60.73845,-54.788956,-62.879799,-76.546572,-86.785696,-62.209325,-19.204702,15.711812,-6.871826,-9.739846,-59.654528,-98.881121,-179.411404,-233.950485,-330.670837,-349.425479,-328.327848,-237.588947,-186.31515,-115.87985,-106.681876,-101.454591,-59.308389,80.512177,87.402669,11.664277,-120.557059,-114.163338,-75.557816,-84.683303,-99.504877,-80.2124,17.31817,63.301562,52.629114,67.47501,109.541212,203.459991,219.08027,198.651834,214.814406,215.725742,128.299697,81.019755,109.384387,161.822934,207.409726,189.671033:-76.808734,-91.116166,-89.887203,42.518671,133.510079,201.657591,182.826107,143.915437,115.491863,94.584465,88.133861,112.475458,141.37522,142.752679,172.754374,170.1628,53.766161,-51.433935,-55.832813,47.043057,165.887729,395.289782,413.572974,226.837159,11.344419,-52.373188,-146.904149,-162.597538,-83.263982,-16.086911,83.870349,87.131216,-4.283354,-102.879558,-100.502383,41.768848,127.900375,171.780179,140.923001,73.925119,-8.707698,-68.377551,-168.477562,-167.664453,-95.694601,-85.197837,-156.019128,-197.516859,-190.007796,-113.299202,-85.960651,-57.583834,-45.66878,14.60429,62.684796,108.924673,86.690526,72.239489,-36.49648,-116.883233,-161.702716,-114.26469,-24.845074,-8.238014,48.715298,133.069081,146.592364,137.269038,139.906858,121.928033,79.96848,5.88927,29.295078,53.627057,104.677961,124.298299,130.079971,145.671263,250.231569,283.867219,179.722919,-37.221288,-100.715213,-7.015569,93.280394,132.265003,58.325943,-82.175667,-127.191831,-163.236149,-206.911524,-164.650702,-40.207695,-18.067194,-49.469594,-68.864368,-66.477311,-22.610701,2.646797,58.652786,87.615427,102.323101,73.932042,-0.839271,-8.120457,7.58831,50.166586,68.163483,72.828842,81.332442,163.267344,188.296047,101.396567,10.055762,21.083877,52.661156,18.35242,-86.868396,-96.070481,-40.022643,-20.151831,-42.463877,-104.41125,-112.398594,-78.938829,-44.646798,58.36592,110.112905,175.951064,164.229322,158.43266,212.856833,229.692719,196.740212,177.355722,134.675408,117.029574,128.883224,158.39616,178.558576,224.42105,239.601856,267.510021,270.402384,225.631188,213.343673,232.160503,215.806501,158.163606,51.335916,45.746038,77.25425,94.198743,85.885383,73.171044,127.40994,320.40156,377.67378,389.459426,371.434584,329.547946,318.372603,292.970298,211.472665,203.721086,298.207879,349.485684,344.136281,294.049593,289.012664,361.532196,441.060985,558.461428,553.312174,467.027141,408.182524,237.989917,32.542938,-64.949094,-164.804101,-153.625352,-144.886683,-179.04656,-182.558061,2.81792,106.157805,220.65946,231.074877,262.374551,306.115937,338.269948,294.535348,171.730265,130.728116,146.84808,243.415497,291.642169,300.440066,283.496067,284.92424,283.699722,262.605068,218.898214,202.793943,177.150906,172.002218,127.462136,67.916463,-43.611715,-107.185188,-140.04608,-167.906206,-178.107572,-222.538915,-210.24339,-101.942971,-61.551653,-86.981426,-129.878155,-108.493735,8.19517,79.77324,164.089581,132.309773,-40.39991,-96.082774,-39.396819,136.738092,211.407055,306.234842,329.834653,323.014376,298.198817,288.067574,269.529531,274.203789,247.961155,194.961361,64.708523,13.099891,-49.716455,-103.613789,-115.915086,-102.047111,-103.656912,-74.766625,-20.143676,21.50798,-108.842577,-161.010673,-149.402828,-100.616935,10.10978,49.785334,37.62986,-18.450851,-123.282194,-134.059365,-116.48864,-23.719652,47.163058,119.284247,96.28705,2.590868,-42.082888,-46.375452,-76.496789,-85.515794,-9.08507,55.452515,93.23715,67.184601,51.665676,63.061679,28.532768,-84.395516,-124.437399,-146.778841,-144.793033,-159.28172,-180.563644,-166.198021,-57.460547,18.294561,113.141749,133.124114,198.787227,224.282072,147.5496,-17.447819,-39.373993,69.312952,119.963768,105.221908,60.803815,-93.828187,-201.338846,-154.541951,20.062402,59.473638,45.398587,53.393146,90.365583,75.756593,40.865554,19.290871,-20.903661,-90.745585,-92.253981,-89.129234,-120.211713,-211.698702,-141.412444,-62.315208,-8.638861,-36.012754,-61.145865,-19.987042,37.598016,-28.348107,-258.291788,-320.106906,-273.991721,-93.695149,1.366404,83.078226,72.318667,28.120564,-67.060893,-139.490013,-194.912115,-150.231866,-95.849905,-149.198982,-303.88109,-331.948612,-288.348483,-267.06724,-282.708736,-263.088736,-203.909926,-61.546452,-23.946788,-68.01509,-194.827037,-259.849755,-329.917296,-310.19682,-226.991093,-201.92758,-197.894263,-220.35763,-289.664271,-300.348914,-262.652249,-122.493265,-61.003785,-9.549826,-18.550122,-110.393865,-183.769344,-189.199731,-189.847502,-175.324103,-111.791483,-103.449808,-164.851123,-191.621856,-182.53869,-173.524478,-155.506637,-51.080182,-16.058429,-66.038701,-104.197526,-95.316159,-90.19428,-145.805786,-290.730762,-306.967349,-185.91682,-107.762473,-47.172168,-42.479171,20.985074,74.563498,74.369795,106.243749,141.237862,205.662063,223.106786,197.203215,111.467884,41.42773,-75.348056,-57.507601,73.585183,125.345061,204.118176,240.855759:left
-141.361241,-169.162251,-183.716662,-200.420256,-211.696087,-254.227106,-281.43544,-342.803624,-310.715312,-250.186646,-130.47375,-99.880744,-137.856046,-174.900906,-214.229942,-238.837184,-266.800025,-149.334687,-37.061922,188.034324,237.299513,206.281537,176.084859,130.493686,113.927892,131.893889,201.210068,234.788217,207.043982,133.870898,-32.766546,-75.775842,3.537217,118.55054,95.454745,-15.123691,-30.122184,29.639146,37.18458,-37.074707,-36.516011,-28.424638,-72.375057,-82.217221,-13.5142,45.031366,121.020635,124.941828,104.587627,80.899002,100.40402,241.529346,304.603077,275.903409,193.612932,0.959715,-110.045191,-138.156632,-164.028634,-140.142158,-35.572026,12.463826,27.131798,-18.689772,-74.090184,104.83921,226.141529,318.023571,268.035573,80.949555,-7.001031,-110.587843,-91.868215,-36.799302,96.334585,147.45846,185.668944,157.726262,24.501517,-29.053607,37.32259,203.939529,238.995428,254.856653,245.341763,167.699785,131.299047,134.550737,229.889949,273.317378,279.11487,259.570803,230.851405,230.401548,207.842792,161.920815,57.206785,20.234988,37.573695,80.546759,50.966109,-39.40608,-42.480266,-61.315484,-107.108474,-66.92147,83.067366,114.592936,37.113614,-33.803736,-194.609245,-276.333446,-328.344746,-210.60979,-138.452587,-54.605991,-65.048656,-101.608639,-66.701911,93.108473,233.497682,271.773172,332.530224,382.106299,457.485592,437.588459,316.37008,267.138971,264.389793,317.041147,289.588326,68.588269,-67.763954,-194.050624,-184.201851,-197.980285,-246.366308,-223.210115,-142.265256,-134.774927,-174.411684,-187.793804,-177.841675,-155.393005,-59.680725,64.739551,116.734979,152.735088,122.681111,62.437457,49.03015,-50.211557,-182.261844,-184.522444,-49.377534,28.516272,24.629094,-37.388466,-135.411213,-181.117469,-257.271826,-214.545386,-181.863268,-179.237992,-189.154546,-176.278477,-173.58099,-194.007091,-168.075856,-162.945038,-194.442462,-187.882797,-129.416646,-109.370514,-119.558056,-146.39483,-134.216658,-48.455451,-30.33516,-30.720594,-50.454525,-140.917294,-200.857575,-266.644414,-142.890172,-45.587062,35.614666,14.633501,-32.315496,-38.279072,-78.888227,-117.829729,-127.961507,-61.417009,-33.473144,24.871733,44.330739,53.940201,45.542169,-92.721121,-236.034271,-189.371394,2.315314,27.738899,-78.939041,-122.828765,-123.711541,-145.413225,-227.555093,-91.471193,34.33511,143.09701,100.17461,-31.911351,-53.901021,-13.639949,54.063005,99.326531,223.038172,284.552325,298.549287,249.666455,136.584566,83.593774,14.112604,62.335194,122.331609,195.843705,161.21492,-12.352197,-86.291047,-116.752531,-29.267239,20.852394,72.133665,88.581119,153.568733,184.790103,202.17669,187.623525,122.686616,46.149581,22.899958,-37.355989,-115.57404,-286.425784,-307.599866,-252.85959,-225.538316,-208.520474,-106.668925,-40.179828,27.514746,7.527115,-95.07274,-125.839261,-35.677012,135.152297,207.03405,356.925763,392.970284,341.484674,300.622873,215.372689,182.165148,219.254163,329.507415,333.89945,177.49977,100.010689,103.253271,123.948534,77.376367,65.728127,122.827003,253.952158,267.665315,169.1522,87.331536,-31.005545,16.811654,66.592104,134.979974,159.667378,162.268047,134.312932,25.41436,-63.734808,-222.35724,-173.46127,-80.020339,95.487306,134.966207,120.544746,74.407792,-72.879309,-99.904706,-42.79245,101.817728,165.150052,232.481057,217.066478,82.3813,-12.527741,-112.43494,-31.748671,23.385256,76.418044,56.771474,-25.059163,-39.596868,27.390242,140.962816,164.58955,124.666361,99.89868,71.435905,48.326875,-22.401874,-62.889916,-74.258118,47.989726,108.447282,169.566772,155.213,44.240792,9.059497,91.180719,214.781832,200.120392,84.12885,55.531994,9.329798,-50.192645,-154.687252,-156.742676,-64.172377,102.998946,166.922293,155.312571,89.211825,-36.923935,-64.400374,-64.547096,-39.103084,-47.449202,-81.693357,-71.680378,-57.308933,-83.500068,-136.589735,-140.238337,-114.766697,-66.105851,-18.732337,127.09767,181.917366,151.826306,94.660316,39.889596,127.933687,207.658107,357.361724,392.339572,359.750807,321.707107,213.893403,124.498138,-29.160931,-0.356814,55.79634,145.097443,164.005043,180.259709,181.170534,144.491849,96.533567,70.09341,18.209153,22.351397,91.283755,117.086771,43.043232,-40.385784,-118.71866,-43.948989,28.582899,257.220946,362.306345,410.676617,365.774747,253.352508,254.520673,286.29568,335.193075,352.561263,304.14926,236.450051,111.298699,63.876348:10.8333,22.087342,-38.678376,-103.546978,-86.624414,-101.146544,-166.621656,-299.962972,-286.784916,-252.153089,-194.91595,-181.867561,-212.216785,-238.091072,-266.35493,-267.835943,-233.905148,-128.584333,-55.597045,106.16122,162.413794,128.565298,61.347437,-2.433339,60.114318,96.870441,151.008754,161.983875,83.64442,-0.129944,-126.485229,-123.867436,-6.324908,93.009606,102.272253,87.88344,85.38869,105.828889,113.243956,91.769959,91.162261,108.882606,155.927828,173.972142,178.030948,165.208478,104.929174,73.404284,57.378705,104.045676,157.983683,282.15638,299.392851,206.713824,136.22,22.572678,4.541671,23.878501,50.728148,48.282624,-2.360632,-51.615515,-147.993471,-172.998122,-173.312046,-101.53167,-23.509567,152.937838,184.440784,95.59102,23.231551,-61.679447,-65.67478,-62.274404,-74.407799,-90.863102,-104.782399,-99.753311,-143.830624,-188.406062,-182.530593,-52.750433,19.513641,137.400842,155.435427,116.010533,89.544018,39.207513,29.030921,47.327812,47.765539,9.902897,-44.242236,-0.491026,128.339028,117.080354,11.437701,-2.8802,-8.439648,-4.503089,4.609131,-60.43011,-115.427995,-158.222424,-106.304443,-69.789579,-23.183096,-35.500106,-149.90523,-223.076299,-363.470723,-432.829264,-495.111748,-384.592811,-309.716621,-222.106445,-206.730472,-144.052285,-86.515781,-2.799417,28.83768,50.518497,128.140113,185.080313,249.087618,199.923438,-19.206371,-83.039817,-12.402175,67.882795,54.829299,7.338776,-0.600655,-22.105576,-62.956631,-178.318166,-184.99092,-115.006513,7.171736,-23.734772,-185.825064,-224.928827,-228.249669,-241.857376,-228.477971,-77.928129,8.201105,80.569541,50.008478,-72.885205,-155.01335,-349.08876,-395.331864,-331.290495,-137.346576,-80.366293,-186.358051,-293.889097,-412.599343,-429.315359,-407.400677,-328.456962,-300.13933,-274.380382,-270.017026,-309.059568,-352.50456,-433.263463,-442.068269,-404.733589,-285.944622,-235.145826,-166.579439,-142.435884,-168.705657,-212.390461,-217.898648,-139.686628,-124.786978,-135.450232,-160.357501,-272.125088,-316.620804,-270.198354,-167.081762,-137.155661,-77.994231,-64.133102,-114.469557,-136.234191,-124.479711,-131.670904,-165.721662,-124.779464,-75.229298,0.861131,-12.02227,-91.097531,-119.480168,-188.29127,-197.493654,-136.861592,-10.554369,-0.775106,-70.54366,-118.643321,-201.960178,-218.237975,-163.941417,21.638705,129.321319,179.660263,107.842007,-19.902427,-18.566083,50.799733,142.246256,186.817956,253.392193,286.641424,353.100688,355.729652,222.179669,115.875119,19.931178,132.693254,211.36978,263.064295,198.994635,-15.939295,-95.878656,-153.13218,-120.118792,-99.263882,-77.977318,-62.334043,-53.028487,-73.324485,-118.979291,-138.571635,-153.948577,-133.842912,-141.76703,-236.487021,-307.783281,-364.982715,-330.51944,-267.407671,-294.662085,-304.746427,-267.931685,-241.882984,-224.172745,-233.647579,-281.776705,-287.075671,-158.119125,78.397154,190.655485,346.192273,356.679316,281.546555,242.722968,211.508924,232.447165,246.63495,279.38008,295.231404,282.866928,265.461952,269.424988,272.053568,231.803727,235.467389,292.022889,409.747206,402.178501,287.83519,234.04482,173.727226,198.011927,254.765305,398.225053,430.686836,342.815085,245.931219,59.197287,-11.255799,-111.232545,-54.038422,73.828538,307.142896,304.134094,191.583664,174.204957,152.687869,146.311577,183.576329,280.411906,312.258588,284.336502,224.901016,119.033363,100.384369,85.888368,52.257043,66.905829,165.214082,191.374161,157.559888,124.79626,98.352524,210.863146,274.337636,255.834381,204.02912,194.326124,245.420551,267.539355,187.195158,71.548349,229.700193,312.951323,300.59964,232.023034,129.740266,132.789324,244.403763,310.566604,258.357117,138.378007,138.603071,140.549039,99.771865,18.784381,4.523806,38.377255,185.167122,270.871802,306.394584,246.810713,132.994559,110.921734,86.780962,92.620112,113.571242,184.983589,215.025913,201.052774,163.682885,76.909918,34.978383,1.507747,68.918682,109.395262,181.779326,212.606423,206.156057,175.994184,181.616924,266.615566,308.562236,404.549759,436.533285,368.906307,286.982903,161.821745,129.349468,102.277742,105.976369,113.4473,172.729815,222.822878,292.42547,290.133282,226.07918,161.483298,166.361488,265.88896,312.979659,282.166076,224.909944,102.268224,24.453691,-70.5094,75.330619,179.773131,344.882006,402.89263,423.894006,385.076533,300.592663,271.891305,281.206784,368.804578,409.530843,383.444884,343.488535,254.121907,187.009535:-16.99815,-15.535935,-18.444686,21.06497,6.061563,-139.482648,-218.965397,-294.536717,-241.932483,-195.467979,-146.400205,-172.980602,-280.169077,-289.537285,-233.878356,-230.362156,-221.357427,-91.10607,-12.12202,84.644649,80.053462,-26.699411,-85.020105,-98.101185,-31.299816,-18.11168,-3.350493,21.489791,20.309108,-40.747098,-161.668866,-151.581833,-20.25433,60.629017,66.322453,28.274401,-5.709407,-50.856645,-56.492236,3.151406,140.147908,181.858596,201.736964,200.425274,201.344627,202.617666,149.320227,101.343154,50.82241,74.924959,109.479364,210.554776,237.918441,167.920316,96.783297,5.752305,32.016834,50.259541,52.669871,43.802254,-25.01844,-64.325248,-98.741707,-113.737307,-128.501545,-60.22853,-6.979579,27.483028,9.663566,13.68287,22.544374,-44.050313,-137.421856,-155.831451,-136.05478,-128.219328,-201.22406,-266.999424,-332.242435,-300.185755,-185.345319,-92.041131,-23.865285,76.058258,55.478136,-28.559258,-39.400914,-41.759849,-53.559848,-33.715155,33.40333,24.962456,-49.17206,-48.036174,-32.068162,-61.334222,-66.788713,26.196691,46.992193,17.547285,-24.296445,-110.592341,-132.167908,-141.368235,-102.850047,-78.621675,-68.620868,-91.696836,-199.645522,-270.74423,-410.747143,-456.440516,-437.177055,-309.710355,-251.071572,-189.414485,-185.686779,-226.55627,-243.472747,-129.221769,74.020376,105.119726,87.816915,102.087725,147.19765,119.817354,-26.854094,-70.861302,-38.685196,27.84495,76.997361,166.590505,152.703115,38.535885,-5.094468,0.6484,83.324025,119.896303,139.320861,120.854422,37.785241,-26.710937,-181.266179,-238.144122,-245.094058,-219.004305,-205.973047,-133.066868,-122.166677,-245.507134,-330.436019,-398.469723,-312.937505,-241.859644,-125.821422,-112.744381,-213.91384,-287.901127,-361.033035,-353.057054,-311.167418,-296.972455,-286.53383,-232.787295,-208.919061,-244.585899,-306.220093,-419.394309,-449.214778,-433.560369,-309.153092,-209.85816,-49.163131,-22.746725,-85.856357,-132.782053,-129.972124,-99.592528,-132.318148,-196.697718,-188.457777,-201.098248,-250.45831,-312.086648,-257.129537,-206.06052,-42.114667,40.814347,35.644824,-38.740179,-125.711601,-115.239396,-44.073674,60.614101,101.403975,104.8762,71.361471,-14.00369,-57.454787,-128.796695,-124.887663,-94.632118,-27.041363,-22.172324,-56.719275,-61.524574,-56.543322,-57.07104,-29.182961,107.644227,198.186596,291.517748,274.712143,136.220547,52.915605,5.426603,114.608215,163.543061,203.731844,212.075378,239.291989,258.927986,231.673346,168.688772,77.173983,147.056383,211.862757,259.789454,203.6936,-18.727596,-123.605438,-182.114314,-51.057074,1.333178,13.859342,15.060699,10.175447,-15.33861,-82.634505,-109.451124,-124.834226,-95.879828,-88.435264,-134.340764,-175.93828,-228.429779,-240.360396,-281.494357,-295.06101,-264.305373,-173.819837,-147.627605,-192.441596,-238.460767,-250.684779,-216.964014,-136.627346,-41.015881,25.494277,165.989501,182.678492,73.093065,13.826388,-4.454734,112.329217,200.571125,367.899619,425.260302,403.611466,338.390445,282.193674,312.84825,356.216658,330.999213,347.884739,398.606987,377.076644,305.005203,297.625414,291.333492,304.744029,343.855159,418.29215,412.390974,343.630434,328.154065,303.929622,265.067359,169.213809,128.827044,156.812745,241.345959,250.819346,226.24918,211.349198,169.480423,123.621392,134.405119,258.899488,329.562376,353.60294,306.263589,198.539578,163.906658,115.671457,86.317356,95.120828,121.593447,89.895527,-47.77638,-98.178834,-106.446214,-26.434183,14.180877,73.614616,106.520383,144.642286,134.540499,51.245387,-7.000923,-9.053826,142.914153,184.700719,128.091222,70.985141,27.755439,50.467079,138.989398,200.277671,175.462669,59.074643,0.794367,-108.824575,-128.958906,-68.609137,-25.966961,67.314919,205.958935,263.618573,287.467157,257.239695,157.676629,100.146395,60.665725,125.981454,150.548813,206.361873,227.531801,163.637761,97.564478,-11.146458,-39.451481,9.353953,115.10953,131.553073,132.767113,149.88709,175.405211,140.87164,67.730271,201.310607,305.139972,410.944672,389.556246,280.03922,246.363877,225.262995,219.138977,246.457442,275.32179,278.943022,325.246408,347.208067,302.493759,253.320812,191.280479,197.503444,224.791366,298.481035,310.892431,271.356524,246.448673,173.405376,127.095726,127.60222,209.410476,241.953207,309.481454,337.305257,374.400211,367.349202,275.818132,213.034487,227.498136,302.490954,317.394425,305.642198,302.38794,231.783189,170.582094:-91.388787,-55.748937,-56.010974,-82.500616,-110.973674,-194.300846,-238.179796,-299.50176,-278.819722,-254.010301,-209.339788,-200.836447,-219.049134,-205.381387,-150.116651,-161.545024,-196.561493,-77.1108,33.261617,215.989112,206.680879,34.671264,-10.242826,62.729672,133.50563,123.495268,112.498379,132.425232,83.08206,0.873078,-116.087545,-124.116995,-107.218669,-99.513399,-94.042055,-94.954356,-119.427023,-183.826762,-189.991254,-138.681316,-76.196531,-65.430462,-50.170991,-28.617074,48.18398,95.130873,138.927852,122.761947,106.617935,167.4443,207.643017,296.569266,331.118612,324.26214,264.74024,88.04072,44.800319,55.161283,27.669639,21.857974,26.232558,-3.703512,-113.874343,-149.905819,-107.021178,69.26625,136.512629,103.244496,47.875639,14.114496,12.197867,-54.882956,-104.477585,-102.649411,-113.557922,-129.561082,-142.995712,-137.339718,-134.756118,-150.659639,-132.064857,40.922158,139.637104,224.080678,200.905994,145.654718,139.11051,104.191681,125.800445,181.661464,250.567378,228.824827,133.284039,115.583055,146.85618,150.196914,122.1712,122.712399,141.593817,142.060337,95.657101,-8.04563,-31.643496,-73.417334,-82.811066,-45.343193,37.943488,31.946898,-96.08044,-176.703659,-303.08334,-351.326286,-366.316497,-258.452293,-204.676741,-138.365835,-125.033337,-106.7148,-74.143554,44.577452,133.066351,159.720914,257.09693,324.103059,364.390137,317.51914,218.360616,202.421644,177.519389,137.147608,135.914905,139.697644,111.228359,-11.795711,-80.430283,-147.39856,-107.670382,-70.968247,-18.316802,-28.114765,-123.528655,-181.858044,-280.188671,-310.461037,-246.739001,-63.971682,-4.630379,26.242087,9.566918,-101.680117,-175.600298,-258.7768,-213.332187,-162.153758,-30.567865,20.079105,-20.263913,-86.910443,-210.367665,-262.344074,-277.103934,-187.321939,-161.486132,-137.362419,-124.807782,-131.013754,-157.416892,-245.780444,-312.786934,-304.208468,-217.467708,-172.695763,-103.176805,-59.187285,-15.713251,-51.260035,-105.996852,-39.791227,-16.718855,-54.785586,-98.662662,-154.535279,-170.110704,-204.917636,-167.837121,-132.914102,-71.883049,-25.357711,76.610438,87.044789,-12.113329,-76.028077,-104.691801,-58.614872,-42.199014,29.314226,82.002447,146.274592,124.60645,-51.473939,-159.880332,-122.291311,2.566773,21.584138,-82.820258,-161.78381,-210.697215,-175.683723,-103.332367,-11.506923,62.495331,135.972982,122.387313,116.517272,128.181663,100.571318,90.445378,128.091972,242.830305,293.931959,334.557831,316.371224,187.694651,97.765843,35.269461,132.950912,173.252293,188.913319,156.513746,31.804681,-23.103686,-55.731391,23.106849,66.727422,66.035738,47.996507,81.719134,120.627072,122.493181,73.772708,2.322022,21.577373,3.209805,-148.20352,-228.432953,-264.748526,-250.825861,-280.061646,-302.246751,-269.378734,-142.26081,-80.697403,-55.70901,-102.716576,-223.552476,-243.681024,-168.611073,-19.117337,69.017275,242.496405,278.851628,203.36519,146.624565,104.672147,176.869211,260.61153,429.375426,445.317896,325.205659,274.766191,295.287079,301.094256,220.531308,205.878146,252.597475,323.800476,316.472916,272.215151,236.286118,111.919483,103.964367,168.18927,304.581271,349.526743,325.650531,242.765219,72.384948,34.467905,-3.707457,-25.407182,17.423648,151.058928,162.430536,69.499364,18.870806,-29.771332,-39.326729,-37.484681,39.326743,106.454456,173.957842,168.552772,107.504465,33.216887,-107.272818,-62.914035,-19.83422,-33.537466,-83.117723,-143.98897,-141.454878,-124.1418,-30.494233,14.919705,-12.914924,-33.314625,-13.733055,-22.771639,-128.11446,-186.718525,-187.554518,-21.369329,51.107199,42.949746,-5.771312,-50.705,-41.314146,24.645749,96.623274,85.915878,40.126402,49.69172,46.408545,-0.475476,-112.579026,-134.637943,-41.216715,144.334172,184.537054,113.789366,60.095508,39.405083,42.451093,-16.341182,-62.567456,-56.042933,20.896597,74.817745,99.838475,73.570264,13.049357,-28.216739,-86.586015,-54.247027,-26.365881,79.28104,138.415592,131.456601,72.220403,21.555502,145.063457,230.588441,400.817903,460.619737,400.658794,304.884181,173.680726,141.360425,99.385408,136.186542,178.791491,246.685778,258.722829,280.796701,294.792173,256.008181,150.109335,117.422049,143.353523,183.694906,210.769664,183.572584,90.039676,48.523907,34.797315,110.782473,180.121565,347.776821,410.147711,453.472395,431.276052,306.779463,212.386108,227.105095,348.699125,396.13873,371.288128,340.323293,289.962151,233.021534:-98.403377,-31.609471,-22.397035,-102.472899,-163.265347,-271.073577,-316.898601,-358.900191,-329.0368,-303.021055,-254.407572,-249.002847,-229.764454,-183.269452,-152.515443,-198.033257,-193.420241,-46.029864,10.021753,79.639804,88.118848,7.10743,-58.536155,-112.650086,-59.258622,-24.090475,76.130966,116.567308,53.658223,-20.239528,-105.874929,-109.026266,-65.881726,-40.408466,-50.083527,-105.854868,-144.925954,-230.96033,-275.491398,-280.263472,-110.043065,-19.044501,63.357892,62.292516,58.674291,79.796095,121.35145,122.24593,156.529092,275.352781,328.187247,330.685958,269.256234,121.965057,76.958174,28.871055,38.595438,64.533741,137.303535,161.382946,100.800959,35.156546,-79.673751,-112.304826,-62.57529,87.850194,128.319727,82.844532,26.376424,-43.873215,-56.435023,-99.055411,-144.760908,-146.05027,-84.192971,-64.837848,-173.558243,-269.429764,-343.360413,-301.975973,-134.414315,101.856211,200.480414,217.311653,151.63522,57.276585,45.486393,30.115453,66.942533,107.409373,136.881704,102.08384,18.747112,17.914684,50.578968,52.691351,65.399266,86.741344,106.079442,137.342944,89.144489,-95.886716,-157.157428,-172.17843,-113.00554,-72.677913,-9.6519,-21.919348,-181.484593,-283.865829,-414.778703,-447.273386,-414.81473,-198.098684,-80.175767,22.450826,4.669293,-70.01635,-93.660346,-65.337852,22.012518,60.819212,142.908943,177.858792,199.179807,183.460437,124.884322,102.882422,80.527612,99.78297,151.578383,211.952074,165.011685,20.843141,-24.208045,-52.119784,-55.56177,-36.667377,50.485808,64.449507,-70.820713,-181.118657,-335.829725,-352.644296,-281.848797,-221.326891,-220.003796,-205.030022,-195.979816,-253.546707,-301.798192,-302.319776,-169.121664,-95.711094,16.511656,23.684044,-112.445921,-196.063817,-251.435781,-229.993172,-156.016111,-141.46648,-140.550719,-106.226453,-107.576992,-196.202989,-272.607949,-426.278976,-389.680642,-295.718871,-144.152087,-121.397229,-125.284103,-122.183982,-122.784725,-132.447867,-85.00954,10.653398,10.153687,-71.766642,-104.569832,-123.191025,-143.859486,-205.008798,-150.980783,-99.174872,-1.857209,54.520513,111.733587,71.014563,-92.003999,-137.935167,-63.054168,101.706749,155.8395,189.240995,176.9099,153.937638,131.792768,-18.52687,-84.049468,-20.169028,125.073834,125.981907,6.480597,-46.117408,-104.73839,-124.617764,-94.529075,71.081834,168.80778,212.441259,145.165322,30.799459,29.425186,62.711537,87.195452,121.138028,237.764547,269.616636,250.444696,246.729266,205.02473,125.679561,1.365512,84.312124,156.754125,233.753789,209.990517,53.826713,-22.830872,-35.61559,99.116434,151.836904,139.256744,94.098265,24.339726,8.244693,-26.119378,-31.544059,59.959145,153.689102,136.316067,46.29018,-4.067664,-134.303093,-204.758406,-302.479028,-246.929274,-161.213246,8.541145,45.86635,-6.71116,-76.087178,-205.377541,-216.952229,-115.619106,-17.294618,4.826581,35.636262,38.712277,22.225746,24.777345,62.926761,193.806683,296.558612,445.303135,447.715197,339.401212,279.222487,211.44236,202.291863,239.535835,310.296545,331.000182,294.940599,245.683518,163.778806,138.847329,90.772955,89.836308,126.16708,235.671345,271.123703,226.687504,169.046797,66.102109,32.026595,29.247035,105.680144,155.507435,195.645966,148.604777,-4.159703,-41.571659,-24.967931,0.181634,32.672507,180.934271,250.061067,242.953094,167.900785,-23.028688,-87.514748,-89.476288,-13.476026,24.92845,51.207286,-10.52539,-239.442128,-305.191128,-238.800239,-106.518871,-70.491094,-41.889192,-45.13557,-50.241534,-41.858937,-106.442878,-183.021626,-219.86818,15.267717,139.902969,179.695529,122.103528,57.536767,60.637625,86.313431,136.311791,134.645481,84.103389,62.653288,-20.327262,-79.514202,-114.234686,-67.637722,95.482467,239.722725,299.122589,338.171306,293.681057,192.321292,154.853399,62.35256,71.366723,114.513123,174.64237,176.181304,125.463931,95.769277,39.731924,-2.453908,-36.469411,83.118198,149.369552,177.041284,146.965975,77.118656,42.200874,4.506721,103.130524,204.420552,441.947956,513.395323,427.237579,316.295189,173.019333,147.931817,134.437828,210.8315,284.11501,342.229656,279.789734,94.005548,49.096608,89.098972,178.454224,220.91766,288.084817,288.799009,214.607451,159.109869,29.044178,-13.890278,31.42809,153.459087,194.512648,220.720116,226.761326,273.532156,265.20621,94.908523,-22.726412,28.475638,276.014043,368.448385,333.430331,239.878394,44.93337,-0.995132:-40.422558,-90.875468,-114.854313,-141.215153,-168.892653,-260.171166,-286.48221,-301.453448,-267.725046,-216.012102,-134.348587,-129.586322,-148.741692,-138.617884,-80.822541,-62.21581,-38.138751,25.084058,85.561894,222.851525,243.966457,168.609443,129.711014,99.757328,54.503971,47.884193,127.527556,170.320118,116.661367,53.211812,13.793123,22.419167,-4.72297,-67.552768,-89.444784,-141.068879,-200.6744,-314.130374,-298.786023,-200.421483,-239.700491,-286.038582,-293.873039,-225.861122,-4.341416,86.417873,122.917134,80.737004,-3.275112,40.546752,125.74324,303.266997,332.942017,258.709839,177.307856,19.238412,-0.532309,4.449077,-81.471758,-127.214117,-85.621202,-20.140073,66.586981,63.377686,42.047654,148.472401,208.414254,160.967364,73.659777,-33.730773,-46.37186,-86.602274,-83.40737,-55.878061,-49.288951,-65.038771,-53.332392,-41.161504,-49.442631,-44.092704,69.867191,245.176413,291.48454,276.379835,250.553647,263.586196,296.512568,300.666603,256.229843,249.680877,244.526739,250.409668,276.865213,279.977819,238.531163,186.568244,76.461426,119.629394,193.581077,236.67804,159.801645,44.308305,85.96614,184.706623,152.510549,153.953384,253.573496,288.399945,182.151082,81.292701,-35.361871,-65.743063,-124.601436,-104.392955,-69.763551,32.987634,87.444916,137.705606,139.978905,139.87648,172.951544,225.972084,404.134625,476.494325,465.072269,409.024598,317.620864,288.64522,258.830773,241.014085,210.119457,83.2362,-11.198766,-194.831942,-240.757488,-251.57898,-251.24267,-233.735554,-165.428698,-152.189905,-214.228786,-260.72007,-288.813528,-273.449213,-225.941393,-160.209278,-112.673109,-23.357945,-14.419506,-20.959321,-11.997487,-49.875121,-129.962612,-130.699825,-23.346946,64.068259,152.67848,113.786972,-52.752362,-117.020915,-104.029474,16.082528,49.083087,15.5782,-27.795226,-78.928838,-81.791521,-84.901737,-90.115994,-106.0696,-145.791234,-143.080545,-119.218959,-106.400988,-76.225828,-78.131427,-68.091214,14.477506,41.188216,13.823313,-28.41958,-82.420365,-74.684373,-65.07651,-88.943358,-72.55139,34.149223,93.447349,127.220405,93.809893,-6.734293,-46.154309,-65.697339,-31.988369,-12.270036,62.892993,96.728846,70.187482,14.334182,-113.83557,-141.270844,-101.714528,-35.657882,-66.024828,-220.563714,-279.291952,-292.567231,-273.068044,-211.879236,-48.898133,39.368799,39.901447,-41.3455,-124.344421,-83.488219,0.822901,-30.782924,-36.672415,52.415157,114.907435,115.410144,48.86918,-86.397615,-133.405106,-149.570786,22.926989,129.751094,168.178224,92.005653,-69.751766,-112.295693,-124.416033,-25.4243,32.394971,110.844959,155.850192,248.58612,262.692542,220.001366,194.892954,180.105148,158.62068,135.190144,91.149825,57.223553,-62.353361,-127.951255,-225.598814,-234.395281,-204.589838,-83.641551,9.504271,139.422681,104.828403,-87.232232,-150.667713,-117.44385,26.27922,81.311703,134.829582,137.75126,85.674521,49.504996,12.941849,71.410658,124.095588,194.271983,198.656105,127.388215,76.703686,38.85066,28.337584,-50.440442,-83.123909,-60.8248,-31.125914,-25.923669,-20.437519,-50.278006,-140.661476,-84.268538,-12.358051,126.482506,164.059876,91.774277,7.268669,-102.424905,-120.055082,-160.964263,-186.481603,-153.638381,-47.033091,-37.430304,-104.643925,-139.95554,-196.762615,-155.71089,-82.975794,70.018678,104.35492,38.969417,-30.463922,-140.446702,-170.315159,-173.296234,-134.485673,-125.812909,-83.691493,-48.802191,-38.587351,-68.223992,-114.512566,-91.29738,-78.693812,-75.576208,-67.857144,-70.088795,-103.061596,-199.287273,-246.265634,-273.018459,-153.121472,-74.74164,30.656952,46.575821,22.570561,9.049547,78.250802,208.515162,211.70246,147.43313,138.458831,83.828823,19.3725,-38.312491,-22.143786,25.517348,97.685088,136.501239,170.04145,156.619552,106.239925,79.980402,37.364576,0.226108,-27.768116,-19.079181,12.856074,-3.371839,-45.257665,-94.626333,-100.059203,-91.654295,-49.53684,-24.53619,22.765486,36.649888,27.018128,9.387847,-5.657414,95.091683,187.093027,361.945468,405.758764,369.126115,305.637115,118.788791,16.973367,-48.407917,54.798043,82.067398,40.20065,7.425004,60.672614,146.224156,250.755118,199.968504,169.746217,166.890462,165.790507,117.33537,97.680077,77.970846,47.981563,-31.116523,25.342345,122.758464,361.299791,450.263119,485.043853,438.820097,283.071689,169.250329,170.065949,292.987991,366.465847,329.794291,224.549685,41.705943,7.960442:-119.319906,-61.797315,-84.600162,-146.812952,-180.923863,-306.873486,-373.371642,-381.493448,-262.400168,-223.754005,-175.565094,-148.595949,-153.858805,-191.326526,-279.146444,-292.998383,-171.250387,39.893271,120.969687,198.166637,173.37013,31.620064,-33.125191,-78.283148,-1.914023,53.10621,122.524992,125.780068,46.561053,-11.207912,-77.831215,-75.521147,-28.522734,-37.119856,-69.667129,-172.247122,-244.64211,-375.823211,-399.43121,-351.061769,-250.785256,-210.154709,-141.822859,-92.837088,19.53746,59.189537,85.044538,82.752428,127.22268,240.012613,294.405891,376.027651,390.625486,323.256387,244.184642,94.187303,89.147274,105.887795,77.111963,48.482122,-15.104185,-51.018137,-76.637729,-66.381304,-8.628502,117.383204,179.411934,209.642801,155.149476,-13.395952,-75.963263,-135.548838,-125.06787,-115.768804,-128.284541,-141.320418,-158.055868,-157.770969,-171.511988,-174.709487,-33.019693,239.045692,316.020239,293.124918,245.927606,204.082392,204.916759,176.116371,157.969646,190.772438,298.228034,326.974041,279.67687,233.386283,170.840456,146.824261,113.660454,174.963935,234.858873,271.231988,217.97989,81.390257,41.13465,7.142904,26.312583,55.643237,118.403102,124.221492,20.547047,-60.971894,-196.409819,-256.42218,-300.537892,-153.776351,-39.97808,131.017632,133.687381,4.393421,-59.634509,-58.1877,59.162221,108.43121,231.868377,306.464634,344.991407,289.895146,158.065552,125.026273,118.360532,142.102807,146.193627,103.628678,43.003394,-127.722343,-198.084236,-256.316035,-225.052227,-199.438822,-155.136081,-130.143847,-117.332277,-157.520356,-304.838892,-352.225568,-264.550911,-77.643316,-27.464947,-30.623083,-61.868967,-123.310637,-150.731919,-182.421828,-115.13288,-49.915895,91.07222,134.824973,105.832014,47.789673,-88.048099,-135.289733,-86.72509,27.849964,32.476361,25.281568,15.087486,-105.704322,-177.43278,-215.695583,-153.926019,-119.664338,-54.0844,-23.758731,-5.891918,-19.782974,-69.765166,-93.461791,-51.609902,73.187462,107.033982,74.684456,17.318967,-99.632109,-129.752102,-128.972088,-82.340296,-62.077007,14.910707,81.640992,144.398755,96.105712,-93.495475,-160.777206,-106.735652,70.248562,132.382019,187.727281,175.748557,82.587355,30.917238,-36.832321,-30.866825,-2.679572,71.309453,78.349071,-62.116218,-177.146345,-331.878043,-338.99505,-222.804251,-39.762309,44.321396,102.125771,45.268431,-120.467607,-162.356914,-130.556199,-18.594551,31.06646,122.968204,161.827778,164.009282,135.652102,69.03247,26.991941,-25.722067,52.983208,128.032367,207.695531,157.463018,-59.038949,-145.246091,-183.688271,-79.205324,5.799906,136.520458,152.084399,154.842374,166.719701,133.214172,81.059568,39.023875,127.733301,174.037564,135.071212,32.471237,-204.852694,-286.92808,-369.314225,-319.294182,-222.705352,68.090955,192.028086,217.336223,105.646144,-202.381984,-289.636911,-194.9063,-9.373644,24.386606,62.142021,69.118721,-26.885791,-97.449512,-107.752956,124.930182,271.622243,440.584928,434.939335,286.797321,186.094495,31.237969,4.169889,30.943762,93.223418,127.295746,160.60226,149.917671,82.010577,14.941223,-139.984796,-106.31851,-19.017159,166.853251,226.306933,190.742648,102.823681,-102.733232,-184.315868,-223.467203,-97.064434,-20.079488,37.459273,-11.358409,-169.559683,-216.92945,-192.104595,-76.875302,-30.133015,103.637247,193.299974,201.303061,90.742361,-182.429562,-264.287833,-198.66977,15.037703,72.077997,33.070234,-18.783326,-77.209281,-105.38821,-177.333754,-129.292132,-70.384356,19.814795,30.928338,-69.491888,-160.49901,-272.581515,-262.426498,-151.48634,-2.948685,73.308449,152.949347,127.453143,35.292103,7.937655,5.576133,119.359132,186.312734,234.25808,227.714861,142.577217,53.531014,-99.15206,-102.569943,67.440827,252.681244,284.99516,274.915197,246.905899,169.618043,135.839294,68.132243,11.443196,17.898724,109.992795,150.877679,106.245623,43.330942,-42.471657,-63.928654,-67.830305,2.810674,57.085888,188.33708,224.614002,139.974965,51.273828,-33.512571,89.525348,192.306513,382.128769,430.688636,389.223895,320.19978,151.825916,73.99716,15.967438,84.381671,126.515452,179.12682,171.819349,92.965831,57.023951,58.466257,83.099856,70.650176,91.882498,137.049549,140.81408,73.500112,-67.063604,-79.258499,16.4279,110.626748,148.384738,253.537907,292.860903,271.531811,206.857178,38.108951,-19.608601,21.678319,201.847224,282.279538,288.469122,226.852397,96.613473,63.669652:-90.3992,-187.922422,-185.412115,-153.396676,-166.062366,-186.352478,-165.527089,-175.518656,-245.682918,-227.201536,-114.828053,-84.309161,-89.486631,-72.122288,21.235252,41.695145,12.26493,62.975766,131.913555,253.073806,263.785724,207.733359,190.022545,207.538918,200.467674,168.690953,131.468114,146.663161,97.644176,11.58931,-87.183477,-65.344305,0.42868,-4.365151,-17.712834,-83.099172,-153.534917,-263.75687,-255.854102,-182.584285,-194.620593,-232.400237,-258.197715,-224.699787,-128.480056,-76.401439,-4.061405,-24.997333,-118.332101,-130.807269,-110.707069,-26.825527,10.74927,14.251128,-6.719042,-37.29778,-38.666214,-52.980249,-94.124985,-95.245666,-71.578731,-53.721161,21.887456,56.086979,71.238591,97.250375,120.049369,99.292266,33.242119,-106.974045,-136.684063,-134.541907,-113.235549,-116.839225,-102.798721,-39.138094,109.224439,109.910495,-24.696538,-91.854185,-81.366575,67.895158,118.831406,124.95534,86.461997,14.636579,28.554536,92.370739,136.941458,174.047421,191.888182,155.095816,93.493424,94.517509,107.012673,88.307697,29.916501,84.860064,142.265833,171.027177,123.617713,18.5391,16.560519,129.506905,248.187567,257.395652,275.737273,321.239713,336.285462,286.21326,213.878565,194.585053,126.532211,99.141225,139.850803,273.375169,310.227239,290.0422,278.186373,335.698345,402.076276,395.400982,372.441702,407.373023,496.785541,483.001836,350.402283,275.20552,185.04324,178.834163,164.760238,44.371307,-54.477299,-191.126104,-200.3444,-195.7551,-212.027625,-221.71591,-252.588516,-268.808796,-273.413807,-257.331311,-223.300953,-224.088227,-243.915346,-206.164138,-161.852252,-56.064877,-10.61235,47.27554,58.329451,49.341132,-1.867627,-34.640187,7.661063,97.189382,227.028941,216.349709,149.326629,132.264347,93.317692,53.302958,69.40444,145.491114,158.111997,108.990931,81.54184,69.698659,54.482401,22.913632,-14.783206,7.738774,46.785103,30.695908,-6.023705,5.542656,76.77013,129.22821,143.664952,121.261238,59.73612,-51.933152,-56.393485,-26.672103,-20.414971,-24.015079,11.194518,64.580296,136.757671,121.301251,49.807929,17.095125,-13.708515,32.979843,66.989274,153.331648,196.610147,181.72906,106.107201,-76.094219,-89.277251,-39.519695,16.574153,-3.005643,-107.366999,-149.130193,-140.447585,-117.068069,-80.676701,-14.963054,28.938161,68.737852,37.224044,-56.814481,-66.670616,-66.619805,-153.961649,-190.744453,-155.968896,-109.105091,-89.151742,-123.335593,-190.536975,-230.182743,-322.625892,-250.853827,-166.911345,-78.909879,-93.72233,-167.015429,-194.440096,-191.813316,-91.246151,-37.200546,22.24717,53.937143,170.045727,225.878049,228.477463,188.964867,158.543561,195.446058,191.247021,147.276287,131.808097,68.103494,-9.836778,-169.08467,-107.397318,3.535506,249.817531,342.311562,396.161266,344.525767,158.026396,93.611095,83.843286,65.429211,31.805053,-10.196215,-25.229982,-86.402784,-124.818683,-170.128571,-66.308143,31.544736,106.702432,69.227199,-5.696445,-34.193757,-136.947985,-208.856911,-291.498295,-272.896594,-265.193671,-251.537946,-237.753132,-195.998603,-176.052589,-185.730978,-195.074563,-174.161019,-106.772815,-60.452844,9.948802,4.553664,-42.069015,-62.215148,-121.403305,-148.592023,-127.683809,-65.18471,-74.527963,-200.925263,-257.782273,-258.383064,-119.155327,-19.246754,100.528744,87.368732,4.639778,-19.440993,-44.711526,-77.715123,-140.263531,-78.040353,-22.912163,29.005484,18.964119,0.343569,16.647369,63.642115,29.076378,-35.634988,-230.341544,-303.782914,-316.713736,-281.574525,-253.694739,-293.623466,-382.699484,-302.843039,-210.81553,-74.490665,-76.041505,-138.792269,-131.971685,-31.46422,38.212624,21.731534,-17.361916,9.446411,34.690644,-11.530041,-118.705445,-143.828731,-102.191864,46.884633,106.753777,134.567445,116.963729,92.898303,93.691961,47.012223,-54.49121,-82.499659,-60.207659,-38.091863,-67.978509,-111.830345,-168.216995,-171.328302,-130.303291,-32.263974,25.363179,108.806652,104.485784,35.234839,28.814891,87.119389,183.803434,257.487088,376.45008,385.56291,306.942342,242.004264,159.235492,148.974368,70.497533,-73.773157,-95.191633,-13.463204,46.407471,136.655391,171.44497,230.167414,229.280821,201.217132,161.236558,171.709516,214.496999,204.453181,61.572393,-37.24708,-111.473873,20.538796,101.198907,214.910187,240.9554,232.431058,211.785223,128.303172,10.392546,-9.030419,61.916598,112.387705,136.486014,97.630581,-36.91766,-100.259706:-355.808091,-411.491541,-398.095881,-334.00963,-299.297573,-268.49625,-269.959307,-274.985966,-201.633019,-146.978027,-136.280921,-183.222509,-242.267635,-207.101248,-99.948145,-107.494675,-191.305428,-100.24352,1.12094,134.39271,145.427597,144.709972,146.067981,137.78758,158.021703,169.480004,198.052375,220.842786,203.797021,156.216121,35.568114,-12.627192,7.231909,88.63411,69.693075,-46.737001,-86.033734,-61.165121,-23.253293,0.006641,-68.465572,-131.995149,-232.533741,-212.517626,-56.83636,21.503489,106.948562,104.299504,21.468442,-57.86073,-45.512247,108.192688,188.303568,214.563686,170.634679,35.336827,-86.111999,-128.291697,-153.786048,-119.104053,-18.626976,1.118748,-24.927016,-40.087756,28.962961,200.304239,239.581714,141.182202,50.898595,-80.510307,-127.102165,-194.538467,-164.203781,-137.623574,-84.487776,-9.725333,195.224435,237.567335,123.831959,29.886936,-20.478649,95.217177,133.220571,121.69326,100.042315,101.468459,116.168866,110.902023,144.462295,178.676978,165.445032,125.249355,74.594997,67.265577,14.575946,-45.790993,-131.918674,-80.086528,-32.965805,61.946185,87.331407,84.462187,81.910359,72.267233,64.323867,86.078416,191.421077,255.466595,297.011228,260.220172,139.313796,82.870672,57.15981,142.828578,200.303953,313.434473,335.322461,333.626773,368.665054,479.327172,484.488423,470.886678,497.028106,513.409723,463.729711,410.081297,312.222218,269.656532,248.673079,302.035014,295.28524,149.996843,28.041619,-170.170772,-205.039601,-226.476454,-255.848637,-247.338736,-193.806936,-162.025366,-109.287879,-91.210799,-67.765246,-66.018254,-46.519135,-5.252698,13.957749,109.904433,175.892185,239.103318,225.547136,132.226399,60.347918,71.223512,107.719038,110.925188,115.391991,138.018061,194.811786,180.341765,92.786348,59.971685,56.760386,41.488175,31.302328,19.681657,16.067115,2.260758,12.752686,9.598201,-20.728167,-25.06023,-73.536239,-114.094156,-128.69179,-110.931689,-19.365743,129.314386,162.192898,141.304102,124.929802,68.917453,9.314465,-89.595515,-45.993056,-24.523911,8.200774,65.443696,162.754889,137.196714,-0.585601,-38.917606,25.641553,118.338077,123.225431,143.512037,166.895158,184.78076,175.906591,67.257917,-46.60284,-9.923928,135.52724,126.158474,-58.829908,-109.656171,-51.78478,-36.449049,-67.844018,13.579625,79.462245,70.171935,-17.73325,-143.876873,-124.078588,-41.086801,-73.661181,-95.181216,-24.859589,42.120295,86.239787,32.630392,-128.93879,-166.003758,-93.725665,19.842925,48.590788,83.528172,66.822518,-67.399636,-111.585194,-37.760454,61.042012,66.883747,86.946531,134.830501,246.558511,270.818112,241.393566,205.58394,152.501425,144.758126,139.768093,91.387474,42.71969,-75.814904,-129.062348,-218.62093,-239.224217,-194.486067,-41.721829,31.43234,113.187824,115.163015,100.720832,99.558589,96.3317,100.543722,119.976432,200.96847,228.468488,210.830047,174.957734,56.481317,37.312712,107.248972,238.094108,215.424459,33.831831,-22.525938,-8.950102,-30.057197,-187.119017,-244.686502,-212.032544,-140.423202,-126.664733,-144.26857,-169.644696,-222.326444,-230.659734,-229.302763,-171.470379,-104.493187,-41.874813,-62.416074,-109.824705,-138.521083,-211.197807,-242.281913,-233.373452,-155.966262,-110.771437,-87.655835,-117.678174,-251.003472,-314.485343,-263.984754,-116.78356,-71.951144,-38.631528,-40.852746,-112.107873,-181.591781,-282.143585,-224.140785,-145.138142,37.312014,76.285594,-2.383986,-53.601251,-97.72341,-140.61112,-166.311012,-187.386717,-161.260649,-108.091678,-100.945495,-91.017788,-122.04991,-259.510149,-220.088007,-107.339561,73.482882,66.487406,-46.577506,-74.446383,-57.598797,12.078232,50.759907,57.124717,18.482703,-134.935562,-221.431768,-266.959002,-216.255437,-90.4119,-38.674525,-38.102796,-53.609578,-51.570538,-3.593203,-2.176139,-104.884063,-119.733182,-85.712008,-92.723417,-132.008267,-205.427672,-230.192901,-233.656588,-205.003614,-140.603904,-119.66412,-91.375237,63.131483,142.918662,153.615561,111.027103,83.064227,157.826489,215.537904,321.756987,351.543565,307.884699,242.919556,135.981589,99.430239,10.645487,-55.063925,-52.885629,6.081259,36.12441,103.656912,142.732909,174.020367,144.077356,120.293956,75.740599,68.225244,83.077314,72.371468,-57.519185,-145.137489,-179.174234,-17.813755,60.611609,182.965263,248.997214,393.178762,436.209784,363.185605,208.274142,172.011157,146.139665,140.626182,136.299704,114.34627,22.239687,-15.922087:-149.997938,-203.943511,-214.888833,-196.102621,-192.215704,-235.632498,-256.138756,-251.980165,-229.178802,-228.68906,-225.590488,-192.84508,-108.710115,-97.413552,-103.681009,-89.893781,-12.373526,68.940202,92.874436,145.360337,176.934104,214.00225,226.111483,218.720081,133.149801,89.267327,45.171978,40.853666,27.482289,15.628022,-24.0029,-56.18719,-88.501643,-86.66841,-122.12553,-278.833306,-358.471394,-407.729534,-371.794717,-277.72895,-258.480851,-264.111209,-233.970376,-182.466941,-50.705497,11.235907,89.482914,76.930508,-25.8632,-53.839085,3.719039,172.904548,204.066521,123.970627,61.843886,-23.843126,-18.325587,-22.779488,-97.984735,-122.519373,-87.279141,-56.077695,-28.531193,-17.444814,61.437734,127.234068,107.717366,22.041709,-10.106954,-57.725184,-77.337099,-71.743648,6.204843,28.574338,-15.154564,-50.332069,-78.542271,-67.588136,-29.975591,-37.096126,-56.262639,89.629622,180.874247,209.22154,162.608537,135.841617,177.408628,221.690054,169.070515,158.200483,192.934363,216.626181,232.011305,233.850085,190.159792,112.054737,3.928797,178.223116,293.753134,389.962093,369.074876,271.220986,208.460097,107.783219,146.768137,179.243988,228.355833,263.737114,223.950405,123.742946,-43.43962,-70.529671,-52.892613,26.714568,69.234881,168.180274,205.688694,178.072638,138.171603,106.07059,96.379677,101.52535,240.398799,357.778895,487.301579,461.911247,285.358416,175.21322,71.184537,154.379464,180.944634,68.189406,-56.898454,-266.204028,-283.48213,-196.181324,-169.152924,-202.453682,-258.979629,-257.659161,-248.17919,-243.068031,-219.965045,-217.881785,-214.329499,-191.070822,-187.235519,-170.422692,-141.672134,-33.158844,23.572921,59.883495,23.907488,17.197593,63.858982,122.01381,234.161792,240.945481,156.151874,119.575112,137.001976,147.487824,143.286937,189.167969,212.002655,186.461125,157.670006,138.603836,123.088333,84.748768,10.631044,2.730841,16.398799,23.930846,37.806905,51.046145,114.363272,154.170238,141.96364,99.014504,70.980462,1.905702,-22.069278,-62.977125,-24.710107,38.119881,133.751636,155.188012,152.115494,118.605001,32.920838,1.984073,-3.663089,63.271629,99.205176,123.201239,101.403714,46.588422,28.825523,-18.398334,-54.412036,-55.934219,-60.708115,-71.900827,-93.240204,-106.114329,-146.650492,-161.368036,-159.07696,-130.768694,-92.736233,0.349701,3.984258,-49.761243,-57.078799,-33.934745,-31.464269,-28.496127,2.101262,14.349893,-23.815279,-82.789333,-189.270172,-200.531224,-119.124845,32.039851,55.535238,-33.748154,-86.454213,-111.177129,-104.360275,-162.201391,-211.778803,-152.91147,47.421807,124.213391,215.908758,234.938,191.903796,153.862883,142.025342,177.984427,190.634977,196.405297,173.621865,56.158354,-29.019452,-177.489286,-137.022152,-38.821737,177.605851,244.259768,243.397313,179.633933,21.689686,-16.494518,-39.610646,-115.616905,-123.261254,-25.149141,-6.165248,-103.534967,-144.299023,-122.01929,26.990179,133.575034,245.521328,209.830605,37.080033,-35.105991,-81.531601,-89.220982,-154.939584,-196.715897,-161.892051,-92.937947,-114.122367,-193.176427,-192.375857,-147.204034,-161.65926,-150.767048,-24.392279,63.933837,145.07601,111.561656,-32.282105,-107.769901,-214.137793,-160.940684,-78.723813,-35.865259,-118.281672,-271.766433,-269.860013,-205.125407,-137.312495,-91.368993,-23.653292,0.538807,9.418398,-15.581863,-71.86472,-94.617774,-104.418974,-9.666075,45.836246,111.431463,120.324651,88.501756,56.93048,5.139534,49.681251,77.50439,1.524006,-69.139875,-165.786733,-191.127425,-195.979281,-208.314911,-261.004312,-138.332329,-19.037554,98.643062,55.406779,-77.659451,-84.565114,4.568896,70.468893,76.319626,56.140671,55.899118,63.751466,50.867965,8.432503,-8.470912,39.937969,169.601094,197.69007,177.169712,165.727918,187.581979,189.989397,84.039054,-43.211075,-70.107877,-41.851058,7.238334,87.650916,84.358463,-29.616182,-106.362114,-151.825892,-81.421221,-31.555155,83.914914,99.286223,8.937694,-26.317213,35.020742,144.064549,167.524882,228.070623,281.015832,276.993983,210.399458,124.416242,104.622864,30.203308,16.832444,38.826604,58.737865,61.659704,76.878106,89.559981,123.246359,138.636777,141.450044,164.869821,173.298436,116.575092,61.20082,-22.04476,-44.665397,-51.910829,37.492955,104.298287,199.319123,212.103742,201.625647,183.713829,85.714828,-4.925347,6.354203,115.038604,171.281149,185.451971,129.3167,34.713348,47.849426:left
20.641047,188.801332,305.064585,440.010389,403.751513,217.940585,154.895753,89.209219,0.723304,-16.862961,-37.902873,-101.405687,-290.830445,-333.409479,-238.627792,-152.912274,-48.205651,-35.597985,-49.280493,-108.543813,-149.807594,-240.808795,-261.834077,-236.295083,-225.621846,-208.046206,-96.70497,-49.83781,-94.464568,-136.814765,-64.177986,20.644222,109.447798,167.454958,207.589224,230.240975,191.70314,89.670963,92.233739,214.250832,272.445635,240.580705,107.406098,37.589065,-43.579762,-41.084884,58.22668,115.910006,129.674378,63.88387,25.792222,-64.626337,-121.626807,-207.213784,-191.6747,-74.316019,-48.975997,-75.19602,-67.928103,-19.138358,39.977365,-0.698939,-147.513854,-197.738065,-236.625967,-124.541358,-13.13336,127.13503,115.139908,6.561683,-36.544737,-21.219087,97.696819,142.807397,119.524398,74.923956,2.807902,-38.74119,-93.881975,-56.667785,107.628353,257.890013,300.727691,289.099519,250.671893,207.891494,227.994108,286.263421,310.728465,330.96998,381.235772,408.006152,445.294509,433.313575,361.772879,322.451062,258.777099,201.792787,174.076835,164.223628,179.313509,206.061736,233.109447,336.80799,363.985347,332.500477,248.432923,194.288216,46.467057,-17.758673,-3.684282,85.894765,310.988283,451.364672,460.05657,377.618793,317.157776,211.629795,187.306895,187.213079,163.925896,139.481475,109.758803,106.748856,95.298666,88.062449,127.028669,191.301201,344.233106,390.536183,340.084737,117.597378,3.201175,-115.205643,-131.56897,-174.153369,-195.389691,-167.124627,-120.760681,-123.390138,-141.147089,-148.0014,-108.2003,-64.87742,4.530988,91.892281,150.858646,225.450219,214.109725,135.152894,122.309649,214.561896,319.456957,309.423598,174.834438,123.796513,161.728368,202.346291,174.105459,98.16582,-85.813928,-107.547034,-29.204458,109.812047,76.730781,-137.767059,-182.923462,-7.58794,192.655625,190.253672,0.75176,-109.323938,-209.650186,-202.189511,-143.60585,-140.234583,-223.942968,-292.144761,-314.763856,-348.679284,-334.820969,-243.376434,-187.497067,-81.719046,-14.753678,-8.427412,-0.124839,28.243375,73.49413,47.5659,-15.442242,0.381032,81.998849,87.388768,38.634608,-73.106946,-103.063372,-139.003769,-135.162597,-41.36728,17.291697,-12.86162,-127.221254,-181.750719,-265.360965,-277.83865,-208.035506,-159.558966,-144.66526,-173.377339,-154.85844,-86.532716,-79.510926,-128.287761,-159.612157,-201.809593,-171.177817,-112.669187,-56.003142,-116.955822,-307.63581,-361.524337,-358.449527,-342.608843,-345.133861,-317.281733,-301.447892,-306.887684,-296.860579,-253.263054,-248.622445,-251.082338,-221.09767,-220.072805,-257.868475,-263.22259,-243.640881,-254.008212,-286.38347,-266.699573,-148.575603,-22.307091,4.761048,-6.217213,-31.660212,-120.117134,-147.746259,-84.111487,66.530027,116.710254,85.200673,36.089487,-11.674566,-14.906295,0.348109,21.358055,79.963134,107.692289,73.348636,-89.514009,-182.923669,-270.713832,-237.61235,-93.431928,6.631558,28.506596,45.255416,65.239411,127.520753,128.932565,52.072758,22.898823,90.875807,250.196677,276.000716,163.989181,82.046265,-33.251198,-62.842938,-65.217695,14.402678,85.361585,175.659579,160.415533,100.169075,86.050572,53.024998,31.854526,36.576296,103.489258,122.379017,91.166349,63.723211,50.569059,68.559195,95.394622,82.64128,102.14397,132.311453,91.440529,-27.477914,-48.351449,-24.939893,-16.518136,4.206243,76.085208,75.868087,-42.478315,-99.297755,-104.404124,-57.553452,78.429308,192.844757,232.442523,236.627358,201.104338,115.893192,72.41248,15.23483,15.011091,61.540137,185.219536,244.103946,277.63746,245.8594,149.355741,135.20987,177.795876,192.788736,185.352404,167.195206,163.574005,147.058152,98.319348,-44.825461,-67.56384,47.467332,189.523819,192.687806,87.495799,25.522394,-50.414516,-58.528042,-6.460179,74.056504,75.461888,-36.422577,-118.306829,-258.878903,-316.668375,-353.894202,-321.67117,-278.48989,-323.449967,-364.24499,-474.305577,-532.769781,-656.022532,-699.393363,-672.911822,-544.854323,-471.922278,-349.83509,-325.01307,-388.244792,-438.29667,-445.798259,-409.565972,-297.966738,-182.222955,-183.92742,-291.721384,-330.836014,-273.534656,-188.044682,-62.574861,-98.803103,-125.032838,-126.250648,-116.567179,-133.099995,-150.380888,-91.267523,-4.921071,146.326579,141.058629,99.586958,41.401151,35.203536,1.700315,-26.326698,-33.990117,34.092099,69.43088,64.895432,31.408756,-53.800882,-107.337156,-209.536041,-234.694243:3.793995,68.889538,124.634858,219.365768,217.590262,141.724816,118.651237,134.638714,167.709987,173.922088,82.041742,-28.885251,-238.057904,-263.27525,-197.11485,-159.70813,-61.15815,22.233179,22.432172,-16.494322,-45.164599,-111.878511,-123.399044,-89.706724,-30.078283,-0.410703,-1.486951,-41.824779,-104.522662,-84.919416,-33.379661,-53.645609,-74.140832,66.488325,122.012196,70.1079,-18.679181,-170.75671,-162.091606,35.125657,176.319251,156.327308,17.426984,-52.200787,-122.41573,-106.961569,21.750305,83.426179,66.786712,-98.835205,-165.381646,-165.768085,-147.924316,-164.914798,-160.560066,-88.609745,-54.354471,-73.600837,-103.599592,-86.876331,-71.870062,-99.086055,-123.38085,-115.393463,-135.577126,-92.473997,-40.989684,6.991849,-9.782975,-66.132059,-67.579394,23.875465,166.683036,202.535363,129.493837,40.563829,-98.824513,-102.507564,-3.440555,43.045683,91.441081,172.073123,209.08786,233.065583,230.668444,225.692436,239.35176,314.635745,423.755506,462.581077,481.721054,477.30434,438.996896,411.878441,409.504875,412.751557,348.935051,277.990492,257.47865,249.296692,254.65523,259.173101,282.551066,383.063688,416.869799,373.682372,207.358321,138.828294,106.238403,115.934756,132.299254,154.3265,269.910593,360.645919,327.513371,170.711037,118.569886,139.712095,195.37028,250.434368,175.017142,135.129597,96.036077,94.530917,128.438081,174.286645,298.303674,332.453859,310.891729,240.279018,196.694115,102.938948,61.354827,33.377384,40.991597,-2.076023,-65.554841,-62.045044,-52.470578,-81.069209,-175.080699,-175.539331,-16.516768,57.386481,54.844497,38.798454,62.328959,123.641637,134.441641,96.373891,91.028985,157.158355,210.277879,207.909666,135.865165,79.444558,-37.554441,-71.459108,-5.118068,78.960359,174.606097,83.507126,35.159125,-1.976191,-38.677192,-144.951861,-152.848563,-81.91223,-25.550874,-19.993063,-61.879495,-102.642442,-190.563759,-218.849531,-220.183478,-213.906574,-248.047649,-300.843413,-307.878143,-307.888833,-310.058454,-281.053205,-241.674283,-159.067556,-134.6736,-131.68286,-111.136825,-85.666769,-19.500694,-5.202356,-43.77004,-89.109318,-117.180008,-9.831927,-16.558853,-192.300393,-264.190071,-259.160486,-211.729929,-142.331368,-198.077576,-263.141097,-359.354499,-364.270449,-358.657716,-357.215955,-274.499387,-206.972389,-135.62681,-177.301731,-222.24978,-281.537607,-270.760282,-211.000511,-198.102263,-241.534054,-278.298852,-254.381617,-188.047108,-187.321328,-271.80044,-325.575634,-353.570157,-322.74918,-246.996196,-229.256956,-253.956674,-320.22946,-333.860897,-339.209807,-345.968913,-326.503109,-273.320334,-281.287769,-380.468794,-414.332525,-435.817943,-476.028651,-530.457271,-482.291379,-299.464811,-185.026194,-163.822516,-150.781933,-178.773553,-275.929851,-276.527047,-152.277294,27.334801,92.72158,60.824975,-1.739679,-44.696547,-23.831202,17.173457,8.352931,-28.743471,-17.562722,-29.265957,-134.2653,-190.784281,-193.317412,-149.759713,-94.272979,-64.36714,-30.449645,22.640881,11.633908,-65.198162,-82.894122,-0.638631,65.533299,169.390155,226.318916,196.36517,62.628838,17.499523,-39.066144,-74.320769,-130.015267,-107.64838,-57.469589,48.531821,66.757142,42.30253,30.326996,76.417063,129.730566,195.737144,163.213348,138.119818,105.502421,83.127372,48.244013,62.729636,77.205463,34.703711,39.825022,61.353903,43.609824,-39.042964,-66.746123,-13.649045,38.784507,92.876443,60.80446,14.449163,-31.529027,1.01657,83.459886,112.200027,167.821658,158.061018,130.73804,80.606972,52.638447,-21.431131,-44.942174,4.508777,54.727755,108.38204,121.053239,96.742505,-36.509521,-104.855082,-104.292022,-37.461449,47.444062,11.955211,-0.590736,23.435814,48.469067,67.984641,48.996981,-19.77213,-55.801784,-37.377841,70.485175,57.302969,-75.018839,-111.939958,-76.573029,-49.13294,-32.712926,-15.814282,-37.788348,-154.502919,-197.966121,-262.413415,-313.982443,-365.765931,-334.244806,-258.240141,-266.674038,-307.127786,-440.246268,-526.964441,-714.576504,-748.445564,-582.801346,-362.507341,-326.669083,-342.810034,-339.701161,-322.042262,-343.312506,-403.948918,-397.482776,-282.790744,-117.094998,-84.765151,-158.634689,-226.420741,-332.642703,-330.758569,-203.214094,-74.844945,-53.444886,-93.344915,-133.71974,-191.001864,-179.626351,-36.276989,64.753071,184.32582,172.098437,143.104492,66.796348,42.041883,26.833571,23.861492,62.534888,162.629893,200.774126,204.835513,158.197233,-73.038283,-191.790871,-206.258713,-118.170668:-73.406721,4.029555,52.157118,145.311368,162.266671,164.986142,184.513075,210.296181,176.58902,166.919821,102.884764,4.122738,-223.872797,-259.496791,-139.368194,-50.513072,61.965481,90.555365,94.799725,69.921804,22.181108,-64.311029,-55.308644,30.954437,112.551778,124.280982,53.007159,-2.747293,-45.743485,-13.577425,68.347314,58.577021,-6.25085,41.936752,59.928678,-45.407089,-138.800583,-226.57223,-178.617629,-1.048116,47.959696,12.379743,-83.091029,-115.214477,-154.272446,-163.280012,-109.828503,-65.42198,-33.507066,-58.149358,-87.841657,-143.180886,-152.187718,-161.46819,-157.732788,-92.092765,-21.898708,-45.577452,-160.388159,-185.352998,-145.155566,-108.984501,-63.10833,-83.239549,-170.882827,-105.089033,-30.249708,52.259839,49.226633,10.758041,0.282736,8.358418,85.87955,146.025828,167.118682,100.714161,-55.619289,-73.093906,26.518548,78.443661,115.207218,162.631361,187.991545,216.619015,222.409828,194.562502,178.350388,196.904118,262.92639,292.100873,311.186731,313.590596,329.147084,342.881189,370.260665,373.033758,368.736729,355.893983,329.209896,260.3944,229.10178,187.190877,207.496014,320.351966,334.665241,280.767426,147.328852,110.789605,98.935117,96.44104,112.448896,148.8313,239.894831,281.027531,270.638,174.651559,104.916445,30.63554,50.088429,124.734192,131.975851,105.836407,63.722574,54.198023,30.67314,46.347384,157.030227,209.994384,271.637857,242.898044,170.254262,8.62133,-29.061013,-12.718023,-0.660179,-53.613166,-36.920343,15.411527,16.570232,-41.592403,-129.450854,-118.081483,-0.083257,44.372962,7.661019,-69.496112,-75.316275,-29.669895,-21.496985,-58.664828,-64.413063,-28.554015,56.952705,86.464391,30.182885,-27.721824,-122.335589,-143.378369,-73.615591,-8.180298,32.173093,-41.24847,-79.64842,-149.76771,-196.115195,-241.096367,-189.54894,-29.76974,1.899898,-32.883332,-112.208229,-134.196083,-182.244119,-210.905545,-205.785394,-184.279054,-209.588397,-303.963041,-316.270625,-219.995701,-170.915385,-160.934658,-173.935907,-208.299004,-190.841969,-151.573282,-145.810753,-194.078846,-259.997645,-240.553995,-133.524101,-93.797757,-85.079518,-112.244364,-152.115393,-266.913384,-317.153479,-343.609408,-298.716333,-179.324482,-184.699575,-213.727774,-243.60325,-259.439835,-343.842958,-370.166517,-279.443858,-201.285751,-120.126756,-179.863513,-234.957751,-284.012262,-286.728082,-340.955498,-355.443368,-254.245254,-146.753537,-152.599271,-213.80239,-231.31338,-283.250104,-339.12385,-404.37126,-368.830144,-239.214026,-219.12036,-246.122209,-298.699108,-324.356398,-400.616742,-433.767539,-401.208455,-303.921719,-303.122276,-412.055713,-460.91029,-477.066199,-475.505412,-473.703228,-444.161121,-258.577764,-61.850203,-58.656235,-190.229115,-250.041641,-271.647651,-240.789687,-159.652436,-67.445406,-30.114328,-18.413613,-26.097139,3.85289,33.823014,56.705772,43.41486,-0.207892,-54.764012,-74.835207,-78.243788,-90.854913,-131.195863,-133.906291,-117.562112,-54.090601,-13.681709,37.438933,34.59804,-20.790159,-35.20496,10.725124,47.704675,121.767446,214.239462,239.309097,173.198714,89.8615,-19.063361,-9.443335,-16.000966,-116.766897,-141.139177,-100.285989,-52.332872,18.029071,29.655131,88.004149,143.581313,204.971522,154.169298,142.115138,168.403391,149.541262,46.225471,17.157816,32.857129,101.347275,120.863151,87.291857,52.75678,-45.599498,-93.967568,-76.451183,-24.361006,26.553731,9.480282,-1.121565,-37.503425,-62.458938,-23.672096,63.179208,209.538373,179.412813,126.895602,25.410917,-11.171585,-98.576878,-133.956872,-58.047815,36.157664,152.763302,107.699034,49.133267,-85.554487,-142.903116,-167.824836,-130.521397,-98.700416,-186.776206,-213.805591,-163.456485,-108.533938,-27.560203,-18.330498,-40.783508,-55.026838,-5.838724,72.427685,55.429093,-55.800796,-98.774292,-76.889194,-28.959504,37.583766,6.989629,-40.35192,-87.858178,-65.193466,-60.347052,-96.636974,-126.587383,-109.639794,-85.50083,-82.415146,-83.821486,-151.244323,-230.819633,-372.127233,-376.394152,-293.602055,-201.49269,-169.90568,-155.306082,-147.639576,-153.934171,-198.64258,-273.772451,-258.273869,-136.97666,1.18821,27.124569,-32.934407,-87.960008,-140.249623,-121.906395,-52.049412,-41.375248,-67.400266,-128.162364,-152.548622,-178.043838,-150.695798,17.288694,132.148878,313.614541,291.791738,211.590538,37.372796,-15.118459,2.697295,60.997542,185.75428,274.002057,309.15164,304.277073,240.841946,46.553334,-28.247345,-41.55346,15.128752:69.396014,283.559885,364.68579,483.773209,481.422965,313.8122,229.678948,178.996869,151.432599,107.759226,-66.707639,-190.87054,-393.239871,-418.84508,-315.645804,-223.658229,-40.037482,47.469788,30.586269,-70.067108,-119.857276,-186.539791,-192.113136,-138.363553,-52.146711,-38.16987,-103.603757,-132.139088,-92.354929,-45.607651,61.498054,102.687517,144.654159,227.888688,261.688107,202.83084,114.260705,-73.784032,-105.033143,-21.071535,42.707168,43.858846,-6.743964,-60.934208,-160.75351,-190.25436,-170.986165,-118.269422,-26.010368,-59.401646,-122.110794,-254.929644,-296.303798,-297.320339,-248.438175,-125.933141,-74.540503,-87.269861,-137.620747,-128.373518,-75.843644,-90.199611,-200.542621,-259.661983,-263.543466,-66.118226,16.461968,53.31045,45.839773,42.006718,52.095329,91.762188,150.552367,173.577428,144.287714,84.659011,-67.149352,-113.918722,-68.303854,4.515744,135.079939,253.03615,296.126883,285.870101,248.999503,182.652643,166.404134,178.635213,271.715857,331.312384,374.464942,367.578107,411.236614,461.915707,493.904898,437.928332,328.55299,368.997463,355.330431,208.36576,128.42953,33.230898,45.053205,170.79981,241.14505,208.992205,69.720032,21.854795,9.170846,22.275618,74.90758,110.591589,189.777459,264.118594,273.290869,202.74123,149.793385,132.823338,181.574976,229.311218,157.864994,155.948766,215.693619,216.976983,135.549618,107.91063,171.877263,234.797295,301.530505,244.661687,176.396537,17.808767,-32.977982,-58.223181,-59.262763,-90.700191,-113.209599,-93.259124,-73.318183,-105.988483,-212.837295,-238.428215,-156.769035,-86.452507,-2.458604,54.969888,88.161993,127.528888,122.944198,100.295938,103.488877,119.781409,162.080034,189.813072,169.444038,134.466112,87.893011,64.997886,-16.478393,-72.605133,-157.913449,-109.127328,-63.114323,-63.849783,-115.385259,-196.429473,-177.826979,-82.967265,-74.233684,-91.911341,-116.382522,-128.541276,-167.060551,-184.107565,-180.523597,-170.081546,-162.08212,-165.714098,-188.979202,-245.199057,-241.966358,-194.32267,-174.149022,-115.24965,-13.140149,11.857155,-23.822854,-43.579451,-40.087593,-36.601572,-58.341108,-81.521842,-58.338424,55.082818,49.497383,-95.148181,-156.096993,-166.855988,-127.271099,-42.683479,-58.779266,-99.050261,-184.925974,-200.31321,-209.196952,-229.148713,-215.092304,-183.91153,-167.628174,-119.957112,-89.621896,-134.836406,-193.349174,-250.409102,-244.099949,-230.861878,-175.849786,-130.165692,-93.151388,-106.673909,-197.030116,-275.315162,-344.42451,-297.892768,-190.412482,-161.660891,-158.992243,-201.996107,-250.928887,-344.721607,-365.749013,-349.872528,-262.177468,-222.23305,-252.668374,-303.46909,-390.575122,-418.076547,-384.103058,-319.201441,-160.710668,-57.168334,-46.690089,-97.278026,-159.730889,-284.367131,-285.615041,-172.733699,-74.721526,-41.821023,14.702701,16.433801,-61.556707,-111.653593,-137.222839,-100.634702,-7.780996,-2.619371,-26.456395,-122.574943,-199.252494,-283.352657,-248.442126,-120.294474,-41.039052,-16.183169,46.73082,81.735471,95.808263,75.394955,38.319915,51.538687,214.762747,406.858757,402.710284,228.991924,157.628753,121.842296,119.893706,74.721583,14.347041,34.167543,130.539886,157.235495,170.440254,171.203868,203.196955,235.983314,258.292128,243.056988,253.463152,246.08722,202.687471,81.507099,33.600472,11.081799,88.225852,129.901805,129.146069,95.946437,46.491738,33.60299,5.072079,-2.527042,59.112894,179.708868,181.789933,37.491661,-40.053109,-55.23633,8.603384,175.080471,213.450779,152.097019,-21.166674,-79.836967,-137.590096,-141.53593,-89.063495,-57.959825,-46.45048,-44.361095,-29.532672,33.981707,62.967579,28.92939,-13.297533,-65.760441,-110.126667,-114.491064,-61.597915,-25.460817,-6.755192,-27.510403,-46.129522,-30.367556,28.919364,85.422147,63.834357,-52.985727,-71.636001,-10.164645,10.753949,17.856724,51.87083,61.292651,26.843112,0.661739,-43.509377,-66.147743,-88.941825,-89.054355,-86.392842,-87.843924,-110.920861,-182.449426,-227.302748,-350.966588,-375.915312,-265.660537,-148.827648,-117.273908,-68.118974,-85.835563,-226.828607,-281.163396,-255.811391,-202.380385,-75.380637,16.894071,10.346347,-86.309016,-139.263154,-187.608878,-178.64462,-120.894078,1.967413,59.593276,83.77285,67.483525,15.72642,-11.52786,29.404553,92.585656,177.528457,192.976569,187.42135,138.693421,96.121359,15.768881,19.938964,126.767991,197.453421,212.687935,255.686055,251.872543,90.007702,-32.388325,-141.713892,-94.881251:190.71371,371.535083,388.931847,330.803494,302.248859,271.142671,265.800854,240.089578,208.639569,195.308162,88.964172,-13.565366,-213.630084,-248.56526,-150.264201,-66.77269,58.138458,100.144197,105.963709,63.755423,-11.431716,-167.847112,-175.249406,-50.494527,109.529501,133.629879,-9.896349,-101.092018,-113.849158,-34.818961,184.748098,267.53139,346.114018,356.522665,314.714901,134.196608,30.860411,-87.068867,-83.576319,-5.006407,63.125328,46.065282,-118.728948,-208.588783,-272.130325,-266.554344,-225.328879,-176.834891,-48.0236,-28.186876,-103.352062,-290.911219,-317.485317,-202.228676,-122.074869,-79.324811,-113.474731,-105.448131,-80.978732,-84.301444,-161.264069,-207.345721,-200.223508,-180.650541,-176.428333,-120.677793,-94.297432,-89.43958,-96.923739,-76.234571,-31.877774,66.811894,86.939836,73.324612,54.056295,46.758076,-52.399277,-129.10883,-156.469276,-96.261784,74.166702,228.405363,269.77762,266.024204,233.896803,169.664023,156.709157,171.58192,254.776945,299.103469,311.449452,302.412333,314.369931,313.044352,280.801886,287.994466,415.740227,493.427626,427.743408,202.813614,107.956239,8.104171,30.583792,200.175737,275.226058,223.714717,73.079497,27.142472,-5.074613,-5.110516,37.466105,72.926796,158.938918,242.269563,256.522919,202.027462,142.037577,77.662616,91.684659,109.033587,133.329142,167.271182,208.981685,204.587198,153.933287,136.994543,188.132308,236.135599,296.879913,240.550571,160.245299,-27.299566,-80.062522,-56.036333,-29.082191,-45.048622,-15.063475,22.222396,1.500396,-55.511285,-154.516078,-164.692283,-82.075484,-18.025378,68.252715,138.398426,180.928367,226.134007,205.273023,111.80893,82.413373,111.915609,225.768932,265.44301,209.028075,123.850451,-84.915428,-160.638402,-169.154641,-142.566522,-128.673758,-97.405196,-69.15194,-90.24648,-158.517579,-265.793331,-242.482075,-136.178989,-145.07303,-167.3182,-164.921359,-154.11884,-152.91971,-146.677275,-107.751951,-101.255826,-132.732361,-182.095568,-203.24107,-235.486493,-264.363059,-320.391963,-302.694934,-150.640327,36.092754,65.58289,-67.332074,-155.79163,-183.95236,-132.142385,-40.989244,-35.115255,-35.508609,-36.169443,-64.439178,-137.189409,-165.164829,-159.469841,-108.315448,-3.751854,1.044182,-16.311914,-96.82446,-152.237376,-206.589636,-192.276618,-147.345517,-138.038861,-104.310607,-87.846331,-101.979877,-146.798636,-183.001359,-248.462367,-244.81238,-181.317773,-108.224951,-96.601169,-171.279373,-212.171671,-227.79129,-235.182826,-230.43405,-186.652247,-93.91733,-88.07913,-110.600336,-213.624383,-282.928064,-367.285073,-352.220038,-233.486031,-138.144907,-150.773384,-260.958557,-300.602385,-349.54121,-380.839559,-353.710258,-268.914753,-54.802732,20.995389,-13.459556,-141.912696,-232.124746,-388.7531,-379.411841,-215.96498,-46.616811,26.854103,74.437459,24.725832,-103.294041,-114.727749,-21.792919,29.200452,35.522082,-36.269007,-42.061867,-33.289559,-85.381081,-218.604534,-220.467152,-133.187229,-41.404081,-5.649462,30.94252,30.519735,-21.350995,-52.710697,-73.374338,-57.420391,96.226268,287.244715,290.806988,148.011061,59.437566,-34.015876,-13.806925,45.058361,-6.1382,-33.489907,-13.951701,6.433603,4.556816,17.963539,159.788456,226.123817,228.134135,224.894001,257.583895,283.535274,222.091725,-3.088099,-82.020379,-66.53837,50.90196,72.329465,-4.978844,-76.394168,-210.400585,-237.799407,-143.52542,-45.841378,119.815179,158.55197,100.326459,-106.836992,-153.312057,-25.528608,72.839255,175.003863,142.463282,71.363361,-82.601133,-118.801206,-174.607952,-201.948343,-141.756834,-58.182619,95.54967,110.982228,57.295288,-85.870768,-144.646415,-185.426823,-154.740045,-52.379802,-10.011734,-10.537394,-22.715007,-33.471463,-47.297184,-45.204528,-20.771013,3.877621,81.677172,105.857057,53.411468,-56.895788,-47.288116,12.763381,-0.43056,-17.703779,89.75933,122.822504,126.430661,130.756812,116.067048,100.372989,91.151337,81.279608,70.277015,119.044402,113.144349,11.272906,-42.607966,-98.316356,-95.784152,-25.654835,84.358259,112.437335,49.38789,-17.019648,-114.367632,-119.499148,-38.072119,12.941571,97.601761,174.953338,167.514021,52.53867,-15.333123,-96.785922,-98.972942,-34.325064,71.14228,92.078807,53.324067,28.371813,-34.738405,-56.237698,50.107738,140.594837,235.119185,260.243927,244.630712,128.589403,53.29245,-50.462345,-47.984783,73.592434,216.949806,250.521802,242.995901,218.392085,110.777753,46.58146,24.606353,65.320015:65.014653,288.675407,372.634721,425.73032,387.825923,235.923422,178.241767,142.290252,138.753236,128.368554,-9.666324,-136.698274,-301.083225,-273.987492,-91.829559,-27.788071,-40.408666,-68.892799,-80.184163,-146.621472,-178.322635,-220.420929,-223.838159,-177.840815,-138.968783,-134.124498,-113.565631,-85.621352,-3.366853,29.383443,88.145256,145.024652,278.01908,316.934606,299.105243,257.125302,231.929845,131.270538,87.909594,87.562101,119.213408,109.857587,0.098335,-85.269496,-168.454453,-129.286486,27.427138,87.854513,106.657368,27.111356,-29.306002,-124.492327,-164.902338,-227.614897,-223.829872,-132.412246,-40.883357,-52.609338,-116.801297,-99.130268,-29.216734,-56.659991,-204.527205,-252.029251,-228.179518,-51.67376,44.655442,125.196066,110.057759,38.37593,13.96829,35.084935,103.758016,113.554238,41.325777,-20.738587,-122.746461,-157.690331,-162.759606,-121.49369,10.121602,184.997083,241.866308,239.554574,221.285111,187.477906,162.119363,158.840613,260.880025,297.717497,293.173153,287.055209,332.117949,354.637352,306.617089,248.779359,172.228395,182.130435,184.135967,133.603516,82.296348,-18.709663,-9.085709,158.807127,251.010391,219.731277,81.434297,9.507513,-74.571922,-72.927164,23.109878,112.956569,317.375861,402.790992,386.644414,279.122282,193.598209,69.096625,88.645479,248.659108,324.11632,290.541342,204.88574,176.556212,48.360707,-33.701184,-0.819866,132.609589,347.659717,266.357963,167.585323,18.424878,-16.329465,-73.383071,-106.170863,-152.9453,-133.642414,-102.983742,-85.824199,-114.309428,-224.579658,-272.884038,-238.353262,-177.855881,-101.065215,-15.608004,32.764531,62.233912,49.08148,7.87992,17.173868,149.163174,287.60611,304.78114,208.526972,141.252571,87.801037,75.476828,-23.056507,-101.208653,-210.033043,-144.492783,-63.122861,50.939424,48.055455,-13.840223,-13.127179,55.738898,67.154714,41.445739,-53.798789,-93.161752,-91.677293,-88.907655,-130.603968,-143.636614,-117.331968,-110.799802,-134.513474,-174.423161,-179.586313,-172.600972,-150.531637,-60.740362,37.800351,51.946005,6.432951,2.433003,52.819709,46.200875,-63.857789,-111.612851,-100.696125,-29.377903,-26.552886,-68.649939,-89.117034,-129.481304,-112.610679,29.680384,42.393362,-28.294813,-85.415994,-30.777704,46.392738,-0.62296,-121.488009,-109.355802,11.159855,44.656563,26.398352,-24.237104,-58.943314,-79.98201,-46.957994,-6.614852,0.144316,41.646122,78.377493,22.210393,-162.882934,-254.053975,-366.323308,-363.762299,-325.271182,-314.817569,-299.578081,-276.652111,-285.571333,-323.661288,-332.278347,-295.516037,-192.114253,-141.413991,-116.262146,-144.862818,-203.722309,-224.753147,-282.182627,-297.007743,-190.725616,4.936919,31.778639,-38.495668,-87.852684,-185.010882,-181.849362,-52.487536,27.04789,33.461478,-13.65416,-64.704766,-161.229968,-187.645249,-143.950473,-83.338675,12.117077,39.241432,25.423048,-77.587232,-160.831978,-320.083321,-350.349224,-262.134322,-147.880313,-126.235853,-69.716296,-10.999017,73.055942,59.146837,-12.542021,-26.816662,20.918079,137.173617,158.091977,65.542836,0.681562,-65.885786,-54.514129,23.959143,42.66001,28.727566,27.904523,47.164637,78.540368,66.305768,15.149694,10.262891,27.506612,70.760046,106.376763,136.577448,119.967648,70.561955,51.745634,38.186692,91.789867,131.076182,137.697834,99.475487,25.200326,7.384018,-32.815937,-61.335978,-45.570706,46.522148,33.568703,-114.79939,-178.575085,-162.425021,-81.420993,87.336701,111.099152,67.974592,-72.86749,-124.129013,-131.359001,-135.421939,-197.339703,-222.341769,-187.047331,-61.756561,-13.3984,71.621686,126.180995,185.057047,163.244925,69.512199,27.000447,36.704005,37.065588,26.481427,40.356468,43.734873,18.279938,16.54949,74.644473,184.968547,220.908944,211.285142,176.593214,86.176999,52.33805,75.629104,181.652634,206.463093,152.52818,105.545676,33.789893,3.479909,-4.300488,34.042446,106.377332,107.027143,75.197368,-44.902951,-120.604565,-275.083618,-318.303878,-259.89313,-110.173301,-70.696235,-111.241721,-152.326164,-190.015819,-200.110405,-214.980188,-207.10792,-173.511409,-114.203219,-81.772947,-76.892461,-94.828369,-105.739994,-98.57514,-79.174423,-21.297573,19.04199,54.625453,41.068429,-28.508752,-69.756413,-81.911766,-28.089566,145.726292,250.68857,236.896909,121.876409,72.383855,27.935244,26.225969,60.394894,92.81806,105.512127,161.229562,203.062425,193.960977,97.353995,-104.529946,-114.344184:250.884936,474.804859,518.207098,484.273538,414.939571,240.615344,210.30104,264.770558,251.552384,216.66617,136.672973,65.50686,-110.432188,-140.320437,-26.414453,45.741558,96.216146,124.629394,143.824368,78.417959,-8.290478,-122.693357,-107.897201,-14.094889,37.014568,37.629715,-2.809069,-34.259744,-59.071506,-29.011084,104.993507,180.152735,285.163844,303.097054,258.816934,84.041118,-0.273427,-72.32833,-58.027948,15.100759,99.038486,104.646219,-38.537859,-135.390739,-235.845533,-241.036752,-163.106227,-85.707091,40.506485,10.397277,-69.379736,-218.979607,-241.863613,-226.282602,-205.659825,-124.024945,-17.43213,-2.956778,-76.660653,-98.979367,-46.514455,-39.135997,-143.338444,-209.353905,-217.452008,-46.795296,17.446024,-9.474894,-73.78766,-147.583568,-121.313533,-42.487276,-11.890726,6.592899,2.17748,-47.840135,-192.219069,-229.21443,-153.819051,-70.700049,107.439226,255.249163,269.698138,184.438626,130.870454,73.734229,72.584471,83.108153,127.661607,183.207986,272.227177,270.649079,255.447273,273.928871,308.190741,300.783095,281.931751,287.61053,246.659896,44.885435,-68.164076,-185.277454,-157.693617,36.509193,224.824451,239.123217,110.735792,30.616888,-77.692287,-98.089513,-46.193043,16.171538,170.625707,251.452748,228.2807,121.284775,63.43678,-7.586086,15.838911,170.804258,305.57065,330.237723,347.773099,333.998065,235.36005,188.526538,165.992069,182.349935,267.358229,288.111931,206.86651,-10.505713,-68.577231,-101.673823,-109.325892,-99.686702,-21.33362,19.034772,-6.483821,-67.708596,-167.45614,-173.322971,-106.532592,-59.092353,61.714972,220.242445,264.76521,238.682542,174.668835,23.043131,1.716618,104.697272,248.874329,291.169321,262.979054,217.258056,121.855816,67.8245,-30.893882,-77.370907,-132.168724,-53.042439,-6.326165,-28.013964,-99.267622,-202.312037,-172.729089,-28.048807,38.294005,9.400803,-131.140033,-188.163868,-228.104369,-223.184234,-143.326012,-88.073376,-27.869688,-13.575818,-43.485388,-205.946463,-270.601866,-214.928698,-137.958637,-56.581957,-0.696304,42.200719,68.260789,36.393353,-87.671048,-133.241548,-102.972681,-71.507788,-40.552947,36.562753,59.801302,-33.400157,-117.730452,-158.844537,-81.219893,78.535312,25.044931,-34.549653,-86.002229,-71.559257,-68.117011,-105.025711,-154.499654,-140.260047,-64.800109,2.634498,-10.521521,-115.723897,-163.611008,-179.27775,-145.579975,-57.61924,0.204843,10.263198,-35.625653,-84.892107,-205.631645,-262.39363,-286.881001,-256.58566,-211.301835,-188.65356,-171.871662,-170.970726,-211.698272,-321.811746,-324.499177,-214.918268,-129.472581,-122.885402,-162.101175,-189.206884,-234.177665,-255.472774,-261.083338,-245.239178,-160.177069,12.497314,42.698602,-78.839872,-166.854076,-280.509595,-288.904872,-193.823676,-39.933086,3.991216,-35.193341,-101.022286,-240.47978,-290.81502,-261.937079,-178.145522,-21.468503,32.988148,46.899518,9.51722,-61.849203,-240.420886,-292.29855,-238.622595,-71.218085,-12.492908,20.494853,17.330383,-35.000414,-74.129783,-51.983596,24.027002,223.539746,324.880726,285.623167,64.892364,-53.854265,-144.092761,-87.064129,81.691018,111.469655,98.766097,63.045959,38.064349,0.64071,-12.104612,11.450427,66.586325,192.370376,252.064599,272.332097,257.879077,176.192399,-27.505899,-58.211964,-9.766297,39.9099,60.331173,78.469223,52.828996,-83.175027,-155.332307,-173.623352,-93.187063,171.646533,300.252897,235.556796,-41.313045,-158.056649,-179.985407,-86.779873,117.280068,148.861733,114.31064,16.808612,-38.588228,-160.212435,-210.901254,-182.658545,-100.775183,62.126336,124.408664,106.704523,47.478137,56.303803,101.644687,93.751433,56.830754,35.712968,22.720306,18.439745,31.34808,18.23904,-17.431717,-33.767961,-0.569309,79.419879,170.177463,190.858864,122.016387,49.896549,-97.125732,-132.183503,-36.74738,171.828714,231.577044,209.950318,155.189701,26.179088,-5.217947,73.932147,131.385706,120.490595,37.750993,14.079484,-34.295365,-62.374194,-114.203581,-123.094536,-31.992887,105.891828,113.864198,-11.206943,-90.880219,-179.18643,-180.308478,-136.728782,-104.811499,41.388102,206.951589,188.494846,-18.202105,-106.501947,-155.420012,-140.565228,-63.206223,46.61479,88.81775,157.358233,167.975692,56.712455,-25.882308,-33.518829,30.438963,142.823056,222.85523,224.280432,94.672811,14.918878,-64.181482,-75.508616,-49.920058,84.539791,142.746569,120.458112,80.504936,22.667584,-12.51078,-60.069192,-43.511544:56.988291,118.366056,189.60307,329.928939,329.906134,180.592781,112.533548,119.424158,170.933781,155.16854,79.775569,46.335235,-16.517321,-45.027975,-51.239538,-46.81822,-106.109944,-128.44295,-95.366121,-93.341847,-165.521938,-331.373823,-337.80979,-223.538627,-176.819565,-168.606321,-113.649375,-82.13366,-37.161414,-25.026732,3.043124,35.098339,128.262902,212.180231,218.654698,159.749785,131.507883,125.32212,135.550436,105.614927,52.63215,48.847883,-6.827358,-67.024675,-123.980888,-98.585289,0.175137,38.491191,39.153398,-47.928599,-111.154426,-176.023146,-157.373097,-94.71006,-65.598809,1.81389,1.405622,-56.504696,-162.298469,-131.975051,49.308076,90.580216,8.891716,-43.68193,-91.817365,-14.394085,63.251105,164.230238,161.866475,98.324565,85.730328,128.864986,148.04238,152.879059,150.617223,114.933884,-27.795835,-118.546403,-225.824101,-201.03719,-50.552507,124.90434,203.192833,278.343275,238.648738,40.487257,-31.883284,25.508574,222.627365,287.393856,291.041709,252.813242,206.93708,212.431915,203.179085,163.987143,63.486204,19.296614,9.819881,-0.94083,-3.075369,15.12287,62.542463,211.204224,268.965707,269.766865,248.428014,216.674086,127.758495,83.264069,91.776269,158.573931,305.549352,403.192685,400.503621,275.797187,213.448988,172.887452,198.190416,356.711657,521.215103,537.339621,429.799475,353.482183,228.62319,173.536865,157.669421,210.982645,287.476278,243.844532,191.904931,45.310295,-14.861793,-51.922201,-55.996293,-114.910339,-202.30918,-214.116741,-188.417976,-184.721453,-195.467945,-195.071863,-184.429456,-179.366307,-165.862204,-125.159627,-94.086861,-24.737183,-8.723766,-30.704857,-40.542216,14.619462,151.430954,209.548275,230.548848,225.603674,259.854676,248.863455,99.985638,3.166671,-100.231925,5.308109,87.136191,165.2607,159.038412,129.822137,145.833868,252.008065,295.016099,241.934029,49.963069,0.276724,120.167083,204.642821,219.431618,180.057466,98.839444,79.668091,101.895407,83.255792,36.053933,-0.904843,31.913263,115.909308,84.907733,40.026807,26.980395,72.10458,164.084539,150.539097,-10.931936,-87.657865,-109.404666,8.741423,63.056111,58.57104,20.097003,-34.122774,-27.794529,34.470476,35.161564,5.890895,-14.823189,14.216693,102.962665,126.284167,111.084683,100.027316,123.628148,193.829751,217.313393,191.810306,151.886301,103.248772,125.60842,203.460715,227.378475,234.804639,216.268422,171.884664,-2.063357,-114.814932,-227.732266,-212.847051,-208.717836,-219.221476,-197.043334,-168.290099,-169.633823,-196.227228,-234.555389,-318.687319,-248.631279,-170.07749,-100.005986,-115.93609,-136.109754,-130.248596,-129.355811,-132.89239,-101.659637,-13.044539,17.561846,22.7842,18.297635,36.53485,72.090849,153.797769,116.333515,91.559932,108.660057,108.686052,-2.543064,-86.773918,-105.86628,-24.54462,144.81643,192.767973,132.820522,-148.557579,-281.99512,-344.97158,-285.939862,-136.680655,-66.521446,-51.132348,-18.167413,8.612129,60.334973,63.87121,37.384201,29.775823,86.426642,163.656758,95.975451,-195.349523,-250.916389,-81.482045,22.083062,69.940208,-17.861,-64.210983,-132.963702,-136.827421,-74.402353,-35.266919,43.042633,70.897747,61.896081,71.566115,95.209582,79.098487,40.388502,-0.325627,1.482257,-4.628191,32.154067,74.904591,113.04149,102.799152,67.403933,17.530369,-175.539935,-248.128168,-195.588438,-36.663022,-23.515006,-124.613901,-158.560263,-119.582769,-85.088098,-54.884756,-37.446247,-29.334853,-61.873375,-100.927533,-165.495498,-170.166937,-98.964985,-40.710729,57.351069,65.686829,26.185668,-30.24208,-1.756175,78.585572,63.266274,-34.228093,-65.341554,-74.35148,-136.685024,-160.366591,-126.669975,-99.330155,-110.615693,-132.953585,-103.889134,67.693359,164.244213,239.283481,190.612044,17.003241,-6.413259,141.812691,231.465122,205.358423,144.581429,145.502666,153.251236,122.264319,51.413286,53.674807,75.515794,22.672893,-9.393883,-6.761822,2.609271,-73.31338,-124.036141,-117.949139,-43.637522,-23.033391,-24.561512,-26.646147,-11.720653,-16.743923,-35.987051,-24.494107,-34.895684,-119.463981,-131.124361,-72.430629,-47.749514,-86.776751,-115.507699,-88.478903,-45.232367,-40.966595,5.688358,33.587211,-23.996021,-93.524819,-146.804364,-115.713894,-4.134808,81.015646,79.365257,54.324709,59.897358,42.355422,12.144261,-53.145706,-123.631802,-126.490356,-31.985873,42.355204,151.144138,135.316292,41.460387,48.556515:-31.45352,77.59543,159.99568,290.966041,289.057435,182.562091,142.821183,110.634077,84.374292,108.353011,185.703662,157.260477,-48.777604,-130.222165,-77.229917,10.381726,60.352924,-36.278787,-62.783745,-102.38071,-166.749103,-317.842099,-328.801691,-229.680204,-134.205374,-101.412571,-47.850986,-25.536988,-0.838616,-1.475659,21.119332,68.570449,189.811558,278.449139,312.4869,337.099744,311.783985,242.187066,230.614704,223.433305,223.611368,239.237549,223.113762,174.56552,57.462877,16.883083,37.299237,84.341006,138.53424,134.48044,104.036022,-19.529621,-86.093272,-178.897325,-184.434649,-111.180162,-70.070097,-87.420312,-107.849692,-76.930296,4.432704,16.56393,23.448854,11.860877,-68.52021,17.193326,122.378187,193.310433,149.774694,81.293158,96.837722,182.86999,242.243819,264.893376,283.600437,244.673122,56.674084,-36.405844,-50.16803,16.394363,137.887019,218.588799,254.825431,302.381355,307.332964,258.332954,206.096522,103.408026,90.470536,138.673622,303.30794,367.152523,395.48721,376.965732,290.079974,212.651639,81.795286,134.879165,181.032452,202.382362,204.114084,234.307365,258.273185,293.77662,280.64874,277.280852,282.009452,257.110275,96.63283,-2.504064,-23.584685,59.588302,223.14037,358.416633,401.869561,348.94059,264.871277,104.608351,89.976113,210.78809,310.395216,303.647236,224.808803,185.431483,141.870939,131.385353,164.302376,215.024149,327.317282,346.964767,283.934471,77.702618,-20.5883,-187.161672,-239.764518,-231.989564,-211.100365,-233.465582,-248.356676,-217.922509,-146.23112,-137.078074,-127.726574,-111.045105,-117.046854,-113.605154,-51.318172,107.402223,139.144392,99.909305,76.068618,130.564206,277.027828,302.620433,193.199032,144.368644,234.440012,302.54381,242.961369,125.066382,-69.283875,-37.953635,41.864899,182.641846,174.053911,47.378168,60.038981,329.156503,469.379555,399.572151,166.568081,95.307936,81.335011,83.109721,57.211983,53.735589,11.253641,-78.516442,-90.005869,-78.871351,-92.54208,-144.924702,-127.308497,8.227109,35.869798,-10.69467,-98.594291,-84.354424,30.348568,48.369742,-23.078572,-47.389149,-2.244785,62.239584,48.785158,-18.020157,-26.792508,-43.582426,-68.688743,-79.744476,-54.636162,-58.525533,-85.918381,-85.55196,-54.822004,-54.333967,-57.213938,-24.742327,65.327068,86.787284,81.666429,63.115733,40.937917,-25.324842,-48.878418,-38.39032,34.065852,72.227894,70.245819,24.366882,-80.806486,-132.784243,-274.678369,-357.574788,-445.636378,-313.820712,-237.468899,-243.478451,-287.511367,-315.348215,-298.369088,-235.579815,-177.297649,-168.483898,-166.054641,-155.534876,-136.530638,-153.363767,-218.720106,-214.555923,-78.536829,81.405305,112.268537,142.25324,176.104017,208.555141,194.146373,178.195637,188.381167,192.079865,132.992543,78.874296,-1.192383,-21.774217,47.550122,139.203329,254.955823,171.924177,90.827181,-90.59813,-174.21965,-252.312824,-229.667797,-99.341698,10.316116,34.795029,42.50574,43.530474,85.758507,104.842214,67.823439,30.191018,21.149856,117.068409,133.30022,37.225115,-8.282961,4.74852,31.842682,40.076609,30.666552,66.779154,129.36016,101.456829,2.963403,-16.206091,4.707119,6.851096,-33.453897,15.664506,55.833538,22.560347,-22.32124,-23.800613,11.617579,15.314283,-21.297324,1.67793,47.706676,49.251598,78.813607,97.9194,36.9862,-34.838413,-72.625017,79.163373,102.996567,-68.660054,-171.248599,-219.067315,-183.113319,-111.762195,-41.625361,21.974155,108.204626,93.283374,18.448501,0.778894,27.453613,46.349598,100.603837,210.259817,236.819825,255.392477,292.254956,395.852059,417.345655,347.05977,252.572448,240.480495,227.771429,211.178814,168.788116,148.091705,102.686475,72.915304,68.14383,197.6468,273.268246,348.970347,324.968786,156.508506,75.124676,56.290521,89.460503,85.509083,87.367208,98.146927,69.885303,9.94966,-83.886725,-87.244556,-104.881299,-153.277957,-180.340629,-262.390783,-313.975872,-428.999713,-463.814951,-436.604808,-380.564057,-371.696859,-368.833843,-362.905338,-352.253056,-343.146734,-277.300704,-236.621012,-238.731422,-336.024732,-368.342994,-357.308157,-334.012622,-274.437819,-232.324501,-190.79823,-252.7502,-272.514436,-236.001777,-214.109128,-211.66352,-216.438521,-195.285643,-149.865068,-28.845416,-7.213242,-10.660136,43.336208,69.328434,25.270214,-9.347628,1.195523,20.386251,1.365454,-37.628697,-28.021177,-12.009191,-45.68691,-122.116826,-119.442571:152.256545,263.561832,275.739655,265.418713,248.084515,162.290613,117.512651,125.186645,195.785323,197.755528,106.179194,53.229902,-1.145184,-14.08927,-7.233388,-6.00672,-101.713501,-154.674166,-106.242714,-66.234623,-123.282803,-230.67428,-212.209469,-84.516206,-60.207904,-79.631188,-68.148796,-43.727047,-24.429541,-41.391249,-64.794245,-23.842888,160.924406,253.724568,214.902736,106.329735,90.379342,89.210801,78.197229,21.653988,-39.09586,-40.917007,-46.337756,-68.510931,-113.069952,-119.730538,-63.667288,-9.464466,44.069224,16.108082,3.443046,-30.88032,-57.305641,-82.530552,-68.508,-6.852908,9.525685,-39.774077,-151.322542,-129.264158,10.740632,20.388756,-99.288927,-146.976124,-150.433763,-62.54668,-15.347396,0.717613,-31.13058,-60.016429,-28.623276,-11.283689,-95.032827,-97.248024,-41.309446,-42.487753,-165.383065,-243.088948,-248.0625,-197.180085,-114.507951,42.042988,117.663728,97.79922,32.607092,-74.505303,-109.180899,-109.844422,59.187406,150.937451,224.608483,242.482988,287.626163,278.128605,200.506787,166.60418,100.625223,25.256801,-16.934826,-109.459409,-149.850801,-183.432393,-151.917492,11.952846,137.812423,137.256794,51.619971,19.959659,42.172342,61.323287,109.02581,156.138999,213.508673,198.069264,199.153328,198.589693,182.149125,146.77543,151.811441,201.83315,240.457962,268.206485,298.816362,258.200544,117.142497,82.272674,124.793845,153.514272,169.009841,161.874939,125.372081,8.99061,-38.461362,-93.822831,-97.610421,-55.963951,-13.888263,-4.990376,-41.389846,-92.959742,-173.121174,-169.791374,-125.244071,-120.940923,-133.413223,-29.40972,42.51873,96.426572,78.809961,13.938838,2.160703,78.831389,167.60455,169.661994,95.061337,54.965252,81.952233,100.635239,-37.777942,-153.504768,-234.666268,-68.805838,-0.556675,-40.883082,-96.207451,-119.70928,-77.238838,27.374906,14.25419,-23.553229,-109.025848,-134.093638,-93.334208,-59.998168,-36.63122,-43.633624,-52.49289,-15.310414,-23.393873,-140.815889,-184.049707,-110.016494,-35.066927,79.951478,133.154418,124.037575,57.973513,36.894613,36.620902,32.715987,28.491662,36.223052,60.589725,160.661862,200.083241,111.049587,22.496855,-33.019487,16.152271,123.517194,116.546049,94.499458,19.240548,-37.078043,-84.926607,-60.482343,33.611825,77.360445,126.744888,186.549259,199.388651,87.496406,-5.435712,-98.104522,-73.74453,45.728175,96.553537,100.201148,88.977117,53.739765,-49.761385,-95.22934,-136.651065,-141.537356,-171.334256,-167.913471,-150.709669,-133.35369,-141.664271,-228.178326,-295.023834,-342.70158,-204.533696,-124.060331,-75.414886,-98.895392,-165.432102,-205.126089,-266.642142,-262.848192,-165.076469,-22.712452,-19.838233,-135.149585,-159.533433,-94.600871,-59.813869,-51.35807,-93.632566,-104.268604,-66.672403,-45.627814,-88.696837,-140.022452,-156.656823,-99.320904,44.324355,104.895165,75.297154,-71.542898,-138.506495,-222.184222,-235.092144,-213.144101,-168.19518,-101.836493,48.562666,76.251209,68.228216,59.414672,44.645369,41.020457,63.587996,92.500991,54.37777,-101.21474,-145.863017,-63.664629,23.858737,81.522204,10.36419,7.074489,36.951527,32.385107,8.28965,3.894764,38.558219,80.505123,153.584043,198.710875,208.49713,202.903897,203.850018,197.03372,169.901093,129.735948,196.325698,219.839133,148.16002,86.262126,-15.858835,-71.716474,-128.603577,-89.837381,40.362406,89.911843,68.603526,5.714419,-22.985782,-94.46215,-99.524066,-8.022056,85.985755,102.922081,28.592036,-53.468598,-193.059317,-221.460134,-172.977742,-115.69408,2.689307,105.343087,122.491201,100.036791,105.385676,104.713665,63.22624,-44.353673,-69.28782,-16.2216,90.612914,67.539779,-38.804888,-52.048189,-14.928237,-2.211354,-0.689712,71.938968,120.590525,129.31967,78.831839,-57.883295,-75.018392,65.36204,199.614714,205.941045,188.297645,181.809063,142.15897,106.308286,43.862389,26.785564,11.531012,67.162492,113.12271,133.426063,91.989366,-42.053611,-90.991349,-79.715685,73.951095,141.904631,106.759108,33.285176,-74.001682,-88.543551,-37.209315,-1.10271,1.82844,-15.368807,-1.596999,1.01535,-26.287565,-111.819278,-139.62454,-96.983934,0.299343,41.343409,101.407603,104.233733,30.584923,-35.039406,-103.86623,-72.442697,62.082431,131.108324,128.530826,115.785637,107.347697,24.861407,-43.687525,-122.389091,-89.237839,-51.514326,45.463481,72.295948,26.097926,-22.127158,-70.538397,-59.317247:left
219.798105,151.297441,116.75253,127.233727,137.118993,87.922471,64.158923,88.579645,120.848026,120.282387,126.118576,136.358442,96.002548,17.855568,-120.546474,-119.014595,-62.401838,-65.194213,-84.623681,-133.909913,-138.525303,-95.809244,-78.636167,-77.821195,-61.532756,-12.242605,126.705471,162.882001,197.033193,236.988623,359.379993,412.787558,426.815855,408.825352,450.745145,546.935315,538.912548,431.385822,406.955878,510.474945,582.86965,562.86117,539.772754,534.350057,433.90218,359.004097,310.06623,334.801515,352.143429,361.233093,402.233286,441.623836,392.585186,245.958572,188.843711,127.298631,245.203132,364.888184,515.97255,493.351841,316.757614,214.248775,133.723009,198.058825,400.008283,417.84131,332.378472,170.012271,163.868938,185.935941,152.684937,73.557473,97.476193,114.717065,63.454861,18.413452,-0.442922,17.977015,21.706639,6.211883,4.054383,79.276079,119.011298,142.318841,123.600542,11.970669,-56.520068,-73.714651,21.936532,63.136332,160.947713,209.07542,251.874658,245.626556,192.039436,171.576115,195.808742,239.868286,237.938854,201.656464,163.570384,-13.522987,-124.791961,-202.376549,-35.438987,62.952738,145.063585,146.643768,152.098939,126.711757,26.478428,29.547117,172.723151,195.797941,89.302983,-159.716423,-190.247964,-149.052394,-177.842962,-269.262311,-174.30263,-65.989351,159.893913,238.666433,273.150016,236.663996,161.410012,154.197776,174.073994,223.155564,241.169095,216.699746,195.916138,157.40186,122.282077,51.221751,99.936546,151.324347,147.74193,91.591296,-20.803073,-54.196219,-72.376222,-76.26906,-80.767052,-6.14859,23.532322,-28.538547,-83.789795,-178.058148,-205.988628,-155.404287,-72.652156,-95.201975,-202.429711,-220.883355,-158.71576,-145.740128,-221.222879,-231.356916,-83.656705,136.780165,206.008227,189.070884,117.495354,-47.5287,-86.148974,-36.923803,29.78172,34.960504,-16.303917,-70.849104,-218.065277,-298.19682,-357.800659,-300.740946,-134.769051,-64.767116,-66.857827,-119.569089,-146.644408,-148.721753,-129.873135,-121.794069,-164.278769,-166.99139,-152.886192,-156.713924,-154.794922,-158.835377,-201.877367,-194.679067,-45.693985,154.100449,204.311828,157.7082,96.660326,-30.920483,-81.090985,-75.914882,23.528829,51.767322,21.719418,-11.320452,-51.209354,-82.153085,-199.344913,-236.192446,-195.352015,-145.853077,-150.111542,-188.504247,-219.813088,-300.750738,-342.254176,-378.278654,-300.218737,-227.877592,-106.201103,-98.349021,-173.806486,-212.597901,-204.597474,-169.828977,-183.232245,-230.216827,-208.121081,-175.005458,-188.194342,-241.273694,-264.899826,-301.003667,-343.033891,-317.574289,-149.337782,-92.495564,-173.469641,-259.602153,-337.660762,-324.521102,-256.483044,-116.455109,-57.656257,-126.467863,-237.394911,-445.530572,-498.098245,-463.096799,-385.445362,-376.952769,-357.835785,-339.289128,-328.530542,-335.723253,-281.757871,-203.268512,-55.742097,26.668451,61.682917,107.031703,115.516956,86.714387,57.104711,7.201303,-27.02592,-10.113732,71.066283,111.195028,180.693718,173.410355,64.780918,34.085749,68.387453,131.728515,151.673615,96.498139,16.897521,-136.297614,-152.302315,-66.795382,-3.619045,18.641665,30.500625,-22.497823,-178.53144,-221.915958,-241.0315,-254.63397,-258.949489,-90.682799,-7.92073,10.454773,1.139877,4.892551,-5.027867,7.985966,35.456772,7.445469,-51.802775,-50.516156,-87.39112,-146.055454,-197.115191,-142.044104,43.386004,176.994674,200.955144,124.844968,38.330641,-147.224909,-206.982174,-182.406118,-70.131843,-42.150358,-87.098751,-142.921451,-241.320276,-286.830792,-391.034333,-418.371409,-365.726799,-212.599753,-131.787097,-49.783899,-61.801373,-178.019414,-243.8257,-229.538906,-56.705943,11.08722,2.55114,-60.916128,-166.842886,-183.271437,-170.688995,-160.391888,-173.645802,-144.997538,-93.013279,-4.906078,-12.367206,-138.502756,-200.70876,-209.844938,-108.827781,-35.230412,57.862466,46.539431,-26.819059,-57.571894,-91.445597,-93.65389,-71.360697,-43.343135,-43.03076,-61.548421,-72.144845,-95.262458,-82.959111,14.498571,133.529799,208.987099,351.198449,355.93035,200.357719,100.076192,0.924969,18.557722,140.407305,254.922563,267.874036,211.124975,171.834812,64.719771,-0.402148,-40.796292,24.665664,48.591161,45.040469,14.479656,-86.613213,-125.298873,-82.4566,-12.399517,76.836775,42.320538,23.79409,44.550309,64.61653,6.154841,-63.111319,-78.095428,123.298406,219.152693,265.811168,232.218419,133.965873,70.955772,-75.659361,-142.232071:103.978444,30.036912,25.232118,81.033279,117.003322,92.972192,35.951806,5.118223,141.822431,203.805004,190.676728,144.56594,63.937749,3.829265,-137.054261,-179.726324,-236.351936,-186.018067,-95.96895,-41.589209,-128.245631,-284.600654,-270.795868,-141.934797,-49.701037,-5.492569,75.541181,82.257454,96.370712,142.440331,275.626452,321.441845,317.564369,273.0972,270.086536,302.560813,306.830216,228.396017,199.783452,312.100174,454.453519,461.259078,408.089007,371.892705,294.260234,264.329063,258.739837,281.722082,351.083451,403.781966,395.853723,332.101928,298.094102,201.272396,145.163323,112.438094,225.022949,303.41069,392.085013,389.26595,254.090954,124.643277,-5.533128,58.208593,228.301701,268.478775,266.781851,209.688176,149.863788,23.348494,-27.597586,-80.891999,-10.287976,68.595363,141.094732,93.474565,-23.240456,-35.703689,23.585745,72.002703,129.681352,84.357849,41.668795,9.496354,20.353664,48.313308,74.921756,113.59492,44.850721,21.315478,96.597786,155.637998,190.735788,175.978767,119.493505,78.690022,89.942898,282.918981,348.499112,334.78241,301.275959,181.103507,86.094511,-52.62433,-18.265408,35.248689,151.911984,183.722509,130.650379,57.940037,-46.626745,-32.313546,47.061584,15.204461,-43.968171,-171.552779,-213.106713,-236.348574,-233.228264,-243.683507,-203.253524,-108.112939,153.286408,231.585704,225.048925,206.954902,265.799778,312.960723,373.939582,402.547735,380.96078,297.116956,265.709577,219.899482,200.923621,150.685154,146.290415,187.046134,243.731845,223.401365,119.121832,60.395127,-37.215182,-53.424534,36.026798,184.763226,180.923196,1.392352,-96.532443,-197.427387,-188.274925,-78.579659,16.632302,48.533543,77.979785,56.220023,-40.764674,-90.173708,-134.835665,-122.439519,-26.884278,144.978169,210.032219,173.668626,78.547122,-129.199869,-169.122677,-55.642459,104.057049,117.634307,-14.528128,-112.115635,-233.585163,-240.694053,-178.999047,-131.586403,-35.703288,3.44411,-29.732712,-131.577195,-144.618238,-96.751436,-84.394357,-125.192081,-114.373359,-50.266052,85.080708,95.12564,-22.493909,-116.010466,-219.601689,-177.740878,58.849635,244.162469,253.842262,189.654189,143.107398,9.187326,-40.193301,-2.149558,86.159782,87.022339,51.01475,42.683379,3.636812,-44.015353,-132.696893,-147.955052,-143.454419,-131.263595,-120.051824,-107.128806,-145.331944,-270.300488,-276.960478,-181.119893,-161.120909,-175.190114,-172.574548,-164.024571,-179.455768,-222.63332,-288.11756,-245.095209,-103.330061,-78.917507,-78.268221,-78.188319,-113.156944,-242.485991,-279.56415,-242.941634,-161.560579,-105.726944,-16.864809,-38.455267,-188.980599,-256.019654,-291.351412,-259.04489,-129.387645,-32.700433,-44.344509,-146.397761,-204.245326,-340.695018,-386.858679,-317.675798,-185.097082,-183.0596,-247.575486,-258.400492,-249.124569,-250.389357,-199.796111,-123.378446,56.99887,170.434653,218.804124,291.849426,274.959064,151.270592,94.182953,53.432361,110.58116,161.278099,213.055301,193.595806,139.939957,127.584804,160.865172,206.236377,244.011908,208.522344,191.650199,149.921512,116.030335,20.319876,-5.346641,10.704837,32.909051,52.37382,31.384722,-36.318465,-200.423777,-256.344383,-274.618294,-258.8153,-234.958065,-103.412847,1.872778,88.297193,58.443497,-15.062554,-22.393812,-2.411271,-27.293664,-52.334612,-99.827359,-118.465553,-179.612086,-237.426541,-288.563578,-222.960616,23.102515,205.194643,233.435121,143.895879,43.006516,-155.891995,-201.873812,-145.471295,-18.277118,17.810929,-31.767284,-104.968011,-208.13075,-221.276155,-223.161962,-205.147173,-109.587628,7.586345,45.441531,68.784094,49.702533,-64.440479,-126.51549,-153.696816,-25.369449,53.417006,62.190736,-12.536035,-164.933735,-217.30012,-281.088722,-261.285034,-116.734758,-11.899046,2.844165,10.645255,6.301802,-62.195512,-116.430402,-178.561389,-101.610953,-23.31013,64.935052,37.573976,-109.585163,-187.382554,-242.098924,-204.059913,-113.997754,-130.778456,-160.355325,-199.897172,-205.241348,-215.697044,-201.868186,-81.584781,89.973798,181.556353,272.741087,221.611665,24.236244,-35.57522,-20.581357,9.727558,63.322954,133.929639,146.18428,94.666095,61.035769,31.430514,23.005687,-59.275417,-127.901015,-105.05861,-59.076813,-77.449461,-178.821946,-227.142563,-196.442512,-112.538896,44.092895,76.465195,59.216948,23.379165,4.782369,-112.492137,-173.765773,-104.983257,108.107729,162.443234,153.925321,136.099268,71.802353,3.247189,-129.181334,-141.393692:101.481295,140.834812,156.189243,187.685131,183.426463,120.819047,93.53301,75.409206,96.03502,114.081509,77.155384,30.349675,-58.840354,-111.893158,-203.279983,-215.468033,-190.050394,-124.776256,-116.258101,-249.305682,-341.080672,-329.689323,-213.401603,14.581542,37.006355,1.779069,-67.42335,-82.815431,16.731832,129.657263,277.58153,268.332159,221.806384,248.04347,239.973874,141.774036,94.008686,84.973245,109.357191,121.12158,119.997048,165.371522,283.334391,285.236567,168.912695,125.847677,173.446278,233.127795,369.074643,455.471693,409.772517,202.68107,125.131062,47.970154,20.92185,35.842713,225.410552,332.289883,376.307784,322.409173,181.388202,109.751568,24.156224,39.203938,163.126993,272.125481,283.333278,213.803072,141.832635,-18.175847,-73.246759,-73.157651,75.607808,156.277095,175.392673,122.571953,8.469806,-29.300686,-9.53568,62.245705,233.199259,245.090462,197.316704,138.886357,121.048133,21.210546,-28.024208,-16.667364,114.278935,183.956066,239.882976,232.076386,235.051961,242.206326,212.731692,187.64557,180.296496,285.481031,359.362482,398.268994,324.277152,93.844712,22.241016,18.907161,51.159213,60.26152,103.516808,122.861986,105.598338,68.225852,-46.273833,-81.181633,1.783437,111.238648,55.068395,-198.540957,-286.972388,-337.277324,-329.929798,-283.86135,-183.077407,-99.166352,72.284596,121.004179,116.068943,90.103832,107.113158,164.726041,310.250771,365.898925,365.580752,385.307064,359.503624,151.167874,55.908951,64.599101,212.226386,267.815801,272.341557,227.647706,103.55188,47.479928,-5.974411,-6.298248,24.294822,104.037011,113.08495,18.574516,-64.868267,-242.830937,-263.585277,-72.853837,145.120915,188.226745,168.375462,120.503791,47.074643,43.526658,28.475122,3.977196,-24.417062,62.070284,127.814476,114.432569,20.018183,-154.249268,-154.816899,-15.89289,87.065162,96.792677,48.248713,0.209327,-122.274091,-169.098807,-160.607951,-104.04849,58.587125,126.711211,89.565913,-35.665719,-83.254773,-114.936802,-108.655528,-97.55684,-85.518758,-67.420299,-1.816964,31.84346,11.987114,-66.548797,-217.030621,-185.785401,74.132519,259.582585,272.800404,239.136199,222.512632,144.135279,94.157983,111.804468,162.37327,118.890107,12.623876,-8.352419,-80.40427,-143.901466,-202.203583,-175.425149,-100.448983,-62.420276,-52.750776,-90.016878,-147.043239,-260.886386,-270.325198,-172.760611,-15.718471,39.021045,9.933454,-50.330835,-147.17948,-183.562502,-185.514254,-124.991779,-9.071056,-30.198466,-57.177246,-96.697697,-125.56871,-220.634567,-238.19799,-144.172941,-69.434867,-58.543207,19.572442,51.362394,-72.295103,-176.012712,-174.295745,-79.210315,13.1998,-48.432179,-50.225219,-35.71009,-79.132855,-229.365978,-272.204571,-242.193644,-177.044853,-161.982816,-152.402709,-153.919206,-164.44977,-172.323542,-184.547832,-152.447248,39.666509,201.698648,233.527916,261.807478,247.238857,167.700534,146.176698,156.489284,169.279644,174.721839,171.743402,154.54297,117.518504,121.662516,181.426236,207.822627,201.846184,192.480953,180.689364,77.326232,4.655126,-106.98099,-107.646605,-16.596,-10.133118,-25.945629,-23.866504,-39.691873,-140.519743,-189.754909,-206.480352,-190.280184,-161.453146,-66.934766,1.784428,99.947046,106.82911,4.79998,-66.917234,-136.172742,-118.898163,-91.15398,-61.158656,-97.679897,-259.907108,-331.03112,-329.571842,-250.146539,2.438897,208.411467,231.334823,133.58988,49.342151,-82.385417,-98.653141,-66.943111,-26.383692,-6.606602,3.17769,-17.503276,-93.802049,-118.567411,-65.125408,-9.160324,74.840521,164.748912,207.833045,227.495133,189.575679,27.083036,-40.132828,-3.314024,160.452323,206.610546,120.905137,32.075676,-70.537128,-93.824162,-105.191511,-66.456067,60.116916,121.835859,117.043621,81.406423,62.299389,16.965021,2.191473,2.457512,23.867316,22.326566,-39.489526,-70.432458,-118.164083,-159.074321,-226.613584,-223.587336,-177.498503,-143.163393,-144.69957,-204.582987,-237.229691,-230.745705,-177.117517,-16.247074,69.762712,99.817005,156.872085,139.977135,25.596317,-1.471859,24.042578,11.329217,-21.44468,141.837341,219.661961,192.890191,122.742654,-23.228252,-76.516842,-165.205406,-204.217796,-171.234769,-77.378766,-72.016721,-163.245977,-200.53521,-160.457278,-117.302855,-36.340528,34.319967,30.555085,5.685798,8.932614,-69.389937,-130.324629,-82.443516,126.411252,193.390714,194.765682,162.158378,64.30871,-2.739643,-101.382502,-112.420359:239.424817,314.48914,319.790178,248.876026,184.027357,53.054477,12.900822,34.683162,105.215813,114.222101,84.688929,57.659843,-49.047304,-136.06235,-246.657083,-217.71351,-104.282044,-75.113592,-100.874998,-235.820841,-307.37789,-336.768217,-291.226542,-165.106135,-71.114599,-22.819668,77.723818,98.376784,113.120179,146.61327,226.178648,247.569546,314.107612,426.985703,442.25044,347.056853,283.057755,224.055289,226.235027,267.904315,343.098174,382.662748,415.489442,390.449982,307.366402,272.835759,231.015801,231.363567,321.46297,466.529306,475.448715,315.714303,208.802735,69.881997,35.663802,21.554253,154.333657,257.20101,358.087745,346.657051,266.679036,200.292492,104.815232,123.468293,236.795983,275.619792,252.559152,224.307562,220.06079,140.398085,77.253196,7.118199,65.151642,131.173728,236.005019,234.679321,114.671121,41.228034,34.070752,107.464566,229.31132,242.257421,247.10822,261.11231,239.278702,104.218735,42.080875,64.823258,244.54876,335.993716,455.172321,494.043163,517.865386,476.195354,334.471179,291.590168,310.474153,385.408652,404.58861,353.681254,282.838372,105.94521,42.473874,36.692086,87.623198,88.816121,80.621341,79.371799,34.568763,-20.109042,-97.498781,-68.672425,72.02694,97.269812,19.741153,-210.291808,-295.77594,-401.673409,-433.36549,-437.074761,-318.771201,-194.430696,41.546215,80.745108,27.73675,-18.149722,-82.232468,-78.498173,22.576602,130.232374,131.154513,82.852323,80.661981,79.053998,50.80683,7.657278,110.336386,198.533608,273.372466,242.26127,139.799834,82.893711,-4.579946,-1.854336,65.9864,126.079632,140.42024,114.291697,60.957417,-82.534669,-101.898127,25.649847,155.267781,180.414163,131.156048,57.574326,-8.059364,21.773167,58.666374,60.396521,136.750052,319.359383,373.091299,281.630808,189.602071,67.924297,47.628381,62.344337,95.063834,109.071229,67.618927,-14.675747,-198.068884,-240.287332,-217.477788,-163.067941,2.721152,110.67567,91.279248,-51.765637,-107.206486,-115.535745,-93.885348,-83.640382,-153.861909,-178.201701,-123.716026,-47.152589,75.060203,54.781782,-66.029471,-59.538388,164.527727,371.849585,386.075949,327.631696,292.795372,145.995506,48.315253,8.310648,134.410982,159.966285,106.864602,63.024235,-48.743783,-113.719776,-178.646557,-174.079773,-163.757398,-122.963805,-76.389997,-34.206928,-78.332006,-217.01805,-252.538576,-242.981136,-183.726373,-137.178472,-57.017304,-52.203211,-142.747341,-214.079375,-246.840587,-185.441545,-65.137028,-77.853991,-120.097433,-218.494149,-260.791298,-337.732035,-344.69689,-265.924573,-177.321698,-118.487135,-18.69426,-37.475414,-191.657629,-278.664384,-353.615117,-328.202094,-256.357186,-200.649074,-165.560295,-170.218976,-237.596356,-418.862349,-474.997316,-444.922885,-314.356319,-245.81543,-159.350993,-178.736385,-300.741362,-344.160066,-298.328905,-210.830489,-31.044758,54.615656,91.967485,180.671678,186.684917,43.885677,-51.709351,-137.635362,-78.778993,-10.668356,92.819037,85.673175,29.182604,31.794966,95.592153,136.47917,212.292507,242.034815,236.567538,182.318106,117.370492,-48.570864,-72.136074,51.893741,115.647564,86.285755,10.657039,-6.726513,3.611765,-3.353729,-85.637171,-126.696416,-104.94628,21.840749,62.657661,59.853602,49.251895,29.217383,0.569359,-77.742744,-56.142766,7.498006,86.521811,64.240572,-57.832934,-138.595644,-243.100338,-218.216928,-28.387016,180.172606,224.171023,138.310346,29.370345,-207.757739,-278.880418,-264.488869,-158.674802,-114.892014,-132.555681,-200.708775,-315.134899,-327.337169,-285.564617,-239.187823,-170.971575,-135.731088,-84.356737,15.744718,15.871051,-84.51098,-149.026248,-181.795891,-40.782806,53.332368,123.892912,62.435713,-156.616388,-235.592677,-257.782106,-223.731321,-126.41987,-18.450518,32.198925,67.187979,40.01476,-60.637184,-98.270207,-105.124363,-51.63948,-19.579867,5.457173,-8.763073,-64.885551,-105.300877,-200.782057,-228.853369,-211.142656,-148.606374,-123.97169,-98.733372,-93.451748,-103.890507,-104.543242,-51.268932,61.126858,139.559966,277.048658,289.290361,151.233841,45.254624,-43.500968,-1.668479,126.834724,195.200667,205.989411,167.791437,123.744866,14.055093,-29.703124,-47.747903,-41.268025,-32.612525,-9.007698,-28.684224,-97.454152,-100.459234,-40.619848,4.56109,89.975091,88.622509,59.238299,72.242554,117.618911,95.774223,16.060443,-32.172927,187.269175,306.615102,362.418871,310.485308,185.784655,106.078503,-94.637904,-160.909248:261.930082,368.596341,376.054195,261.791966,170.974792,-17.434957,-76.150343,-53.344898,53.351446,89.443197,45.550044,-25.784687,-186.917516,-267.918091,-358.596367,-340.503684,-236.602648,-149.168519,-160.184967,-313.19826,-386.82046,-357.55604,-274.563729,-133.798452,-94.448789,-68.159658,14.045616,20.564477,-0.594969,43.208907,195.960996,240.024601,283.331532,324.233068,329.697381,264.199149,184.374551,49.159771,56.676462,159.591199,205.165103,209.999451,210.616501,204.00043,142.341577,92.848055,75.09006,129.058687,310.819885,431.440736,396.117077,193.516007,102.429519,-43.701288,-109.714027,-106.274475,151.683336,291.195409,336.993818,259.947728,89.476149,24.900735,48.32732,149.21944,298.270392,245.393783,199.363542,145.580597,106.317608,-52.035572,-117.99735,-92.39047,102.545521,195.657705,215.720783,155.665553,40.708131,15.588016,83.496499,171.344641,319.082809,326.772949,292.389693,208.323854,176.87661,113.951464,83.350862,87.754892,249.009111,365.928327,485.081256,472.970598,399.551592,346.150975,234.470068,213.697283,305.831666,450.595368,457.861898,342.197209,260.009689,118.347739,74.25885,40.388312,61.224363,81.349235,84.053822,52.72683,-35.646232,-77.352945,-136.940368,-120.602808,33.363662,106.025326,29.612748,-230.390528,-344.065193,-488.451266,-498.038679,-399.909466,-247.833074,-178.649487,-131.243254,-148.221281,-194.737651,-207.269381,-167.066077,-121.925135,-14.045436,111.574253,140.268609,89.156295,31.385564,-76.65133,-88.497383,-15.2661,127.571453,204.567404,264.299526,239.117332,168.478413,139.898273,80.212926,58.802808,118.23555,263.3049,254.425305,40.324381,-81.325484,-190.664724,-152.613645,52.829213,257.214325,302.898801,206.450566,112.022149,41.629587,60.039851,63.763519,61.331771,130.539055,251.399816,284.218538,196.53119,95.547103,-50.474647,-45.286633,67.686497,138.626122,141.82005,61.719952,-12.593493,-126.239903,-159.704012,-210.390798,-188.200987,16.828641,171.694743,133.531236,-56.70316,-134.269787,-214.484974,-217.347729,-157.606661,-69.054643,-33.269055,0.062249,19.930039,48.813382,17.991433,-25.946983,39.276194,311.941261,449.417021,387.398183,211.055665,188.11454,194.845219,181.832542,184.092648,237.630979,246.540193,199.264315,128.911717,-86.859452,-165.607111,-136.115694,-75.588224,-26.926796,0.978282,25.901318,-7.43613,-80.261716,-202.875284,-198.683402,-134.687303,-87.812594,-56.981735,-40.441877,-63.528083,-133.604149,-179.952604,-236.766409,-210.105997,-91.591763,-22.841968,-25.998707,-123.225665,-202.12756,-331.17998,-351.048146,-289.31164,-153.757651,-75.531917,21.249795,2.015887,-153.537149,-223.87047,-209.121028,-157.750156,-125.846536,-149.020214,-131.719125,-118.302386,-174.882898,-342.265216,-385.309553,-336.391168,-174.262649,-87.871198,-8.531785,-28.916144,-136.6084,-192.690306,-183.79432,-102.46789,66.978245,93.842274,96.327585,145.867721,134.520537,-38.50863,-130.058221,-132.856532,37.448361,104.283609,122.936631,95.731227,47.786265,35.700287,53.781754,106.803855,279.221069,334.138328,250.048307,18.232855,-35.387177,-20.371097,26.629949,126.307376,118.176667,91.835831,42.417219,40.520463,67.919147,43.080264,-72.668249,-92.441704,-7.772359,124.183307,171.581559,146.402025,67.326397,-95.226334,-125.523758,-105.543299,-10.873413,52.815445,98.777277,72.65418,-32.715422,-95.133026,-161.150989,-142.81892,0.452475,210.49907,263.843482,166.153688,59.765402,-99.961532,-120.689732,-66.745977,32.591535,73.724357,55.175988,3.144774,-94.352752,-113.861854,-75.789087,-48.241807,4.324076,101.831123,114.660119,33.751123,-19.013555,-103.337684,-113.874632,-8.448366,186.430356,267.405709,267.947115,168.692371,-75.349717,-158.026872,-166.930207,-84.020973,128.377353,214.463168,220.134169,190.479196,135.814416,30.384971,31.712415,75.474281,95.387204,102.727036,77.249665,42.143473,-90.137713,-189.201666,-310.47765,-287.705669,-169.372542,-74.663254,-58.287512,-115.269818,-162.342685,-202.782835,-179.113229,-72.447031,39.288537,71.052403,73.272049,67.935589,73.770341,75.137903,70.40293,68.810198,100.116947,209.656044,247.754854,139.588601,4.176325,-198.070336,-182.722611,-24.959753,18.512748,-4.020506,-51.88285,-77.423613,-161.045223,-186.613788,-108.096885,-42.369225,47.828685,103.940095,98.395116,62.424117,71.858957,82.889821,69.792259,113.809921,286.601725,384.009698,457.48465,401.981209,202.963982,113.367713,-10.010229,-49.259854:351.610164,413.221227,399.95938,333.694813,310.58662,246.328083,195.672009,149.83251,153.76104,143.643434,122.925497,109.234555,64.307655,36.562455,-35.063777,-60.272131,-44.728077,-40.11942,-77.60871,-171.535809,-181.346634,-151.929872,-145.883144,-109.210404,13.220393,90.441567,213.878286,241.853406,258.55493,274.470687,372.079825,436.130731,479.812665,469.353065,491.395738,541.704679,535.131231,438.486365,412.361558,541.914541,619.819064,574.976711,490.65629,467.496224,383.516446,330.793957,264.637776,246.733494,223.643772,263.027283,277.407992,197.696845,133.209065,37.30922,1.01711,-18.684449,103.055428,190.479955,301.619116,308.644338,230.455448,164.496149,115.572631,167.74565,342.734567,418.705334,370.54087,253.273905,273.176559,334.217256,282.672681,139.619626,201.464133,275.23296,370.4742,363.11092,208.924053,113.245362,71.943875,122.564683,201.831,186.634561,173.134016,204.076331,232.629917,152.364548,61.15285,-2.581688,80.332871,123.566274,195.67236,245.379299,361.176004,381.546235,336.27084,303.638227,216.669176,162.651045,173.046796,179.44283,153.430832,30.497375,-61.947763,-153.033101,16.671358,130.282673,215.677651,196.744078,145.059961,99.031626,10.431517,26.820202,110.371161,38.856707,-67.899698,-274.458603,-307.234921,-303.605646,-334.963363,-394.518757,-262.285299,-145.4827,19.099051,28.069022,-69.144438,-123.529107,-130.561896,-91.593892,-18.733948,3.169156,-21.684169,-129.606286,-168.472838,-153.88955,-129.897384,-111.211045,-32.672995,35.976928,103.27747,93.162346,77.362109,63.966772,-38.000778,-90.23042,-67.593957,80.323261,108.803538,17.617074,-48.249132,-114.116162,-88.965612,39.322492,68.634457,22.860166,-100.557653,-133.822743,-76.415451,-30.683306,-21.187118,-8.461302,142.493376,316.909829,363.403091,341.786165,280.299985,161.314171,136.663834,91.967954,12.972316,-13.909305,-70.55407,-112.816575,-214.188542,-257.827852,-261.075845,-211.131932,-66.589831,4.610718,-35.025526,-189.198905,-215.533479,-155.890971,-131.830295,-138.018898,-229.061641,-295.667187,-332.080198,-279.192113,-132.618273,-84.372986,-1.675789,71.224587,242.523528,350.511082,368.648098,321.023345,254.688317,65.811839,-3.262929,50.307449,232.32831,273.405988,212.792949,133.280264,-65.273667,-142.064429,-184.159606,-167.241274,-118.981774,-78.049061,-56.634696,-67.34295,-122.871048,-283.475508,-342.773746,-312.721278,-148.549036,-83.344317,-58.695402,-85.55928,-161.728121,-204.168544,-247.976577,-223.334218,-118.862953,-28.946153,-20.673494,-130.503406,-219.630702,-335.825029,-335.901249,-276.11533,-258.960631,-234.913516,-118.160401,-90.634691,-153.637644,-207.917707,-294.600792,-309.534141,-256.352204,-126.447749,-79.250241,-139.010901,-236.56715,-417.944373,-453.29718,-408.32512,-343.575656,-321.863841,-271.286742,-275.190182,-382.19654,-431.596568,-391.39943,-306.026399,-124.697027,-62.360324,-63.1855,-29.083616,-2.648932,-42.620453,-100.054765,-174.068127,-218.408751,-228.231874,-177.249311,-132.201526,-50.204738,-35.531051,-32.866468,0.556936,89.008041,127.206901,134.14774,66.553125,-19.041444,-196.930033,-211.604039,-51.614701,86.78165,102.937304,64.697744,9.464484,-90.085399,-102.643734,-98.354445,-96.040695,-100.273536,-91.158263,-76.05252,-40.903164,1.381107,75.436511,53.912671,6.959012,58.467557,67.485689,32.351162,20.561093,-19.474291,-88.370777,-209.573814,-166.441175,87.254364,250.121426,241.377043,86.792427,-18.900367,-188.728242,-233.455155,-242.386036,-217.866055,-212.456275,-217.851277,-237.903383,-305.278812,-347.371356,-409.245862,-383.508704,-224.880615,-98.459854,-60.614874,-19.896672,-31.093858,-145.167648,-211.488578,-215.152051,-70.12617,4.827123,34.601779,-37.160667,-234.71805,-289.508846,-270.293731,-221.783551,-108.813263,-14.255183,18.021388,50.797808,53.400157,16.02648,-20.051657,-96.360597,-74.421306,-9.347425,100.140719,105.815449,21.319285,-54.878787,-161.749634,-155.694276,-93.064734,-8.392905,57.385776,131.585162,98.144905,-18.037519,-17.664231,110.397702,170.407511,180.318068,253.52969,278.879558,249.917467,234.279358,212.333008,185.546553,197.616803,329.845672,339.402983,162.712498,61.705751,-17.370422,-16.427097,2.437975,7.572871,1.510705,-18.38995,-43.772715,-103.547985,-105.527182,-35.12864,12.602743,49.848987,22.758627,27.693711,98.616315,126.821365,81.876966,48.67018,104.408646,307.300055,404.084295,410.31435,330.552743,199.136662,146.632854,-40.751798,-151.379329:389.568777,471.92276,453.701957,351.155909,266.976677,72.316833,30.212075,145.238469,276.478122,261.847342,151.666592,88.552784,-94.538185,-213.831917,-343.699124,-304.252831,-127.866647,-23.80715,-48.242321,-242.951508,-343.090197,-378.490715,-303.043976,-104.515321,0.17371,46.851465,120.271842,110.948719,65.084302,89.42101,273.545933,376.492994,464.770161,483.510688,484.11601,397.997659,325.790232,242.392901,258.686428,347.045552,391.342447,390.259195,349.599716,323.385898,271.257894,218.923002,95.402803,86.329684,220.074205,373.996619,380.161444,242.228643,118.724885,-161.488078,-235.824977,-132.418327,122.074908,242.331613,343.136237,289.589665,90.475267,12.952408,15.499575,92.205763,265.051796,380.858572,378.256172,250.55969,183.71862,90.646552,59.178494,90.361998,258.414594,335.741715,368.124837,319.713111,133.416011,41.968397,29.945734,124.23542,364.439036,467.66382,448.155126,341.185511,279.103895,145.284791,94.127625,97.624602,269.835545,388.075639,509.681327,497.490329,433.587765,389.636521,283.915596,262.834853,353.988293,483.518051,486.118267,393.273959,325.467451,123.259988,16.51318,-49.623355,79.179178,152.67102,195.234976,166.952502,51.380385,-35.778593,-156.322774,-121.995332,86.370811,129.364593,25.764479,-224.450297,-292.015554,-362.993689,-392.680099,-377.423715,-250.548622,-167.913066,-73.88501,-97.106265,-214.642912,-257.525816,-288.295594,-298.167474,-252.031091,-89.013932,-63.69099,-162.081895,-183.459466,-94.535411,-48.507987,3.097318,141.08675,233.471549,294.510212,238.68235,79.129057,26.285718,5.053647,30.646825,130.465042,232.829839,215.662123,24.589086,-76.39018,-141.948961,-96.32183,93.175535,241.226791,244.993028,93.40301,-9.391259,-78.738989,-38.108845,83.603709,137.253641,243.109231,357.676161,366.16244,209.576178,98.0111,-47.946795,-64.168683,3.294931,91.609485,102.61887,2.923391,-76.6364,-161.62331,-177.191213,-225.592328,-230.679664,-106.84762,69.920916,68.236075,-123.654196,-205.112956,-211.336836,-177.567468,-120.473108,-71.772638,-56.356777,-75.499776,-74.431024,29.241916,97.954921,193.240659,230.725787,317.23097,409.919003,431.778204,395.231569,332.704207,154.356384,115.544655,232.602742,384.442829,396.31276,285.817403,185.486047,-52.238563,-145.368079,-149.760015,-90.075979,-3.63799,11.048982,-7.679164,-100.1163,-156.015951,-219.206914,-223.9659,-189.34254,-79.807659,-22.2089,-21.388168,-71.769452,-177.714299,-229.110558,-283.711304,-249.14859,-82.338572,47.86629,42.652747,-100.54077,-205.512396,-400.345689,-437.513665,-321.030045,-114.707152,-46.706209,-52.320696,-115.096675,-224.723648,-246.194433,-269.909626,-284.349278,-293.028663,-215.089605,-160.806106,-143.124889,-205.062015,-374.182863,-406.467144,-339.874781,-267.617474,-222.680339,-105.291918,-100.755206,-270.017313,-379.49031,-433.225398,-354.037298,-126.863744,-0.413927,5.148831,-53.652699,-92.684003,-206.937021,-268.006653,-280.488101,-172.349199,-117.491659,-77.950718,-97.84607,-124.241941,-107.728514,-16.044835,66.833917,220.102754,225.955504,173.528197,7.236017,-63.988552,-123.137627,-97.44209,32.553159,92.571529,102.958782,125.636135,117.222262,74.061696,47.456943,-19.157208,-39.293056,-9.623961,70.616645,81.712596,-7.569936,-63.898097,-107.168573,-119.962786,-145.900241,-11.473283,91.064465,150.857174,102.004426,-45.14694,-117.149676,-163.297479,-111.263513,73.481857,235.770284,267.218569,140.217464,-5.800276,-266.065969,-297.200997,-172.900811,-66.759597,-55.004595,-85.098094,-134.801615,-269.710903,-321.177135,-334.119014,-288.360863,-150.67024,-31.143657,7.924292,-17.161289,-73.812282,-207.463543,-244.872104,-151.092799,64.914002,152.382909,202.69545,140.075981,-68.097442,-145.128758,-167.01203,-118.076876,17.707326,124.725788,146.754219,89.116963,20.830343,-73.390952,-68.082923,-38.676985,-38.274992,-13.327815,77.473662,101.458322,2.061465,-111.83761,-261.548837,-249.26447,-175.482878,-93.720584,-37.572397,7.962859,-15.669736,-66.36917,-41.003485,111.615558,169.584512,146.75144,127.70608,144.076454,106.817912,42.818899,12.409996,62.561175,164.252281,261.320298,273.572537,112.278117,-16.237512,-159.174983,-142.351218,-39.055863,-12.182273,-16.666631,-1.657047,-6.365815,-86.26815,-130.285246,-116.28065,-55.171893,85.060465,149.827213,152.524755,165.880327,179.975143,158.202386,134.857606,187.617156,387.933349,476.470756,479.119734,406.232166,241.38089,156.616345,-10.832524,-57.836587:248.885683,351.587628,373.055143,364.345074,345.902991,304.405001,303.510154,314.769563,261.127767,215.322183,103.475004,65.318841,69.329089,79.147447,37.216517,-13.724617,-100.597652,-46.662199,0.957947,7.480269,-18.122635,-56.84435,-80.038758,-124.058159,-79.968563,-34.974813,21.41242,25.864065,66.643224,121.664962,237.608784,287.041052,387.138928,512.98433,576.306982,623.400156,599.526907,508.269237,495.180335,605.618986,660.121298,613.400743,505.946714,472.690785,386.988846,319.496468,197.935918,183.723183,196.508879,153.378827,139.831688,145.293907,139.013164,46.272927,-25.191332,-116.865592,-58.139901,42.988106,278.382551,324.416658,205.871822,92.561743,-102.563762,-131.030247,-23.01107,128.392005,162.518002,133.920787,107.944639,71.569329,50.227514,42.235324,110.749366,154.565406,195.708884,170.837915,52.299406,-3.113052,-16.394576,18.384769,51.287829,53.643927,86.701937,150.792901,132.05249,-57.709516,-184.411425,-299.231598,-241.21972,-214.29783,-143.973734,-71.274699,86.422918,113.818921,21.865216,-59.727241,-170.185231,-88.426287,6.09733,122.545683,105.096944,-30.624496,-82.213587,-63.148677,-32.251813,-44.564058,-3.140139,73.370332,168.795175,125.497429,10.03864,27.426467,133.054962,37.383263,-98.941892,-322.440762,-341.536929,-305.453085,-320.803376,-350.511188,-291.17541,-251.337565,-150.964144,-107.983924,-110.650972,-146.7877,-174.283048,-146.612078,-93.919184,-101.595089,-121.295917,-184.81348,-203.264764,-167.565143,-143.068157,-112.76575,-41.656638,-6.203486,12.413031,7.010076,5.098325,-12.111646,-107.90008,-142.804611,-92.724393,4.898947,-12.079795,-131.645807,-157.76344,-157.731397,-158.85681,-100.073326,-56.865554,-88.745362,-177.207454,-190.780585,-117.242758,-54.374008,65.300421,132.965234,254.185464,267.787357,241.320433,168.359115,146.047057,104.617461,66.704307,2.189067,-32.730093,-43.271448,-48.613592,-53.018309,-63.600522,-67.3971,-87.305744,-89.689929,-57.885547,-70.583746,-110.937882,-165.241781,-141.652306,-67.090215,-64.072228,-131.315731,-267.238981,-326.454027,-303.764617,-224.261219,-58.848771,-22.644461,-15.199166,7.852928,128.639402,281.488834,318.862871,272.29539,240.840296,241.201973,251.47324,226.636878,172.020078,185.44769,249.223353,221.458465,39.869389,-51.808467,-150.060509,-150.342481,-83.016374,-69.87091,-110.243317,-198.263573,-216.496451,-245.785772,-280.651657,-282.119563,-62.306295,57.217121,80.349457,-10.621733,-152.733112,-145.973796,-49.636723,-2.304981,41.574391,40.847494,24.766874,-46.261951,-61.096106,-23.888065,-13.358236,-50.293997,-103.270868,-102.41466,-33.020861,-1.006998,-13.237725,-55.14146,-117.778549,-105.142313,-57.260758,-52.649221,-52.660448,-103.347093,-172.350701,-326.840999,-358.184615,-280.912,-216.940883,-231.349617,-239.892219,-238.653141,-317.030912,-383.949124,-454.095607,-415.282471,-257.950721,-185.402146,-182.487707,-131.543445,-83.029682,-73.171355,-130.212224,-273.339998,-367.48694,-360.397519,-267.193739,-253.009146,-290.574265,-284.481815,-209.442542,-168.614469,-134.237091,-182.622035,-203.634647,-170.482619,-153.881592,-233.915373,-264.743889,-136.192125,-42.074199,-66.482581,-92.178907,-69.060274,-8.336859,5.249316,-22.234743,-50.643562,-145.358316,-215.754022,-178.754231,-60.881751,-43.791055,-48.214262,-24.168669,45.144654,-1.034675,-56.998179,-99.19597,-72.481184,-36.856431,-68.501386,-141.408004,-122.112929,-2.788692,66.356546,72.593609,50.927489,15.327552,-102.413077,-158.305047,-200.047001,-160.949767,-124.853067,-79.5446,-96.191048,-176.355505,-225.671228,-308.348998,-285.772308,-79.893331,82.64583,83.75849,-7.505401,-37.009758,15.57181,58.438046,76.405717,90.658661,128.674221,154.523083,119.2118,52.71883,36.508432,14.999045,21.885729,52.144351,90.95642,135.820774,204.236071,204.489336,183.450578,156.345031,67.785774,54.455641,98.552235,209.56322,237.748324,246.876343,234.583357,144.753016,95.822111,98.290567,175.53308,204.651612,215.533662,205.72206,206.012784,215.633918,195.304527,109.113369,98.976704,202.79511,266.503616,353.57769,380.869327,350.512361,294.40711,212.946506,240.640317,242.117297,142.098477,95.789713,80.531896,71.437235,22.790505,4.255411,14.362626,51.033201,65.736106,110.974781,125.245634,27.262266,-44.950943,-60.992209,11.546309,32.412329,90.729615,124.749166,97.966101,53.831211,81.482916,272.494121,328.077829,220.499588,128.651573,65.225432,45.467072,-89.989394,-168.533717:149.678877,188.677875,171.612851,159.033828,188.04063,208.277422,177.286644,152.855913,221.663545,243.54021,181.614705,103.640856,-28.064788,-49.163194,-54.115581,-66.966226,-117.391789,-104.686522,-74.730863,-70.073143,-68.364424,1.74262,21.695918,-19.280105,-32.755669,8.690837,122.879133,154.606336,199.450249,239.161718,335.198857,362.939597,356.639421,419.133158,513.915863,681.520848,681.205679,556.985672,536.299937,649.262358,665.845656,630.114004,606.423578,586.902683,477.814239,410.539899,303.445035,286.048295,272.284563,247.839048,268.016183,309.078024,298.871885,244.112294,207.179732,147.511087,210.613751,297.755547,475.056282,506.79731,407.684621,307.471001,153.027911,145.956949,265.498323,382.197456,359.131431,176.797924,116.482399,144.259551,178.229101,197.655937,154.813753,123.286363,43.009112,0.452152,-45.351173,-33.436356,32.425271,44.979377,-16.770326,-56.471699,-39.014444,12.446928,28.386026,-1.538145,-59.452232,-181.386157,-181.538345,-146.378972,-54.158312,10.410974,162.452179,197.095565,118.875079,58.472389,0.095735,-25.923706,-28.467031,52.157782,98.020919,-5.136465,-124.51598,-185.732717,13.956911,89.045831,108.224409,108.799089,124.570476,106.241091,96.128538,139.784542,208.294073,156.939435,86.790322,-123.525391,-205.853346,-263.799204,-272.321119,-254.788349,-129.773416,-21.81949,193.484068,235.436435,162.872751,101.175701,33.627846,38.96944,108.062236,154.147978,138.079103,87.110957,76.435331,61.763229,49.717658,21.599101,16.048821,22.128967,30.544705,48.585478,65.711252,18.017946,-98.529203,-99.914334,-34.852813,-28.089887,-57.013539,-143.86091,-179.765415,-223.931793,-239.155837,-225.666448,-218.738613,-264.683158,-383.462879,-390.158349,-264.403044,-207.286693,-201.42917,-188.701986,-83.425283,3.429762,38.386865,81.219106,74.948212,2.913032,-48.848242,-113.854005,-119.827127,-112.640657,-78.696606,-57.781505,-55.49213,-76.001065,-115.754129,-125.393501,-127.843998,-118.095783,-132.171048,-206.962274,-219.449566,-155.90327,-125.855297,-179.864906,-272.563055,-259.154881,-190.466051,-184.908332,-191.947451,-203.834918,-256.906403,-244.187155,-72.392797,111.186757,124.547698,14.881007,-39.168351,-84.518237,-84.097107,-50.4046,-28.616427,-21.743848,-3.746129,10.410224,51.302218,48.368955,-44.733089,-94.00244,-115.554991,-124.963494,-167.267163,-269.020424,-295.138836,-341.092644,-375.660577,-386.504926,-256.573185,-168.270189,-98.078005,-149.641113,-284.996452,-301.028777,-244.215144,-215.03415,-217.926279,-242.029901,-250.659379,-231.868717,-170.384721,-50.954009,-54.705572,-138.647915,-210.941864,-217.899745,-171.058448,-149.69064,-154.431798,-176.863749,-240.30887,-254.5367,-200.200267,-93.260673,-69.785857,-166.25119,-260.135912,-396.511082,-405.836215,-325.477213,-340.088577,-395.726145,-398.107909,-342.573,-295.672595,-331.367121,-395.088509,-370.447042,-261.057825,-145.294267,-81.59627,-11.450938,-25.942367,-121.265693,-186.532973,-308.432184,-327.059006,-269.060245,-116.373529,-87.967433,-123.997138,-162.557848,-206.322361,-177.294559,-122.482553,-156.038346,-157.639164,-128.570107,-137.638492,-248.437164,-280.983688,-147.295095,-37.914823,-65.859082,-129.32632,-132.036779,-102.572586,-90.01749,-116.289195,-154.182299,-202.908099,-137.151569,-109.879011,-100.965285,-74.800577,-10.354758,-4.251324,-15.771242,-66.988936,-105.838751,-127.961672,-106.712703,-109.970955,-147.863303,-167.438576,-121.068994,15.282676,138.652082,168.228364,128.073855,66.819301,-84.407801,-120.728259,-53.121086,-47.974983,-121.214039,-246.181334,-254.59422,-242.47601,-280.898649,-415.391833,-418.228884,-252.427627,-49.164365,22.464366,48.398306,18.076188,-50.571794,-70.90715,-51.337941,3.990004,20.741856,10.397467,-11.375622,-64.600464,-93.962419,-121.249537,-102.486905,-36.800063,6.443994,31.023774,107.771582,127.132372,41.391154,-36.196222,-100.589755,1.523649,82.436718,203.002547,211.932185,147.526938,95.475853,29.748078,46.989365,114.914866,145.638391,162.127205,155.435402,113.415269,17.695598,18.636066,113.019939,171.63317,203.633751,299.272029,315.237074,262.568946,231.314341,199.756965,190.698719,160.08144,164.474476,181.123746,131.462935,64.967092,-34.570682,-39.974065,24.184928,80.167736,88.689849,67.126595,24.740195,-72.839944,-92.540155,-52.821927,-7.856673,34.431215,-48.301282,-81.70598,-34.404533,19.367121,48.25001,24.291089,28.085913,120.15041,171.950558,240.747007,245.201222,227.440209,214.22515,107.204743,9.573908:355.105998,477.685708,540.186472,539.661682,464.834324,297.817116,260.830902,289.060671,317.320612,289.391424,130.513739,38.553812,-38.740656,-40.157026,-70.855277,-93.389647,-89.388623,-10.848181,23.201421,-4.818494,-65.575427,-194.806488,-212.893584,-90.846525,41.904839,41.095441,2.013433,23.706526,138.722646,183.920635,261.30086,331.625356,441.240353,389.331284,364.584151,437.404061,497.311975,482.06587,412.108654,342.307277,381.160619,387.819534,328.991615,278.558516,208.516371,181.247775,99.636656,74.39845,124.105022,220.416849,233.165069,161.38193,100.359839,-46.340499,-125.516167,-144.865586,63.823825,157.425725,206.03215,184.433398,107.440919,58.482542,20.233128,61.998673,219.202854,315.358371,295.148781,169.193923,120.310168,90.165907,96.31131,182.722738,288.520871,303.104311,309.081542,298.421834,180.26637,100.916637,60.249165,116.244503,243.680364,264.652297,263.980279,282.175649,280.490572,174.769977,83.69218,-13.057998,82.942549,147.978698,166.982703,134.846693,160.685353,223.17261,242.157682,168.621776,16.297104,43.485516,89.33746,130.167371,144.132777,103.148765,10.22546,-151.482742,-52.210973,33.655593,96.893734,90.076341,69.218846,44.804405,12.354766,36.5722,81.633516,-21.418532,-113.164371,-236.104241,-228.58908,-206.12938,-241.819434,-259.383564,-155.74599,-133.184669,-145.435303,-152.104357,-190.2361,-227.812907,-311.425959,-345.483288,-329.415029,-204.918057,-160.838536,-172.074828,-190.225043,-175.321402,-157.727838,-94.140486,50.422326,105.405251,74.69805,33.665871,49.57891,63.207058,-40.496796,-109.692965,-112.65023,-17.048239,-9.630695,-60.648056,-70.904557,-54.757554,-53.32062,-62.866634,-29.867453,5.379627,-15.57137,-80.88977,-108.614564,-35.932457,127.374521,169.130095,208.159715,268.079118,277.267997,183.35568,123.428258,55.184095,30.116123,-23.553932,-68.007671,-71.119439,-49.200387,-55.630226,-148.117024,-205.447994,-245.292522,-216.724163,-118.784765,-107.421268,-162.256531,-278.256635,-267.643989,-144.169676,-113.525368,-186.363805,-238.433398,-210.671385,-110.139004,-68.15355,-7.37787,26.773909,134.450397,214.119303,355.252211,424.158127,433.016105,339.727885,254.843239,163.799702,185.399729,296.023785,357.610753,355.384991,281.675753,198.657244,10.949245,-52.42366,-75.197554,-49.57813,-25.387695,-16.10414,11.400476,56.173875,43.821082,-70.26435,-142.710893,-159.919316,-41.792951,-5.638878,-28.470036,-63.385818,-108.727172,-124.929728,-145.254549,-111.176422,21.528938,49.906201,15.773735,-92.478533,-145.743256,-195.734699,-174.32115,-92.478912,-87.363252,-95.112331,-93.316601,-85.813919,-63.20404,-71.096989,-95.258299,-86.235092,-81.058115,-132.640322,-166.13248,-239.792503,-267.197791,-285.61858,-275.304069,-228.3934,-248.781655,-269.855899,-264.279147,-256.49006,-290.747874,-340.553436,-392.167142,-329.19181,-152.995872,-145.020102,-178.10983,-207.800416,-196.423326,-193.632117,-216.17416,-255.202073,-245.599,-205.711599,-107.467026,-112.287472,-198.859978,-205.343331,-107.173751,-41.255737,24.465216,-14.024834,-47.032296,-104.624668,-120.689247,-157.126654,-147.130658,9.715192,122.183635,114.899957,96.486937,109.162306,104.617832,61.232594,-14.063675,-7.603789,7.929575,8.159081,32.227988,46.310052,24.97065,-29.640514,-50.981281,-16.642546,92.080132,120.825031,117.588299,113.498092,55.8161,-29.441607,-143.265966,-94.428437,88.526227,141.742532,103.812145,-23.349798,-64.988779,-103.512749,-121.436219,-117.866717,-43.795126,-12.594516,-51.434545,-109.686494,-217.842236,-275.408008,-358.70484,-327.55168,-144.031873,-31.704353,-18.776441,-0.264627,4.587069,-41.239409,-85.734157,-102.079935,18.968322,94.087403,196.97883,179.82927,6.492467,-82.607271,-137.820229,-107.964002,-23.692638,81.604986,122.671427,93.90929,55.513316,35.55334,34.444163,-3.759573,16.879402,58.013239,99.259665,95.022198,106.220137,110.791337,56.310187,23.109353,41.667821,102.181698,81.05076,-7.603257,2.657942,123.454732,167.181973,156.852982,87.980307,85.85194,168.232135,206.337488,205.541654,182.453968,114.338757,77.733217,86.860406,223.912388,267.595698,183.795944,84.861569,-61.977332,-65.773669,-0.140129,47.969165,77.608328,125.563859,124.813765,104.137684,87.781783,31.103271,7.153092,25.682151,99.467261,121.5429,142.475686,156.686378,143.554419,113.825169,122.187741,255.178444,317.153551,358.463193,338.528127,221.850969,137.623989,-27.142137,-87.073958:left
-187.450391,-120.146654,-132.93082,-182.600602,-193.122544,-224.270991,-254.615776,-308.526857,-282.983249,-245.977499,-176.979242,-144.70864,-94.740396,-98.301559,-143.466188,-148.174379,-88.50722,-3.974419,52.231145,166.698983,164.033629,34.498081,-23.259218,-26.701877,41.999199,48.547328,40.078371,63.455934,90.480142,43.725629,-135.256824,-201.88432,-191.173489,-83.749779,-32.663725,60.120648,90.703846,66.214222,14.914144,-41.039888,108.395009,205.042274,290.77451,291.650214,251.490018,220.770296,193.609225,209.334066,256.834713,204.089532,140.43363,18.337791,-20.934404,-26.487382,-0.884543,7.038164,-43.371953,-48.518768,-1.847347,31.735064,6.732795,-80.84085,-332.09391,-416.947369,-410.292295,-375.731201,-375.179287,-293.62005,-217.118038,-80.663274,-52.721835,-99.829114,-126.107238,-63.07057,144.048325,194.660454,101.206893,33.024503,17.229017,36.428783,12.265178,-76.924909,-103.050351,-93.675791,-87.008578,-98.025551,-102.804884,-99.617365,-101.69705,-110.438821,-103.710516,-73.270574,13.517154,39.491273,-8.208525,-52.547424,-60.709859,-12.211227,-0.661972,21.343847,34.01531,34.093115,9.993726,-94.653372,-190.774541,-201.641034,-134.123797,-81.884485,-37.940434,-47.816069,-81.855955,-95.490311,-37.378642,138.617383,207.218699,253.636702,248.231405,204.867378,172.360836,129.945195,128.034316,114.675614,58.726247,53.283818,104.865883,114.438444,3.597168,-87.840578,-188.411088,-160.084897,-107.695677,21.563159,17.281119,-156.860758,-216.832474,-139.148469,-20.395136,-11.808866,43.720047,132.222352,235.348053,183.42047,-2.510929,-54.928081,-13.700558,104.007385,145.238842,165.132616,140.0642,35.568166,-21.772535,-93.155846,-65.595489,-9.688872,130.662457,160.596476,84.239358,30.491932,4.540851,18.375521,36.217412,18.893743,18.382901,67.457638,79.73576,39.287415,12.374115,-29.030687,-10.454953,36.84823,170.769806,210.601527,120.694333,33.97652,-27.793795,-4.779887,74.75965,138.145098,144.242777,103.00813,51.440196,-50.459374,-52.691867,3.697075,34.627903,61.516972,167.138466,215.347242,226.204712,198.693663,140.984012,123.647048,99.278294,64.699213,57.452106,65.734935,62.253801,55.170181,72.209876,121.639809,176.071903,222.451553,338.103717,367.790612,299.265116,228.256291,80.85165,9.884311,-63.330401,-4.121856,32.23365,-0.973945,-63.074618,-129.106074,-120.010014,-110.797291,-141.230728,-156.380194,-115.201765,-38.956695,118.192285,143.285016,72.663014,18.629969,8.510722,109.571577,145.136399,129.146633,93.532835,81.352571,110.232595,115.645961,99.530998,135.659925,189.406871,159.187964,44.418185,18.732995,73.370565,119.171196,191.543522,241.119508,238.682387,168.468178,147.282804,177.792933,158.207851,-20.113492,-88.898524,-39.932733,14.763194,-19.829656,-87.176868,-79.10291,-71.201477,-103.355259,-124.851673,-24.103445,21.951619,37.238409,18.323242,-37.081827,-75.176179,-117.067808,-9.878005,52.812447,94.401361,88.302367,22.9794,-40.971881,-165.65726,-193.033343,-147.790937,-53.261383,-45.41365,-111.869273,-144.948554,-159.538725,-153.321809,-125.64006,-81.911167,-77.092329,-93.016972,-88.372456,-85.704591,-113.851928,-226.182552,-276.383214,-258.299795,-177.590239,-178.380375,-242.86593,-266.23172,-241.651142,-217.460576,-158.87545,-5.316319,87.526753,238.485265,293.111207,321.829585,291.123494,227.174238,223.611704,224.956637,145.961297,110.926883,143.29972,166.136244,108.551133,42.376852,-88.566244,-115.782218,-70.067548,114.022892,194.592122,176.904706,92.278414,-67.373001,-105.653802,-131.20854,-95.998722,-46.653188,21.601522,10.981113,-55.251208,-97.758736,-170.262411,-126.014717,-81.877792,-53.548263,-62.478164,-105.225943,-137.427777,-182.319886,-182.188103,-133.650992,-64.729445,-36.166394,3.986057,10.660227,-0.61558,-16.305357,-75.892406,-63.391547,3.038975,123.993037,129.301064,73.838394,55.678433,32.194653,-6.884281,-109.876576,-82.74586,-25.901811,61.605521,83.905053,101.536416,79.207957,-23.075593,-65.287791,-61.621538,-40.690772,-0.030279,125.746375,158.977955,86.002743,16.05322,-80.267219,-122.144841,-104.903321,-20.842948,-17.698487,-114.521177,-166.497101,-249.748843,-258.829878,-206.430205,-78.447632,-50.389699,-62.841627,-49.70832,54.765016,90.442056,50.361958,12.327406,53.105656,147.939246,144.011836,107.927637,105.20725,33.205691,-57.147238,-30.793259,124.139218,198.395438,257.719378,244.435708,169.305746,124.381399:-251.229854,-212.795285,-194.178355,-193.0434,-228.127434,-323.925392,-359.720851,-366.198672,-274.675719,-211.974686,-100.891382,-80.066496,-140.775513,-206.6258,-291.661566,-264.777385,-134.726588,-75.182,-57.787454,24.489863,62.60911,45.674858,2.814456,-53.598519,-39.205579,-16.459348,56.928932,82.915706,28.896256,-24.140039,-61.928828,-55.900717,-44.499144,1.728136,55.143366,148.924232,147.011839,34.433804,-45.204969,-88.645607,57.487486,127.689445,208.035039,228.029815,170.046954,99.5606,-4.830095,-29.667801,-23.957864,58.830563,98.931495,95.705648,31.310656,-129.587384,-165.359142,-146.824888,-115.247455,-118.757521,-152.175483,-176.04185,-257.875788,-304.176781,-368.531222,-385.048336,-362.079881,-306.458794,-285.560965,-224.001661,-178.820301,-102.858028,-98.936935,-126.834992,-41.645829,63.768883,253.486886,247.54185,62.716342,-23.303881,-84.016216,-68.606669,-16.675678,-1.038174,8.700646,13.232663,-10.953277,-53.960739,-51.039581,-37.535237,-21.289852,3.618381,33.732042,17.1513,-4.83665,12.663467,31.255348,18.823569,0.047747,21.492502,54.627389,121.04856,128.013263,82.704168,44.084768,-0.933482,12.783971,21.076655,55.716367,78.49509,55.781329,-1.345949,-149.294034,-185.827324,-68.113033,175.521927,247.815872,234.606751,194.841017,174.596892,191.112569,180.385349,90.091776,66.101574,135.725402,193.324354,230.858794,199.683145,60.624461,-28.829691,-160.524466,-139.082421,-97.402472,-79.163498,-116.471901,-224.412197,-241.214691,-136.366725,-66.678077,-82.838315,-38.897885,33.037692,91.276938,52.206237,-62.847254,-100.612799,-68.625831,33.282311,44.359825,6.662627,-12.696436,-76.399758,-132.05811,-201.822232,-131.047066,-64.214383,87.573879,144.655043,113.777427,32.258235,-82.067724,-57.894529,64.86563,40.077927,-4.38698,-16.536256,-7.612145,-14.88245,-20.385092,-52.919502,-66.11965,-21.085217,104.044227,126.636266,85.782796,46.11505,-36.067796,-44.086462,51.553281,165.741405,189.732059,194.995647,180.787304,87.872235,32.401079,-4.370582,31.602195,69.199874,179.284846,210.105515,142.944264,70.00444,-36.09625,-50.921809,-33.324496,12.230249,43.638197,56.749712,17.049561,-57.61355,-54.130824,12.952331,99.411612,152.536266,308.30804,361.042205,246.593019,118.711962,-48.058671,-57.69853,22.529647,100.258995,109.45327,69.229377,3.522274,-167.11149,-212.211599,-169.927523,-79.20589,-58.448388,-61.88436,-67.619444,-77.896434,-90.621503,-106.756056,-92.514364,-37.236762,-15.323098,9.423864,134.114251,188.066444,186.914692,137.923737,11.61158,36.409273,135.899576,310.728947,292.854179,79.259011,-10.02533,3.965828,78.527899,225.241188,285.3451,288.226974,242.090061,201.825929,113.907346,53.596048,-67.671916,-16.482938,45.468383,77.675348,53.214359,24.357456,36.730394,39.933631,19.988791,3.148012,44.644342,89.939285,121.419814,58.029902,-111.682705,-153.463289,-138.960056,-9.01519,88.591876,196.73905,151.057997,-22.938839,-78.196659,-135.135101,-142.469291,-66.866306,55.77157,72.04884,-28.727508,-99.208559,-172.813024,-180.516323,-176.961725,-141.918007,-104.217086,-24.573087,-11.659352,-57.999505,-95.861265,-145.756061,-146.716619,-94.554685,-8.808239,-0.522648,-82.792015,-114.533377,-93.987701,-89.420649,-87.100441,46.112824,121.430937,185.536619,197.358542,214.658731,198.4416,121.678655,106.486843,177.494989,229.355735,207.706577,128.811533,80.57401,-39.890138,-90.153223,-97.897181,22.395948,116.228832,290.079662,301.310599,159.550957,82.430347,11.077568,-0.360692,-18.931063,-11.601112,9.637145,25.107114,-10.800646,-113.721006,-131.394539,-84.45284,1.904772,63.258175,177.890249,171.255826,39.684727,-22.516669,-63.940053,-48.926214,13.453146,111.147012,178.32611,261.720394,219.332227,28.678422,-28.293841,-5.364406,85.873675,131.619508,185.629774,162.947032,27.104129,-25.929163,-32.727597,-26.227406,-71.585568,-103.197996,-76.79198,1.305259,13.877654,-21.634503,-65.995326,-171.625106,-170.868042,-138.848955,-61.605536,-16.559487,26.193354,12.278007,-26.053405,-38.995489,-56.844485,-122.470265,-174.071473,-197.957142,-172.668788,-164.286127,-197.504178,-263.015677,-230.547361,-185.457938,-101.207399,-84.860834,-74.240692,-51.797845,-16.149677,-9.12513,53.467257,146.967222,181.4622,178.392965,143.574255,96.059315,95.339224,94.728045,65.380182,81.200221,239.651193,317.110012,318.348579,278.624988,223.098091,218.106974:-218.486416,-163.080734,-153.371243,-172.348206,-198.373768,-277.498298,-321.280456,-361.85709,-288.483732,-214.19903,-77.564294,-61.019108,-148.766192,-202.626605,-219.678045,-187.053885,-109.724351,-42.444732,-11.470451,13.068731,21.243441,52.186652,40.420907,-43.717175,-39.424746,1.072527,40.769876,20.784154,-52.036617,-74.501527,-88.846997,-90.727111,-62.795652,19.102692,73.177116,117.586243,101.284421,79.239932,60.486859,7.030891,112.439447,187.954164,216.315797,178.254566,84.025136,48.2325,-30.636845,-66.90287,-49.505365,20.99931,39.575327,26.121128,-18.239414,-118.028653,-123.519316,-61.942272,-80.703811,-124.918931,-139.094344,-113.984603,-173.058232,-269.33277,-407.739534,-398.616269,-293.049912,-201.12536,-162.332032,-102.168435,-83.205574,-48.553698,-32.304315,3.032201,74.779143,131.142197,217.492962,201.373418,46.271641,-27.96173,-40.352626,-8.383401,11.126954,44.514216,93.246869,151.025311,125.953111,8.162543,-35.980377,-29.920237,41.952173,70.265305,88.305206,79.879897,78.256391,99.205055,79.712392,14.826923,-68.875131,4.146738,60.853467,154.957238,166.746518,79.118439,-5.242812,-115.399835,-26.100459,52.404985,149.979868,141.304398,25.889441,-39.016547,-134.337233,-150.637153,-15.613187,208.189751,235.338457,127.186108,82.027525,127.661683,171.895096,172.734553,125.940389,132.017122,157.862044,156.784481,168.121279,168.958396,51.372927,-57.642412,-228.50081,-230.015228,-176.895461,-120.734019,-165.354871,-314.508985,-356.353008,-308.287331,-157.296017,-99.644563,-27.231999,16.382384,96.819471,103.018555,37.615239,-2.294665,-24.677357,26.058597,53.736091,55.083209,25.858557,-75.88789,-137.617291,-197.590021,-81.311855,3.016911,108.999307,113.663481,23.350386,-42.873763,-134.110746,-139.125829,-68.427109,-13.510394,-0.223433,44.948772,60.955635,38.019859,3.23571,-69.732644,-71.106264,-38.457765,37.221134,30.96067,-119.535616,-200.554612,-172.240611,-74.746389,71.436192,107.112919,146.329343,234.346778,225.805942,89.108582,16.341173,-27.039673,10.485149,44.378462,146.464877,185.874129,152.230974,83.285245,-40.69596,-59.824344,-41.124335,2.29718,24.205515,0.226663,-43.189405,-59.246072,-16.293201,81.030607,156.599316,208.669956,329.875223,349.047996,213.73769,98.542164,-41.301291,-35.240767,59.613609,151.866573,184.330327,158.361181,88.325659,-73.156857,-136.029674,-202.544892,-151.943509,-109.198374,-52.801639,-36.704481,-40.001902,-49.56448,-47.305192,-36.659084,10.506207,96.046063,145.658664,212.882802,208.01456,144.823386,102.563526,53.005384,143.043535,205.284412,230.979329,205.586331,175.708133,179.631766,179.642079,178.576258,250.94468,345.983303,352.170554,306.509454,285.392541,229.683265,162.688904,31.872489,93.325302,185.787798,327.424855,312.780753,140.495293,67.423735,71.08846,116.272658,161.6637,175.725668,201.533529,204.922319,147.32715,-33.94458,-102.892419,-117.935054,22.004381,115.291351,269.659153,306.84769,234.783232,133.600232,-51.340463,-76.226757,-3.429776,124.569926,163.119055,96.695206,17.447944,-117.817803,-160.029754,-148.400554,-11.767017,48.995663,123.243564,147.926414,120.390763,49.577908,-109.824474,-129.445969,-1.905464,118.805165,100.806458,-24.413672,-67.52634,-85.181391,-103.016844,-127.964444,29.230264,149.490896,266.614648,211.607433,23.318822,-7.804714,54.633596,99.10629,169.656308,175.518772,159.314662,104.938421,73.960928,17.283073,-25.363969,-121.403085,-93.051353,-11.368749,188.506134,226.871516,98.724004,-10.561635,-161.54892,-180.118352,-121.452831,-20.633924,30.983088,104.854849,91.038257,-32.087546,-79.649431,-22.729792,100.722375,114.10686,109.041024,108.905465,44.668639,-16.182886,-90.582217,-83.795117,-11.402683,88.027965,133.736941,182.601509,178.831997,131.688235,91.260577,18.202745,12.319314,44.894026,142.744635,157.964577,62.486531,-6.200204,-78.36411,-91.437088,-115.602754,-91.744896,-58.158922,-33.155126,-57.613983,-135.373242,-165.586469,-185.115565,-146.172054,-120.50297,-88.479189,-63.49198,-5.819579,-20.880572,-165.379141,-223.372158,-210.371516,-176.610711,-154.770778,-67.207502,-60.240208,-159.838415,-204.465421,-215.260416,-191.744619,-155.212012,-21.487468,23.88074,13.851182,0.677091,25.973034,53.249012,71.354044,73.563202,113.549548,187.864257,164.989842,40.851522,-6.707142,5.353828,59.859967,71.931531,172.601919,254.812184,300.048778,244.606823,146.605781,163.621402:-241.575193,-183.670449,-164.388643,-207.24049,-233.001916,-251.762421,-273.576646,-328.032162,-246.739647,-168.239684,-60.588474,-45.97436,-69.18374,-90.102598,-120.103396,-117.066817,-52.082638,-11.723668,-17.23308,-34.539969,-58.544654,-131.932815,-149.413853,-108.102741,-65.190945,-68.252982,-38.786046,-10.097884,-23.34311,-56.266377,-97.179158,-98.960202,-84.45479,-70.924244,-70.094793,-40.373326,5.470386,108.215601,121.32224,67.226972,89.640176,157.00758,297.648653,303.42884,145.904057,69.536381,54.586868,76.518993,113.730161,97.708386,68.055301,17.700692,-7.079328,-52.993641,-47.979425,9.877962,-14.010347,-74.968733,-148.602397,-137.807714,-145.634254,-195.187159,-340.93908,-403.839033,-459.574191,-439.431871,-403.319609,-285.080037,-218.121021,-122.047306,-116.677001,-137.647562,-61.0041,3.619817,132.588426,164.166273,79.810685,19.87301,18.891466,44.019627,25.935403,-51.127254,-64.62955,-12.732327,17.165118,33.39796,23.876835,-54.738066,-95.526335,-62.045529,0.011193,3.782138,-4.87044,-10.83837,-53.36632,-95.373802,-192.08401,-159.62058,-71.688111,108.046922,145.630196,95.15774,33.399667,-41.962865,7.483855,31.218961,14.449987,-12.283743,-73.98281,-99.993868,-141.577547,-149.550471,-55.941741,125.137758,182.428315,235.880002,229.447573,119.775991,51.694275,-12.051632,20.662295,52.587378,109.090457,138.647473,170.496884,136.892293,-38.723255,-143.349866,-254.641945,-186.991582,-119.848522,-32.26688,-62.403466,-247.085301,-312.264377,-233.20502,-73.233437,-53.3403,7.976203,81.747532,97.454051,5.153899,-136.496069,-120.97103,-11.697002,102.898686,149.990413,142.693844,77.401442,-90.956932,-153.442852,-184.854029,-96.443694,-30.535003,69.054095,66.915614,-62.456405,-139.276539,-152.217296,-70.683513,86.209054,35.867953,7.935469,63.738638,78.715708,13.508023,-23.325491,-93.033253,-140.661753,-119.085231,-20.140277,9.769227,-16.265119,-52.086352,-87.321817,-62.501153,59.938637,165.20681,162.982758,48.96724,-19.001063,-61.923612,-26.802497,48.962976,59.094136,74.853015,163.748476,208.818295,191.305845,129.262995,7.547882,-17.786622,0.566935,38.152311,48.234141,39.329556,23.757649,40.000003,88.978615,201.640251,251.667586,258.984676,265.110071,267.354963,262.766086,247.213533,144.249816,71.77346,14.114353,92.997313,140.244998,173.718648,139.801297,4.519769,-49.950598,-65.383768,-3.409856,5.329263,-40.745547,-51.261618,0.344633,36.041056,51.602882,37.231411,52.30868,168.833751,245.237325,309.631222,260.251159,141.10356,133.196407,154.868532,217.535453,272.095251,296.127692,245.368594,98.139902,51.326282,88.847563,160.039295,317.644031,396.574908,395.138634,309.401029,255.086623,219.565539,216.330123,177.408484,191.772671,215.252434,212.59482,173.591587,57.883893,18.675841,19.06039,44.099973,105.087978,169.997039,198.816345,174.543997,112.770914,-4.573048,-43.258525,-112.131781,-57.940037,28.866869,186.708062,207.172083,100.940306,18.744971,-83.839025,-89.370819,15.763675,177.489827,210.628456,135.640125,62.741264,-34.801909,-53.963784,-52.792915,27.513265,81.438096,157.023547,183.419818,174.081972,110.228192,-67.4132,-117.230165,-70.201188,15.55008,6.188987,-109.124477,-159.112111,-150.703368,-133.63419,-119.269297,13.888133,101.904553,193.539909,195.033226,129.772009,82.165691,59.537817,101.210362,199.08688,140.158614,66.258524,8.462206,20.612418,-21.27192,-80.880852,-175.029172,-199.417123,-180.908146,-57.791427,19.162683,53.390749,-23.096401,-239.387717,-302.406919,-292.441717,-197.198015,-144.008957,-69.34737,-70.669824,-113.325071,-123.084075,-89.747474,-18.94646,1.625709,-3.605802,-23.575057,-70.750689,-83.695457,-96.143477,-101.912947,-95.374079,-31.533327,19.844126,77.252998,65.272111,-10.678234,-66.413921,-164.184815,-100.131381,-11.40318,106.041817,90.610752,-2.179265,-29.206068,-43.606163,-53.367804,-72.142898,-60.300683,-52.330124,-23.296927,-12.870913,-54.508752,-89.188899,-102.994306,-49.732567,-25.575372,42.181396,107.157213,232.701029,238.952581,89.058073,-12.839365,-96.916768,-40.269216,15.538438,113.892457,96.137813,-44.722079,-83.496947,-76.981959,-33.687097,14.495701,99.76459,115.7857,102.162038,77.600419,44.820473,56.725239,116.883719,173.468595,200.569793,224.033585,202.946498,140.153456,125.880219,128.782184,103.808772,79.913485,100.669531,163.921724,279.328919,271.39,147.100463,104.51018:-205.562797,-82.738155,-65.675254,-91.264993,-111.406298,-121.069436,-142.102012,-243.214314,-177.276017,-66.347329,109.762773,117.935854,1.538316,-55.400617,-93.430164,-97.277373,-106.163061,-94.908996,-54.115979,22.803949,2.822794,-103.384891,-133.042737,-114.062425,-109.352081,-141.576234,-158.730192,-122.840056,-88.932529,-123.904934,-242.823335,-271.155698,-173.509001,17.1414,88.376442,99.428769,51.209907,-28.680661,-51.276368,-21.041295,193.820545,287.310866,318.364973,285.437083,162.258187,88.48339,-29.556789,-56.581949,-25.451849,28.806327,46.625554,44.634505,4.188238,-75.800635,-79.441019,-67.674458,-91.390132,-104.484146,-88.27538,-80.449688,-163.078176,-246.108862,-396.409103,-416.699352,-322.67746,-201.674781,-157.815013,-88.761634,-67.369672,-78.037463,-109.360942,-146.398203,-32.276195,70.355728,214.162288,206.647472,47.608102,-27.290014,-46.805517,-39.582269,-55.448435,41.198893,120.689573,174.118342,133.924559,9.702061,-36.256969,-42.132292,35.046573,66.583247,99.167291,92.137158,4.139408,-40.994325,-68.339622,-72.072316,-111.011235,-81.198154,-2.359138,157.502673,179.786268,107.102989,30.039309,-111.708373,-51.452614,41.899275,175.137358,164.100082,-7.479956,-114.496995,-236.439922,-235.5605,-141.64681,21.889323,106.658283,176.780969,139.272835,3.840963,-49.444507,-51.550759,73.655348,133.099619,188.863902,187.014277,110.351627,29.876529,-178.281167,-264.352148,-282.538737,-122.304443,-53.601322,-70.38191,-139.965776,-270.915386,-315.830253,-312.224722,-129.952349,-39.334356,48.493912,61.119581,53.622789,34.345999,-40.178882,-70.321731,0.612993,170.60967,212.387916,165.132134,101.281961,-37.69906,-95.844316,-129.769295,-56.896984,-11.242158,106.325558,141.236771,30.122246,-70.007705,-159.300437,-128.84272,-27.062182,14.512863,48.409379,111.440842,80.299378,-59.170966,-110.005582,-141.303869,-86.730587,-47.297815,-10.896745,-29.905875,-113.045693,-128.949199,-71.175215,-35.920638,34.209158,176.542461,236.280312,192.486221,108.052182,-30.267271,-59.354482,-23.204625,111.757313,176.255829,261.427521,262.626734,148.354852,77.545377,14.306525,12.517218,4.310932,-23.762642,-13.786928,45.272569,56.014139,32.032615,21.50748,47.210663,176.158652,256.26579,342.200326,343.165061,280.897837,210.059509,37.564111,-9.4786,53.493394,225.979316,282.675436,253.061528,180.263136,22.528177,-39.689809,-108.544925,-64.059242,-32.989175,-14.780329,-6.469549,37.579459,38.642938,-31.361462,-61.211924,-24.653105,137.209887,205.839417,184.105707,126.454297,69.405266,67.634261,84.503272,144.087249,185.704354,274.511582,288.818595,194.861852,133.779043,103.923446,134.182441,250.863836,361.264603,376.947371,315.117128,282.36541,278.381235,266.315093,192.639118,219.386959,251.824685,224.198875,177.44002,123.882463,124.341964,108.1631,91.973246,104.449322,171.748028,200.594014,185.120908,140.34948,-2.209599,-99.148195,-209.335746,-59.662286,61.175834,266.649175,310.287798,215.055786,98.5781,-141.821031,-199.83287,-103.636833,137.753944,232.136385,238.248623,137.576862,-113.494789,-173.95698,-105.444367,48.216749,100.09031,197.975238,244.772354,182.010905,73.461197,-87.614457,-94.981202,-27.646716,44.880521,69.140356,67.338171,42.24982,-72.48847,-172.220368,-318.271566,-201.501204,-76.98498,104.760661,106.023935,-6.998451,-41.402803,-35.404817,-14.786559,123.142972,258.410754,240.371532,100.66444,43.447085,-26.933903,-69.602388,-114.191741,-19.9804,48.666639,157.056209,157.519329,-1.210392,-113.043584,-240.631088,-237.699408,-171.112286,-88.682946,-30.019976,73.935069,70.12298,-32.689217,-64.180003,-32.241319,-12.220104,8.054487,143.393271,192.757111,118.747934,35.708243,-45.340839,-23.138293,34.296622,58.2639,95.424269,157.508401,136.026579,9.243099,-62.226894,-135.59144,-58.927317,2.815732,54.562149,33.465679,-61.533826,-104.112148,-126.58113,-134.249193,-178.697529,-138.431613,-69.392004,16.647247,-22.974093,-202.471373,-268.901275,-274.15273,-158.515804,-81.708255,17.825683,15.387913,-19.678689,-26.930234,-95.184294,-150.308736,-189.411743,-107.222067,-41.656527,17.167114,-12.180924,-94.858906,-118.219715,-101.471149,6.344901,47.886517,63.226742,73.975121,128.671466,125.478943,26.100419,-15.203704,11.115699,158.203062,239.834195,256.868158,178.299917,12.783628,-32.596879,-58.997651,-38.85346,-25.723537,52.459594,123.147207,226.557871,214.071013,80.129729,24.155264:54.737672,-36.572951,-107.575093,-130.955362,-113.951153,-126.582724,-138.808873,-164.555468,-145.662896,-93.95179,-14.644037,-16.026836,-30.637623,-27.03922,-19.371792,-14.36506,-5.832454,27.551835,67.999612,84.585647,17.614562,-147.756844,-160.980152,-63.998796,-11.82278,-12.329791,15.004379,28.293592,-51.089858,-117.637373,-181.894347,-194.822298,-214.099139,-134.090163,-52.635372,81.032476,92.922308,67.936547,76.743276,123.219928,199.369395,255.998266,352.748481,343.706058,171.018216,90.444581,119.085176,191.406886,307.155542,330.274658,302.557929,200.778465,151.785031,101.010631,106.84161,166.3858,207.965455,202.632401,165.15755,123.928125,-56.544609,-168.865623,-334.86775,-371.723407,-380.858432,-401.35323,-399.782339,-283.944764,-172.53657,37.227171,53.336205,-81.097196,-64.979388,24.352448,156.453903,171.997555,139.804447,102.355269,37.211734,15.948248,-20.789395,-20.833097,-3.964741,47.485759,56.532211,-0.910176,-57.002068,-186.41844,-222.792856,-185.50961,-137.760751,-160.813146,-191.733289,-171.207106,-157.362828,-191.096018,-241.633603,-178.986567,-134.669848,-55.509254,-29.930998,-20.858992,-21.771185,-25.4456,-70.030697,-94.920405,-60.726471,-16.317714,-27.056772,-95.929417,-226.117004,-215.570119,15.596346,243.006938,260.288368,186.280891,137.268186,19.356243,-38.772412,-72.972957,-38.852724,-52.140221,-82.357088,-47.708078,23.694804,-14.632836,-193.714791,-263.068467,-296.380152,-175.651652,-54.379505,139.245839,130.595468,-26.763126,-88.060096,-106.143535,-64.466687,-28.310431,119.583849,212.074914,217.145282,108.161346,-26.256583,24.830942,173.163081,193.900003,187.444059,175.599971,139.431655,-2.082399,-79.950691,-199.219698,-172.823382,-105.684647,17.405275,38.865185,-1.174978,-35.739271,-85.081152,-93.772521,-58.706255,-40.858266,-35.535116,73.702391,114.666789,-7.60101,-105.18007,-176.248039,-101.510606,-31.082753,119.687937,150.353978,65.411355,-11.088849,-64.967784,-24.92457,65.30172,91.889106,103.967337,122.147095,84.892266,-78.786378,-121.427857,-41.218086,58.354737,72.815136,97.763721,131.407937,176.948953,152.391823,57.672472,41.735071,102.643797,161.34984,158.903744,104.031301,72.515568,85.018248,129.558241,202.108825,216.967781,238.026546,350.355631,397.487744,353.954197,279.319892,118.862008,71.301507,118.047227,233.688656,252.667999,185.130224,103.795179,-74.352635,-125.603226,-133.27301,-108.23755,-103.85907,-61.98669,-1.589138,106.193679,99.673015,46.640414,70.905457,201.688986,267.469318,269.292924,233.422506,187.14307,105.027455,97.78778,123.651722,188.189613,235.638659,290.967623,272.404099,160.987356,94.660051,37.846227,70.193936,190.510983,286.06972,316.540367,292.197285,244.006614,198.412559,199.966779,189.323351,183.232681,155.479022,10.309833,-63.950258,-120.051724,-113.048123,-110.927869,-109.454182,-36.296823,42.628511,48.038338,9.1715,-14.141032,-46.083408,-80.260064,-168.321307,-68.996758,39.883673,167.748284,165.798287,93.12393,31.288031,-104.105532,-134.869927,-68.174133,64.759819,101.772221,78.019735,44.787401,34.008127,45.640121,42.308529,50.445307,66.024892,124.539864,159.497556,107.755706,7.404818,-208.83103,-273.635453,-251.632497,-123.494899,-88.931731,-116.26216,-153.567998,-205.056486,-212.565519,-187.431276,-48.567927,53.83831,197.477562,216.870586,174.428282,109.724459,-43.396207,-52.192875,111.899778,208.334804,171.253052,83.106093,59.380857,-16.795377,-72.289819,-170.208591,-195.458498,-167.787897,-59.897073,-18.662562,-15.065982,-54.860516,-212.32767,-280.041786,-288.002937,-251.304044,-241.800192,-209.333414,-196.69833,-161.833502,-121.863822,-64.780054,-130.718636,-160.046741,-117.721045,-85.129875,-81.879893,-87.480169,-86.653532,-101.384808,-121.467674,-76.324695,-58.157806,-36.34655,-35.540713,-93.839332,-138.678641,-154.542472,-7.734356,72.164511,93.501348,45.498481,-34.947381,-40.975953,-41.007987,-62.925213,-100.565573,-47.283833,-5.238471,28.327224,4.370995,-45.482523,-28.582963,66.250459,110.502544,84.697426,56.269341,99.322663,197.372795,202.042497,123.480095,77.061716,27.303236,-50.484944,-78.09896,-13.7564,14.935819,-38.247908,-64.27562,-60.308971,-39.059444,-17.969276,-1.858193,-24.486757,-66.282738,-53.064581,21.191629,56.79836,115.034529,120.597123,104.339009,77.164085,53.88422,-4.364365,-18.562903,-63.214905,-122.068798,-103.261143,66.498331,158.172056,163.156764,88.343164,-2.49187,19.941491:-40.352632,13.632582,-11.75816,-72.968696,-67.482553,-39.652463,-65.613033,-182.801336,-172.777209,-92.575708,64.070841,87.432593,28.376409,-15.46165,-67.217241,-79.235195,-64.008617,-0.621785,28.505015,49.354558,19.105123,-126.97781,-199.076232,-240.488662,-177.505662,-140.256785,-82.304077,-71.3695,-100.232652,-129.069623,-197.417572,-220.14109,-174.060291,-43.926177,7.763608,33.091058,20.911564,27.77921,44.684416,85.23885,218.862601,303.622987,373.703088,337.57669,179.158187,99.545426,6.413364,6.697608,97.221445,182.436232,194.46959,167.508141,134.508836,92.522714,87.828176,45.249454,2.517152,-12.48134,-54.43902,-80.68455,-178.192418,-260.451978,-423.402721,-444.514386,-347.902086,-231.024669,-178.655638,-91.338411,-90.674291,-167.153852,-197.404104,-176.785368,-73.999148,-2.704506,121.258644,153.6534,139.265712,94.15674,-14.335032,-50.781238,-43.488475,49.396396,97.466073,126.995498,91.779383,-50.230311,-123.034269,-168.68087,-84.663724,-37.404918,3.794657,-5.8761,-68.063277,-110.493068,-213.445137,-264.965236,-301.706168,-149.354522,-13.694784,154.759498,132.577319,-7.146434,-58.019638,-77.854757,-20.207633,15.551071,53.426454,42.824083,-61.830222,-146.343551,-278.42015,-271.614642,-88.141201,125.662989,178.920213,169.668615,126.327558,4.289743,-61.377148,-140.977935,-55.412661,24.3864,130.338272,146.143743,83.567789,-4.258702,-200.539761,-265.387419,-286.89864,-191.756028,-116.215681,-4.35071,-35.228413,-215.800827,-272.039494,-252.085993,-141.00143,-54.640802,134.538384,184.945061,153.553392,99.964799,-11.257337,-39.151823,15.833754,185.394855,261.072656,234.496594,131.365242,-84.62339,-147.422558,-157.002146,-62.629424,2.655441,128.877211,129.372626,-49.231375,-155.448031,-241.135325,-218.018362,-115.881687,-15.803494,36.318136,87.169562,55.525311,-73.293726,-136.074222,-215.509134,-161.873422,-83.201179,40.742834,28.500275,-107.337571,-164.823843,-144.934593,-77.043574,58.949658,114.489086,114.276812,64.585847,18.787677,-79.771144,-114.598659,-117.32633,-22.591015,43.605954,148.036201,156.349259,48.527753,-31.210158,-85.517748,-61.944984,10.137831,115.332385,153.875519,148.477806,113.440909,28.154093,0.78609,32.222824,161.961863,217.267153,271.830132,280.657836,233.802926,167.442541,26.354949,7.379049,105.209674,212.940956,216.156932,129.757713,59.027084,-90.317523,-146.049725,-169.713097,-123.061425,-101.208098,-58.117757,-38.731995,-45.795213,-80.556172,-151.692339,-149.211585,-36.228118,102.358392,150.191691,175.227833,121.393637,-27.73441,-37.403291,56.139408,138.195269,171.232401,187.541603,147.713442,19.493489,-27.73206,-10.106975,52.69182,196.845847,310.909053,347.515637,317.766471,267.673476,214.407833,217.499953,218.740102,216.269326,197.753416,106.700761,62.264407,-1.292203,-15.756166,-25.186694,-42.33613,-35.578076,84.715271,136.627463,126.466538,65.143405,-81.504082,-140.570062,-191.856863,-46.890776,68.462275,226.66347,247.915908,155.094405,48.941513,-148.100864,-171.18426,-60.668442,90.201212,143.990575,145.905988,76.906444,-86.508851,-113.956557,-58.634134,16.934287,58.166308,150.819336,165.442738,74.604358,-5.309483,-128.639275,-149.764787,-111.582241,-11.646482,24.145582,-28.725339,-121.326307,-316.311917,-369.599909,-333.211958,-127.82519,-6.387558,174.865507,201.014591,99.85355,20.010618,-64.671847,-45.069325,83.944981,168.188803,172.540789,125.797376,75.73395,-51.501087,-104.458312,-107.105432,22.469592,76.013667,141.070871,171.712394,134.73602,35.232239,-187.637673,-236.982689,-199.808072,-89.717975,-25.478594,42.585622,6.961128,-104.671324,-107.03516,-7.596454,79.90472,119.437672,187.51975,175.900877,56.260062,9.577721,26.494711,47.318743,41.947082,80.748068,133.504289,178.909272,127.463797,-57.913001,-138.40869,-165.365333,32.159631,145.188897,210.858193,168.276765,13.301025,-86.410476,-232.200857,-224.649287,-81.176579,0.687866,-5.503655,-32.722579,-57.353101,-156.937425,-202.490623,-173.888359,-24.834448,40.294101,132.692823,170.032922,173.473981,107.763006,-80.286188,-125.525236,-72.027293,30.46389,75.87011,126.451658,94.360217,-64.028974,-124.67893,-143.386038,-59.973601,20.253107,137.903637,120.952345,7.407874,-28.859249,-63.340404,-71.323363,24.605844,166.703298,167.590879,54.203707,-18.11012,-133.177085,-153.011035,-112.237314,-48.373936,-7.436277,111.929575,156.604996,112.508746,32.301351,-98.591237,-109.530724:39.471382,48.602092,-23.937755,-134.388119,-94.627251,64.794609,82.629844,-41.083877,-107.216939,-78.761291,-1.685837,26.168251,33.772588,31.265318,102.611585,141.342462,78.953271,17.692395,49.427201,79.629472,43.679272,-19.365475,-12.69806,18.781221,29.091289,47.905337,69.707733,25.08525,-217.779067,-353.831007,-458.245773,-433.92655,-342.467423,-224.137018,-160.658983,0.975804,79.46528,117.530286,91.025873,81.125918,124.782568,143.076442,210.239214,249.837285,232.6139,176.290856,126.160743,174.169772,323.576671,385.075936,375.958907,330.883797,300.170807,228.688965,205.390204,200.369694,203.660577,182.568961,84.004295,38.382087,11.977779,-7.980926,-170.140457,-270.814378,-357.247187,-354.647526,-328.464135,-166.870365,-73.912855,9.277327,8.542817,22.384193,165.563366,253.385537,266.60725,188.553369,41.25954,33.586347,114.512621,125.381463,55.746401,-14.668076,-36.71572,-39.751333,-45.470448,-123.466202,-176.118561,-219.65966,-191.877331,-206.834785,-320.939309,-370.125523,-387.242211,-376.59838,-371.75232,-369.730543,-339.539577,-311.632363,-301.785095,-258.860141,-232.43396,-200.766279,-197.281417,-215.218788,-233.877481,-227.959356,-166.87003,-107.011306,-11.146747,-25.499706,-121.542534,-120.404163,37.570378,171.134854,182.527674,181.109655,170.405901,100.890024,73.346097,87.303311,71.674148,19.652982,-97.463155,-107.319787,-16.612644,23.950434,-35.859527,-124.480476,-230.914907,-81.51881,43.427499,192.151456,176.998354,26.560123,-55.497174,-125.094444,15.983278,128.263784,273.600258,300.736912,272.876247,218.980261,128.28561,117.730146,137.546178,119.502411,106.543154,123.273961,113.231664,29.070265,1.054017,-12.475698,-49.648712,-64.094225,-71.599034,-87.990107,-179.080198,-226.020868,-222.970074,-183.86595,-122.742058,-97.195747,-73.365814,15.796425,25.703064,-104.6763,-166.292746,-127.502859,18.998538,85.076168,141.431985,116.388153,43.451364,44.619069,112.685365,130.058124,67.69508,-13.560974,-0.646326,79.217037,65.729425,-98.57149,-173.623474,-157.402104,-4.367392,43.351425,60.897498,87.77208,182.384616,180.126488,53.384106,-0.968215,26.606894,145.968071,169.415071,124.566222,93.143204,73.411176,84.950567,139.35348,248.56851,294.187022,347.996854,388.037746,437.622529,388.7943,195.627265,130.631218,152.497462,279.388317,299.557776,201.741622,127.989622,-5.693839,-64.316722,-134.872459,-106.122272,-87.978303,-108.932294,-115.004307,-53.523122,-11.833479,63.192117,96.725407,116.13871,115.323022,135.668645,194.405448,212.547979,197.685569,159.643556,73.176238,63.024866,90.268102,185.966,215.479072,158.295831,102.29901,71.732053,111.894238,209.970484,232.279637,218.397896,173.352926,148.086422,95.61053,79.040554,64.140332,3.881322,-60.238067,-180.194594,-210.969001,-244.587078,-244.917015,-220.914678,-229.300802,-253.896387,-173.915127,-115.931476,-46.883519,-35.831481,-55.49364,-88.877782,-122.688703,-2.809905,61.538404,74.908684,58.83688,54.687988,46.16815,-3.179812,-12.917571,36.521103,37.575965,2.780974,-58.980008,-71.743549,-56.047086,-51.520772,-76.19219,-45.945873,-13.328449,19.667416,29.663831,29.699062,-14.305485,-172.139349,-231.880614,-221.300289,-126.490625,-118.058562,-188.462047,-216.260216,-169.108394,-126.595291,-120.138035,-122.650039,-62.371057,153.33624,245.333218,267.260798,209.339749,83.648637,63.105946,151.306047,222.87602,190.949655,112.589582,97.326726,62.591447,29.279082,-65.365164,-130.254212,-130.881506,-111.084143,-99.481592,-56.859075,-34.037512,-28.522016,-52.484683,-150.905931,-262.601154,-266.624839,-161.717572,-117.999737,-67.558633,-16.45738,62.481425,2.639961,-25.883989,6.636852,36.987797,16.677759,-24.226586,-47.854195,-26.69563,-15.261721,-46.84926,-73.72049,-148.337689,-172.341571,-188.637001,-205.8558,-229.366987,-131.198983,-50.252901,25.580231,-14.065811,-132.07984,-146.121522,-138.699059,-153.580379,-159.151829,-142.002679,-145.81338,-119.447371,-92.068668,-71.567374,-71.841824,-30.357059,43.619814,50.121534,29.194731,45.869553,91.189261,67.355793,-33.028836,-62.646482,-72.189006,-72.747338,-70.094045,-47.220932,-50.501622,-85.035666,-86.667047,-89.869125,-112.902454,-100.935167,-46.745019,-31.333908,-58.34397,-78.079178,-55.340042,-21.929997,21.997401,17.193686,21.40848,55.823079,40.407756,-85.753432,-142.326739,-143.720788,-30.050847,19.219554,51.81687,61.010411,80.61258,71.448169,29.321614,21.340674:5.740141,-36.303415,-75.589224,-52.428502,-20.880451,-35.774288,-69.41374,-104.29895,-68.392244,-50.571339,-34.210324,-14.382453,18.085559,9.124675,-5.038573,6.484067,40.479808,72.694764,81.769767,95.888105,112.055515,124.626269,104.971651,78.075411,123.804374,140.103223,148.061031,148.860109,91.723844,30.78107,-92.199407,-145.243297,-212.681989,-178.502565,-123.017509,7.512591,41.67621,15.989726,-12.228245,10.236721,162.703799,227.807124,253.77048,225.199366,137.393228,115.022771,168.527936,225.097649,326.308192,371.880957,372.105478,292.607846,221.433216,144.458702,153.92339,183.065058,163.522546,146.660486,148.869505,160.735416,83.973474,-15.392791,-194.723589,-241.056857,-306.637591,-341.285361,-302.909499,-138.830038,-70.616619,4.818548,15.817645,-16.807299,15.537361,77.966294,185.143127,190.372901,145.814938,143.795394,153.732738,104.077585,-66.235306,-120.917294,-106.978818,-101.254661,-128.135008,-191.577105,-201.176964,-180.931923,-185.943824,-205.348243,-233.228826,-232.122679,-210.245327,-198.695641,-191.800674,-191.426559,-170.391261,-162.173096,-178.76427,-196.192741,-180.244953,-149.439674,-158.159191,-218.965401,-310.314763,-345.439525,-291.395824,-206.747051,-62.158504,-46.909848,-107.190174,-128.510488,-56.750288,77.888317,136.0747,200.419717,172.549482,83.383901,95.477344,174.318349,134.657058,71.631443,-25.025214,-24.909231,-2.687052,-24.461119,-114.507991,-154.089833,-174.319659,-100.753903,-33.501126,102.965448,126.992067,52.819123,-5.161451,-72.500267,-59.74332,-14.934507,163.995047,262.960708,285.61284,194.559693,29.515687,25.474862,158.013717,290.800791,301.547687,221.825082,144.644854,24.741347,23.878019,81.13278,126.357528,130.089383,106.882731,86.627053,8.032262,-25.599161,-13.606379,6.940103,30.424788,31.859666,41.260776,124.515627,146.946517,76.978779,31.591184,-18.66407,-9.979626,44.163208,206.173852,236.323846,164.511238,137.674264,175.237978,195.871414,130.219755,-22.182813,-47.961233,10.539117,16.358082,-87.44228,-136.788491,-123.334742,-3.144426,63.457675,189.062746,256.729295,340.414966,327.48683,223.798001,154.092322,64.346767,121.533659,148.808594,127.17098,120.733935,167.544711,185.395779,172.835404,192.888966,222.24172,321.648172,365.375774,314.710392,231.196809,62.595763,-3.592626,-55.286847,3.668847,36.086137,44.630989,3.350079,-130.676976,-174.033324,-137.061899,-29.242249,-23.403051,-73.631231,-51.63562,90.927108,140.781867,137.320213,123.869894,148.534848,199.449248,231.753906,260.332634,218.562813,102.705223,90.558837,161.230354,241.569334,254.705609,238.052408,217.163341,111.287724,51.677287,52.349211,96.942166,159.038215,125.758507,88.747542,84.085641,131.270444,188.973478,144.31467,13.255927,27.53772,59.671061,43.256206,-1.221524,-60.075343,-60.127058,-120.825377,-189.500237,-208.570726,-104.299974,-86.618728,-68.30142,-35.510883,31.265626,45.809659,74.868731,117.796176,109.410427,43.36536,13.247009,-43.770077,-79.828736,-168.517886,-205.130312,-187.826402,-117.167822,-105.117342,-97.464585,-102.797082,-124.950964,-111.639178,-40.096189,-11.357488,-30.619424,-67.526525,-56.485846,-13.784853,-27.030789,-197.216762,-304.476314,-343.308215,-247.230037,-252.212399,-359.131404,-408.06372,-369.998159,-300.580871,-211.53068,-149.257693,-87.802993,75.162701,147.189744,193.163593,179.638169,150.732104,138.600669,149.84674,199.255202,204.858139,175.404543,157.379464,109.207329,58.103252,-77.993733,-135.603361,-124.113289,-21.182787,38.761869,60.303514,35.551343,-43.373643,-110.396521,-249.921293,-278.986073,-248.302537,-180.995536,-156.532899,-70.141905,-18.872577,-14.783048,-85.723747,-85.21889,-18.265317,12.323374,8.304738,-26.301264,-106.064193,-129.382486,-115.452148,-59.621197,-44.534304,-57.775654,-87.869234,-166.228876,-189.876731,-152.673663,-43.222129,-16.379996,-36.739798,-60.504074,-75.484826,-65.527509,-75.047052,-91.970509,-124.734067,-204.766965,-227.355559,-138.906798,-58.772229,46.993131,60.192745,51.428593,39.763869,16.149983,-6.689364,38.473815,149.727376,152.001546,99.5512,94.02455,59.588105,-117.936115,-182.046837,-110.682715,-33.160795,5.262159,-36.493669,-135.145565,-145.504269,-112.262877,-27.124244,-2.041977,1.775893,14.842516,78.925245,96.618669,109.420002,81.854866,36.429592,-20.598013,2.516487,83.01233,76.381498,-68.220848,-154.557468,-123.626842,14.840725,76.357458,73.156266,15.821293,-59.837196,-45.187833:-31.664731,-20.572328,-73.606723,-118.68993,-49.731863,150.853086,182.405965,45.172081,-105.168457,-114.272428,-42.282569,7.238713,54.148668,54.16841,58.565733,45.51548,-8.185636,2.808778,11.268098,-47.187587,-88.429839,-95.927288,-76.3561,-81.223428,-93.39048,-85.966816,-119.819074,-147.377771,-149.901846,-139.844386,-159.504246,-188.381324,-199.228131,-111.450128,-81.511446,-92.43542,-81.085497,42.370275,103.368111,128.608731,153.213348,206.389975,295.531965,281.492666,141.792413,63.890791,33.517369,88.070216,213.41305,226.343776,218.663872,221.913955,217.1279,204.21652,188.453667,115.02456,65.172539,48.541066,-55.147843,-127.327155,-176.019779,-166.694795,-238.221207,-305.324396,-331.565239,-225.705814,-184.747811,-161.736415,-151.029043,-73.331345,-41.070656,-49.956334,13.08377,68.953203,79.443217,62.850461,88.101246,97.844625,68.396089,45.751102,-17.603956,-46.33836,-1.140587,87.205213,40.572208,-172.573637,-239.64494,-236.227561,-206.41044,-222.410685,-285.29254,-299.73672,-277.26835,-266.544284,-295.445468,-312.462984,-285.964833,-229.160923,-213.195256,-139.572785,-80.445927,-33.593342,-50.4366,-90.483174,-51.556489,7.201563,119.55898,131.325154,47.941378,-9.039672,-94.594282,-111.728901,-17.02582,157.135025,198.218658,193.660715,166.924891,45.670606,-52.377648,-173.574592,-43.017868,31.0252,33.313604,7.85094,13.752061,13.222448,-114.520478,-232.795238,-365.70704,-168.545854,-27.107076,113.310672,98.90501,3.945055,-26.460993,-24.581104,67.000752,135.804857,242.720841,274.982726,228.587445,142.41349,56.644491,96.018879,216.102571,243.850374,199.801881,57.461092,-0.247153,-45.724865,-51.193118,-84.640316,-134.666232,-151.649797,-143.205164,-114.34898,-116.219157,-163.383077,-215.044753,-201.077486,-176.772476,-164.920287,-128.763931,-23.66062,-11.583395,-88.60648,-140.534072,-239.123696,-231.891499,-140.632281,48.550182,54.418357,-40.876202,-64.478321,-26.934367,4.625841,42.975086,49.458581,56.837224,82.751358,72.457448,-29.327186,-89.448072,-114.649268,-15.46202,23.821022,5.73865,-23.684014,-41.749124,-39.777238,-32.117608,-9.153856,96.787212,182.254239,177.857491,149.814617,141.502041,97.636822,82.86052,132.498427,253.317745,301.068357,308.906646,297.887921,283.876522,244.367021,135.628068,121.107458,185.237332,257.902006,246.162969,117.789921,29.66601,-101.080958,-110.304828,-52.469262,-18.517622,-41.71131,-125.263998,-132.460997,-78.090806,-52.550922,6.876767,47.832,110.417344,172.647546,212.085813,197.942663,118.416257,-2.648198,16.304556,102.898576,164.161815,185.607378,147.864263,85.352743,-7.814797,-8.432869,31.509932,45.428111,127.851374,306.817577,329.819438,180.361701,95.644449,51.826266,77.935666,104.83159,36.80462,-8.215778,-110.641412,-158.281618,-179.519416,-149.773734,-105.658152,-123.907083,-172.718119,-96.272656,-21.692061,78.187722,55.775618,-131.362977,-224.920433,-219.826996,23.417337,129.803924,139.089232,86.296924,39.002032,39.137806,27.162726,38.575596,121.411563,124.842703,72.563739,-13.543891,-12.020928,28.399996,38.305071,29.475251,15.309153,11.615396,14.134182,22.53948,-2.793224,-61.451478,-235.198803,-300.329309,-233.105865,-27.445605,0.323041,-77.639872,-120.353787,-156.781598,-152.048334,-133.938544,-80.279849,-27.267612,67.234148,93.366259,91.085963,72.661843,41.161749,29.679061,29.206969,54.297616,70.211286,98.490819,84.855786,4.435186,-26.104164,-58.236377,-65.934293,-54.123904,14.920549,51.35513,16.752651,-46.759763,-124.373918,-123.147844,-131.207382,-164.399821,-155.322036,-102.70511,-88.382024,-71.186747,-45.903845,22.18967,55.485866,67.361826,105.111273,102.231257,26.455793,-13.705186,-36.571322,-23.066594,17.326668,22.820323,17.196759,17.395581,-2.541951,-87.878659,-126.795706,-159.28024,-27.103141,75.512155,132.878483,85.74991,-25.231605,-83.405771,-195.31573,-204.716467,-100.414299,-42.163948,-52.586665,-10.881884,36.340128,50.017571,14.290771,-28.345857,43.2478,88.244646,143.52887,160.839877,165.823388,143.452377,92.58632,76.293068,23.897069,-34.262157,-28.697183,71.189037,103.308491,26.283128,-39.33337,-58.540585,106.782784,182.163575,204.971126,161.168576,49.858552,17.606765,-12.322453,-17.433586,46.042796,173.576505,188.613825,106.405777,46.82497,-64.040313,-80.960383,-18.019382,21.93519,36.784831,107.563766,127.358035,91.642578,63.02504,12.976638,-11.24702:left
11.047401,70.741467,43.069161,-58.355908,-74.811019,-19.218748,37.246464,133.40466,61.983486,-15.370436,-120.072625,-112.233781,52.632245,158.032152,250.064693,232.865698,158.252514,102.233408,79.719092,46.011413,42.359194,35.914317,37.061132,81.022884,122.933526,136.672853,154.701227,160.10325,181.211185,182.831889,158.456441,151.634276,173.420979,182.006196,142.605291,50.072747,53.590797,95.531853,83.598348,22.938447,10.350344,23.106018,6.0475,-23.808625,12.755563,78.344917,109.785351,57.758614,-39.790983,-84.626539,-115.987989,-168.331352,-168.347404,-131.161015,-109.502189,-100.11116,-152.874223,-183.714672,-210.291923,-192.525441,-131.923076,-109.027329,5.772509,96.450833,157.586415,10.830304,-89.243801,-208.938416,-199.777715,-135.483143,-108.753658,-36.239815,8.104336,11.221897,17.70184,36.81561,133.778245,181.658149,202.233189,180.407854,134.164947,177.053783,198.640482,166.725631,152.280928,166.884646,175.660158,215.123652,300.925939,323.815296,217.345509,113.200695,-45.789265,-86.608164,-76.339257,-41.475264,-32.360838,-26.395078,30.822436,181.261136,225.975042,245.319263,254.179423,275.480797,296.212913,309.034889,184.732457,40.623759,-184.392461,-217.863001,-182.501581,-143.228694,-122.584875,-172.989144,-185.035625,-166.696878,-122.919505,39.46231,138.87051,308.685394,305.798738,231.862773,69.292406,22.3228,-7.596176,-11.824903,-31.022764,-46.395233,-65.503061,-13.73319,25.509956,51.338453,32.647695,-32.663039,-56.317917,-50.7146,-28.64788,-39.86167,-156.046456,-235.901781,-298.706467,-262.874778,-95.84289,-5.413117,66.003816,59.884201,96.501163,248.294053,321.610762,405.414903,434.433222,525.947824,559.948165,500.598172,303.914769,238.843563,191.620194,174.868558,208.978599,255.566801,237.208866,90.36791,35.231479,-8.332649,-11.42615,-20.84921,-28.949509,-33.161687,-13.541117,4.370139,-22.201495,-58.987663,-33.468006,20.317863,33.619098,-6.181189,-15.423242,80.433262,102.133042,57.298279,39.28539,92.443436,139.957661,155.223438,23.496326,-44.103422,-161.394387,-218.562336,-251.570208,-242.886726,-274.016668,-292.9733,-273.81725,-271.113161,-310.258398,-360.069847,-322.524337,-214.299522,-184.522881,-145.504411,-113.001848,-115.402825,-179.147552,-214.692378,-183.165286,-121.896663,-56.325156,-75.558304,-117.447534,-126.20149,-180.478833,-375.382945,-423.683887,-288.707077,-141.143824,94.227495,89.56514,23.490909,-124.456124,-142.703792,-30.326174,29.643483,74.636547,92.056405,122.094723,59.069299,-1.082657,-78.490551,-74.290514,-22.163039,-0.801792,-6.801807,-44.961962,-47.337294,-70.777665,-103.293636,-119.197787,-94.530109,-25.234778,13.455143,68.652423,37.122883,-25.259714,-171.127367,-199.771704,-178.852216,-145.989963,-42.268619,-41.617938,-92.65932,-186.88907,-183.062118,-24.112335,74.99973,145.218316,101.451276,-80.9145,-217.75411,-250.527558,-280.768638,-274.743099,-216.574879,-153.562001,8.178028,79.162425,80.333349,48.660566,23.525999,-28.569322,-85.037191,-211.397891,-203.722283,-107.636159,-123.830196,-158.81167,-211.627291,-222.041579,-150.558766,-68.476623,55.872358,69.591904,75.799647,73.147105,55.224222,82.792696,133.136271,220.552617,237.948281,219.727621,173.194061,123.571618,-42.38787,-105.555429,-85.748913,-18.037985,68.022274,-32.414558,-96.075159,-140.854878,-116.623569,20.926103,82.383157,42.355485,-31.542916,-152.337612,-186.543338,-175.660531,-125.457065,-92.068438,-40.735534,-3.981561,128.704854,205.035376,186.456415,33.023139,-45.702663,-46.386943,-16.806303,-70.550738,-123.448955,-164.893614,-176.884201,-217.208333,-285.943079,-245.542425,-98.720962,-74.027144,-106.165308,-96.264852,-85.046098,-189.131357,-290.58701,-361.489565,-315.155838,-210.831262,-180.599726,-136.149524,-75.660664,-65.104922,-108.012749,-123.394047,-65.021941,18.880977,203.08774,165.410004,79.701296,-77.513374,-124.099612,-136.144004,-116.572419,3.549234,113.643082,259.874679,244.578532,229.647595,203.459676,195.698331,195.051356,194.58925,175.204679,106.135686,71.991577,76.88157,113.673233,162.516033,146.320075,125.528478,160.161325,208.354313,114.440211,56.304679,0.310146,5.051464,36.510251,48.267158,88.760718,122.537148,104.535348,5.874255,-36.662308,-33.972027,9.448162,130.488222,156.549279,70.760353,-65.048877,-126.756174,-202.071752,-167.257933,-2.971419,54.470749,84.712729,74.412259,75.483279,43.815204,-1.00046,-12.913214,49.270687,181.595425,196.152546:47.551911,34.203725,-0.940571,-31.58552,6.860506,67.856979,60.099957,36.322088,-5.479053,-33.98375,-70.3394,-58.174303,57.8499,126.957724,153.80385,99.677277,-33.710558,-83.326674,-87.96121,-95.23983,-94.629646,-69.963862,-25.803709,103.84963,80.898068,0.209784,-79.203667,-16.180514,155.534099,184.683373,147.625757,101.86029,2.203383,-16.729486,-18.062212,-29.415185,-1.554791,125.406428,173.515054,150.252005,53.123687,19.419918,19.480948,53.824005,144.123741,170.125906,155.038302,126.375624,63.573812,-32.790437,-97.843408,-192.342103,-202.106217,-153.337312,-132.746747,-182.251421,-249.432289,-265.042573,-294.148762,-271.383231,-122.610232,-55.93436,41.474691,89.858722,89.873087,-92.915325,-196.545284,-252.999072,-200.022285,-107.027391,-110.34469,-144.285186,-119.139625,-91.834749,-71.771912,-69.675052,22.851268,93.84564,137.626391,102.081391,28.157705,-7.872112,-31.718745,-30.022272,17.208268,122.316143,141.989444,129.458056,129.984282,127.911926,38.730634,-8.758923,-1.039849,6.392562,-60.589994,-107.444183,-167.67061,-111.055665,-32.95594,148.525331,219.282574,274.67043,279.63635,289.694157,196.922531,110.414699,-48.23261,-95.763031,-133.154431,-140.245641,-112.488856,-77.215493,-64.677845,-170.312317,-195.510025,-82.086091,4.86045,88.298555,109.586358,188.216718,228.838959,199.279477,69.753761,27.4165,12.764096,-0.559398,-54.32486,-83.012551,-124.466217,-125.991621,-118.679095,-61.072045,-24.961825,-12.785556,-27.550959,-59.849992,-56.7688,-49.703798,-106.75468,-143.557145,-172.655223,-182.688837,-137.484058,-64.911006,33.526537,-14.320525,-12.376857,130.757242,212.582346,289.99788,329.518937,463.513327,463.589058,398.004179,274.509344,247.330223,230.833748,222.875187,224.09158,220.656048,117.228849,-9.813506,-28.152682,5.802889,24.865553,22.072354,16.566657,6.684266,-49.140524,-82.252557,-127.184885,-125.885679,-84.301274,-79.33592,-128.751583,-163.276699,-178.764574,-91.408453,-59.958445,-101.528722,-132.265151,-85.757457,-22.201335,14.997519,-103.564267,-147.39845,-161.446641,-152.116398,-79.650302,-37.652251,-69.11459,-137.80705,-269.03841,-288.111898,-270.219248,-181.432,-103.561258,-6.896646,-10.742514,-34.957919,-75.616571,-130.436837,-226.484793,-210.087549,-112.948646,-93.623549,-97.081633,-80.188336,-65.435528,-266.450575,-401.995534,-471.174989,-392.76591,-225.982749,-196.112048,-186.758581,-153.38123,-157.946045,-245.626107,-271.645765,-190.255254,-119.704408,13.983544,68.432288,48.155806,-149.84834,-240.979568,-308.691337,-302.055045,-223.789064,-141.861534,-30.135586,-136.99971,-206.647755,-253.285138,-232.269817,-135.807626,-89.390394,-50.535812,-44.166203,-20.029735,-78.120668,-147.537552,-206.204939,-183.374373,-143.689425,-131.585883,-106.831653,-118.046199,-121.885833,-123.225059,-128.95637,-69.275943,5.637829,125.023523,122.076102,-10.607367,-176.595554,-225.873364,-219.002196,-189.804355,-171.951616,-149.291664,-4.664607,95.733822,99.579731,74.2553,62.451871,69.396393,66.405245,-12.081038,-51.549021,-23.177463,10.101237,-36.462501,-165.526979,-182.844123,-109.079987,-50.332459,63.609922,95.984333,66.102589,-13.922721,-19.392222,66.767748,126.81934,217.000036,226.069268,160.731782,69.318782,38.566153,48.366166,82.356293,127.564883,125.169641,86.480181,34.8163,15.100669,-7.221708,9.837305,139.449129,204.093975,221.552699,181.999898,4.502687,-120.026482,-97.038588,-21.330775,-7.456544,5.559338,23.134328,93.186528,158.452739,140.803564,-36.803163,-125.77009,-129.098381,-73.322508,6.173352,1.492877,-73.835175,-164.574475,-218.394894,-236.833309,-158.182726,55.277046,105.368605,49.774303,-42.31483,-70.43907,-155.463533,-195.17551,-150.086226,-80.171378,8.186943,10.790605,26.145976,73.945771,63.830291,6.638319,-3.799133,17.497329,83.887477,296.541107,253.376172,139.751278,23.897745,47.956328,111.012054,113.570811,86.672752,91.593086,204.564462,286.830603,232.090747,79.763346,76.037387,154.863329,161.246093,105.704058,89.267065,89.527952,38.811256,-1.97936,-28.267317,-15.632919,38.047003,86.034734,114.568593,-17.3043,-67.968157,-26.484496,33.284157,93.494762,88.493898,86.236821,113.531393,112.756534,48.292333,14.11244,25.370425,75.608764,227.386298,284.52815,256.035702,84.737193,22.276,66.967449,138.781411,213.858099,205.195104,152.171359,135.410722,146.787449,106.251494,46.871941,24.800057,100.646669,246.426338,239.781416:35.389422,128.597025,105.8168,40.912092,31.712629,31.444548,56.009777,142.17164,149.61379,115.539578,30.314198,12.919599,52.177466,80.690256,89.804063,72.138859,25.728438,-42.999904,-74.954597,-82.099868,-64.489399,-11.582627,26.534629,71.52782,32.489279,7.826944,-8.838183,0.845379,35.109103,51.982709,51.042606,22.336693,-25.138355,-33.712536,-52.542312,-64.541395,-28.524182,35.405104,26.570049,-25.318204,-37.14746,-22.975266,17.303271,36.733871,69.685352,86.048785,110.14397,107.92908,86.941047,7.880983,-62.003533,-168.154532,-180.264302,-136.49803,-116.802083,-207.731468,-366.976848,-390.253552,-335.525554,-276.755276,-133.435876,-76.944032,-22.347447,-15.78392,-45.028719,-181.900968,-258.454762,-263.997782,-190.290066,-46.709075,-32.005167,-115.259277,-160.823858,-138.133535,-108.14121,-109.176891,-69.352842,-23.840375,65.310955,70.67837,-17.249096,-122.471016,-156.367416,-102.28327,-6.16814,182.464613,221.982522,197.12014,161.339063,143.793946,69.351807,41.228034,19.967548,-4.777118,-42.646669,-39.00591,-90.934968,-167.139733,-142.609386,30.00663,122.334261,181.329466,164.389733,135.307157,25.620343,-61.223468,-163.894992,-170.015879,-146.29416,-123.960692,-56.556633,-25.999604,-41.340571,-175.63374,-224.10129,-144.965724,-54.902188,43.357115,40.949787,-12.685652,-60.309475,-46.939401,40.694229,73.378973,60.128166,32.268805,-30.686668,-85.333172,-214.718812,-191.005604,-132.734745,-83.488137,-102.779994,-122.21,-107.343359,-100.966758,-114.215725,-122.992388,-185.528782,-212.711436,-172.828009,-109.815982,10.457242,38.972522,22.606236,-115.209279,-176.931492,-83.474928,42.171767,227.885811,267.914083,305.769368,303.059422,273.103169,185.71714,158.595829,135.899187,136.668928,202.164853,244.568144,211.543082,28.600087,-46.177415,-47.738634,2.505625,64.401349,68.059323,65.151612,10.198003,-38.196122,-117.056767,-124.23579,-101.39474,-107.416313,-124.006364,-97.784314,-20.352784,-47.402312,-92.049188,-88.710409,-27.886173,56.526738,44.824215,-48.346927,-146.664018,-172.641201,-187.587598,-169.813127,-71.198086,-22.368353,-2.131906,-28.381117,-129.14648,-211.627128,-216.723757,-132.615731,-45.010783,104.87707,124.611435,57.992784,-72.44258,-113.50388,-81.534418,-27.453326,57.810777,66.899634,3.453516,-75.307923,-280.670814,-407.761718,-422.583211,-398.656362,-363.78042,-272.471789,-234.872495,-166.730326,-134.469309,-149.855996,-219.785354,-237.389452,-169.367777,-108.867362,-26.701748,-4.646998,-7.498636,-155.117513,-243.377999,-280.582801,-248.950355,-168.966251,-99.558501,47.732815,21.04847,-39.468148,-159.673709,-188.657144,-111.356486,-33.009789,69.233114,77.07955,52.070168,9.593291,-18.738032,-55.289252,-45.601958,31.202778,67.725805,36.164153,-71.889918,-105.596653,-108.852213,-76.042209,32.254713,89.250805,158.71473,141.655927,19.568514,-97.672497,-138.688681,-163.093031,-134.061619,-61.476969,-52.65863,-74.897753,-48.957782,-23.680702,-47.443118,-71.937667,-1.995568,66.802065,126.609806,126.320023,116.780757,44.002851,-0.110679,-10.284494,1.776255,-23.671158,-34.116451,12.145302,63.197981,53.766622,-31.253955,-59.64116,2.99968,77.723659,182.285173,174.838107,118.591686,66.677482,13.187268,-54.344699,-18.962477,106.527765,127.63209,55.254077,19.717409,28.072578,20.368372,33.000744,104.355779,125.927304,138.903447,124.081661,19.180464,-60.95986,-75.88163,-57.581179,-14.145673,44.671546,26.044401,-40.137376,-19.092265,3.954296,-37.725451,-85.275212,-131.704607,-115.185106,-35.162704,-20.822719,-79.150892,-135.341159,-140.935148,-89.608442,-46.524789,14.252999,32.360719,59.150186,65.988953,51.204235,-34.609249,-86.593801,-117.497765,-79.174966,47.849384,84.541857,46.371896,-52.00425,-77.88509,-45.933971,-1.71924,120.153795,188.431552,216.223317,96.762066,75.837008,125.181618,138.645287,112.931365,98.9593,91.673235,87.16176,87.739409,119.421412,122.637549,106.086626,104.589828,118.251169,132.337113,152.284297,125.632507,111.656213,101.8842,97.263782,59.265705,27.257208,24.498244,67.693817,126.591696,51.842212,-7.680463,-21.20395,36.686155,79.174196,38.098035,24.776443,85.912413,70.369001,-17.702358,-21.434302,117.214642,208.783805,293.303566,272.932107,196.010842,160.55911,153.363089,174.896451,199.235377,214.517159,194.352094,122.583674,83.657656,69.112509,-1.105641,-17.228404,38.209389,60.963796,57.030156,54.575622:126.549084,29.473108,-54.469375,-144.14173,-127.209894,-83.059783,-70.279828,-18.282025,-5.025545,-20.469042,-58.699623,-55.778353,33.489451,87.981062,138.841494,124.218303,27.064643,-63.608402,-100.382122,-117.253976,-70.465225,43.978375,56.997758,4.307292,22.872734,72.973352,121.936792,109.55486,101.580749,110.034625,79.305177,44.468869,29.214326,56.003766,32.717306,-30.321548,-8.467932,106.383629,116.857216,5.814287,-56.305245,-49.367544,-67.888089,-79.652395,-24.066003,18.891194,38.334455,16.382551,-39.537308,-94.889348,-152.382676,-288.428866,-296.486582,-194.478037,-163.758378,-232.485734,-341.559964,-354.308975,-313.586063,-278.886238,-203.797459,-180.518667,-113.569333,-55.771201,-50.545859,-273.716162,-383.776301,-433.140941,-383.628142,-299.127157,-285.025071,-236.355833,-183.556075,-180.443064,-172.336367,-129.375081,47.749252,123.478756,124.056473,67.256218,-26.238947,-12.41123,2.97718,30.095988,77.631608,229.425995,298.384157,397.657814,407.056144,354.83023,157.485039,69.588518,16.665247,16.044859,-22.960123,-42.949348,-48.596475,-22.55961,5.977307,88.408061,129.602161,197.396012,227.824712,243.076197,149.696596,83.068528,-30.095511,-60.935229,-94.17994,-120.120811,-133.076552,-94.686956,-35.181342,-103.273701,-155.362105,-192.152221,-160.781811,-27.436751,61.075266,234.176915,282.331353,250.092299,153.858526,112.937426,74.54803,73.003947,45.709204,1.183902,-92.186078,-70.140383,-43.652828,-59.798631,-76.591158,-81.525146,-84.090567,-79.117989,-85.298919,-124.732718,-239.068103,-258.534393,-207.025058,-174.930028,-72.306252,7.721031,87.288821,-8.065342,-43.601618,73.720547,204.952822,410.560658,466.196658,561.27959,563.080809,500.395986,346.201007,308.552151,265.040854,223.161796,229.329285,300.454366,355.765224,200.397218,127.11673,99.343704,103.492371,54.033888,47.829356,113.271015,101.531629,63.36397,-41.945452,-103.23672,-153.912912,-131.544735,-50.737106,1.044939,93.612597,51.960128,-12.746832,-48.945676,17.146788,161.533707,183.416138,141.66552,63.633318,21.888576,-105.488311,-146.03896,-57.039399,10.642745,-9.898267,-73.017967,-131.574295,-85.276881,-78.409374,-105.356808,-87.728883,5.569796,32.64291,37.942213,37.953534,25.909805,-21.578814,-31.221053,13.510943,50.485491,95.205342,81.586054,-48.307169,-217.041473,-271.42251,-304.366072,-278.476143,-150.204205,-68.447688,50.221297,68.901191,36.717577,-111.277685,-178.295474,-146.900642,-82.391547,2.147212,44.854938,125.749312,49.83905,-16.503433,-64.963402,-44.680569,4.226714,17.176033,32.269149,24.123204,-0.724297,-102.683713,-134.510914,-28.486221,76.211011,218.647416,237.650891,226.551684,172.906663,114.94651,-6.503174,-36.813096,-60.397487,-70.769043,-65.160544,-73.882855,-105.614794,-112.743001,-54.502061,112.196387,171.433629,163.992782,100.469458,-29.27797,-73.869457,-92.003109,-130.025994,-132.550164,-102.363652,-62.363983,33.613099,58.683413,52.060358,25.107392,2.170316,-8.048224,21.00405,82.659824,88.800958,53.629381,15.948428,-8.773654,-105.331336,-144.320817,-120.828272,-73.553561,33.814554,90.068029,65.078194,-45.660233,-57.244221,99.507641,198.047454,257.491736,217.29956,102.220164,67.858668,41.946934,-91.205434,-148.098292,-136.221569,-79.064612,3.366153,-61.525071,-131.764965,-230.80424,-201.136947,-17.433847,39.854987,-3.924946,-43.252732,-91.288674,-163.11463,-198.848168,-179.028933,-126.050205,-81.689003,-88.247107,-21.159531,46.804291,11.923421,-124.698849,-170.945582,-243.053275,-293.274587,-291.009479,-210.546382,-93.524689,-160.550994,-211.20033,-262.71609,-255.351339,-194.093923,-148.074899,-46.177622,-30.221119,-53.069185,-126.886786,-193.586094,-326.824682,-331.687137,-195.279659,-112.781285,-59.337231,-117.429778,-140.587901,-156.405732,-140.693247,-38.820068,45.957721,194.623215,154.957355,93.881101,7.389456,-23.865257,-65.848294,-55.756145,27.199788,68.78602,101.015628,134.307203,160.096412,145.877248,102.629612,64.148707,102.376237,211.055454,191.958996,150.396314,79.6712,57.216115,64.516983,84.314508,131.556478,161.205628,150.46597,52.509356,19.273779,4.539549,0.446578,-44.059292,-33.10162,109.708385,144.134959,86.62704,-9.686564,1.403224,90.718039,114.585623,127.79745,149.258527,170.193035,54.182397,-31.962318,-97.22841,-50.374608,87.167757,121.426531,96.793228,59.36366,46.242525,-52.306674,-109.953136,-85.705859,-28.346254,43.197797,54.647385:30.286788,36.49104,-33.504098,-157.63155,-172.931208,-147.411355,-99.350139,14.55447,7.544521,-36.743352,-105.282259,-95.777311,17.394328,91.808595,191.368637,194.560001,97.036631,-72.119084,-148.679988,-181.671952,-124.63353,3.771959,30.999063,51.19915,66.674214,58.668202,42.424504,55.609138,89.567638,95.680796,71.340581,32.146599,-55.037474,-110.97002,-139.443683,-127.137504,-57.526164,112.730964,151.296537,56.679713,-108.593495,-139.112121,-138.58653,-130.540699,-74.331442,-17.866738,97.459203,113.667352,39.094419,-108.574378,-178.880076,-237.620338,-219.188167,-122.127163,-70.486206,-63.323152,-179.64029,-227.682137,-277.820452,-281.659147,-178.75293,-84.551142,36.394356,32.547105,-74.987748,-264.152127,-347.37217,-377.819201,-322.605234,-182.236982,-137.207378,-134.546049,-217.369209,-243.622968,-231.61692,-205.536683,-112.419089,-59.190454,-30.254209,-46.502161,-65.087453,-104.533909,-121.673476,-22.171157,97.817689,314.166992,366.808577,387.981784,330.285644,258.904226,80.752748,46.798981,92.015558,97.909227,65.947362,54.574978,-13.695905,-140.548296,-177.587721,-139.497945,-71.380249,104.596258,179.175697,207.684597,15.614052,-112.399875,-251.978355,-246.13375,-157.767616,-114.265376,-58.371643,-41.008829,-56.651154,-164.931126,-230.379096,-225.815349,-143.809838,-1.829866,28.878469,75.436918,101.370718,85.086957,9.061573,-17.680129,-0.40344,25.378594,25.358784,-8.544099,-79.10963,-119.043101,-147.615078,-193.902771,-185.386779,-123.556675,-96.766178,-81.521251,-103.161467,-132.669226,-246.597739,-278.374999,-211.453427,-152.27322,-41.421618,11.025683,41.426349,-66.303248,-106.81354,-16.985656,87.138342,253.644623,310.217118,403.271976,383.707172,332.803245,249.417294,230.280361,207.043305,205.535011,259.140301,275.044855,156.181856,-18.788815,-57.773457,-43.952393,-6.725501,79.414391,110.631131,122.794381,49.80581,-11.936212,-147.225688,-186.695885,-158.862844,-114.552453,-27.277215,8.016915,33.779737,0.657651,-10.308681,34.61499,95.561964,226.100128,244.173913,140.424329,-18.038777,-78.168262,-143.578129,-130.691779,-41.292978,3.597681,75.920524,94.91495,50.5271,-83.415292,-137.267489,-117.772657,-60.734235,53.429361,101.470562,153.011789,98.644223,40.25794,-81.241995,-99.071269,0.705913,73.162242,109.803352,56.631233,-94.648174,-245.51755,-339.393126,-454.35001,-407.764893,-168.170924,-70.916684,-46.132397,-121.55131,-133.839568,-132.823257,-138.198386,-121.173352,-86.399757,4.06918,40.022813,71.914269,31.74716,-26.047121,-140.760809,-136.119307,15.352231,96.317599,132.836093,49.618402,15.183238,-41.026206,-61.889706,-5.530151,72.713456,231.979741,266.100736,207.598837,124.172567,113.546624,134.619108,140.673784,102.282354,69.072063,-9.054954,-76.697952,-92.120931,-78.501888,-27.970269,140.190475,200.396327,185.85062,113.478116,-89.625989,-184.05734,-173.429094,-115.804369,-84.183882,-28.433823,17.338734,138.320943,123.298671,57.081649,-74.657609,-99.098923,-21.005918,45.785596,115.966131,117.674073,89.615628,2.969299,-52.156835,-85.312428,-51.713992,72.348328,134.356673,152.581483,67.290394,33.87531,-32.177488,-37.983664,104.59904,209.922014,289.464966,241.563144,121.564668,15.219971,-75.135762,-187.193506,-166.168385,-41.619313,26.925343,59.950715,-51.752781,-104.012035,-131.390321,-93.330421,55.484456,131.962154,196.580092,155.426708,6.842727,-45.562376,-56.965547,-54.805251,-6.217548,96.812043,105.770711,105.236602,146.926101,135.585534,25.011538,-25.89694,-99.728453,-137.723074,-102.638587,-22.569069,55.08146,-34.650806,-86.031269,-100.200019,-55.876083,70.018012,124.228851,174.750248,140.839377,89.399266,-58.158415,-120.188821,-157.003987,-121.173835,11.574328,55.774195,43.878299,-34.871008,-58.351102,-12.164974,32.639737,80.354594,111.627078,217.061862,248.876803,227.411307,129.882547,85.432851,85.436325,113.833673,150.883751,141.416884,101.473835,114.221288,104.695636,8.841995,-32.631715,3.982252,82.585825,214.315335,163.868752,101.310654,-4.268764,-31.667706,-7.178759,40.273679,141.850426,160.795354,113.905581,51.162802,19.842929,-13.17664,9.65008,85.261958,121.201535,183.726933,116.567203,37.74319,-69.747938,-56.556937,81.060348,155.706026,254.336911,274.839,242.331897,134.800269,59.327178,-36.433153,-10.147152,136.404445,191.654066,165.769806,59.602146,27.094459,-60.66867,-103.649269,-75.753466,-17.432266,99.921539,140.453699:-34.92626,-35.377735,-74.406511,-174.88149,-194.997648,-136.451139,-61.129042,76.46423,35.348768,-26.194316,-111.531279,-99.532377,23.047698,68.549132,50.199702,19.844768,1.46185,39.524871,46.414737,50.006611,73.276384,87.034546,54.377055,38.509117,149.342351,208.722598,242.472139,228.167762,257.289477,288.99408,260.576588,201.62934,106.197525,93.234169,98.392104,123.948685,144.363269,161.329219,141.95738,35.524131,-66.719107,-79.556218,-43.310585,6.433773,141.622325,175.162408,155.852116,134.662656,69.088497,-4.910721,-49.826942,-169.173802,-196.832544,-144.214951,-111.160589,-100.247198,-122.966503,-144.911257,-212.744564,-220.02077,-142.146016,-101.347212,-70.167027,-70.845075,-114.183941,-175.049575,-209.133518,-247.393296,-217.697675,-115.085139,-91.861519,-112.838267,-116.017127,-92.966988,-26.16395,12.8721,71.551532,80.373691,102.349836,131.414936,178.907805,135.064137,106.084271,149.339879,226.518267,404.609057,478.421301,565.819346,564.026166,536.563328,397.415522,298.313992,164.567674,137.580477,88.897709,61.777947,27.424345,36.540593,63.074199,150.689884,196.459462,231.38127,225.267993,218.034119,257.682701,293.391671,247.107131,135.718174,-112.31837,-199.401366,-256.588506,-201.48554,-21.211998,-31.486946,-104.155099,-158.426028,-97.207451,100.50921,194.584894,347.261396,337.664838,244.763501,2.897126,-62.21705,0.239934,53.173325,17.452927,-44.685242,-97.000136,-30.000929,-10.339906,-50.022346,-83.27273,-161.751283,-195.273361,-153.64305,-71.343019,-78.296435,-148.991577,-174.480387,-145.390543,-95.930506,17.479927,70.354105,130.78272,140.767379,160.600102,270.142778,357.294472,499.646309,540.047359,630.76153,648.046645,591.817427,419.934521,342.499643,232.899842,206.40567,236.174928,249.073645,127.063215,4.761968,19.16349,98.730071,117.668246,70.486332,32.26839,45.160502,129.107575,133.975815,29.320384,-25.671388,-11.474789,36.667099,118.469926,147.18666,156.48294,87.483362,40.763223,-7.183717,27.793369,145.721587,169.803821,160.410958,95.72047,34.415371,-139.48085,-239.434747,-349.969598,-329.627781,-221.061558,-180.362839,-150.318226,-133.031514,-127.46045,-150.806138,-177.315904,-209.848412,-183.208495,-59.442756,13.827024,13.417871,-77.172086,-137.030893,-114.322028,-37.576108,25.532368,-36.315327,-198.281158,-226.067006,-232.710643,-291.684653,-291.756374,-152.293059,-50.028175,78.976066,86.499087,58.775382,-57.521365,-102.09855,-56.134509,-4.915824,51.638532,79.33773,167.623458,212.610299,191.598534,132.850241,135.965833,143.306151,121.181379,104.720313,139.338182,128.769593,31.83108,-1.51198,34.908363,68.934878,144.773054,195.740682,271.539302,266.840277,211.563072,1.665772,-97.857227,-172.704946,-133.988583,-10.052085,-54.730044,-122.192874,-152.00257,-72.956171,156.63995,210.681813,141.625661,67.443077,-82.568678,-192.551461,-243.058734,-353.050924,-371.687744,-238.155297,-109.871921,16.941255,-90.755608,-98.673585,-6.004699,-5.103207,-98.668236,-128.663327,-152.273467,-175.275216,-205.285598,-105.398744,-56.116848,-148.17659,-263.550367,-313.294609,-188.323956,117.521262,161.802506,95.555942,-51.611259,-70.9933,93.55904,219.274916,325.098953,298.96385,194.069995,120.808226,80.468005,-70.956352,-150.402934,-221.295543,-200.913076,-130.873684,-191.604437,-240.264649,-216.516456,-143.112231,-12.873557,-3.59489,-49.663957,-64.153837,-100.533327,-164.513608,-182.686883,-159.667098,-126.753441,-86.337207,-55.377901,108.537544,164.903613,92.848259,-59.515377,-66.986544,-18.054528,-42.866101,-177.660275,-209.856131,-182.682943,-201.378328,-243.646066,-300.424506,-282.91544,-182.607598,-126.596625,-45.910265,-50.307726,-91.778001,-244.372131,-345.040839,-478.662667,-444.629721,-191.619083,-77.096922,-44.783036,-82.390522,-57.281268,-4.966944,-24.106986,-53.059728,27.408878,303.301201,292.224672,162.297218,-81.49089,-111.992426,1.993136,73.998965,185.22984,230.297594,224.677628,173.267061,179.727866,159.780707,135.83837,189.890041,245.251268,237.793881,141.961095,132.990835,127.20039,93.461972,60.003091,96.847947,188.697026,198.918991,193.972781,229.38152,221.123409,117.89164,83.8052,144.281048,196.951999,209.358655,64.613867,1.609054,-20.604874,4.276448,106.999727,163.043301,203.824613,184.182984,69.136619,-109.14331,-187.610304,-253.394189,-226.509595,-112.068542,-65.746021,-40.058681,-39.591824,-26.031393,-29.692058,-62.411377,-83.768138,-39.368273,97.669485,143.630583:57.042662,27.212987,-61.215187,-225.233711,-232.617848,-136.564674,-76.66571,-24.997304,-95.081327,-139.517378,-179.535797,-152.831104,4.934025,91.814803,182.267559,180.795931,70.870654,-116.119544,-178.657016,-146.971734,-50.363412,143.972322,166.062094,99.638133,88.266253,110.557787,93.929424,64.837414,74.749519,98.281491,87.640597,50.066309,-48.2951,-107.009948,-110.759135,-32.142019,40.639616,135.686482,147.748733,143.008843,65.35092,-21.424565,-190.745889,-198.10228,-42.271447,43.105456,79.552891,46.798345,-30.220749,-142.873753,-236.343022,-373.427908,-353.470746,-177.315216,-88.18639,-47.299826,-163.559016,-226.253708,-313.948555,-301.826314,-146.761382,-72.711381,3.75986,22.276295,-68.271226,-309.147733,-398.578324,-401.809425,-322.289184,-141.18267,-101.836415,-126.405021,-134.458595,-129.646548,-150.593282,-140.902732,-35.60719,26.596188,116.693921,133.116699,80.857593,2.418076,-11.340872,67.669708,176.483082,425.85112,509.443174,572.699817,514.598003,428.707683,198.311275,130.456384,151.837604,175.872346,166.148135,148.900195,93.251805,1.791207,-28.141935,21.983299,93.047554,212.072844,234.139613,218.137263,159.19971,115.156224,-17.356882,-79.055332,-131.548858,-132.310246,-78.497479,-29.431453,11.277669,-86.784336,-136.881219,-80.013648,14.778909,178.787587,225.698618,271.443985,238.781778,184.204007,49.775426,16.126482,31.801051,45.283111,37.36699,13.971642,-53.511679,-101.309626,-117.262317,-151.615812,-151.182582,-104.630028,-71.744257,-31.977063,-91.474941,-141.756454,-210.274099,-204.200012,-114.837496,-57.192533,33.927926,51.608881,15.476497,-45.131865,-37.266981,68.185718,143.589384,307.758589,388.771997,487.690334,418.924458,342.663445,211.357121,175.506207,146.322214,156.844353,280.101993,332.804251,218.922855,-15.423229,-82.295565,-93.502818,-61.702291,24.473401,57.562085,54.841818,-0.811498,-18.176471,-71.55679,-111.008568,-88.902093,-25.514176,54.570243,52.181882,39.441238,48.706369,35.469211,31.548538,74.354075,195.929282,244.505061,294.402433,177.563582,46.142873,-193.471182,-232.337996,-133.365392,-45.676832,67.102633,70.082976,9.441701,-58.630746,-78.622026,-58.957498,-33.676978,-23.035467,-20.059436,33.955828,41.986135,-5.912805,-131.587486,-158.304638,-102.261998,-31.18637,127.243036,147.792815,-33.59302,-279.936551,-335.31886,-316.1409,-250.779966,-56.893064,26.653962,74.623906,-2.589597,-54.538967,-172.993256,-215.381172,-162.593887,-77.584227,78.429233,124.956547,181.845901,135.074025,64.095906,-31.085514,-19.951984,50.655976,77.972819,102.701994,111.828544,118.976053,76.815732,31.32803,29.026553,91.829485,251.878364,290.570309,221.934669,79.508045,25.058886,-10.435094,3.93933,53.224939,76.109904,49.606274,-120.532248,-218.087288,-319.620284,-290.54428,-82.409904,42.647925,163.77148,122.390009,-70.031027,-173.908014,-192.929243,-213.764576,-190.823928,-30.00197,73.752733,138.647518,31.642523,-9.070428,-54.774347,-68.568099,-53.456663,-33.198312,12.930578,27.522468,-20.912737,-113.485278,-137.135628,-140.764282,-118.690487,1.161513,84.475993,169.668708,74.844975,-3.541288,-84.998422,-32.572387,207.738972,303.221227,341.204945,308.920486,175.696692,-8.528556,-87.430784,-172.704512,-175.94589,-138.533535,-96.945576,10.628219,-36.002458,-142.778037,-304.952501,-269.363126,-13.728213,98.971887,144.298443,108.953126,15.369458,-67.505986,-102.475362,-143.21376,-124.355072,-14.781535,60.152136,232.833368,296.125225,233.858676,1.154063,-89.500649,-130.041025,-121.998188,-126.992903,-122.618659,-103.236635,-164.618576,-223.477232,-260.838191,-213.871799,-71.620364,-3.112768,58.411729,-48.106739,-107.604939,-164.60215,-195.973675,-259.658756,-244.210123,-72.68,23.880784,54.593415,-66.106281,-122.02067,-150.0848,-126.32135,-34.189232,54.074507,227.052027,172.81748,90.969288,-16.016695,-12.365858,65.350573,99.63422,135.311897,133.755981,81.626493,59.781104,62.426742,7.669575,-26.204093,39.672897,129.61454,249.806048,171.240734,90.328668,-42.5689,-68.683055,-31.624785,25.55425,199.56886,272.786137,261.312853,104.002822,18.893196,-73.687649,-48.053264,72.307062,121.862982,162.75654,119.551705,92.058811,24.578936,-13.065466,16.40879,111.358401,331.73207,362.742481,218.630998,15.927575,-51.795532,-89.945175,-64.316574,15.818617,45.709374,74.459181,41.614859,-2.465141,-84.150235,-85.215235,-8.792112,30.908929,114.220276,150.125476:-51.301529,51.944222,43.387115,-109.154501,-151.72792,-93.376554,-46.820269,-23.176447,-119.790933,-162.61661,-175.25255,-154.855364,-57.325965,3.105945,112.278152,143.484617,115.823196,97.366144,127.224803,191.18296,208.948045,217.245242,211.172946,242.91853,341.367598,373.208465,343.521193,310.145767,256.300454,217.001316,151.574089,154.868313,211.765475,303.991204,327.85751,281.114237,245.422929,202.589423,190.510565,147.245752,40.735379,0.241867,43.681851,128.282552,293.738439,331.485009,378.456276,395.966529,338.775785,246.906898,219.647654,146.749498,120.607143,152.360886,185.87765,219.545088,156.936938,110.039256,90.830227,105.306312,74.481913,43.901728,76.637153,109.784495,46.580303,-49.26651,-47.319952,-37.264456,-56.756507,-90.154413,-73.091871,33.403479,121.659481,120.174675,61.439741,55.164878,123.779712,150.579643,136.174191,127.138778,146.498491,183.139393,181.9845,198.013347,259.808736,403.052434,436.866526,461.791101,469.017744,468.953304,412.461893,353.73064,286.881212,283.579118,250.987347,201.348923,56.624959,-14.520256,-14.485335,-3.487079,9.673446,42.639226,54.115465,84.334745,168.017027,230.454974,221.417445,96.741483,-201.193914,-272.893925,-239.266831,-171.782897,-28.600061,12.274482,-19.397533,-92.153503,-85.24384,38.564276,136.120122,302.315853,277.925282,195.188723,-13.549667,-88.662645,-103.474115,-70.411419,-32.66555,-47.748348,-65.872965,63.014294,112.474094,35.81651,-34.930392,-94.711982,-74.071987,19.565982,36.161869,18.883766,26.385289,56.684109,149.296358,203.158913,310.901423,356.065546,360.922167,305.44938,315.466902,416.647341,476.22512,539.563752,548.972905,604.392761,632.33384,587.726443,436.216352,355.303335,206.777358,157.227231,116.844258,101.564872,35.662679,-76.891462,-133.575259,-171.588906,-130.645925,-23.136684,-3.724367,15.224825,85.519487,115.914204,97.441989,81.304182,152.074608,211.625693,260.014626,257.088826,236.700318,157.405888,113.835805,114.443579,156.803298,224.82769,230.013389,211.438797,144.947704,83.499071,-107.83211,-210.474922,-314.645763,-310.900511,-242.591887,-185.817704,-49.300664,34.576157,16.560659,-84.593876,-107.105615,-96.248843,-94.519728,-57.521103,60.340712,92.306696,-38.64916,-154.043183,-211.499724,-139.853369,-5.241535,-4.884448,-90.22767,-122.428888,-135.305946,-184.014864,-175.961664,-72.477499,-1.475888,95.603345,27.602126,-32.986334,-92.588111,-78.6269,9.307109,38.969522,36.047556,41.190046,102.15401,117.712434,86.79102,32.447241,41.62634,83.647092,86.022534,82.892074,84.229201,66.789305,-21.352991,-72.088786,-75.985424,-19.814532,84.861781,113.122859,138.147303,60.160986,-11.740505,-163.262549,-217.711472,-246.919433,-229.071395,-165.053196,-132.469725,-143.030473,-216.254798,-242.389828,-134.213885,-49.601721,-26.112535,-58.971231,-89.420344,-139.232445,-217.19572,-399.562451,-422.298774,-314.958149,-249.810537,-221.050255,-252.797776,-218.832416,-142.532479,-159.501219,-219.042546,-237.546261,-298.162048,-316.983809,-297.973817,-263.347794,-236.937094,-202.524507,-206.974661,-187.620582,-128.947284,38.819105,51.495866,-11.402627,-100.520026,-90.000109,31.967752,110.906588,210.404592,220.360346,148.31891,26.81186,-30.268579,-157.043585,-202.809819,-146.954879,-49.155645,80.103908,-79.424381,-190.996127,-268.698051,-241.536912,-193.673781,-207.520563,-270.125238,-297.484666,-298.218652,-205.35637,-182.689654,-222.914858,-226.628996,-115.88571,-24.872603,107.958318,76.25529,27.61157,-40.532004,-40.77787,24.03441,27.960946,-99.717231,-156.412861,-168.308559,-192.07665,-203.833508,-151.766245,-99.471568,-19.320338,-10.56514,-38.631244,-49.483878,-49.977271,-92.069026,-140.236416,-227.528391,-234.144484,-158.631682,-102.639693,-33.474783,15.27883,42.418827,55.542113,55.941888,105.135598,149.459071,218.155843,212.422133,166.284446,17.688744,-16.519169,68.629918,136.185232,267.873425,330.871488,340.896296,251.604314,231.963063,244.15854,274.936649,348.376708,351.118235,296.332764,252.06455,235.095104,186.553013,151.372731,107.066017,108.515975,164.425581,226.059982,345.461088,396.716877,394.983387,344.443271,339.436592,395.970904,392.830778,298.049376,273.628727,283.457874,227.096514,174.726042,146.146139,180.207337,250.558431,232.789854,43.394781,-173.2009,-242.139691,-306.420662,-280.52209,-180.144237,-161.432679,-123.133481,-33.182468,-16.268435,-57.134256,-85.477597,-79.259504,-40.362653,61.396092,95.336063:-90.39093,45.712869,74.984207,-27.805625,-81.802965,-32.634751,52.672831,162.58286,88.764415,32.308671,-79.454106,-96.566422,53.175383,162.555689,290.850817,299.724233,237.422005,220.877479,240.839644,252.762901,244.483537,187.405165,164.913913,221.545141,288.216457,296.720137,280.025747,256.063913,214.078155,195.97876,160.058942,151.259302,177.41162,274.598798,306.550068,239.989712,168.966928,81.827744,75.346778,74.008753,69.882322,94.220077,187.580814,226.632405,261.320587,263.593558,264.313503,263.760938,243.005806,231.219236,221.799336,163.5033,134.596131,117.258907,133.39329,169.692255,147.997458,145.518415,184.079764,208.294256,221.681229,208.886572,190.951356,184.081774,144.416497,120.973519,106.433839,48.442435,33.490693,44.169224,47.863218,47.311224,58.443711,54.45938,15.068538,18.658204,125.270314,173.991009,149.716095,115.290896,158.130464,269.174125,283.234143,290.564776,300.083292,247.469942,206.484456,242.245034,374.00971,392.741883,270.037358,168.264201,7.3172,-49.983199,-112.751421,-100.145316,-35.609484,9.87341,14.888494,51.387065,107.538194,210.510902,218.953548,194.832487,264.486168,328.630866,296.613016,159.723194,-156.340347,-251.319225,-269.667502,-205.058524,-54.149513,-31.28273,-59.652522,-115.378285,-123.513493,-59.395503,32.887427,289.516448,385.038777,316.837512,43.797233,-71.759741,-116.273206,-86.928626,-49.88761,-33.609158,-3.938307,14.488181,15.11832,-33.693948,-71.58669,-121.193015,-98.008198,34.817788,62.618815,39.002175,7.164678,-12.795105,-30.38875,-2.670031,119.431117,194.362157,271.365945,258.533578,279.703864,406.544718,475.527817,550.978177,574.20781,632.605146,606.70023,550.313905,429.550512,392.798591,359.842442,325.024802,227.947075,196.913625,127.862342,32.385376,-6.177064,-65.779397,-81.040559,-58.034063,-17.344421,89.814051,113.235652,90.456819,38.88569,40.957771,140.69003,191.763902,199.700608,184.52586,176.412718,200.684712,219.696682,213.33611,183.087756,165.124759,201.920095,252.456651,103.785181,-9.23069,-192.267948,-259.155508,-365.638673,-407.824921,-426.021921,-378.002431,-201.73629,-135.586644,-191.383357,-272.039992,-209.722527,-6.122745,34.709142,-23.966119,-92.895463,-92.783885,-109.615573,-163.524726,-257.125366,-255.097909,-202.478924,-177.634383,-160.58865,-163.236731,-182.873872,-280.897375,-311.952812,-195.577827,-64.967152,119.631899,146.687111,155.693696,124.706391,82.41779,42.305193,54.023451,155.615754,244.250676,355.972659,255.699745,176.680413,85.873433,87.636973,147.084386,168.529264,168.36343,191.713147,214.619158,140.274405,49.950595,-14.546899,29.186285,130.138559,159.295957,176.983404,132.406659,72.507874,-85.190364,-151.689194,-208.067136,-165.569917,29.783646,81.167109,50.469118,56.196748,83.666151,102.30642,92.214106,44.536989,-0.520341,-80.090849,-90.85833,-143.11555,-338.37959,-375.582347,-267.237305,-195.538358,-157.22463,-184.948952,-153.827547,-81.002542,-115.288364,-287.402443,-361.337679,-385.961181,-335.836777,-264.88675,-327.660135,-344.513095,-314.09909,-303.916655,-277.712016,-221.003669,-36.818713,46.250527,14.845615,-132.617879,-175.77328,-52.637182,61.522532,188.259988,194.625184,156.204178,105.085021,48.597663,-140.427796,-203.017093,-148.717463,-53.041677,99.738766,-11.492984,-110.323666,-192.102311,-177.717074,-129.52871,-119.944611,-153.341767,-182.124828,-229.472974,-217.582187,-209.776236,-295.444272,-341.985174,-287.540789,-199.641034,-27.76718,45.76862,59.898225,54.716485,35.511142,37.506235,45.836242,-38.936742,-122.862184,-257.904924,-299.982509,-311.152289,-340.85414,-328.935573,-232.084654,-176.388593,-120.651751,-127.716602,-128.651953,-178.305091,-254.626762,-395.079248,-385.360746,-242.18853,-193.490992,-158.84296,-29.133959,33.869413,19.229386,-38.358491,-138.476861,-120.370509,61.604353,87.120775,-4.161417,-181.458367,-200.358995,-104.308339,-35.284093,89.270084,148.572805,216.54066,210.915224,213.388007,228.520811,228.229263,208.932704,184.813754,108.905225,64.272962,75.388119,125.254645,128.895226,103.901219,104.129857,172.586449,217.281185,240.887373,223.765788,199.119746,83.493911,26.584247,28.707562,83.095154,168.852318,132.254392,108.557434,91.538271,75.070823,7.667684,-17.542384,-1.669767,-3.378041,-157.856442,-340.76097,-365.481335,-352.111038,-329.507581,-238.416276,-181.563057,-31.123337,101.322878,116.424771,95.104162,80.444268,58.748331,73.307957,184.957747,244.528696:66.421711,37.02312,6.561612,-87.067907,-115.392927,-72.56151,-29.242863,-35.120335,-132.333997,-159.576713,-166.989768,-125.652531,44.178604,101.232555,131.983539,152.56018,145.006331,40.590299,21.116266,112.15378,180.520321,205.969022,174.092903,168.838594,227.375017,249.848126,249.212648,209.265507,126.93254,129.159207,193.605447,214.53629,194.380247,204.022039,217.086091,189.546248,180.224573,210.629476,225.922717,200.322448,68.464681,-11.084068,-98.280531,-94.693687,11.933864,100.755763,249.402501,266.827899,166.68256,31.368017,-32.883545,-179.495261,-207.964615,-124.303791,-54.591851,48.040418,1.111322,-52.763925,-110.026756,-113.130207,-68.234177,-29.333653,33.382431,42.055967,-58.085641,-162.853014,-145.717653,-103.541573,-109.823337,-128.781937,-119.634924,-34.393123,42.664275,43.425805,19.10072,12.509101,23.531404,36.219632,54.090398,62.462726,75.430696,69.057702,65.588399,130.116655,208.329479,402.923556,491.93637,584.248093,570.66289,555.481491,457.363365,377.662979,297.077462,285.199291,200.00234,135.976152,46.816708,52.51105,66.32781,86.892527,121.055413,196.625444,202.770448,216.740696,223.640163,191.711161,73.095797,2.904738,-121.498347,-174.012562,-238.049784,-235.108658,-147.391399,-4.595544,23.495753,-28.844998,-38.202871,74.810847,169.615155,320.972233,330.198735,281.188585,75.761556,-39.46342,-93.746832,-32.18971,50.241011,24.114761,-47.799689,28.86424,80.739033,30.232429,-61.954328,-182.47799,-147.254158,-11.531392,-77.308657,-130.275514,-87.367157,-24.40906,58.784402,80.161842,111.363727,122.760863,170.106868,289.131167,334.213627,310.803775,284.219741,367.845585,473.257248,602.083928,485.162776,423.342813,367.711467,320.157858,234.083062,236.210636,260.204625,250.066753,182.776034,33.671878,-58.893683,-131.411259,-83.797302,22.003225,28.242274,22.688601,60.49855,84.319225,115.894741,107.454588,91.018089,110.294499,134.539827,110.30424,52.385815,70.784408,91.184287,114.477448,131.169565,176.745761,190.659278,200.219044,135.961582,70.140868,-57.249198,-91.719818,-105.151545,-112.063085,-93.958338,-41.020449,75.843918,145.307902,157.06839,66.074726,-12.427386,-102.565952,-86.201651,63.22116,169.539776,144.315191,-10.940985,-82.349834,-69.054932,-3.491198,25.935724,-41.18523,-166.686845,-131.691832,-111.952744,-110.239218,-75.140867,14.704223,33.528453,74.479879,65.800386,17.039998,-91.159571,-107.539538,-85.242715,-87.31328,-44.025792,29.845724,154.349382,150.308465,113.72602,15.659649,-23.748742,-22.940195,14.090522,62.727605,45.046771,37.003263,-15.678998,-57.697816,-40.922054,22.25413,152.806757,186.934055,150.730805,74.231646,35.006184,-143.220569,-256.057504,-325.460789,-261.973806,-100.771744,-114.079546,-166.944766,-244.821028,-251.983943,-169.212137,-98.481786,-32.238938,-61.378917,-210.904692,-336.800546,-335.068006,-255.69861,-216.502475,-173.039171,-162.809609,-146.626344,-169.250335,-186.424471,-178.180663,-157.665512,-96.243571,-77.480586,-134.534607,-177.487315,-196.889283,-171.186046,-164.938146,-178.516219,-182.507061,-95.688202,-15.524542,76.020903,16.387771,-44.297379,-106.377695,-55.772518,176.457473,273.827226,306.168145,270.142605,171.228318,47.83555,-32.36745,-176.13363,-198.270502,-161.284148,-132.602988,-140.790557,-292.611558,-361.477874,-352.807971,-288.278878,-119.484071,-57.95748,-83.668721,-154.663647,-269.952699,-224.996152,-185.934211,-230.492785,-261.366926,-153.375773,-52.304055,83.543731,116.729534,102.571642,8.254082,-45.169947,-96.807251,-122.165088,-208.189014,-220.731229,-162.652801,-186.410412,-226.450709,-225.680573,-182.249513,-96.253142,-77.993641,-73.46617,-37.703981,-36.560815,-162.104088,-259.817606,-383.007497,-381.890377,-280.319658,-220.374111,-161.0614,-140.891154,-125.068522,-83.607628,-75.568587,-69.095808,-16.22716,191.369956,261.435255,203.824875,42.691101,7.81393,64.034323,93.088819,94.533379,99.47567,110.820127,78.043469,49.331793,31.407144,62.823417,137.399266,138.558528,94.164323,110.292274,134.047329,106.371824,39.950716,-109.774403,-118.22429,63.024585,170.289083,227.131501,203.642037,215.905766,208.89307,183.702193,163.010266,175.940512,224.367736,263.047172,272.202323,231.005763,178.881502,123.86278,158.643487,297.304319,324.577257,201.318946,59.489356,24.846582,-63.416509,-114.002697,-155.402408,-130.711954,-35.682764,8.562684,12.899896,-3.56243,-27.323827,-25.307374,18.629471,85.334639,72.622707:left
177.535454,24.037924,-59.341095,-155.807995,-136.880504,-16.512939,18.107954,-13.579959,-60.833414,-64.438966,-92.130044,-148.100219,-262.51679,-271.044022,-214.498876,-172.581075,-80.096557,4.30025,30.706578,3.703629,-37.6893,-36.353789,34.470179,202.171229,161.527296,55.656554,-181.886392,-294.373057,-445.498305,-436.491157,-287.685478,-205.807802,-109.228074,-110.521275,-149.011839,-236.158585,-220.220115,-83.047747,-30.352288,-4.512964,-105.953172,-203.010334,-368.466778,-402.891706,-372.679692,-336.271546,-284.566344,-275.354401,-295.300619,-300.919412,-283.178946,-269.282644,-267.68786,-213.382643,-167.857943,-100.923809,-119.338835,-127.193321,-108.968721,-117.08377,-163.675455,-181.469047,-202.067187,-199.773879,-186.560097,-206.576763,-232.483027,-268.804797,-255.853955,-176.279487,-110.516892,28.290164,23.904546,-30.510035,-202.265774,-290.925602,-312.722214,-261.432476,-219.191175,-238.916776,-271.997963,-232.972377,-219.611998,-263.099064,-270.386589,-147.960147,-43.790608,135.068971,194.859865,188.417997,113.965205,42.528827,-80.367648,-98.175946,-88.199724,-94.996867,-155.207217,-192.553407,-200.91367,-231.583857,-219.798098,-138.120142,-110.351535,-47.535471,103.15773,165.470098,138.676131,72.200402,6.752206,11.696268,41.469521,81.709152,197.057541,207.536204,146.924288,9.948686,-5.919655,50.642535,75.939306,132.949831,171.121823,134.669084,-4.747693,-64.268517,-94.973691,-74.168047,-16.042137,8.965581,14.812428,-12.141217,9.195822,114.588621,140.938294,79.498298,35.481208,26.099725,87.817467,100.831793,1.442263,-99.634614,-221.997838,-212.628336,-139.572717,-109.614549,-106.533042,-144.899457,-177.432717,-276.957387,-293.664563,-187.280314,-116.047719,-64.517217,-46.466392,-3.140909,63.305054,53.437598,93.278631,158.620444,186.402442,135.576553,4.627914,-129.772817,-184.705408,-205.761219,-144.246891,53.764899,118.035128,127.107381,73.335878,50.492486,-11.543293,-46.257398,-48.881462,-22.735141,21.660055,39.288309,40.004955,-10.16904,-25.11899,-83.159802,-147.748262,-241.047084,-221.143804,-130.428187,-124.698693,-136.148423,-164.20325,-201.889093,-270.866956,-275.574245,-236.915384,-183.939645,-25.905447,42.781144,7.039037,-159.517543,-232.018248,-260.905614,-233.42129,-171.335023,-142.366806,-120.717505,-113.0254,-162.786189,-237.501992,-203.914114,-74.242194,-29.17513,-50.93464,-126.971855,-106.818418,21.624951,73.156418,109.043362,121.632211,156.529367,111.314991,64.77884,-22.270571,-53.322507,-21.725334,32.922729,93.458798,89.133357,83.504981,157.139523,195.149496,115.812561,25.592592,-31.4243,29.243402,179.028853,160.12066,112.41704,20.523873,-28.143259,-33.354244,35.9217,213.118793,297.92495,461.54725,517.143005,480.550309,391.416377,389.854854,392.69533,338.382941,179.732126,87.278885,34.840403,-130.411837,-185.29612,-63.298564,75.127499,241.758214,243.06999,223.227136,249.260625,246.18614,192.957287,184.207223,232.050516,260.383345,275.270829,204.251961,164.423056,120.123383,104.151656,67.535204,35.625849,-22.281705,-14.703094,24.385465,6.356937,1.622112,35.291309,66.344294,120.525865,137.923713,184.883359,206.313573,183.973678,141.921276,144.365154,196.932281,234.861848,235.46108,184.772315,122.683851,210.855424,243.501506,164.322619,99.5041,79.398934,142.865194,327.093379,291.978698,196.062442,104.78713,115.34458,164.210361,216.886252,351.789409,379.389368,285.191694,131.980881,94.361294,93.245268,112.205373,121.901089,93.454844,43.545884,39.954664,17.599081,-68.082961,-83.565199,13.656212,93.777842,229.602943,282.030995,297.409933,210.505553,181.881223,176.057226,196.687828,273.645709,326.467672,436.133251,403.976634,327.17549,162.637501,105.072234,83.847353,111.091237,191.660918,223.312163,178.266158,60.407914,9.627245,-143.724584,-214.543268,-195.675496,-132.772529,-80.099458,-197.46831,-256.72121,-305.191404,-313.171733,-266.020347,-209.999018,-128.573598,-118.068521,-110.344483,-128.534298,-174.104821,-258.018572,-250.834836,-189.163186,-155.623864,-48.049458,63.813857,93.915253,64.664311,9.506636,-8.605466,69.069176,235.450778,251.327784,155.095015,31.541863,-17.689547,-97.529664,-113.313417,-52.725849,20.80366,178.442948,231.072285,207.830518,129.219822,102.010399,111.655694,139.513854,173.922987,163.549995,102.830287,52.850593,1.984435,-173.546562,-211.364776,-70.92282,46.853967,143.77057,-35.302586,-125.201626,-151.58016,-129.973185,-79.129579,-37.003422,62.439065,98.610127:214.728024,81.487716,-20.169126,-232.796931,-295.482505,-251.759153,-180.11435,-109.991259,-158.042511,-164.525444,-175.595262,-240.107023,-396.044536,-394.959744,-238.384025,-158.573074,-104.87641,-136.406436,-152.790526,-195.611324,-216.83455,-155.80193,-54.00681,136.514305,95.500794,19.427094,-138.451667,-224.276728,-360.206593,-358.400618,-222.865301,-163.503813,-141.117643,-118.283486,-118.786794,-204.707145,-234.900464,-138.313036,-45.341919,26.247867,-134.256855,-227.045874,-342.853157,-371.886636,-363.642923,-354.317988,-333.482634,-294.0242,-215.741448,-210.322399,-215.591024,-194.363676,-188.287898,-229.394794,-226.132914,-132.093561,-125.026223,-150.368891,-187.635687,-217.055385,-281.093314,-291.517309,-250.985365,-219.182769,-187.17052,-218.731611,-280.150625,-407.727906,-409.314606,-301.377496,-223.855564,-56.96732,-19.365448,-79.821922,-273.075029,-343.78804,-284.539242,-171.265036,-7.86621,-30.856275,-209.668802,-230.805157,-175.491613,-108.205375,-87.273481,34.933235,138.127832,311.52325,231.947899,138.060251,54.513484,42.171759,-30.822742,-60.697382,-59.402237,-56.895863,-96.967469,-160.745808,-188.872185,-257.014038,-272.264236,-216.918821,-169.588165,-49.186521,108.346071,148.742628,96.574293,43.056718,-15.397884,-7.558483,92.444751,151.726444,154.047311,33.906847,-24.19167,-61.777901,-28.862318,69.742095,100.092631,129.717112,133.19338,111.633371,29.647928,-19.554263,-105.82726,-116.498195,-42.024383,-7.479274,-59.122193,-134.593989,-132.876369,-79.509939,-35.753471,43.219613,49.046454,4.832456,-5.301419,-8.889644,-119.41866,-194.853365,-205.604548,-155.477691,-104.84605,-107.210221,-116.32517,-199.185896,-274.828315,-379.074245,-369.654679,-241.065931,-145.099789,-7.431848,-31.105076,-51.978226,-37.396775,-13.015302,77.807035,108.557628,46.419963,13.569741,14.612403,-37.266713,-104.376792,-220.11674,-204.030376,-68.330983,-12.823744,29.227982,1.124579,-27.97514,-102.172009,-122.189256,-83.334139,-32.08129,66.284053,68.460207,-49.665524,-158.882543,-152.525757,-70.571556,-57.828209,-133.19799,-162.438104,-134.976339,-149.668353,-205.665395,-325.294933,-345.42287,-303.553594,-275.010719,-216.680715,-178.122815,-111.560477,-134.48931,-196.616791,-342.368871,-370.950563,-326.652377,-288.144306,-215.054876,-168.989194,-151.498854,-116.674031,-117.422072,-122.125783,-83.846439,34.515621,60.052604,18.782071,-15.58893,-3.087516,40.378404,68.622189,151.806143,179.149621,144.369942,39.167781,-14.150104,-107.380018,-138.448464,-115.526256,-50.484846,116.188562,166.022186,162.469511,106.53413,59.373314,-51.807444,-59.354341,49.602986,93.409774,69.016324,35.810474,29.359419,-23.928662,-49.361274,0.411061,61.402173,189.989202,253.126509,319.610176,308.398995,302.786687,317.953207,335.27714,313.666145,272.838981,207.232801,149.441823,102.845776,-28.573137,-80.429243,0.622222,119.733422,271.931212,253.493141,126.609087,59.403087,54.447397,37.17068,27.724455,84.127579,177.611214,401.044768,393.982358,301.351749,108.461656,57.499052,91.241539,151.339038,245.001168,250.011863,183.984839,134.827801,131.264001,100.484925,92.725131,196.344613,276.586701,316.85663,241.200195,221.052772,222.439589,243.843396,347.732179,402.32541,407.456911,344.705012,190.835696,192.875289,200.685352,97.263474,70.962032,216.47868,312.793971,325.22231,175.498022,133.667228,127.104185,147.881372,277.830216,368.089999,503.126141,536.454858,504.676361,330.361917,265.466221,284.159617,316.618321,300.965887,262.861485,218.504529,200.519626,173.835701,110.303465,92.050418,99.773768,130.38464,255.627517,311.708148,306.593637,264.461862,238.474942,162.758806,175.211438,296.288346,341.163747,357.016764,249.534616,171.753088,72.122384,48.243183,47.896501,69.885695,120.725445,146.86678,207.704259,248.707654,199.317356,-76.319362,-200.659607,-167.58826,-59.46208,18.236297,-132.465019,-194.190464,-245.33774,-244.028045,-125.452721,-40.547864,40.145868,48.213255,32.533013,-58.765985,-117.311474,-150.026001,-101.341869,4.308129,19.83724,9.488348,17.787565,34.612371,46.680375,45.909263,118.116677,190.815952,308.122159,309.808421,194.365023,69.794456,20.42351,-52.979933,-45.616642,70.637088,142.639446,238.703133,279.160141,283.529119,210.99111,147.243925,98.226606,123.304726,169.589538,168.13873,129.554945,58.121017,-8.093066,-208.573404,-269.354606,-157.094797,-39.929231,60.55838,-62.564068,-132.520293,-172.556733,-164.966818,-153.316519,-124.730993,-1.292295,48.955793:-68.521143,-192.132076,-256.266535,-318.005788,-274.188142,-102.190997,-53.729129,-125.719967,-235.443682,-242.03943,-255.415625,-291.430994,-324.20658,-288.038644,-156.634243,-106.532078,-78.292276,-74.37014,-94.849744,-219.020286,-282.238308,-272.001513,-183.205164,13.171706,-18.87678,-90.306507,-198.393455,-236.613676,-256.436054,-205.452075,-41.24416,3.826189,-12.829723,-94.334549,-154.991442,-223.449885,-179.890194,-18.863853,33.692809,24.70041,-91.728715,-136.976127,-219.846227,-265.983744,-251.663205,-201.810029,-129.910567,-117.549529,-105.827749,-65.01406,-68.70493,-144.968228,-158.525929,-52.116922,21.032026,68.044214,11.526314,-29.03444,-133.758177,-180.564243,-198.586019,-162.425029,-50.690762,-20.45126,-55.17189,-162.402309,-225.472079,-264.490202,-214.522353,-71.28734,-16.456568,44.22211,19.921429,-18.48864,-102.097541,-122.090807,-57.128357,6.65803,103.107077,126.081152,98.664784,-29.740719,-108.46761,-152.718777,-96.726274,46.002794,112.282916,262.977352,264.352903,175.375071,-17.43728,-62.300389,-28.02894,5.146288,-9.886726,-41.912848,-78.918311,-112.314035,-148.244865,-231.621478,-256.08877,-241.700554,-194.480614,-53.267977,3.776333,-7.465886,-23.895305,-29.526505,-72.222565,-85.405189,14.768188,98.261783,103.271032,-74.966266,-146.016358,-198.16607,-172.992701,-22.54547,77.890781,217.985174,158.134177,77.416785,-62.896132,-92.347497,-87.147357,-84.642317,-74.247635,-47.289141,-8.105325,-47.893218,-83.337517,-100.419085,-49.267673,121.121056,169.899975,122.788869,45.288349,20.622188,-75.479177,-113.091692,-42.563681,12.29469,15.628503,-9.586018,-32.189324,-72.932433,-136.226776,-283.167798,-298.165585,-179.104986,-111.463253,-60.327209,-14.001256,13.568125,-11.731744,-39.68029,19.878721,77.989731,85.753589,55.853377,19.884154,-48.99428,-116.764671,-220.178966,-212.791089,-141.5795,-130.236248,-169.220543,-211.769098,-215.922125,-229.409879,-241.300218,-190.947103,-115.320486,27.83606,32.301013,-107.761934,-248.694382,-262.515528,-246.469977,-261.917652,-299.02352,-282.386725,-223.217322,-220.628441,-235.015996,-307.33389,-335.580444,-307.147514,-273.598712,-219.093418,-202.284296,-179.998051,-244.214993,-341.966843,-517.431082,-516.706363,-382.24024,-327.253323,-312.015695,-284.44819,-245.805341,-189.849379,-178.115695,-119.592017,-43.119451,153.702918,210.14577,190.343324,167.873422,197.841399,259.917803,258.583314,224.671848,201.81364,81.879987,-72.370585,-105.001539,-102.009461,-101.857298,-96.478797,-60.14836,71.427892,121.965664,146.976432,79.112448,8.700127,-59.920452,-4.074575,164.980416,201.139507,165.732972,105.646009,85.546094,24.638755,-1.666382,61.085234,138.045775,250.321412,260.241543,241.861137,272.912126,286.850072,290.945493,302.633447,294.910892,271.240013,231.233258,115.413643,41.261439,-21.795031,-12.970155,65.017616,138.127211,308.80777,370.3911,350.480534,149.857683,50.074251,12.586212,91.002224,272.262123,308.490378,340.891101,398.349032,391.868319,281.247119,218.454157,197.173875,247.292846,382.891177,411.897353,346.84983,281.692569,289.532314,304.161819,289.152679,275.030642,289.623015,321.926704,319.640639,296.85581,220.27883,208.588723,314.867557,392.731103,455.925347,425.721075,305.389914,218.99057,185.945893,105.03657,88.991917,168.348904,233.241319,294.768484,225.942392,185.907135,140.601766,146.066095,281.216333,389.512434,547.436147,549.669184,362.730789,185.668328,193.437028,318.060867,400.987417,521.460049,498.59367,307.864968,155.91268,122.967971,39.836371,-19.926772,-45.506447,7.318483,160.245492,237.312133,304.798074,192.859308,110.981259,17.874915,27.38784,137.36107,198.135388,226.799683,129.752288,54.701058,-68.012953,-95.214557,-91.343983,-70.951999,18.56488,78.655381,108.259998,22.200321,-15.269193,-116.021412,-187.572821,-242.549284,-192.09532,-74.812093,-136.114521,-208.189355,-301.100866,-286.647964,-150.534228,-84.289373,2.402035,49.138436,119.539468,75.021269,-10.044764,-163.46916,-135.439372,77.431381,153.268813,136.485831,67.972468,69.575644,76.315492,66.794352,135.135813,228.708741,353.38666,314.095911,119.000091,19.129854,1.951143,-36.450329,-27.822808,89.886281,165.539955,237.193643,209.733736,206.552326,173.689377,111.902623,22.362434,50.872726,185.545019,225.274091,169.019979,69.294344,23.388804,-138.815152,-202.249399,-120.359703,-15.276727,67.288059,-71.745782,-147.053192,-211.992093,-210.567462,-194.16281,-171.900965,-39.341517,34.143198:7.602526,-121.713595,-197.61037,-262.445665,-236.061461,-110.714275,-57.346896,-36.452334,-101.017451,-150.465884,-254.338499,-293.972993,-299.191954,-263.671698,-132.412304,-59.900894,-6.959935,-25.654141,-43.720542,-128.173081,-157.078678,-70.387145,23.361921,125.676798,-5.318457,-108.156953,-278.401338,-349.912048,-436.544227,-421.86363,-295.160035,-228.67856,-167.55556,-185.289924,-215.556738,-262.503981,-244.989794,-133.97352,-68.317935,22.822697,-27.398999,-103.399073,-278.3781,-342.498358,-376.570545,-369.939446,-308.007234,-229.841937,-83.091866,-120.235051,-177.518151,-236.691776,-227.408461,-153.826639,-101.275105,11.496245,69.022885,72.062844,48.991783,20.688387,-3.814701,24.165593,105.122272,136.392321,158.156036,70.1093,-5.78499,-80.974845,-40.822276,111.741406,179.038818,289.051077,284.30389,214.064339,28.469429,-44.512571,-39.812864,37.724061,190.139481,202.998377,63.461234,-93.597532,-130.226829,-183.42021,-181.241995,-50.296645,45.814533,203.699175,224.700148,190.044381,123.914608,83.618704,12.064324,18.14013,63.019229,68.165396,46.189971,-21.728094,-81.024406,-222.425696,-258.324325,-227.257664,-188.780627,-77.003972,30.599159,25.246371,-97.595444,-151.427741,-127.09348,-71.796267,30.389613,62.672798,70.06669,14.298224,-27.173551,-104.292335,-120.945644,-96.344,-55.2035,67.324227,133.597994,112.952138,-14.518228,-72.654664,-65.916811,-21.551986,55.457746,77.276973,80.199961,62.529976,61.976065,112.799398,179.212198,299.281063,298.522485,226.292356,194.479924,181.926439,111.865788,79.576067,115.339235,155.073046,169.751271,150.719861,110.927173,87.695983,61.703811,-19.802802,-31.704306,38.950484,73.325441,71.800951,95.793339,135.722677,145.12845,101.562888,106.696999,181.869775,273.50699,258.431818,197.887107,114.531182,69.390278,73.199735,129.591077,218.734147,226.718476,207.021147,143.600298,107.637469,35.916282,10.104362,46.27562,90.061522,114.031262,91.295472,20.010859,-20.756571,-23.839463,-58.004381,-77.483361,-82.222765,-84.007102,-84.082308,-81.988015,-107.275074,-244.684585,-321.201265,-323.216918,-261.576568,-195.662496,-197.098622,-160.77195,-145.778597,-192.834943,-335.575741,-373.768749,-295.551192,-215.375969,-116.741651,-77.139004,-68.195143,-134.99051,-194.95279,-240.196944,-203.191083,-74.32772,-23.43245,-3.784119,1.531015,41.03363,174.175373,238.253341,272.382637,242.371042,164.063389,60.243418,-1.684202,-114.35658,-157.534589,-156.669378,-93.514103,94.556481,153.417353,133.978034,126.403455,140.503163,22.736774,-68.118415,-32.009125,78.169309,208.2609,142.468017,105.027321,56.573549,23.302449,21.39622,77.050307,213.621039,266.747067,319.349386,284.788012,241.800361,193.225166,225.113649,286.458545,258.255612,174.111726,109.482366,57.74973,-46.761346,-75.428866,-26.594995,52.935155,236.238311,295.977929,278.56986,123.31645,49.077286,6.400688,44.307279,146.823244,193.160202,304.586325,293.242514,225.511226,138.531437,132.67062,145.342255,169.701098,239.495594,253.023362,189.633005,123.739801,131.551576,168.423054,176.04132,195.067727,223.81539,313.720872,340.125712,303.148723,209.744158,199.517602,251.915821,276.424194,257.944543,227.74168,179.855761,170.332173,150.902573,-6.815785,-84.428853,-24.001651,76.993013,154.135671,55.214063,54.817674,136.696687,149.877529,158.663629,182.13857,220.390019,216.61208,151.573626,62.683567,31.074783,17.482925,47.802998,112.631753,100.707116,23.023405,-15.000138,-38.015431,-150.96322,-228.22417,-293.238711,-235.520755,-27.153037,47.969654,83.777147,54.479551,36.998147,17.460594,21.34013,44.134765,87.384131,237.585326,213.730873,135.217315,26.83058,4.414051,-8.540912,3.828811,37.328299,42.364462,31.092305,25.202365,-3.440345,-179.704099,-276.902813,-310.492024,-251.380568,-149.757233,-198.250516,-238.428071,-274.64437,-277.448078,-249.40575,-234.384208,-227.357606,-195.005208,-70.044478,-66.454975,-132.678103,-224.897086,-178.180608,5.63732,47.37452,28.969267,46.277156,58.521442,9.76144,-32.264969,-3.248518,80.502012,227.602303,233.819061,156.912892,74.234094,24.488557,-87.476815,-111.924824,-32.746528,54.585557,212.69175,238.403549,229.013129,215.891592,196.707809,168.079216,180.044931,225.666691,244.568979,242.091738,159.421564,98.392834,-45.301972,-91.57525,-38.352159,41.423205,175.052386,137.930214,63.92762,-80.215855,-139.955442,-168.352531,-92.05142,128.439703,177.321176:-108.687413,-105.450505,-135.909608,-234.245568,-240.203717,-129.397484,-63.345898,-25.288287,-129.126915,-198.590955,-295.115697,-319.886009,-312.5949,-275.600089,-147.706227,-85.955843,-50.240439,-86.126936,-124.386086,-252.844471,-294.174237,-184.718824,-54.840008,77.993747,-71.128004,-150.812147,-247.018816,-299.811969,-384.248249,-363.182724,-189.518134,-105.31713,-58.883458,-123.211604,-170.157461,-218.113277,-200.972608,-102.685329,-27.144439,94.25757,34.371971,-46.430349,-220.440904,-270.709053,-254.375251,-228.090547,-168.569,-124.584388,-75.338107,-79.651963,-89.893587,-145.575907,-156.641277,-55.222675,37.997373,154.714829,63.065099,-7.725128,-86.106217,-90.26747,-20.061998,38.545281,136.466679,150.621883,91.385825,-22.80117,-83.95351,-109.179544,-53.90867,71.380418,119.600236,227.794009,227.594534,144.103693,-56.804339,-88.11678,33.688079,119.251658,201.452893,197.381553,123.6114,-22.476719,-125.237528,-278.083147,-252.388944,-23.860108,97.525727,212.934675,157.834445,103.907407,-29.330741,-89.683409,-100.670216,-63.124408,-3.26405,6.101572,-15.908364,-109.493139,-180.922818,-283.162491,-286.883923,-271.029405,-261.799251,-204.91515,-162.428874,-174.826635,-264.179825,-292.14455,-210.689287,-137.447988,-22.185715,29.03922,54.576641,-127.393915,-231.807462,-307.772587,-285.670928,-154.994718,-53.131365,98.262359,43.578647,-23.047645,-117.561364,-137.672759,-140.937163,-113.985135,44.802225,135.255915,155.328593,42.632471,12.06541,31.772821,82.792235,234.887487,295.918523,314.430417,210.754658,153.813043,76.329451,52.978799,71.141846,117.147847,236.091975,274.307545,254.128978,99.66245,-18.033277,-161.071788,-135.096088,3.688718,44.1464,9.573866,-57.369175,-73.84807,-130.11032,-143.103933,-14.553476,94.928683,208.972682,192.971412,103.178239,35.994526,-3.3356,-43.688565,3.566593,112.780314,106.258717,36.770591,39.048912,45.308611,-65.240218,-134.594308,-62.137998,53.67963,193.834683,183.300269,79.364909,-55.5786,-119.516403,-184.14086,-174.962049,-116.597639,-90.158032,-64.46241,-96.987692,-142.224174,-280.415503,-338.508711,-350.152419,-316.055097,-221.789071,-186.822663,-203.114851,-287.106171,-322.235965,-358.405426,-355.500511,-289.517658,-239.088415,-168.399328,-121.013528,-102.05759,-136.568499,-179.669278,-199.22813,-152.904133,-7.301121,51.534742,60.422858,46.080824,93.516097,219.295403,259.151546,289.351431,292.005384,233.349336,90.822623,35.70188,-59.727761,-120.805676,-171.02396,-110.459975,105.125887,177.641636,192.243444,131.262393,81.12571,-46.611093,-61.856462,109.223347,225.054919,300.34341,208.293151,134.468785,-12.661245,-38.022902,61.646769,143.944513,249.317931,271.181082,298.697083,284.855446,241.142566,181.345215,220.892832,326.081561,321.546797,230.597543,93.61195,17.296147,-113.169386,-152.722464,-94.831903,23.842045,301.30442,368.10569,285.383082,68.525091,-19.60813,-37.691718,39.203316,216.778093,273.479714,337.950657,332.645031,289.146417,144.919512,94.428106,139.763141,195.788707,271.314358,302.607511,321.267768,221.407739,167.28996,146.011401,171.912309,217.996135,238.770992,325.197284,375.367675,319.446273,140.586999,113.043658,205.261853,256.149716,248.118935,203.526014,120.36975,62.28145,15.403723,-97.601967,-102.988895,40.580344,120.624561,94.026855,-77.444315,-97.551343,-8.764769,45.461238,140.206563,180.118938,232.974032,235.351172,174.981313,109.407775,77.020403,11.235084,28.752976,170.740693,222.321735,134.924111,-64.765361,-114.950628,-179.368457,-224.860759,-229.493841,-167.370615,0.275598,68.954242,102.031239,17.556117,-40.434975,-102.455292,-66.779034,89.576012,155.585422,176.054149,105.168022,76.941145,25.288741,-2.192237,-4.556252,35.738553,177.384283,243.177516,254.728146,160.067286,101.941973,-48.412309,-115.626675,-117.997354,-50.04748,53.113238,-32.447612,-89.163044,-152.963057,-163.587346,-106.502028,-58.958568,20.730644,59.931488,81.041796,-20.927522,-73.754415,-79.471785,-28.029437,123.654539,194.39545,224.206124,73.501065,-12.666171,-101.182084,-85.961901,55.934259,150.474399,265.223899,248.906147,119.381853,47.843112,37.626513,-0.763552,-9.502344,24.245291,58.692618,144.926882,182.281509,173.688722,103.896479,49.997315,-4.126234,21.379946,132.313669,178.479246,178.433566,57.952844,-43.041077,-246.538417,-261.716975,-64.238822,55.677647,110.856538,-2.113776,-38.655543,-135.953477,-216.186508,-234.47412,-131.873273,101.348838,149.732288:-145.875499,-253.006092,-225.858125,-152.391725,-125.928257,-27.499053,20.951283,49.19543,-30.692581,-98.976844,-208.013148,-228.067263,-179.042647,-133.936198,-55.337024,-16.630026,27.44766,64.934316,107.206506,123.67054,69.672354,-26.440674,-7.376887,100.130483,79.768547,0.09783,-253.71147,-389.477932,-523.095671,-510.161214,-414.958738,-353.597076,-265.03896,-242.85947,-242.930586,-254.518063,-257.252072,-215.674887,-166.406095,-114.176314,-219.71999,-278.786365,-304.871274,-296.854907,-332.768253,-366.312777,-355.780708,-308.327025,-250.869896,-267.821744,-267.497605,-258.560463,-240.654687,-160.143893,-132.431829,-110.029527,-27.282097,43.993525,128.637031,92.381952,-11.65766,-2.279972,84.332284,86.919997,-19.296337,-133.938849,-175.823402,-166.985247,-105.122745,-3.881875,27.738785,176.17112,273.104467,232.24066,43.864927,-41.131699,-67.01091,-48.160972,-85.697365,-108.748073,-123.960461,-225.680982,-298.830488,-404.181383,-424.002,-376.74129,-300.333538,-69.145514,69.774726,42.042785,-116.823295,-161.266027,-113.521851,-82.108963,-72.890862,-66.337217,-75.845744,-128.856292,-136.523792,-174.366867,-199.743372,-193.878596,-169.602287,-98.846911,-47.548838,-57.90303,-153.959561,-194.980498,-137.573131,-71.115075,13.666544,55.685561,159.542515,150.946254,90.77201,-37.443653,-49.178518,-7.922353,-7.432766,28.633342,170.880355,189.363222,84.114494,36.773043,53.801182,91.730517,141.289469,156.841384,202.352766,191.701495,168.082228,204.844399,259.956525,314.419746,307.038915,269.920039,204.29209,177.715111,162.862886,163.965891,171.087125,183.003275,185.743773,162.252144,110.580774,92.474385,72.499186,19.035492,17.908221,68.856347,97.671585,120.283618,111.858164,103.818502,48.487758,16.947997,93.212246,210.266215,352.377874,301.360219,93.548522,1.247972,2.434908,79.839946,165.008408,295.360828,300.68289,290.485087,243.232614,178.507777,70.235227,59.925666,92.818277,101.142053,89.323439,73.671918,0.59957,-24.423687,-10.840164,-71.605676,-123.733465,-127.624361,-96.123969,-34.341041,4.188128,-8.960733,-114.025576,-187.907,-260.594545,-244.907423,-208.948326,-202.485738,-165.668423,-161.171289,-185.768154,-230.920402,-243.944924,-246.279886,-219.525492,-135.828255,-106.816568,-95.814958,-134.732989,-220.18405,-338.865828,-295.187676,-143.436306,-131.11451,-246.140367,-263.769925,-178.572129,46.964728,123.346995,121.199213,71.610484,43.914085,115.962538,112.934289,-8.301216,-74.497906,-84.72309,-41.2492,18.262833,30.756784,78.214056,171.207012,190.171433,62.023389,-37.628529,-103.13797,-65.12423,38.699499,87.297666,84.142529,7.448932,-53.301021,-26.378173,74.789765,205.540583,214.282983,252.551534,253.311058,193.343969,105.171334,136.3694,176.951154,111.473698,-45.225345,-49.525015,-37.724609,-74.115045,-105.442944,-106.520872,-57.558867,120.147262,215.210065,273.314404,157.927736,95.47822,9.840125,-0.977689,34.258043,46.164266,13.308269,0.12653,32.044675,83.929606,60.692094,8.701265,23.728927,56.622652,58.633725,82.935169,89.059836,65.145312,31.866741,49.890769,97.672705,114.838582,188.967508,227.951388,183.319489,89.533491,111.030486,209.823911,192.926052,10.897764,-67.033761,-40.91756,95.091164,97.436098,-25.954074,-56.989503,15.693274,46.518978,3.49019,-32.270495,0.743342,62.688889,41.839444,-26.418201,-20.700819,61.312309,85.815398,17.130686,-73.120587,-95.42022,-151.716022,-162.094705,-113.573264,-97.924879,-98.407919,-112.972866,-153.205026,-277.744196,-328.265537,-308.053469,-239.688176,-86.717638,-12.273795,81.722889,41.851433,20.49823,48.157173,85.936599,165.259913,200.846419,271.876152,267.171957,220.152676,119.757104,99.2867,133.425678,166.973119,232.751597,261.678664,247.532259,140.295641,79.877045,-71.719141,-150.905563,-226.642484,-207.834009,-142.241921,-165.398466,-180.339359,-192.344948,-212.519977,-232.281976,-213.639471,-167.820558,-129.508342,-24.252266,-27.411086,-72.737105,-161.273564,-172.572158,-119.409307,-74.356028,3.076217,78.134247,107.864829,52.190284,-15.261178,-42.16212,7.912581,79.617481,72.996097,33.124531,-58.1282,-142.56667,-298.693404,-322.257117,-234.120178,-159.456392,-54.626581,8.600959,44.904741,55.784064,21.636357,32.780429,102.698173,198.845939,177.113399,84.681654,45.847423,22.355439,-107.286672,-161.378641,-87.196012,-0.530466,61.945473,-2.430376,-10.539355,8.859088,-14.429465,-101.628955,-88.472581,84.847514,164.141518:-69.212604,-171.638611,-206.883104,-229.419719,-178.189569,-34.025076,-13.629845,-43.677826,-90.539098,-144.239187,-269.598031,-288.930095,-180.479223,-94.078516,34.789891,75.673229,77.76945,-11.088522,-54.964522,-105.730136,-101.998724,-40.904043,8.232619,80.895164,-2.205948,-87.126692,-260.894854,-331.018407,-370.874372,-334.314649,-220.281869,-173.046786,-131.955251,-151.989209,-176.436811,-230.923908,-237.901672,-167.936078,-94.694096,66.788595,69.620246,-13.329775,-209.56547,-252.131749,-179.038729,-113.09112,-18.65833,-3.176111,-42.407431,-119.49245,-149.501985,-163.621213,-146.241264,-61.200356,2.294831,100.697824,84.61806,47.643107,-3.99469,6.584939,97.57419,146.779049,213.048956,235.211165,244.028276,149.426066,54.677084,-63.110101,-25.975566,152.652844,246.387809,387.662036,327.965539,236.946407,115.023867,116.42778,191.281099,215.621979,203.392017,188.307339,91.534231,-107.690281,-190.847006,-286.961154,-298.039518,-212.308413,-119.310566,41.694875,-11.411952,-76.641522,-153.158513,-163.054036,-118.212543,-65.376157,43.965584,81.531844,101.339928,-6.197205,-120.889468,-329.021015,-339.383258,-209.60347,-146.891149,-112.554001,-143.124386,-162.912642,-237.303733,-268.4505,-191.120839,-103.520744,19.796242,53.997425,83.807357,-5.621542,-92.747075,-263.493798,-286.765191,-142.809516,-25.783117,145.249223,107.592238,22.403118,-125.341756,-143.650448,-40.65602,29.034322,83.773548,97.25073,152.488797,153.271728,113.78701,55.130015,99.731789,304.890063,372.061417,319.276121,192.0207,168.417471,160.879445,152.801762,184.092783,239.681487,343.720365,347.812014,259.893971,140.901273,91.19971,52.833147,82.160039,205.660149,250.206235,209.106376,104.627309,96.856174,111.782843,90.707665,81.628106,129.257971,238.338525,268.701294,236.127325,86.958532,38.283739,111.882301,204.050858,282.06097,262.569061,284.172222,294.977829,233.927735,58.921862,12.523947,85.29183,161.648012,225.145806,195.818014,105.022199,56.890252,11.173726,-137.260559,-160.806472,-28.907137,57.86907,121.353207,48.640512,-8.651777,-141.633214,-188.648162,-162.620971,-130.394384,-124.178614,-130.56037,-168.955037,-232.819685,-230.500739,-220.585946,-242.864108,-245.464281,-195.023958,-76.983403,-86.022479,-141.924201,-263.534232,-299.720648,-281.294243,-221.318351,-92.846971,-83.587935,-192.722557,-211.892207,-133.460711,18.696917,39.620488,40.708788,54.027396,76.890626,34.398852,-9.568236,-147.23808,-209.515484,-174.645982,-76.690653,122.903631,157.536997,95.52235,22.887354,-18.544657,-142.101334,-173.553998,-52.841628,62.667188,165.955621,56.066574,10.120316,-0.160088,-1.277609,18.660728,73.343644,207.637567,236.591294,200.820123,138.593998,105.402009,55.304572,69.823482,157.066906,199.50261,221.212719,65.305654,-37.035797,-143.720053,-152.71925,-104.47121,-35.445081,165.547031,235.159008,181.998647,-2.058398,-72.372277,-108.84256,-70.594351,80.550178,152.376021,164.700295,18.360128,-31.802321,-34.095713,-25.146051,-0.106078,21.448596,47.846665,52.020109,47.605757,-20.58466,-63.900967,-47.644116,2.972545,87.160164,139.07294,278.759783,270.859865,181.709705,-7.70636,-39.57204,7.393527,43.523605,85.899831,71.562823,-35.572652,-83.463917,-74.713841,-105.068424,-123.746763,-46.135906,20.151767,28.801761,-91.132989,-104.399119,-35.481366,-13.857711,-28.054073,-34.914044,29.803698,85.673652,77.626855,-76.394108,-139.759705,-190.793095,-170.738257,-75.448429,-36.453293,-4.102396,-53.168088,-134.46818,-356.285623,-422.911564,-346.417073,-239.300635,-83.203348,-57.538245,-30.567761,-11.045936,-36.549298,-96.263417,-61.088836,118.626027,188.097738,197.751847,100.356062,57.574909,-3.776228,-16.622748,77.901464,175.238849,325.545272,338.997983,261.484047,130.91596,51.027522,-94.838116,-129.009729,-122.217712,-87.764056,7.05186,-23.063349,-107.531768,-304.869512,-356.54008,-281.965243,-191.259282,-61.028791,-32.419541,2.208676,-42.744827,-107.2601,-195.845824,-165.569851,-24.848727,26.34439,70.643385,81.965573,72.786072,4.317145,-29.916349,7.17549,70.380317,175.484943,181.619648,76.634417,-71.039858,-128.344525,-205.880951,-205.402324,-97.163093,-0.757461,158.457724,101.132177,54.461647,63.687241,81.552863,85.054698,95.119415,189.277269,247.813108,250.580195,78.751557,-25.940806,-141.435882,-107.635825,78.512451,158.296856,195.381053,79.026634,3.878841,-106.385238,-139.772608,-138.647101,-89.449128,82.484581,169.117987:100.96224,-4.585687,-42.100705,-0.027932,43.280408,76.073374,61.060459,41.763936,18.955893,-47.560616,-207.691817,-218.851847,-105.488439,-72.322796,-144.331472,-173.760489,-83.202465,66.176228,101.243121,80.159855,61.084529,74.166022,88.572952,100.777503,86.789967,41.266017,-175.938519,-304.485475,-434.398331,-434.694411,-385.9558,-331.035651,-168.196143,-107.392707,-139.390202,-164.122645,-102.369436,22.654086,4.541161,-119.642973,-162.479042,-146.984505,-84.439468,-57.186364,-69.335201,-106.42501,-168.70904,-175.180481,-158.953988,-73.159568,-11.921282,10.88888,-19.358366,-10.817355,40.693409,139.638019,151.962675,146.724599,130.863109,115.768202,113.089217,119.932241,98.361616,58.918818,-74.863028,-167.775834,-152.762535,22.310643,118.902589,110.48383,50.275799,112.775655,250.640702,230.546126,97.600176,49.074986,32.194669,20.453403,-90.988746,-146.81899,-160.122226,-187.109295,-233.636453,-285.717416,-267.588867,-177.898856,-114.06449,92.006245,274.36333,287.786583,192.849612,138.136452,120.842152,139.910666,153.385372,162.18402,214.349673,251.592718,261.355914,254.200291,244.39295,244.984117,239.133621,190.437631,206.222457,260.850095,315.869319,272.275749,196.275556,233.120573,384.552913,430.90652,418.291949,350.863917,317.296425,235.27632,187.357111,128.8489,149.295302,281.353079,332.845532,295.843019,248.963429,273.158761,351.949068,375.358766,315.859513,238.301351,143.48486,208.364225,266.844573,347.786902,347.902975,252.704546,186.031333,165.11983,282.242192,306.538256,248.31441,212.365284,190.371937,192.014676,185.183155,172.315938,113.428987,50.164549,25.139723,-9.66011,-0.013456,80.692706,122.224929,141.82123,120.070543,129.638302,159.540106,142.555037,96.034704,110.805406,160.500031,149.204722,36.860934,-63.382411,-66.929,43.698455,141.708639,289.756174,316.167963,333.546273,282.088135,208.017851,31.630592,-27.302361,-51.546295,-35.456969,6.835646,9.38026,-46.37119,-41.465463,-14.994497,-78.223324,-137.51142,-98.015144,-19.75223,59.186439,47.209546,67.811089,123.532322,101.526487,28.675624,25.017807,-10.553727,-52.238561,-99.871992,-131.939361,-156.644984,-205.843935,-211.667515,-175.205232,-138.188093,-33.432698,-0.387235,-18.158868,-53.399139,-79.335531,-129.677387,-133.349728,-156.77448,-183.181239,-210.027193,-206.111457,-189.149805,-133.027877,-98.379956,6.187108,56.760688,70.321911,-5.432081,-36.97819,-95.961689,-138.208639,-204.329901,-231.41124,-307.530754,-320.030849,-245.319427,-173.078525,-168.608235,-232.212554,-279.146601,-290.834203,-252.43602,-163.33267,-107.079813,-106.956747,-165.539679,-190.73819,-136.341529,-63.77733,66.758364,106.997456,150.83722,94.95046,23.893776,-62.043369,-38.962739,-15.635194,-76.778612,-205.340981,-153.761232,-107.419683,-134.982243,-201.29051,-230.138374,-146.10595,26.364614,36.848738,-30.821956,-76.216255,-87.256742,-123.659679,-140.249836,-131.09191,-123.273235,-159.711987,-171.729156,-135.681925,-66.552709,-75.201787,-133.296575,-146.262254,-133.926947,-110.085506,-96.913479,-133.820288,-120.582239,-57.545454,-52.404397,-119.166013,-145.600458,-71.554142,5.408478,-25.305741,-88.208537,-81.590906,-95.672021,-142.032281,-233.057017,-224.160155,-66.991267,86.007723,82.325398,-58.345968,-101.311461,2.70379,69.080702,29.384665,-122.019264,-142.370849,-89.952409,-112.421426,-292.18855,-336.494432,-167.323807,-35.699343,37.892167,-134.346481,-214.520094,-223.624469,-166.92035,-96.692776,-122.886932,-206.348027,-261.146518,-292.363086,-305.543719,-288.4293,-284.285055,-285.498277,-198.918722,-127.620305,-66.019461,-28.446993,15.03725,42.767157,32.666184,44.811899,67.018625,130.000228,141.327833,103.741967,33.866049,30.909242,62.349432,77.65913,77.470641,64.078267,25.729014,-1.530766,-17.927324,-98.673777,-142.145018,-167.596611,-149.899488,-108.540448,-170.436884,-213.268655,-230.433407,-233.395655,-251.764695,-230.532819,-144.013587,-102.258774,-23.274908,-18.786662,-64.049565,-162.967771,-160.530445,-52.212627,16.912018,100.038113,89.413839,88.58588,38.613364,-30.729492,-67.361685,0.887019,105.548689,82.277839,-51.05388,-200.21257,-251.297562,-278.825292,-276.736697,-283.979258,-273.423472,-173.326781,-102.152687,-111.552217,-125.938299,-108.356023,-35.063327,3.518811,35.218337,33.669052,-5.567485,-88.198041,-111.611453,-126.162169,-120.933891,-85.731682,-72.369736,-57.272883,-33.068841,-15.972831,27.993518,44.484811,71.577805,97.510481,155.967228,165.486813:233.274334,43.643801,-37.445954,-31.54383,27.383138,100.398281,98.735871,80.52168,93.876364,87.458529,-21.367626,-105.654736,-193.143016,-186.557454,-163.290335,-142.910929,-41.496325,112.993353,186.027093,231.308492,201.200076,159.77424,187.469111,321.914008,409.107048,371.667612,103.696445,-89.668991,-367.407819,-384.42566,-268.172798,-200.001499,-75.458526,-17.809107,-73.074441,-254.568381,-268.150171,-126.906908,-65.266188,-56.914039,-145.391838,-201.849935,-299.377859,-332.134327,-358.523889,-350.051289,-298.713584,-265.279702,-208.950289,-197.54488,-202.110007,-227.961151,-226.586973,-126.619552,-63.979391,-9.627382,2.912614,21.065534,39.543813,14.926813,-31.48279,-31.309645,-40.986762,-73.5038,-197.491329,-302.298943,-304.963466,-253.514564,-235.523432,-204.665356,-160.914801,-17.779726,1.196021,-49.673603,-154.78116,-194.903406,-245.774612,-266.343896,-329.227909,-350.075424,-329.541978,-291.583655,-287.842372,-301.938733,-286.710137,-149.730792,-57.741411,93.013015,209.432698,236.890889,163.723683,81.589028,-8.527194,10.792315,29.392322,-13.172707,-102.897659,-92.126971,-61.816538,-10.192805,3.834841,27.554235,41.692991,59.096151,83.521347,113.842861,146.188059,126.664003,111.037912,154.837495,278.650072,317.698985,333.560778,273.501988,228.678579,173.756768,168.828651,180.279,187.14251,182.151873,167.86933,164.521345,152.071748,132.228706,89.543293,89.754974,117.520201,121.742917,100.742773,83.637324,83.400824,94.945176,113.552572,118.615014,76.160376,21.89344,106.407976,119.577135,31.809996,-16.504173,-63.242825,-94.040734,-169.004831,-160.610326,-120.058574,-161.192761,-175.877805,-225.047536,-256.919323,-213.41022,-136.266988,-21.1489,-4.323801,18.810495,53.324358,25.620164,-8.35392,24.719505,64.558535,19.898881,-154.06943,-261.478823,-272.593464,-241.511656,-182.098205,-0.669251,70.429097,110.327842,33.280329,-19.392834,-120.251216,-172.365143,-205.83825,-184.013108,-173.101401,-185.474893,-190.429148,-180.551966,-174.060376,-156.442859,-155.639146,-223.295936,-283.183868,-336.921139,-265.805108,-226.088121,-209.559814,-219.6063,-183.102992,-156.82459,-199.163009,-230.174676,-187.253714,-147.763438,-167.650459,-222.136771,-245.091337,-271.163294,-258.475145,-190.212755,-159.139258,-160.420227,-185.257039,-218.272912,-249.126351,-227.343851,-223.548256,-279.354852,-407.823702,-387.718928,-341.276265,-244.463642,-184.599369,-45.776691,4.918654,19.112093,-27.961758,-52.746084,-89.756799,-93.126521,-114.43286,-148.829553,-186.965888,-154.496524,-63.691338,-45.184918,-56.405941,-124.25051,-163.678797,-196.803809,-187.957223,-150.303421,-129.20652,-109.713118,-101.50183,-144.772056,-190.013821,-134.375569,53.119501,142.523214,293.641483,308.385485,251.365362,151.720697,152.146668,141.885256,69.156022,-97.680379,-90.08552,-68.487463,-155.411778,-240.908708,-291.565076,-218.333633,9.545435,90.495566,132.621876,124.125155,125.038358,105.473984,95.70787,80.97653,44.15787,-42.628238,-49.28411,-57.148344,-149.144654,-196.967767,-156.062434,-85.985229,-19.985208,-48.182614,-156.858477,-162.096196,-126.761024,-132.299361,-178.163229,-269.198729,-274.742729,-150.320391,12.811473,56.726484,65.046063,31.180524,-48.257997,-64.570117,-74.157783,-79.44275,-61.139527,68.880791,130.588978,71.527173,-1.226212,-10.026078,49.022564,137.769269,83.212154,32.624568,-25.582363,-39.854975,-46.589364,-9.680941,164.39079,234.385366,182.490611,51.806658,15.226915,-52.605603,-60.671844,-8.579146,-8.117244,-79.03724,-117.21521,-114.881385,-108.336588,-116.546691,-92.604873,-44.749632,61.342951,100.157698,109.765152,94.634112,126.699476,183.937291,180.584005,205.194954,251.558098,338.082264,316.252526,279.272631,241.115404,229.702571,166.310879,119.852763,47.606943,47.486448,114.749664,140.387131,96.420499,-55.113503,-98.059128,-61.18023,-33.718632,-45.78907,-71.190025,-77.576969,-145.289355,-215.995511,-272.019765,-220.845381,-124.154129,-120.578571,-125.142758,-88.154844,-83.338947,-173.338205,-210.682691,-93.535475,21.811043,170.490148,215.217199,227.968006,124.574958,10.948256,-61.531987,30.582143,253.438838,289.413287,174.515788,-57.237992,-158.757166,-268.832037,-262.368708,-180.356236,-158.098861,-108.81858,31.269224,75.021651,20.592924,-39.698818,-17.826272,60.757081,97.488917,42.299137,-57.269088,-121.489983,-152.378495,-196.385938,-179.102856,-71.545317,-25.30917,39.388195,79.421833,71.837518,-9.802235,-52.902955,-31.972824,24.300444,121.024137,129.535363:-49.140897,-129.426479,-174.143587,-178.349271,-120.591806,40.659822,69.596431,-32.431553,-158.693479,-183.79386,-170.388598,-153.695684,-146.722467,-138.735193,-62.924536,-21.252507,-19.792208,-84.153161,-91.611065,-51.940654,-24.632209,39.366352,71.424009,96.949686,-7.379762,-111.351029,-315.992486,-377.820643,-405.769089,-411.966571,-415.396093,-354.191739,-171.439901,-138.975243,-158.350666,-150.883965,-126.712321,-132.00724,-160.25379,-165.39965,-156.478686,-154.729985,-86.59884,-53.53823,-64.189288,-63.932655,-34.110102,-66.102689,-186.102951,-146.531417,-95.114204,-80.273258,-98.268592,-72.879615,-20.030482,89.313735,69.732497,28.219822,17.811826,60.371798,138.890534,136.384161,64.044562,24.711756,-2.600239,-54.883681,-112.073082,-88.956984,29.448197,248.519577,281.476835,323.910786,364.29457,331.529225,209.38841,168.095041,175.00687,188.482294,124.974586,82.211161,43.005039,-127.473467,-251.888251,-378.067158,-366.206675,-276.334347,-207.639217,-47.945977,15.791998,11.696369,-30.249733,-59.704627,-56.571197,-32.836899,-5.156725,27.122749,103.890684,55.980567,7.393418,-54.532683,-40.484525,15.259012,3.641873,-53.673949,-23.637676,-7.52584,-37.164899,-54.17437,-20.718327,17.640945,64.831326,74.627396,108.848867,98.03762,40.834735,-55.227787,-30.452059,45.596389,26.929248,-4.171555,89.164144,127.627421,130.328205,105.690915,103.248926,142.60328,180.817897,161.161716,145.332742,192.322915,201.730785,181.527606,192.940152,269.815002,287.844346,245.809415,246.907823,271.891939,262.429463,235.575062,226.074424,226.907185,182.790909,186.877775,289.479117,270.411341,192.531978,51.853016,40.960376,128.557703,168.457221,164.96904,139.537718,134.388639,99.054945,65.861434,61.330657,101.964904,152.004296,149.76897,105.873474,27.707454,21.120111,127.73572,220.172066,337.03577,341.22397,324.942739,215.677877,117.790352,-23.692476,-46.805751,-40.8537,-36.372497,-34.200987,-33.024435,-57.19947,-63.976937,-45.220914,-10.489496,2.403923,1.909653,-1.638621,62.902259,90.32783,34.105894,-95.097819,-99.061958,17.737536,66.622207,9.762152,-57.821233,-94.780674,-84.70219,-123.585847,-238.567441,-268.277318,-217.952894,-153.519961,-52.829235,-68.44861,-87.64162,-79.671532,-74.301999,-114.373081,-152.462222,-243.068241,-267.557872,-253.291326,-206.58704,-157.155704,-60.270591,-50.673599,-90.877693,-104.899659,-47.788581,36.066178,20.839605,-114.919873,-172.497417,-167.850884,-135.94876,-91.586114,-69.199767,-14.468944,4.386902,-29.720522,-203.41518,-271.012982,-199.982292,-100.007122,39.569278,12.395739,-42.451422,-128.040706,-148.166688,-129.714181,-75.837463,23.989887,30.280932,47.505364,124.928313,125.934004,23.032488,-24.80113,-28.892306,-10.567777,-22.253559,-132.80146,-174.227818,-160.981345,-143.943641,-133.518844,-99.464312,61.774164,121.523139,82.297697,-40.290195,-110.661848,-244.828924,-257.481136,-175.669791,-123.516029,-61.911784,-111.500401,-126.956322,-94.901513,-88.607056,-76.696684,-67.2971,-134.496157,-178.960239,-148.640444,-87.095606,-99.56575,-103.697527,-48.170388,58.050676,63.900968,69.4061,85.949285,64.170178,-23.279445,-72.156359,-148.867143,-149.198781,-88.627066,-78.687189,-133.143183,-106.724995,-46.134833,19.140633,22.938019,40.273876,32.180738,-56.90291,-135.970679,-122.927716,-53.125795,-56.807524,-99.302868,-82.5501,-17.243819,-15.328229,-88.913895,-156.974674,-165.615558,-187.086537,-181.092486,-92.006265,-51.194817,-68.147975,-182.726151,-229.718573,-288.411921,-307.635238,-278.851337,-237.243594,-157.552499,-108.119966,-8.87132,-2.173819,-33.57814,-91.186441,-72.289669,54.114402,107.561534,167.417789,168.752552,132.082625,70.625513,75.850108,152.968405,198.737283,274.538859,306.439852,285.398771,143.221047,60.871322,-91.990457,-137.607977,-156.173334,-157.360655,-138.522883,-129.962777,-164.826159,-276.293795,-302.977976,-230.122605,-178.276987,-154.833368,-140.98685,-33.735268,-9.594127,-68.418985,-163.921374,-139.37847,-36.878177,-14.844069,39.083492,146.809508,130.865201,-68.743816,-165.252552,-169.839397,-77.829738,93.075068,110.178518,29.913584,-136.5058,-204.207839,-253.663283,-252.244024,-207.672992,-152.804431,-56.542777,-72.300113,-65.763206,12.123706,35.404867,7.081616,-5.941968,77.206254,136.510694,127.573564,-13.741932,-73.844095,-121.480333,-97.034651,16.455354,66.830856,112.911258,77.591302,62.079336,65.808075,38.297495,-60.535589,-57.434471,89.125391,165.982958:left
-43.65025,77.181396,106.389528,111.793569,78.727604,-57.882677,-133.296087,-221.937742,-172.302401,-117.557742,-21.097574,-3.474995,-67.641839,-122.63012,-186.617379,-169.175618,-58.290809,10.47062,33.134154,131.916285,191.038098,220.246471,182.153361,128.278009,159.660267,153.894024,126.749629,139.06445,148.796709,100.252144,-79.435558,-133.311213,-84.745944,-22.346807,-9.443698,63.597117,118.640449,159.943687,103.309473,-52.621719,-38.310018,-24.510837,-90.482755,-131.655336,-155.678597,-154.339871,-217.794396,-269.79018,-264.279732,-123.046275,-52.558061,45.370103,81.107044,123.222659,109.807229,43.245996,29.499674,22.155027,-19.17496,-17.096107,25.458106,31.29002,3.936741,-6.37984,51.460505,213.47508,287.161246,306.01674,240.59077,64.026086,17.437017,110.696847,293.373479,323.278973,317.67469,313.779682,210.529083,120.270909,19.164229,14.717762,47.505059,114.440293,135.923765,124.810261,92.251009,8.017488,-6.040673,76.050394,131.487002,89.003551,-13.472512,-32.781507,-51.756796,-67.083266,-140.015621,-185.897834,-183.488701,-83.199541,-37.106888,24.763596,35.748224,11.937817,-28.361293,-118.769739,-85.032046,-29.282131,57.086759,70.079497,34.585017,-10.112881,-94.300164,-97.615868,-18.972416,33.275523,21.73489,-31.774291,-63.558694,-140.955831,-185.972796,-218.623918,-115.818592,-75.816619,-148.206491,-233.352075,-330.382016,-310.714909,-256.479676,-273.591012,-315.743061,-252.998738,-232.772999,-301.483146,-333.423865,-261.555406,-213.012049,-191.717618,-81.312663,15.000407,114.837011,104.586395,52.724144,23.354437,-73.530892,-120.887751,-76.951581,123.632203,191.911941,179.940732,140.3593,77.616638,50.030914,-9.139678,-95.754138,-133.428371,-109.630539,-84.098906,-116.645436,-133.577003,-93.556485,-60.30629,-11.470106,-14.227081,-27.706563,-12.593786,18.950502,53.189612,23.429217,-103.290911,-169.021471,-149.432575,-59.925797,-51.246572,-122.661951,-137.128502,-99.76415,-78.812047,-27.54861,48.823458,104.11284,209.039781,234.640244,237.20504,215.319335,146.167521,120.444391,102.484506,31.698543,18.309184,74.764452,116.146071,192.397527,239.153598,308.01985,251.944297,213.424353,167.895462,128.164317,32.559549,9.493035,37.639064,154.520187,209.764017,264.777678,272.677982,256.271543,228.746784,164.783515,161.142764,239.373916,316.184434,349.199028,443.063771,454.586876,326.858511,245.022366,216.904125,296.481402,298.72232,203.130216,138.189888,41.316736,19.185504,-4.440525,-10.615094,11.327211,33.461535,45.171113,65.302069,52.531059,-16.708693,-59.838608,-106.101552,-29.76884,47.89981,222.431642,261.553993,150.331124,60.91964,16.080821,76.47627,260.217092,324.699973,286.579371,218.253049,241.757622,273.519614,203.20877,20.396086,-8.54855,-21.561401,-43.510909,-14.207295,47.761282,31.91592,-103.809393,-162.711227,-119.677439,43.104409,116.458423,169.386337,147.720936,92.94825,68.107984,26.950571,71.902747,135.048511,287.602058,315.590558,211.001507,154.304465,161.799683,197.652565,267.992353,271.469668,250.043749,255.335995,276.962996,278.343899,248.402574,178.134841,197.231638,216.783035,193.089091,154.758286,60.170432,25.199832,9.364004,20.023365,63.293967,128.944194,169.144891,238.796492,235.990315,116.556112,25.161621,-100.100948,-79.062707,-46.792476,-0.227976,14.705106,19.313828,2.644644,-60.856501,-81.521293,-14.972647,113.694929,159.432372,185.356576,162.309412,83.448968,34.933853,-32.38778,63.164262,152.901198,295.910333,325.85691,268.976168,185.109031,13.06752,-21.191222,45.997762,146.21251,158.792802,142.848872,131.116715,56.965702,-17.95262,-129.732289,-58.880117,-16.396007,-52.938708,-83.498552,-55.910496,-54.550233,-244.823691,-382.217902,-458.992636,-325.149609,-264.024966,-183.383176,-180.021732,-239.85534,-267.921193,-277.990786,-253.911121,-255.245832,-234.869558,-182.189562,-100.135861,-133.704001,-289.030275,-328.508956,-269.019453,-129.678421,-70.079417,-60.68224,-127.643207,-329.642647,-407.891647,-391.083913,-181.076768,-114.524189,-122.891538,-147.987235,-198.542776,-224.271198,-229.60895,-185.74993,-24.921417,78.347739,96.801805,98.312413,80.194754,58.01214,61.969827,99.168431,166.448247,170.203491,153.091211,171.48259,218.160965,202.265814,117.606648,106.607298,125.285908,51.896933,15.978975,-31.97751,-69.030138,-114.837179,-118.868322,-147.353277,-168.714428,-167.260515,-113.682752,-69.513985,-4.693588,21.038027,39.20015,9.93948:-71.303666,21.163984,42.194266,-4.221069,-64.748833,-195.546655,-245.404469,-241.250051,-137.769227,-106.637651,-94.625554,-101.793798,-120.768177,-117.597774,-68.841631,-26.215097,57.271586,107.791434,124.915012,110.09296,85.257113,58.712155,38.060442,-38.537053,-34.730677,21.72587,161.610317,190.429764,153.85028,107.509964,-54.063754,-131.888339,-145.72367,-49.530668,-4.787831,46.463623,43.432609,-14.130432,-69.922604,-160.960924,-118.611316,-94.873789,-116.519894,-143.659068,-188.021845,-208.779339,-291.884859,-333.890405,-291.948926,-157.704272,-110.330932,-54.834677,-36.482917,-8.350026,-9.65621,-30.988482,10.944174,49.136019,89.559148,96.490043,124.219172,133.023189,81.367094,44.971368,85.976752,255.531847,329.010003,343.296349,295.06324,196.13439,155.341011,101.286111,199.003746,310.935342,463.642569,439.907991,286.925878,221.289537,118.530931,82.090152,81.437441,140.386965,190.912778,296.265584,304.118458,192.911962,123.957784,96.561091,97.487288,43.706802,-84.951335,-110.853118,-116.687648,-133.408347,-191.829934,-195.988128,-115.10033,-33.056183,-18.174931,-9.450766,-2.33497,-5.212864,-32.425803,-89.598067,-71.962773,-36.623392,63.964016,109.753456,99.052237,25.461958,-172.435912,-238.444274,-227.668213,-116.505811,-86.658739,-131.190689,-170.354343,-199.135729,-207.081974,-247.378963,-240.060221,-199.958736,-112.161219,-111.816021,-163.333603,-152.362849,-79.76943,-76.324544,-139.707852,-163.508764,-152.614063,-174.433825,-188.417985,-135.336403,-107.969099,-108.243977,15.043311,125.453992,254.869396,246.458567,131.323734,62.282186,-10.574223,-2.339836,86.779406,188.4916,212.323571,152.928506,81.841334,-28.519835,-51.2884,-46.268246,-38.747533,-48.54505,-55.104286,-55.140938,-61.842476,-57.366652,-48.745347,-58.258416,-66.122454,-18.472111,20.632024,117.910845,153.828968,137.695939,93.54189,44.898774,86.871929,111.159064,142.072356,120.485904,-27.845945,-103.736536,-144.149909,-107.827123,47.100166,173.346331,190.649244,266.408281,346.784723,440.113626,421.253278,353.141177,318.607016,294.203752,227.926635,202.364993,190.495233,206.056728,268.501763,301.725094,335.534275,308.598273,303.436684,317.667158,282.990871,110.099153,45.093,89.24404,181.683885,182.173325,171.91135,172.035846,143.163879,129.746273,145.063477,161.008649,164.972274,172.762124,209.683893,312.214521,316.875008,191.801914,113.357604,60.438757,131.119953,157.839952,118.50001,60.512252,-14.578218,-11.086889,-12.901193,-30.37146,-31.920661,83.71033,158.618179,147.143784,59.228979,-69.675198,-76.750465,-29.998701,109.957558,194.72707,268.776833,244.122792,179.645002,165.191453,150.380045,168.134735,264.478341,294.325235,263.317273,222.114084,241.499568,265.477574,237.809333,151.493307,82.457489,74.577464,140.399536,145.488099,-17.697316,-111.628365,-191.004665,-191.400327,-116.285672,30.008158,91.866978,147.196602,150.704561,126.762891,93.605641,38.912985,60.72613,90.515104,185.883331,245.652489,315.47186,300.38929,204.871592,164.025072,181.464703,229.756333,210.048982,154.792712,142.884341,101.286117,74.612841,120.871982,277.414138,321.893094,262.873695,196.218679,102.981098,74.847745,26.952377,19.814163,68.167983,133.361925,143.468726,119.307501,84.035603,-44.478015,-129.654194,-254.879587,-182.967888,-82.462788,109.246769,153.591625,104.163433,45.576776,-38.797335,-45.803671,20.044309,137.43788,193.709863,199.876719,135.326259,0.811683,-29.275204,-40.397353,-7.425387,35.858703,134.527867,163.312726,149.516826,109.933572,25.851124,13.265532,59.377451,123.536071,129.555194,43.315287,-24.751636,-122.523964,-166.453092,-230.415422,-110.743389,-19.531034,28.980103,0.719117,-24.319932,-32.387697,-153.222195,-251.539686,-363.461096,-316.262194,-277.470094,-225.46256,-219.022182,-251.594425,-292.988277,-395.975602,-392.387036,-342.860611,-253.356288,-244.928039,-254.863962,-258.785684,-315.671205,-352.826123,-338.96717,-223.985736,-158.724669,-61.442252,-33.68245,-34.067378,-75.126397,-175.831742,-169.667393,-119.742878,-25.999992,-44.062235,-192.054754,-244.798033,-260.635935,-231.744581,-92.47542,58.982632,118.428624,179.057887,155.341283,37.087414,-2.872836,5.880027,60.098515,100.079989,196.592096,200.646721,100.159491,61.230499,75.740737,96.433276,95.824105,102.042389,121.927783,110.655155,63.725177,-16.730266,-34.645241,-125.009668,-215.308129,-193.379239,-88.700262,-73.571878,-89.074505,-71.455854,-49.412589,-71.412029:-38.428671,66.653252,58.557285,-44.056533,-80.766851,-78.290915,-101.941285,-232.486641,-208.502619,-120.331271,12.790727,10.375198,-75.300646,-114.116585,-113.923948,-63.234996,87.373316,152.279764,132.493742,49.310492,10.876004,-30.984861,-28.071961,21.789692,41.381062,41.564951,104.514902,139.008574,100.965142,33.765946,-103.409801,-133.057854,-99.487035,-20.853349,2.903235,-68.669173,-141.912081,-210.225458,-191.166036,-118.199421,-99.046158,-123.229063,-182.564776,-204.5013,-254.758222,-274.992892,-259.562178,-228.430508,-153.000636,-88.043448,-68.468466,-30.306315,-7.320999,-25.476895,-65.044051,-76.294102,31.217299,74.529289,100.035713,94.200917,66.277654,52.185059,34.374043,57.187564,209.707154,374.598479,412.235529,362.694115,290.056142,160.486752,138.325819,182.950233,256.442684,275.751219,314.737612,334.406154,292.420289,214.961732,63.638636,57.186453,163.313108,217.186377,216.197137,209.427717,180.940005,71.341893,45.940807,112.354802,128.814373,74.455459,-11.062782,-12.929998,-46.918866,-106.698486,-224.150492,-238.37628,-160.380061,-7.478851,38.931636,15.370823,-14.077959,-60.508171,-97.700115,-159.807702,-97.38512,-29.592737,100.715021,147.982296,149.698774,79.161899,-120.179395,-164.760143,-100.864547,-61.444374,-92.195719,-180.529671,-204.548265,-229.902743,-248.981923,-244.167323,-178.533862,-146.947544,-91.378482,-91.297586,-160.313446,-191.912259,-223.603171,-228.342438,-182.104845,-99.232785,-77.151567,-93.50237,-115.529487,-148.879577,-151.817884,-79.731293,66.956101,119.981001,132.12015,105.006006,74.158451,69.687915,40.890814,42.939926,109.426328,170.263492,171.958377,78.768484,7.855199,-26.802738,3.802217,-0.636211,-48.127211,-21.03794,73.982463,76.934738,-7.918304,-46.843917,-86.623345,-84.156562,4.536118,93.254105,97.38385,119.812967,165.384307,227.38524,212.593151,174.331929,228.54617,256.163404,225.234097,180.873123,116.83513,92.0585,15.17302,-5.918158,28.085416,140.936385,234.681743,410.579995,451.234508,449.543495,421.567425,376.426772,424.954254,456.642169,436.795038,380.743086,241.88523,190.674358,161.745417,185.381361,275.432359,358.030971,369.260951,268.51629,167.430686,-0.138209,-13.857462,93.842209,192.17577,198.875875,161.207072,133.748539,98.717179,93.666724,103.911265,113.853353,126.119307,197.526896,256.538026,323.414367,312.180552,221.082667,147.988391,37.051057,112.775542,177.306348,180.617408,132.118923,90.303388,94.246613,67.979476,60.030115,91.309432,93.782893,78.601827,43.654759,24.598114,-53.96296,-97.436363,-39.663268,159.351802,215.972807,226.718768,218.142186,164.188697,114.2833,67.635777,107.204393,254.523904,321.643329,313.343227,270.437726,254.661967,226.075411,194.034484,97.497742,42.953839,66.996742,196.132101,220.474324,79.080824,-23.046666,-121.001803,-115.226612,-54.96411,62.810828,120.326539,135.223373,112.705179,90.796259,70.538056,33.849613,119.45109,170.206048,215.107822,223.899262,212.571325,175.910938,73.209193,51.905761,111.505318,196.313059,205.259992,143.815159,110.885285,98.318963,100.431144,124.119395,206.943722,247.143517,243.904453,197.281496,107.718219,93.398288,64.424947,34.72275,5.498404,65.551031,86.900373,75.452829,81.933395,65.46727,-8.461905,-179.784784,-129.253022,-18.112544,194.579128,212.84782,55.80132,-41.491734,-100.084767,-52.604655,115.496604,258.654937,286.589002,224.011502,149.507614,8.71155,-34.699864,-57.649352,-8.289725,40.082851,126.149668,131.033795,83.330707,44.343177,-58.147887,-93.330569,-51.528247,51.119269,62.538837,-0.219739,-28.645214,-60.989484,-99.293824,-186.499466,-149.460922,-81.052238,32.439658,39.021851,-27.853015,-85.475987,-235.031252,-298.810674,-327.945883,-267.31236,-226.40857,-130.678226,-105.698005,-168.687966,-227.038357,-265.334089,-234.255571,-244.122979,-282.534243,-281.529061,-268.676715,-292.417087,-370.747357,-377.027635,-294.057316,-164.512744,-94.309145,32.493458,63.69833,4.182052,-85.877336,-198.132047,-39.073969,64.714432,105.632732,43.241563,-101.705974,-144.428539,-165.304994,-140.358733,-26.767603,103.150423,151.428657,174.531723,143.861388,27.646137,-30.831293,-22.951365,131.614995,175.380434,156.420468,122.916912,50.033277,23.820678,13.407492,31.243297,91.158,142.372585,148.536039,84.326416,33.5675,-42.462017,-91.08615,-236.13654,-267.189752,-221.06808,-139.419433,-137.025344,-187.769106,-228.331839,-308.630438,-317.353908:-36.699006,48.367465,87.047038,124.783981,95.726309,-56.850163,-135.523886,-184.237727,-142.302314,-131.663541,-87.083265,-39.504717,7.031123,-37.229138,-186.52583,-201.677475,-59.274313,97.140502,145.086313,215.3837,247.423652,276.982364,249.726674,159.900895,108.569222,96.82435,131.842294,144.871292,37.679619,-53.247015,-165.210504,-167.646771,-112.568146,-67.953897,-52.33492,-42.290598,-55.531148,-114.464212,-159.512502,-184.722494,-67.532791,-47.763874,-157.734832,-216.162703,-210.087166,-178.698684,-205.724941,-242.634225,-221.817972,-124.309821,-60.22104,109.917392,188.306849,250.742694,215.341171,92.803319,53.80766,60.789107,105.206985,126.203698,99.527419,73.982673,109.121654,156.669056,212.757249,260.223219,298.845613,328.540348,295.115931,165.688212,110.995497,122.377808,229.967557,256.713783,259.047794,238.990529,131.213422,82.62835,52.824743,50.815,69.066229,116.329796,147.851768,157.968913,111.833753,18.708622,20.39804,105.674882,129.539719,85.393765,4.106651,2.692008,8.533167,-35.828523,-204.482331,-258.466639,-228.173661,-159.767239,-142.718364,-98.72041,-70.264772,-64.434509,-101.893795,-199.037747,-213.918295,-173.59757,-18.541675,55.236067,108.551969,89.525656,6.486742,-16.907533,33.043779,83.732908,74.881484,-4.768872,-72.729424,-202.361037,-247.307982,-259.196164,-147.09976,-93.724053,-65.865458,-93.994919,-189.012552,-224.024657,-256.298909,-259.793026,-251.905904,-211.887905,-178.343055,-184.024123,-238.425821,-312.380235,-294.747512,-192.67296,-39.642915,35.443405,128.872749,146.414794,135.140176,104.237542,-3.147514,-38.728581,17.09927,93.57108,88.630338,53.930028,49.769373,45.73852,12.107977,-82.881994,-58.085097,-20.361779,19.622252,38.89782,76.462372,57.988606,-48.174223,-70.22359,36.98287,153.863484,160.487503,133.63905,134.697599,163.842343,158.778384,127.04816,183.668071,220.535937,231.041832,210.481126,110.762366,43.810962,-9.589968,17.748408,89.479159,162.457124,224.590874,314.258747,317.093761,318.705061,323.299146,298.826487,258.234419,234.007475,197.216182,176.370684,95.385253,60.041519,54.00731,93.58166,221.55795,242.677566,208.144012,143.016916,107.413143,20.542387,0.611849,65.185666,204.748972,250.923499,269.728087,253.472872,190.958954,172.336312,178.289977,182.414712,238.672035,346.695738,388.184409,455.735237,461.525238,377.466576,314.987381,268.542723,309.418667,308.111815,254.651693,210.765098,94.758295,49.001494,21.281856,11.312266,-38.914117,-10.647744,40.993062,40.296148,-42.131314,-189.15705,-189.725137,-91.026153,0.996745,20.728122,77.723737,121.622217,143.258505,115.374936,64.52031,91.359468,268.450539,340.300629,294.103477,190.135955,177.476017,180.941017,143.431358,-3.066075,-59.911097,-41.358658,13.707661,23.677601,-8.258181,-45.172981,-197.917055,-266.869272,-186.431231,-5.781333,28.274394,30.871002,32.267972,32.653529,8.413388,-45.474809,14.409318,71.931833,203.908658,255.538599,247.504958,199.538061,101.53502,79.576375,104.490458,89.526044,51.747171,41.359922,77.618063,136.644078,137.556586,114.034988,121.591377,140.814877,166.943527,146.187635,71.75555,57.546034,46.312276,35.552875,55.840913,119.123757,142.984919,159.057395,153.333844,117.472945,77.355701,-3.432261,63.388991,126.570701,182.680258,178.427456,103.556426,30.918738,-66.220428,-48.433432,80.717569,212.921192,249.746511,225.9001,181.454111,95.907632,46.901412,-48.376696,-8.09633,75.716925,226.543237,234.372693,161.222334,122.323925,43.189063,12.630525,39.382214,139.657829,159.362274,98.269753,56.590047,-3.425542,-63.369603,-184.645116,-87.421365,-12.475249,-5.640573,-58.524422,-138.985238,-147.810165,-190.171697,-250.76288,-352.576634,-305.195028,-246.673747,-144.2474,-121.879938,-147.074888,-181.131271,-224.783142,-203.92269,-198.657196,-211.176982,-197.325215,-116.697167,-116.096322,-284.68095,-367.707915,-340.615882,-164.476893,-89.662346,-66.846517,-103.633566,-167.88801,-195.281538,-238.136486,-165.967938,-100.566274,-22.248975,-21.583967,-67.797805,-97.199935,-119.070974,-100.060984,-13.21348,119.708208,178.923701,136.598811,32.300098,-92.005381,-48.378511,99.609403,110.591047,81.453609,43.323471,40.245816,54.529497,56.68513,21.526769,1.248546,7.459747,42.071992,31.869936,-67.442492,-131.762081,-200.832663,-198.091794,-174.554109,-192.846095,-219.411347,-253.06282,-235.590847,-163.470748,-154.875054,-234.58558,-282.38465:-59.619387,47.21684,75.752711,58.084555,23.364484,-53.304351,-115.955517,-259.296692,-243.573907,-173.443764,-30.344642,-12.310918,-115.54752,-182.818432,-199.909097,-145.836437,-29.436993,53.039367,113.489176,211.84397,209.462752,133.318484,98.197818,92.18176,133.677722,152.608947,208.355718,213.709749,77.316465,-17.659715,-104.565437,-112.763488,-161.921065,-185.030176,-139.227348,-42.481239,-49.379295,-165.29896,-237.24613,-261.431754,-126.587843,-88.805773,-149.32326,-206.321974,-238.84812,-217.03203,-178.077779,-156.086152,-96.015954,-22.690277,31.804234,117.298972,121.910213,79.928858,49.899697,26.757777,79.84766,111.047184,150.099959,148.525294,118.355884,120.768079,193.483391,244.354359,304.253791,331.579875,363.819896,397.194314,353.614476,189.67385,125.368444,94.773144,179.179158,266.42189,402.898553,378.211977,222.496196,177.479366,162.188867,152.356998,150.096513,228.208932,270.090716,265.629518,213.086752,114.999137,102.17143,108.202244,121.207246,132.86478,133.382459,97.617547,-32.961283,-95.911462,-175.961392,-189.192802,-155.474014,-51.201966,3.272644,31.64822,11.750315,-35.236215,-61.111742,-101.164238,-73.200116,-21.25765,116.656071,162.6883,184.086534,166.500476,82.364407,51.887608,85.60158,180.201731,222.996917,194.477981,102.975285,-122.604654,-193.05471,-157.771788,3.503157,56.248448,81.212981,44.99625,-134.637451,-222.411577,-275.936784,-251.379189,-166.672264,-75.489973,-43.616814,-54.999647,-100.428115,-195.811816,-213.072387,-169.797712,-55.138684,20.424675,128.338571,122.929271,63.963495,56.12378,50.149963,45.280215,65.363983,90.795568,93.642292,66.123633,43.094806,0.466841,-24.940764,-56.82001,-34.390685,13.169736,178.991346,228.79314,152.520738,62.630614,-70.971427,-60.919606,86.265564,167.027123,167.271383,164.537231,169.730656,155.978346,122.28206,69.475624,153.187172,223.211084,285.528675,253.767449,128.084771,75.884843,43.478404,73.643096,182.550469,228.357464,233.508048,269.144753,294.328836,330.564227,337.614176,347.475479,362.512495,362.104799,323.155582,281.703346,204.943613,180.167392,108.064287,73.411939,83.975509,157.074705,193.006707,223.810478,198.894935,59.32221,-21.014613,-48.316365,119.432537,211.31433,312.943589,307.424302,228.641012,204.496872,198.624087,189.428856,207.935874,328.233134,388.070322,418.171084,386.204605,290.857363,256.132205,224.475307,198.523446,211.428822,287.74301,283.952468,148.372777,77.372992,7.762679,6.692452,54.974813,102.225358,123.815185,134.721744,94.852948,-50.61042,-111.064728,-115.543674,9.556694,75.53757,145.510241,158.171458,195.081167,200.403057,113.743401,83.535355,187.98891,315.44628,329.866514,271.026667,213.097314,100.83577,62.324402,45.050697,99.726799,122.002689,117.605137,97.896321,31.263279,-16.1102,-104.892688,-107.631891,3.978098,107.316692,140.318785,201.266472,204.569337,141.258294,85.463947,13.715389,113.869132,195.835356,290.27367,266.386141,129.323848,69.888191,1.516325,-14.899516,5.844228,84.549289,97.872641,31.924416,6.308758,20.919639,19.670324,19.479974,146.083083,220.245744,214.572259,131.386945,-22.818484,-50.210781,-55.886209,-49.106676,-11.447107,43.751882,83.997553,159.411831,159.972988,62.949418,2.326772,-15.762625,106.180887,169.270647,228.131413,212.810609,87.129,11.850147,-66.806032,-76.738112,-29.018429,150.674297,243.035194,294.069926,252.975986,124.879308,69.178337,44.73469,87.378879,114.439152,173.978047,181.088261,94.275602,12.172029,-123.583788,-142.554479,-95.360378,1.399243,42.343532,43.783841,8.915007,-101.498825,-171.7914,-244.720093,-151.619861,-95.616372,-50.188817,-61.392551,-173.218356,-268.276739,-443.627338,-470.055321,-385.986325,-287.066936,-248.04988,-168.091639,-152.325031,-206.715551,-248.005158,-287.96986,-271.803156,-253.599351,-213.852615,-195.363967,-232.992252,-308.696339,-424.150367,-405.039357,-311.93214,-226.422161,-164.512334,-93.846758,-102.908243,-150.364008,-183.760906,-235.596332,-150.32133,-52.709143,77.822495,52.604206,-103.063811,-165.492317,-179.3558,-133.935962,-25.32391,69.444682,138.533903,196.039609,117.064416,-136.937595,-198.317052,-101.734246,43.435212,62.334032,35.509557,18.435056,3.786606,-1.576239,-19.742415,-9.929345,38.922483,29.982837,8.615265,-71.332379,-138.315581,-257.390276,-288.573267,-318.582252,-313.611427,-287.37071,-208.378218,-178.6194,-191.767233,-235.736565,-335.815929,-361.181192:-60.786289,139.41971,208.899323,157.174243,77.097808,-55.922925,-119.90717,-244.446261,-202.836785,-135.150478,-53.942301,-54.184665,-74.727251,-88.747116,-184.415114,-236.707343,-215.250625,-48.542296,59.587499,281.24297,358.737631,378.2324,330.960975,195.246733,98.402033,85.016652,108.38779,110.801827,46.234664,-9.408444,-107.196638,-115.150264,-52.922581,-33.476326,-30.229985,58.093586,115.739253,119.875873,53.47575,-68.815063,-14.511008,21.659716,-23.14701,-80.828299,-120.129315,-95.376856,-97.818954,-113.07828,6.341604,177.596007,203.454913,233.275063,264.453617,294.355738,262.642449,129.914694,81.012916,105.588058,131.810252,94.764835,-25.132526,-37.832109,41.039772,71.268305,117.158658,245.109128,320.961082,377.241509,322.643692,124.364819,55.395574,67.063652,210.002926,268.936168,287.50853,243.982823,90.78225,46.580804,82.657199,91.57306,25.823298,4.337842,35.833373,109.658991,121.714618,161.289784,205.050834,239.420187,153.500744,99.149196,39.16441,34.630897,47.168858,46.867246,-4.718509,-26.953948,14.161315,31.887778,5.015257,-17.227762,3.932962,29.080588,-3.862729,-108.227033,-72.422847,-4.382215,102.024221,130.6923,179.925649,204.720281,261.312225,304.653968,376.712795,352.561482,331.57954,252.324617,167.368834,-18.633932,-77.990015,-52.015574,137.571653,201.533483,172.655593,103.160774,-69.054246,-133.213596,-199.876114,-222.791882,-210.90787,-167.497887,-184.663552,-268.130426,-296.763752,-267.765258,-232.445295,-174.913687,-73.054567,-9.153726,86.5199,93.891853,22.742051,-21.471337,-31.931361,14.078643,119.784661,117.775928,109.819394,171.928609,209.180558,195.746969,154.442218,49.880846,-38.767284,-74.195318,-94.645234,-52.856904,69.016438,81.155393,-4.217558,-34.508231,-8.996098,-3.109366,-13.876415,-26.936231,-44.409526,-88.389154,-94.377428,-39.046218,67.282982,92.399612,69.590252,50.045047,57.328427,76.393002,37.604862,-28.422035,-81.927528,22.317196,50.307009,13.546058,18.976373,140.695207,167.680625,55.398729,-23.331209,-36.003783,-102.034996,-130.644825,-106.411642,-60.678756,-2.875988,-5.942863,35.636236,157.454621,188.241896,124.731155,60.0944,3.478593,29.256895,112.659601,197.757831,242.916367,294.138887,293.930706,275.940591,263.168262,243.561934,258.196976,337.625893,406.066118,454.625027,551.778962,530.067086,343.356715,269.214252,290.570636,389.354501,396.951802,295.083994,199.808182,5.532415,-61.51693,-148.715011,-180.476061,-208.398557,-124.108176,-43.937463,17.497385,-25.048995,-145.218186,-199.381319,-251.80447,-205.997663,-180.317715,-87.271345,-3.138517,114.116946,106.262216,8.262373,-20.21062,87.657041,270.006315,292.927478,197.189195,138.918698,94.989688,72.907736,-40.924966,-128.502774,-140.293043,-93.540653,-54.765201,-62.391213,-112.061501,-232.663303,-264.508428,-197.621612,-73.293824,-43.559572,-30.539291,-20.061894,19.473451,24.367115,-15.30866,-29.822604,16.984065,191.662118,230.57188,81.326066,-24.43169,-97.21153,-73.170661,24.817951,135.432384,176.905203,201.79558,185.382358,158.146671,159.589769,157.187228,166.990453,174.81789,142.044048,93.214838,-22.090758,-63.625177,-109.187918,-102.918718,7.148228,151.706173,195.754201,229.564127,223.432168,147.569053,84.368498,-13.428122,-0.387867,16.220609,3.339861,-6.083764,37.004548,75.457679,80.843785,43.520846,5.931266,97.272672,163.838366,206.024905,157.76345,31.766163,0.37072,20.451193,111.504163,170.004338,299.93925,341.224317,262.541278,160.518643,-33.886712,-96.504334,-63.085084,127.97789,195.396718,164.739934,85.181246,-26.905112,-34.258042,-63.598952,-59.656928,-1.974731,108.396084,109.170919,-9.123356,-85.099831,-214.031741,-286.587683,-385.497814,-268.398909,-173.99509,-86.197556,-99.512359,-169.923934,-202.133404,-217.668471,-140.17497,-94.188871,-63.699251,-81.705658,-161.791352,-208.421995,-271.169703,-272.221017,-176.944592,-28.56388,-3.547102,-66.982516,-113.475046,-189.481757,-223.455846,-276.833945,-271.849953,-232.361732,-117.706833,-81.341453,-76.910584,-79.926138,-40.490446,-8.095992,63.863793,133.629725,145.784636,89.684569,26.488568,-67.891055,-61.027142,27.853716,71.903054,56.07859,63.524107,109.734322,151.957843,120.016731,51.583662,44.807004,47.41067,-2.394342,-40.949578,-129.056585,-172.893386,-195.378817,-160.798168,-66.52049,-52.174544,-81.158813,-130.546087,-134.847567,-118.206194,-107.766309,-129.676201,-162.036564:-130.543765,-3.725866,76.824987,136.880101,78.992691,-144.636029,-268.487904,-391.178959,-260.315185,-161.902961,-24.273418,-1.03942,-55.859415,-109.265242,-195.762556,-206.701429,-130.227773,10.464445,86.239252,224.381127,268.046528,255.92428,201.427108,105.370228,106.844312,131.666785,200.899002,204.232262,40.175312,-80.872307,-190.312932,-170.268168,-108.219715,-68.020727,-21.376671,69.034707,56.12527,-48.245014,-88.004997,-115.789459,-79.581731,-57.095584,-63.353971,-87.91502,-131.212965,-136.035008,-147.591594,-144.846426,-30.663566,145.440345,204.373978,232.493393,210.846601,159.253857,139.106903,90.131875,41.625829,43.084743,111.74148,141.122032,116.960841,68.817,-17.743452,-7.229258,159.770182,388.595714,472.643801,505.082811,448.422886,274.049025,201.379728,155.090113,250.091902,320.565458,400.739023,386.959099,268.133241,199.320568,133.078814,147.520002,249.1762,341.8861,361.23615,331.998378,274.540134,150.880212,144.015626,242.353289,265.623014,231.430726,198.654781,194.061543,136.672678,96.610178,26.551824,2.394829,-1.525444,61.155295,102.345813,119.09462,98.534343,66.153938,48.161526,10.919809,58.316376,94.360756,124.931845,127.194923,160.053223,206.88163,286.608944,291.481757,284.307007,338.895769,377.867858,336.0866,226.838789,-41.691467,-127.309186,-100.963194,92.263401,177.166188,278.714319,277.915187,135.672105,41.674005,-61.966559,-68.769461,-53.092385,-27.840903,8.710184,36.734204,-23.10025,-182.888827,-210.369589,-153.438909,1.292603,104.420247,255.666034,258.065464,149.025893,91.653857,31.792365,38.480329,112.376015,154.084067,151.433204,88.21823,41.435727,13.182082,15.3952,-21.005872,-21.93481,7.582383,116.564738,167.213745,123.559306,33.963355,-103.715904,-88.34788,66.943404,167.866548,168.421449,97.796363,60.088994,22.181074,6.066124,12.415664,137.284111,207.449199,253.642726,223.333823,122.629529,85.267593,37.962318,25.649525,70.570663,160.89691,203.263848,275.736893,280.090478,225.333698,200.742272,188.193764,171.267068,154.176614,117.39494,83.526451,5.534178,-13.06772,-48.715493,-60.365225,30.770732,184.067435,222.100553,198.374576,149.579184,48.085485,17.17355,4.966269,116.008662,204.948769,317.986453,308.107046,195.416269,153.725317,173.407909,195.134023,236.508478,395.536704,491.031678,511.294097,415.396477,197.278195,156.723795,247.761177,398.780062,430.392421,385.667762,318.441028,136.959682,48.237739,-85.169173,-107.299428,-51.691568,37.085177,82.794786,116.356297,69.065453,-58.606095,-88.280807,-77.294129,-11.50825,26.887567,99.467692,128.146562,159.325944,149.028462,67.682705,51.362711,170.125576,300.625761,316.958321,281.459751,219.512223,60.607176,15.414607,-22.167928,-44.572514,-11.187281,131.220847,160.079011,76.895845,9.88506,-122.588861,-140.693006,16.055682,184.904661,198.793295,131.972845,82.682628,0.677272,-31.660944,-43.111623,87.29859,182.375099,321.545245,315.465298,132.46401,27.588732,-55.731257,-45.033963,2.644379,59.390593,85.555238,108.419968,91.765914,3.349524,-33.319833,0.833787,98.627756,118.833248,119.286739,100.11401,-17.592262,-96.60921,-193.115771,-170.520114,3.064687,140.489379,157.065653,126.600387,99.008398,55.449267,21.924983,-40.703096,79.987573,153.491923,144.546866,89.514917,-26.117199,-76.779013,-155.056692,-177.71847,-114.380575,70.379686,144.856813,193.045113,178.526535,104.851253,41.222604,-74.856801,-49.182838,18.206379,154.130691,157.535918,9.730548,-96.492136,-264.488368,-284.767847,-173.243174,-32.590317,-6.757899,-25.094565,-52.997137,-146.231781,-208.745826,-270.14354,-157.039483,-78.379972,-9.283882,-35.393818,-174.948691,-256.750891,-413.909725,-472.963356,-455.24849,-297.941159,-235.061072,-244.768783,-279.510024,-285.261833,-288.028949,-340.237313,-359.965648,-332.664752,-206.089704,-167.225,-253.847041,-343.558789,-487.972922,-511.796942,-446.230218,-253.462079,-150.016647,-99.590853,-156.170329,-297.433468,-357.528396,-421.771739,-354.385265,-275.623492,-110.60683,-78.070454,-131.980285,-185.912168,-258.2517,-239.335198,-99.176309,34.304107,79.03228,68.447385,-9.485106,-168.429888,-184.824775,-105.994045,-20.033145,-8.589863,-19.759,-25.415023,-23.419418,-33.878694,-133.003342,-176.450598,-104.653292,25.723322,21.206442,-140.991392,-240.709299,-327.610192,-304.389813,-226.530034,-198.904003,-168.318617,-63.316915,-47.819339,-136.829802,-191.557331,-256.270761,-264.01677:-47.735421,45.165882,68.011017,-20.302624,-97.666632,-176.132829,-201.575078,-306.881649,-318.455574,-259.93777,-145.159714,-143.585252,-251.204691,-306.546776,-335.45567,-313.13459,-210.491491,-75.43082,6.288729,223.146887,327.16588,384.54912,318.54506,151.279119,128.68921,147.97127,172.869385,169.28039,130.233694,105.950001,78.868912,86.072164,124.418071,118.471246,98.072312,63.577527,63.816534,88.409385,89.736807,61.764412,11.695199,-22.357732,-50.395817,-28.491803,61.801559,109.963517,138.999554,118.112449,109.300483,175.018758,204.154169,235.765317,248.622151,283.372458,291.281221,233.351443,64.857512,-25.742347,-96.576941,-70.754077,5.829085,19.761872,-39.716331,-70.457485,-12.815175,61.155114,72.522564,91.446906,82.955664,36.022727,7.850148,-67.903727,-35.481825,27.505457,96.926351,91.03212,59.719388,44.419542,12.645366,20.968784,130.681402,206.187615,182.594584,95.211204,84.83413,181.012005,245.2675,279.965448,195.151777,131.102936,40.775868,34.756128,61.626592,77.578527,103.237409,110.099154,99.518502,72.267854,74.884255,128.006746,166.338815,215.276762,196.339867,119.015593,140.898129,179.447053,291.837572,350.902393,383.136929,376.395802,412.004665,442.25967,511.364372,599.191157,611.500303,507.480158,404.816829,235.086639,215.588304,312.181789,439.624643,440.004837,313.472143,227.947608,113.540897,108.671572,115.227388,84.253084,19.904575,-9.842237,-46.102418,-134.581893,-150.762647,-118.451562,-113.659947,-179.785772,-193.424294,-145.072809,-32.5591,-26.499726,-91.726496,-111.853627,-112.774036,-84.8531,64.49919,212.047213,252.925704,278.899318,267.039522,229.215993,199.849634,70.936405,-101.958904,-161.293081,-149.346077,-97.136418,-33.556924,-35.206322,-68.77925,-95.910055,-133.486894,-134.512754,-134.760309,-148.718411,-173.464942,-242.693932,-262.249428,-228.92779,-118.674282,-60.31122,-11.034843,-33.974275,-77.125424,-63.942636,-57.822585,-101.149214,-187.206647,-187.767195,-175.626392,-144.969126,-130.142461,-145.398711,-178.211871,-199.207762,-175.066676,-183.735022,-192.300067,-183.003956,-186.989812,-198.3846,-173.202984,-126.436338,-50.47121,-51.153146,-40.739299,-2.946973,-8.184504,-30.66197,-15.191591,37.685787,64.324817,73.849026,86.211909,80.630402,66.686507,83.550016,123.676088,120.131459,128.04189,216.238282,269.406679,308.088409,264.673611,123.278526,94.963069,176.047718,263.692255,233.278495,23.173104,-93.430293,-225.415416,-245.470309,-254.813878,-256.795625,-262.856108,-221.508642,-164.380698,-57.59904,-62.533126,-181.773802,-222.062475,-141.078783,12.331207,57.265829,103.336738,110.975297,71.928804,48.828788,38.305265,35.074148,68.952664,199.403051,251.083456,193.025784,117.913915,69.865676,98.135819,116.344605,64.253159,39.851245,26.159729,35.31341,30.238933,3.059445,-94.269273,-132.62653,-125.847779,-84.39264,-60.430824,8.48301,42.463566,47.244828,0.794671,-129.484087,-125.249859,-64.162148,47.288732,45.817652,-85.535223,-149.31831,-147.328533,-98.912981,27.05771,153.502689,198.916481,233.525431,250.109261,304.989578,278.997286,86.46515,44.43676,103.030749,139.433118,87.823928,-62.283582,-123.482349,-165.805182,-151.654667,-91.088203,-18.165711,30.264623,150.205665,188.994962,160.688997,95.957658,-86.644923,-211.017135,-208.08461,-145.538658,-139.258661,-139.554599,-117.145853,-103.527486,-123.570938,-103.630594,10.256348,48.335571,30.78234,-5.780107,-58.436566,-59.951681,-5.886545,114.322325,209.409579,387.021207,383.460261,202.509474,137.063533,99.467412,41.350536,-139.89876,-176.791585,-139.074356,-60.193149,-40.225377,-27.299583,-26.953971,-45.502398,-66.863257,-47.661567,23.725873,29.272847,-33.914295,-76.574124,-188.247041,-243.516195,-223.904946,-58.454374,7.747452,34.941814,10.28162,-13.000598,-5.741754,-43.910184,-113.778309,-99.898571,13.36132,33.63701,-79.524965,-144.484261,-180.672952,-171.374047,-108.780343,-37.923945,-37.373058,-89.016516,-127.573986,-199.525883,-219.653154,-225.235417,-190.774336,-160.07334,-57.493738,1.107237,49.387787,40.541508,18.579943,13.235862,37.546156,131.274729,172.779741,160.768724,128.207798,117.58633,136.112203,127.843957,56.700349,20.149608,-6.867902,36.74051,196.367722,242.479322,218.414159,196.721741,175.231874,19.098916,-78.336179,-125.178019,-95.205149,-10.112207,44.9502,114.647386,26.2152,-52.757441,-119.435608,-92.616049,4.84492,58.259886,81.89666,23.896674:10.819213,123.125496,143.507926,65.541731,8.870562,-7.620441,5.559605,-51.564053,-113.91606,-113.739151,-117.303603,-141.95584,-206.09364,-227.693539,-265.263768,-271.746382,-192.629412,-40.37772,36.808737,162.64013,198.333209,231.03576,219.918141,138.799404,55.539168,26.877129,52.222293,97.951463,123.942456,103.20955,98.911287,129.930637,190.290553,171.107887,160.628304,181.128984,193.570015,170.449552,125.618096,45.39705,78.632651,81.717351,-13.829745,-59.764365,-41.784429,-7.827196,-34.378684,-91.268134,-119.94477,30.077719,110.876948,176.742403,177.200258,190.212771,196.259065,179.636852,123.133899,72.801957,-15.275597,-31.953101,-48.504804,-60.686525,-83.819097,-77.351494,18.080892,121.884379,136.431498,123.619572,105.883039,48.917312,14.680701,-18.791043,37.858107,65.173699,100.140379,116.869644,62.452481,-14.713948,-140.968587,-146.740842,-36.671315,32.621254,-0.426908,-43.824051,-7.026842,101.590837,140.041706,185.661612,149.070709,98.327538,37.361329,35.422045,45.106777,60.285583,82.837571,73.413839,42.246084,46.971064,89.874328,197.16985,206.304491,151.430387,121.96464,53.639645,15.063228,40.185503,148.427877,183.182994,173.405333,166.579897,184.334829,198.518884,230.330363,261.722401,281.829992,271.168028,210.471475,41.848906,-15.937238,-9.430705,31.591446,-3.902255,-125.477327,-164.279174,-172.535691,-151.119717,-127.799427,-140.768175,-173.2586,-206.252676,-223.74474,-237.568714,-234.389411,-190.884967,-161.536121,-169.734039,-158.069811,-107.585274,-45.187678,-66.567266,-142.704447,-163.75814,-176.960061,-163.429949,-33.739002,126.93362,173.671751,225.725771,226.465553,160.757513,97.80166,-75.477793,-213.651998,-246.042241,-229.590116,-181.856846,-70.783772,-40.330781,-85.234915,-141.746914,-175.244698,-119.737033,-111.113135,-103.089928,-96.441121,-108.912154,-134.324508,-190.413185,-175.636768,-151.637266,-132.744061,-142.695235,-155.688623,-140.148686,-135.905083,-170.799229,-190.043526,-97.877077,-68.701586,-75.571884,-80.101952,-46.574072,-47.553615,-119.807344,-113.091699,-103.189786,-219.429367,-297.625435,-283.511777,-196.908325,-46.130819,-19.679361,11.181195,97.705457,141.945206,151.300913,109.74415,10.669251,-14.852538,8.18986,93.291517,127.495744,162.813436,180.807131,234.660271,254.634169,222.871821,188.121067,217.459117,360.805013,414.503047,408.53029,349.612285,237.90777,233.048851,312.071383,373.442024,359.501492,257.970819,190.742387,29.383709,-52.306287,-140.703433,-138.41491,-98.935254,-51.036582,-14.743882,9.967538,-22.478566,-101.411543,-127.048413,-162.959594,-98.307756,-26.651711,91.090199,106.286134,30.255472,-12.419276,11.377644,64.483001,166.509255,148.979931,105.861448,77.585688,108.709499,159.447366,126.45604,-12.526307,-93.670434,-106.144114,-65.92912,-16.757147,67.084772,69.966447,-41.301582,-100.544664,-54.190983,54.98081,70.102104,65.146892,62.975654,59.093926,31.028466,-50.15192,19.587198,105.268908,257.243665,266.918233,130.251689,71.065898,83.790591,109.94551,150.266761,209.696769,243.057275,273.604272,269.559375,238.556671,199.064939,108.799483,105.362021,105.977018,83.994469,80.820706,2.760032,-90.42231,-183.147868,-130.785663,24.780257,89.012967,122.884106,243.540426,289.438413,259.929278,169.536712,-85.016844,-181.879065,-157.30441,-101.373065,-84.963167,-57.888238,-65.850785,-121.394215,-120.516047,-13.718012,68.738221,69.268923,46.49241,28.452232,-12.594452,-26.80789,-18.801821,84.901717,168.263063,321.899497,341.202176,219.672489,130.744687,9.925568,-23.219132,-47.567647,-18.233198,10.069186,31.120384,1.159246,-90.806325,-118.323762,-112.145826,-63.797082,-41.409814,2.248095,24.647214,40.183978,8.107753,-155.601044,-238.189066,-246.528475,-97.606291,-31.5306,43.716148,73.294386,130.920644,125.145161,30.271792,-13.363575,24.927126,148.084318,176.624379,103.713798,32.679573,-62.737141,-66.541197,-4.920118,31.427188,9.903299,-79.218747,-120.17433,-165.086358,-185.950622,-256.004239,-291.382818,-260.68828,-98.946508,-17.467738,13.453604,-20.585392,-41.75557,-4.584639,106.551993,180.622904,197.796745,172.004331,129.23345,93.277558,127.349054,222.343276,263.332319,245.046294,201.101859,221.941357,285.915627,273.063288,185.50734,166.223329,171.907295,78.185536,18.835953,-43.35585,-57.357963,0.806173,68.273541,91.988138,-66.563358,-134.668888,-173.069676,-166.895092,-110.806536,-45.057202,56.371371,48.948741:-33.414379,-38.947566,-4.445035,50.417585,0.739973,-161.366158,-224.569484,-313.435025,-273.654256,-214.270836,-97.423375,-37.308978,11.485354,-46.447486,-242.840637,-283.869596,-173.502406,6.588698,82.257204,173.609682,184.607071,196.609153,207.621253,201.854416,142.335268,107.16116,108.994448,124.02968,48.356526,-11.565489,-18.575229,42.090311,158.144828,70.929599,12.869928,70.947435,114.800624,39.040386,-37.445548,-91.295606,-58.980351,-87.770437,-145.172207,-111.644807,-10.301477,5.590195,-10.833618,-9.664578,32.504059,123.215262,176.831673,215.439134,192.777439,146.243423,131.744359,67.29206,-21.196048,-57.391924,-60.924028,-21.56874,61.915662,71.78506,-14.766606,-61.780138,20.322234,208.662647,276.919609,359.770556,345.469483,196.800363,114.462515,48.720512,142.310965,231.854115,356.909013,327.953569,157.866674,114.490318,141.007992,163.672749,231.321078,266.642764,242.650548,179.682635,162.539823,181.979363,222.252284,313.450255,286.406089,220.742849,133.694911,147.166846,227.85812,259.170906,208.233633,126.204936,-2.37444,60.362021,133.527709,190.758625,163.41893,94.060713,63.182482,7.149681,26.532241,63.387538,106.094161,125.084136,256.747782,341.161316,389.862063,361.647931,381.722201,519.899759,546.496557,412.49192,285.669489,113.730763,111.288815,189.839519,279.98316,312.240508,323.673693,303.933238,197.312551,117.266898,-30.481766,-72.19457,-81.279745,-42.698406,-15.877108,-1.290943,-29.530749,-97.619223,-132.626859,-188.811359,-57.18079,55.777835,139.782303,97.040124,20.331628,31.340264,83.604983,91.70136,82.493558,77.894991,89.717092,142.863986,159.663393,130.105256,96.353047,1.345295,-114.256675,-142.788104,-70.662592,15.080731,102.251283,76.728064,-7.928201,-54.031814,-155.290638,-171.678316,-130.55218,-94.89172,-163.847797,-347.215539,-355.430266,-177.14992,10.297695,51.196952,77.28979,74.158247,38.613784,25.376683,-25.700081,-84.169269,-164.13646,-81.661317,-15.450915,37.222041,17.309265,-8.840061,-0.015597,1.817418,-41.257468,-69.369188,-73.149638,-58.404919,-82.742556,-106.351601,-139.582226,-155.320269,-97.297093,53.32765,87.309044,49.090039,4.815412,-78.976456,-99.975344,-50.781227,47.592759,64.012478,93.423226,116.335452,64.421863,17.606424,53.672319,128.516203,248.604111,287.001276,309.452532,304.582489,241.021987,123.058817,131.126523,202.720083,198.670937,174.1517,143.75405,112.22272,-65.277109,-159.287335,-213.882881,-182.482715,-100.153868,-69.454888,-53.628105,3.920972,15.567191,-53.925452,-122.879758,-194.452657,-35.855415,60.359172,90.488652,57.482011,38.956238,48.019021,38.183308,8.872828,-20.678169,83.397011,129.815953,103.201991,68.44179,40.458915,8.297572,-107.233665,-84.48664,-20.612252,68.572689,74.214245,23.089106,-39.135864,-199.97729,-224.513015,-65.526955,85.457618,62.89421,-70.5676,-115.207953,-137.083403,-136.855136,-106.705586,-30.990371,-3.086071,47.398677,57.471669,-34.916193,-96.557584,-88.775372,-36.196412,12.675836,-35.259844,-15.610652,135.05534,181.581378,139.142242,85.189641,-21.580821,-53.951089,-26.761144,121.827026,188.601239,88.138947,-47.944503,-194.666834,-164.20339,3.392366,145.850552,174.513452,175.800519,168.363994,153.014868,135.481803,76.439847,25.732822,19.440035,31.801913,10.097909,-75.702098,-84.541945,-34.285034,-13.678933,-15.407597,-17.026354,24.482404,96.475163,91.872734,101.179745,111.086719,42.519672,13.954886,72.257701,256.355341,301.229269,155.602171,27.056096,-123.487912,-129.295597,-72.824957,-33.796246,-11.992794,44.342142,44.668615,0.475306,-12.220452,0.796726,14.384888,8.688299,52.60828,101.783246,87.728143,13.012912,-151.097064,-226.451024,-304.387303,-180.00703,-103.427004,-105.688772,-163.042287,-202.141725,-176.788654,-134.400467,-108.135878,-108.737181,-132.922359,-137.466385,-133.680379,-137.742525,-235.453353,-320.304993,-342.008174,-129.248562,-60.508176,-127.713559,-194.925576,-241.860585,-238.554132,-272.423962,-308.678367,-287.276695,-163.931603,-98.737877,-20.717196,-9.579351,-55.513669,-86.780629,-46.003958,38.954449,43.583342,35.94911,11.947077,-100.070098,-132.253411,-79.42715,-28.595057,-41.200348,-32.140948,6.717816,73.161016,77.377994,8.706318,-32.709799,-25.740382,-5.765741,-38.798594,-136.417221,-168.579434,-177.88311,-171.373454,-161.954202,-127.954883,-119.948535,-125.986676,-104.748981,-32.998853,-37.226267,-137.869123,-191.097518:backward
49.199169,4.868466,14.118208,41.267779,32.489332,-13.481132,-35.7375,-107.972478,-206.469854,-205.048084,-111.259837,-71.194524,-66.539055,-98.129003,-158.028757,-160.358286,-129.536699,-127.818815,-154.025057,-194.904773,-170.847482,-69.116379,-21.730116,53.630067,43.477359,3.677821,-68.182658,-89.115424,-157.842412,-204.605743,-213.309773,-185.088397,-208.493831,-268.10638,-267.432057,-266.688113,-276.650508,-246.218203,-195.410437,-137.670538,-270.29871,-334.003329,-326.630682,-309.319859,-309.025749,-295.541141,-247.561818,-233.434948,-179.774995,-6.052251,64.581955,36.24125,2.441085,91.146034,197.221522,338.927644,231.101518,125.038536,-29.452701,-45.452143,24.137639,56.410521,38.338152,10.918477,8.384572,89.623152,110.440996,62.091869,25.004502,-13.866759,-14.463913,-25.044618,-109.649621,-162.805137,-222.148828,-207.828801,-115.826672,-68.147958,-4.196246,4.109324,-30.114483,-69.363627,-89.793178,-178.076401,-236.619384,-322.474391,-327.21732,-300.053211,-362.13393,-398.304951,-377.102357,-330.455705,-261.178105,-263.522597,-262.115338,-225.837047,-185.44984,-302.137891,-384.551321,-496.135312,-506.547581,-441.577974,-378.532409,-226.686078,-129.70933,-124.342889,-162.547188,-180.823588,-183.823956,-167.492915,-129.133356,-106.14513,-62.940901,-119.49995,-155.009082,-105.691942,-49.873068,-2.644773,5.145907,32.35267,21.40985,10.553464,-44.474493,-104.280606,-172.16348,-150.105772,-84.583566,-64.515074,-20.331377,-23.076593,-76.104538,-157.520284,-114.596187,16.093702,13.838699,-54.308411,-1.669039,39.598358,-5.580437,-85.962277,-165.412038,-126.841145,-17.606441,1.861823,-60.748906,-147.639085,-165.756924,-176.036031,-162.433657,-101.274076,-65.388321,-21.914024,-109.004724,-185.323041,-298.389567,-311.566162,-255.536255,-200.012293,-35.372301,39.040096,6.96693,-174.534107,-216.68664,-115.994383,-3.8268,165.086338,179.298283,153.511785,171.872731,188.804008,160.147705,110.309111,26.438027,14.812105,41.288051,54.077699,-5.208363,-98.2668,-127.662164,-231.130259,-284.4759,-302.625389,-265.049483,-138.404702,-83.184566,-107.004771,-159.804928,-146.409361,-94.207054,-95.945845,-135.30042,-148.032829,-116.52963,-82.854458,-139.061711,-298.566292,-310.243175,-219.650866,-173.850039,-136.173239,-194.209566,-239.768971,-305.223966,-321.501605,-239.120877,-134.32205,36.774033,68.652569,57.249705,-0.285152,-22.513619,-23.574542,-15.755367,-46.292813,-70.785043,-39.28097,44.365568,33.703367,-109.716336,-181.917391,-175.693344,-94.55307,96.971857,152.635376,133.254396,38.152525,2.786751,-24.474175,-21.412791,-24.475382,-36.589898,-37.401558,-19.824003,-38.699779,-147.301569,-193.141297,-158.030135,-98.930678,14.490871,44.353146,-20.278421,-138.479471,-159.45843,-147.377023,-131.339323,-69.662432,-10.525713,124.654935,145.462064,104.248024,-2.948022,-18.415633,111.691951,196.609076,193.658974,123.536327,40.906212,93.494786,104.533294,55.670208,40.740495,72.137722,112.55504,202.382842,236.358374,251.939603,286.62711,292.826602,306.234475,298.965912,230.32405,203.21192,169.788251,114.570952,100.322988,138.683789,186.004183,285.199619,319.574971,353.338774,382.876917,380.939937,224.69683,97.029641,-4.608402,51.091732,206.743315,246.430958,218.252699,162.824713,167.544517,226.439137,267.564986,309.834315,299.474381,244.200754,138.649245,98.637573,73.085543,51.369185,-24.33526,-48.951891,-39.168109,-18.192329,17.01228,25.41587,7.981534,-53.94158,-73.322617,-79.279057,-61.984218,26.223814,33.352147,-13.062326,-101.766848,-112.267077,-36.270964,34.388114,158.914503,195.097879,219.327462,206.952869,199.904476,223.417253,262.318857,332.918987,342.223231,323.656441,276.118355,242.975046,164.669085,126.421659,129.864119,193.890278,375.602494,436.418937,434.990603,392.108993,372.074638,295.291299,267.430597,280.517931,295.933451,312.933249,281.545886,244.405587,192.558316,176.809877,143.435256,147.438774,241.245863,306.559339,367.200651,318.675086,255.274393,117.685483,106.668043,224.024353,284.975618,263.724559,163.292732,137.589573,63.242711,19.129658,17.250791,43.458881,99.901739,136.170885,174.003261,100.977007,37.398451,-69.640862,-64.864573,81.454658,157.910343,185.195646,154.528839,158.611399,140.622784,125.949197,161.761869,197.919998,307.47519,386.042356,450.537136,302.544706,199.448772,74.179742,74.191162,129.059178,162.892756,246.455873,204.556279,100.919691,-77.876822,-82.801785,9.89787,53.394477,138.340761,178.964332:-12.615191,-115.980935,-133.081619,-68.513166,-29.061621,-27.088804,-58.668838,-154.685257,-209.645282,-184.880476,-121.265286,-118.46194,-139.116025,-138.578248,-90.336609,-62.020724,-57.285487,-88.000447,-101.468774,-109.729398,-109.9446,-111.167859,-85.595949,7.812757,0.351003,-45.410745,-123.773726,-163.696642,-251.707546,-243.85332,-126.033443,-96.218021,-152.371674,-214.632347,-245.536432,-322.839014,-327.799235,-215.636613,-135.829806,-76.137867,-161.134504,-216.662545,-303.887552,-317.113333,-272.263524,-234.919174,-174.030893,-145.401001,-64.195588,32.926702,56.503411,31.927485,48.335588,274.274008,407.649211,418.468191,176.377685,71.377882,-48.783322,-61.650749,-33.367827,-29.682442,-32.415496,-31.250634,-56.22454,-30.453357,1.991193,65.373439,113.887114,184.013112,166.486947,62.272779,-48.582969,-99.197373,-182.066848,-188.170498,-124.670938,-87.207679,-35.425495,-19.296296,-16.030853,-62.367419,-102.763479,-203.263922,-260.694667,-346.03575,-338.208822,-248.111204,-248.234624,-288.840215,-359.219531,-371.521138,-330.55637,-272.956874,-125.08638,-101.283479,-239.491515,-413.219387,-457.617708,-469.532813,-427.459909,-260.442945,-171.023731,-66.586613,-77.558208,-83.836381,-54.560353,-39.666275,-4.829719,25.025426,55.324893,29.568396,-95.898003,-169.170945,-152.610351,-67.305711,-28.823121,20.00837,57.946926,138.537541,93.629327,55.853306,7.036757,-27.69959,-72.962711,-57.228148,33.344976,88.966746,139.423597,95.021675,60.605051,17.487661,24.956279,64.05889,82.034716,134.311787,142.764061,103.9857,7.257556,-18.195774,-15.537654,4.100531,77.428928,109.900135,68.899627,-82.62177,-151.28773,-205.429574,-182.181679,-64.221378,-5.435843,-20.102187,-195.009196,-262.690846,-274.623022,-251.188228,-209.964027,-173.735553,-28.19511,25.408331,-79.924335,-243.652672,-233.570256,-94.432448,-23.510382,93.971551,144.885874,166.121485,82.470199,57.750802,49.708374,48.37104,51.430342,49.872922,43.775666,38.80166,-1.358481,-74.531957,-118.106685,-199.120686,-216.127476,-183.051198,-139.237439,-46.692949,-18.314009,-31.792821,-100.509617,-121.857736,-50.312824,7.398189,41.085356,35.45963,67.811446,74.503788,3.597123,-193.95791,-229.187434,-150.403009,-93.1568,-81.465113,-219.797785,-283.234766,-315.009802,-287.086143,-175.081004,-90.314148,104.413898,166.715668,151.705384,20.407535,-53.241923,-115.478544,-81.180143,17.212608,32.36052,-29.323127,-136.039019,-181.671514,-254.371357,-260.720934,-191.334465,-124.311579,34.639094,83.235442,58.502637,-43.548992,-104.602298,-153.222963,-106.927002,23.943622,58.216686,6.755695,-123.769959,-152.247711,-173.159566,-196.829186,-182.504669,-107.92724,74.922231,105.396686,-1.125379,-91.891383,-81.534923,-21.251401,4.18631,52.945503,96.335721,178.443067,136.622719,97.838964,97.475646,134.033902,198.342987,194.74535,121.871277,96.014198,111.781743,94.21471,56.98842,42.835063,91.416117,203.654716,234.422129,265.997008,300.315015,306.559756,276.459308,256.636745,219.250637,201.025506,210.346831,227.158003,212.421136,145.204552,110.184901,91.437904,126.899862,229.734993,263.674138,300.407017,248.93621,171.178189,3.045958,-43.180987,-42.326617,1.775755,184.945531,277.16525,276.196998,96.423078,38.719617,63.252368,109.288987,180.841204,233.353217,346.38786,235.152996,125.249455,-46.912855,-94.175306,-76.838513,-25.674121,45.769316,34.285835,-26.207634,-62.868725,-98.855798,-153.692673,-132.250207,-51.960007,-25.235403,1.050989,-17.921291,-29.004346,-49.622546,-71.657265,-82.052914,-40.456412,89.690236,134.746341,166.21231,201.368506,207.060253,159.476029,146.842,178.499721,195.662863,230.353468,261.381344,250.335642,182.359133,141.775944,140.240201,200.589995,364.759385,421.363942,453.222043,439.497401,403.521607,292.59551,280.819085,383.810501,431.626762,418.435123,325.749678,258.999714,143.54826,123.803696,140.669687,169.399743,262.512619,300.756286,285.106519,190.556333,138.73557,73.687677,74.807512,109.222474,127.664044,162.258332,186.355637,181.8703,93.963718,17.514698,-97.850309,-107.522906,-26.910368,46.426864,150.723454,53.899651,-41.421812,-134.304906,-84.451403,145.428836,235.592432,254.88027,185.424545,137.218931,19.399501,-2.297167,90.463068,161.652667,264.441478,301.368509,345.571421,302.243842,240.838295,120.498787,92.650764,104.220112,140.193927,220.262284,170.480218,69.015494,-160.637771,-196.883816,-75.889881,15.990293,170.073825,216.987196:-27.227929,-76.205849,-74.966675,-49.834154,-42.675411,-34.151029,-43.303031,-127.03843,-224.868057,-249.197827,-272.646346,-275.75144,-253.633885,-246.307492,-258.039286,-265.498932,-274.522292,-274.920319,-277.148199,-226.504985,-156.020982,-13.713587,23.76039,19.539685,-56.111444,-103.65994,-196.406325,-233.640966,-254.16175,-216.315047,-87.957315,-65.894642,-127.94339,-166.358797,-183.563189,-192.196347,-144.783298,-12.391763,18.247578,-10.527178,-38.393951,-40.590012,-124.478532,-189.487384,-243.591752,-229.280139,-137.031802,-78.702321,-27.683562,-41.244194,-46.84339,-27.193426,18.994152,176.287732,251.079079,255.130621,59.205074,-22.298321,-78.865798,-75.455188,-45.329352,-31.440681,-8.24623,-5.217621,-24.790473,-12.382205,19.686534,104.393385,134.955016,147.637075,142.264771,119.532891,72.518352,30.46831,-97.180686,-142.605654,-120.859979,-54.040048,133.323011,182.948009,95.146907,-42.237397,-85.586356,-167.349631,-192.417872,-173.15395,-142.166296,-93.973317,-138.153635,-186.667934,-233.621414,-211.77264,-108.632912,-51.142213,-4.325923,-48.229381,-217.611002,-306.2489,-296.139303,-233.124242,-208.712534,-155.735451,-109.18995,-31.37274,-11.340995,-8.052813,-37.847211,-52.540437,-9.038244,25.149493,36.396846,-2.719616,-125.984007,-121.210618,-81.3226,-70.55694,-82.892324,-13.409969,76.016381,244.325216,205.340301,109.706862,-67.363676,-82.731599,16.367097,72.700877,151.906141,168.579093,121.43185,25.935949,-8.663569,10.017287,59.789189,139.585809,145.676372,105.964887,56.003115,48.523396,53.297418,42.954344,-14.305445,-31.735643,43.018357,94.554138,33.929757,-119.924827,-160.551921,-198.097044,-191.647675,-100.270983,-46.909178,-60.875129,-249.696612,-350.64919,-420.74532,-367.507641,-198.519799,-138.503885,-81.241078,-81.128379,-117.902937,-139.459262,-135.595726,-94.267752,-58.862938,50.697911,122.469039,195.207264,132.830982,99.439917,51.023873,43.523795,71.076841,77.854308,62.194913,51.382199,9.630461,-43.344115,-62.48754,-102.672082,-119.651947,-76.487571,-7.204755,105.965675,91.34406,55.747218,-0.223888,9.002516,71.98416,90.357411,110.256702,127.488461,152.562309,135.830399,108.766245,17.596266,-14.488175,65.406748,149.064269,174.182688,-22.159804,-127.3308,-256.224828,-258.623558,-137.842488,-52.58792,81.121846,125.226862,168.095311,82.74471,-0.072519,-112.381409,-117.525853,-94.823617,-89.690331,-109.887289,-147.063954,-167.798116,-248.873677,-274.377878,-172.009207,-67.502893,53.924988,43.810157,2.638014,-28.331131,-85.238207,-174.494999,-126.846119,68.252575,120.379942,42.719655,-142.67422,-207.036468,-244.168826,-222.528799,-110.803055,-34.873679,75.071381,69.416381,-35.591773,-80.097212,-61.104221,40.303851,110.050666,188.032643,191.007113,196.292265,172.248743,130.636122,66.762562,83.505301,161.067226,174.182985,125.360934,78.458416,16.639212,61.52491,81.808459,92.425452,103.222179,126.440653,133.585791,114.623738,133.138066,187.430048,252.063544,235.297111,224.542709,253.703975,277.394038,239.282375,146.27454,109.942044,76.841112,14.70694,46.81134,214.552686,287.502842,325.498486,179.951937,77.335125,-75.690897,-112.731835,-88.211189,-35.463966,81.579754,118.014332,103.175828,11.984439,-8.413253,53.314823,113.408525,216.311587,238.849488,228.721243,145.928586,60.200351,-145.663077,-188.366523,-85.247604,-9.856885,56.241357,52.210672,22.384998,-65.039241,-132.723486,-172.278495,-120.6815,9.647671,42.258852,35.321022,12.42497,-1.284014,-58.781126,-73.900643,-34.083432,2.591591,87.464185,133.531198,223.28968,228.202551,180.46307,114.286275,141.008417,250.607935,287.212336,287.515102,231.261602,179.513924,61.972686,45.515617,144.907468,216.056707,308.752565,329.457007,336.551431,304.833981,255.295811,142.137174,136.872922,264.965912,352.848513,409.195756,279.819495,209.590677,142.778553,145.909483,190.992553,228.411848,295.399892,285.097482,177.488919,87.54935,67.793408,64.631071,75.319368,80.726411,72.877183,94.663613,145.490485,131.572085,35.467899,-9.050172,-74.989444,-99.109904,-78.324617,-41.22558,-23.81394,-157.030486,-251.123636,-306.175226,-233.575193,-36.762997,22.680959,88.990704,155.263642,155.372581,77.51787,54.791023,106.419143,160.349019,282.949394,324.315979,295.23177,164.116767,99.253561,41.007036,52.910855,118.567983,163.126753,220.062966,122.316117,26.93987,-118.773262,-132.875308,-25.115036,66.042846,155.964489,127.90763:61.777456,-9.564458,-39.23014,-87.670274,-103.893411,-113.74904,-114.06991,-132.155563,-186.783371,-215.480934,-265.62024,-284.981353,-298.666771,-290.98402,-241.990268,-219.262509,-227.434007,-245.476343,-240.78698,-222.400745,-208.355891,-169.071723,-137.43072,-53.65914,-32.6013,-53.486561,-119.805036,-155.315057,-193.468319,-172.440073,-68.081772,-39.779563,-52.856839,-33.757496,-39.164989,-136.756184,-172.428686,-127.08644,-82.854932,-51.631887,-117.282915,-164.075185,-241.710963,-275.276811,-319.426272,-313.409113,-274.609689,-271.373754,-270.618579,-165.330938,-107.744102,-41.917215,7.723613,154.144369,206.183768,214.437378,117.601178,66.612375,-2.034426,-32.449111,-66.824932,-61.786877,-10.778901,31.213365,108.062472,159.157906,161.379766,92.598923,60.9888,95.221075,141.731035,189.430012,110.85794,43.887504,-50.533548,-55.020112,-17.562312,9.321568,86.342918,112.222629,88.203395,15.25649,-37.683669,-156.787503,-192.954109,-203.668599,-187.780102,-162.24632,-214.868989,-239.232503,-224.415799,-194.953984,-118.09573,-84.611875,-20.61129,0.766847,-78.893194,-255.695623,-330.966107,-432.023028,-433.955861,-357.126211,-302.020958,-173.732718,-97.633221,-100.357421,-152.197839,-166.42993,-114.727597,-70.373429,-38.416855,-51.238902,-53.633678,-24.454074,-40.271212,-105.490169,-104.17891,-27.723848,16.955505,132.933244,205.219586,175.237485,46.269441,-2.83934,-36.93315,-45.402956,-35.972314,4.085629,67.947971,-8.20655,-77.40423,-144.855257,-103.873651,42.722953,86.923945,107.220278,101.415191,74.522388,-62.046163,-126.648647,-115.571386,-63.619579,3.771419,3.915499,-44.618735,-86.801137,-87.849946,-80.513063,-78.378076,-67.138783,-60.459915,-92.153259,-226.15436,-294.958089,-327.974811,-304.116466,-233.084384,-169.119708,6.701998,53.3511,-48.198654,-208.668658,-216.344581,-105.430516,-28.255365,105.710647,153.85223,199.730042,166.929937,133.508358,62.997971,43.185487,63.313644,80.667054,75.085234,51.318114,13.754994,23.035447,-21.829574,-208.085634,-237.117312,-60.979822,60.638177,172.013473,121.507238,91.211267,79.429293,103.618767,192.653886,221.85136,200.68726,181.910729,204.665626,220.4838,163.439112,-36.159423,-96.590416,-67.858146,-22.33536,19.775646,-94.127979,-184.846477,-294.733074,-287.074178,-159.495335,-81.026576,-2.066383,11.612305,60.759727,100.180692,79.939073,-28.3758,-72.054287,-63.569426,-24.740878,23.023126,-74.646262,-155.182955,-304.987785,-345.116937,-248.927419,-126.045781,64.44997,74.19538,-11.954021,-69.350232,-71.468732,-68.626914,-72.268126,-45.190574,-6.140956,-3.924864,-170.358492,-231.823108,-263.243127,-254.959886,-170.689544,-117.429455,-45.203241,-18.258056,-23.80225,-132.065247,-172.713168,-92.061415,8.401225,133.460551,138.897826,111.810718,52.531418,22.254546,-9.085504,-7.561329,49.035624,82.727186,83.980155,69.464141,55.321352,31.020706,15.171895,-11.037182,-16.426981,6.830756,39.335024,104.70572,126.616587,120.057001,96.780139,95.609216,125.816035,135.999638,126.089351,134.185015,157.600198,95.44399,55.366935,36.562489,72.341897,179.78644,221.00917,306.565583,364.741382,331.866594,144.39086,44.75312,-17.471405,27.985405,139.77473,149.341977,74.935198,36.201377,63.314627,118.311152,124.570974,173.9952,223.569634,249.099873,121.905595,48.110428,-35.325379,-35.798367,8.092085,20.750621,23.624381,22.387486,9.243711,23.495329,25.003845,-19.13708,-24.769635,46.853697,92.127797,125.592214,102.197464,94.396735,42.761321,-11.769787,-83.264271,-61.421589,112.473875,231.539221,364.776461,303.186756,249.170871,171.63141,174.931433,264.835958,320.282035,377.372289,301.357823,243.713706,178.158014,167.152487,187.678746,221.408472,294.93706,309.888744,291.899565,276.870491,261.129123,217.152423,220.299504,271.959102,289.157952,297.417881,274.835098,234.674425,172.913585,190.646135,253.138348,261.715422,265.976237,273.874002,260.359505,197.719719,155.039186,94.739049,105.205021,170.37564,193.584942,217.368356,220.159453,197.03756,53.878548,-41.769947,-102.01272,-50.272072,41.225434,31.724856,-41.779492,-109.137465,-149.327573,-214.610469,-195.081971,-24.798474,74.222323,154.45197,99.512667,70.203587,44.830228,60.628954,134.286641,169.015366,264.918273,317.990171,288.633698,148.366549,103.015705,30.529804,11.772268,87.086052,152.290392,185.36893,37.005796,-61.498204,-167.608577,-155.059001,-46.474711,20.138936,115.226419,117.083732:145.89177,-19.139392,-107.269425,-154.623089,-107.430192,-50.066845,-85.839602,-193.54612,-240.163767,-268.310471,-383.576659,-429.413392,-415.398627,-372.411008,-257.875946,-213.201323,-246.043074,-367.1861,-399.815576,-351.264772,-279.832209,-163.038998,-144.496179,-142.68635,-180.202232,-201.272562,-184.717715,-158.817677,-90.180572,-19.794263,134.495786,131.71665,-37.815436,-159.827336,-177.095891,-145.347434,-97.651752,0.359097,45.767287,109.702317,6.213181,-96.943067,-244.237041,-255.927638,-201.084786,-164.9007,-128.433275,-154.668328,-243.575084,-206.966804,-178.598254,-177.867605,-153.10498,18.445516,132.127527,247.32387,106.455992,4.915455,-120.856094,-139.176532,-116.929487,-82.096708,45.102048,112.994531,139.686692,12.508481,-47.297954,-35.34907,24.677523,91.603441,82.688793,116.847626,163.295169,119.087538,-46.125657,-91.426246,-66.644823,-24.363939,72.661001,89.594532,27.116806,-43.426465,-72.273704,-175.46477,-229.205494,-228.047098,-176.535936,-90.36032,-54.766205,-44.219934,-56.979014,-54.853737,11.992241,60.216615,109.940518,71.423027,-94.502311,-185.884839,-201.381522,-201.744475,-187.783976,-129.462157,-70.028149,37.222704,13.907198,-20.028524,-78.066587,-85.618558,-18.655956,27.570969,84.489376,90.626607,12.936397,-117.774198,-161.326192,-151.16069,-95.08502,52.423763,117.758708,204.847498,167.682028,80.418754,-112.406223,-129.008863,13.959487,92.68873,165.79189,176.059403,157.447664,34.384097,-44.898956,-72.047895,-12.339299,87.565361,92.497781,53.731008,9.35027,-12.193758,-86.063852,-123.76911,-123.88437,-82.490625,12.969905,17.407925,-85.34611,-169.315223,-182.492915,-179.273347,-154.675172,-54.306287,-14.193399,-70.954379,-254.135571,-320.088329,-346.15017,-312.582015,-187.531137,-112.872692,38.145759,69.898282,-46.02046,-189.364063,-184.454162,-56.038947,11.424541,63.640023,69.675478,107.598658,104.424319,72.90029,16.979365,21.285809,90.969371,120.459036,133.762989,135.312883,121.299665,7.047331,-74.791963,-156.673373,-118.882785,74.958681,173.260327,258.102004,242.923907,237.246527,225.803864,232.00889,319.983006,375.507762,411.546529,392.507999,338.772424,256.419054,195.113992,114.93346,116.870468,170.404974,209.178702,206.32532,2.670149,-99.846867,-192.262506,-183.331254,-40.475118,58.630703,166.937065,170.790511,176.270271,173.371476,121.085615,11.066257,10.780971,72.402877,98.952913,91.145642,-13.036574,-69.877132,-165.147265,-191.246902,-103.439305,14.367713,194.827315,194.619893,101.462312,-13.220755,-66.015656,-55.511149,10.531795,128.214512,142.730388,79.759819,-23.021933,-65.373873,-156.709511,-194.182442,-185.190089,-129.35073,16.663293,50.076789,16.962322,-3.991309,-0.720471,40.700517,90.78341,180.89142,201.498837,200.006006,134.044267,90.320962,36.204671,55.388734,174.663477,215.832978,201.371487,170.12341,97.150769,61.39415,67.340762,91.069906,108.697227,171.48151,196.261386,162.887384,78.156262,62.972055,70.480214,85.258642,151.441183,183.544989,217.043739,226.877691,206.571377,58.647956,-32.543276,-65.522554,10.605514,207.962604,269.949943,287.143481,194.484198,124.226092,8.832445,-4.69134,59.27585,106.958405,196.947367,225.327832,160.856889,-9.605373,-54.339048,-5.33538,45.025235,145.382475,210.336162,281.284245,127.102552,-2.692191,-192.857411,-214.024406,-144.99488,-82.500182,43.903316,68.627156,24.110726,-84.792025,-183.283024,-338.152477,-312.088568,-97.31374,25.718321,141.423963,-12.735343,-126.427497,-247.83324,-235.760624,-137.915144,-67.485891,113.242914,174.357701,158.938726,111.184205,111.36821,136.317065,163.585361,226.67409,243.818542,241.502459,158.110083,74.13531,-54.745224,-35.361936,106.651974,153.474834,199.487707,236.577182,275.329782,188.722758,128.161078,60.112368,88.013613,253.111373,328.559805,358.912326,274.857634,226.869989,184.410795,203.519648,277.937216,313.213242,346.324564,325.006058,241.777298,175.385648,138.691544,80.130261,78.324608,144.754988,209.863038,312.059021,254.366574,187.129234,42.322293,-21.676186,-93.396287,-92.345881,-17.144943,28.494185,27.625049,-150.606564,-250.74147,-271.060084,-195.748819,-39.847823,29.103798,158.884416,153.022615,84.004845,-36.808539,-28.702111,57.643647,96.857202,187.831449,227.275552,206.900904,91.091002,40.786344,16.832187,33.433081,86.947725,129.679401,160.206831,24.965169,-64.803673,-156.15524,-135.396531,-38.900745,5.478058,100.063143,123.941064:71.726397,32.320755,-3.548149,-77.823671,-74.900144,-29.03161,-31.311298,-93.469059,-180.001564,-206.17138,-225.878655,-235.349006,-219.583305,-187.325412,-149.979491,-169.386382,-221.550572,-180.887487,-161.299612,-174.450748,-158.008035,-77.596084,-71.889272,-110.6904,-101.57692,-90.828463,-85.447712,-79.813177,-40.850364,-3.991223,97.942776,120.258369,32.105652,-44.525639,-49.948633,-87.949457,-103.921822,-76.571823,-60.283204,-100.940943,-223.393656,-265.525124,-287.137425,-296.40018,-318.838054,-317.660021,-311.658081,-306.922416,-239.657345,-98.344565,-50.942736,-48.03921,-40.430645,74.742025,148.881288,212.379336,104.613476,19.01072,-120.696279,-157.359342,-121.794045,-59.965258,45.396537,66.136529,87.776751,105.441625,90.107127,33.716897,36.621405,120.781588,143.134367,57.796646,-75.695279,-107.222034,-116.151682,-110.321556,-65.427015,-36.102602,7.837853,36.588341,48.746356,-70.662564,-124.060558,-150.633544,-152.34315,-169.315049,-169.397643,-168.841804,-175.736084,-162.371387,-134.984131,-143.038113,-152.167357,-120.532739,0.491669,49.323518,-4.261632,-183.089389,-248.015924,-355.229019,-400.239706,-424.273743,-395.247605,-270.680767,-191.402567,-201.406246,-230.799847,-227.289078,-215.532186,-213.294019,-154.310882,-79.489182,62.708928,37.693937,-21.172779,-54.070625,6.366538,166.18577,214.65324,251.064093,212.469411,141.910994,-55.84917,-127.187817,-150.603954,-133.089376,-128.208657,-136.201848,-125.402505,-110.866429,-147.111258,-235.667828,-205.837869,-33.813232,19.50196,10.474659,-26.662809,-34.873857,-73.469273,-104.883943,-119.73482,-95.464107,-36.801395,-10.563527,11.926051,-33.785818,-49.476494,18.93193,77.968447,98.449061,67.92323,3.374736,-76.377114,-111.912546,-159.527259,-170.327587,-119.314346,-53.666333,88.308827,126.768311,38.097685,-178.281935,-215.865786,-112.256427,-35.044116,74.736398,109.183733,116.159139,82.1829,98.274097,112.928439,67.401856,4.765499,48.540276,164.701041,148.505396,20.593714,20.416079,32.26892,-71.534963,-132.939595,-123.752062,-75.214999,15.855424,87.130475,115.072115,84.561046,39.435354,76.721798,171.876449,285.775479,246.79642,96.518441,17.432964,-4.879676,-50.193079,-76.474841,-153.256297,-168.607176,-76.165832,11.7558,-3.376898,-116.40603,-156.262942,-114.769572,-73.803942,0.103654,60.078618,183.132257,263.81956,279.116123,168.441732,83.464145,60.910529,126.764778,216.954818,103.941894,31.797103,-35.268505,-56.375909,-80.14396,-49.100675,96.243785,154.372326,112.556903,-37.252537,-88.014578,-85.846485,-43.42654,-21.202792,-60.756568,-108.073144,-113.772922,-143.169194,-224.741497,-252.194832,-241.658383,-194.338918,-51.295101,-11.416906,-92.36001,-206.39944,-202.458816,-142.75547,-122.536717,-79.208677,-38.84512,63.947877,121.552039,84.707237,-92.05053,-153.916718,-69.66845,51.744631,204.342024,169.3043,-21.288167,-60.614611,-9.61609,67.637088,66.305614,13.17423,0.662054,49.193546,94.526687,97.739187,69.269025,55.895738,89.405316,117.720615,149.95489,159.48147,104.515705,-59.405414,-93.860159,37.388342,148.399177,280.803118,285.644235,248.283119,280.822297,309.783981,208.421319,81.027146,-73.521577,-60.687412,2.507233,9.906893,6.593683,74.183788,118.703186,158.729849,175.15467,238.808984,265.808649,249.227538,123.30627,42.111713,-107.69625,-164.144921,-183.11101,-160.947522,-140.376734,-117.536566,-24.79514,3.347366,-16.023901,-92.731874,-127.780694,-103.764726,-45.567547,57.267012,53.726113,27.14609,-47.331799,-77.428376,-32.599415,42.484929,208.16174,259.700461,230.581002,169.205984,196.522782,285.749647,305.649639,322.29264,336.677496,350.617722,265.735747,182.773302,30.527203,13.768017,74.745857,100.616902,148.199732,178.886315,169.969659,97.416864,69.035999,24.813441,30.511982,113.206492,151.75679,190.778578,210.555697,198.846336,196.818633,245.262779,315.850253,275.614783,194.665839,241.783577,412.2827,395.10246,310.143553,179.635017,193.508639,309.172923,346.779167,316.966378,218.408759,173.413368,67.433595,21.877896,55.926699,118.048195,182.463565,166.347079,89.718561,16.109262,-49.384706,-240.481044,-275.793253,-118.038789,15.345102,210.146468,204.285968,153.958661,88.848047,95.647109,148.701086,157.767649,140.008507,151.617621,183.603309,123.573432,71.429853,-33.62545,-65.89755,-30.401979,28.836452,172.390577,233.694584,158.69184,-143.143558,-233.993628,-132.015229,-20.513014,126.871658,143.856759:211.455903,19.901578,-69.875977,-147.489466,-135.070359,-87.093879,-73.521827,-109.126211,-219.61407,-285.932131,-418.519703,-453.87915,-386.037388,-300.481495,-137.854199,-107.749914,-181.808975,-283.735038,-316.210213,-354.597594,-328.221026,-179.062111,-115.309266,-83.317886,-127.604185,-163.859617,-201.636199,-172.679705,-64.599364,-18.370206,93.962036,147.789664,119.341243,-39.641563,-117.437344,-158.352941,-100.82367,41.22766,82.32722,78.784486,-86.612635,-202.10506,-343.369137,-337.207392,-251.342298,-230.640489,-263.143346,-297.779335,-346.04227,-275.265885,-236.090768,-196.831492,-145.970073,21.526334,83.388909,89.012555,-24.060579,-85.098066,-196.531289,-233.925196,-200.667597,-132.853039,37.601485,105.318498,151.158522,91.141752,47.856338,6.21613,14.308585,33.355027,43.463161,108.469331,111.817119,53.621893,-109.269533,-158.232862,-95.360064,-5.289673,177.143172,221.243814,133.153024,-62.258135,-143.49534,-238.466301,-236.930354,-127.523933,-46.57567,16.059675,-68.943858,-92.422346,-101.583191,-107.578816,-59.002783,-5.939306,79.179891,88.047167,0.221301,-154.2375,-221.333178,-312.557435,-332.73336,-310.447517,-244.756639,-71.709499,-58.098172,-104.946962,-210.450353,-236.879441,-150.753237,-59.55441,73.929207,88.480053,49.916496,-16.385201,-57.705751,-92.462364,-50.222443,128.103146,225.396398,337.144178,256.137679,158.638733,-42.562351,-84.748956,-34.666898,0.677206,74.001276,129.883425,156.347459,1.559951,-95.733719,-187.168926,-136.762036,43.809425,98.400019,85.041869,16.221781,-2.5957,-82.513973,-128.153697,-101.945928,-47.05419,37.473036,48.430751,-6.860316,-97.683975,-122.265645,-102.364781,-63.277272,22.807516,56.833291,52.085949,-116.382855,-222.527402,-375.653849,-396.092222,-250.343087,-101.689173,153.384036,186.771366,51.728422,-110.477659,-134.952504,-95.05693,-35.269419,104.629291,138.705816,129.287428,128.536978,132.855683,83.338535,64.126379,123.516694,156.357575,163.375522,157.4559,106.386277,5.88272,-31.550058,-34.43668,6.315678,113.765379,162.89467,272.929983,332.378273,314.86237,233.34988,210.698542,257.21798,297.761653,352.094814,351.089873,251.818341,170.210608,166.410184,134.34136,89.298302,8.089967,8.083204,58.900537,18.400385,-36.834042,-133.599647,-149.998296,-53.990047,45.985406,208.910441,220.276545,149.540792,139.989253,135.373679,59.050575,37.815573,112.845678,185.734392,276.384458,168.52781,67.675944,-109.264522,-152.106898,-47.593695,86.50004,288.321487,291.260338,160.438829,4.071331,-51.057188,-60.847274,-32.376078,25.711481,71.548441,134.485403,11.787932,-77.684004,-204.624596,-223.666985,-142.026457,-59.972759,98.154586,133.079756,88.99882,19.141089,7.035176,45.494348,87.584965,186.225775,238.041443,260.371786,167.515239,134.101568,46.610885,-12.82703,-8.448013,56.814976,158.731932,165.088685,97.565714,27.961052,18.555592,25.308991,49.460505,126.105441,152.541488,151.691149,132.762482,124.675374,60.342058,27.316379,80.17172,144.777237,207.291924,188.887364,77.136789,-42.392848,-55.39755,61.584161,158.785965,294.18068,324.393027,339.877897,247.207566,167.215927,-6.734286,-74.840377,-70.040398,3.958694,134.609523,138.955092,63.082896,12.754654,11.293027,27.648409,45.370598,131.970968,199.286432,234.371547,40.32814,-53.654396,-126.303164,-142.718696,-166.556475,-147.706976,-54.983415,-18.264759,-3.707641,-96.087704,-189.064871,-324.862604,-299.242349,-100.603057,-8.113988,17.753675,-80.503439,-131.283789,-244.882139,-262.718647,-132.812065,-33.600385,82.964789,101.325509,127.088678,138.493476,121.103673,75.100741,78.519333,150.73648,209.894119,274.278934,148.237881,56.14986,-66.121614,-82.564417,-30.190717,32.476318,162.673241,178.931231,102.51869,76.555939,74.0262,5.807141,10.035533,191.154279,286.737997,314.905839,228.033427,198.311869,187.630935,222.37066,353.895661,394.795986,400.447838,396.945795,358.471201,260.453981,204.84524,149.902323,185.326155,332.95559,385.975033,373.853848,252.143775,181.565539,40.344369,-16.326783,1.492705,80.461149,217.271706,203.334183,20.902908,-129.476729,-176.347878,-255.02075,-230.626816,17.389231,173.895668,290.626289,139.854422,68.534141,23.723097,36.521832,92.973746,126.152153,188.047775,206.331889,174.795818,79.742913,32.505224,-28.107841,-30.60728,26.741857,80.997095,167.380121,85.491938,-14.833202,-185.563465,-200.936585,-102.815843,-29.438033,116.783803,160.073864:206.806379,149.896536,137.658376,113.578112,111.398112,75.884359,28.440702,-45.055728,-77.701491,-95.274568,-143.198074,-175.209417,-148.431275,-61.862922,90.161551,84.201638,-20.818264,-25.035501,20.322168,90.38907,92.427254,46.991334,38.849514,126.852317,209.958229,210.10265,214.022876,230.469262,242.873735,236.154202,201.612834,168.652145,85.344992,58.050003,58.880556,2.991644,-35.250636,-35.203247,-11.184863,-49.636318,-203.166519,-258.195281,-315.890758,-338.715061,-338.278678,-315.596938,-289.349148,-276.094324,-195.166492,-106.677373,-81.717872,-10.186097,55.366305,176.834744,195.418348,130.563756,-21.304661,-93.272777,-175.483637,-192.368722,-191.666572,-175.706376,-95.391059,-29.676554,70.203067,73.043612,46.782232,-45.734191,-71.585183,-41.708957,-40.536507,-89.815718,-87.112735,-83.017099,-140.961591,-193.612643,-216.089245,-156.169546,1.453655,57.972014,96.582789,23.469189,-30.977279,-90.206978,-84.458412,-49.004607,-39.267662,-74.483579,-156.126395,-166.68082,-106.039897,-48.769668,90.909422,132.017546,83.883315,32.934252,-36.291685,-78.987182,-107.17387,-201.569528,-241.749102,-285.711909,-304.954715,-324.035657,-319.862302,-306.024843,-255.088044,-246.376627,-288.80706,-317.006013,-259.669349,-145.383518,48.981588,-0.272224,-44.197405,-73.979162,-84.969838,-66.941463,-4.761504,133.041986,127.630513,83.014267,-22.992549,-72.920387,-141.512361,-156.595965,-140.800563,-117.124388,-68.011217,-23.356336,-31.717852,-120.242515,-163.416161,-178.171695,-150.514656,-68.833847,-22.899455,-4.773925,33.948863,25.756854,-25.819026,-23.82432,44.831477,66.466046,30.604539,58.479338,127.688866,235.643461,236.806585,151.32424,96.651385,51.798548,73.995727,89.910665,106.365489,84.313636,12.15514,10.607865,84.135284,103.522473,57.12548,-15.032438,-59.290178,-151.268143,-160.390977,-82.086516,-40.219046,-29.718716,-14.37243,43.26688,166.753421,176.306005,147.318333,146.81378,155.874004,150.924014,115.868389,107.533519,107.219405,63.210819,56.448206,148.345385,208.769563,254.570965,193.453265,157.93074,144.025445,150.703311,148.350282,149.932167,139.534169,102.107005,-13.858258,-89.453313,-115.794379,-184.423469,-219.549194,-241.582324,-180.957725,68.21081,136.427484,82.692417,5.158111,8.815701,95.247895,165.458421,265.240212,276.1439,281.093559,333.225899,358.849917,354.675182,340.322303,360.564082,405.460582,495.973612,452.971025,394.320617,298.149835,256.512688,202.42357,210.628862,216.847061,161.234076,7.654982,29.162092,74.797095,96.013682,77.791441,4.93357,-53.532399,-168.516868,-210.960177,-205.067107,-213.402222,-250.535426,-286.108535,-237.604235,-62.817119,-9.435256,-88.917198,-198.669737,-186.57869,-88.714728,-35.694315,13.221003,1.870325,-3.90309,54.195647,65.587084,21.075204,-8.327419,35.041076,107.414912,220.391963,235.91153,195.940707,142.895017,142.608076,128.775765,96.4716,51.411171,67.370487,76.407906,-43.836691,-83.149628,-103.63627,-130.407855,-168.835781,-144.548594,-31.915468,33.665518,41.487296,-158.306369,-214.302423,-92.672817,27.35072,163.393528,159.432267,137.663577,164.692593,163.690147,87.449324,30.44482,-49.491339,-66.031439,-93.955126,-117.81191,-148.403963,-102.319213,-50.245254,49.066914,59.098891,-2.459169,-16.686921,27.705831,-12.741691,-56.439499,-128.392531,-167.956528,-216.541566,-235.28608,-288.290855,-276.900889,-168.24118,-124.1428,-149.802393,-216.448047,-236.380228,-270.584193,-272.543519,-176.88862,-81.904263,-112.67809,-277.298561,-321.686323,-231.15108,-147.50263,-31.570923,16.924435,102.706108,90.777385,72.364154,76.007423,85.237102,64.242001,47.09473,46.919606,17.136466,-34.943137,-163.777863,-208.18974,-225.589015,-217.503656,-166.377057,-112.573303,-53.036545,-93.133325,-119.192791,-172.582879,-183.718018,-151.932826,-118.348546,-13.33262,61.988502,72.67126,96.131374,100.806814,86.492071,93.148368,181.99925,257.628974,378.773225,412.045646,399.123302,282.490388,202.603229,98.570288,96.068728,197.352593,264.531817,233.97694,135.599531,122.145704,166.764452,168.916881,101.820746,78.761484,78.69182,16.328552,-60.548442,-187.067074,-168.724184,2.03178,67.470226,31.333891,-46.281862,-18.082875,97.806094,123.517203,125.448213,123.881551,93.192658,72.459166,31.888352,-36.714902,-65.287477,-108.41731,-133.131072,-185.418585,-190.07156,-85.527998,20.806352,9.693724,-66.059657,-77.71923,-32.203109,-4.472707,45.428983,63.449425:110.091457,109.453803,156.986553,194.107943,173.101258,102.405758,56.756914,-34.209472,-27.624166,15.294891,26.292763,-19.696965,-67.96222,-58.159191,-58.133005,-71.576941,-84.748296,-48.413413,-15.202979,20.923574,12.286277,-22.126518,-13.874518,97.616174,206.224858,226.958411,223.541239,191.036048,72.563915,16.093406,-52.572106,-64.378838,-55.230197,-19.169067,-2.695618,-34.071113,-68.359791,-64.300503,-15.832869,46.498333,-106.05175,-206.191559,-303.437919,-326.849342,-352.539332,-323.764538,-221.029565,-194.665462,-169.997839,-37.902175,48.614281,121.686539,112.852917,144.28852,215.485589,342.579328,199.531723,59.894857,-139.237367,-158.633382,-84.025123,-58.73209,-86.358579,-85.840859,-35.77586,-39.522303,-56.18387,-52.535052,-22.069801,8.148577,-34.771039,-157.205535,-159.776289,-140.528102,-188.827641,-249.303161,-307.573053,-261.821638,-11.652105,119.067555,167.010973,39.350244,-13.293542,-86.791523,-105.625398,-106.537173,-103.429514,-170.808575,-293.160639,-297.080824,-223.473825,-203.799878,-171.734344,-142.172109,-87.994845,-55.961806,-43.074969,-169.117608,-223.175363,-245.494556,-233.152334,-185.040151,-162.122336,-190.359276,-283.372945,-300.740874,-264.205076,-239.30789,-210.706582,-203.434413,-185.497695,-159.804678,-82.769643,-63.745017,-84.538049,-150.168364,-169.475873,-171.46612,-158.813975,-80.13407,-21.719594,-36.504558,-92.421887,-114.582637,-158.116332,-182.672514,-220.88147,-218.723705,-157.750285,-84.163007,-82.538652,-108.019927,-105.730692,-120.840083,-138.192469,-93.17986,33.177602,79.868743,72.45128,27.546165,-28.009031,-23.782258,-4.374487,-0.399003,3.756306,56.572519,73.384085,31.727283,21.982763,30.050563,16.349517,9.212863,3.417901,-21.018213,-57.761214,-69.068263,-103.336987,-102.401183,-10.677101,37.868924,-25.363547,-230.703337,-268.147299,-124.075448,-10.04515,107.181142,96.895976,31.364956,37.991972,80.047905,140.109089,132.767712,89.491196,64.617903,19.592554,11.863566,-2.068757,-23.166362,-35.036959,-105.554283,-130.601325,-100.491719,-81.100214,-98.735229,-157.401389,-164.686429,-89.712015,-32.354442,26.04792,8.774377,-90.623166,-138.639739,-190.728456,-226.688941,-257.158128,-325.227261,-340.487719,-308.708697,-261.675614,-131.611588,-76.009747,-91.62356,-149.545073,-170.427222,-140.020892,-82.869436,42.151854,88.311335,151.123246,173.118021,175.904179,171.395009,145.411709,74.958712,84.97917,205.054095,230.480849,176.971329,24.611837,-34.836773,-20.66636,49.924422,160.255334,158.637839,111.929197,97.790383,74.557948,-10.746579,-24.336255,-21.244346,-65.68293,-193.676974,-202.043064,-180.395463,-224.659424,-294.007758,-364.700934,-321.983702,-171.263616,-126.84544,-157.038675,-250.273646,-268.950153,-247.071511,-247.289464,-280.376332,-257.586965,-99.559232,22.826844,37.473342,20.77298,20.649506,113.607796,166.069556,147.675348,124.035529,147.364892,159.31213,141.306789,96.033835,85.117809,90.246709,109.786071,141.893951,107.508601,110.188886,166.388318,176.708438,133.588856,90.186525,34.411154,59.305963,118.451945,29.508924,-38.041,-63.623003,6.496964,188.580133,236.521138,257.4901,272.270749,268.07067,179.578521,116.614084,40.575843,26.341546,3.372168,-5.473954,-17.644759,-15.501558,23.391145,179.691768,242.732106,226.812633,187.027049,145.985943,60.835237,14.005073,-22.34797,-33.445878,-66.821689,-94.684536,-172.505441,-187.667934,-146.620922,-59.984162,-24.027159,-70.218063,-145.220403,-232.949527,-194.89864,-38.548261,-44.921591,-101.93353,-177.652047,-181.657836,-109.045421,-60.225876,-30.34073,-31.768924,5.207581,93.067745,128.124294,123.966646,103.276601,73.36261,53.64335,2.164824,1.104051,13.021091,-32.539315,-86.722249,-172.792567,-180.824458,-74.768619,25.828746,157.231662,79.504534,-1.223796,-102.847914,-88.765,4.017844,32.867561,59.56149,123.643005,149.247899,112.054358,65.527627,38.55003,71.510648,189.277025,253.221984,312.20867,278.402837,237.528659,128.289389,92.557974,130.093999,201.438692,300.45952,201.58504,121.670077,18.382082,10.19383,54.352713,76.809322,114.002335,144.064674,175.558613,113.293312,77.149661,39.112709,33.602335,50.299593,68.692797,73.987619,50.227025,64.452056,120.8777,128.861105,101.344511,92.54001,145.236765,197.492069,249.98035,179.85858,104.593174,-61.41246,-109.131876,-106.31815,-56.067632,90.110837,129.66652,113.915356,48.361588,-15.541951,-113.230306,-91.359612,70.494355,139.628945:100.088838,113.061725,123.444782,48.061042,3.695609,-48.967894,-76.644322,-130.134224,-108.194184,-73.161638,-109.506183,-184.587557,-190.111773,-96.530527,57.109064,67.600266,-7.75236,-121.167031,-165.006384,-209.772283,-190.644262,-84.396313,-41.025595,-2.699321,14.894959,25.39346,41.869942,47.538221,119.608056,180.934756,242.665197,227.896956,150.037561,25.633479,-61.518402,-178.761939,-154.048243,-62.404705,-63.243832,-88.893949,-123.710617,-178.702271,-319.26595,-374.595891,-390.924297,-356.363986,-267.874636,-221.410682,-146.391543,-122.944431,-121.43319,-73.121054,-3.527963,152.51923,170.001462,51.833704,-75.785752,-89.668413,-97.190841,-107.616282,-51.409439,6.415165,89.030616,107.311675,113.12923,99.714636,104.616613,119.727267,119.020885,68.750495,2.288458,-116.335358,-87.554611,-44.524258,-16.601586,-57.453824,-132.91758,-117.781946,-44.00439,-16.004853,-9.229375,-50.332191,-58.790443,-68.671873,-79.462197,-80.910546,-53.225492,-0.675359,-70.966503,-110.496606,-104.729343,-75.614227,-16.573761,-1.993761,8.177001,7.515194,-82.595716,-247.22832,-289.578239,-287.342677,-283.590622,-313.343544,-306.76105,-202.612091,-139.387811,-172.289283,-277.931082,-288.549959,-193.620447,-128.12032,-23.172921,41.567701,168.664345,127.713216,80.796197,101.137109,152.611476,196.103133,195.123374,232.971066,209.786504,145.147692,8.413943,-23.192485,-22.543781,-28.322132,-60.007421,-60.007705,-43.707713,-78.525725,-122.315449,-239.638186,-275.459234,-241.139264,-183.911881,-43.498116,6.779123,-19.955322,-85.449776,-107.858095,-147.892545,-153.975769,-80.87359,-33.570481,-63.729281,-34.026329,61.400056,192.990362,194.141213,98.223776,31.782753,-24.075422,-64.643908,-101.11583,-115.310658,-87.872111,-46.277744,-44.743786,-5.397196,34.678491,14.284556,-162.734029,-234.206232,-227.680629,-146.947467,24.594762,42.455441,-18.437113,20.389704,73.364663,95.452836,67.645945,66.022405,100.139255,131.893483,105.654127,28.278809,3.562475,-11.969873,-69.141036,-58.38712,78.827264,143.048305,197.381143,253.046619,279.898384,261.34381,223.00185,182.852285,182.206026,144.069249,109.147175,86.398017,111.490302,87.075819,-31.131283,-68.980678,-85.890046,-91.192439,-41.979932,54.055941,55.735094,-10.674205,-23.140592,62.898311,132.790191,246.598792,288.312677,345.149409,393.792247,402.379125,315.696347,256.346795,289.258268,381.797378,493.136292,386.101639,325.654027,261.638412,225.112501,150.86712,145.502435,151.227228,115.464237,8.141826,44.925833,80.900197,44.936146,0.347598,-36.932451,-19.55503,-20.693274,-170.211261,-220.043071,-191.062624,-186.365011,-254.025715,-258.924116,-128.927487,-47.119823,-28.372118,-128.160909,-142.100927,-23.803655,87.485853,201.280732,167.554876,81.998621,93.349931,80.670891,-43.764452,-85.096614,-25.031975,28.521475,79.964458,71.236775,14.443213,38.223938,90.841051,137.59315,100.861407,47.384075,103.429926,234.10732,52.880635,-91.391102,-205.562567,-166.014538,-31.114906,14.408269,69.292927,96.561833,22.143146,-177.547913,-209.354398,-107.053101,-16.374725,125.702431,166.483082,223.201769,167.256784,111.613063,17.173315,-38.011732,-125.769971,-127.882546,-100.082865,-114.728964,-190.06432,-105.510413,-12.710447,63.916009,43.534131,14.729547,15.078749,4.538036,-64.135284,-125.274414,-230.188227,-241.232064,-191.683338,-184.147798,-221.272289,-199.550681,-64.065446,-16.004498,-39.398765,-125.145483,-173.231666,-194.151596,-143.708074,-36.301776,-75.89049,-134.403686,-252.038124,-261.411524,-119.710407,-21.219786,119.817362,172.393678,198.130005,119.661533,102.774181,140.29698,168.923156,176.935919,154.094783,98.314976,30.47624,-16.993471,-124.921601,-162.535556,-148.931858,-110.786401,-38.740846,-10.857136,10.186997,-19.869373,-54.047349,-125.639502,-118.375078,-11.081164,43.988339,109.152488,123.710836,133.196148,174.120558,201.490328,293.534981,329.338144,322.515781,319.787447,362.663494,365.435716,336.842856,315.787323,332.19479,296.757005,258.434437,273.644623,350.030615,354.11998,258.031412,191.19274,107.280729,99.268572,123.782373,114.023147,17.222057,-84.425583,-132.752996,-182.617394,-155.763867,-82.910604,-49.000695,80.647633,110.946806,62.505687,17.25019,49.677547,147.364492,167.598476,161.00056,146.435089,25.296996,-83.625961,-81.975918,-98.502272,-135.153247,-124.242404,-50.492637,83.918416,68.580005,31.754027,-86.618121,-144.817102,-160.909556,-103.947563,113.692711,196.634141:backward
414.042109,379.146841,329.690059,153.670021,61.201742,-16.119935,2.113021,140.08338,317.126317,343.433177,250.111249,186.42784,179.02447,231.594582,318.192081,320.046929,270.098089,281.90003,291.971376,215.718607,177.755671,204.833965,221.236973,221.665217,226.457198,190.921678,33.225683,-65.666255,-233.072076,-249.554084,-102.217695,-4.618502,67.723163,24.598342,-12.771334,-84.791281,-68.406389,125.141509,254.832867,454.664384,485.523781,443.33176,352.0377,310.593471,271.428694,320.435419,507.935913,579.832565,579.381764,410.623777,335.539225,250.636834,224.210249,257.023362,304.900351,353.402867,337.124352,309.924822,215.66011,174.085949,174.946708,204.903093,274.332027,333.057567,435.60154,391.898062,375.721609,417.625277,422.709055,329.667977,265.820053,240.624662,342.881301,384.668212,354.452768,286.425347,176.247156,163.406745,147.020404,129.424895,133.122487,147.465318,113.009962,-39.640143,-75.320329,61.625824,139.997999,123.64116,56.884965,64.100753,78.68455,32.562291,-114.886294,-151.992272,-152.69863,-150.509077,-184.55503,-247.572173,-249.566598,-231.601042,-253.475836,-351.479349,-392.818144,-348.157473,-149.688449,-63.406082,-15.894456,-33.710129,-7.110365,43.250533,73.562128,37.51004,2.15676,119.325641,177.78889,161.908487,124.227613,121.368151,139.046758,159.57662,109.672554,22.823182,-171.831744,-204.363701,-118.660114,-68.503588,-71.049496,-91.687798,-92.200281,-105.11102,-139.728342,-245.191411,-273.716309,-216.802728,-152.451781,-3.518308,22.630463,-38.933086,-119.128128,-103.612692,-85.402614,-123.662263,-218.463675,-212.935919,-76.205134,20.848339,-11.471536,-170.189858,-207.861402,-133.390854,-108.159129,-181.400131,-196.430642,-138.428103,-45.710512,-80.525054,-202.608787,-213.571408,-195.197254,-208.042207,-237.428353,-235.598217,-243.016929,-302.331717,-327.278977,-289.238913,-253.478311,-209.918739,-140.342183,-107.282358,-129.99735,-180.516191,-200.594245,-135.768151,-1.995304,7.464067,-70.864934,-140.559052,-146.852509,-195.908028,-248.653954,-279.245083,-244.64125,-173.173197,-112.340438,-87.133129,-67.472897,-83.590262,-200.834445,-258.628124,-255.176761,-231.478707,-241.283264,-203.802599,-154.29875,-117.44999,-119.263532,-61.672823,-15.046331,81.925112,134.871179,99.789141,-38.734601,-84.604272,-50.295503,10.125563,92.931944,109.42403,142.465811,104.979902,48.053374,-57.691293,-72.289201,1.067137,61.121797,103.503105,14.274748,-40.122236,-100.134949,-116.091034,-156.246699,-170.236285,-127.767976,-61.420376,58.183136,30.524728,-18.992169,-121.896707,-165.427663,-206.596098,-195.01256,-134.827548,-105.258985,-103.761723,-110.534381,-136.202599,-203.485596,-205.401474,-118.006505,-46.881467,36.256321,-69.376005,-154.809284,-249.32472,-231.517698,-124.489589,-66.890299,23.056307,14.115719,-12.922358,-20.821366,-9.335946,-29.413869,-67.612802,-128.722237,-103.328808,28.816952,4.529653,-77.656128,-189.829676,-170.599161,-93.058046,-102.676566,-122.006203,-39.617546,-13.534569,-28.141948,-46.064906,-27.375236,4.865485,46.902236,71.112687,136.808718,115.277339,67.341665,-54.807515,-86.464837,-8.847372,48.084468,26.944851,-82.42289,-89.162821,-4.988034,33.840548,63.022836,74.249867,123.323935,154.627255,182.966822,104.955963,18.920841,-189.23741,-245.857337,-169.745556,-77.874736,128.583309,302.868829,316.504984,203.231142,123.424701,-14.41046,-52.286695,-16.57707,44.897198,90.482588,-46.263676,-125.464514,-235.089166,-240.345369,-167.143731,-147.177665,-178.499857,-195.12304,-178.341823,-124.343317,-97.727526,-26.360842,4.612548,-21.797716,-71.540542,-164.897123,-168.287195,-147.903487,-169.829861,-216.487683,-280.790036,-263.058415,-140.524816,-59.593875,-71.849003,-130.584695,-172.722018,-285.012046,-304.895327,-210.362225,-151.611675,-143.761015,-185.379324,-192.098729,-209.412201,-194.085604,-68.155229,-9.082646,25.608291,51.114305,68.651836,2.614865,-87.363773,-173.93891,-125.764476,27.302486,105.166978,246.759838,208.158631,138.516526,54.86075,48.465362,70.412143,71.720841,11.337331,-15.810483,-0.119697,-22.548322,-85.58111,-199.313331,-183.846187,12.048344,155.236559,338.350353,256.185715,194.171591,125.910033,97.670567,54.071005,47.869424,110.840647,240.22734,286.526426,272.996405,191.850501,24.382802,-6.274522,-45.055956,-59.541978,-14.093869,40.149578,47.890439,47.421276,23.423545,-38.731776,-19.30551,136.206165,261.710174,258.979136,180.188352,151.930715,166.513443,179.748603,106.454919,37.527272:359.828364,337.231566,288.623871,121.268501,66.202586,55.742818,53.97888,69.896038,186.756478,238.029383,226.123348,169.013954,106.331921,166.67354,352.027304,364.615492,251.676073,205.622001,182.28695,102.820257,115.640683,218.363582,219.718621,162.581889,147.634922,99.447929,-47.346638,-86.4937,-134.83111,-172.84845,-148.550134,-53.261544,126.990658,127.078306,75.489922,-25.775499,-17.43373,166.380902,299.389692,492.699813,477.005386,423.270288,335.752007,315.079458,345.110091,376.763824,423.548574,457.970559,473.857255,285.88824,200.136931,148.884476,151.688298,207.54216,253.41273,307.581597,241.014427,179.598231,88.900604,73.11716,91.351467,117.091176,193.842971,249.624005,352.127111,322.459436,269.850622,201.347432,199.658879,223.873801,260.854361,404.966459,441.267547,380.889527,251.09266,210.99436,149.47789,140.452309,162.82463,163.53786,161.552464,155.761525,103.048396,-40.382409,-46.37698,83.405963,139.036979,175.422996,207.310539,203.530732,120.570517,60.570543,-46.5609,-100.378125,-179.736447,-166.428385,-96.41309,-115.378846,-146.958898,-235.25645,-271.025275,-281.726617,-261.997046,-150.89429,-53.950674,-48.817509,-66.858102,-78.219345,-87.361417,-81.7195,-63.357016,-42.658635,8.420145,20.671474,43.478973,151.916994,188.294837,182.15294,165.234358,120.951232,36.66211,-20.404792,-126.058983,-151.055182,-135.274267,-110.228271,-41.896381,-0.821659,6.556404,-122.804513,-194.880647,-295.493156,-283.812457,-109.418422,-17.069735,43.513312,7.197135,-0.858497,-9.828508,-33.399448,-87.039402,-86.967836,-12.256596,33.305263,70.691355,64.819239,45.000971,-85.510515,-164.437745,-162.476292,-78.990624,65.247072,28.780984,-12.699092,-11.341996,12.349653,2.435176,-27.514236,-64.037742,-67.955937,-114.744588,-165.549599,-143.505762,-98.698321,-126.630397,-171.978364,-153.642579,-93.374705,-53.385924,-57.664454,-139.334948,-200.621689,-206.590821,-118.680847,75.384723,105.475771,20.065091,-143.758588,-209.553193,-240.321725,-229.168877,-198.00385,-145.674725,36.819211,152.03072,137.455379,-24.506067,-126.416664,-266.645328,-296.361367,-296.378918,-280.010008,-235.8384,-114.478711,-55.06111,-105.465354,-161.419211,-103.216963,-31.618867,9.343127,-1.745679,2.053182,-62.933028,-124.659712,-110.099061,-20.965409,91.866901,72.973416,21.364252,26.504092,20.851488,-17.261444,-27.133943,2.870086,47.456481,171.821932,141.85717,36.111083,-155.284454,-178.360469,-141.952009,-131.430149,-112.730049,-62.672539,51.277519,15.965179,-24.624352,-79.709043,-109.709931,-143.020865,-116.415217,-19.299509,-48.484075,-116.014821,-168.796337,-136.426034,-72.662138,-59.223896,-29.543584,-12.714418,-8.036355,-6.226356,-8.599861,-94.801058,-147.016436,-128.805312,-65.650948,36.768221,22.756669,16.929836,18.530228,-17.646361,-81.596691,-55.904427,37.654214,58.394634,31.928534,-10.39005,-18.282026,-57.116125,-80.438952,-59.749628,-21.497982,61.86406,103.320706,110.027,97.551435,71.310043,79.796522,143.281165,223.25994,184.680604,49.489489,-9.731454,-19.987584,-81.012368,-110.045146,-25.048909,75.486968,168.763963,14.003198,-58.958416,-30.397931,11.674051,25.609769,30.433242,59.056827,58.137428,24.482084,-30.76632,-79.107233,-221.795279,-280.001669,-237.316681,-126.367274,130.493751,221.657604,178.448356,32.170203,-12.759574,-53.040777,-78.083713,-79.910947,-21.193982,59.985243,-77.213585,-161.458552,-245.219236,-232.064285,-139.790139,-97.766753,-58.543213,-101.187156,-134.059177,-154.43892,-151.346221,-100.791809,-50.187462,-56.937056,-126.174106,-223.735901,-218.391438,-203.738238,-159.855553,-147.564202,-159.154364,-156.048046,-66.237594,16.480775,-17.99955,-145.641012,-173.40734,-156.11228,-147.205339,-146.839255,-135.34223,-87.339373,-56.41758,-70.987449,-143.778206,-149.476277,-35.52128,36.164167,102.817986,129.335238,128.346209,44.834838,-6.152654,3.549469,63.548125,162.415673,181.05043,213.795017,251.263854,251.111826,154.933435,76.202086,17.602208,69.309244,219.310955,215.554798,142.403966,-36.564018,-103.21976,-132.281556,-79.645908,116.223719,224.746704,358.579581,286.690387,214.344143,81.041956,35.459113,67.682081,139.782932,257.683474,237.634273,222.433386,214.377294,169.045467,-1.056735,-63.576297,-36.627245,29.452126,88.315566,44.355726,40.295811,45.262037,23.27375,-33.751224,-28.336675,53.715099,167.162405,195.311734,113.482349,47.604978,4.442466,11.319495,-1.302427,-33.468404:375.901293,281.183419,208.656255,115.621754,108.544155,141.06911,151.596846,130.490215,114.332542,129.662511,137.438579,93.19676,28.005863,87.184462,302.186265,356.79945,316.918474,275.776421,246.003675,125.81775,125.153706,281.183547,314.642709,200.646905,72.7965,44.948701,40.773331,25.625665,-39.156145,-42.285557,31.631522,86.752813,194.804203,258.549838,231.703777,57.476634,8.734287,177.556008,343.295953,576.825396,551.648163,466.174253,293.671057,250.242935,242.852122,260.778549,337.970969,385.816594,356.231558,150.206425,59.779592,-17.183679,0.175237,84.741358,105.090553,106.740354,92.017922,62.038231,-17.184357,-39.926207,-0.101477,58.121676,160.019017,190.238387,229.618788,251.772899,256.015466,209.345785,169.27602,149.47555,186.686041,321.718642,376.172978,314.189017,103.850441,32.363521,7.181351,30.3479,113.419564,148.333937,127.641702,30.479593,-43.325147,-190.924049,-182.302563,-1.046917,65.482968,84.787462,97.468322,77.207088,-72.185908,-151.674285,-183.639441,-157.805393,-125.863705,-123.765638,-169.093315,-219.069037,-204.27483,-191.858565,-222.540945,-285.459633,-274.253247,-120.295446,-1.82863,-20.217048,-123.490047,-159.972319,-140.271891,-105.778543,-69.323807,-67.726191,-43.902701,47.554783,100.408397,161.188699,158.409562,139.339397,148.467565,165.212341,53.287711,-52.681928,-198.089176,-181.501351,-100.514473,-113.413717,-118.48045,-42.420647,75.604766,-67.306738,-156.113184,-205.904385,-180.287382,-121.946693,-114.862336,-116.883689,-103.652198,-109.668843,-115.322067,-102.754982,-93.031021,-96.989923,-63.39895,-21.907069,77.228514,110.224633,70.039502,-106.594878,-177.733903,-136.155329,-56.170172,38.344589,-9.808141,-30.546866,-21.235531,-22.319096,-14.363124,2.830652,9.878427,0.383371,-25.964468,-103.123536,-147.315062,-174.84657,-149.639946,-29.508226,42.192269,142.114073,175.911183,150.083396,7.940719,-49.072325,6.352503,83.130956,166.934938,159.437442,59.972969,-81.72642,-132.91015,-183.157034,-187.777848,-138.02495,-78.384347,44.041418,72.593122,55.426822,-36.928904,-110.300757,-209.365392,-209.528448,-158.993223,-134.158018,-133.05613,-154.969696,-157.524725,-191.292889,-200.431526,-125.23131,-79.090291,-4.887959,75.799722,79.408541,-23.109614,-91.742432,-98.539462,-38.627936,58.996926,98.777958,180.706164,91.341637,3.785102,-30.147416,36.936164,214.056415,293.381873,348.444937,167.898161,56.189415,-23.152071,-14.404788,-19.729227,-17.677026,85.146245,167.730754,216.428147,83.217567,35.746695,38.330857,51.602401,60.189645,84.499983,176.539355,142.426873,77.200782,28.205174,61.000439,98.151747,60.658991,-50.530704,-77.565617,-59.778474,10.663177,4.400347,-132.353344,-187.568079,-112.90925,-7.658709,126.812289,58.93534,28.562616,29.059491,7.815529,-49.441373,-25.590904,122.008868,184.160543,161.969264,32.462508,-25.363374,-98.415863,-77.427188,85.926157,155.308561,166.822527,148.789072,158.710225,121.423955,58.935182,33.225153,122.757965,296.586395,279.30336,108.561293,-16.916476,-63.191434,-118.374706,-85.680119,65.614869,117.043801,107.90369,10.319253,-38.205301,-92.889756,-85.257165,-0.249664,43.894773,103.11058,111.093056,35.696425,-37.456477,-52.647074,-133.184635,-159.952684,-82.518165,-18.651569,94.775029,169.650765,141.813963,-12.283336,-68.152204,-81.988485,-64.464674,-6.80148,37.93143,77.697051,-47.966937,-130.417196,-181.07124,-126.756347,58.225901,131.42411,164.897148,45.202764,-36.95262,-124.538515,-120.206132,-61.370982,-33.477336,-43.006749,-71.251828,-95.062199,-59.623327,-51.434337,-99.721848,-123.737829,-46.131722,16.382118,20.875965,43.223872,97.995823,133.870357,83.882558,-40.770944,-54.022014,34.554838,82.293663,59.108007,-36.718563,-76.019958,-130.642362,-105.799388,60.405397,117.887874,89.658867,59.392813,59.791046,-5.024104,-67.333411,-108.52362,-56.44242,93.096934,153.835189,221.954488,189.145281,142.844411,49.492376,11.942211,15.871879,112.608445,345.669552,201.725732,56.714269,-79.558712,-104.218965,-122.927549,-84.033819,27.984732,80.829162,178.804856,168.049198,119.456132,26.004848,15.824186,93.292401,163.616249,232.91115,62.373115,-55.444966,-143.301595,-125.092897,-70.734559,-36.499836,41.885524,78.714926,67.664151,-49.547161,-81.710865,-118.020738,-159.636569,-197.537725,-151.915955,-27.321019,-0.439754,-21.262057,-68.017287,-58.32745,49.612119,90.036471,-8.357756,-110.617693:503.878349,439.28195,363.930566,237.190291,185.223256,118.459312,120.188192,169.731005,174.559461,150.744593,101.265481,88.813518,110.877469,151.594422,261.063958,307.397232,323.250277,241.693825,187.081064,91.501184,98.68205,216.234278,248.069781,222.66292,169.253436,117.361413,-14.740282,-64.371825,-80.129811,-48.407094,60.236968,128.352393,226.409575,213.45176,168.340967,39.176573,8.603886,120.395974,237.511902,451.083645,484.377048,436.26936,341.705488,315.849736,284.444752,273.215304,300.25667,343.817423,354.903794,211.046611,158.229617,143.852188,157.237208,181.50585,180.063071,166.072134,138.614062,113.089138,64.777113,49.324405,56.999974,94.530785,206.753665,248.93018,258.834309,233.441188,239.228456,246.834784,242.100649,236.617372,233.861115,259.0994,261.009214,200.906374,53.155261,25.578097,78.909012,115.477024,71.282113,5.311114,-53.02348,-43.096698,-87.255619,-221.316028,-217.510917,-52.755144,17.14015,53.844285,74.056541,78.955863,-15.18847,-122.076431,-303.355007,-315.726024,-212.234799,-165.280753,-185.923481,-258.203428,-268.762985,-263.544684,-267.689569,-302.780049,-299.875326,-165.397935,-46.875386,-50.579182,-124.932529,-158.280995,-108.771895,-44.635947,11.113973,0.874598,11.003118,118.337927,166.549539,148.390403,118.693979,120.861338,120.971323,105.177617,74.066932,9.196279,-155.581555,-182.216441,-107.674334,-71.462745,-21.867806,25.430187,65.307924,-66.308741,-144.552681,-276.638856,-311.575468,-245.056076,-174.824465,-62.723519,-28.351856,-67.944159,-204.682721,-246.816826,-245.012119,-230.924243,-201.7186,-160.255026,-34.949295,-8.429714,-50.318696,-168.239777,-209.225693,-233.549932,-228.972271,-176.005121,-120.634686,-124.731973,-141.865365,-136.395112,-104.837675,-90.893123,-89.46847,-92.72478,-99.866797,-113.910375,-108.87309,-122.397247,-151.641167,-126.476996,-49.73944,104.970047,142.028831,123.635373,38.237997,-22.275083,-79.72177,-40.539336,91.131389,117.804532,23.084648,-118.399771,-152.577489,-202.750154,-238.919767,-254.636337,-208.465045,-66.705145,-10.88534,-39.334396,-133.943276,-177.009516,-229.597427,-220.639972,-180.953412,-188.128094,-235.452252,-184.581836,-135.167448,-157.471171,-201.601945,-158.29338,-78.126881,78.318184,139.872159,108.332995,-7.64271,-46.533889,-29.276792,15.078512,80.214348,102.381074,168.034983,153.259398,99.493879,3.876002,4.605229,111.79999,188.457153,292.835419,215.015744,110.153384,-82.782332,-135.793288,-142.619112,-95.109654,54.878878,118.228472,109.805726,-23.136001,-60.846308,-77.605349,-81.031163,-65.710883,-35.68642,48.348521,65.846535,63.247117,88.478588,77.22304,-29.101785,-83.242249,-124.179393,-107.470373,-36.342188,-11.862594,-48.090537,-195.78464,-247.326833,-160.838133,-47.406087,119.134091,107.142777,82.179588,54.791237,25.945616,-49.975842,-61.301225,-0.667463,58.274216,95.806182,-109.450197,-227.014711,-317.069244,-278.640232,-108.131821,-32.321889,26.339856,-5.995578,-17.653899,-16.570943,-26.537075,-10.914592,33.199353,94.478813,83.496645,0.335857,-81.004068,-102.611222,-120.20625,-112.269095,-58.527917,-28.296681,-21.273401,-128.589031,-176.567383,-149.366054,-90.785118,24.999435,64.751967,116.701496,133.324783,115.908427,-7.174489,-98.4337,-281.063153,-334.546436,-284.516617,-188.943028,54.974473,165.46646,130.424997,28.941915,-8.016732,-54.13909,-29.977887,91.431411,134.669359,119.792071,-24.003463,-122.940075,-298.049308,-320.107214,-151.93338,-33.558501,19.730817,-120.58126,-154.310442,-88.619315,-51.199647,-42.82531,-44.953911,-56.473304,-68.175676,-47.972786,-25.266121,-53.461534,-118.148226,-99.95568,11.968807,45.490358,42.382301,73.967818,92.567679,81.408439,41.171188,-90.038776,-127.960222,-48.923054,16.409029,-5.919153,-127.237109,-147.055977,-152.224434,-153.044911,-93.054236,-49.200229,2.743266,49.526897,52.019003,-76.155782,-173.595062,-218.025905,-146.20487,22.200603,74.038994,107.697142,59.658683,21.76051,-79.038327,-136.654879,-182.153202,-142.557902,-15.784543,-33.543504,-88.068295,-181.732829,-230.899162,-300.668327,-264.776689,-52.5967,75.958983,246.443197,192.129577,129.746238,35.246266,-8.275756,-8.827411,68.123031,217.306089,162.268167,112.939482,66.011729,26.177412,-60.797194,-58.27045,-9.375118,4.12626,-24.76217,-84.500414,-87.161655,-96.290352,-126.588085,-163.411219,-133.523149,26.598107,172.632527,165.051824,58.610391,52.577413,154.278351,180.987414,100.230011,32.037333:385.830824,369.405235,309.18936,190.917066,163.077541,180.785979,215.110921,258.372441,178.130177,114.224066,14.441907,-4.358816,67.65794,152.199892,296.508974,323.812832,328.28499,292.872869,225.390238,72.750291,88.32547,259.267683,289.725884,173.937214,50.31056,28.358637,11.161293,-7.370923,-46.688955,-56.738751,-49.696548,-14.926692,96.611116,129.512354,85.761271,-69.820061,-108.298596,17.754324,148.905022,371.373886,382.49189,311.241253,144.986266,89.168697,66.891896,96.297974,197.398086,243.395736,193.683156,-10.607985,-71.562232,-56.444873,-21.65451,19.405003,30.108623,29.639922,-56.919883,-99.527071,-152.086859,-174.030546,-134.544489,-50.567115,153.344324,222.841391,208.687642,71.484014,35.431006,45.230248,58.002331,85.662851,118.562488,227.150608,205.939637,103.099431,-119.763482,-165.784318,-108.213214,-54.426815,-30.920899,-56.606724,-108.089576,-173.97626,-229.604589,-287.876961,-240.394133,-43.659824,61.130452,210.084636,166.336707,83.716035,-76.899455,-135.770228,-155.197123,-96.444297,66.097866,95.260444,1.315039,-86.835353,-100.484044,-171.025915,-215.889426,-228.443871,-181.533857,-18.618481,39.340306,4.47512,-91.476266,-117.849438,-95.406696,-67.8526,26.126293,92.513934,152.63132,125.475719,110.154199,66.425782,46.573359,67.301652,102.752438,138.514839,44.930859,-38.933285,-192.735558,-216.998158,-153.928307,-129.135081,-101.378863,-43.277306,73.104315,-35.833669,-142.412876,-278.767237,-281.01502,-192.678625,-140.18434,-80.427299,-99.319557,-132.632246,-202.623398,-218.802794,-179.52114,-154.396964,-157.190358,-152.055779,-84.51263,-39.613015,-51.741081,-121.491849,-140.746004,-133.638495,-130.108851,-100.088049,-89.502545,-110.519657,-151.125345,-153.074406,-81.812181,-31.13553,-1.748632,-6.508095,17.274984,10.65416,-32.524167,-124.25494,-116.938288,26.002503,124.089255,280.402564,323.199765,292.972555,140.337511,61.696319,57.730232,117.459414,207.699285,217.284102,137.29386,-58.306842,-142.811132,-171.750092,-126.132551,-24.751415,10.431894,51.971112,21.520731,-22.113385,-100.112971,-133.503055,-203.361209,-198.723362,-84.283806,-48.242854,-98.162563,-118.670318,-110.371945,-137.452945,-127.41275,25.686732,111.813408,204.988663,236.070689,219.352991,78.102084,-13.69967,-50.866296,19.972993,200.606535,266.046359,284.800831,148.035398,64.679752,11.170153,64.079323,243.34473,330.515786,411.06105,288.463287,194.228235,54.527311,18.093042,42.89843,108.04881,272.227982,324.90871,257.63767,25.040071,-50.130919,-17.516976,39.178805,93.947635,120.639615,236.185856,223.025196,163.677723,76.343007,42.142145,1.078654,11.890994,50.232503,51.356902,18.258175,23.451077,17.602052,-76.947501,-105.893199,18.230853,137.643182,304.964202,273.421685,212.458614,83.789197,22.308145,-24.204341,13.896317,122.245472,148.894255,115.238658,-23.96107,-111.509019,-202.818539,-159.280681,43.39644,112.225726,102.664118,83.937548,96.596462,6.70225,-95.718324,-125.608164,-30.183329,101.97276,87.44262,-19.584827,-142.702812,-189.72956,-199.253707,-146.681748,16.947254,87.817865,113.15013,-60.837742,-147.543019,-200.620807,-180.482497,-99.61049,-65.216946,2.855734,62.553075,105.721311,-110.435868,-246.948125,-374.980615,-330.977966,-94.226884,19.203733,101.498334,34.943426,4.115949,-7.351783,-15.958073,-21.475727,23.028981,138.08805,156.543107,89.674853,-100.930525,-200.656005,-300.271245,-276.425503,-59.767181,81.803049,164.876482,-15.100747,-60.7664,-5.412152,13.955848,-35.155314,-66.401121,-60.313511,-26.504058,-11.080748,-70.076011,-86.464481,-99.964178,-86.962602,-3.920494,41.400924,97.414619,116.198098,120.242099,137.937071,130.760956,69.185106,41.219172,36.253634,45.011524,-8.240938,-77.962255,-70.783462,-63.777932,-69.008764,-7.218596,46.439672,128.063259,131.19595,72.294322,-141.433308,-222.844964,-167.315343,-61.158819,88.367676,105.351714,78.632276,-10.76661,-62.75034,-124.09781,-122.47607,-32.261141,63.234894,197.465487,-5.2448,-160.832324,-308.2375,-300.459362,-206.740861,-134.806261,21.439742,89.148858,147.423773,139.09292,136.841625,114.551033,98.419702,81.273799,92.584287,129.126684,73.967553,39.910473,7.19167,-24.664583,-64.686974,-33.156997,77.105828,121.638474,111.568794,31.426151,5.555698,-52.426637,-93.028722,-146.045262,-109.474311,70.632581,142.436638,97.137339,-22.277199,-16.070919,112.289647,146.961502,100.702945,61.482554:461.046675,407.633101,339.703328,217.680672,175.234122,115.371688,90.897441,105.018334,234.900867,271.14305,181.097801,101.518961,48.337446,89.813225,168.5442,171.61585,154.191803,157.604464,177.019394,214.353326,207.454786,133.893775,81.164724,27.38453,69.178781,56.374467,-77.047594,-127.577151,-106.310964,-85.733904,-113.277318,-116.576564,-41.071844,-43.381523,-98.844125,-181.284876,-149.367001,82.226071,225.765147,404.912764,369.027574,294.070714,138.44891,84.500706,92.604971,151.490095,226.643578,238.033125,296.980393,314.168997,280.012785,157.91649,118.963681,153.028708,179.861463,189.16451,138.940543,65.338319,-76.215576,-83.612578,-5.325335,51.717536,174.817421,218.635021,215.21507,135.107647,114.048382,124.055211,145.209312,188.85067,185.582881,153.429703,120.052152,98.823925,76.596958,60.654927,7.631909,-8.386636,-11.342019,5.311825,39.27071,-51.404149,-133.116691,-252.560251,-251.68238,-144.027829,-89.820305,-61.141071,-74.045428,-81.373904,-168.751235,-256.596042,-364.162903,-325.905453,-214.246283,-223.762712,-306.468086,-294.808067,-264.592783,-228.091688,-229.85693,-310.785089,-371.876183,-353.939318,-134.339327,-22.685189,81.49643,65.252577,8.023484,0.469016,7.823622,24.284927,83.132242,154.04978,185.528987,146.727665,87.363468,18.731434,18.626985,46.281813,21.227591,-39.595414,-224.169888,-284.771949,-185.436765,-69.510087,21.919431,-15.043062,-92.716039,-157.574112,-213.181529,-364.863323,-408.529802,-329.878752,-249.65756,-110.674783,-72.814306,-106.768159,-172.515896,-185.833525,-210.692687,-215.317408,-202.640552,-196.930574,-171.737828,-137.064952,-145.838367,-243.970572,-305.374158,-353.507323,-343.980505,-316.694318,-255.701575,-186.741532,-63.142496,-86.179156,-220.557148,-210.494704,-42.460072,9.468056,-5.146133,-55.959213,-84.42652,-167.664464,-202.865147,-173.348757,-105.676879,66.198009,149.22891,124.285629,24.229324,7.274828,86.643719,133.750071,96.059481,36.301441,-20.073183,-25.372668,-48.260015,-94.930288,-95.953438,-106.16256,-144.621171,-214.403466,-181.128621,-169.200545,-174.46161,-158.320732,-85.064944,-52.180905,-71.523138,-147.044958,-336.222169,-300.345891,-197.288204,-116.645796,-166.874249,-208.026477,-148.405857,59.496088,156.202564,104.192616,-50.573417,-70.488751,37.140763,102.600712,132.579866,122.532687,133.713077,156.652172,144.046868,72.793417,57.147219,122.172175,159.757892,180.132741,160.925048,119.580111,-36.067973,-115.887546,-175.440348,-138.98442,-12.950916,22.748323,12.439157,-23.369658,-31.63969,-59.107501,-95.023945,-137.420031,-96.042639,65.521921,115.689941,96.295311,73.266528,55.563112,-44.023822,-110.997476,-163.918463,-119.651466,2.367689,-15.7789,-66.7633,-147.095979,-147.112831,-14.470939,98.713453,226.221365,133.39936,71.893417,9.925231,-8.293515,-68.562697,-108.19216,-124.576102,-75.510759,14.351355,-86.462469,-173.124292,-295.4808,-303.649921,-217.978915,-157.464467,-78.915425,-55.606432,-41.246846,-36.399842,-65.880089,-90.430533,-58.233328,1.048436,9.360865,0.568073,-19.824569,-34.765093,-70.521851,-76.48966,-55.047356,-33.244129,-31.126343,-132.387928,-155.253486,-34.558883,52.973716,162.663094,207.738585,273.567723,268.068183,200.456184,117.163668,46.683277,-194.609036,-279.229771,-192.824602,-91.288091,48.387203,173.045314,223.437994,202.092832,148.33301,133.583622,186.895422,244.880177,227.494928,178.766528,72.858017,-15.257715,-192.661614,-220.748755,-116.402451,-66.872801,-74.885587,-76.134328,-53.146239,-8.769745,-2.310532,41.219193,93.125294,151.856387,128.308016,26.874868,-39.487104,-39.56479,-59.576491,-106.432265,-193.337891,-184.999756,-47.024225,49.817175,16.170179,-130.981541,-195.417002,-263.910012,-265.534506,-206.597622,-158.114634,-114.877674,-225.767385,-305.200256,-404.808323,-383.167335,-177.891615,-73.414942,-12.846155,-4.171751,-9.182388,-139.849892,-234.159696,-307.656047,-261.730916,-93.901308,-16.442409,82.733122,45.474995,-13.755613,-113.414832,-135.668275,-156.121667,-162.896754,-153.588394,-135.933617,-124.988178,-128.07413,-166.967151,-250.205296,-237.416622,-76.270234,40.08495,199.641976,122.769826,43.96849,-60.143785,-69.485532,15.692268,87.050835,215.336927,291.775991,305.703345,261.889489,210.624262,130.297826,115.186945,68.161753,28.919674,8.610912,46.986726,41.051213,-33.294922,-73.184461,-49.67749,32.319184,233.590464,304.304051,284.585972,226.695516,234.893431,306.837377,292.398301,120.323093,58.216485:506.368026,409.02963,326.847621,224.663308,208.964982,198.080974,215.410534,298.367903,252.561472,162.66805,22.064239,0.211036,20.804473,70.593272,231.068113,300.030985,313.057587,188.246342,111.357095,3.653994,0.205924,58.540206,91.850283,134.758182,64.700849,-17.941455,-166.463428,-192.761193,-102.81341,-29.505685,32.950019,44.014522,73.662597,-0.164144,-82.380464,-241.137624,-259.190595,-79.863828,79.677982,312.411232,272.198981,202.470857,117.22276,86.599817,58.366991,90.679056,199.064484,243.793875,215.753122,16.708239,-63.491703,-80.873971,-35.288769,67.342447,90.789679,66.1411,-30.070055,-85.025294,-175.214679,-188.971712,-76.051811,29.310686,182.232027,198.811013,140.957631,42.127346,3.093485,-39.367309,-34.604951,37.862448,91.580943,159.953751,52.458939,-42.238875,-158.262077,-167.571745,-93.817585,-24.32896,65.629229,69.153986,-1.932925,-186.537143,-284.945595,-383.332568,-348.103604,-118.995959,5.161966,108.246515,43.112027,-13.855603,-155.817642,-238.584085,-337.021406,-307.082039,-106.618769,8.419744,103.023912,-2.714227,-44.722894,-45.610774,-56.908348,-192.015409,-260.289936,-180.935544,18.259695,48.978425,1.272977,-26.605534,-15.148407,15.900359,88.766254,119.221418,102.857335,38.184381,39.885087,60.817717,60.805544,79.467567,97.887445,130.10184,73.533708,-15.22838,-205.130462,-242.78114,-182.629278,-123.750363,3.227647,80.409127,177.609275,20.202351,-128.090347,-375.434743,-404.68792,-244.955359,-133.86064,-29.52253,-53.824463,-85.817584,-180.082021,-225.897748,-228.541223,-189.585122,-110.908003,-80.233646,-51.580479,-64.946947,-93.894728,-173.791361,-180.917752,-144.586884,-141.804904,-143.712698,-134.220953,-143.430741,-163.314477,-159.214958,-101.722655,-52.303412,20.656694,31.788539,35.031541,18.321322,-9.935893,-113.150713,-146.796284,-57.601728,60.979714,320.674438,418.388897,378.718169,203.877002,134.572962,157.88181,220.32348,296.808272,285.850881,144.690937,-60.125428,-124.451813,-139.39553,-109.494663,-45.448279,-35.397984,-50.3298,-61.878338,-85.178144,-163.236147,-184.983849,-106.191076,-27.561659,30.605948,-2.12658,-106.725181,-168.946054,-161.037637,-114.057042,-90.592518,-21.464962,35.092158,193.326612,268.63107,223.449192,74.839261,25.33299,34.420146,84.564436,221.035069,283.648064,294.69848,160.636078,84.688883,-21.356058,-11.020804,170.191564,285.687866,402.342793,287.316692,168.083918,-48.979896,-109.240985,-120.206647,-66.615383,118.748573,178.705492,109.118155,-61.764027,-117.540918,-128.048135,-84.146913,30.312232,90.105303,225.962981,227.325425,160.808476,50.020146,30.835197,-3.630014,-27.678425,-9.953149,43.088123,120.268177,22.046959,-61.801258,-150.487071,-136.289655,3.313261,109.357545,256.640212,208.424696,143.851389,34.088263,-2.812858,-23.302998,5.978971,126.907621,173.631235,127.31183,-108.373585,-244.349283,-377.000162,-319.82872,-48.648087,55.511311,94.063886,19.870196,-13.278225,-75.893069,-116.244869,-99.890588,-18.215253,86.996097,60.953902,-27.383327,-119.838959,-181.951943,-254.38683,-231.47442,-96.349232,-24.423226,-1.97249,-141.126757,-193.172023,-214.681571,-195.464748,-93.313631,-44.967036,7.942438,35.793647,31.448459,-107.574374,-194.570379,-351.552624,-387.484139,-293.768465,-185.502615,1.388307,49.623055,41.276418,3.129613,-27.197803,-36.923869,27.747418,210.657449,253.855586,179.613427,-57.493425,-185.094996,-318.917558,-278.130206,-34.719337,68.334253,111.478882,44.469977,1.130556,-69.797721,-79.895984,-36.364547,3.448964,87.804266,116.332688,86.535118,-35.755561,-92.834851,-124.499005,-92.080735,20.431544,70.293654,114.168752,112.992851,104.880061,62.85147,25.711983,-48.427766,-66.767541,-14.934599,34.854494,13.970105,-139.995145,-189.385908,-198.577191,-168.618381,-71.550112,-26.097853,82.257514,173.099162,129.554913,-124.612896,-233.825985,-228.711005,-139.43219,55.794005,133.00024,190.745799,39.147714,-81.189681,-240.882497,-240.928668,-129.231451,-53.360272,61.739508,-0.170239,-80.118925,-225.872042,-285.585937,-308.479389,-240.986062,-50.094313,34.663334,165.711444,140.919938,70.551307,-67.347386,-90.108822,-0.81718,82.517808,234.840186,241.69767,157.794357,-63.333094,-121.739068,-42.516852,50.57473,147.868566,128.747068,41.835701,-8.223178,-29.384719,-104.139855,-134.893166,-64.48168,46.795319,289.900267,360.512792,301.73813,116.922607,83.357012,170.392217,209.693324,195.454815,169.990593:380.293046,441.3928,392.357934,228.901729,166.250248,92.886261,74.412461,122.363497,257.394707,302.013798,297.11961,247.41335,82.673426,20.079668,52.0854,123.488477,221.018597,198.540882,164.483652,72.7141,17.769267,-79.449075,-113.951049,-116.010717,-91.54516,-139.8187,-293.339309,-303.120592,-179.850742,-155.737769,-264.31094,-298.875616,-228.239508,-213.066311,-235.091139,-191.224304,-137.278327,-30.435415,34.062406,176.668828,208.047009,176.268764,93.032269,52.703059,40.089251,105.121295,273.294765,299.905235,271.73845,223.461008,186.140155,118.006992,82.363314,-22.415857,-64.185801,-46.722012,-31.111846,-65.591089,-113.931862,-126.778302,-176.454935,-174.703975,-25.553669,80.384617,141.933156,21.254822,-22.861972,-26.425277,6.888639,74.67884,75.400385,39.158654,-21.970191,-57.679582,-60.695347,-17.102878,79.057195,77.64817,-0.807985,-12.116977,19.176373,-30.349383,-74.864279,-107.526125,-98.446019,-92.049889,-97.928302,-112.517108,-179.652097,-210.236716,-187.369555,-174.480675,-199.166637,-196.838612,-124.725958,-68.373452,26.580904,58.912675,87.065925,181.786515,199.39642,107.731799,39.147587,10.328102,143.836928,215.468917,243.242803,196.577707,108.409933,120.012588,224.02565,266.613906,301.10614,313.317195,302.869568,181.401338,89.973146,-16.384828,-25.336772,-44.653895,-159.45763,-245.344849,-299.442872,-250.504328,-152.442233,-142.574559,-173.964614,-171.645839,-104.835732,-173.748515,-283.615082,-460.31621,-460.996679,-315.441463,-219.826029,-76.528471,-90.784007,-160.458102,-293.34583,-304.107283,-251.934811,-225.93359,-197.995432,-192.441068,-190.892698,-208.660871,-215.798089,-241.180627,-263.710022,-293.376625,-307.866291,-314.864251,-205.485033,-123.083208,0.377755,7.584143,-76.018807,-98.379044,-7.52748,50.258086,73.086373,55.317901,48.669478,0.50699,-18.489638,21.072823,52.376757,129.383594,299.685492,361.296473,349.820934,303.922225,223.754317,203.89988,120.271529,45.148802,-59.445344,-101.344725,-117.153484,-125.17217,-135.33572,-198.397256,-246.906262,-329.860937,-358.62487,-352.926727,-264.104102,-220.871043,-218.744479,-233.462906,-304.228927,-362.779103,-413.368026,-317.939676,-241.562466,-152.295006,-164.689903,-195.132757,-157.88453,13.503113,113.187115,105.995976,67.840012,56.333341,60.72963,74.011624,95.559103,111.531055,164.000323,127.4515,52.423626,-92.935978,-102.583852,-1.57428,42.606579,43.016433,-17.625339,-45.264281,-22.798328,2.829148,14.247356,32.813471,87.825345,71.265377,-10.88889,-16.615165,-9.612889,-47.797627,-86.747518,-113.798555,-83.274162,15.740387,30.364589,2.239577,-19.295366,-8.439208,11.216753,13.937563,14.187546,25.298311,62.57998,9.087791,-49.532511,-152.496286,-161.821577,-57.122449,2.304087,16.344149,0.973244,17.794682,24.706082,-11.565876,-91.333853,-110.780878,-151.564503,-155.791285,-93.700776,-128.809811,-203.25551,-297.39132,-278.64117,-181.770182,-147.109972,-149.030712,-230.473838,-260.713359,-256.450155,-244.720098,-195.87827,-160.536437,-138.003512,-144.759878,-154.542253,-176.362799,-181.115319,-176.240773,-179.400989,-191.438477,-193.649492,-177.307934,-129.554054,-87.962591,28.759774,66.47307,74.773083,91.789932,168.905197,177.315085,99.197404,31.843852,0.035662,-128.777003,-191.824569,-196.469283,-142.406499,47.363751,264.229635,314.870299,273.030643,228.438333,217.409825,254.373675,319.877148,334.156203,335.646657,250.615919,176.228678,33.86021,-5.326912,8.649205,26.674419,1.465775,-16.116433,21.371154,182.875847,252.675291,263.04771,235.58868,222.538473,227.336085,178.045806,54.648664,4.639199,-72.280729,-102.804444,-117.163236,-100.089476,-51.667867,-83.40966,-125.866462,-178.559031,-191.122067,-221.856936,-229.569627,-189.095842,-138.228144,-72.464566,-195.21455,-305.872439,-425.160367,-374.200277,-178.84373,-136.382665,-153.807234,-166.453791,-203.037613,-331.348916,-371.713897,-314.651501,-227.145494,-62.047294,-36.793573,-93.831671,-144.394283,-140.896953,-114.024884,-112.610253,-120.679725,-115.09668,-112.688905,-136.975421,-137.110702,-119.643113,-129.971136,-186.869362,-183.957102,-75.29076,-18.275417,-11.248199,-102.193986,-133.903853,-124.750082,-83.549962,29.188159,61.516699,96.114843,182.465719,200.738503,122.97705,59.778988,-11.502744,-3.490229,18.659034,1.351552,-32.469613,0.519051,5.968765,-84.894698,-151.128494,-164.367945,-98.406584,37.134957,82.204124,110.650915,236.639811,292.439342,278.964079,209.536052,44.091532,12.524512:381.753244,384.700541,319.419103,123.386339,29.383767,-62.290623,-54.474808,89.016184,355.501259,441.312142,369.196865,250.747989,83.804172,69.72779,117.482554,155.191319,206.931545,219.932597,236.357209,240.476639,205.121041,113.733228,81.549876,66.059242,29.163329,-42.765243,-199.223107,-229.494653,-235.220778,-257.583575,-302.987211,-263.903211,-80.133712,-28.157584,-70.521131,-144.646777,-138.648695,-17.026716,85.65585,296.073231,319.251934,231.531705,80.258094,82.857358,182.86027,248.410326,367.725458,403.481254,390.6102,291.121833,242.817637,143.8397,95.489202,75.235003,106.454098,191.525549,171.982381,94.10013,-36.403124,-26.623858,52.335335,65.388834,83.204761,139.586266,303.433408,332.804705,309.92817,289.314332,285.315076,247.099575,205.380628,127.555088,143.306761,169.999988,188.956028,163.922545,54.908597,13.857242,15.966936,22.98819,-2.630204,-28.603185,-44.139598,-99.046062,-110.773369,-25.896195,30.250309,0.976152,-157.893808,-205.92975,-232.182453,-255.209341,-275.225019,-235.567683,-198.748015,-245.92525,-325.028203,-236.009679,-161.83198,-81.495377,-87.128925,-157.946544,-208.384305,-241.661617,-98.154548,-2.79058,71.98051,42.058675,1.393124,23.60133,72.431087,79.785055,75.408201,67.613441,81.122698,57.63599,10.705503,-16.7279,2.358632,-26.541839,-132.993378,-169.848408,-203.540088,-214.109966,-224.321014,-224.236045,-223.935996,-214.316726,-154.70014,-129.43574,-149.493143,-236.976027,-280.991441,-252.352612,-171.200939,14.161579,12.906941,-74.301187,-167.716277,-136.07573,-100.151991,-140.756041,-243.612409,-244.869677,-136.098307,-32.17087,-10.839277,-66.512995,-143.646496,-264.534678,-277.226413,-227.177995,-96.326906,-22.565283,48.841322,12.950831,-129.718047,-147.865305,-55.616707,-30.894423,-85.988038,-115.459679,-107.071082,-124.18186,-141.954853,-135.153297,-118.4236,-76.935605,-8.295283,34.291077,104.864895,104.46516,48.495511,23.665782,-16.792756,-45.875516,-111.53094,-132.977894,-130.474225,-136.502743,-152.426163,-212.873481,-248.09895,-266.671604,-218.245287,-208.597299,-177.309469,-142.764565,-123.141569,-153.275594,-253.701631,-297.436797,-288.763345,-167.561095,-124.806389,-160.717468,-199.226233,-133.915504,-32.974189,133.069886,111.616336,55.294422,-5.209754,-0.399234,25.10964,31.019649,33.536564,69.573498,193.125169,183.907686,146.766249,104.135802,92.15342,69.612332,59.545114,36.148737,28.674966,39.987489,32.057863,-21.614822,-153.354779,-170.373263,-125.489865,-89.433324,-5.316746,11.858892,5.928096,-14.828369,-59.281818,-191.914219,-251.603473,-282.223345,-142.712706,-55.281281,2.869118,-42.124352,-153.521898,-167.440194,-114.409824,-64.833402,37.538932,47.916436,18.899608,-48.200878,-58.433607,17.691982,74.303385,102.188257,50.805457,39.940702,58.640984,61.43074,0.683367,-68.823207,-209.02836,-198.811669,-32.398501,-54.065399,-152.017888,-300.036519,-310.13991,-272.181932,-265.522346,-227.9548,-130.447423,-101.871899,-117.387901,-157.399502,-202.105006,-175.883654,-132.972137,-141.268445,-159.41635,-136.502666,-112.402325,-90.795686,-102.147183,-109.546883,-92.222548,-95.285723,-153.836548,-136.954932,-19.487767,20.638972,99.863829,173.596584,269.503512,248.883813,167.30617,107.011927,54.692634,-107.871934,-174.839981,-154.201395,-68.368733,145.950823,289.283096,313.007398,326.430025,317.825251,221.88527,161.917296,107.313683,130.447328,221.452385,223.019468,172.770039,-9.599378,-85.427729,-104.341357,-89.419674,-71.736369,-18.839142,15.219004,74.662765,97.944192,188.912241,252.595588,304.050226,276.896962,162.455898,54.78675,26.941359,-47.994727,-108.608607,-164.649094,-136.933203,-52.975075,-82.773982,-148.535184,-257.340709,-277.69989,-275.225176,-251.979301,-180.518883,-164.699956,-206.525138,-232.90563,-237.349528,-312.172671,-334.827504,-202.298007,-88.986992,59.294284,23.26066,-45.661193,-182.224634,-226.926359,-205.895099,-142.717532,-48.750467,-25.791046,69.202136,175.336428,189.026712,122.501259,70.704262,11.007808,-6.108225,-56.333496,-65.292105,-35.516708,10.527167,-37.632207,-208.269788,-207.301968,22.105414,143.185444,189.133023,64.415188,24.276779,-14.182978,-28.497145,2.940203,28.931086,85.111324,215.139834,264.022233,233.339509,176.53218,111.582834,119.734263,109.425253,58.276079,-55.166161,-51.018961,-30.453218,-51.780166,-74.276132,-30.112064,41.040524,187.911605,229.472555,206.329599,172.406724,173.182765,149.010335,111.231009,14.853129,-8.202441:413.663594,392.009721,344.334725,242.531111,179.174305,85.860442,106.951724,227.424255,299.535341,303.413273,225.949808,153.761062,65.692288,69.931999,133.532231,181.633022,267.69399,223.159677,148.929188,44.994113,44.497041,3.725916,-66.604289,-115.923359,-32.187928,-64.000177,-232.775656,-241.891535,-55.994549,24.864024,-7.836681,-52.559959,-52.336372,-109.528716,-155.574467,-137.156789,-85.653591,61.843423,157.249256,307.366486,289.360682,240.602693,154.518929,105.784732,33.66667,55.34786,187.7977,255.391841,308.440486,224.318143,152.625554,-4.836541,-45.129256,-7.377579,9.34044,-19.133833,-77.497351,-127.181604,-221.590409,-242.067763,-195.613752,-124.16933,38.771792,79.147285,18.990336,-103.978544,-119.666027,-71.855484,-39.136535,25.84432,52.912091,103.851867,47.653847,-32.986625,-86.059529,-33.52934,77.661429,82.365082,18.344358,5.757799,24.294973,22.407902,0.233584,-138.64446,-194.334469,-80.71331,24.9293,73.209651,-55.696245,-116.184621,-154.617553,-167.92039,-232.368355,-205.508988,5.861624,74.795985,27.195464,7.358854,40.463911,13.823519,-48.988153,-129.246976,-151.644836,-181.538679,-74.103015,18.758458,151.037616,150.321255,99.261596,120.106181,229.029336,255.384073,209.34879,150.595516,147.093412,118.828033,87.412467,65.872908,65.092996,22.790459,-87.634503,-167.05895,-258.346428,-234.720613,-145.860735,-111.458547,-39.858743,-8.585337,32.219136,35.490767,-17.428561,-227.933689,-293.789316,-207.434728,-116.689894,-19.786555,-92.879016,-178.261953,-288.313021,-277.600451,-211.187136,-192.676212,-221.454904,-244.271036,-186.869376,-98.777959,-120.88171,-246.106726,-281.078167,-240.978806,-210.709302,-187.704955,-159.584537,-153.409526,-171.889318,-188.1474,-212.125246,-200.216896,-144.123646,-117.196598,-69.356355,-14.282904,22.193206,51.110993,39.534422,50.463792,84.429181,200.971021,306.404115,298.488355,185.813452,133.288792,116.972111,151.498683,190.383225,154.876274,17.512879,-81.704306,-85.08959,-37.09463,-42.257209,-170.090086,-252.049183,-321.43194,-239.041813,-181.114472,-142.959765,-162.50544,-144.199698,-107.317145,-147.273447,-231.710234,-342.924267,-270.059056,-196.34377,-91.476887,-83.320554,-91.562596,-80.757204,44.954401,213.388057,206.871042,75.997077,42.712383,92.613726,124.182074,111.747752,103.431968,148.480876,193.231685,185.452216,69.86105,-4.833056,-67.830967,-60.958925,-20.937285,-5.715057,-45.089381,-145.310007,-149.359512,-94.493855,-65.532251,-1.387826,28.319256,22.231604,-43.836232,-57.998765,-75.249469,-102.692359,-127.197778,-91.943214,35.235779,80.358928,53.270272,-1.047175,-29.833395,-97.098813,-109.133424,-115.902971,-107.451646,1.739608,83.649207,55.017511,-85.460152,-136.809832,-67.38898,20.865079,94.075837,7.348071,-24.624563,-27.169647,-41.81998,-111.328378,-131.167383,-119.458938,-100.849424,-102.46007,-229.35636,-314.443094,-399.207581,-366.50854,-228.147115,-172.915544,-94.674047,-29.968927,-11.204583,-63.817854,-133.446565,-200.235269,-164.465661,-94.227938,-109.505617,-168.573476,-205.226683,-236.443194,-274.569262,-242.412699,-108.502201,-81.571501,-145.954899,-161.228577,-149.152774,-149.292012,-152.865306,-105.121848,-39.455865,85.528739,104.849775,85.92216,27.819633,-47.352318,-258.990941,-318.747474,-243.874551,-142.861724,15.456658,62.255517,97.15735,170.919884,163.605076,100.633553,99.062383,155.633853,169.326902,128.907386,40.269812,-11.469819,-71.739455,-60.757663,1.675617,22.876965,22.291568,3.507582,15.672167,85.60161,97.890695,54.782128,36.450965,86.645297,141.229555,134.574224,-23.642894,-58.335753,-38.596332,-29.905978,-13.918887,-4.709073,27.008315,82.569822,78.664377,7.104981,-23.35623,-59.463861,-72.693827,-79.20534,-66.769254,-64.266765,-146.729783,-190.085175,-229.559625,-217.355128,-119.150328,-49.64898,50.856226,12.046578,-51.426137,-203.163145,-268.158549,-268.205795,-197.32966,-50.924397,-8.64469,21.155396,0.091291,-13.652035,-56.583015,-88.247041,-95.419897,-55.256791,11.050058,-46.991712,-82.296186,-105.47767,-119.003704,-164.97294,-176.987697,-113.544945,-28.124115,89.949172,-35.552247,-116.9987,-145.647761,-108.06217,-22.801422,26.351469,145.923873,217.135427,212.164358,61.360529,-38.63623,-54.780283,7.551836,32.303281,-18.485951,-94.71859,-25.27791,17.078743,-50.201965,-130.797319,-148.221452,-59.170006,163.084223,248.351264,235.154593,220.433033,259.538372,361.384288,353.936371,201.137827,123.588634:backward
-28.379418,-147.478381,-181.615805,-133.260686,-105.631313,-175.140962,-251.008811,-323.153635,-186.062028,-85.547254,66.683075,122.728818,210.457554,226.622414,175.260918,124.40919,64.148079,84.486559,105.022338,116.413752,88.21337,-3.303487,-39.975142,-68.96203,-55.157381,-29.797321,76.685848,128.393684,139.184186,108.023182,64.672649,90.76452,230.748413,303.934681,293.613416,236.785681,203.692209,148.629686,114.832372,43.455678,66.37968,104.934798,145.338985,127.478837,65.893728,57.387239,35.619385,15.933757,31.7721,26.125552,19.628713,101.227831,147.641979,107.574961,33.537511,-88.418698,-47.99241,32.806753,232.997821,288.924806,211.026233,147.031109,146.650225,177.068985,167.187634,68.111877,37.120996,39.951351,33.988033,-55.968081,-120.214803,-160.147246,-105.468451,-109.13362,-120.207541,-95.13787,-65.988173,-70.937749,-94.138162,-111.959136,-61.778963,70.636902,76.322919,-54.247091,-135.384226,-210.830838,-203.830794,-146.832945,-75.119325,-43.994925,35.968463,65.530957,38.028962,14.486309,12.286559,23.498129,89.161013,169.90651,197.128243,220.146005,205.450848,191.310866,217.545566,249.807152,239.945945,257.860105,347.193799,400.511855,472.740153,483.79972,467.871943,442.969123,356.332231,284.715365,292.397064,316.784605,281.361921,156.416076,111.379556,112.711064,168.953092,167.586878,148.777059,162.900717,141.630633,69.607082,-93.184102,-116.509583,-14.775309,104.591502,134.968998,188.146345,211.437706,220.046175,194.52027,94.157424,65.894642,110.259252,229.635397,246.498188,152.724062,87.835726,59.999681,99.185048,209.866028,295.724866,320.521683,335.526368,313.295479,212.210494,157.086669,106.939745,131.273688,141.879704,139.607667,119.24628,31.073142,-19.389305,-100.293653,-132.395623,-195.185991,-211.972973,-156.954508,5.333834,24.188987,-73.709933,-106.374236,-59.004654,-14.800686,-3.999846,83.496461,144.532269,146.603539,82.917653,9.932214,45.780099,159.935775,162.93502,143.655615,120.245983,92.29792,-4.394869,-47.674921,-34.670189,96.819503,147.17031,211.756873,238.825986,247.069262,230.857888,147.239457,79.126807,0.499947,48.053587,79.219806,74.643169,43.945251,9.027274,3.136977,-11.837983,24.085812,40.193662,53.778206,66.28733,32.504054,-41.672684,-241.363087,-301.773076,-228.550356,-62.918038,-39.04744,-81.970699,-96.921886,-64.790164,-41.542084,-39.811285,-56.133502,-63.20006,-53.433105,-27.257732,-20.248479,-65.86112,-188.516672,-221.755473,-233.593412,-264.18848,-242.309686,-117.52361,-118.612375,-288.18578,-345.66725,-301.108814,-254.030737,-275.934988,-346.197194,-356.678456,-286.10064,-227.546319,-143.881716,-114.252147,-70.578234,-64.002002,-25.926159,90.250328,98.593344,13.242976,-25.425738,-9.151251,73.793168,104.162362,116.905567,99.426179,50.640617,22.313339,-68.801698,-119.363816,-121.87912,15.026445,75.848215,69.145959,3.783137,-113.003003,-111.660225,36.752467,226.679807,243.08977,147.166264,115.213658,121.936258,115.400854,30.110715,2.605789,83.142386,161.949582,121.940658,-51.810572,-113.760462,-131.868597,-122.031485,-125.955462,-83.420831,-37.165927,0.252357,-26.454641,-90.771728,-110.278129,-194.310585,-269.463689,-370.756068,-301.256579,-222.932269,-97.728425,-103.238018,-195.553582,-215.512629,-199.992671,-268.225965,-322.755936,-299.641484,-227.684323,-135.725675,-146.093517,-233.930891,-270.533648,-278.553502,-274.782286,-259.818244,-160.64073,-112.916348,-66.956327,-69.666967,-160.637174,-242.159749,-217.769505,-76.898307,-10.333095,25.237983,2.681839,-27.169519,-11.035542,55.202867,62.042892,48.266041,53.372203,58.640979,-3.038133,-58.501273,-59.880302,82.386523,110.983316,43.970783,-0.250296,-45.051282,-48.66794,-66.356553,-94.377908,-142.028338,-84.928866,-14.126755,99.108449,87.424172,-77.587402,-184.600138,-308.652763,-286.072709,-270.783992,-254.306708,-252.387845,-289.895204,-316.748149,-345.561553,-328.640672,-230.959838,-137.849694,-120.292737,-171.654072,-201.236817,-166.53498,-146.841195,-221.196304,-230.838537,-149.253574,60.135426,129.160319,129.340624,91.496361,42.054067,27.503361,-7.723682,-38.011963,-43.846853,-46.319283,-59.690958,-152.527959,-230.651213,-301.557392,-126.686835,-11.054422,135.495441,147.642191,59.479908,-5.150148,-111.675759,-160.631281,-235.712286,-189.73745,-106.79485,70.541318,93.872222,-8.389845,-74.132876,-130.85637,-115.274927,-124.234734,-218.317767,-276.680978,-330.962567,-327.889567,-306.670856,-272.696463:0.155053,-143.881362,-186.619346,-91.203102,-51.58948,-191.094263,-298.568447,-343.335312,-230.551245,-178.214933,-24.2787,68.944515,136.719612,96.607939,-54.898729,-117.150699,-96.805177,21.678073,42.069245,-47.313089,-119.36873,-173.091559,-164.385268,-148.142204,-104.974983,-62.214951,36.087179,55.3347,41.895301,41.773233,23.152839,-3.878599,17.849157,147.284847,185.61424,175.847577,173.814672,177.762334,122.595571,-38.939127,-33.984647,11.608534,83.730517,88.762129,35.053733,-3.467163,-93.103799,-113.384902,-13.814208,111.590011,145.522488,180.28877,170.295599,83.639635,21.644126,-59.313272,43.231428,157.359702,349.557281,355.285066,174.462728,73.158504,-5.543656,1.515798,74.125912,161.904213,176.198591,136.709702,80.655016,-71.322864,-117.988777,-89.643487,-38.981704,-43.667023,-36.807489,-0.034097,69.446891,55.75476,-47.443074,-75.071372,-16.255892,80.9173,89.271512,37.081861,17.849028,-11.124426,-41.066679,-84.599762,-62.79182,-24.386136,99.628893,124.12817,12.117205,-47.831751,-37.340411,0.952552,79.648918,214.267893,278.384215,241.419094,161.498214,93.971801,120.440347,170.713558,202.822956,232.063917,325.893852,356.046258,309.646405,272.663087,237.842868,235.553969,261.091775,285.204457,292.766376,263.956327,219.196657,142.960741,116.944244,95.657459,136.715302,136.966255,91.149099,76.861072,64.681973,47.257152,-37.433656,-77.191147,-49.543944,45.934693,96.407242,185.071974,191.044151,106.845999,33.499189,-40.229539,63.222806,121.230413,171.34939,173.513574,142.194846,108.009258,51.231855,48.426674,126.880951,277.00438,323.194029,293.789182,233.330742,120.14912,94.022138,107.864759,164.883695,190.739979,192.747237,140.985587,-25.999312,-95.375728,-191.377581,-221.399399,-244.815515,-236.130567,-208.581518,-100.349779,-45.529006,-14.562789,-39.820839,-80.737319,-53.96906,-14.119755,138.911008,199.566155,144.279364,63.743173,-32.619345,-5.985453,160.786055,211.349923,174.828965,99.853984,65.249276,-26.506808,-58.029726,-2.050117,138.888616,193.113751,259.00428,265.826907,206.83811,158.051357,75.242041,49.418032,45.270926,83.801011,81.493429,22.142119,-3.565802,-65.591845,-109.812412,-146.349663,-131.307611,-128.099203,-68.954309,-25.152719,-53.125483,-127.453721,-232.31251,-217.179897,-121.305706,-33.556415,13.243433,37.869228,0.34402,-49.826221,-31.633043,6.781202,17.684662,53.228698,137.010026,130.74179,26.197763,-40.930937,-166.340381,-190.105062,-131.037075,-96.877473,-100.724811,-116.045514,-147.203759,-240.524423,-277.09386,-289.511997,-179.377572,-111.644103,-75.067745,-100.792696,-136.359601,-126.197306,-85.806551,-58.333024,57.943447,172.278837,196.352929,211.699437,206.687845,175.80677,162.179672,165.163781,202.380894,214.637672,203.210578,186.648978,130.640243,84.974107,-4.841996,-19.184605,24.708169,85.339184,122.178137,179.16544,168.039156,90.539246,62.801159,103.020846,218.921892,258.914899,268.784486,240.815604,143.023436,89.340288,4.196474,4.962882,111.813648,200.492209,208.084328,183.710655,166.120455,105.306705,56.283619,-37.264308,-44.208425,2.540011,115.582546,130.146586,50.797374,-16.608509,-146.34493,-182.411556,-149.71135,-23.429432,41.218377,49.595209,-23.394505,-170.071493,-198.393352,-219.078294,-274.583841,-286.821851,-225.663118,-175.643227,-78.134179,-46.189107,-55.168413,-61.101347,-37.906123,-65.027536,-69.863784,-10.128854,21.273939,4.700505,-30.318054,-45.488686,-27.874542,-22.936664,31.458896,69.183337,97.277017,82.763007,96.20731,152.613656,246.949444,200.547095,181.749673,164.204844,113.401601,-24.736061,-60.550541,-50.72916,-18.890719,-2.257877,72.837689,107.248142,107.98087,81.665615,-19.40021,-75.35179,-68.243295,102.016819,167.422714,135.500426,55.775453,-124.241384,-195.447285,-247.07278,-188.718947,-152.701852,-110.298011,-98.555049,-113.151699,-162.051418,-320.070412,-375.351833,-336.477627,-127.503653,-28.794395,-62.250111,-174.532281,-317.333207,-329.201866,-342.731592,-255.249016,-130.763192,135.377182,170.363217,39.550741,-17.184223,-24.614004,-31.355867,-114.698604,-171.640242,-145.169938,-80.759821,-103.282234,-234.792775,-294.25566,-298.498535,-179.019277,-122.369136,-13.645602,25.730308,-15.336941,-70.3797,-143.455077,-175.86856,-234.220098,-175.142178,-117.716122,-37.554197,-17.45007,15.323658,29.268292,3.513859,-103.954808,-126.425095,-38.820907,-8.934816,-139.275697,-253.965427,-381.739418,-351.155928:-164.906853,-151.525542,-109.782703,-93.667547,-152.547695,-305.518869,-355.515444,-376.413561,-318.515627,-267.029582,-154.937603,-116.055252,-99.586296,-135.136701,-234.346615,-236.580076,-142.914157,-60.069997,-43.236059,-68.433537,-107.369405,-222.053277,-268.269835,-232.290533,-84.96178,-18.852882,25.351606,-8.81954,-84.099522,-93.990566,-122.71008,-139.083956,-73.916907,39.072371,61.993257,76.281921,84.252989,40.929606,-20.405581,-124.327955,-113.274731,-62.078828,57.278298,63.653153,-68.101106,-152.186939,-225.356339,-197.45424,-67.495178,36.604149,60.042795,45.135312,22.020028,-11.251488,-23.194233,-19.875835,94.607978,172.813262,253.576992,238.332511,156.914992,119.036862,70.38212,84.85667,201.809323,292.065687,287.386949,155.033455,68.206922,-12.856497,-22.567163,-34.625163,-4.062162,28.582106,67.041158,56.780627,28.317926,15.283192,-20.253994,-11.609252,58.491755,73.834228,62.880414,24.437623,-8.046298,-62.87281,-78.058165,-75.675009,-19.685895,15.942701,66.157565,50.361491,-49.559048,-86.959475,-122.411591,-124.410408,-34.189926,169.927493,255.439161,238.075583,145.373979,-6.284191,-10.415988,86.402569,167.993555,179.413622,151.729553,135.127125,157.454001,176.159228,145.744035,119.218029,139.10214,215.684049,241.715697,235.271219,191.71784,44.383409,-18.915958,-20.320548,52.470438,59.576854,43.803474,21.818203,-82.122224,-144.194186,-207.936684,-205.152902,-187.566861,-98.98428,-17.162972,65.711122,51.875198,-16.469183,-70.196962,-154.95846,-83.672626,-8.978733,93.018411,83.73178,21.945767,18.211915,43.33863,70.623062,178.747936,282.871778,317.219771,339.824079,316.706382,222.650374,177.785321,109.852532,116.508131,169.542203,251.420329,199.189032,-11.239548,-75.972512,-153.578676,-206.86226,-275.490092,-258.114183,-240.703132,-191.89177,-154.285937,-97.494021,-93.989203,-76.90505,16.403988,90.172638,228.896575,241.252976,136.897369,74.929723,24.598283,47.104575,208.444382,373.641868,369.989797,225.215316,156.433187,61.602077,8.253199,-42.256604,64.532677,130.76516,224.35637,239.155724,157.204507,83.042311,-13.272613,-5.983897,72.438034,66.926145,33.343499,-56.20086,-115.021958,-201.404131,-200.417494,-146.480847,-100.977862,-70.78461,21.225255,48.863257,-16.439239,-81.529272,-149.661442,-129.430556,-15.290334,83.612177,113.833224,133.943886,115.73625,71.191011,67.757812,83.845619,119.307951,149.562034,156.821349,109.987607,-2.678271,-45.786857,-112.840947,-113.20597,-42.291301,-30.824499,-53.045157,-105.356088,-131.342239,-146.907487,-138.585852,-119.008006,-42.386932,14.003004,93.84172,100.848557,55.146404,29.95625,35.843041,79.419444,255.229891,417.269678,449.552415,420.208433,375.938941,296.627995,275.490523,280.160833,332.267831,356.296989,342.218839,294.205636,192.801176,163.145916,99.484707,62.219903,55.453409,179.278001,253.441686,286.60686,237.854918,114.463927,89.712226,180.144168,318.649871,337.450261,285.776763,244.17715,168.913719,141.76513,91.650559,73.8192,151.09099,287.474215,288.640734,240.663142,254.407597,263.381276,206.239093,108.332305,121.220321,127.775677,147.031178,153.297519,110.833152,42.992056,-179.729954,-254.502434,-157.178695,46.373194,80.524078,31.548891,-15.17478,-105.314812,-134.081401,-142.410684,-124.303028,-115.755959,-107.700155,-100.626298,-42.227755,-16.885539,-49.980707,-72.381325,-59.577087,-49.705101,-56.24314,-87.098414,-101.601367,-110.022517,-113.918685,-120.547525,-102.693609,-69.151708,57.17525,106.931775,125.449537,118.094394,115.885397,138.286329,179.903742,131.791216,127.371504,178.835329,174.177277,53.444579,-12.712839,-27.755869,64.816344,101.67565,139.110278,136.29049,77.765603,40.485654,5.266958,12.01204,25.241161,50.924017,90.096378,93.76283,26.321807,-145.32794,-207.935292,-240.290912,-189.882732,-167.872042,-125.818687,-108.19838,-157.957953,-236.404888,-401.280632,-435.663414,-382.990395,-240.477762,-157.838538,-98.704695,-147.667632,-254.340041,-268.028335,-261.131401,-224.829685,-165.680254,14.92026,61.424684,-8.737057,-73.11349,-170.944069,-190.609455,-161.250355,-124.987924,-115.399528,-108.696218,-144.784655,-302.39111,-369.057783,-367.599356,-202.491433,-100.325095,16.74172,-4.833641,-145.676752,-200.027873,-261.900863,-300.359899,-338.962048,-207.337851,-98.853999,6.338106,-29.37999,-130.181749,-136.81569,-92.156205,-95.44151,-107.588956,-73.680327,-43.878247,-57.81978,-108.871301,-217.957262,-241.319841:-125.214937,-262.556158,-304.494781,-229.696935,-183.647894,-289.278802,-396.274374,-455.771659,-309.691736,-230.924287,-94.147904,-36.242394,31.056797,39.584296,0.548604,-31.816588,-67.865525,-71.345072,-68.581512,-69.058558,-80.188427,-110.750794,-122.120302,-106.148593,-15.075326,45.484493,135.261882,131.87031,42.200086,2.646775,-19.695336,-11.371438,39.207356,93.968163,112.418462,153.602634,172.487777,138.513544,69.541091,-66.484249,-29.658014,22.337136,69.65343,58.198935,21.478749,21.328245,2.434388,-27.194046,-34.480621,-12.883023,-2.505651,84.116242,132.439083,111.079963,47.548163,-30.424707,44.053741,98.520206,213.922226,259.0973,231.223673,172.789064,114.288688,145.216253,240.496915,255.943866,244.672037,188.30042,129.146677,-25.683273,-96.939865,-195.513243,-202.763831,-175.135694,-114.767288,-89.68973,-65.306558,-68.171414,-78.72579,-77.147694,-52.60869,-4.85003,24.392031,29.443591,-14.466861,-113.93396,-124.513396,-98.213551,-126.813593,-122.362661,-13.025217,20.642695,-41.337863,-82.857065,-90.657309,-46.492151,147.894888,320.856091,342.395514,313.952826,290.216537,266.399787,272.951112,269.387516,223.297281,209.131479,214.828565,224.919133,282.781183,316.986739,267.160466,213.715786,251.873984,335.869614,319.165898,194.990983,116.534434,46.196555,47.244877,10.344601,-7.199263,-3.373048,-29.848816,-59.712781,-150.106494,-202.300826,-257.550903,-252.505223,-197.418542,-59.288536,19.312931,79.95368,62.661684,4.985012,-35.223282,-96.744023,-28.264406,47.104938,188.520357,204.135767,123.357031,84.374963,76.282358,103.653082,224.200603,334.645807,351.537227,318.231525,265.077939,137.032303,99.298604,82.818845,80.238539,79.027721,109.851667,107.355496,-12.143494,-94.438695,-219.363922,-251.498822,-244.746662,-175.572374,-130.136823,-57.975055,-60.943228,-125.106097,-137.237437,-49.798196,89.071972,119.643358,130.42066,137.381552,146.19725,148.07103,160.561269,173.50303,219.443587,259.575331,273.070103,239.749964,173.588516,30.453249,-6.123904,19.76904,133.355629,193.425324,250.170084,219.990694,101.811854,69.856239,52.562327,25.6207,-30.792963,-11.401026,10.971978,24.444595,-5.947587,-114.479769,-137.141297,-62.392872,21.820805,39.891149,70.96514,84.367397,65.744851,12.833751,-173.395736,-241.51268,-167.186737,39.732236,108.061897,123.970526,80.68995,-10.084234,-19.809663,15.536072,43.325562,44.35971,33.344239,24.693944,-2.02303,-27.769833,-128.034535,-175.683437,-179.16451,-156.356588,-165.188129,-164.348382,-146.08575,-119.971574,-130.632725,-177.439257,-145.861464,-101.671944,-76.9447,-113.232402,-164.944877,-131.829981,1.633482,58.572879,152.788885,254.135149,300.823359,326.335218,279.802289,153.879989,131.669994,152.439337,189.142994,211.344609,219.890765,203.367883,183.799078,173.250412,89.72828,30.189909,-0.570616,99.394961,163.326412,249.607288,230.95213,94.312164,43.327991,93.709679,283.657264,333.7019,273.917323,217.652167,164.039043,164.44243,131.026613,94.973978,89.002767,164.159015,176.325487,104.726668,62.194307,54.153233,59.886062,-2.6629,-53.863435,-24.923083,84.962134,97.167357,-28.953346,-114.720178,-209.714469,-215.277716,-198.563533,-226.454074,-219.479346,-125.569391,-115.791053,-223.178908,-268.613783,-257.492931,-233.744121,-242.542095,-241.909539,-223.851127,-181.569684,-163.54812,-142.302524,-146.197471,-212.128687,-311.843388,-309.299213,-191.478264,-141.022426,-130.250755,-143.201063,-158.397196,-140.147737,-110.736818,3.822935,62.659103,75.600712,44.194779,26.279765,47.65476,101.566367,133.168417,138.103423,130.096828,108.157041,4.04769,-56.470671,-57.9126,65.848768,90.661704,35.385051,0.024198,-11.200094,-11.836901,-80.613078,-117.44666,-93.282046,30.360086,98.247299,125.024413,43.994898,-182.483587,-237.176777,-191.003583,-123.396991,-119.30815,-123.577198,-144.743575,-254.092208,-297.692679,-315.927323,-310.025311,-298.054975,-297.351625,-283.526477,-236.054315,-223.233586,-222.992602,-250.676294,-341.298136,-259.910238,-150.954286,35.1008,85.817908,121.763601,106.477595,-0.741363,-52.274098,-64.691209,-90.79839,-113.282131,-113.692035,-124.995713,-245.029452,-326.069005,-386.552138,-241.479897,-130.92826,30.444798,43.941286,-24.833415,-65.56799,-171.921567,-237.188273,-285.635737,-172.493555,-78.681854,43.823003,29.818054,-62.046709,-94.07818,-145.025987,-203.233518,-230.997887,-255.451891,-245.47603,-241.665807,-267.101399,-333.333731,-338.416806:-128.337062,-122.12237,-98.989036,-58.374658,-93.008641,-296.783115,-398.217387,-424.266234,-273.460596,-191.267867,-45.615277,4.540763,9.56737,-40.620733,-151.31257,-147.545895,-70.927071,-52.820197,-39.924965,-0.566755,-11.161439,-117.694983,-164.773887,-137.037458,-18.346627,54.71372,169.11158,166.05604,64.43607,18.46161,-12.438689,-9.015219,14.973277,75.788573,122.7938,196.781675,201.878141,126.388571,57.23492,-50.438946,-33.893344,20.732905,105.761701,80.758881,-37.142839,-72.241821,-98.674966,-91.577023,-2.143415,70.786838,77.88755,71.689725,65.368661,37.004731,3.833862,-18.464396,148.034511,251.375465,359.693827,350.663493,215.174228,126.283739,65.493902,122.583213,271.236578,270.895208,234.825934,160.346635,117.661005,12.1753,-43.056518,-104.870823,-59.015466,-7.292559,47.531759,17.071598,-52.701926,-50.822157,-84.473189,-134.087793,-126.956724,52.050013,105.58698,16.731636,-59.351473,-130.774022,-152.769277,-179.486146,-114.765296,-60.398337,45.019191,56.749812,-57.919118,-147.496428,-265.897256,-245.624171,-47.839668,166.592732,248.41576,298.201872,245.785765,103.293534,87.21988,189.15533,225.701421,189.968119,145.228997,146.975806,145.834251,140.475911,104.753747,79.823273,88.348577,206.628167,249.177361,110.788423,-39.221302,-230.18457,-250.066676,-248.932797,-167.833238,-109.290595,-49.489829,-65.022904,-159.315171,-205.465416,-278.473525,-296.436115,-232.039695,-76.702781,-10.047514,20.570188,-3.051465,-36.061557,-37.457709,-15.338304,40.667019,70.992796,109.006434,101.990023,54.038405,43.26281,75.410966,117.257231,240.896037,356.525208,404.104921,421.760291,345.350534,96.13675,13.227598,-3.615941,13.536114,3.871471,11.34886,16.7311,-48.481669,-129.78718,-362.212095,-445.189842,-384.882139,-187.007696,-140.168947,-179.409477,-213.75,-225.974783,-211.766106,-144.160889,-25.148436,43.041838,186.503013,229.738232,190.890403,144.15222,99.242153,100.900202,160.959415,315.94087,380.746828,292.76587,152.571075,-59.016416,-80.930018,-5.005895,135.913038,185.392087,199.868707,172.29462,28.203301,-80.72601,-195.430321,-160.503412,-52.724517,-21.066259,-8.497456,-20.343141,-61.135289,-158.120293,-187.30035,-155.84284,-62.671,-33.722485,20.306939,53.597472,48.725387,-9.033512,-109.80664,-97.761652,7.874499,125.364923,172.98405,180.471265,145.635155,98.35222,91.184065,96.476926,140.903523,151.78905,99.383595,43.235689,-62.047532,-98.835264,-163.585137,-176.996896,-130.649584,-63.2613,-65.271579,-159.843486,-203.27638,-214.493433,-206.049432,-165.725078,-46.726547,27.412376,119.918907,112.843336,35.347325,5.905149,2.306133,31.965597,166.657655,318.314541,364.783663,338.01772,262.497525,114.865429,104.697088,212.037546,327.483518,349.705229,337.717121,328.539209,333.102646,317.045384,201.314879,146.92847,148.029132,254.692972,322.971316,368.282382,318.660521,205.527178,192.355984,226.219283,272.573845,292.905853,301.896027,275.200852,166.530311,105.187801,6.626569,3.485323,117.863011,213.794681,221.917847,196.684229,164.195394,73.355922,44.252695,32.291192,-3.084222,-10.709934,72.78505,118.718685,48.39343,-59.446029,-249.372007,-290.83911,-263.176914,-151.241321,-110.727184,-135.940063,-189.857634,-288.97798,-316.717275,-329.95779,-331.818222,-331.278032,-270.163068,-224.242209,-201.013494,-226.846267,-269.449839,-257.375971,-201.442731,-139.067723,-87.187343,-45.437499,-91.868451,-199.356687,-214.451841,-197.085052,-130.624866,-60.742699,120.218527,161.68552,85.181968,33.231171,-7.903625,-7.970793,24.154556,85.111965,124.862589,180.46162,170.811443,62.136547,-11.267934,-66.208758,31.628659,77.442412,100.6786,82.855184,10.414282,-17.657609,-60.021745,-85.236204,-68.002482,120.967641,213.230792,167.912553,53.92893,-126.138782,-158.13267,-159.166733,-116.545685,-66.715038,34.794207,13.834174,-194.490575,-291.896097,-340.99592,-315.763683,-234.514719,-157.806711,-131.722478,-118.645371,-138.032534,-222.625261,-274.142866,-323.633991,-230.386404,-137.132479,49.848763,83.498518,14.263978,-34.358996,-82.67737,-68.78233,26.336425,47.275751,1.247542,-102.77949,-144.58492,-268.476458,-326.766345,-281.753055,-79.258621,4.432611,42.359636,-2.674437,-111.663489,-152.239625,-240.590764,-272.899569,-254.193086,-127.190602,-54.864605,-42.082174,-102.849492,-204.813435,-223.285981,-218.807654,-157.992933,-130.178862,-144.044088,-184.031074,-255.900016,-274.516342,-324.314093,-341.650481:-119.366135,-223.686091,-266.028674,-256.717357,-239.931356,-269.01229,-289.046409,-262.645454,-153.324651,-84.990583,79.738065,158.297927,221.179577,210.772178,138.616461,83.027206,20.158894,100.295031,165.306132,218.951454,182.291712,44.534222,-12.327119,-52.073686,-43.072941,-21.584608,96.136036,169.977305,214.856332,178.305453,96.277188,87.400011,157.021715,215.492097,204.640986,156.588993,128.386574,57.893657,17.718433,-52.032617,-39.373657,7.087079,115.514481,130.154207,71.039509,42.71831,10.446435,-7.805712,0.609932,47.503458,50.796104,56.154878,72.829311,88.654913,63.144772,-36.408927,-31.495855,30.609354,173.945057,193.896005,103.683502,74.324432,132.647421,167.139827,201.789332,180.201409,125.71511,0.117816,-34.380182,-34.82846,-18.22918,-18.250332,-110.947244,-168.788167,-191.726012,-158.397846,-116.794934,-115.547957,-113.33559,-106.744562,-50.763535,3.56421,4.295164,-48.942055,-103.149778,-183.129206,-169.902279,-78.068962,-34.174397,-29.830676,36.916953,85.162521,108.963287,71.678322,-63.208423,-98.470732,41.994473,281.922436,336.163827,290.221248,224.304713,149.228538,165.972202,235.9331,259.731984,253.255763,294.727666,353.768416,393.395331,344.235928,284.12788,311.21702,356.627361,307.689805,277.933917,180.316019,98.211001,18.234944,35.311185,27.201603,-26.124087,-38.552541,-79.646547,-120.056231,-173.385102,-160.574133,-120.330347,-127.694035,-108.040154,61.300503,141.81586,184.23034,157.237389,80.076779,50.211729,37.094377,100.788189,147.182031,204.603065,188.980498,85.600018,42.796719,63.854166,123.165597,263.725608,385.158143,427.116477,358.352661,255.972904,100.884777,62.378754,-4.912125,-38.411838,-40.162175,6.251802,38.867432,15.603769,-36.330048,-151.309622,-191.739774,-170.926305,-77.100773,-44.618843,11.701124,16.108003,-80.04739,-130.146072,-108.050153,-25.306214,-14.431109,-9.851157,16.460723,64.183783,66.483351,94.642396,126.810068,164.632233,163.321704,163.553689,116.155404,65.451174,-2.585763,-15.42541,-25.818954,46.973304,122.456656,254.828615,251.673675,99.745499,15.698911,-98.944406,-137.309381,-136.591256,-5.165232,60.501803,92.885053,83.469323,73.613337,54.809566,35.937706,105.064416,118.824891,81.166017,70.792092,81.012246,54.959382,-136.935739,-240.126701,-248.071928,-138.412627,-104.50008,-39.662284,-32.438491,-75.888819,-82.151154,-70.261137,-77.718352,-51.77406,18.696284,-7.661286,-169.603825,-218.717221,-174.348566,-136.739292,-167.826239,-280.765802,-297.594774,-252.633225,-246.042451,-280.853203,-304.673001,-356.21465,-326.885418,-289.410757,-286.523603,-307.105772,-258.465662,-190.828629,-77.086918,-58.4736,-85.887844,-84.149104,-46.00872,-27.220951,-87.628047,-191.220813,-169.973239,-42.738654,59.315032,71.077432,50.951206,42.550833,21.305,17.824246,9.076662,-17.591027,-53.828325,-0.531206,45.924966,107.30477,96.487348,15.74338,-19.738933,23.388518,253.934075,340.798902,287.933468,207.284698,123.992167,107.719041,40.047548,17.2124,51.505368,44.233873,-3.03154,-117.426307,-148.681179,-121.28383,-116.14178,-197.317139,-173.674987,-101.416987,-32.635883,-75.106444,-222.594643,-274.20938,-320.501345,-324.358438,-296.231797,-321.957401,-341.774658,-287.812314,-256.253309,-276.622411,-288.597514,-245.066914,-193.252047,-217.084602,-326.641582,-356.568223,-316.218278,-273.760102,-249.784453,-279.231228,-353.806296,-368.993801,-350.833325,-274.484086,-233.64735,-169.768715,-148.116072,-145.035577,-157.941847,-125.342397,35.370139,94.699946,45.243684,-12.545949,-56.576167,-50.437211,-33.455579,-15.59283,-2.582515,8.971747,-8.219056,-99.053477,-155.502847,-180.761279,-69.004968,-24.677528,-37.601235,-83.486834,-174.056468,-187.173956,-144.878448,-110.659381,-68.442907,-34.259947,7.04278,42.746385,-15.828605,-196.04944,-255.822325,-275.627275,-182.814178,-131.989412,-131.401019,-184.545017,-303.617735,-324.357258,-304.383409,-278.258702,-183.92541,-118.734581,-125.680955,-208.949921,-245.038722,-216.760977,-187.043037,-189.728277,-183.668374,-143.834637,-24.671195,21.409319,52.064516,39.721866,-12.258915,-20.387056,3.901903,-50.978958,-99.541455,-150.045659,-160.893745,-199.875275,-224.903068,-235.541952,-118.660451,-9.641828,203.07555,238.238318,126.364389,32.384699,-101.182676,-114.041055,-68.557058,-40.966164,-23.35382,25.265303,18.191409,-52.454487,-84.625103,-117.549877,-117.66276,-132.635492,-220.653019,-262.453915,-281.367122,-273.920348,-277.943599,-265.007558:-75.957424,-28.874362,-39.055311,-103.853565,-168.746933,-355.590581,-437.799723,-384.795862,-62.052997,60.245636,105.800514,82.486469,101.43093,144.575856,160.588966,123.784566,78.837597,113.397188,131.130298,137.248094,123.873455,52.022352,0.207681,-54.869148,39.113544,131.640002,293.430825,297.740729,143.017705,64.289662,38.889263,76.147784,155.925189,177.556375,185.559916,207.31128,198.503778,133.800901,83.660959,-7.052489,38.407862,103.312063,207.206725,221.306729,191.422661,169.422416,120.338325,104.234402,148.482227,223.992839,242.059148,238.346913,212.257355,135.19949,100.918131,86.759036,184.950038,251.980661,332.524759,318.736845,212.489858,165.887681,148.92934,186.088034,347.476809,434.066047,389.415049,228.00277,153.907333,24.481106,-24.304207,-59.001262,-43.095077,-36.634151,-13.412337,-2.399513,-30.400184,-60.477609,-104.962163,-103.810081,-48.427055,7.536831,24.595506,7.406365,-37.51315,-156.901791,-189.563207,-118.810345,41.318559,81.609604,45.444895,-3.290817,-74.995466,-79.710515,-63.79466,-45.143139,52.83578,182.08295,254.768886,355.237906,335.016649,229.503088,205.997443,218.539691,259.959357,276.88905,252.899066,230.536661,199.858674,181.36079,174.841461,192.610192,230.699745,244.551182,242.223301,156.890781,60.511847,-111.792536,-143.935482,-123.253914,-55.695016,-41.941748,-105.867705,-149.482287,-188.9853,-187.627868,-135.793258,-88.716332,-10.491851,35.331768,62.847402,93.84249,87.435363,56.485308,35.369029,37.242691,138.994904,196.624509,247.953405,218.610695,92.473834,44.337048,25.050293,60.932606,216.68769,350.304,375.290034,301.946388,211.360145,43.236354,-9.977947,-72.769885,-83.41346,-64.252271,17.065762,29.0799,-110.365192,-221.180359,-358.216461,-363.436972,-304.965854,-234.98424,-212.429521,-205.356511,-219.964285,-267.53408,-270.749958,-165.50653,-30.075023,-13.361711,14.485372,65.69869,127.429501,90.926558,-28.214235,-37.551947,85.311376,247.285317,287.004333,166.068039,34.027819,-113.938341,-107.133542,-39.321024,74.767274,135.741688,190.935069,152.782003,-40.079381,-127.826211,-147.453992,-108.140662,-61.591609,-6.856008,39.93509,63.962074,17.347777,-102.591277,-129.729987,-105.095852,-27.746279,21.148629,72.801093,37.202938,-98.594856,-136.353811,-153.452045,-154.089187,-92.217953,7.797384,24.940658,10.033182,2.901187,-28.81396,-54.120857,-20.917973,76.204289,82.39381,9.363513,-57.467474,-215.367356,-275.106832,-321.769406,-306.390457,-210.557956,-160.471715,-182.618544,-268.673843,-316.660107,-349.704715,-307.657639,-192.07043,-135.509939,-118.780302,-97.975149,-92.142697,-89.006337,-104.77459,-132.870831,-100.198361,49.038,152.696,165.108048,148.484964,113.004691,-8.140652,-44.82804,3.047802,94.044599,122.115273,160.648118,170.27014,166.500358,151.556576,62.619009,11.37516,36.902539,180.399045,220.175255,191.702535,149.447078,67.656278,45.240094,105.801487,269.346988,306.270094,217.643072,147.970562,97.969289,106.049561,46.770856,-14.389398,-8.317453,163.827502,220.587297,150.224058,51.222229,-90.012003,-101.182211,-55.745828,23.903186,56.928217,58.242906,20.197814,-85.14431,-136.756698,-253.660199,-295.470501,-280.888769,-238.794373,-224.687032,-199.134645,-219.411122,-345.569189,-399.500848,-382.003471,-298.301968,-292.975763,-341.259039,-368.144697,-390.975111,-385.336164,-353.603804,-328.914511,-306.82408,-323.878196,-298.318292,-203.602025,-194.108807,-280.504607,-325.789616,-307.369212,-155.467965,-56.136458,111.361043,136.732262,74.498698,30.880123,-8.935148,-4.421528,30.835877,78.678969,101.131607,103.63565,66.524638,-65.590858,-128.008243,-131.591568,22.888181,100.039855,145.958448,89.526392,-117.098092,-188.916715,-196.111975,-167.188947,-81.023839,94.007046,171.84157,103.593613,-37.806735,-268.505864,-285.030153,-190.621256,-61.223211,8.236214,65.696285,2.934609,-229.122847,-314.18498,-345.209298,-314.417307,-213.184403,-117.131652,-99.778955,-114.459237,-124.768097,-148.516807,-185.296434,-257.708783,-141.946281,-28.134334,135.719138,147.746311,73.796907,32.536297,15.524378,43.36261,106.561569,88.920653,67.763965,16.124572,-42.871806,-213.650204,-271.568664,-228.67488,-55.303687,17.068606,108.863056,125.741003,55.259468,-24.883544,-162.775734,-179.763561,-129.685346,-22.814412,21.92514,-52.924554,-161.11273,-310.774484,-305.630231,-215.030462,-184.671612,-201.999207,-236.108599,-247.928846,-281.995443,-298.121462,-325.582067,-307.670514:-144.531742,-165.217028,-148.627096,-54.249045,-37.884761,-70.026924,-43.459524,115.67805,212.54274,209.955677,233.059059,290.332758,414.043918,446.951316,422.129682,374.058985,323.750627,365.615785,397.503612,453.049316,442.626991,330.4648,263.760577,151.13379,41.323855,6.127028,32.938712,80.069706,123.526189,107.903675,81.111386,89.492784,139.243245,140.184275,116.243787,74.833128,43.972224,-32.649314,-50.893206,-43.327423,13.048768,48.002711,62.569976,41.432014,3.619275,7.991373,37.837264,39.04289,61.909541,139.613079,149.797304,100.41226,73.051645,12.958284,-44.827198,-162.439717,-136.984206,-81.82106,14.376971,30.132177,-18.841075,-47.97429,-6.11385,54.536927,170.94635,183.634745,135.442797,34.751502,12.73001,24.290404,40.351536,65.948837,63.745352,30.892915,2.880428,35.208678,81.260869,73.047038,7.003449,-42.883028,-58.410205,60.318741,110.386753,89.865083,28.077519,-53.99365,-45.758173,-18.371624,-61.313898,-80.560697,-10.421174,43.816507,18.757278,-52.55091,-184.501819,-219.275983,-192.326253,-18.172278,69.572238,98.549602,54.737026,23.274547,63.463459,145.132632,133.763771,130.124839,204.621239,250.162597,276.841619,280.929174,262.182257,212.179405,126.654995,163.337379,161.983318,48.540125,-0.801584,24.086428,58.109161,9.318156,-146.213345,-175.050166,-109.436123,-56.730164,16.410195,33.878479,-20.079007,-94.521247,-119.217448,109.871836,216.019033,293.091321,274.407272,205.81057,181.210218,150.736193,151.917044,146.736803,118.132474,99.948573,9.841603,-45.07979,-55.459173,-7.464561,121.010416,251.470735,302.31019,299.858052,242.389631,89.923405,13.218888,-116.24064,-129.174482,-123.109083,-161.577476,-175.662616,-201.46976,-247.906618,-314.304377,-265.964002,-57.314676,21.79297,-10.533324,-64.2529,-75.946846,-179.076749,-253.499522,-293.711453,-221.227137,-209.601746,-229.67457,-231.157168,-174.941129,-114.843977,-23.98846,-30.269781,-103.502793,-133.449265,-109.526159,-57.27006,-57.905115,-70.463233,-72.779016,-69.479809,3.539307,58.548856,149.2895,161.513412,79.306106,12.483033,-71.259394,-75.298474,23.477948,213.032576,265.480363,243.804325,207.16376,185.423969,202.715228,228.441755,252.690176,247.116447,171.605561,132.143046,79.342217,53.442635,-43.961088,-114.141399,-206.094546,-164.531672,-120.28919,-63.602043,-58.525745,-89.504117,-111.52996,-135.620083,-139.48787,-130.415349,-71.483804,-60.573266,-187.401304,-268.991621,-293.380389,-261.719763,-224.78677,-250.794063,-266.215133,-296.676232,-323.335229,-352.737002,-347.647488,-333.571463,-364.272459,-402.417228,-429.149017,-397.801831,-324.816115,-290.049318,-175.824266,-134.822884,-213.765686,-352.226994,-355.554054,-285.134676,-273.077207,-318.031641,-350.663343,-377.781896,-269.146234,-176.632359,-22.868182,6.68889,-8.954027,-6.610379,0.633283,-30.923169,-37.027111,117.852604,179.20347,175.228368,135.558591,73.11546,55.104878,52.873358,129.111363,167.145813,200.77719,204.341017,177.411078,142.534487,16.04843,-63.250469,-127.386707,-73.682566,-86.067863,-223.337299,-278.68545,-262.834842,-249.678834,-305.867821,-291.501579,-240.426992,-204.977787,-255.470222,-376.460262,-389.837382,-336.588888,-296.166081,-249.599426,-272.571829,-267.937356,-193.339552,-171.321608,-185.611828,-175.575082,-119.23307,-139.310873,-197.348749,-301.455099,-308.634879,-301.436715,-286.678713,-214.302574,-204.31161,-249.540734,-233.81565,-209.939283,-159.779284,-115.795336,-14.605295,4.581044,-44.791817,-83.158328,-41.131214,105.808379,125.250095,8.608458,-54.241839,-89.691543,-96.696175,-133.052632,-115.170137,-82.00709,-42.632199,-73.134155,-207.815551,-254.741574,-222.205702,-53.507337,2.939433,-34.531818,-80.480397,-138.566683,-151.16209,-152.652867,-146.613009,-139.888173,-162.654327,-180.968431,-210.830588,-215.306417,-190.969671,-195.371151,-259.93585,-226.848579,-171.312761,-101.999155,-121.96795,-244.631264,-286.902894,-257.543985,-209.964373,-145.883144,-194.854104,-213.951481,-148.15993,-106.814523,-89.323226,-94.43575,-87.325586,-80.720969,-78.323309,-11.753815,35.234526,25.316344,-13.660575,-19.095461,11.098059,54.729661,46.18177,27.857038,-13.465809,-35.685344,-86.428023,-110.385335,-93.803609,69.432962,153.959517,220.904321,230.78995,240.95843,214.919997,95.970027,41.13752,37.554338,131.888726,158.123945,134.05186,98.653966,24.042497,-4.131458,-14.130323,29.741364,25.841887,-64.892865,-127.220242,-216.52974,-227.11817,-181.717252,-139.217573:-91.121047,-150.908457,-182.63346,-158.484552,-118.300975,-80.186504,-98.619418,-149.089574,-81.492763,-17.336351,105.696387,168.562399,277.434277,309.71362,289.655869,226.902869,120.902005,181.120625,241.724189,278.926097,234.137625,116.933289,73.718159,-8.049798,-61.545881,-69.798235,-35.026786,17.895131,89.790133,72.36262,29.219531,60.196436,170.895434,152.511062,104.498549,26.294094,0.277429,-14.387002,-6.825036,-3.34622,8.693123,15.746178,16.974665,12.167717,-26.209108,-40.137569,-21.593752,-17.602399,-26.097022,-13.031782,-11.018259,-7.35841,-5.046977,-19.741809,-44.577005,-136.519033,-156.835691,-96.652253,77.613777,124.517414,64.361928,16.627493,43.109853,81.812434,74.278996,29.910407,15.525082,-19.153604,-25.47223,3.778113,12.452633,-70.151626,-141.518173,-129.989063,-83.243198,-76.853186,-109.333141,-114.151574,-91.376495,-84.749811,-24.413125,31.152088,-12.048898,-178.333557,-231.168027,-212.340884,-174.291943,-116.075826,-113.849602,-134.185294,-109.517163,-56.493998,-7.119728,-33.083347,-89.062716,-96.153279,-83.208182,-28.598324,17.535056,105.337735,118.202441,75.48364,52.218068,89.331445,201.814201,242.562517,313.659995,352.444029,356.20301,321.909855,285.400738,284.256585,249.566644,182.26094,168.598708,164.871713,145.959672,95.139778,80.308171,60.215384,22.938613,-3.502264,-9.216562,27.297528,95.044031,84.246294,-44.156368,-95.773644,5.73819,189.608474,227.03291,255.551977,262.536415,220.809012,164.268891,52.16981,71.533159,111.613369,151.904909,135.790426,48.214674,6.3309,0.01041,44.006447,197.971627,340.078646,372.500252,364.055322,339.524445,236.022226,142.492458,-36.587307,-61.609106,-38.886067,0.807706,-3.735077,-70.804122,-95.30637,-100.655887,-101.74695,-93.97874,-43.229361,-8.669512,31.127392,7.96856,-131.727745,-202.516302,-222.896127,-117.748382,-92.894064,-121.645779,-117.943018,-43.751207,-19.805423,-43.839635,-63.610399,-46.054026,-0.566713,19.879507,52.082435,37.224486,-36.742576,-68.042336,-62.91117,51.341814,109.826971,219.03392,285.56886,324.917329,276.430678,139.228874,78.479051,17.944849,39.894326,81.208924,165.027569,162.409731,104.611681,93.0528,115.25863,145.265647,157.976983,194.555297,198.695357,101.105805,11.626034,-157.416823,-220.395996,-251.4541,-147.327936,-85.994597,-43.055388,-62.504194,-85.188803,-78.340243,-100.976131,-107.002744,-77.317964,-37.339993,-57.822392,-139.299666,-161.867696,-170.061016,-177.986693,-190.660865,-173.937971,-161.328643,-151.210088,-172.958811,-280.524338,-344.830424,-445.805931,-443.961934,-415.861277,-366.356462,-337.610706,-289.180023,-279.13831,-220.168302,-171.713011,-151.213563,-207.819138,-211.831841,-198.418614,-218.613182,-267.63335,-257.138904,-185.84791,-128.079628,-101.063039,-33.853449,1.551296,61.005102,75.832571,36.265642,-6.120182,-7.040796,105.907225,144.768388,117.104425,56.416659,-67.383266,-94.123519,-23.238116,176.46152,240.73354,203.335258,152.495111,90.492403,58.807282,-29.179157,-52.586843,-39.100921,-46.031205,-65.014536,-127.12812,-169.33502,-234.684026,-261.963632,-301.302278,-203.110785,-131.513874,-90.640857,-109.566859,-155.204353,-182.162507,-264.099588,-305.458344,-360.319087,-409.326072,-398.073591,-251.471458,-172.481786,-125.077092,-137.254952,-175.649561,-246.605716,-269.665783,-209.572246,-162.219935,-193.268166,-264.304218,-328.824087,-286.251127,-195.280946,-209.08477,-196.642512,-78.294306,-34.526981,-62.001284,-82.980667,-61.117006,-55.70312,-63.363922,-1.745709,48.898316,44.523145,4.24935,-39.143551,-55.291873,-104.919202,-87.801028,-51.754015,2.886272,-5.292054,-88.349676,-131.449486,-120.474154,16.098084,70.761902,74.165715,30.152888,-102.066109,-149.670852,-119.627093,-62.55301,-36.987997,-170.644287,-206.462167,-148.956977,-104.876693,-79.494869,-111.90391,-194.17962,-162.286612,-145.845921,-167.720542,-180.769524,-211.375883,-223.329452,-195.849565,-159.611757,-84.467322,-82.468238,-98.822884,-117.03791,-118.698963,-96.55843,-87.45062,-144.142054,-221.787984,-201.888801,-30.989537,57.13724,73.204575,26.065462,-14.339899,9.718521,86.355376,63.859671,20.62003,-63.72545,-107.531169,-195.259204,-224.248494,-145.995697,143.752892,261.884184,315.885247,291.481033,229.64604,184.606201,-3.573656,-127.275356,-251.016576,-149.265829,-69.763344,23.671838,23.751293,-5.257337,-18.618002,-61.632679,-94.358514,-100.346152,-126.713097,-139.58449,-143.257561,-155.82688,-187.212819,-162.338486:-83.897068,-119.326413,-119.33593,-126.302986,-151.315232,-203.640741,-220.445247,-149.172407,69.625113,143.59908,216.959401,258.367857,300.937669,285.575556,247.368845,239.224174,238.813896,245.870948,241.864606,218.81482,182.382701,85.066196,75.58956,131.280135,142.168931,130.354446,128.891744,133.931864,120.201008,103.35701,77.887821,87.377839,169.911671,224.024212,220.218921,175.662791,130.176292,33.395536,-6.691959,-83.442024,-79.286619,-17.693681,159.579736,215.411102,172.208252,120.846847,134.816341,179.232722,204.794096,170.969109,152.289559,101.915293,78.463232,73.394547,73.200028,72.959574,180.390175,226.336071,163.9353,87.21083,-9.385544,3.062161,111.69804,179.477069,346.073839,432.163046,382.071578,183.901844,115.136433,144.601363,195.223778,157.942845,6.824409,-24.092453,46.035734,101.879523,102.557474,43.960717,-68.617507,-79.505105,-34.67325,-20.716637,-20.78662,-39.496217,-66.836896,-45.421077,10.934274,69.586464,37.041084,36.755711,81.629699,78.74366,-32.624944,-94.248873,-128.409551,-93.58316,60.538312,198.890404,242.997989,282.002033,250.821692,153.321015,135.868166,144.258953,182.363515,213.630333,242.977499,238.571798,226.952923,236.987109,307.926724,332.867427,273.46041,139.10444,112.229771,126.357227,102.918856,-10.097823,-57.268088,-104.412317,-101.099942,-85.662798,-85.869932,-110.602529,-143.315402,-128.735125,-61.894558,-22.786821,80.323419,181.812986,192.121229,150.782985,125.945782,97.975686,99.748297,102.163644,117.552369,144.575419,173.854395,148.98113,53.722922,24.80356,32.889749,67.937166,209.428123,330.96287,353.303496,313.759434,233.204469,3.211682,-94.433952,-189.037511,-164.782209,-147.500235,-131.643274,-131.555332,-181.413157,-227.461209,-322.759937,-331.117048,-213.138146,-123.83509,-118.14379,-78.536269,-60.765811,-125.001063,-192.06296,-257.542517,-172.758413,-114.059698,-44.406548,-33.703081,-34.557867,-37.58182,-26.493774,-11.90558,40.150331,104.414034,133.296518,126.705547,64.388237,-71.550567,-81.766784,-24.835974,-3.308752,7.861486,96.912082,143.514251,95.401453,13.956614,-87.980539,-80.094642,50.1206,196.406238,191.331612,70.183008,25.417438,8.256646,1.463132,-15.954647,49.201827,92.674551,134.692289,127.499364,28.623937,-53.146528,-197.092087,-227.290917,-162.351755,-50.867448,-24.620551,-33.558928,-63.005311,-131.134844,-165.164288,-186.775571,-82.962191,-23.784956,-2.936643,-60.697437,-260.073838,-325.818051,-301.806121,-261.008176,-243.372773,-305.878923,-339.775897,-366.234718,-348.840235,-301.278329,-291.075476,-266.628581,-251.166202,-242.755942,-208.063438,-212.572834,-256.421048,-242.973749,-132.793727,-94.151203,-68.917518,-66.449174,-82.843971,-122.275669,-155.98051,-202.385998,-175.917871,-108.240359,-100.152183,-70.439725,38.938885,50.24108,-25.503873,-16.416288,96.976029,104.236554,12.942844,8.81092,58.114521,110.357917,85.958289,19.810253,17.36345,114.447201,237.727805,236.287686,130.199392,90.588507,128.0247,171.866958,149.61157,73.441893,-47.919082,-28.954014,-21.091373,-60.195255,-82.004378,-117.997537,-149.013095,-208.162593,-176.838298,-133.499834,-76.441844,-94.716163,-215.449332,-282.127203,-381.414136,-399.052975,-338.308857,-250.369292,-228.685476,-228.778668,-246.955425,-257.808181,-246.221796,-268.146159,-359.445707,-394.740832,-357.569413,-306.145374,-270.2468,-278.617176,-255.616412,-230.714373,-224.552138,-256.110161,-255.121485,-232.675408,-232.874798,-259.135363,-249.367193,-125.596986,-25.558874,-5.703754,82.562744,123.352926,58.790061,-21.086224,-143.886281,-178.637523,-175.318392,-102.399673,-77.436649,-53.605447,-54.040426,-106.900972,-149.779308,-162.143481,-24.715932,38.337942,61.05529,36.328306,-75.243456,-143.376561,-205.698442,-187.648818,-89.502251,-11.263936,9.604681,5.650283,-28.031254,-95.91428,-129.782148,-207.021541,-167.607777,-117.294786,-114.17673,-186.74038,-348.276582,-357.608258,-263.189762,-215.457607,-120.276318,-71.486863,-89.172265,-124.595792,-123.700137,-127.20199,-148.857718,-198.358903,-137.232415,-74.584241,5.918296,16.652892,8.580316,3.815855,43.917332,66.702795,20.597583,-27.809263,-8.575944,23.477051,-3.727152,-118.371955,-168.519981,-163.875604,-39.704356,46.402804,217.127459,260.150335,195.737676,107.486659,-46.044304,-80.168545,-64.344896,12.26477,27.78748,-47.123504,-114.525989,-198.500458,-199.084087,-158.575087,-124.01591,-130.999284,-201.971905,-247.824643,-266.923814,-226.551802,-192.470667,-231.406616:backward
348.384299,235.938609,148.179769,54.171796,57.654576,111.969211,159.475228,236.757368,222.661976,196.770095,137.482994,136.416856,207.711382,227.038701,198.310814,192.350793,259.406853,352.453932,346.040081,227.06962,168.984235,129.917492,149.919522,196.96299,109.194384,42.14171,9.588338,45.1824,128.119315,159.640474,282.914931,381.764456,481.526409,255.327264,72.114152,-90.796931,-37.752746,90.397011,111.131227,112.208007,43.205932,-33.495374,-207.924954,-253.28385,-190.860097,-102.137983,93.787424,148.894769,107.452573,-19.658011,-92.438002,-192.752408,-169.778369,-61.156137,-52.511001,-128.469011,-139.79995,-120.852568,-145.221791,-142.032291,34.281674,147.693322,227.705691,208.557221,228.967976,315.069203,311.491328,280.106542,297.587292,332.939616,333.112856,334.006845,297.250132,257.422558,209.615954,213.678955,229.706272,233.050023,273.921353,297.687716,301.745202,240.607747,154.290122,-29.059083,-63.340539,-38.107359,-6.302256,38.092099,9.374104,-15.058992,-60.910423,-81.550318,-118.491648,-115.514476,0.987218,65.422393,7.083157,-161.099473,-182.129177,-72.454627,-2.808454,-28.613979,-104.904456,-169.586271,-83.183028,-23.636649,27.704998,-2.713149,-124.900372,-177.03092,-160.503624,-93.703648,-15.407946,-137.527138,-211.390986,-266.871303,-259.175513,-211.685748,-171.98595,-105.366883,-106.866341,-121.812328,-197.664262,-241.194955,-201.633832,-121.674801,10.599015,46.022614,84.036,35.941246,-3.477687,16.952495,79.406283,193.512437,218.84129,243.237558,235.747642,180.561111,7.985885,-15.749627,158.782548,268.859082,308.318268,238.890639,89.124578,87.320435,99.915432,24.291874,-36.927686,-54.406968,-6.494249,40.220349,-71.068909,-126.728475,-134.415667,-76.507595,64.970681,84.479473,59.944993,76.904024,180.664906,218.194512,195.271387,193.051953,215.578981,213.316143,183.798267,95.535176,53.32917,77.283072,148.218289,171.461143,212.75615,219.690815,183.615408,163.61673,149.149378,102.826399,68.673437,105.516404,163.381469,139.644931,50.895381,-93.33677,-100.799815,-93.722824,-143.319507,-172.600834,-133.582544,-64.68062,84.331685,117.670796,65.320203,-22.48499,-46.954128,-76.085311,-92.341032,-133.560583,-147.738831,-149.199819,-153.261033,-167.664768,-189.757818,-192.085588,-247.650275,-306.359644,-353.438022,-315.372419,-217.533138,-215.219766,-270.550865,-416.920075,-451.970096,-384.762313,-284.669216,-110.276489,-135.873436,-157.109631,-135.147024,-117.720862,-97.611176,-71.521106,37.515366,64.583954,-11.45886,-72.331851,-66.721847,-68.668602,-81.13436,-70.787796,-38.278867,7.481605,0.924754,-0.985305,-14.576532,-29.194916,-31.88842,-16.842372,-17.643477,-51.412855,-112.38983,-70.399361,-45.7046,14.289108,73.38215,141.779295,109.780518,-41.017176,-177.740465,-203.716541,-258.688687,-333.169068,-411.14626,-325.262344,-72.178031,-58.998945,-290.978598,-468.284557,-471.3689,-395.585676,-354.319912,-314.484608,-301.249421,-268.953872,-290.93951,-316.686955,-342.86427,-338.39674,-319.121148,-315.420012,-296.768629,-266.213252,-201.068102,-162.208931,-149.079383,-134.096664,-104.20596,21.62367,74.285769,18.006109,-135.776606,-151.534054,-158.501906,-190.467752,-194.619586,-157.925962,-134.626292,-155.767074,-164.580792,-100.363629,-63.90736,32.06508,85.545686,162.093992,184.366275,146.437417,55.947783,30.815606,-95.46386,-205.927153,-321.622231,-281.998128,-122.447386,-77.958503,-119.928234,-182.879806,-184.737573,-151.925452,-123.268489,-48.60729,-10.062935,66.651623,121.193313,113.735719,8.399521,-42.163683,-66.59176,-61.65644,29.386272,114.474031,228.11786,201.889943,147.930182,26.585357,-8.373261,16.343735,80.238022,207.126423,186.839618,139.478493,55.921909,57.048754,122.862024,137.64353,141.453072,144.965901,126.789996,79.497883,36.399605,-27.454559,-4.517137,79.690219,86.879671,30.926666,-34.790125,-42.980504,-3.243621,22.580887,-6.496475,-82.473957,-204.901731,-185.475796,-80.084434,-12.292717,6.292817,-1.853199,-11.542581,29.169489,87.610101,198.575868,107.377531,-6.613697,-135.792369,-88.431357,100.651931,130.275725,20.496061,-48.960772,-130.767039,-143.05912,-133.580944,-169.529673,-206.598547,-177.572343,-111.384001,-77.301447,-184.885911,-195.115139,-185.48406,-197.051041,-114.955165,-18.686524,78.079542,58.268412,31.61738,96.366538,149.478974,270.512298,306.522715,267.728581,219.383756,146.592466,65.857383,9.778799,-88.605016,-106.569973,-70.904208,-57.027777,-75.283863,-73.863286:268.571277,183.350051,127.399079,44.680214,32.536674,63.241637,79.538177,67.473595,122.958338,169.314934,125.440188,65.971131,72.535698,131.988136,207.26905,195.65574,156.532818,180.62415,165.938749,61.402313,28.298055,67.346572,139.716707,295.322382,207.260996,81.042427,-33.622166,3.4259,77.948359,100.04337,214.307106,291.769012,381.35593,282.110772,149.509239,-76.479134,-87.828161,39.335621,101.743359,108.111999,34.002261,4.869133,-53.25872,-75.951053,-73.826802,-45.254216,38.586913,61.12373,39.015364,-51.095323,-120.884453,-231.344912,-229.0852,-105.509912,-23.092408,68.774116,47.90092,25.104963,-37.310443,-51.468571,54.834928,155.829138,287.158931,272.720541,174.966458,147.480802,181.908622,306.365598,313.106977,144.155349,63.399736,65.828712,109.968056,108.30076,76.649138,59.592827,82.721651,131.455682,253.166367,274.691527,196.410307,94.820488,57.078417,-0.766175,-13.308586,-9.826749,3.352129,34.71045,4.815666,-52.658499,-185.492396,-174.774937,60.290994,189.255834,259.521673,195.232666,-11.118764,-110.91446,-84.851154,34.933303,69.30168,83.875284,98.119478,98.67636,42.419978,46.194701,99.787439,100.312012,62.464666,54.225648,30.756142,7.539603,-53.860545,-146.159811,-184.703336,-261.293708,-295.63068,-230.348701,-147.802094,-146.010025,-287.220329,-312.317607,-315.143631,-312.549154,-247.575469,-177.929706,-34.220555,8.840366,0.836652,-44.379795,-57.254117,-92.926814,-102.787851,16.097748,139.781165,266.149605,171.274128,131.837243,102.34408,96.558185,155.409329,218.517776,261.698672,214.462037,120.14559,158.118107,196.088202,193.051101,151.199825,129.731509,165.852065,186.05265,82.539435,20.583032,-27.234191,18.289102,152.86732,180.649852,193.492958,200.579121,192.50334,208.273125,230.374277,265.18093,265.341995,235.40704,213.488174,127.996415,76.225592,91.197927,81.755538,48.80135,45.775894,71.829807,78.895655,67.246956,78.966046,66.322101,40.759307,40.029331,51.007757,-17.937131,-80.37008,-138.619573,-163.228702,-207.710645,-326.67647,-347.353644,-233.258219,-140.303035,-41.248479,-47.435211,-132.998838,-280.105848,-325.935727,-310.434316,-284.945906,-228.443986,-189.304098,-194.402651,-307.900758,-325.684643,-261.413293,-219.875592,-196.757421,-214.989531,-225.514832,-194.985069,-149.959996,-231.108159,-292.960686,-338.043629,-291.156603,-118.509826,-41.111281,-10.673531,-119.541431,-155.121258,-141.369181,-109.732571,-46.455764,-13.393506,79.984487,112.157415,101.448998,28.106776,-7.145716,-41.635804,-50.217919,-66.802173,-62.635508,-56.055009,-86.425293,-103.393743,-126.753741,-112.70322,-49.032427,-31.407553,-17.184082,-20.336458,-76.247461,-144.277856,-145.738077,-28.850998,62.895538,146.687873,111.998348,-5.700243,-107.619468,-153.900903,-239.787939,-273.402842,-236.383857,-154.553819,-48.240505,-88.018885,-263.292304,-365.596386,-370.588108,-304.560135,-260.488446,-209.591687,-186.029419,-157.230958,-232.897091,-291.147736,-354.213578,-344.706383,-284.897871,-252.375566,-219.977633,-222.720978,-234.918276,-222.827088,-189.787727,-69.171309,-14.068839,52.917916,68.867194,-9.140881,-168.675518,-211.03881,-258.328682,-268.961322,-197.940946,-137.731519,-93.530434,-105.678153,-76.927026,34.244829,77.092564,99.513562,83.299617,62.077634,88.665745,133.819275,51.588439,5.234945,-49.867629,-65.51689,-74.715233,-70.805306,-43.466329,-16.016928,17.255579,-56.182364,-95.048505,-67.585984,-12.764475,106.72138,161.900126,210.122645,139.438514,92.99071,33.916856,26.937116,-18.849582,-68.176152,-35.477266,43.87556,139.160318,145.836926,114.351634,46.395148,53.871606,92.866946,103.165842,145.775592,155.491025,126.453608,67.275622,65.547092,153.647428,215.728325,253.156876,220.164146,174.494765,177.797303,128.054528,-24.427146,-25.551854,167.141036,233.150912,107.78917,-55.811735,-77.319106,-58.431244,-22.711573,58.803933,64.151701,28.241199,10.910778,-28.613905,-73.553969,-95.026556,-100.057086,-71.010812,31.297192,93.066648,195.057692,95.110895,-18.067894,-57.689467,38.566988,177.305275,143.184585,-21.316152,-76.999624,-86.279775,-57.301588,-66.665856,-144.545243,-173.684815,-106.273229,-33.607045,32.927963,-10.251386,-29.705181,-83.740667,-98.080713,21.977669,116.080061,116.798268,38.452173,25.796312,223.981184,289.209226,271.003816,243.614791,268.876001,291.671591,237.117465,125.621987,86.686106,-33.581847,-99.680692,-69.16497,-0.670732,9.886315,-41.945174:148.46335,126.606126,83.765579,-7.17358,-14.806213,56.117661,96.102634,112.388633,102.662918,91.589319,52.079035,57.945624,114.463303,140.060578,157.114193,142.65622,84.54989,-9.327212,-54.433177,-25.252712,54.114552,234.650286,298.945371,311.631195,182.289926,96.249347,0.981852,33.429821,158.982122,178.882356,163.477237,185.463481,294.108257,266.198183,180.800087,18.681652,-36.31106,-41.906612,18.743897,135.790665,98.385319,16.138509,-141.402572,-152.406772,-76.82802,-42.605478,1.762934,23.884804,17.772888,-102.048476,-173.195997,-225.754803,-194.797506,-53.84991,34.948352,127.625425,66.276995,32.73533,45.242157,101.160364,291.60581,375.498892,398.137933,353.589327,233.146767,108.246026,100.66607,226.769928,267.781475,159.153697,63.166737,-41.138877,-23.913999,-18.003458,-38.671878,-30.826063,-1.287108,-7.677203,15.009139,46.229832,13.895028,-114.954368,-148.563583,-110.180005,-64.869576,-9.849367,-9.359776,-35.863698,-55.962969,-79.297755,-125.252456,-97.808843,56.939209,142.165526,227.858056,187.75905,-0.735036,-35.001186,25.569553,159.112515,195.950561,173.585806,145.372356,102.014237,106.137662,145.971843,162.987779,130.548414,128.422448,154.241406,99.29477,6.052095,-154.907693,-163.647608,-161.071356,-193.814504,-201.099033,-161.429042,-126.660993,-113.491847,-177.730215,-202.211099,-225.737461,-217.588018,-121.793877,-47.901072,75.365404,108.229769,88.842188,-30.513233,-87.206877,-136.797418,-136.691662,-54.783907,49.68475,250.817741,277.073471,260.392636,211.083642,184.681234,210.903261,271.438051,345.539569,315.766697,224.34065,211.808226,217.423584,215.853216,197.321577,175.505709,215.782434,300.243463,183.401424,110.028673,124.522972,203.589856,348.578801,383.996501,405.985956,381.85299,281.839569,262.033844,289.452696,328.318219,302.734696,225.991447,223.899803,200.887077,119.577528,104.870852,107.59171,114.188426,152.119158,174.675811,180.734354,151.016296,74.981237,56.915881,60.621237,75.614115,85.790396,112.563698,129.950696,103.600564,-71.6314,-184.293209,-304.321719,-272.041537,-123.901322,-71.341959,-61.716805,-80.332697,-105.065389,-241.636681,-345.355699,-366.664505,-291.13841,-185.830151,-164.791057,-144.112228,-136.13097,-133.698518,-152.197915,-172.313073,-169.605004,-122.646936,-20.141405,-4.081606,-42.762456,-136.727945,-162.368474,-116.202086,-62.747035,43.134924,76.329993,30.368614,-70.174002,-86.920354,-98.292614,-94.895084,-41.37092,-11.346703,34.882982,60.896293,122.752884,140.742517,94.22872,-20.246006,-47.093037,-82.767959,-97.214117,-115.743507,-151.782917,-177.374837,-192.936972,-155.399158,-38.093914,-6.479163,-1.811855,-2.334387,-0.60848,-80.444868,-142.295454,-156.485284,-122.681744,-93.097302,-69.774273,-2.138366,-90.315815,-181.536837,-316.437738,-348.97668,-394.010601,-375.479417,-229.895599,-201.16599,-345.523422,-485.291407,-498.214663,-447.209704,-393.68329,-277.062519,-252.317525,-323.279207,-363.302554,-331.078361,-305.118504,-302.582807,-163.333339,-63.224076,-25.266585,-72.069197,-113.079524,-123.514237,-143.223501,-108.121616,-56.98275,9.906511,6.230636,-100.599003,-230.70005,-267.552027,-310.501911,-312.008359,-231.467915,-166.458961,-109.987024,-123.049856,-108.986584,-70.258753,-62.204891,11.682409,51.68939,39.867308,16.970593,-10.740344,-123.867438,-216.650372,-327.243651,-312.922979,-232.908843,-205.400686,-187.06872,-181.586071,-151.906713,-178.43306,-217.891921,-238.16166,-195.396724,-66.711315,-5.341227,69.879671,46.212088,-1.606073,-139.142819,-163.5525,-56.438208,3.283581,63.334447,85.057988,87.794352,48.270242,15.990976,-46.518478,-37.194486,62.1279,107.799284,101.804258,20.533735,22.837193,128.125828,165.843117,173.765103,181.262639,211.432974,212.013602,167.42879,62.330652,0.468274,-35.707809,10.888271,180.418944,234.811516,165.069111,28.473158,-26.296542,-86.828043,-71.644384,-35.772697,-39.99012,-11.266236,5.984288,-33.221307,-73.829397,-87.27596,-158.607316,-196.29348,-131.586067,-27.03695,117.149105,89.038832,60.153598,49.246038,67.629416,93.015761,80.414484,5.268246,-40.673112,-87.651434,-78.06437,-99.39716,-158.372452,-129.113079,36.948279,111.613917,126.108796,16.700439,-21.694972,-42.706775,-24.584566,83.595974,141.575843,177.659884,164.175565,152.363376,234.102835,279.967432,252.145533,197.671233,181.536741,236.614541,293.865947,87.56763,-40.909607,-99.414727,-39.921734,83.280142,105.014225,62.325076,25.989889:251.705391,179.331601,124.207089,69.76672,70.364284,74.103955,73.315549,72.921726,101.21603,109.557551,45.774672,15.600605,80.026453,144.891927,232.142726,241.67914,184.954491,98.825003,77.643836,79.668118,86.615103,110.636997,155.499526,255.362069,185.286174,105.420545,-7.787786,-12.220282,57.471045,98.752492,219.763503,305.772393,398.168635,287.291387,191.459086,45.922539,21.773083,62.083905,101.441967,116.899792,1.420467,-80.520995,-212.026999,-215.979181,-133.332725,-101.537535,-39.900736,0.338866,-19.479972,-216.550307,-307.989193,-323.671077,-253.548512,-60.26653,26.146653,73.51784,-24.693165,-60.420782,-63.281951,-34.432812,101.611248,194.418753,342.446445,374.230894,353.336667,255.506204,219.062011,233.328107,247.164201,183.404038,116.325012,18.462513,23.570878,29.427772,-13.447311,-34.151644,-33.925764,-33.266489,-2.069901,33.952478,52.066212,-21.699903,-70.663316,-133.98758,-123.064867,-37.235967,0.281631,2.136977,-72.235026,-115.07826,-168.024344,-147.770675,-14.297788,43.343145,75.71554,72.509306,44.870297,13.461781,24.177004,78.238249,81.870618,35.054819,25.735529,29.606612,45.421877,80.834224,102.185075,67.144267,-35.955276,-90.239756,-136.74027,-110.641612,-44.365946,-103.549142,-167.385284,-233.767039,-216.695116,-104.816807,-36.150907,7.325652,-95.023474,-143.340559,-160.885076,-144.913241,-104.273032,-68.334007,61.375319,128.684447,142.545953,-1.263727,-68.168985,-92.761002,-62.200154,35.661588,103.247482,194.747979,142.60025,111.957389,132.508957,173.200986,287.464601,349.732254,420.441953,411.209892,357.934841,358.25342,351.937099,250.833961,194.351834,219.207703,300.751287,388.915864,215.97838,125.194161,107.431829,159.703024,256.915352,284.037569,359.544577,394.148603,367.514862,258.332432,203.979252,192.240025,231.33686,262.564756,246.275326,210.5916,178.117501,162.610673,127.682639,125.939876,200.206396,246.886237,262.324175,225.546572,127.01329,82.299478,92.79175,148.891114,155.084993,127.277471,154.866451,246.579683,147.685887,58.123509,-57.240452,-68.388733,-12.934747,31.062171,96.036488,106.263699,61.713025,-40.019951,-82.247477,-77.66731,-39.618912,-5.615794,-28.601302,-115.886237,-154.667304,-134.448208,-63.691031,-45.028333,-67.034014,-88.443583,-121.910768,-127.628356,-73.507515,-95.946573,-199.353473,-323.259336,-253.188134,-56.042221,-26.068774,-96.649344,-167.604044,-150.235312,-83.475114,-80.796898,-120.708407,-120.397454,-15.288163,41.363799,37.830832,-18.716706,-36.992499,-43.579183,-33.926988,-27.999962,-25.079324,-20.059292,-62.808282,-87.755591,-126.009283,-125.196641,-73.958128,-51.078059,-33.694677,-32.144753,-76.611903,-147.956413,-139.35453,-29.187793,24.0318,49.214523,25.729778,-90.659225,-207.375148,-226.662931,-270.170393,-319.421826,-399.856132,-393.768639,-303.236679,-278.657502,-355.858633,-464.767527,-482.183794,-407.777432,-348.640351,-289.349939,-284.327508,-341.09185,-384.059041,-352.88488,-334.163606,-367.429385,-370.420578,-315.239574,-185.827743,-160.13541,-210.098734,-237.073061,-204.465655,-120.229179,-110.632076,-124.07374,-105.672319,-119.788424,-270.585396,-315.041401,-337.524116,-364.09634,-376.485434,-330.150405,-233.944672,-225.296817,-271.442674,-235.607624,-157.09906,-9.755772,14.194661,7.331691,13.134332,-20.145914,-169.304019,-250.817872,-408.718574,-441.283246,-350.560658,-300.431064,-279.182169,-253.753946,-166.075299,-205.630618,-278.511482,-374.308211,-353.728223,-232.958355,-166.758789,-73.868134,-81.678375,-117.351696,-191.532933,-188.142494,-135.310185,-148.687383,-174.540615,-124.741769,-0.037081,20.005911,-18.04145,-133.85521,-157.17371,-69.002647,17.503464,109.469836,50.346896,37.063586,54.049277,53.330967,64.070173,94.853189,166.577239,160.134288,64.48527,47.266044,43.016558,-48.516184,-60.870444,100.909999,186.617199,154.404887,16.151047,-10.921124,-16.825294,-12.526416,-32.900703,-71.260957,-95.019254,-58.088182,-8.007878,-51.865817,-86.802614,-124.210553,-104.179935,21.798166,99.435957,178.464514,166.252555,152.384701,113.902633,110.457458,143.076675,134.594653,26.373239,-48.65213,-185.293471,-235.750639,-232.891111,-188.154054,-137.342802,-5.736426,47.3005,69.874473,21.333121,9.141983,-29.033582,-55.195389,-8.077488,56.042211,119.013119,102.759573,88.27651,217.244504,299.656461,328.576751,268.90657,188.738512,220.617728,287.790581,176.040417,89.878736,-39.477471,-66.632521,-37.242863,-1.287796,41.559461,36.187426:142.061166,46.644105,27.056887,44.372528,52.860754,69.579474,88.349485,88.341176,24.598103,-16.196298,-105.815147,-126.580197,-60.878417,11.028592,143.482224,168.513438,104.569987,-44.628055,-120.887626,-178.380291,-132.573886,50.218093,132.744786,157.80713,2.008833,-89.010991,-176.094241,-142.626542,6.038517,58.578095,97.936235,107.377135,113.103932,50.823371,2.756442,-39.539534,-33.527191,-16.91187,-12.1133,-20.778972,-78.145995,-128.157119,-215.438315,-206.308084,-103.103716,-61.18279,-17.482387,-3.01127,-19.865083,-147.864375,-227.992084,-284.454105,-248.296168,-76.610447,32.781919,135.932141,49.343306,-4.696305,-30.596065,25.682544,213.032746,287.871265,363.438654,354.668082,216.299911,80.797887,86.138264,168.396932,158.154522,11.384964,-58.217588,-99.866497,-81.135393,-100.400865,-168.389963,-162.96152,-97.119634,-82.290383,-80.056188,-78.6037,-100.89335,-131.232558,-146.363892,-193.464816,-189.267292,-81.403592,-22.989459,10.142276,-57.965097,-104.443034,-138.695924,-109.681848,-4.865404,51.736132,137.002684,141.87662,94.087116,16.65888,-14.894596,52.202079,125.208678,168.555806,144.016603,86.341089,50.07831,36.739521,-18.443684,-31.797085,-2.35757,-2.56065,-75.584472,-128.755013,-213.372919,-258.350826,-277.25061,-263.077585,-223.857236,-139.760165,-101.311167,-80.311794,-218.406826,-288.42828,-284.715708,-228.387725,-118.207586,-77.743544,19.348405,71.323428,61.308204,-128.821531,-202.983496,-180.5548,-125.686927,-12.452707,54.909573,153.379665,127.521763,93.959875,59.431161,71.746781,151.299465,206.478798,274.698415,269.823518,266.522085,308.555108,291.940138,190.570046,145.08539,135.644241,195.845713,307.606225,192.21462,109.100206,65.50294,106.993711,215.105428,251.454144,317.477017,342.605889,316.907334,189.019964,119.580791,83.889956,117.977262,215.249266,257.343729,264.283441,124.995884,33.155235,-76.232478,-54.948948,106.326875,181.946705,224.542498,202.047284,132.77321,43.627067,7.892142,27.009788,72.710413,163.884288,208.462057,253.213921,114.83504,-11.872766,-222.569125,-225.816704,-43.746084,33.475061,24.967215,-9.810205,-73.340497,-246.751795,-325.959967,-255.39901,-156.358036,-66.277789,-63.791456,-63.161112,-61.660331,-53.094994,-57.385042,-80.864656,-94.674247,-58.687396,23.987901,19.766278,-88.064734,-229.998508,-261.794965,-163.477477,-73.51203,55.362336,82.913637,37.028458,-67.594841,-91.600518,-123.457761,-135.275738,-60.794043,26.758912,178.544347,192.040321,94.855258,1.996971,-5.498233,29.226629,39.877426,3.615652,-8.076904,1.008689,-50.242,-92.815901,-163.598098,-173.259715,-94.447314,-21.573257,59.349921,41.017342,-57.939215,-140.202723,-125.183636,4.818067,40.398056,-0.241226,-14.665607,-45.465788,-171.01871,-224.786295,-285.758585,-315.209659,-333.74903,-281.896466,-98.018196,-50.853114,-144.064939,-305.438168,-344.910182,-287.827081,-220.089768,-156.995674,-171.548387,-204.669774,-149.904305,-131.47492,-208.668634,-225.701294,-62.720716,54.187352,146.745341,110.637137,3.269253,-36.036815,-46.732574,-21.934992,18.766864,71.433185,68.024399,19.492301,-57.032427,-113.886325,-220.664242,-234.60229,-184.711959,-144.931338,-80.917199,-69.841485,-66.71193,-78.397024,-103.288897,-86.344938,-11.329853,159.520324,186.68634,73.854714,-125.47162,-209.38264,-311.675484,-315.119236,-266.276502,-248.495153,-222.001586,-199.376405,-161.56773,-233.075363,-298.313293,-319.995773,-263.60082,-134.165069,-85.598415,-77.28573,-161.748607,-183.965447,-203.824266,-200.531913,-111.065084,-45.387014,55.620905,68.586179,-4.190222,-72.0453,-84.759211,-66.806004,-23.169444,80.601312,113.238094,99.732191,-1.208935,-36.800736,-29.655933,-1.671688,102.708567,175.797366,255.503156,239.975508,159.612934,35.142015,-23.466248,-21.318088,24.372212,112.192947,144.994164,145.526215,50.98653,10.41181,-22.57672,-41.161864,-112.763842,-127.103751,-57.368832,-19.685758,13.563426,9.8553,-26.653046,-52.733046,-6.62254,92.562288,105.235945,67.025993,39.27004,33.70191,34.045852,81.545664,259.365579,318.054308,262.450217,149.029756,-108.086741,-178.609175,-177.929895,-198.240752,-159.221699,86.641248,218.327938,273.91854,116.629256,48.781043,-29.961888,-36.513533,56.314445,135.225221,235.31497,219.728304,154.990601,206.427791,230.167112,207.061463,190.584069,233.758045,292.884561,327.606116,150.782293,66.730743,19.301226,19.849031,25.644466,58.860231,153.636736,156.777405:250.502228,233.906668,228.59696,221.752262,201.343925,121.959125,96.549406,80.825774,14.405573,-48.396489,-148.66277,-126.14718,69.566338,160.984276,201.322181,172.690608,118.777553,98.41862,64.522765,-39.247263,-60.507503,-2.852916,49.63789,85.148684,-41.058443,-115.986396,-157.744836,-99.956871,72.856716,122.226899,193.254312,265.355705,389.79689,263.909738,129.405752,-43.295014,-40.066546,12.453095,11.992353,-38.061207,-151.058755,-225.390226,-341.067585,-341.153704,-211.726699,-118.083946,61.11848,113.521,61.956258,-87.332548,-156.463033,-232.937573,-198.755677,-29.7173,18.456518,-51.40409,-169.863317,-189.076314,-160.772371,-117.025977,34.457779,125.767261,255.354234,279.833198,309.976049,310.865811,272.202557,200.024414,196.780766,188.543198,157.813933,105.215318,144.858884,159.170169,56.390111,-16.121385,-0.729637,59.190711,118.92816,119.750234,81.203062,-18.08302,-74.634016,-105.510743,-59.731712,64.985369,99.197311,79.878105,-16.78663,-71.085489,-153.828802,-168.398323,-128.076321,-77.009706,23.864484,42.149708,33.43007,34.0473,34.461784,50.084108,56.613649,-30.003375,-111.468579,-185.136169,-102.80887,-55.331364,-66.44763,-123.111493,-237.777228,-254.287399,-195.733932,-165.21706,-178.80555,-265.427343,-313.284272,-321.889747,-254.397588,-71.080646,-10.328973,27.775229,-10.905297,-48.773429,-142.857395,-169.320485,-124.961082,-71.261208,34.281106,61.741126,22.18196,-21.31696,-3.329049,56.928456,75.054504,62.821502,55.311311,85.523999,64.648388,34.43986,21.472188,50.196791,146.102052,174.270655,142.233945,107.775644,67.434821,54.358576,22.826408,-118.374384,-178.878653,-150.349926,-69.522993,56.111937,3.6353,-52.262142,-139.98651,-142.267405,-32.468923,37.199616,94.934483,91.013713,106.654324,85.689454,24.931544,-34.803287,1.134421,78.621706,90.151218,83.791174,55.967427,55.644729,104.663465,143.661143,234.826725,266.83928,281.362345,279.044471,279.423271,273.22157,240.014553,116.967012,81.181265,112.535577,143.81423,171.858732,158.123168,120.163001,-27.118628,-72.398485,35.807666,140.59024,222.038357,201.543865,152.341793,21.722907,-57.912577,-68.344018,-5.113426,66.930927,33.1587,-108.297773,-178.942647,-160.861869,-113.182994,-118.547348,-144.257311,-140.512475,-127.189744,-143.216993,-234.037792,-333.576151,-378.977389,-422.720437,-393.255653,-259.455836,-193.494779,-140.020346,-155.049818,-148.434604,-125.421717,-124.823983,-110.451066,-75.299499,62.286563,114.966864,52.482179,-58.633486,-60.790328,-52.193525,-58.268536,-19.245815,24.555899,44.435604,-19.784586,-34.787965,-25.25962,-11.678237,3.774403,-5.657458,-61.409357,-100.764482,-159.332585,-121.630111,-69.716544,38.360277,77.647655,95.08194,64.432508,-41.529664,-91.066995,-100.24567,-203.794661,-284.773521,-364.313535,-340.183796,-233.398462,-199.07579,-249.022769,-386.539174,-423.111967,-352.007652,-273.595867,-201.136349,-224.430971,-257.557438,-223.558374,-231.9812,-329.286985,-374.538783,-318.294414,-208.045324,-6.653366,6.856178,-84.241213,-102.301981,-75.443893,-72.04084,-88.032358,-34.96838,10.598737,-38.428316,-183.501753,-199.935747,-186.141061,-194.810086,-181.566875,-158.304559,-124.661851,-91.892603,2.361361,-25.085486,-56.354218,33.784954,118.9842,161.546183,132.322768,78.983456,17.869059,-16.512806,-130.002164,-214.477173,-326.934191,-316.759117,-194.339099,-141.564744,-148.873573,-188.493719,-206.793479,-274.276888,-279.605333,-161.86073,-71.224349,67.95353,76.166763,24.324792,-118.659367,-150.713507,-117.167479,-107.572505,-107.252085,-71.152809,41.379035,56.178129,2.844989,-102.728046,-67.85553,124.983218,177.356087,138.401467,97.200397,105.704493,123.027676,132.490898,152.359533,143.841817,146.172123,165.003815,135.294116,72.238943,72.101064,95.632054,111.877275,150.302166,150.488512,98.517817,51.384501,35.774345,-0.544024,-4.432142,0.899338,-32.914594,-125.34966,-113.560831,21.750585,109.571705,113.244152,133.653846,168.21254,238.532576,277.417262,315.664472,232.903719,192.401444,160.287525,159.765509,189.140273,198.378833,146.048816,80.940705,-106.006779,-231.090616,-216.593132,-98.611304,-52.721689,13.885012,68.588388,151.615093,108.329079,67.464841,-71.358772,-150.934981,-135.924737,-33.634576,127.713307,124.353209,79.456269,179.142362,221.95408,174.05841,136.554152,149.551943,180.115864,187.304401,139.145688,132.576859,85.546092,29.949863,0.113826,58.257694,173.64752,167.975996:234.587835,180.740653,128.655823,55.856734,45.646937,52.94379,69.10771,88.436109,32.148969,-29.467856,-166.318853,-175.942566,-35.694048,51.9997,160.59619,175.54929,86.421128,-98.490903,-155.046453,-163.80666,-149.216558,-79.601425,-10.738486,105.592828,45.334138,-48.996725,-204.166202,-202.955355,-92.63687,-33.107383,81.640666,138.719464,198.768389,106.38596,6.79984,-123.874818,-107.853822,-21.318644,0.101746,-18.354369,-113.827727,-182.52833,-298.632939,-294.09563,-161.214657,-92.733692,18.337771,73.44482,86.242656,-118.724911,-249.505326,-338.301517,-262.543975,-30.062001,55.250812,81.617291,-46.568262,-98.946374,-113.198784,-79.79277,100.07922,233.87774,419.007789,416.293776,289.149172,161.453363,111.619099,35.027361,22.480315,55.94125,65.604781,47.495695,6.022075,-51.372812,-182.571559,-201.360442,-114.0349,-44.520151,39.847508,52.224529,30.376269,-81.319662,-144.664114,-168.875034,-121.160713,16.973306,74.688222,91.994617,-35.290013,-122.936002,-248.199335,-241.019908,-107.26991,-31.61462,78.74313,103.648236,93.780864,46.402651,5.997671,-19.089265,14.041528,37.726941,9.65938,-68.874833,-104.894262,-92.127286,-67.880356,-70.363319,-128.738941,-178.717823,-214.193319,-185.384291,-112.379672,-152.870189,-238.742351,-355.606441,-297.596673,-44.227167,39.090238,32.814598,-62.038381,-106.902006,-202.029259,-235.963994,-196.267194,-121.359803,68.949173,127.666099,64.33118,-115.833714,-170.8338,-146.650362,-87.668024,28.089901,70.89372,101.497655,11.35565,-35.824818,-43.63198,-14.500132,83.439676,142.418569,225.597252,243.408011,248.257899,161.063873,88.508018,4.732741,10.594469,104.43517,182.860407,228.458587,34.31261,-49.083139,-64.817547,-12.278018,141.918421,195.686118,204.860642,178.165332,105.029747,4.739925,-45.206818,-77.725902,-57.37457,17.907224,64.166556,124.064548,109.101791,87.22324,8.557132,-15.272708,88.631293,191.838921,327.243971,335.466043,284.024835,178.612063,117.42127,46.541974,57.659529,156.962997,209.33382,206.497017,88.479853,37.59682,-70.679697,-111.184238,-41.436649,57.879936,197.642757,184.883893,57.773457,-88.752995,-147.651446,-146.45272,-86.115621,25.084797,49.745478,45.269641,-45.28649,-102.878625,-163.277213,-174.316633,-209.572996,-203.135011,-108.495527,-85.288784,-153.795683,-279.966265,-354.439681,-412.203799,-354.52707,-151.245316,-70.08519,-45.447156,-148.365019,-187.009626,-176.131656,-138.819233,-74.700142,-42.550207,79.027309,126.46574,66.124536,-62.861593,-83.729722,-56.1564,-26.18287,68.139402,130.023393,141.464194,-37.310892,-102.108066,-109.220253,-86.560153,-88.820452,-105.425348,-89.294377,-68.164597,-81.93198,-144.665697,-153.270687,-86.566644,-13.412071,130.227716,148.935539,29.582948,-128.712398,-152.524239,-164.080818,-184.748824,-196.222835,-162.591705,-50.512152,-19.105157,-99.466481,-236.329766,-256.714138,-186.675534,-123.26827,-32.00539,-21.855468,-49.037867,-74.479061,-99.262678,-245.716125,-306.956953,-192.507643,-41.723258,186.002168,194.243316,57.03076,-39.19652,-33.25163,13.530023,28.27199,32.729855,17.162119,-79.542094,-192.170896,-213.983203,-230.858421,-232.534725,-170.317685,-121.891868,-50.274314,-30.059457,-26.247043,-53.984485,-53.931168,21.588675,76.946698,158.581189,185.507127,164.326943,24.01212,-62.130285,-237.746985,-297.066268,-284.054472,-236.293783,-151.955438,-125.246553,-117.703539,-198.293879,-255.359428,-322.257501,-303.81891,-183.203633,-109.396572,-22.172316,-67.249533,-111.296168,-180.650792,-174.244756,-86.608898,-56.277535,-20.425335,17.055923,73.269196,-2.023598,-64.520048,-97.470713,-44.104863,115.931796,184.148095,245.469018,159.654928,81.758035,-42.819898,-35.807606,112.616131,171.330566,198.893455,204.462057,191.328792,119.293431,60.558894,-53.561092,-60.713576,71.92941,156.93963,182.146554,49.720777,1.150631,-30.387152,-40.750093,-53.976809,-38.805839,32.123203,36.477162,-77.584372,-156.715726,-155.827153,-91.32663,-14.242396,173.226336,244.008164,262.726316,152.288999,101.491672,78.967994,132.160904,290.556044,319.266136,205.068362,86.828077,-157.14893,-264.375534,-259.285566,-191.658056,-131.504531,70.538579,188.536402,254.411655,73.201545,-13.060546,-112.495489,-127.863565,-36.655603,49.471162,171.767162,190.229421,190.637732,185.389521,175.63691,163.516951,161.989039,184.771784,226.925882,282.322507,161.055833,68.152819,-43.226402,-41.34334,43.78735,106.339564,211.880578,216.430108:229.680869,238.157213,257.312308,260.95199,257.643059,263.431094,248.56667,137.325507,-30.139245,-94.296604,-170.168224,-165.671765,-16.08651,72.094254,114.116048,80.649838,-8.216542,-72.239907,-88.591119,-123.102783,-144.227574,-160.604691,-144.585925,-101.903734,-175.849532,-238.913491,-248.341439,-189.903839,-75.716261,-32.641791,110.577752,189.302633,206.856014,55.528717,-39.375858,-191.83083,-236.870927,-261.532616,-233.322488,-151.679489,-168.726094,-200.324274,-240.797887,-225.875415,-56.536756,79.61866,278.33549,296.174336,227.307626,117.324856,39.289278,-103.791351,-111.307866,-13.600837,35.647564,23.452051,-100.8067,-151.88075,-199.892721,-192.489813,-50.073434,81.949333,275.051657,274.298833,191.157402,144.33027,106.464927,11.945216,-5.257632,-2.340405,-24.490587,-111.05846,-98.004683,-51.626652,-40.38395,-77.212445,-88.399594,-40.490317,101.911101,160.79588,190.751491,132.417732,96.401008,60.010985,84.137839,194.395774,232.228804,169.707391,3.178392,-36.074299,-52.668333,-87.608409,-144.1126,-113.200816,5.292982,45.729116,57.880023,5.262955,-17.569879,9.06465,20.801997,-83.994194,-150.864508,-169.870084,-96.257658,-51.387431,-52.654765,-123.075722,-293.752634,-336.387046,-316.109316,-283.266524,-241.641289,-300.594944,-361.945172,-385.00238,-323.050627,-197.576137,-155.577785,-52.353775,6.756115,4.286526,-16.2842,-29.886258,-74.5774,-102.867958,-124.239311,-118.407587,-110.358623,-27.687061,36.424121,79.953612,52.287955,-11.840304,-24.213272,-48.129264,-132.878976,-168.279205,-181.529384,-167.300585,-130.374713,-121.412646,-130.657383,-148.396282,-205.147699,-232.029886,-234.745784,-297.765749,-368.008875,-458.192122,-418.341427,-274.907399,-272.601256,-295.853342,-312.052563,-316.567588,-313.646199,-293.857982,-210.097159,-149.781101,-44.897291,-97.700007,-180.349988,-254.151972,-217.293235,-135.250613,-115.111214,-65.402867,0.769666,24.187099,37.186403,40.807565,98.045682,152.307498,251.698429,258.583306,220.33732,264.224742,275.01865,243.068336,255.788013,323.60728,336.4783,315.144161,298.018471,280.03299,154.886077,92.665053,101.937687,136.70867,166.517491,161.343015,103.6329,10.046582,-30.087385,-42.443944,-15.57172,-13.822214,-60.333414,-131.907071,-106.897272,-103.910552,-164.088625,-196.103153,-228.766595,-242.880154,-249.509865,-241.589771,-277.235209,-387.720446,-422.920235,-374.378986,-317.099234,-260.629808,-261.226497,-212.673547,-108.675719,-82.196817,-69.456727,-52.384068,13.355957,38.05162,65.916617,63.017382,14.350941,56.178979,117.592899,152.131673,99.56251,26.670745,67.614193,179.488761,147.629489,126.330306,153.1371,161.359806,110.356244,63.89192,0.233522,8.235098,58.786144,80.537285,78.087037,63.876938,72.576031,76.563817,40.490985,-34.284904,-19.71361,-8.46257,-71.043833,-138.347885,-194.970247,-140.366068,24.517793,69.466656,77.599004,49.629911,33.679515,56.639024,82.721416,59.187907,31.046224,31.717054,5.565541,-36.263854,-85.065187,-85.007096,-72.524475,-49.455193,72.070337,140.085632,158.475503,47.818831,-15.367201,-68.786474,-40.44705,34.291313,27.633922,-78.898692,-89.158914,-27.100229,33.084872,10.055355,-18.760574,-8.871629,90.534471,177.144856,292.635804,200.3975,121.216653,113.189712,179.712039,279.563386,292.988085,261.712993,219.92465,211.57379,93.190301,-1.01306,-63.224242,-49.833022,-73.879663,-95.336345,-95.207153,-38.64074,-15.308213,-48.245514,-83.394716,-63.668514,17.186829,210.619778,256.390756,238.60623,172.111813,112.604745,-43.217478,-105.489286,-98.26614,-27.48762,132.731479,179.156859,153.830082,94.37706,89.991594,113.904007,128.184179,127.837858,107.989653,111.938721,132.175559,143.133474,138.891328,103.794575,-5.266595,-52.918314,-91.623776,-20.702992,9.830933,-26.764025,-52.05418,18.616538,74.497998,15.62655,-137.000854,-149.010297,-117.055272,-108.754771,-103.307214,-123.353151,-185.119914,-180.488248,-73.198309,14.32869,9.803489,33.084095,108.384992,271.743736,288.455895,160.213465,-3.73359,-16.328587,42.74216,57.104175,52.070406,34.922766,-18.772009,-28.86999,-40.550152,-97.815112,-126.567406,-187.289112,-216.83659,-198.290633,-148.994984,-42.93623,14.773295,16.24576,-68.384218,-126.139423,-120.158335,-68.56783,-24.540445,-31.156237,18.629506,104.555551,96.470566,-6.147083,-46.88137,-29.098967,28.21815,150.318644,109.828886,53.490781,26.709936,53.319962,91.545031,84.512571,30.235468,7.916676:353.016618,245.457115,168.697991,145.887154,209.77487,320.438496,315.344427,213.809543,118.534032,106.89121,88.724375,96.774553,243.533076,308.252608,227.005742,138.977578,68.201894,151.42558,201.883664,192.072485,124.946865,-2.302235,-2.555742,53.947753,-35.942347,-99.423498,-73.125945,9.077427,118.082035,112.858432,154.114288,240.404387,341.111573,120.233569,-39.722743,-165.303309,-125.220508,-37.153858,-21.503139,-1.692383,-31.472134,-86.952751,-225.744309,-255.457902,-158.485276,-45.106739,206.659947,276.726095,223.532219,104.048895,66.494519,32.824897,37.522696,13.335455,-22.999027,-98.466125,-168.879853,-186.173986,-202.567367,-201.397298,-79.153466,27.338541,134.31159,113.921546,90.226841,199.10026,251.098732,295.731881,299.03126,285.889485,298.589421,372.640859,365.301652,329.415834,262.391248,228.690805,187.968685,206.522476,310.51575,352.865735,350.912712,249.029286,157.195753,4.094801,8.463691,137.623678,193.111374,175.546121,8.654304,-61.405236,-95.530545,-93.159849,-111.595546,-103.527784,28.682277,101.230456,57.567019,-102.758108,-117.17453,6.411065,69.206162,53.625901,-2.023614,-97.166492,-99.343055,-68.698956,-40.934657,-75.844247,-185.449968,-214.562439,-183.47487,-144.215565,-81.154827,-122.670036,-200.255301,-326.513425,-319.547695,-223.183505,-161.583325,-37.876515,38.348387,51.973227,-26.107713,-101.103131,-145.250364,-90.96888,36.991909,62.978394,72.385995,134.967991,192.855082,325.04573,366.436791,342.615169,289.82295,159.355682,42.851919,7.806323,-62.276946,-95.650526,-76.669917,-42.240597,-33.339324,-63.945249,-110.569648,-112.946915,-147.456183,-299.996529,-354.421743,-325.537368,-281.413796,-241.924256,-217.239915,-198.955869,-203.00534,-216.899414,-227.023637,-234.684943,-225.384653,-167.574744,2.413014,23.968507,-20.805918,-37.893737,12.12659,139.989855,176.547216,154.692044,143.081472,170.425733,238.59517,285.006022,411.858598,445.2895,386.644334,335.434992,317.469127,360.593992,343.411166,297.509655,314.621278,345.905415,318.082342,209.818153,170.430182,195.973569,249.038422,244.854458,191.265117,172.147702,215.327581,265.913137,307.251251,231.940596,183.981721,115.216097,87.148757,15.500957,-6.476587,20.789086,58.758679,51.400188,-45.216885,-124.744519,-257.380147,-294.403552,-303.076569,-279.650557,-253.671838,-321.0502,-370.885019,-411.523503,-400.780966,-346.165579,-280.615655,-120.370822,-86.541061,-96.075833,-73.873094,-47.817864,-3.775752,15.459926,59.041678,66.411673,16.866304,19.088882,56.864975,66.612421,34.611868,0.856678,12.89222,36.110293,41.7964,51.006504,92.398086,124.883764,143.827751,104.902326,10.538541,-1.99543,45.766686,64.336443,31.904412,-19.519565,-15.323154,-34.124029,-73.160832,-135.055366,-196.178691,-234.791187,-301.798195,-337.013923,-383.154211,-366.751723,-259.277769,-216.771919,-260.951293,-376.814255,-397.43164,-332.048574,-265.236271,-157.68947,-136.749307,-153.886134,-244.024545,-278.525917,-292.53683,-298.523691,-323.557758,-323.312336,-236.887279,-166.484233,-92.908888,-111.137928,-132.482863,-154.68161,-113.033118,56.237501,106.000972,16.786314,-109.854584,-102.922282,-61.204121,-67.20618,-105.645866,-135.480457,-152.807849,-101.373629,84.957479,154.188672,103.677295,-21.415234,-32.946073,89.325337,188.019712,264.040168,146.913735,80.401334,-71.158982,-162.315466,-278.024311,-282.603685,-260.12379,-255.229665,-249.169312,-246.758689,-255.175784,-243.146644,-191.719697,-26.262868,42.637788,101.288333,110.097303,102.011774,43.411615,15.027326,-50.739735,-114.335217,-145.863941,-58.577658,129.913654,95.877768,32.13482,-39.627542,-32.546404,1.599463,18.20899,52.916067,37.700652,13.944727,-50.519808,-71.700578,-37.229542,-5.695959,-14.873934,-67.011949,-186.335503,-181.143725,-150.360649,-131.915633,-139.085577,-168.283095,-203.585467,-313.267446,-341.046373,-298.100082,-219.092286,-219.53239,-273.080599,-305.491741,-291.57525,-233.618629,-118.631057,-78.463588,-86.731311,-86.847019,-50.951934,42.029807,65.335225,45.790875,-71.335775,-145.340368,-202.969423,-163.177085,-45.593397,-23.430208,-56.328345,-82.52447,-116.772099,-118.229255,-137.669827,-249.913482,-295.479249,-296.339846,-271.566927,-249.477684,-260.410543,-230.742526,-178.344486,-193.590032,-163.272254,-100.235835,-49.033542,-71.437857,-83.647625,-46.569663,-45.467417,-56.351602,-33.819326,37.854856,52.07589,37.738949,-29.513917,-83.062854,-149.454403,-127.851647,-28.731137,-10.411335,-72.122503,-106.420526:308.39057,332.857886,302.277676,222.569319,192.06442,152.019001,166.381271,169.900913,-14.070893,-80.782229,-61.796108,-23.302623,86.296881,150.31213,197.819316,184.63526,142.507717,74.639115,27.983478,-79.020157,-106.976762,-58.368088,-5.154894,82.823447,78.111571,59.567499,18.658861,-19.860964,-72.548519,-57.521933,47.879225,127.222562,246.882251,164.4593,46.404066,-177.934566,-210.014786,-104.114607,-44.128331,-79.021967,-229.27706,-258.890269,-210.190523,-160.340165,-7.625436,75.516785,190.313938,222.586126,195.96183,-12.464951,-137.556121,-200.544735,-118.517562,58.912007,74.163607,10.599638,1.375586,1.850003,-48.783565,-63.525218,19.873541,103.485115,260.170362,286.698506,194.009831,41.562422,-34.921292,-161.392456,-165.350781,-79.747194,-63.379218,-99.925434,-70.852021,-45.455246,-89.191048,-154.265655,-197.013342,-142.845181,-7.565424,24.323826,20.954961,-7.231048,-38.09055,-64.871508,-28.375736,86.719177,137.402889,153.360219,31.548886,-30.137025,-94.368915,-105.911185,-106.182276,-98.188313,-12.503748,62.242136,116.994207,5.115644,-36.633303,3.244485,16.654519,-99.962254,-171.731094,-216.517086,-179.874906,-138.059216,-92.513723,-126.241091,-225.825504,-255.826116,-296.984619,-315.038981,-311.165313,-323.634618,-361.067993,-372.912379,-288.447446,-11.810638,85.2991,87.883248,-31.249542,-74.294983,-94.340872,-87.420985,-85.006427,-96.730769,-108.236029,-79.796721,8.698118,36.831081,1.156145,-57.008388,-22.817918,55.846796,50.116609,-18.320745,-69.793455,-73.721605,-88.385957,-89.888874,-32.816781,-6.911138,7.10256,22.218742,66.946509,12.179872,-79.12865,-214.843981,-188.968875,-53.108036,-14.322669,-16.650721,-69.257638,-97.122251,-118.912316,-101.620376,-51.514623,-50.188599,-69.390801,-52.923121,6.401767,-68.678879,-151.723628,-224.609319,-192.99803,-107.411691,-68.607053,42.762689,110.511867,86.0229,-16.116456,-21.941396,92.250473,151.345638,231.49651,276.166629,361.887202,327.426697,221.854144,7.419023,24.509669,234.520471,305.866144,314.124896,224.593027,150.56847,6.062617,-7.406008,92.51923,144.057884,161.063492,139.796585,79.330508,38.878955,21.64654,-11.014758,-23.249726,-81.049379,-106.608928,-58.051372,19.644787,14.333881,-18.238193,-27.265919,-91.903097,-132.531832,-147.102408,-143.820831,-189.58864,-259.74904,-303.14213,-414.18705,-447.179498,-347.599424,-223.331786,-29.498853,-62.313218,-119.763902,-166.782937,-148.532792,-84.844483,-47.984365,31.314783,46.627017,-15.03863,-33.868804,-0.452586,56.203155,58.573327,32.733264,51.464996,171.400141,154.479337,87.130522,34.410397,57.542901,49.952139,-1.843683,-63.722765,-36.152905,52.076939,80.625589,69.321026,43.170066,62.617969,111.093863,94.66893,-3.664494,-51.928418,-32.524247,-36.843784,-85.537446,-177.278125,-181.341394,-77.039345,-24.360931,-71.387642,-141.301149,-112.166444,10.793309,64.377898,106.575005,93.998066,5.94893,-67.588941,-65.215724,-69.463712,-91.856121,-63.940568,16.521208,196.020758,216.783074,82.876061,-37.485804,-30.047558,46.319903,63.098234,6.173989,-42.275597,-129.470456,-131.039355,-76.950422,1.988434,-40.280336,-204.974512,-236.991699,-103.611161,22.589652,195.478278,151.319291,99.8826,83.390532,126.830172,228.997271,257.376669,233.364234,111.792417,57.57882,-13.295978,-64.700775,-187.451468,-208.553572,-107.474704,-35.801846,-47.094447,-162.293658,-175.000254,-139.586562,-114.551489,-12.036687,79.322354,212.394424,111.764446,19.977172,-126.679702,-164.843448,-155.867048,-133.044624,-80.603309,-52.393784,-40.95897,-45.720866,-43.464873,-63.865653,-67.557936,-12.630298,40.582839,128.795545,86.868207,18.598469,-85.109063,-57.618465,119.444117,177.10946,132.563673,77.118468,25.768161,34.984623,13.388119,-77.741076,-105.568589,-61.03794,14.158942,156.516476,134.511486,75.502856,-51.035672,-88.476801,-120.178066,-145.50692,-133.728484,-68.528802,6.046109,-60.634806,-89.171084,-65.326066,4.346018,181.998119,216.103957,121.489867,33.391582,52.765585,131.610695,148.554431,136.955075,125.408237,96.035133,67.097029,-53.017922,-170.572757,-168.197325,-100.779397,-85.653201,-57.08361,-21.437471,-1.674735,-15.573299,8.470944,-30.591632,-106.569379,-146.681713,-91.621739,-0.276858,0.747107,-3.131218,71.541244,104.867687,124.662383,121.286982,95.846814,84.18542,91.212083,76.20159,55.763078,26.725024,25.59611,67.540238,97.979737,125.198569,102.205461:backward
-7.966616,-98.458927,-88.296729,-47.940613,-13.73089,133.241057,183.777485,91.73148,-124.026413,-181.641063,-97.940457,-17.611207,38.986424,25.092888,-16.466928,-44.042272,-112.004028,-171.353126,-175.775913,-124.062745,-88.862042,-52.939743,-65.354954,-153.543243,-230.50272,-219.061598,-129.82425,-104.550841,-127.9567,-128.052606,-19.713958,50.391816,31.316924,-159.443239,-209.194837,-186.801506,-155.267,-75.073872,-38.311357,-35.024309,-130.217827,-175.805001,-153.411932,-99.279334,-39.284876,-23.994316,72.776854,136.104621,172.85197,100.682841,90.7607,129.405317,139.409548,126.758164,104.320986,6.694868,-103.395484,-130.787236,-105.44574,-61.754521,50.604128,100.138229,115.670915,88.452743,6.471145,-68.366004,-43.204022,99.573643,142.480087,124.781495,90.619064,4.782746,-77.080655,-100.589856,-123.698068,-135.801356,-124.012611,-95.035328,-60.475054,-61.015968,-89.825567,-180.344362,-220.201167,-231.953094,-207.572055,-123.170258,-83.008189,-84.780579,-247.181493,-325.665757,-284.251211,-190.79932,-34.065386,13.067315,81.502925,106.834812,107.360383,78.5014,92.59756,176.713333,238.617833,364.103135,381.351192,323.83747,230.452388,175.113254,124.881478,140.388063,137.525497,84.20487,-48.577222,-88.081737,-165.885976,-270.505042,-283.073358,-240.254895,-225.062945,-189.955924,-150.029868,-85.630215,-155.21463,-234.273942,-367.379202,-396.446921,-380.785033,-338.202746,-243.414767,-235.10592,-317.514452,-387.002017,-359.590625,-234.701708,-184.795105,-128.026349,-124.430057,-185.79692,-263.504762,-268.675209,-227.349539,-218.175745,-224.047784,-204.649388,-116.723068,-77.590767,-65.962113,-104.03734,-97.039028,-41.441685,-14.270705,41.410983,71.006822,120.624288,132.5142,129.309984,123.580433,101.596183,7.230572,-21.450574,12.88811,26.462985,-78.821607,-218.353794,-222.367139,-139.812291,-87.448272,9.441035,39.821746,47.98467,-27.584706,-96.728224,-148.094387,-94.898294,20.342981,17.455452,-109.838936,-170.921152,-189.711006,-202.033589,-221.679991,-203.533695,-165.351573,-88.819344,-72.037093,-149.000183,-279.001222,-263.234743,-92.50593,-25.999401,-2.747008,-14.94634,-67.306794,-111.051399,-193.255119,-224.339707,-208.914036,-82.882248,-1.601134,50.999293,-13.97553,-224.92488,-266.470216,-223.063052,-217.799387,-271.075254,-282.020772,-211.4743,-128.39349,-166.719952,-302.711206,-422.421822,-463.071214,-446.1943,-376.557082,-212.5975,-193.951779,-284.758953,-345.135136,-346.411784,-317.618349,-284.718572,-182.548933,-133.749866,-84.419622,-83.039651,-151.413524,-261.357707,-252.961007,-89.1585,15.142851,149.756505,150.095463,76.477064,94.116569,145.539678,213.008677,198.276831,138.720207,136.979503,140.344647,107.164107,-19.969008,-117.615034,-117.093349,-91.493558,-86.80686,-42.384164,-20.067387,-58.136647,-138.916662,-155.072169,-119.487803,-83.39758,-56.315281,-73.18394,-110.909838,-114.464053,-118.254829,-197.828738,-240.844475,-246.521876,-208.612544,-79.567061,-13.803259,43.539606,27.431544,37.435665,120.29685,165.455294,225.023842,255.274856,277.819443,234.569551,95.927425,29.161657,30.323145,24.94763,14.346734,53.928615,98.128086,116.259909,-8.759842,-68.654423,-63.008655,-15.888856,77.174593,123.91679,216.48504,250.301337,297.834919,355.373314,408.315876,515.502745,537.094638,453.558695,341.793778,120.065823,41.997887,23.249145,-1.706586,2.021151,-5.523632,-10.734575,17.115564,29.989585,4.138914,-50.17038,-39.214179,139.980013,293.956083,553.710319,598.803226,572.284463,594.372718,652.655649,799.762245,844.742734,809.20204,745.723858,577.83341,473.628955,237.455096,61.536171,32.959738,60.56616,89.575377,122.820662,104.74905,-9.425834,-132.873839,-146.843278,-46.439625,29.260555,153.139349,206.879729,290.795501,313.096501,351.923619,404.574928,435.311803,506.613465,526.005162,466.443356,390.442825,213.704072,75.186632,30.057871,-51.221484,-107.383278,-175.959352,-161.188879,-144.018417,-175.351166,-250.540408,-265.831786,-230.297194,-35.108466,83.38526,204.045943,198.418378,186.841248,240.444019,267.77536,344.674981,387.979053,459.388304,498.37807,589.034767,625.92965,600.349175,436.2385,354.122765,240.807513,214.888646,248.723395,291.782099,337.690095,212.707689,113.05399,46.722354,79.272594,127.356217,131.717213,117.984798,99.059764,57.562589,65.481596,115.78852,257.865059,315.577874,397.258083,418.422217,406.191922,350.468912,324.575843,314.287142,311.871901,263.74858,242.885189,237.678729,222.040003:65.599634,-111.700941,-124.533104,-28.603322,35.286787,119.975145,106.759996,-31.673938,-176.597316,-192.926026,-108.130367,-52.369421,40.914258,75.834871,32.916532,-50.230908,-179.586541,-87.934525,-7.242323,54.043673,42.863649,7.901651,-10.942944,-51.876628,-105.905315,-114.300571,-57.46807,-35.774527,-56.300646,-43.459172,34.502185,15.391168,-145.72356,-174.206233,-118.034325,-18.444648,11.183088,71.776591,90.570915,57.196622,8.364038,40.103649,194.168837,234.321415,186.676527,161.70023,211.429412,265.595782,293.569392,210.574495,193.007703,245.998807,298.467256,325.027355,261.67933,124.078373,112.039228,114.565405,44.291589,1.725955,46.541808,114.931,157.310049,108.791202,-15.152873,-50.80574,-18.642687,140.499235,236.756262,342.551347,310.261879,114.531057,1.835563,25.892082,78.650049,57.016579,3.133779,-5.499278,-13.914277,-7.927421,-18.236368,-105.715629,-143.37301,-180.569009,-174.109457,-93.011234,-49.211903,-102.373493,-347.231954,-420.307456,-294.249997,-155.715588,22.782518,30.325078,-2.809858,1.656635,6.896868,-30.232296,-27.220357,45.96458,105.402767,207.127343,217.506269,198.669565,171.836479,132.817383,62.083682,74.492264,139.124034,117.239557,-56.055714,-141.433307,-253.505097,-276.068452,-236.279614,-146.603215,-125.043991,-119.056428,-113.091717,-105.463642,-235.310626,-302.612991,-301.202278,-264.254521,-200.004116,-192.411671,-270.995271,-332.029952,-385.893865,-353.65985,-334.460298,-297.13739,-254.242659,-157.716658,-169.543307,-329.723074,-408.367221,-361.719083,-235.38527,-205.297384,-163.86986,-129.89569,-70.342222,-55.029692,-56.963181,-70.084014,-52.128465,20.601193,56.868967,97.715166,94.67636,67.994356,30.305516,-0.332619,-53.961185,-36.327616,38.113779,24.253022,-51.521906,-54.516326,-62.902343,-145.012246,-166.412889,-137.536033,-110.413617,-55.543009,-9.305161,79.763469,-6.359843,-77.856897,-87.444648,-35.276193,24.133625,-2.300958,-120.852273,-173.779357,-244.567865,-299.098484,-309.346733,-286.155406,-255.178891,-186.107058,-171.560001,-172.290344,-156.647836,-135.291036,-47.161723,4.291207,55.176789,43.890295,-55.87472,-106.124773,-110.344405,-31.058993,22.199666,101.240808,98.365817,16.341724,-49.59218,-218.585568,-331.550667,-329.969182,-242.556599,-194.192071,-148.41657,-147.648916,-201.234066,-257.695533,-371.682055,-442.799689,-455.277207,-423.949881,-365.578364,-197.248266,-152.361211,-198.916405,-325.097576,-377.226774,-364.240314,-279.309825,-66.443145,-26.30184,-100.29108,-140.981542,-199.341671,-301.506181,-304.532471,-144.678265,-30.984618,127.662135,143.976845,71.286397,-22.463528,-17.58276,95.214499,134.008982,126.002056,128.975562,168.588248,154.156001,-10.832395,-195.503667,-207.31022,-103.523867,-47.342507,30.732868,45.540191,-6.287972,-58.831185,-57.143543,-44.643157,-51.612376,-46.181698,-15.741415,25.635623,-7.336027,-155.681611,-215.689568,-195.111163,-143.812948,-118.865805,-58.685949,-26.540304,25.42776,6.278405,-27.354822,-19.293998,62.276182,286.018741,338.128042,269.859322,207.857325,91.861302,12.159502,4.833706,37.749268,54.018098,31.848498,12.710149,0.723363,-55.464314,-85.694555,-45.482209,15.358746,149.354579,213.903814,326.556754,361.150945,389.141662,444.536959,470.788881,417.02087,356.092435,272.008667,236.500139,142.169283,19.049407,-51.263045,-118.850824,-99.840539,-19.6611,15.145272,49.103447,39.425529,-44.19938,-66.960295,2.688269,234.66257,349.863869,490.554002,515.13836,534.255185,547.68219,582.364224,683.172102,696.56871,606.488664,527.508088,341.972488,244.428065,93.957528,4.414761,-28.424808,-46.600969,-18.380606,63.2903,68.816854,-71.952192,-221.639481,-191.186106,-5.889431,61.528701,110.218714,125.826966,191.065801,238.526348,302.371073,299.271811,300.482712,321.682629,336.922044,335.080718,274.141507,45.906033,-92.745276,-109.91493,-166.952658,-206.355022,-197.108294,-165.400429,-192.12094,-239.604577,-285.643664,-252.841572,-210.304379,-58.004044,48.071813,227.004203,267.911615,277.90289,255.351314,266.39746,386.228237,468.74205,586.008556,605.73997,580.881412,550.645257,449.622876,314.315478,247.348984,152.926327,142.083915,167.687315,187.382914,223.781497,168.566325,94.376261,-23.825352,-32.416305,32.774811,78.80761,141.887704,143.094631,73.153777,69.873466,136.751158,292.842745,334.311032,316.525392,284.447642,197.628654,35.820191,-8.519725,83.552555,150.350951,154.58251,121.412901,105.768783,112.345446:20.140537,-25.18706,2.49212,80.404824,106.76908,131.930109,133.212247,68.756427,-35.973761,-32.116612,67.457757,98.131387,85.011721,62.766901,-36.775635,-113.986326,-210.011389,-141.838295,-83.264766,-21.479122,-2.468043,80.138824,110.73813,55.075693,-33.640737,-47.27512,-59.059263,-51.573606,20.837382,67.631318,102.932389,64.859414,-54.969089,-66.228739,-43.963601,13.739607,77.346114,228.654493,242.554899,97.142662,-45.583352,-26.65155,133.918779,201.478222,269.642838,299.984663,328.008307,293.626405,181.312089,157.650106,180.269062,263.628922,320.269818,335.877377,264.873636,124.728468,73.613075,38.887631,-13.815701,8.971303,122.745959,148.720736,65.570029,-7.718303,-132.274278,-159.608242,-126.342685,-0.327598,83.66794,211.573391,224.705699,150.627832,17.875355,-3.231726,61.517941,86.475975,68.647559,60.283226,69.539435,59.862985,-44.119763,-170.964298,-201.21339,-216.852193,-207.826581,-132.559278,-83.22214,-112.641332,-310.408026,-352.446546,-232.885737,-138.950224,-33.677448,-35.310203,-49.45209,-46.615185,-126.034059,-222.068591,-205.606362,-70.642537,11.487785,96.174897,67.98432,-47.606394,-99.084108,-97.759111,-27.518259,25.000022,71.211714,39.197075,-120.394741,-206.877922,-310.238663,-313.254026,-282.304586,-204.796388,-174.376703,-154.277182,-158.685042,-186.112747,-281.607506,-313.330036,-265.996518,-233.526601,-241.215304,-254.002115,-262.361797,-274.492748,-311.724361,-297.702034,-269.505265,-223.137404,-206.151604,-203.706389,-233.139807,-329.011058,-359.788154,-318.95093,-184.897835,-112.01598,16.167271,29.783215,-50.503732,-67.460346,7.326583,5.041403,-29.62808,-13.463688,21.540047,46.749888,53.060363,60.109279,21.66537,5.192881,-9.43893,-7.397271,37.684254,61.72649,78.909555,79.13788,14.932471,-53.042642,-28.522823,36.092872,42.045083,62.004594,83.684252,82.907923,-18.874091,-42.810114,41.113912,96.920279,117.92725,75.689416,-53.569982,-103.339747,-172.921262,-199.271579,-183.609016,-169.866501,-183.178164,-174.575837,-146.127576,-132.882631,-126.795849,-62.020724,95.123551,110.368121,78.245021,81.055064,56.961786,12.400445,-55.946518,-14.002965,47.467979,182.095135,210.085256,139.072553,62.788525,-110.651808,-268.243636,-298.256556,-233.40458,-183.400878,-102.323693,-70.714759,-105.119593,-168.749096,-286.549831,-348.261053,-345.07027,-272.516088,-231.988359,-194.166932,-198.302932,-249.763499,-310.399175,-311.961256,-256.147149,-219.634435,-149.475144,-116.881265,-80.078559,-90.120445,-164.191108,-199.653758,-169.706849,-79.83671,-35.924066,59.893023,95.346115,88.903999,-15.125646,-54.002845,-7.454192,45.848683,103.111136,130.661643,183.910088,141.065231,-86.08834,-205.58152,-178.824744,-50.048759,21.732362,121.293532,122.464298,51.01563,-36.415123,-57.287834,0.037696,49.224015,93.264611,84.442933,44.993158,18.99486,-69.198386,-145.790184,-140.006292,-40.025454,19.008477,74.692857,66.104843,-17.909461,-103.350757,-84.257061,45.750524,112.190081,249.774126,305.034955,266.481477,180.429259,17.222313,2.364379,43.399902,89.526365,83.099536,82.587154,79.575479,-10.830416,-124.280097,-117.888801,4.848681,81.480005,250.169975,313.277517,326.320881,322.98883,368.518079,379.154217,357.32252,305.252925,294.846068,274.208178,226.870309,63.26266,-18.587778,10.947564,72.405948,60.244771,48.533237,72.142584,81.388607,45.621904,-58.465144,-137.901314,-130.346729,64.332509,226.722627,475.998616,524.186802,529.289942,490.274606,488.156301,536.788996,552.309913,517.058612,466.010618,290.924139,186.226659,23.322745,-44.83648,-61.089913,-107.521876,-132.789188,-134.796067,-113.241757,-82.73654,-75.159348,-76.676365,-64.199066,-21.518362,134.721669,203.34618,230.91689,199.566288,148.276981,200.609646,249.271214,308.461385,316.262707,267.115327,186.556576,-11.865086,-91.272891,-96.900106,-126.948323,-145.582185,-121.577468,-92.485927,-129.847628,-198.310067,-318.541799,-275.584471,-184.618027,4.712387,86.022608,237.239249,264.537533,219.262274,250.104651,310.642357,423.885864,456.016584,459.530307,422.126075,303.879924,246.879876,138.826145,81.675502,79.87627,64.958865,52.053335,54.402271,58.506855,42.422053,-7.466141,-41.181853,-85.823276,-71.588023,27.594477,79.627398,122.88455,108.057341,69.921255,134.953724,186.792217,221.063956,208.845534,182.418231,168.346697,88.779865,-74.923971,-117.807204,-39.311737,24.367741,65.346686,50.284548,21.556072,2.573442:78.969259,-17.195661,-27.090486,-9.289773,14.023035,115.518739,171.647479,166.269687,-18.656145,-84.418383,-3.059436,82.256994,104.497617,48.72284,-48.284722,-81.745988,-138.073479,-151.600748,-159.071925,-156.288211,-113.639798,-13.448424,-12.63689,-89.027291,-144.637189,-140.393005,-92.088342,-83.713974,-115.303602,-111.255364,-11.863057,40.102872,18.428532,-110.557518,-137.906206,-97.003669,-61.092934,23.131124,55.00734,8.031378,-87.217882,-74.994287,46.584353,83.930422,52.743341,40.439557,84.81409,104.816841,88.665061,88.960381,118.087065,152.278638,152.923714,121.987939,68.97296,-53.355194,-127.755525,-163.383988,-178.190188,-131.219524,14.107702,63.250655,46.362413,-4.833327,-128.171261,-211.152571,-188.399587,-30.174359,46.560673,100.106009,71.43351,-43.005282,-120.30952,-132.770186,-126.566655,-117.767659,-118.098968,-130.60632,-149.318316,-156.476206,-223.732369,-311.54191,-327.992857,-319.818623,-288.965646,-160.614091,-104.898594,-132.048084,-323.96551,-395.116698,-354.36047,-276.546756,-139.568924,-93.930521,-15.144072,12.138814,-9.306389,-42.389318,-16.859933,64.016738,98.413194,158.713451,158.378633,78.045387,13.765171,0.730076,-1.123024,5.201994,10.462393,-7.846782,-119.194311,-186.638777,-269.747197,-319.704981,-341.551783,-333.118959,-289.777829,-163.217764,-110.18465,-109.794534,-246.964564,-303.620967,-313.442864,-301.731626,-316.333864,-320.857693,-304.365509,-311.00183,-376.168125,-368.592722,-303.962259,-165.902881,-128.586828,-124.202402,-152.989775,-217.944888,-268.518945,-281.570905,-225.302695,-175.830964,-111.265046,-90.865284,-57.93488,-51.102527,-51.7067,-18.220031,14.700951,47.28126,45.035293,81.485043,130.32847,162.020641,29.766195,-2.493496,85.375777,125.037136,79.5761,35.196338,31.660056,68.176644,75.254027,3.425604,7.05616,44.801747,57.432505,131.716649,174.086777,173.440839,75.228191,34.594998,41.40245,68.766686,104.900222,97.157516,-24.720857,-115.283606,-231.690255,-241.025026,-203.721223,-56.842566,4.224813,15.167077,-22.001747,-95.391653,-118.602608,-103.83871,-20.758167,18.274287,44.217878,41.527622,37.366176,43.503054,58.618395,75.538118,112.619939,224.192775,250.488952,194.420383,123.380248,-31.177385,-87.95861,-77.613948,-37.343449,-30.32048,-19.414698,-3.619338,-34.831627,-100.586531,-258.030325,-342.732656,-348.201592,-273.560604,-198.589389,-78.085532,-70.853146,-148.701253,-267.801687,-314.268794,-329.854815,-305.564865,-234.274907,-191.7654,-127.365234,-116.896753,-138.03781,-204.461424,-220.742925,-155.956467,-80.432612,64.274695,95.476472,76.543316,38.678035,45.088975,93.405445,95.851204,63.637894,64.836843,83.957114,78.947741,0.617632,-155.820516,-185.445192,-106.873778,-62.025986,-38.285192,-33.361186,-1.694835,-44.806426,-85.686234,-101.317463,-82.925268,-42.911447,-30.724193,-68.171276,-114.675611,-201.422841,-258.03569,-266.930425,-245.906351,-201.613698,-53.804678,-8.66395,-29.752375,-61.590157,-40.147008,39.445289,84.324792,221.169615,285.682192,277.232237,220.640753,120.502322,81.844825,79.78258,73.726652,72.022977,79.579995,72.136119,-6.210779,-163.105237,-207.502817,-66.695255,76.286921,287.348908,329.383297,317.828289,292.410479,309.974133,440.44317,501.786817,507.526335,457.776743,338.177978,275.794821,166.104324,75.865119,39.259198,40.044544,60.684261,64.389538,50.762652,33.822742,28.761355,-24.047531,-89.772743,-60.477259,151.06154,281.381258,488.28599,547.426921,563.668077,519.90869,519.550419,593.033708,625.418114,567.531934,485.450921,316.171417,254.640969,119.358491,-67.787118,-117.971534,-68.43986,-19.449799,4.549842,-27.337062,-138.051127,-189.271405,-168.220327,-88.594902,-30.447169,169.339203,275.588244,385.591616,391.015334,351.521038,342.928242,372.951207,432.58041,447.415169,444.413341,394.421872,194.134223,19.335865,-19.555799,-44.60341,-71.041361,-128.232745,-137.891284,-183.007336,-230.421855,-311.185287,-315.408637,-262.385498,-24.255365,128.084136,344.316842,356.916467,262.817162,237.796234,293.932906,475.134479,532.475282,532.129733,511.208932,479.390386,460.015841,352.712802,196.639682,160.59976,168.294743,176.458915,164.384601,146.130794,120.343512,82.511647,55.555193,82.534592,125.260621,179.738338,196.688261,187.815883,146.684518,49.870738,37.539122,70.056384,176.528909,231.166909,263.957217,228.669583,136.194567,90.375619,100.905509,176.670665,198.638464,184.257726,175.932995,197.488209,199.568553:27.367334,-92.88998,-86.900749,24.774301,77.15058,128.943854,134.668412,86.205305,-32.075851,-63.028238,22.43131,91.331286,152.511169,143.044297,34.087278,-69.154301,-247.006675,-231.541116,-177.677942,-60.256942,-13.060698,1.472818,-33.502233,-135.777805,-205.684754,-196.056151,-112.500155,-82.070265,-63.854429,-43.854808,12.490902,5.473783,-90.97282,-135.864922,-94.388074,73.899123,127.272561,69.440592,7.617928,-54.38489,-69.087435,-62.737301,37.653103,117.933523,242.227435,265.952614,212.490467,141.160341,9.53503,44.959788,105.884724,166.313216,180.860541,243.584144,252.26649,164.72366,41.570019,17.471626,27.800378,36.30333,76.809312,106.528722,87.582628,35.963208,-62.483442,-136.366745,-151.597492,-60.752759,47.558466,243.641145,264.201553,142.932953,-49.041478,-104.279711,-95.336031,-75.332655,-78.960547,-89.143881,-97.02496,-117.424562,-232.323115,-352.308685,-363.926667,-260.80175,-169.403748,-1.187663,27.28295,-78.592253,-254.228509,-282.679429,-171.667429,-81.634396,59.940402,99.063013,124.711894,120.868217,72.116768,-6.746146,-23.091721,48.706801,126.411833,214.091238,175.828718,9.527172,-95.727231,-101.855805,-13.234702,54.400936,109.271032,76.243968,-77.199365,-169.586766,-264.537696,-215.603104,-191.061692,-152.02048,-114.771711,-55.191359,-67.735352,-132.199323,-203.315709,-236.377205,-204.156565,-147.109732,-73.74744,-69.674702,-81.087888,-86.936317,-142.468397,-239.441459,-231.767697,-94.316171,-28.203016,-3.847021,-48.647102,-191.450551,-260.551891,-233.256387,-99.515949,-18.877084,118.90501,131.607379,11.485861,-61.177173,-89.118692,14.221722,65.579297,105.939442,120.324509,177.210549,199.304365,183.852932,70.188026,26.977412,74.524123,141.308351,202.412305,167.819041,102.63464,116.351065,108.581328,37.082182,53.20886,141.372976,178.43006,253.496146,278.886314,223.805459,53.250696,23.217282,142.823333,209.273611,239.878269,220.252809,117.622887,31.050214,-167.833875,-249.53369,-206.710854,-61.770168,-3.312884,53.408036,34.922148,-67.702472,-136.371607,-137.166803,-52.956949,20.187537,125.241611,131.977302,94.048409,75.507962,42.138453,66.121556,130.685212,276.462614,308.141574,284.03062,241.132094,113.236444,11.196368,-10.584882,-14.047543,9.783318,126.25639,165.400764,59.580949,-42.231349,-185.898018,-236.391604,-241.955161,-213.32368,-151.217595,18.164739,46.287544,-88.494795,-303.638218,-351.635525,-286.184206,-224.730716,-143.649129,-130.322329,-161.555257,-181.489588,-194.459648,-195.402825,-168.234806,-44.538495,19.609551,74.103604,62.72264,-22.2448,-115.270471,-116.819283,-24.706204,36.763303,114.14074,126.105299,131.348703,111.315782,-9.182998,-114.355154,-132.052898,-67.992531,16.732886,127.16206,108.862547,41.814559,0.359709,-26.459417,-34.763759,2.393737,92.759646,113.747737,79.12081,33.05301,-54.346283,-76.72757,-62.386633,6.772963,54.862555,77.559406,25.584544,-86.015797,-68.267439,-20.189832,55.922005,65.819693,95.842489,130.696719,144.672137,99.232868,-35.181009,-79.708085,-42.413822,53.955639,75.912926,60.276507,37.125313,-39.619467,-183.086535,-217.562159,-65.451715,87.922835,334.536519,361.690686,259.151317,205.432673,186.678651,224.422599,231.419313,257.964232,310.803238,358.644519,285.679299,49.596093,-73.180746,-55.742147,40.190625,67.324214,124.183694,164.803359,159.639845,96.80135,-62.35226,-162.487689,-165.507327,-4.811693,135.552747,321.687541,333.622516,282.730968,284.957338,341.904901,471.966102,487.920761,413.6971,350.350697,190.645113,96.613492,-68.567814,-132.522635,-128.838716,-78.850166,-51.647895,-75.779144,-118.274676,-175.948549,-270.508589,-318.41575,-232.781518,-100.704529,171.679774,246.766184,249.791326,223.500629,161.164521,118.785015,144.945474,293.344181,388.915323,439.79864,333.251881,20.685795,-122.579861,-121.219949,-92.682971,-94.297809,-104.702974,-112.737419,-170.146313,-220.149577,-320.41891,-290.264056,-185.068674,108.235584,213.518642,234.196383,187.583196,162.245255,254.339046,313.180207,412.669384,417.462628,353.052961,339.580001,335.58954,296.754827,150.553776,39.814336,26.675499,58.330288,76.445531,39.155302,-9.341048,-46.873053,-47.879977,-68.658689,-68.577018,-29.104064,92.335593,142.916141,127.892834,64.159214,-61.445737,-110.439056,-112.008179,-53.380653,3.644333,83.969387,77.765659,14.750277,8.355581,45.03566,130.364999,161.377399,204.410995,188.781463,88.081554,45.407056:-13.572443,-116.202697,-88.165227,57.969983,130.12101,237.220483,247.969558,119.881912,-108.945913,-173.107926,-86.312701,9.15391,84.731874,52.058098,-43.83357,-81.419645,-153.883148,-190.281353,-172.194408,-111.704252,-88.685436,-41.572279,-24.013345,-58.069706,-160.552167,-201.805901,-228.217396,-219.679515,-182.197836,-143.891767,-37.206719,0.039617,-16.069719,-125.544173,-180.663145,-223.651943,-182.286626,-25.465702,12.531631,-63.062469,-205.658276,-248.544866,-195.618192,-126.286794,-58.76046,-59.276322,-20.68957,19.718554,31.424092,-54.793154,-52.294089,49.796331,76.783615,20.995425,-36.512736,-141.920446,-218.202719,-255.342591,-234.216556,-153.719875,15.852237,60.260774,76.053835,63.001526,26.397275,9.516533,18.979394,51.806918,54.348162,0.945098,-60.92974,-230.813094,-298.714447,-259.878801,-170.291524,-176.915057,-268.82373,-301.613982,-263.686729,-213.987955,-194.577039,-306.01273,-332.680436,-291.933271,-270.670149,-225.837845,-184.808477,-143.607038,-273.026932,-339.773739,-287.731984,-212.053467,-131.05421,-111.927481,-9.13488,67.237341,151.222978,78.322546,38.226095,102.224282,183.69698,256.712064,230.096479,195.078729,187.040038,136.949556,48.025731,52.538753,59.700408,16.63484,-107.708824,-150.181946,-262.415771,-431.163894,-449.132518,-325.014312,-252.458742,-162.162038,-134.295764,-105.021649,-149.315088,-214.35261,-325.853016,-339.396334,-321.110034,-290.347559,-188.844588,-162.719769,-262.655041,-358.459765,-299.136521,-88.044207,-25.669939,-35.73308,-67.195519,-97.033989,-158.171043,-196.275475,-154.196046,-93.154205,-48.775581,-68.623842,-91.14343,-78.366705,-60.225258,-41.805229,-2.589328,86.544678,105.001981,114.410371,143.821037,231.106353,184.858652,141.66384,184.554199,219.164132,155.39424,109.083316,85.701438,86.531625,86.917769,87.077701,86.855352,88.577571,109.260333,200.276381,218.795648,135.846307,52.582864,51.76027,90.483971,115.280438,140.501722,110.82063,-56.49254,-147.172794,-238.832857,-252.060985,-227.748898,-114.272969,-48.445315,32.459646,21.740467,-77.633303,-138.009513,-110.273675,37.227993,102.08298,138.095007,120.020431,65.541356,61.368786,76.70834,5.546968,-19.517211,44.219784,104.666047,166.742495,140.019622,16.971577,-13.385764,28.521839,77.554556,34.896056,-68.800304,-62.70495,-10.540727,-32.102696,-181.780092,-322.616202,-337.879246,-287.728266,-246.443217,-140.357693,-99.072387,-110.183089,-176.463462,-186.245006,-141.454641,-99.867304,-45.444059,-33.788342,-14.011729,-24.34982,-91.243622,-118.905845,-102.467897,-55.336315,-28.56664,55.006056,101.827374,147.923627,85.678084,50.863731,58.608278,71.982103,109.489417,149.24944,167.052094,124.136606,17.375364,-66.767426,-81.082643,-70.633461,-53.878077,44.49063,90.477935,38.597594,-83.462778,-96.577729,-37.135167,-8.355627,-50.546183,-104.057599,-148.161623,-135.817614,-136.535443,-229.446033,-253.993014,-159.796677,-99.178846,-78.841629,-94.840491,-89.387118,-44.016871,-25.007342,7.795217,33.282809,147.825242,217.980776,251.142089,211.354997,143.772945,132.583394,118.516341,61.366889,46.962171,108.080802,156.727023,148.017577,-30.225797,-127.00654,-166.625188,-104.769127,51.93818,123.890921,239.899884,268.605809,267.146319,315.203286,381.313298,479.23884,481.885182,372.766155,266.316204,96.379213,47.227982,35.468826,39.78367,46.40256,54.723486,72.290433,108.832246,99.428443,10.524299,-63.490249,-61.825055,-17.309102,49.48658,296.092677,402.834857,478.134614,476.452785,484.932562,551.360016,609.905149,703.151629,698.209441,552.573793,432.647644,177.44959,16.947122,17.124348,114.331836,148.917183,122.867064,75.121779,14.945173,-3.47807,-16.241312,33.582042,98.456632,195.335235,203.362739,196.159634,207.2756,229.422004,275.038812,351.794828,496.732811,493.79448,364.736037,286.406472,169.360398,66.011955,-4.632253,-138.138442,-176.555451,-173.563865,-154.342106,-203.499837,-285.031699,-473.315991,-499.310696,-419.372873,-190.079337,-78.244362,82.751627,89.44382,2.970196,20.294067,74.477482,168.803849,189.388316,235.956696,289.385517,396.816193,403.746898,307.345834,179.233042,143.193231,122.015551,118.906539,126.382323,149.326084,204.542367,158.629449,127.200706,143.88468,139.788496,33.953442,-7.469026,1.995372,10.434757,-59.208244,-156.129867,-127.493788,63.855645,144.528625,220.613614,255.087607,342.641392,332.422706,293.008042,254.511508,245.838983,218.47631,221.527979,223.284012,190.272551:-24.701138,-121.271212,-99.498618,-0.479398,54.999481,184.819391,223.78308,135.404143,-90.454373,-156.882289,-84.906631,-0.146134,78.869036,59.145508,-44.063852,-106.005633,-221.477846,-276.572503,-247.709058,-100.299846,-22.915651,26.866254,-23.244845,-188.862859,-292.91884,-288.809804,-186.466227,-128.476847,-44.574704,-12.145223,-3.778272,-46.203173,-163.708999,-182.391755,-159.212153,-128.659097,-95.701421,38.472984,70.123334,-32.768658,-180.203545,-194.712513,-64.989936,36.324442,159.777732,157.009863,68.79802,15.748892,-60.527202,-55.157015,-18.522018,79.084686,127.792704,176.822277,138.797923,-64.193403,-214.107254,-211.111481,-110.418867,-50.440976,46.740706,63.038251,-0.726111,-49.495981,-109.012075,-92.919109,-32.771805,147.129508,211.377953,184.939092,90.979847,-139.595466,-220.551935,-197.842735,-114.822068,-68.367093,-13.063795,-26.32431,-111.13958,-173.394103,-313.613795,-331.141638,-269.292525,-128.001688,-89.387376,-35.108818,-17.917189,-61.973112,-220.87114,-287.691091,-250.52082,-159.348866,41.354942,116.55289,187.926466,195.4913,176.083652,113.060179,102.156374,177.776107,248.278844,333.973009,305.537171,184.78348,137.273361,135.95389,151.398291,154.649987,120.767016,98.117143,37.377991,-19.173205,-158.485599,-257.044221,-256.816001,-115.345736,-19.611632,65.864476,66.603604,64.937709,-12.926556,-81.421742,-121.737753,-73.248873,33.414598,46.931,-10.068985,-63.196496,-180.841623,-218.664452,-158.26128,41.931262,111.569725,124.094582,76.987342,-82.060503,-218.08709,-225.634666,-110.761708,-40.683079,32.446388,49.336863,37.986005,11.589651,5.057604,49.781273,73.846593,142.855965,180.787988,231.705578,241.832747,211.70483,81.10478,34.151305,101.287529,176.705938,259.888884,249.165528,163.557169,128.789012,117.473463,121.957579,123.014031,103.693985,97.796312,158.752673,200.017253,189.959588,51.113906,19.971969,153.418075,243.142566,261.733596,191.200442,-27.224766,-142.927651,-318.115355,-309.744868,-216.958669,-1.575047,59.461153,92.705107,75.297174,-10.253924,-102.301767,-115.350628,-3.340298,84.671758,183.334181,187.13973,172.306165,174.466289,184.033258,138.138635,123.476174,205.084423,273.691972,316.544882,261.837048,85.933247,-25.101218,-39.705692,-2.421315,36.0144,116.861826,136.709493,66.107671,-29.793062,-247.768409,-317.336384,-278.127502,-123.566517,-39.442619,58.490319,48.099909,-76.803225,-230.32534,-265.927871,-224.337084,-180.989171,-138.530151,-129.831539,-102.235547,-104.296421,-172.769233,-237.16391,-222.166883,-92.213525,-9.942574,98.51267,107.732384,38.220359,-97.331276,-139.08394,-89.286518,-28.509596,82.096307,127.710769,132.351289,69.416778,-105.966145,-182.679786,-156.378373,-54.150918,-7.842059,63.782856,60.104365,-65.819791,-207.206553,-219.903315,-99.4198,-6.988941,86.899436,62.325979,-45.858789,-93.478639,-165.638323,-167.67134,-121.102098,29.869129,86.15899,67.029429,3.324564,-116.707721,-134.746047,-93.144631,42.826642,92.111149,150.164369,184.204705,215.132278,179.852558,33.389396,-34.493594,0.406744,98.073937,126.455123,133.342033,108.214239,10.866003,-123.906527,-165.651117,-91.79632,5.973,163.449118,189.95227,157.854502,123.289494,113.000195,225.016897,291.595037,336.453491,321.833744,284.146266,255.433018,152.101276,9.911179,-37.483381,-56.529178,-50.828208,-19.214117,10.687093,29.473186,-9.004833,-123.094043,-147.763186,-128.819401,-46.345006,33.041674,231.540081,300.321196,292.957995,196.086419,201.426779,315.748654,365.540922,408.690395,398.56145,262.083012,153.376042,-18.478615,-82.573486,-80.112685,-33.414378,-11.743283,-20.391877,-56.392381,-174.283504,-281.139219,-287.838492,-157.502179,-43.526473,162.994987,218.48065,231.634414,205.768481,101.088347,99.120968,195.323384,417.115794,476.992923,445.664725,348.828921,98.309754,-94.64233,-161.559179,-204.888854,-191.024569,-139.617035,-116.793925,-156.240518,-233.983762,-405.31668,-411.999032,-329.537348,-41.705805,116.410004,273.952752,241.254525,125.165008,156.553538,218.221572,333.839225,356.879961,351.437749,346.603698,312.008244,263.404249,105.540741,-3.501404,7.008783,92.666321,129.270843,142.867813,117.468866,36.129068,-53.342811,-76.864002,-29.76498,20.395877,102.658459,129.339217,124.161559,71.352526,-127.970634,-259.247124,-228.210525,-37.284073,61.243001,157.202001,158.743525,132.483505,64.560133,58.143478,147.072274,191.18378,232.454578,237.323786,162.306459,85.151466:67.604312,-65.36771,-102.159595,-85.185538,-39.515071,136.004383,203.234766,143.945221,-8.387613,-44.879033,-22.499616,12.723444,63.49373,64.091468,-31.067312,-120.281755,-242.418825,-220.578269,-187.345254,-141.482153,-128.901806,-68.164597,-30.022464,-40.140023,-140.121338,-169.924458,-149.277144,-119.399985,-82.64187,-69.679151,-8.923142,33.534509,33.48412,-115.994818,-161.639855,-133.056359,-104.280174,-65.038466,-50.934528,-56.330056,-160.484702,-222.159441,-219.838327,-154.780557,-26.921681,7.088602,44.454669,68.021316,109.385078,71.724416,58.393598,111.901867,129.006176,67.620538,29.839257,-2.919746,-59.917996,-80.944994,-20.133768,28.553304,71.099274,80.703616,114.520491,140.597224,184.724437,152.020785,137.241897,182.791972,196.766877,60.481502,-87.567389,-342.248739,-325.408316,-277.587911,-239.645362,-226.012694,-167.524611,-130.127992,-115.490332,-151.881516,-214.53122,-218.545713,-231.919629,-270.758203,-254.058308,-123.482001,-56.685275,-7.893818,-65.155695,-135.53028,-265.830543,-261.104776,-118.545867,-52.762583,0.375719,29.141249,110.673407,113.945803,98.188958,115.085655,144.100071,183.450937,185.531543,216.261104,203.203739,146.805737,116.084186,157.481405,180.70629,145.498642,79.922331,51.803277,-101.045677,-281.266285,-289.784463,-158.150076,-100.199728,-71.289839,-47.936184,61.781379,79.019973,27.035657,-77.790301,-107.621799,-90.790558,-39.071979,57.241215,65.682876,9.05389,-47.46871,-38.364675,58.032722,119.742367,204.867771,222.022847,212.468158,161.751605,137.241073,112.07671,103.208896,41.759169,-14.372594,-63.378703,-23.635357,43.244707,-2.728981,9.964369,125.658032,160.348628,154.875214,157.414739,208.185013,218.524628,188.377087,156.572183,150.142474,102.05478,97.647115,154.764897,180.362767,164.4035,99.863049,85.889308,91.134139,99.198163,122.232225,124.29366,101.258597,79.758967,66.07908,56.825692,67.868045,59.541567,-1.454881,-237.186483,-329.869699,-319.939883,-278.126608,-285.380533,-216.999226,-148.654405,-61.29809,-58.954892,-112.30769,-214.583331,-248.011251,-173.912947,-101.656086,-63.771145,-91.317267,-84.809796,-31.165552,40.90283,-42.017122,-71.139656,-27.842339,15.187401,106.001952,125.112311,79.818281,68.932456,85.940489,15.217122,-80.389983,-202.240639,-175.930964,-52.673972,-22.529352,-60.150113,-159.405958,-193.8466,-197.477933,-161.487211,-24.312532,26.933445,17.511861,19.419177,53.037142,90.270653,76.45192,7.688281,-34.737329,-64.847684,-30.239354,36.587444,18.432613,28.348812,94.375347,114.219714,127.216117,137.709023,141.523142,122.929635,130.422324,192.757473,202.860775,118.940488,78.708349,81.754349,93.074878,61.079424,-37.322103,-73.415872,-41.914995,15.375148,98.229132,91.481551,38.744797,-2.773013,-49.817332,-157.822633,-166.553547,-107.511531,-93.240221,-143.418212,-166.918279,-100.621731,-18.77728,-33.607785,-92.724618,-96.520747,-48.068754,-14.133329,54.35783,159.029447,197.090368,136.300287,70.566849,97.76283,204.630802,349.893392,320.642662,164.049138,95.34668,107.672256,88.633881,40.268206,-21.6738,-4.774642,69.945658,36.532581,-37.639012,-138.514309,-119.943112,-37.958787,-23.249742,-45.061399,-60.434829,-76.142575,-15.193062,46.223597,126.446721,143.458649,162.733079,148.213228,99.752395,52.391644,16.176309,-31.873581,-25.030321,4.261866,11.974415,37.874537,54.796389,15.741771,-134.051179,-190.691152,-197.593792,-164.941139,-79.262831,-36.936175,20.001852,69.267903,120.397838,287.228506,385.343286,541.355967,568.775127,455.378858,337.339522,147.715333,123.000415,149.37896,186.554507,182.953876,151.983373,119.327409,16.664517,-83.612771,-110.983115,-116.06575,-127.442029,-174.894612,-172.089645,-109.830248,-88.675583,-70.130166,-4.402563,32.145772,28.859419,-6.493819,-34.179441,-23.447192,-41.629392,-169.50046,-247.902041,-309.150659,-286.226833,-248.143385,-267.786167,-368.711736,-423.97168,-500.585255,-534.055622,-530.197161,-460.704594,-411.766782,-348.549155,-340.267745,-353.655846,-398.694611,-403.346245,-314.823282,-250.875633,-153.299998,-105.862286,34.214248,109.718886,134.121254,-29.664104,-107.915256,-156.593057,-125.395806,-19.473437,21.502259,65.080698,110.306518,115.713082,72.365051,44.982513,-49.380755,-113.505709,-179.210522,-177.072366,-190.198976,-260.678871,-264.466083,-129.946621,-43.223325,39.487153,66.592553,212.305733,357.467213,365.881705,302.794222,258.705628,187.89383,175.245005,156.020279,135.764833:10.194726,-84.295396,-110.49013,-74.736903,-12.780001,142.595356,176.59631,83.698936,-81.988977,-148.541013,-201.071081,-169.125207,-49.787569,-9.972472,25.158222,39.062842,-2.346008,-134.677139,-172.318134,-185.333172,-172.892239,-79.110015,-27.871978,-33.03054,-158.06238,-211.421717,-216.391098,-186.234736,-122.843368,-75.860459,54.059301,97.368668,-2.762405,-273.951862,-340.385776,-270.214632,-205.06737,-129.345272,-125.50454,-168.967341,-290.628361,-360.719296,-399.092609,-384.782388,-343.036534,-277.368141,-101.472147,-47.635166,-16.625996,-37.427075,-41.555349,3.101677,48.048479,142.434308,154.381278,60.362912,-87.736791,-147.999817,-173.452898,-110.638312,81.329273,127.511735,86.064395,68.074145,92.384175,104.619192,114.393343,142.10507,140.199323,83.763517,3.982445,-226.330565,-314.623512,-309.861761,-319.430839,-313.283903,-216.272938,-156.292759,-126.514321,-143.356781,-161.220803,-234.087916,-280.670492,-277.489558,-226.50619,-98.539463,-63.009413,-81.861808,-183.650393,-259.336845,-346.998085,-323.672474,-185.501943,-110.452507,-22.997319,-1.368035,21.372286,-43.054722,-67.656317,32.751833,123.164616,212.66193,199.953336,175.317032,166.153981,138.321348,104.81417,99.321677,40.402935,11.344224,-8.730724,-42.473679,-186.032619,-281.881363,-291.555325,-265.822992,-223.673242,-112.315546,-76.896856,-80.629096,-192.758013,-255.107531,-309.070895,-324.560429,-323.170349,-267.339249,-128.889701,-102.708005,-122.079347,-114.987522,-74.768639,10.297769,22.169362,55.46191,93.656744,111.446663,52.841384,50.834849,105.857828,104.923008,-3.43475,-44.907398,17.447636,70.303487,44.926413,-68.770494,-88.616847,-46.3853,-2.10436,56.661926,58.894746,75.793907,120.351936,127.807033,96.7349,53.559846,-32.783997,-23.77423,53.579269,47.098317,-56.711014,-65.926336,-24.747403,3.484524,-17.74481,-11.392267,21.022282,34.212677,-84.501264,-163.578927,-209.905253,-158.817624,-16.520298,32.260865,10.341988,-54.638813,-167.056848,-196.963624,-207.070594,-203.430656,-152.920644,9.885993,44.682427,-73.169653,-241.651431,-252.497013,-153.165054,-117.986965,-153.912641,-184.616269,-187.68594,-167.260867,-142.802256,-180.841861,-203.504205,-194.034982,-155.043976,-56.181924,-46.708813,-114.723457,-158.082054,-181.719629,-264.879089,-298.432892,-288.875664,-251.128893,-176.75899,-155.699091,-169.938795,-304.472663,-357.330669,-300.982652,-232.354894,-155.172774,-147.23369,-151.179362,-200.152941,-215.060634,-108.652233,-28.661669,8.244417,-15.05454,-38.006995,-31.558898,-10.749709,-45.601869,-68.754359,-41.657008,14.574309,106.276505,100.469759,55.955513,95.193311,153.309927,301.650816,329.600125,253.039083,211.391685,175.591451,153.904187,91.995831,-25.639122,-99.285662,-134.67598,-67.759464,117.420779,153.380632,60.864702,-65.451357,-94.959281,-124.255092,-158.111504,-223.608246,-204.766048,-108.931026,-89.95946,-129.053605,-201.145829,-224.449798,-184.047827,-126.368457,-3.678016,37.821433,66.953478,69.72197,67.663831,53.154299,59.573813,167.344777,251.804099,351.054727,328.41867,187.478725,117.923474,128.33946,124.944501,110.450841,157.392799,205.383622,233.967106,151.450754,89.246882,-19.849159,-52.349836,-34.014141,8.30432,38.078279,29.336747,71.226166,186.101157,274.298492,427.872563,427.131798,301.670372,252.556921,258.990617,231.09699,154.724024,-13.703962,-59.533618,-54.755351,-13.34403,44.541759,27.543875,-51.534298,-121.956703,-137.864548,-78.491377,-16.950663,83.932362,124.58781,227.215836,342.649968,402.024895,543.878661,623.57932,721.336819,713.134889,606.849347,526.585249,304.848766,89.892515,56.323354,118.936788,162.67476,191.597431,158.098807,10.881185,-161.429586,-220.403184,-187.151635,-132.362636,-108.169154,-120.005529,-111.624034,-95.12124,-24.55362,113.424604,184.429135,247.033646,241.719675,232.292286,219.306946,94.870036,-118.781487,-196.270158,-219.731158,-203.635819,-194.294229,-182.906235,-186.430963,-232.63596,-347.935977,-357.793422,-323.837739,-246.487213,-211.936178,-152.65814,-144.606812,-193.382277,-292.19931,-312.544317,-213.96255,-130.996283,24.925669,108.259202,281.57102,357.413495,405.658594,205.492154,70.757836,-34.728383,12.177379,154.71629,193.863303,235.266609,207.573684,133.721363,17.234547,8.318291,-19.480372,-51.636976,-60.569767,-18.059921,47.988293,-5.985405,1.898187,152.329101,233.206468,313.668213,330.663766,393.393895,457.979434,455.452138,392.028031,349.048047,276.599063,248.656218,199.518926,189.976905:59.334405,-46.514477,-80.139434,-76.640395,-29.387762,122.683882,170.78122,131.954711,25.500147,-14.251539,-57.496344,-65.370597,-47.391687,-45.971412,-132.0111,-177.897183,-188.602984,-202.834192,-214.77217,-196.898732,-159.641014,-34.7722,9.130693,-35.852917,-115.035476,-126.998782,-164.807661,-188.23854,-166.932737,-130.111556,-80.144631,-74.434284,-110.542848,-215.011717,-246.79682,-185.432076,-122.849141,-79.107848,-121.116733,-231.461753,-230.146692,-193.528558,-120.833774,-85.293527,-0.67866,23.96031,38.122425,55.272652,60.770985,-23.945887,-34.936565,37.267342,66.80743,67.804903,49.915906,-36.43606,-174.546455,-209.622549,-149.143824,-97.381637,-5.277318,45.900736,141.142057,167.857301,130.103195,33.347348,41.678518,163.967668,187.546263,72.153071,-23.183286,-188.139536,-255.867063,-239.779519,-119.054157,-61.693301,-76.709205,-118.849722,-144.301925,-138.897735,-197.396266,-308.193673,-312.082118,-216.737179,-164.612383,-86.4946,-67.320708,-66.936546,-91.396988,-118.028701,-129.292057,-109.628025,-66.957644,-30.626284,73.413081,117.253528,136.799854,61.735533,50.916146,121.897855,164.617379,209.611515,194.75401,157.714211,254.855783,289.344157,193.742526,117.091132,86.897176,131.914909,163.433741,99.262767,-139.617565,-329.832722,-330.232339,-196.06767,-120.69023,0.902667,36.555259,21.524508,-59.896529,-90.443223,-151.277297,-189.0888,-153.424336,-68.397598,28.276039,-13.178799,-137.391743,-99.853772,-40.779992,40.27892,68.250386,125.732762,126.552929,59.879512,5.627708,1.437989,28.488158,26.801602,-22.627239,-37.503498,-61.255869,-82.068121,-84.341548,25.336292,116.704084,257.454503,283.131722,307.668076,311.061221,260.334482,136.374789,84.174205,95.711564,128.166483,119.437793,89.052709,62.016537,76.760874,119.106829,70.543674,22.163458,9.069202,61.541989,178.846172,194.320452,171.604535,116.045133,71.783657,34.487558,48.029941,54.410612,14.351955,-171.860392,-278.726913,-375.53992,-330.153518,-290.091454,-156.117458,-64.233347,63.807668,52.717491,-62.122919,-97.787327,-68.416155,9.792096,24.753589,16.016051,44.694545,171.646798,204.210029,196.175227,172.583264,149.36482,121.740942,141.438647,228.147646,237.214957,154.735913,133.986196,159.706328,162.035898,113.247627,-17.685204,-57.862609,-56.133608,-47.84183,-112.900605,-252.986899,-286.619392,-228.313892,-155.083341,-3.911295,13.948358,-118.984124,-224.63543,-205.538677,-106.468115,-71.129017,-78.528279,-108.00788,-136.728544,-124.267082,-93.815626,-103.277416,-110.974022,-91.702363,-56.596491,33.735806,58.848014,35.669038,6.49323,2.542425,-37.706584,-74.106051,-110.856533,-82.705155,-8.550623,-21.742665,-126.888879,-209.285509,-209.405001,-107.119386,-23.755699,117.326126,127.509349,-5.854577,-144.298173,-142.005857,-27.555353,27.414332,27.621854,-18.04265,-106.652393,-121.016826,-99.488619,-100.831957,-102.905228,-61.79035,-38.378962,-24.819656,-19.244533,30.133929,46.622015,9.214014,-86.667389,-99.115726,-15.854138,48.083153,132.682756,144.452671,107.613466,29.827249,11.361767,7.563423,-0.350945,-14.863412,-28.480592,-83.223821,-106.728962,-122.762227,-189.489303,-207.0518,-107.55017,-22.876216,3.386011,-47.191912,-70.146301,51.366961,126.873501,204.5124,189.441061,165.545032,162.991357,60.071943,-71.438162,-93.390074,-46.64368,-15.302128,-4.976706,4.797836,56.661385,60.38688,-42.537281,-204.565906,-242.152582,-203.825864,-137.109263,90.40702,203.371399,264.458715,185.921965,161.294338,215.866277,282.011863,369.459499,365.373838,266.99035,198.419308,118.099828,69.583966,46.849019,62.423448,92.775483,108.208692,66.041988,-57.367622,-122.107252,-134.271201,-111.0004,-79.060067,-11.735553,15.189931,34.617013,39.21803,65.972013,92.507702,108.427032,127.44801,130.749428,135.831539,126.474982,80.325223,-39.269546,-126.973357,-202.417648,-175.338606,-137.256639,-157.438221,-199.095474,-201.011801,-290.936621,-433.328211,-396.058513,-159.570477,-70.821184,-18.335274,-11.60071,17.279084,3.404622,-24.468662,-19.503929,22.027399,103.696572,122.338803,119.865616,107.406984,53.066502,-26.289083,-57.610536,-55.222471,-17.772898,60.679997,63.863085,6.785109,-20.883508,-13.808996,7.256887,16.357531,40.664874,44.444148,-6.24255,-45.288005,-111.403941,-185.158036,-199.434738,-104.539642,7.10112,228.121369,272.495051,262.2451,300.846271,343.139133,360.562181,312.088616,179.536546,150.137489,193.605839,232.135214:backward
-267.767607,-391.534919,-371.893008,-167.187279,-66.837144,-33.393082,-76.055971,-145.532215,-236.147601,-314.625901,-423.28342,-398.844454,-260.253456,-237.744046,-335.278493,-389.05612,-387.11962,-286.936405,-259.808977,-259.446874,-216.562808,-31.946905,28.122284,17.12848,-40.055093,-63.25933,-78.5713,-54.571498,30.371281,35.0828,-50.103694,-92.885793,-112.526318,-59.512063,-46.202205,-77.648558,-75.665691,-17.338704,-36.488901,-160.765458,-79.794557,27.109113,89.465071,11.626559,-68.130159,3.098796,147.180585,153.882202,115.18634,141.50282,180.02133,239.994515,261.220719,287.280843,253.492772,36.392846,-237.099646,-297.966817,-220.62163,-165.436917,-173.593195,-184.271797,-97.209832,-42.003815,-62.811457,-191.201231,-206.056947,-135.834141,-111.591994,-161.14286,-204.166707,-188.905868,-97.051156,-122.285522,-283.619353,-313.472179,-202.730979,-140.145684,-120.418042,-141.12235,-183.974144,-185.479249,-150.480761,-35.172879,25.644955,90.467316,61.950988,-91.334285,-204.442168,-203.763398,-114.562052,-64.772446,-43.21502,-89.120481,-212.115199,-247.927671,-301.613361,-345.098448,-338.314998,-270.930559,-220.90362,-156.380926,-147.862358,-85.108283,4.006544,-5.214128,-74.506238,-62.921275,127.748598,260.240112,348.131845,277.382669,101.422308,59.202444,80.145405,146.709279,192.913903,255.871783,224.780431,56.805165,-73.655702,-88.468779,-42.045364,6.273667,123.608537,165.787711,169.249891,143.58766,115.638637,116.24537,93.403264,47.932643,86.91914,262.660783,317.964364,271.368516,145.003985,130.272358,135.162935,71.458799,-91.650895,-94.402832,41.55855,116.881683,212.232671,270.324269,322.222409,508.204701,614.692166,701.005906,639.251173,404.851457,236.717729,206.319785,193.437877,199.832913,205.198982,163.580415,61.925954,70.875937,127.637367,130.202635,165.070977,204.833254,149.455941,18.872329,-7.483851,-12.116793,-42.475464,-73.571962,-95.158159,-101.864277,-113.844073,-104.37631,-116.655141,-117.651444,-2.945382,136.01759,163.598565,170.310073,176.014691,178.9897,160.978839,152.265294,211.57334,245.394571,312.606419,333.512658,385.431239,426.088662,416.73524,355.270841,186.76949,76.641138,108.305175,250.438459,286.17792,252.861531,221.792908,180.979238,71.000806,10.763669,3.85577,64.407613,280.612766,376.728569,399.698509,365.956923,287.800882,178.604314,163.095657,231.288224,262.972735,218.914565,148.675336,24.5106,-13.082432,-4.528391,7.698378,-19.712377,-74.876516,-55.683575,55.151449,99.354843,54.103341,-96.071233,-141.550487,-148.727199,-111.425791,-14.017905,-2.16352,-68.01452,-185.470739,-228.401776,-202.969411,-133.135206,25.426519,71.46843,141.521732,184.788548,156.743447,64.753617,89.199485,199.967385,246.941497,266.861044,213.813548,107.833901,93.789583,67.43672,-12.05208,-16.90966,135.511019,278.706762,450.713979,407.660596,216.352404,156.419366,171.219131,220.942001,258.772008,278.797608,225.702446,124.572495,144.451952,116.268541,-77.745108,-160.872644,-139.822197,-85.732423,-61.202641,-69.003519,-85.430857,-164.21379,-217.283859,-285.095191,-272.929119,-160.3017,-87.631664,13.326362,1.903376,-26.186348,-53.707835,-40.656646,22.682172,37.895667,-31.003652,-70.373546,-77.018944,-131.228454,-196.574155,-253.350665,-215.423104,-77.750706,3.451912,114.050127,26.391776,-34.691625,-64.812047,-73.111054,-131.742933,-156.281515,-140.673665,-86.896098,35.019857,-6.881616,-67.48695,-78.07839,-12.26394,68.079064,27.315056,-62.771289,-48.74483,-44.745741,-91.520639,-142.234318,-178.587469,-144.858105,-79.867557,-71.394009,-149.211251,-254.250174,-228.684953,-133.806072,-142.850151,-189.02614,-171.566331,-194.371665,-420.609949,-499.468325,-420.326053,-315.603403,-142.427327,-93.066514,-38.899511,-46.400633,-167.880574,-228.645975,-180.311753,-74.199177,-51.776495,-16.24214,-31.801125,-156.570933,-168.805901,-136.982237,-99.76821,-72.597824,17.833541,58.371095,139.172751,186.981476,129.506617,-71.409257,-83.081673,-6.334832,-2.114724,-31.201905,-33.307337,-17.448288,-52.812952,-62.468823,78.773498,196.033596,347.947031,350.350923,239.997422,169.660055,54.941866,5.217944,16.582715,66.043878,70.917567,30.5718,14.820865,19.93285,-10.896822,-41.966008,-51.727817,-20.308562,54.385854,46.746158,-73.963402,-112.799033,-77.701971,-5.405184,13.13524,11.314895,34.851116,95.539831,72.834904,-47.425479,-164.653934,-216.940687,-247.309422,-212.34129,-121.543673,-99.136178,-79.018717,-50.815697:-130.277956,-183.415771,-164.086204,-18.584624,31.550231,-17.620981,-61.869682,-66.672069,-142.118034,-222.721643,-299.211305,-276.575296,-208.521323,-210.141917,-284.571228,-336.421268,-400.729808,-299.484634,-221.632188,-156.859614,-138.406845,-72.59946,-85.086598,-224.909647,-234.573762,-172.353794,-135.867988,-171.17199,-176.371885,-153.198317,-187.456607,-233.687099,-257.099474,-190.52968,-187.3686,-196.554672,-145.777133,-11.359217,-14.63199,-119.488012,-36.078486,68.707637,117.599322,30.668334,-68.799139,-22.613301,64.115383,61.388997,1.160585,-22.320708,25.682107,173.888177,211.985384,160.985476,98.696346,-32.397542,-169.499056,-193.220783,-91.800552,-29.025176,-11.544565,-30.327809,-9.617897,12.741954,-39.483731,-158.679299,-162.65263,-81.122226,-72.731771,-171.778561,-229.189021,-243.341885,-141.850456,-130.602733,-244.927626,-278.213619,-159.367993,-81.042282,-98.764072,-183.065447,-324.267546,-292.627975,-221.987223,-56.356296,-0.763572,1.823823,-31.921192,-110.73756,-197.748335,-212.35207,-125.040821,-59.408544,-12.735352,-44.331199,-145.70807,-193.101235,-278.508424,-365.251773,-400.63856,-303.514381,-162.7273,31.881323,30.650328,-31.217724,-92.338271,-123.448283,-128.116701,-87.396502,63.407193,152.699548,186.608951,82.43581,-173.688476,-177.742537,-117.420059,-55.129802,-33.807006,22.008586,13.974191,-92.306122,-167.705133,-160.584795,-83.430498,-28.386924,41.897301,52.924635,86.238443,83.260624,4.233896,1.252372,11.411532,-4.310642,32.807635,186.151336,217.127403,161.641473,147.024468,197.391396,276.311848,235.44709,113.826832,108.558364,161.133033,172.928018,175.179298,202.175019,224.591425,350.03003,446.067027,509.627154,449.764421,320.560525,305.944863,266.946337,72.49329,25.156092,137.329744,194.182797,193.426746,195.216704,237.625002,192.134265,140.361849,91.220356,93.463084,40.48949,-6.131809,-15.799004,-18.30955,-60.261103,-101.890247,-83.575007,-16.08735,7.357729,-31.950305,-59.795506,-39.010719,-0.530446,25.445979,129.286666,187.496233,245.728701,239.121351,173.722224,146.517808,188.045634,268.081818,251.32779,204.707193,233.924421,305.613912,301.34556,207.812677,85.674895,83.287973,209.334788,274.816842,251.206194,171.259828,19.360398,-66.230681,-75.464267,-5.50428,57.127748,222.906413,308.913802,345.507335,297.607101,192.102242,143.842693,142.534852,158.324622,180.624252,208.439233,150.903468,-66.672067,-110.311205,-50.116073,49.281264,46.447588,-18.649613,-39.712429,-6.942542,16.452528,-5.480199,-92.738876,-132.87167,-132.769056,-89.741062,-14.862227,-12.405974,-50.438519,-96.292898,-120.890679,-160.136831,-147.312277,-51.05484,-5.49515,46.593126,52.602255,-11.344276,-51.009884,-23.83912,58.29503,132.212075,293.178529,292.482819,139.321905,28.471807,30.253829,106.213474,130.363896,143.08056,181.210255,266.726368,257.089559,201.927794,233.069625,233.738999,202.792827,241.132663,371.071951,368.871848,247.933535,211.935128,228.394487,194.167577,145.14097,124.371317,138.439636,67.408196,7.801015,-61.857773,-94.689125,-97.280121,-61.572534,-20.020739,31.157111,16.392887,-15.892638,-30.400608,-32.107247,37.259689,104.953597,228.653595,242.081428,145.26049,84.082734,7.135416,-78.787659,-126.651381,-130.612986,-84.338446,26.520716,72.879969,60.434678,-80.79436,-95.699703,-40.625193,-54.878766,-87.522247,-56.396027,-10.662996,-30.550174,-101.906031,-112.111758,-88.689859,-53.928223,-42.676229,-31.557909,-66.209252,-145.963015,-66.702845,-6.788373,-12.13378,-79.09489,-130.186294,-88.953237,-45.941943,-64.656883,-160.821551,-244.796362,-206.259005,-62.053277,-38.017868,-53.564835,-44.147386,-102.858303,-333.97619,-393.762095,-306.088499,-224.982923,-127.092497,-111.631971,-83.530605,-96.688983,-251.267968,-339.162941,-286.457276,-149.504002,-117.163348,-100.733255,-129.278641,-235.38267,-263.835383,-245.007076,-125.323465,-42.535864,6.296717,-27.557155,4.259458,90.238385,92.75319,-122.88528,-136.200965,-25.326396,-12.338243,-76.54554,-109.2172,-153.693296,-203.450079,-204.892934,-83.38148,-2.53583,96.394547,98.804277,-8.88873,-89.347735,-209.058057,-186.594266,-121.122783,-14.618929,-1.768671,20.752644,34.955754,10.448049,-70.344165,-102.052872,-68.291214,12.465331,186.928029,181.795683,-47.347202,-153.465154,-181.580578,-78.494073,-39.378916,-5.403933,24.929121,13.922726,-51.997856,-112.172748,-65.824081,-94.717787,-256.542002,-297.883872,-194.617558,-116.125821,-83.715912,-126.935549:-49.041003,-144.213174,-176.43399,-120.454463,-32.551687,105.837873,113.600487,85.907491,-28.464856,-120.991503,-177.009715,-118.339089,-51.346582,-129.43836,-343.069954,-363.816523,-327.897684,-356.811816,-350.276956,-282.501109,-238.273322,-116.260861,-88.260615,-203.669701,-211.241652,-125.020047,-118.199083,-232.208418,-335.557444,-256.482731,-100.07207,-112.407434,-218.394267,-199.073539,-175.477394,-169.134541,-146.685558,-101.955579,-118.897628,-158.162165,-45.187147,51.670628,74.839546,-13.995733,-144.759318,-156.110488,-152.888961,-125.956971,-37.710061,12.426591,34.384637,70.399759,78.417517,93.783587,101.119532,54.28665,-58.941335,-80.665175,-82.609876,-100.934857,-98.082997,-49.870985,54.317666,67.913856,-11.398578,-152.575271,-214.090435,-273.313527,-231.839361,-106.895455,-103.553195,-140.882749,-148.397266,-196.167003,-322.426477,-311.129348,-152.010848,-99.460516,-194.591617,-306.406738,-404.477582,-239.784998,-139.710833,60.036843,134.953996,84.834322,-1.484727,-132.227579,-191.075103,-186.281378,-116.743991,-100.125288,-138.688395,-147.927974,-93.446078,-86.323783,-212.456817,-275.3239,-248.165031,-188.780131,-149.045591,-52.339782,-28.159196,-87.604449,-135.493485,-109.461379,-80.301289,-72.67693,77.284593,188.718245,199.794506,62.625819,-216.520885,-172.661755,-101.476655,-58.091686,-50.369786,10.05956,33.927505,-27.585401,-162.891413,-159.657181,-12.382899,61.149745,102.338336,60.208686,-79.849341,-121.430098,-60.698396,61.739861,73.50078,67.983538,104.954647,196.395707,197.777843,180.968253,258.188172,308.999755,348.031687,316.972912,228.31675,200.199641,157.146978,123.501245,54.518687,116.648355,197.888034,380.0396,427.398046,302.407478,195.759474,167.689009,226.710175,178.265373,14.372728,13.428427,193.476395,246.022706,181.220594,135.356462,85.046265,67.712554,85.209321,145.447705,149.644856,42.690513,-46.067971,-132.138731,-84.177043,-86.759167,-137.779606,-114.24372,63.632346,121.826561,31.66517,-24.861623,13.270617,86.122839,86.959408,66.057189,79.966191,132.921203,147.504323,143.846229,128.387013,159.910891,235.385281,234.570854,264.067583,329.173354,388.060664,337.148375,212.934219,184.509061,177.193114,167.858469,197.488314,263.177097,248.122257,149.627611,30.499011,12.343015,108.832591,153.499525,196.995691,255.041023,338.227461,284.202797,129.815425,130.87748,142.701975,142.605135,163.365187,151.359401,59.946091,-119.023596,-88.133586,-49.38488,12.178086,28.463265,-45.444935,-97.216035,-77.188941,-58.931418,-108.419449,-98.770026,-62.904869,-47.023611,-65.593932,-49.911937,-14.491734,-33.565171,-178.870699,-194.305048,-96.809449,-61.110589,-68.005163,-87.250797,-90.607107,-88.572061,-142.647834,-159.028153,-131.707881,-56.364361,-13.494961,-0.96715,-32.294963,-26.64575,-0.140385,-6.403732,-7.644149,-8.691005,-0.936326,16.041637,53.755706,63.112931,52.486133,91.701113,144.796338,267.311081,303.579196,298.103315,288.807809,272.572112,207.996692,183.910113,168.844757,161.439302,175.806734,186.095474,115.353135,55.076349,15.474478,34.909045,-5.114575,-77.350738,-17.12512,166.913576,177.180359,43.050278,-55.047509,-49.781828,54.421846,131.333869,222.465144,212.773908,131.511436,81.933222,-35.589611,-87.767974,-61.377349,74.845877,140.29137,86.427014,-19.037309,-119.125227,-4.666942,50.061999,28.547241,-30.555475,-77.12071,-62.342036,-77.679809,-114.750526,-183.905111,-174.642155,-118.666532,20.447252,37.617914,-57.28669,-108.778668,-68.17467,71.014315,102.984333,72.114217,31.143849,-35.580509,-53.590224,-76.031684,-70.691296,-57.64198,-75.131804,-48.340151,10.428467,-33.495681,-133.123506,-81.218456,35.878673,-136.426897,-223.730717,-223.439685,-157.978636,-20.096436,-15.460403,-108.356091,-147.143173,-221.27595,-235.643192,-172.995424,-61.644857,-74.753554,-176.355508,-217.630381,-207.05245,-155.323798,-151.827653,-100.79787,-26.649413,99.508065,94.486901,20.198982,1.273112,-54.962079,-98.541286,-70.066288,-24.692679,-43.838386,-127.300005,-151.909067,-114.725919,-127.49206,-172.27162,-181.581093,-103.840173,158.244508,230.395027,108.206702,-7.052473,-136.086013,-105.817386,-68.942312,-43.050185,-38.056854,63.674475,113.442148,53.952041,-23.828869,-15.227617,18.091768,55.829752,188.260782,204.18949,60.858419,-31.300126,-156.80655,-110.966238,-25.938065,140.818961,204.211466,174.570755,65.934213,-79.784013,10.730884,50.393647,-40.171114,-140.663726,-226.126668,-161.783315,0.791754,-17.5548:-133.759046,-237.280551,-247.348129,-170.117002,-113.623706,-32.672607,-8.638313,43.738306,-12.104505,-97.611654,-205.567889,-189.49153,-105.919785,-111.250049,-250.336973,-315.516962,-395.549457,-432.000937,-396.865008,-274.725989,-199.967012,-20.521252,28.783721,-32.777962,-88.888318,-91.945948,-159.674655,-183.94354,-75.142347,-1.015908,-16.942357,-84.035491,-167.514121,-132.274208,-122.294215,-176.894954,-179.585681,-79.934031,-46.957759,-74.020228,-38.819575,28.410931,20.252562,-96.169448,-202.701532,-102.945604,139.701174,167.917983,67.67553,52.361981,100.757545,183.133352,211.325489,242.518151,210.23931,23.958269,-143.081635,-151.007192,-104.91916,-106.533974,-82.409692,-35.712185,6.458796,-15.403075,-119.357794,-285.311496,-347.525985,-338.071506,-267.257338,-149.310041,-156.176527,-191.539095,-171.761476,-205.257919,-326.115135,-320.957109,-139.237527,-67.663527,-149.123068,-236.956288,-248.155652,-106.919285,-57.559544,30.312266,78.640303,118.30929,96.587318,0.990669,-99.976583,-132.836611,-127.846804,-92.901465,-45.495276,-56.440836,-111.149304,-150.484681,-267.349009,-347.3592,-338.783099,-223.918277,-142.172266,-29.94586,-11.337479,-5.404073,-13.808257,-28.702185,-14.219939,46.529946,251.870593,352.232794,354.75338,223.461346,-96.087331,-118.817016,-12.402748,177.665377,224.029057,264.500755,245.216608,90.363813,-86.928381,-107.613555,-18.073568,54.339628,181.179085,209.800193,174.419054,135.755261,111.473336,139.52888,132.983298,98.628571,124.507865,273.195436,326.831851,313.180175,225.094189,197.399868,180.001989,147.810661,70.920813,73.655052,96.861364,83.903019,51.717193,117.257122,205.851153,426.748968,509.144473,522.292601,474.944395,417.341113,374.805305,331.128148,259.104221,266.021259,349.449999,346.943241,181.427325,104.514887,93.595077,93.268902,54.732433,13.916285,17.977535,-53.781227,-118.26832,-133.358911,-117.147099,-175.268329,-290.78317,-285.990984,-153.851415,-77.48366,-28.578587,-42.034453,-89.326354,-112.341464,-73.624542,61.690764,99.362038,66.166549,51.166595,98.868922,134.910798,158.912942,222.830552,229.249036,263.925495,317.711222,372.835278,358.214011,289.501004,171.714023,130.554628,158.440185,218.129195,308.809919,311.592383,301.167286,232.376144,170.072693,116.848591,138.79631,264.472641,357.270207,455.195618,421.030929,291.683097,251.335226,270.38037,314.209373,317.325105,211.697784,102.074758,-35.820661,-18.297578,-13.781867,-13.303032,-15.224233,-35.061875,-20.487094,87.032775,126.547926,61.285933,-84.76023,-113.616543,-103.552693,-91.858464,-38.715643,-2.397725,-2.762144,-142.440496,-187.175472,-106.071446,-32.264117,21.366364,8.187972,27.844024,53.310116,-0.004924,-71.994053,-52.490492,44.578549,92.535856,122.244846,102.737135,69.794393,0.144735,-56.86554,-118.326641,-106.93423,8.110541,99.036556,248.627096,284.890251,271.840231,193.634468,168.762309,150.864806,147.822802,167.895575,186.709629,190.214359,125.869914,87.129376,56.085015,64.04137,75.500872,67.848118,31.065405,10.867462,-14.847026,-32.089312,-45.999933,-45.33694,-8.190858,85.40003,105.693403,75.829554,-19.373911,-60.312025,-44.46612,9.896639,120.031606,139.448675,70.965884,22.719947,-24.709924,-118.440853,-164.069373,-95.191789,-6.594869,61.121496,37.082831,17.948421,-34.520784,-81.131207,-102.717618,-90.103107,-52.6189,-28.81899,-47.702329,-101.675559,-202.877016,-145.204226,-70.952084,16.466715,15.672415,-9.22019,-31.589682,-71.511485,-49.353174,-32.442518,-49.650135,-85.546899,-139.90242,-148.885708,-150.34649,-134.368689,-141.931183,-227.352932,-222.421621,-130.535179,-107.600419,-135.604078,-139.594506,-122.365037,-249.299889,-342.064886,-395.638072,-326.453427,-106.895019,-50.534604,-85.761158,-127.109959,-228.139841,-254.777113,-206.560963,-135.855831,-134.377385,-129.462878,-136.718779,-191.96907,-253.978621,-272.556818,-221.516176,-143.275146,11.202786,47.690711,67.68091,69.142203,16.592263,-59.824882,-57.179291,-5.02207,25.478443,57.83567,30.463407,-44.956801,-46.861506,-35.886927,17.892044,75.819913,225.761088,253.765802,140.305964,61.441884,26.905221,82.64613,68.616284,-7.102821,-9.928053,90.327494,143.677132,98.468146,-100.758319,-136.202533,-1.664572,65.643213,58.553654,19.510672,-58.356627,-83.955266,-93.979224,-47.080056,-29.313765,-24.617981,2.003826,53.67695,22.692477,-74.482565,-101.26534,-136.828918,-233.489056,-240.271433,-148.240657,-79.994784,7.048147,1.673635:-199.635778,-219.66963,-187.741365,-101.483932,-31.485239,104.917333,109.542244,17.359231,-26.333869,-24.161736,-16.115312,-18.389033,-57.581476,-117.952223,-268.165614,-300.956484,-315.9573,-334.115669,-339.83054,-298.575196,-205.885826,39.624185,89.454996,-32.175605,-187.978346,-197.410143,-193.83398,-216.436983,-173.575804,-109.783552,-109.139625,-162.665486,-175.339033,-116.552893,-122.669586,-146.038398,-116.795497,-34.569957,-19.975165,-25.353667,-41.035192,-42.601162,-63.469995,-80.50356,-75.161995,-77.197913,-104.3765,-84.523413,-7.745232,65.947709,127.901023,240.099805,259.252644,215.830306,155.95937,14.229896,-54.36744,-50.256347,-18.234972,-2.399995,70.183298,103.010735,44.168827,-25.395514,-138.408039,-171.461672,-170.352452,-155.512153,-110.394778,-0.61276,2.401136,-57.286377,-146.897723,-195.77884,-193.253581,-121.472411,34.752604,33.196288,-157.862648,-259.593104,-283.601972,-130.166457,-41.351253,180.630509,264.859025,171.516133,58.262703,-59.507179,-107.880183,-115.811455,-71.41657,-51.531551,-64.028506,-83.930411,-118.5704,-137.410844,-210.109887,-238.225631,-218.000958,-152.667067,-97.57142,9.374464,17.416041,-73.469548,-165.164495,-149.03111,-25.345616,57.702929,244.901338,315.50655,285.864614,174.148653,-89.426859,-103.530692,-15.305426,116.209462,134.532706,173.477706,194.854391,116.873473,-87.729264,-109.349641,43.565429,123.933132,183.998427,186.00034,148.650507,99.678303,28.913145,110.130341,174.657351,259.824644,273.916147,259.191736,253.864408,264.38836,217.017125,196.637041,248.142201,298.542235,374.902913,371.413226,258.584969,188.483315,94.216121,117.188611,200.416954,459.661143,562.735868,492.502997,366.009263,261.441793,274.59048,253.087824,207.703762,223.060307,350.449292,387.941059,275.737528,173.699166,55.763037,58.880695,57.572203,82.057937,126.307847,157.706804,102.880923,-53.711656,-132.276832,-147.388859,-159.141367,-135.999399,4.55528,52.961853,-15.818944,-70.402923,-131.273402,-179.521439,-178.601253,-56.649768,39.484988,110.461861,77.304791,40.084508,43.136258,57.594024,128.708118,169.992942,276.46616,332.613753,368.95575,346.716979,259.685724,174.623565,152.018869,164.441006,209.634298,303.005727,314.460478,297.226496,189.676097,115.135513,125.390685,230.396899,476.52928,535.004637,474.085958,412.722171,343.492086,334.331713,341.802879,387.858708,408.661327,318.227079,219.979595,109.330088,70.051238,20.958737,-19.087047,26.445301,120.757594,146.559814,210.437197,207.016407,64.443958,-9.532318,18.319411,82.806613,108.934031,118.20293,82.556106,-7.606999,-51.866239,-38.112497,28.538504,49.323549,56.298902,46.019047,35.163194,35.239489,-28.952301,-116.439465,-121.409533,-71.692551,-52.668457,-98.27236,-131.160576,-87.765891,-20.364397,-39.067975,-123.626661,-129.590095,-13.158769,52.023164,99.930228,108.857832,83.045003,13.126484,21.37626,136.141181,185.65127,173.715741,144.333024,112.822443,66.163595,34.992989,-6.780248,-2.871741,64.315251,76.741573,-47.194578,-136.652513,-193.020319,-132.429957,-123.154893,-87.555849,-7.778575,156.290136,153.444187,32.216571,-71.138718,-90.464477,20.056807,130.063824,257.554266,231.545623,59.566037,-15.438841,-89.607441,-158.236121,-168.354217,-73.534612,3.999756,25.095352,-35.528993,-100.0571,-99.11511,-107.959793,-119.18009,-119.502262,-88.562998,-67.33743,-76.765596,-121.584547,-220.986367,-186.31386,-136.142842,-54.864971,-31.975313,-17.228165,-35.193656,-94.629116,-81.386609,-58.141255,-24.869189,-10.282198,-45.359888,-106.530175,-158.134396,-107.235488,-32.726623,-105.924461,-102.554033,15.569874,48.613865,11.796749,3.968191,-9.61724,-191.737165,-278.13642,-267.616756,-192.731233,-26.293041,9.111601,-48.347008,-101.773745,-196.657757,-188.040329,-144.811891,-107.710606,-106.455204,-56.770511,-18.13873,-12.789148,-103.981764,-110.395752,-9.943497,64.464348,171.181258,159.439269,59.113597,32.660665,-2.453754,-40.503285,-19.93403,27.943019,15.192717,-87.243833,-140.973992,-158.337099,-141.628509,-131.251812,-14.809149,80.789818,233.674496,248.774062,143.232666,58.606797,-72.767113,-52.186982,2.202233,77.880817,80.639044,103.716522,136.250388,131.7611,4.352406,-42.266685,-35.167141,-3.487507,62.311488,68.09072,17.299958,-6.468263,-64.236966,-94.271971,-67.996201,6.509311,50.754314,127.162595,121.003357,31.018643,-70.652086,-116.438498,-180.440046,-186.595788,-115.221209,-35.402499,84.396092,55.822444:-240.062906,-399.514153,-393.506452,-265.129836,-206.181418,-136.326949,-107.168081,-52.603041,-126.843266,-205.940785,-317.247567,-328.316018,-255.339509,-212.383546,-258.536098,-328.288291,-369.914689,-220.858564,-143.106537,-54.242863,-1.330092,144.288994,192.716676,187.429965,91.229369,37.574087,-50.179485,-74.052088,-37.510961,-2.918113,-1.216556,-25.777447,-70.345015,-86.973686,-79.041444,-41.612014,-12.708808,42.125166,57.427876,65.684276,43.412804,39.089736,24.864853,-12.258285,-14.901409,71.1587,250.781964,268.218813,198.318907,210.492806,261.339821,311.825248,295.481895,252.899556,237.944167,130.468074,-97.657887,-167.599735,-156.513216,-134.477698,-93.093973,-47.826495,-0.203049,-53.377034,-245.053895,-332.947343,-320.909946,-223.570776,-144.853512,-36.870635,-53.48676,-88.532238,-31.642733,-59.047801,-201.064079,-218.448291,-117.244852,-86.617345,-147.970257,-177.620915,-130.489033,21.933885,111.87968,228.323419,228.318812,126.165123,52.309235,-41.286743,-74.386919,-86.182035,-33.912002,-1.362183,-64.178649,-136.765714,-235.979702,-254.04377,-272.373078,-240.087424,-207.055446,-144.191096,-98.171421,-31.646643,-37.404718,-45.063113,4.152707,35.692253,151.585526,243.283752,433.119487,512.269781,552.527401,484.493443,296.080436,270.773137,319.426381,411.390563,451.387512,488.596778,430.682527,188.095701,9.827005,0.30483,103.812016,170.480699,297.257716,341.427235,296.421783,243.327426,223.151352,204.276602,166.074413,118.371567,145.256429,268.571216,296.031141,195.971117,65.084918,69.332347,136.302661,107.524263,-46.486126,-88.546722,-81.859106,-60.97891,15.810341,132.228744,204.719128,391.411711,491.773512,605.568141,583.584962,399.457105,214.152524,182.231851,247.20304,323.061563,416.230539,359.861212,130.800403,72.144439,57.283764,-9.442333,-20.989285,45.637299,65.303925,-8.116799,-54.901697,-37.409926,-58.006277,-129.217839,-213.484991,-204.982991,-139.111843,-98.971676,-65.105776,-64.091393,-62.073004,-65.448224,-41.300266,58.898364,84.514663,31.182511,6.931954,80.162887,189.395621,210.027339,223.31498,234.789325,314.167707,380.092202,420.677735,358.365481,170.431124,66.324169,52.733575,56.461175,89.98054,224.299606,284.908158,360.687099,301.15556,200.67241,42.621295,62.743394,265.032219,358.725477,419.520549,408.804251,333.236867,233.7472,211.820476,225.804157,242.28998,208.010924,145.290029,46.01475,-1.914722,-35.146867,-66.541087,-76.043306,-134.652161,-140.518165,-69.370146,-45.74194,-106.512584,-247.222005,-288.286508,-255.818873,-205.192495,-113.249864,-93.940985,-100.342666,-122.77994,-125.606075,-114.035549,-107.434609,-43.731358,17.519348,160.797659,238.46656,303.507323,208.429298,170.560901,168.299014,168.646187,77.991134,18.473615,33.679594,66.040434,13.263425,-129.908756,-150.439179,8.654988,148.124947,328.091229,323.742496,156.651808,-13.767067,-21.383807,68.97906,111.191204,111.742064,89.201502,115.135179,143.189813,82.148813,-85.448927,-118.976596,-56.300915,-4.943857,12.812621,-9.556975,-30.408784,-22.635096,-45.394517,-157.251829,-181.30369,-74.844062,9.834267,71.662798,-38.20268,-92.385072,-85.018975,-48.707252,-52.423074,-94.733064,-161.482687,-155.616254,-116.253955,-205.593779,-275.622674,-268.765442,-172.000008,24.670492,67.441387,98.764838,34.863156,-22.576607,-65.57605,-74.202737,-105.680718,-94.90413,-20.230835,13.258714,29.675541,8.350344,-9.84221,-80.8402,-106.984131,-95.985422,-81.489863,-32.0562,23.24141,28.12167,-46.693049,-142.426274,-270.660518,-232.856923,-110.127361,-102.227919,-180.763453,-214.61427,-172.355488,-73.026723,-69.123107,-127.75593,-132.810319,-120.245418,-336.38145,-483.944932,-548.38901,-452.084449,-178.630189,-79.958384,-44.355428,-84.102526,-182.05992,-191.252569,-152.166966,-77.64135,-65.853953,-68.75945,-82.518997,-137.281686,-158.365565,-150.895177,-129.218839,-109.843345,-10.344231,66.936956,161.825273,150.208574,69.156471,25.61907,14.813412,-9.045768,-3.393683,30.072809,33.273542,23.867625,41.619991,65.283508,98.10102,99.842053,151.454426,193.147422,210.656857,174.92601,64.572044,42.527384,69.000241,103.33268,105.759868,150.813509,188.742894,175.027767,-12.729144,-81.472859,4.854818,93.803907,117.976191,38.631679,-132.588823,-144.189822,-67.326778,-46.085702,-30.681688,67.88622,124.399212,146.285189,96.738572,-47.900605,-157.866951,-179.756281,-135.955765,-79.629807,26.890842,51.825162,73.491971,91.411191:-271.188651,-342.292529,-297.660925,-191.389264,-151.66987,-61.960755,-23.813314,-58.542297,-197.585429,-222.795621,-174.847502,-137.84515,-36.719635,-6.788234,-128.124978,-255.998343,-441.284912,-361.550324,-254.405841,-74.204339,6.7037,177.82871,215.886869,122.736942,-74.004055,-131.109006,-135.685282,-109.397694,3.018403,63.2157,69.633923,20.643596,-96.987643,-166.688419,-176.89922,-107.397374,-20.869501,109.796214,100.160693,-5.756,-72.65229,-67.911659,-30.466372,-33.338408,-21.19644,37.018277,165.205413,170.600979,67.158703,65.182566,149.01919,303.183935,329.64487,335.847785,314.355502,164.624758,-45.254595,-106.374319,-109.483089,-82.55473,-21.714485,0.828204,-12.742345,-51.452868,-176.303641,-295.9153,-309.71763,-194.347228,-76.766859,99.185317,96.241829,-5.428468,-78.486992,-93.710396,-108.592655,-97.607087,6.694436,59.452202,19.602951,-68.151714,-184.710263,-39.195046,73.307297,260.533455,316.689133,254.795062,163.246831,33.920176,-82.301285,-149.69454,-166.710185,-130.365568,-95.493617,-101.38761,-115.122561,-120.793183,-184.23288,-275.846023,-293.360108,-231.903262,-138.240822,78.722363,123.801608,22.776812,-151.039028,-173.869679,-24.696371,123.416047,434.094573,533.044639,502.36183,382.490938,117.573762,80.753996,153.754973,310.833203,363.941158,410.913639,388.319381,218.711461,-15.796956,-62.818279,27.210608,125.350319,342.988883,404.227825,325.077348,230.213038,130.22088,178.36473,206.612626,221.719131,233.731565,320.396694,362.669492,341.625242,214.648239,165.488351,119.335881,109.71715,154.73052,194.108238,187.716986,127.65757,-4.73903,56.926357,174.731562,478.397365,597.571355,605.344655,529.422285,424.256815,303.916964,230.785342,248.582403,338.441701,464.356064,436.171505,246.646164,151.18401,66.506761,111.341956,140.614725,160.238274,153.063311,119.709221,100.629876,17.947045,-173.634495,-239.961462,-219.046935,-170.26459,-35.052219,24.200735,8.205284,-42.87052,-105.605987,-100.161329,-79.027308,-8.245926,41.833675,122.1711,123.285764,62.940576,9.247497,20.542228,112.666496,154.271702,240.402909,301.775502,367.010914,335.751007,162.018413,19.146842,12.923068,83.913327,155.976431,313.704632,340.748709,290.43583,177.133107,134.702023,178.989125,263.188439,459.206877,507.607508,461.877095,426.845451,370.454044,248.567486,223.009849,353.677775,434.498809,385.305681,281.886774,145.080189,57.678473,11.064314,33.562824,90.160029,174.938693,199.919483,207.052952,160.36429,-21.915201,-159.080032,-147.959327,0.854758,65.984771,73.657069,41.562047,-39.39789,-109.591618,-100.429175,-18.375868,11.112797,92.727386,164.614676,236.959779,192.300515,-1.465403,-101.358073,-69.488513,46.737063,73.031304,15.300465,-27.686376,-21.067552,-30.093668,-92.682336,-224.957042,-222.619542,-8.391512,130.785673,244.859362,205.977813,37.945037,-46.98519,-27.010429,40.550696,53.35334,45.478285,37.8161,-2.395686,-96.364789,-135.597737,-161.061043,-149.338548,-70.699983,-33.491087,-48.94735,-92.87146,-175.358601,-186.268796,-180.401376,-135.531063,-51.630563,162.827678,184.251703,-7.238501,-201.065995,-201.39173,-56.722947,17.010993,55.636172,35.59086,-18.080618,-52.946415,-157.106414,-280.512226,-299.312801,-187.371922,-95.047219,10.427014,6.80285,-49.474415,-132.980525,-170.604234,-211.084872,-214.077793,-133.40554,-64.589159,-24.965394,-75.602256,-191.219119,-156.32369,-100.28479,-24.35853,-13.981023,-14.537305,-14.783625,-12.532055,-77.434334,-123.38226,-123.109234,-87.606325,-46.794056,-42.101784,-30.021858,-29.688288,-107.817145,-184.156581,-145.629905,-31.148813,-11.489341,4.580852,21.106849,-3.111375,-193.717628,-306.529856,-381.71121,-308.871732,-46.820349,36.402755,-7.684912,-73.25656,-172.049134,-181.772293,-127.588406,-39.04856,-52.703461,-88.892129,-90.091978,-128.690268,-194.896813,-207.31982,-159.646886,-99.70166,58.238873,131.195834,181.388342,143.131025,11.383612,-59.7373,-56.024121,5.865222,55.587229,104.172483,64.354836,-79.980411,-150.616658,-147.902665,-59.317306,33.025682,266.49993,331.874091,213.383548,92.418034,-27.187054,36.194724,81.841141,140.817629,153.824308,183.780531,202.549158,180.903306,33.231905,-40.616953,-52.801616,-6.44733,53.688151,38.522587,-59.197211,-107.770868,-167.217567,-155.263852,-112.278597,12.797688,75.564951,85.125021,12.472195,-113.647183,-109.933256,-106.574451,-105.467834,-81.228176,26.68482,86.444331,132.916021,109.614183:-251.311975,-418.95854,-382.628672,-163.063251,-58.618458,14.34236,-15.010827,-43.119108,-33.62091,-81.95572,-218.150505,-240.909275,-142.732992,-76.14712,-58.244856,-76.90918,-26.647153,112.406332,181.021875,264.473833,276.332406,255.76192,224.32335,148.081752,71.8559,56.534554,119.169939,166.085546,220.339055,218.169439,153.831914,119.624199,83.860904,73.605896,82.321646,119.039697,154.594265,264.24366,282.491854,201.280371,182.398137,214.240294,216.57268,175.75368,187.150071,287.544072,505.886512,526.391961,395.193609,285.214323,276.123793,248.867279,224.471974,199.523693,183.923651,107.352638,-92.520399,-216.038669,-312.081113,-281.987231,-238.135665,-248.678947,-281.15664,-287.810782,-323.034939,-418.216743,-414.081456,-258.9453,-192.117848,-139.428317,-97.168974,54.161963,87.421829,34.93804,-37.041306,-26.640383,28.981505,40.716416,-8.390157,-34.351702,5.794278,137.996498,195.02729,180.702767,111.667734,-1.848001,-14.663182,-25.625302,-90.242576,-121.502768,-127.611194,-144.726703,-262.3278,-305.448749,-287.462795,-246.662141,-142.850463,-116.643426,-143.720225,-157.415966,-117.839294,-30.851971,-26.56096,-56.962739,-32.603631,-3.078164,89.385246,158.660756,338.367838,438.778405,556.664338,534.939322,365.349438,226.234805,230.293455,299.442836,310.864751,281.487803,263.127003,196.323121,14.961688,-70.294611,-92.241163,-47.92878,69.312464,129.531601,194.913124,195.679496,183.039041,141.371997,103.881165,55.323767,77.042736,221.980493,288.446363,232.630945,2.910211,-75.698077,-70.234828,-50.02453,-123.775895,-167.936237,-147.016547,-125.960891,-186.26846,-230.102145,-162.445835,81.904627,179.295222,217.710338,145.865951,-125.739081,-312.583557,-310.889228,-197.704418,-132.331127,-24.124836,-16.140989,-155.339824,-222.050186,-176.508767,-49.811616,-5.317717,36.814069,29.023885,2.285716,21.372882,84.545478,7.776044,-67.922421,-138.550247,-107.969893,60.655403,133.245016,148.343018,147.156687,162.643026,87.55445,58.188055,51.85744,40.410314,26.653707,55.150773,174.93599,191.535198,107.078558,-52.843259,-36.026331,150.125811,241.930679,293.182234,267.539834,208.807118,129.046161,83.270138,62.170364,91.24186,116.43993,92.991507,77.793215,84.862403,31.328957,-133.322755,-162.881798,-65.112001,-0.776693,33.422197,27.358139,20.616667,-35.268247,-77.26063,-100.182956,-50.633051,34.222079,-4.359158,-139.386023,-179.936562,-187.018187,-203.486807,-215.419091,-255.865358,-274.850402,-308.322493,-310.735685,-294.160622,-359.931677,-400.266031,-394.31302,-346.244509,-255.789217,-252.501642,-296.444957,-305.058938,-274.263754,-157.356274,-112.546675,-59.629103,-13.979815,134.917705,215.157553,282.662512,223.190468,214.556006,218.374206,189.364487,121.021774,103.839545,97.338426,113.712612,96.319987,-15.162054,-67.000001,-13.66602,87.062923,182.209088,101.784052,-185.269192,-331.242411,-311.13483,-182.055899,-115.973583,-26.627652,-20.595085,-64.824298,-91.639141,-114.82532,-199.864939,-235.909021,-244.095568,-209.795897,-108.532597,-79.105184,-109.589041,-205.265493,-263.52637,-347.171276,-334.616112,-217.11941,-141.018189,-21.165285,-72.077479,-137.426765,-163.200816,-141.547152,-141.319109,-145.622865,-125.960068,-103.125335,-54.981358,-130.70697,-206.849216,-214.09678,-125.221563,19.99908,20.883179,-16.465705,-68.674879,-139.170247,-254.328616,-253.419079,-165.532336,-110.85502,-22.177475,31.74819,107.792066,-2.651683,-69.022551,-108.654351,-106.902902,-105.560753,-100.133854,-102.403702,-175.364807,-204.117662,-199.774371,-194.414312,-151.414519,-102.047275,-20.133526,-10.13017,-56.921544,-107.970782,-124.790662,-211.50033,-258.1398,-206.452451,-121.230306,-43.533301,-251.015129,-401.676819,-524.509524,-466.233898,-244.989556,-121.834828,94.207087,151.157385,125.841656,62.743646,52.782653,12.047373,-15.707907,-24.676121,-20.860918,-56.920064,-131.225408,-171.706998,-231.767381,-234.913731,-142.975367,-41.046922,139.541853,147.562288,16.558103,-112.847445,-138.587735,-180.686587,-195.242911,-116.172726,-51.365435,-6.850619,-12.270951,10.306421,65.90032,74.093086,96.783873,122.073316,144.445896,135.429283,124.8005,149.40266,159.251292,117.459452,82.863341,120.813224,175.426333,194.817526,80.873613,26.510875,9.784249,30.692991,34.931012,6.466779,-51.889746,-42.131479,47.089085,133.386153,169.747345,213.495105,209.679331,145.650668,101.050886,64.206673,63.349795,54.048924,97.432039,145.405182,187.247304,180.645381,218.338384,274.367244:-330.923573,-393.017925,-328.71181,-79.964355,12.561251,-4.226641,-67.851793,-134.610419,-206.024196,-260.698472,-260.332152,-187.093858,-20.019885,-4.455231,-154.456513,-233.997631,-165.298381,82.650398,129.602751,45.230859,42.077334,199.800099,241.260727,135.048175,3.845507,-15.104467,8.300058,41.208232,166.324305,205.270166,146.988277,114.495041,134.722464,103.891975,53.426167,26.747793,72.428775,167.833279,168.524592,134.25132,226.043464,283.384785,215.138579,111.092946,79.732457,182.840271,337.104145,326.94661,272.899442,321.915759,344.985647,302.402613,275.68932,265.641837,249.167423,123.746153,-141.371125,-234.076241,-177.493529,-130.752145,-195.842226,-243.860861,-275.885079,-283.435787,-282.64565,-251.974904,-224.836345,-141.081977,-102.097983,-36.115668,8.475758,114.125156,123.140075,66.328629,-68.451663,-91.708962,-41.73086,-14.705172,10.551193,35.958894,97.621178,106.185382,112.953427,131.276699,127.017007,101.982735,62.210116,-69.581749,-108.783351,-78.04538,-25.517657,-33.986652,-116.408043,-177.924888,-276.076493,-280.727724,-206.467543,-174.22101,-205.24775,-280.960851,-292.615211,-261.435371,-219.459535,-99.874447,-54.943493,-63.464465,-33.080362,16.606142,154.309359,226.159686,289.735959,270.219124,199.274219,170.733954,192.192509,247.370402,255.307449,215.742581,160.501126,20.898341,-58.18166,-69.75353,-80.607865,-73.361848,9.341868,65.847327,165.082656,214.57481,247.178733,123.652007,66.64808,59.762246,91.425387,156.642321,167.450886,112.313102,12.993487,0.644793,20.286793,-4.096498,-72.326373,-58.8469,47.040295,81.919159,39.239347,4.298612,64.733794,309.152813,441.759191,595.092471,566.593242,319.617911,33.129072,-35.073561,49.773352,143.729432,221.420133,184.121216,101.235377,113.419238,187.024528,208.571372,226.675314,281.964084,268.574993,148.842766,102.188005,120.845082,115.406298,58.231221,-42.935683,-58.314406,-19.188035,15.395704,50.037639,73.478931,149.115825,170.276249,159.98245,107.424008,85.988613,119.220862,165.043998,267.08073,321.536885,318.06398,275.782447,249.324117,276.098592,328.303813,365.05949,335.404386,223.014363,90.522637,46.136223,38.314592,63.672463,95.629487,108.330365,133.754805,23.54436,-59.713996,-138.471041,-114.119045,66.427834,171.612648,258.666135,246.442807,181.460523,133.019116,141.065033,187.997308,194.990515,150.11467,119.25329,73.415543,7.606453,-25.382444,-48.019534,-51.671911,-90.233771,-115.913141,-125.632182,-91.859969,-5.571988,-62.578538,-131.282226,-198.098349,-167.773881,-76.690295,-72.726199,-120.520779,-177.216129,-198.367028,-155.722871,-96.712295,18.18414,55.749967,126.82567,187.453413,263.548737,197.298897,172.986461,144.089221,114.813311,25.398456,-25.281643,-35.583653,71.789109,85.092296,-15.814669,-73.186118,-47.168093,44.291153,186.448011,144.869336,-107.808193,-266.445192,-282.019666,-231.803152,-159.72877,-61.031435,-101.471768,-222.751233,-202.593698,-203.553473,-315.367653,-367.457014,-357.920869,-331.219844,-276.527806,-214.328329,-124.964825,-261.289937,-355.131393,-478.372317,-503.570761,-440.78,-366.272838,-246.667015,-220.984605,-215.96469,-180.158199,-190.056483,-274.862906,-289.631228,-213.795862,-155.065057,-123.221041,-248.252948,-288.421608,-189.386377,-91.831451,37.829707,63.286293,65.638409,-20.110207,-70.448268,-133.162313,-156.244269,-166.94438,-140.230118,-40.312077,22.658546,89.30425,-1.83698,-52.577531,-55.943579,-16.516517,46.507598,40.637518,-2.026533,-53.610008,-68.126781,-61.98763,-88.254244,-138.367377,-104.18923,5.47406,28.687046,-23.506086,-97.651045,-85.35504,-38.816026,-42.998994,-49.899251,-40.391724,-73.531607,-242.196147,-344.539148,-427.375349,-378.955569,-149.273401,-16.24853,108.76346,79.705878,-1.866084,3.81764,-0.068705,-62.285134,-76.087783,-33.220325,-43.041528,-144.541952,-129.420053,-98.627936,-53.516531,-27.163032,15.57878,46.462963,161.110921,207.614742,146.761298,-21.227321,-60.648659,-63.810631,-53.383596,31.256545,88.947144,121.281162,90.565502,114.59854,243.334285,280.995715,285.773666,291.930061,263.10673,209.512212,99.941541,89.812912,119.525995,137.833544,106.143266,72.302219,93.633407,103.250146,1.903744,-35.581765,2.556336,51.135712,78.368577,43.364158,-22.274409,-11.352838,64.448885,121.090738,140.025292,169.79938,186.270397,132.983924,42.051254,-73.60404,-85.425946,-149.64077,-262.046549,-217.315646,-43.361658,-8.867136,12.087881,63.217104:-229.314616,-334.022652,-291.42719,-184.794991,-170.784301,-153.497376,-139.292288,-95.018566,-53.191987,-83.125039,-204.917798,-238.229223,-171.716219,-100.198742,-45.123149,-84.828131,-206.149142,-192.962958,-110.918001,75.857378,148.78418,227.417665,211.313945,105.082281,-16.60732,-56.539246,-16.494174,46.210652,107.762235,85.75391,64.523376,79.425486,56.11596,-5.383634,-14.658218,36.420772,94.670418,175.629864,159.83055,79.722569,71.490647,90.283048,96.924206,89.948921,142.007307,204.391419,304.467501,305.047903,208.296157,170.258396,203.820301,241.159564,230.031827,183.58344,140.299124,29.462139,-26.613357,-28.418378,-47.132006,-75.106183,-108.331534,-92.31982,-59.699995,-86.298029,-228.180052,-331.851124,-316.774488,-218.0076,-165.580451,-67.694161,-22.947264,49.270294,14.060817,-20.354455,-2.474248,25.394056,57.69888,70.307619,64.109568,34.043771,-28.395975,5.870121,62.818191,127.246852,88.642738,-12.495177,-5.906223,28.262235,-81.214264,-142.949072,-164.489205,-158.369697,-235.582855,-308.776131,-370.880346,-325.804238,-235.841411,-260.318572,-242.741998,-132.225717,-88.014862,-21.97924,10.920512,18.138574,-84.51224,-122.094876,4.764127,161.814434,443.194492,496.919129,441.308089,378.264158,287.359321,294.608117,314.13758,312.759674,308.224947,325.023719,318.056672,210.635137,-2.728904,-66.286686,16.216336,94.662258,174.944122,191.926637,179.836499,162.727455,158.807965,125.478249,109.064591,146.767231,194.242324,259.655328,254.233228,198.838559,76.46427,-0.198089,-67.085945,-39.925658,66.313752,94.178756,38.821498,-8.687952,-45.38477,-26.38377,8.819098,169.302337,262.670832,358.402436,352.746893,237.613314,-22.579825,-122.877393,-62.519516,47.229734,163.202191,127.427273,-19.008285,-56.88065,-71.01115,-116.003292,-95.093565,25.445271,35.375921,-98.184657,-162.886058,-144.602022,-142.782938,-206.40007,-294.474833,-258.034569,-39.071363,70.466598,118.40983,72.032969,-27.14451,-81.844957,-76.19058,-1.620546,33.966351,33.521964,13.198619,43.069816,101.667427,90.895207,59.720237,70.36506,166.986234,237.057762,304.664623,282.076891,143.897668,-6.756348,-22.095355,37.423066,82.245214,206.17956,250.940253,240.151844,175.75283,131.755087,60.371778,59.947394,157.542728,241.158155,305.394307,234.990736,59.540836,82.56896,133.261402,186.512122,194.793405,155.504901,87.212775,-27.866549,-53.463851,-69.130646,-59.079045,-33.722365,0.404306,5.687733,-38.151047,-100.961176,-250.133486,-301.626311,-284.214905,-255.533558,-245.830848,-168.487023,-123.320669,-103.347286,-110.000126,-89.152022,-23.487639,-4.725815,36.346102,86.011373,211.619862,251.904875,234.150076,183.860116,183.914653,172.293658,135.258193,14.662206,-35.797327,-15.280718,58.928649,44.781552,-21.270842,-29.325472,25.914025,79.157597,132.329282,106.220901,-6.965186,-124.155832,-138.281633,-61.519262,-1.927228,102.448892,126.657283,86.10382,-2.555052,-40.132337,-90.858934,-101.96831,-82.095071,-55.016811,-58.253269,-89.867789,-94.789571,-98.915484,-141.397411,-159.34868,-93.432198,58.386374,79.868516,36.796294,-20.20131,-39.882321,-34.622449,-17.608717,-8.017439,-30.83673,-123.939724,-150.041887,-128.824514,-135.904029,-137.248739,-67.793431,-23.871346,-21.997966,-43.491722,-6.591378,13.165476,-38.615537,-160.420692,-190.969202,-148.270001,-77.701706,13.527549,4.317178,-19.253292,10.817318,22.712128,3.945907,-8.952602,-13.70606,-14.472855,-30.069864,-101.212805,-138.445272,-173.836677,-194.995881,-167.821629,-93.115011,-14.61212,-48.743666,-98.262254,-125.806031,-171.551111,-207.145601,-160.859925,-47.015248,-25.077958,-65.049642,-249.26197,-364.862048,-466.773525,-417.49736,-166.323624,-30.643719,105.665598,101.879952,10.401765,-37.849966,-14.258021,-3.604378,-34.084626,-55.444557,-44.553396,-28.547663,-65.685555,-129.675443,-260.610195,-270.635503,-108.078067,27.784986,178.444297,142.083536,-51.112502,-140.631699,-111.837748,-11.935469,17.660974,2.714795,-23.351508,-20.538235,0.689148,-10.541297,3.634146,30.813912,73.471917,77.547583,46.078864,45.1039,129.073215,165.535078,146.941908,120.902825,121.208548,171.469122,220.415699,269.55227,129.246327,27.827251,-10.464365,34.296488,46.53065,13.187465,-44.258089,-61.155712,-63.286436,-32.379793,1.394685,133.380259,204.50388,223.698592,176.483514,124.490441,94.610757,28.306004,-81.029283,-50.527764,123.909293,202.854561,291.465489,302.787485:backward
-70.251972,55.801771,91.894037,73.982621,47.057557,-39.278465,-90.448289,-122.20368,-52.391851,7.480885,134.628879,163.264047,97.390852,30.755969,-13.300137,40.967459,187.25029,207.805022,180.007697,156.184731,167.272091,146.392225,109.412385,59.732463,60.585313,87.653219,202.676901,250.344576,209.382651,130.000376,-7.948407,-21.502897,37.833502,78.742828,65.996432,-25.310759,-92.694208,-206.658263,-231.622674,-208.915863,-100.331749,-41.755635,-16.026967,-51.341859,-124.083994,-161.512612,-258.159581,-263.938478,-139.118811,-51.038932,-71.532729,-149.069776,-173.349681,-231.417153,-265.927707,-232.456979,-94.168079,-47.043145,-11.686015,9.132468,94.760739,120.56331,121.827337,145.683587,258.233926,395.935171,454.242688,479.458509,448.898026,353.962704,302.547279,246.532704,266.547413,282.760947,301.652932,305.980384,290.885193,268.073846,226.559351,214.995757,205.829605,258.602849,282.474178,215.243376,156.04191,125.835543,156.572463,213.022888,231.211697,264.904553,339.502876,339.636982,332.246628,371.545167,496.784159,520.754478,390.640775,217.01481,213.591809,278.858339,267.602919,157.840888,122.299073,153.647066,177.65649,184.512821,281.845099,333.163627,302.665649,253.868956,220.555516,217.27164,153.841324,96.72751,86.14332,56.232591,44.9841,2.806409,-33.019916,15.167875,199.409863,250.161756,230.526626,203.820552,193.471612,164.095083,-9.260853,-61.901868,55.570234,311.373064,414.800878,432.383252,347.553926,172.497825,148.264718,210.221236,199.661239,172.377778,229.766499,291.450876,327.747794,304.530438,309.760359,359.96568,444.934323,447.256496,431.20131,354.394924,318.781168,288.972069,270.928408,245.419961,325.877028,403.632743,489.467366,457.520535,365.280416,366.909143,473.182719,531.084899,580.299334,590.867885,560.440091,395.055175,319.920268,246.212907,210.967302,131.895742,98.977226,87.169998,43.994029,30.175794,63.980503,83.273704,47.578816,27.819137,50.065472,64.831985,46.309555,-39.810408,-89.487098,-146.243189,-147.391661,-162.129182,-221.165931,-226.010253,-172.310631,-144.118463,-127.889485,-142.361977,-172.6317,-151.748789,-23.549284,86.418251,99.065803,79.695662,65.469033,5.070081,-55.703434,-202.214556,-228.733569,-162.174395,27.477855,72.984969,2.350975,-64.847202,-88.354351,-28.289365,75.479336,67.375407,54.554693,10.782803,-41.353851,-201.734007,-263.1313,-230.027026,-104.050663,-65.869433,-38.506041,-46.575636,-97.846957,-123.399473,-85.674409,-8.160137,155.890325,194.653535,176.091775,150.407392,146.51157,62.105177,-10.908287,-54.013844,57.91405,113.258642,125.163567,57.802956,-126.905204,-164.027275,-123.28535,-102.909706,-105.966329,-76.568133,-48.996343,-51.16591,-87.822465,-203.733135,-253.662245,-268.284774,-221.564386,-218.384124,-259.695148,-262.014273,-180.445257,-127.466984,-76.885851,-74.911767,-72.115229,-58.610743,-50.050185,-21.414792,-6.490464,-49.615098,-109.294044,-182.382665,-106.424119,-57.118152,-49.489213,-69.313002,-57.113406,-60.434567,-144.07989,-166.899227,-105.39251,-29.612723,-33.534698,-154.728893,-235.940027,-324.842686,-326.972884,-266.302176,-252.590237,-291.999189,-328.828343,-297.475734,-220.196015,-217.341939,-258.481977,-257.181409,-186.209182,-95.925235,-91.185215,-179.872287,-224.585109,-301.575685,-352.637569,-386.288923,-326.302416,-315.312048,-331.143526,-335.475978,-316.440724,-308.775706,-333.463631,-345.965359,-279.985132,-104.928345,-24.144044,81.152624,100.499916,23.411373,-65.986599,-222.635203,-192.669375,-110.480686,58.775838,94.410341,83.949305,56.78434,-54.091961,-90.003761,-15.991613,126.079646,167.872051,161.01631,136.406308,61.492279,-4.381768,-106.613164,-77.949867,-38.523588,17.755943,10.53617,-63.776438,-91.228661,-82.403289,-72.866506,-80.98808,-74.830082,-74.212795,-140.303067,-197.723358,-314.661525,-360.619887,-343.798501,-218.843894,-154.987684,-43.724115,-28.143162,-145.600105,-239.077621,-319.47256,-288.029463,-195.222229,-148.880751,-125.633684,-103.904054,-124.611146,-189.56145,-205.600997,-184.775891,-118.608711,-67.994512,44.782099,76.006892,55.919793,21.960482,-57.120005,-90.278231,-112.225238,-93.337429,-95.267546,-107.554557,-85.676545,-55.048898,-91.56935,-175.186104,-140.553038,-94.5697,-37.100301,-56.912742,-143.776497,-161.539455,-147.370758,-151.987907,-198.421926,-175.674974,-127.60799,-77.119487,-74.817547,-29.856761,-15.749376,-83.648373,-130.827991,-113.352139,-87.848325,-96.141366,-82.34064,-58.863706,-71.940611,-82.212897:-131.689888,-83.977426,-101.861304,-176.001739,-209.92187,-272.343655,-265.181781,-112.397012,13.324542,24.605358,1.86478,-26.377888,-105.006038,-134.055549,-102.434549,-50.173266,11.479708,43.028219,83.868935,167.068784,172.723607,76.869817,2.940741,-57.524096,-0.363613,27.180247,26.315444,-8.100784,-106.968235,-152.972463,-203.139576,-188.418796,-80.335277,-24.833417,-56.47636,-104.373287,-78.722873,-53.12526,-80.379277,-78.005354,-9.948107,-4.391036,-7.386263,2.69584,-37.666927,-111.644989,-253.712615,-262.33389,-148.671215,7.1021,29.042049,-15.140323,-25.018372,-20.691706,-22.557004,-0.331328,44.311571,59.424612,64.141565,65.072315,94.554623,100.973023,67.515185,71.341405,192.403239,321.732982,347.404383,359.425533,351.404282,277.65833,229.029291,197.97202,222.031018,199.871955,102.696237,87.139257,118.546478,113.880011,73.9648,63.38087,59.750208,143.892856,211.059986,234.738771,194.684325,177.036159,196.636095,193.38717,223.913527,270.930446,361.502349,377.083579,322.946946,272.465098,206.44526,212.481644,267.521212,285.474413,281.774766,275.081507,259.671633,199.962005,189.881427,239.588473,241.735516,241.42185,316.899559,350.328811,353.910392,332.856269,254.645992,224.334094,223.906198,199.952199,147.4234,36.365151,16.194335,4.542133,19.452235,152.690156,257.645638,273.699666,295.165298,294.459851,261.077989,228.836202,134.657276,107.494222,183.537435,350.184549,414.497692,466.052803,440.565964,318.117372,264.4822,206.556003,175.146657,191.31706,306.083266,342.296038,276.216324,233.955366,288.854485,368.210796,470.740613,443.213055,412.948253,365.738935,341.314692,294.108219,290.412205,286.774076,274.938403,286.746718,279.878778,266.911196,315.76788,346.843105,345.569388,350.255754,425.742598,474.584082,432.484441,236.048373,157.576053,120.260973,113.98212,48.049789,0.249226,20.429021,91.275897,109.086048,127.363176,138.521583,97.145094,43.919566,52.407656,199.178983,206.749356,68.417493,-10.136762,-87.994635,-74.692155,8.311376,41.580746,27.431464,-31.009457,-64.12035,-101.914253,-116.396869,-142.159912,-111.292306,78.731743,243.947525,229.708732,77.992218,28.210136,13.926877,1.35608,-47.395184,-23.382032,24.793133,106.78075,123.188191,120.038867,83.765056,-4.076436,2.743786,100.916104,131.370379,93.174353,-2.688539,-41.334579,-148.079819,-189.640985,-140.038698,-21.805668,12.667442,-1.339427,-48.89565,-175.069476,-208.246542,-122.061548,-42.118699,99.920882,236.755436,242.925985,113.174898,65.787422,52.006956,33.900252,11.410226,88.33652,125.876236,105.172327,45.516548,-84.065697,-115.090995,-92.492102,-46.919901,73.531297,121.640311,88.125455,-34.082087,-81.041337,-141.986857,-153.949814,-114.075255,-135.778858,-189.934622,-201.420535,-126.12423,23.597255,35.98061,0.882111,4.897739,18.711768,-54.345486,-96.680515,-150.420258,-159.477439,-116.639597,-71.894568,-21.442924,-97.783644,-139.18594,-140.818571,-145.27957,-231.56506,-278.394183,-268.280309,-201.910096,-64.344698,-47.353775,-69.529677,-169.963555,-246.450415,-340.413478,-322.02961,-219.936231,-184.597145,-177.403868,-140.803219,-145.793159,-227.265408,-283.060704,-338.223856,-286.565764,-76.309905,-22.911513,-103.003505,-268.392656,-293.963462,-370.108765,-442.590859,-456.346454,-294.77528,-242.858678,-246.313399,-286.990635,-361.209911,-360.312769,-283.237175,-220.640603,-83.473322,84.316655,162.833929,201.197057,162.32549,29.655239,-48.256281,-141.966632,-110.202714,-77.032504,-39.742491,-26.667897,26.916075,33.322689,-26.703971,-42.021116,19.421786,119.926896,156.180232,134.248701,74.365622,-53.916461,-103.106702,-176.478097,-195.516198,-184.834972,-170.039016,-173.538355,-183.019083,-206.264407,-327.563247,-363.386012,-244.656451,-73.842151,-63.439463,-160.034011,-221.416846,-302.713218,-307.267371,-283.649058,-260.364125,-227.318512,-148.092619,-136.874076,-201.184879,-246.06693,-270.245511,-240.06455,-136.404108,-55.176359,-46.435108,-116.516824,-175.01342,-235.889887,-226.300518,-157.247201,-79.114592,-40.090691,44.988385,68.320646,75.383677,61.275723,-21.757062,-55.110731,-19.624229,43.631622,35.819943,12.160694,35.225538,48.928833,4.85237,-81.634218,-91.874637,-75.400419,-43.521672,-58.275061,-171.528241,-239.51923,-279.935652,-253.166362,-200.924161,-133.145154,-88.664744,-90.742805,-145.139353,-217.629209,-217.590836,-223.732431,-186.176062,-139.297078,-120.865878,-164.14832,-212.733223,-175.211079,-67.09114,-45.032392:-20.767279,-11.654442,-92.35681,-285.697525,-312.682429,-277.524751,-255.896107,-157.436656,-46.115574,-26.843304,-21.143091,-19.210731,-61.996865,-114.586494,-174.176019,-134.578996,17.232508,55.140046,27.342715,10.04376,21.057004,-4.222507,-29.919288,-52.935142,-87.356424,-112.166038,-158.560067,-170.62134,-180.954222,-220.478809,-297.174457,-252.880258,-87.690657,-111.926578,-166.985009,-176.225572,-151.887834,-151.899909,-141.968021,-42.744939,35.595937,44.529899,16.158717,-15.19209,-101.469345,-150.545382,-230.396499,-244.381412,-173.042646,-52.167404,-40.296397,-52.019397,-41.592437,-73.79667,-105.662531,-35.104241,68.848626,58.299937,6.181192,10.56546,46.751498,39.684125,19.688284,49.543847,169.054001,228.112898,219.646554,181.893783,157.201274,80.352693,51.350849,52.877339,65.199499,52.53241,-11.853848,-45.652437,-93.107686,-112.099141,-133.097389,-130.650967,-69.244159,58.606541,78.983597,14.907149,4.961242,100.764994,156.187847,189.160852,175.288416,165.502028,155.967088,167.442557,189.343018,198.694788,258.407189,290.977764,274.258583,174.385713,148.205116,176.695045,204.045615,236.055448,242.430586,223.527388,185.597981,206.98475,311.263034,334.680297,303.597456,283.95227,262.130632,244.410697,188.081643,150.445259,109.011462,-20.363413,-47.455377,4.969574,49.145136,151.514888,223.276937,233.877162,243.853255,254.837591,247.513719,193.761427,57.66614,58.420467,199.408719,298.876437,305.390032,259.630901,223.161958,165.023296,146.868551,143.117133,170.316171,178.554206,192.692348,197.250858,132.363476,74.096218,109.99311,217.609766,351.111991,301.393942,289.467401,295.889179,269.851984,185.945716,178.312911,205.560252,204.330424,203.675171,152.686253,112.216947,144.844104,212.632903,328.564256,375.423703,469.146636,478.641381,431.489871,287.688245,217.669705,119.900096,116.775,191.911471,215.118231,189.119734,126.110576,122.939008,170.178178,167.895965,82.835907,54.685229,116.922499,207.697305,212.525019,177.358089,128.898512,1.660864,5.537077,140.534581,154.511376,102.616306,14.799188,7.940251,16.587838,3.700225,9.520915,62.50019,229.138185,324.600503,299.742048,159.372221,98.364868,17.732631,-16.581329,-30.78871,64.145973,129.0825,218.129483,240.188749,254.477556,223.842278,110.897158,82.203474,110.303165,145.674244,142.220155,117.617747,99.431366,16.506824,-25.847298,-31.339471,28.449819,61.438785,80.962101,52.580429,-46.314767,-94.189904,-112.281967,-47.669331,212.835951,403.522083,393.119101,286.251591,258.676317,214.742501,174.874911,132.537962,168.13862,194.671257,198.78999,145.477909,-4.39569,-46.790276,-7.734612,56.301433,154.359085,143.178457,91.521206,-50.440634,-86.787509,-83.661961,-86.515974,-136.956462,-160.265034,-128.636992,-1.341951,60.828776,104.179387,78.888175,42.750443,71.510232,125.896481,107.557028,96.354988,71.119234,61.47743,33.983748,9.938808,-21.057726,1.490878,22.927733,-19.269274,-104.028306,-246.610632,-243.881374,-140.061719,-98.779625,-80.245467,-78.136636,-91.401913,-133.017899,-147.735512,-199.313927,-226.616554,-193.618736,-72.435021,-32.194112,-73.610565,-138.586236,-251.922075,-293.055688,-331.800794,-292.174583,-97.579973,47.86921,39.432885,-86.781576,-159.394794,-308.886256,-376.881223,-379.635117,-199.633645,-142.70994,-186.694249,-235.665761,-278.195861,-276.008934,-236.823041,-180.436005,18.435129,214.512524,245.718553,152.75522,84.340572,10.660274,0.289263,-9.211872,7.273806,31.926774,70.365785,78.2721,68.987082,36.032166,-38.589182,-42.564672,-10.733852,64.025778,137.984284,216.243924,163.361901,-9.613717,-47.932753,-21.186182,-37.909551,-68.633619,-128.315817,-160.33613,-215.155008,-237.640512,-279.905824,-277.754845,-170.804786,-12.012021,7.475605,-120.59674,-204.35669,-286.503019,-296.729278,-297.309515,-249.49788,-201.173411,-141.509338,-153.703789,-183.020169,-174.069025,-158.311187,-163.778506,-154.219633,-133.083059,-148.307875,-195.154888,-200.566295,-185.110928,-170.979017,-109.759746,-23.501918,-1.589497,11.786841,22.496708,20.764927,-6.921183,-48.042276,-23.177346,76.645929,79.200731,32.064548,-29.678333,-16.394453,-4.324327,-28.112078,-58.183398,-80.466865,-93.065553,-59.965827,-21.1346,-25.629615,-96.165871,-222.365798,-212.346761,-111.471837,-91.478547,-135.0622,-224.917483,-222.996071,-174.988153,-171.635672,-186.017633,-150.831936,-117.591249,-124.941952,-182.15783,-283.710393,-289.208234,-219.882154,-158.326704:45.87068,106.583111,83.392982,-63.071799,-106.914795,-123.267955,-126.503477,-131.984219,-146.968659,-127.585771,-33.187806,-12.225816,-95.332368,-164.720002,-196.031828,-139.484654,-11.782357,31.7352,24.477502,-33.74706,-55.544629,-48.927623,-45.807257,-66.692165,-71.417229,-57.654091,-52.380913,-67.338147,-45.506532,-6.921822,60.627241,98.901363,153.094418,50.289275,-29.733945,-113.262009,-136.341286,-220.51348,-252.905202,-256.950535,-274.502475,-275.559217,-181.849818,-129.300853,-169.629204,-251.191572,-356.879235,-342.310808,-274.705271,-214.674836,-180.375666,-174.882813,-204.402384,-245.850463,-254.360189,-244.391323,-182.66898,-141.195878,-27.119347,38.216263,130.319309,143.383185,173.521466,229.228,362.135349,373.60155,345.381771,291.144257,254.002991,127.051703,61.454128,2.925964,43.494536,81.822358,107.10477,80.157746,-17.099981,-68.958583,-111.622898,-87.590981,-9.207104,81.516893,125.466922,105.810546,62.498765,61.61806,107.682895,182.336427,172.648439,181.214529,264.644893,290.992226,274.450901,266.167659,325.516055,386.84772,403.060291,288.971507,284.906638,353.084141,350.476133,236.869237,178.14543,144.252415,162.340285,192.450674,316.571629,374.823121,374.672551,305.551226,133.624726,91.640747,109.620538,133.236502,106.796966,16.259347,-19.44141,-83.836547,-105.482719,-34.158149,168.589401,265.909415,359.681082,355.169029,299.557191,235.942734,79.327983,54.268886,120.468262,209.349802,235.970225,247.193452,242.287445,194.685197,148.784466,94.029558,116.482634,140.759923,206.28957,213.048649,142.482989,118.034821,203.835269,280.393326,323.400282,299.85726,317.44283,321.603125,296.917278,273.636053,280.148418,277.109748,286.970213,309.818436,297.226331,255.66933,237.544962,282.41033,399.668875,452.835619,547.961438,573.671456,550.401372,488.560538,456.307693,307.868213,200.617617,99.111223,156.230688,184.483332,195.34974,184.020032,190.011284,202.223336,172.240848,144.874793,153.796753,201.178561,185.550134,93.959763,50.476963,-30.617298,-55.753904,-26.670215,50.016745,76.526924,42.769618,-14.103959,-100.006003,-120.834933,-135.943602,-100.35949,90.516656,265.704252,269.834555,147.832837,91.281893,7.372381,-50.725179,-125.322519,-36.225692,48.84646,169.571045,186.273605,198.031051,182.964129,83.713045,46.924918,95.54315,220.720593,227.555717,97.661726,25.054916,-70.399859,-106.321507,-104.503881,-31.71469,4.207991,60.70239,64.44142,39.304396,29.59663,32.030305,60.629353,192.129231,310.094644,310.051836,236.244442,205.441667,135.826416,97.387586,94.373269,180.953893,229.192182,220.19383,148.80625,37.643417,39.931679,65.892486,68.650367,95.004111,149.002886,161.014905,102.169337,50.073918,-14.92208,-19.89158,-40.705917,-96.738138,-106.103955,-59.467865,-11.192239,104.481637,151.819043,179.332547,171.433833,139.507898,89.395994,85.38888,116.533243,119.975074,71.42837,37.943022,27.638919,76.175878,95.233325,95.526298,64.111182,-19.285192,-55.907072,-148.422139,-190.919717,-179.796228,-93.577786,-83.003074,-178.418172,-257.712616,-380.519981,-399.203888,-323.588846,-214.782352,-178.679953,-124.845816,-113.751924,-147.222491,-203.980563,-323.652136,-316.694881,-148.694344,41.273586,67.575927,-72.640182,-189.857649,-351.201332,-359.361609,-239.939386,-134.77597,-119.13441,-116.243576,-149.378202,-244.203322,-249.514647,-196.278081,-170.084011,-88.955601,22.186883,69.143965,131.910105,142.462668,51.839812,-63.074513,-250.264531,-190.730062,-120.261288,-13.273477,16.659237,-2.544603,-62.999855,-207.371126,-217.162915,-56.68564,154.799241,208.921129,163.924517,89.365904,-89.190721,-167.345142,-188.206391,-93.497256,-72.962469,-65.096074,-53.754406,-55.233545,-100.903464,-246.995149,-270.668913,-151.183021,-44.487212,-68.124411,-204.037852,-263.069382,-348.735305,-375.310371,-314.94041,-189.187057,-158.766504,-128.405718,-113.317311,-138.904173,-189.761921,-287.186033,-283.48391,-167.287598,-91.271489,-107.996561,-190.726617,-210.992516,-210.519354,-227.829228,-254.196407,-160.827862,-91.099515,17.259945,30.384711,-50.562953,-102.833244,-107.915549,-73.682625,-20.74351,-2.313801,-18.384665,-69.711188,-64.760989,-49.936607,-73.882507,-114.56395,-82.846297,-53.587806,-6.020499,8.384919,4.875671,-32.621945,-138.14579,-149.423987,-80.013036,-2.785912,10.757246,-51.581983,-100.467891,-92.163796,-38.762972,2.829681,-73.572762,-105.622194,-152.886733,-175.22081,-170.673863,-158.402583,-162.293785,-151.225876:118.639918,100.974808,62.352303,-82.354171,-158.121213,-258.187649,-260.784951,-145.639877,-64.561573,-72.669645,-90.431452,-105.152474,-198.908661,-250.894138,-255.641069,-199.417884,-33.787498,41.650653,10.692703,-92.572654,-126.78147,-181.810225,-209.035545,-205.196026,-173.008889,-180.992645,-201.139855,-189.926391,-151.836628,-142.189621,-93.469381,-20.253161,151.510358,147.236116,75.021796,-71.96359,-127.897371,-247.92412,-284.716048,-197.391765,-34.711016,-23.093675,-105.615295,-127.582814,-140.815186,-190.702789,-349.97153,-384.341071,-309.094857,-219.998461,-215.734761,-237.904941,-247.82061,-297.803075,-316.534334,-212.594416,-10.79109,42.040136,94.686033,140.092784,179.862832,145.32284,117.589978,181.139191,395.926563,465.87397,395.686239,175.02669,94.137536,-6.071671,-47.592332,-97.926067,-27.614111,32.478043,15.25861,-59.520925,-181.78347,-225.725838,-291.612604,-273.634929,-146.486836,-36.688167,-15.599079,-30.00651,-38.547017,11.831043,60.346589,107.166754,105.273952,129.123364,217.792534,252.929372,267.389481,255.660909,262.229522,287.389686,327.240353,281.476941,233.388318,182.348329,171.58424,96.365849,60.771758,84.431074,181.330004,227.114964,252.369563,240.03386,213.914053,177.1579,51.056148,12.328346,22.83604,39.021828,19.925208,-76.255635,-131.669778,-192.13478,-168.225356,26.063603,250.441595,318.070425,319.05025,274.535567,212.737546,176.75073,57.670384,23.969978,53.562492,130.786415,148.18146,115.973739,85.49714,30.825395,16.108941,14.115706,27.120428,44.946893,106.524953,112.036761,10.795423,-29.343235,81.369608,179.710889,260.096144,267.577866,273.931928,219.999947,172.111045,151.60239,186.072433,236.928751,269.259899,294.468505,214.041101,110.207259,48.390347,116.736791,262.562294,311.570061,435.511592,547.275196,527.557782,376.201718,317.440378,235.235146,184.463472,155.690115,251.320268,295.558543,291.105118,252.169195,206.129281,201.471099,171.096341,158.21936,202.30774,285.491721,286.1211,200.949168,154.370291,80.859138,63.036724,117.219187,239.103197,264.004137,204.146173,158.843522,73.436682,25.188197,-2.694924,46.749886,224.470795,382.64575,398.745852,285.937019,187.372755,8.810426,-18.387518,44.926124,126.360545,183.18454,315.629458,364.523242,390.892796,347.819885,225.165182,202.09446,242.173149,292.614686,264.383901,102.590693,37.368065,-5.987494,-11.700777,4.163034,57.879696,104.626064,200.851254,204.676986,107.653108,46.302994,2.485211,57.823517,297.529318,447.41557,440.870496,378.684963,340.883967,202.997346,140.345669,170.092784,267.083533,275.417832,254.785718,234.629816,150.708678,105.592671,91.697055,126.565274,183.980036,166.958905,144.36684,103.451923,86.025734,22.535358,-20.740105,-75.274256,-47.337034,7.836902,146.841872,180.892641,144.175953,107.670093,100.206276,122.202597,110.411741,73.804867,95.858323,161.547993,163.398277,94.037258,42.008873,15.39079,133.130033,183.576453,140.987811,46.807791,-122.919957,-136.172872,-61.51337,-32.02982,-33.05205,-36.25429,-35.691791,-82.943205,-142.9735,-305.267645,-349.468162,-264.334659,-98.283558,-49.647452,-46.044333,-80.53995,-169.238186,-212.744523,-261.414436,-241.037724,-115.850185,44.602076,82.0214,-1.915195,-88.118069,-238.85108,-279.643849,-259.4831,-98.87386,-15.202571,-18.854492,-94.326241,-194.433188,-191.485522,-124.449001,-71.139763,62.466443,204.748901,225.843222,95.586414,8.093988,-58.378097,-77.396095,-164.701563,-142.126679,-84.309933,-6.842305,-3.124605,-60.807587,-130.011205,-254.887724,-232.334172,-4.72301,212.750373,237.53923,136.63916,63.948377,-58.882413,-102.794532,-109.85984,-39.569698,-22.667112,-43.334337,-57.96193,-86.800955,-125.914764,-226.747916,-217.906068,-34.722464,74.172689,29.948304,-121.647773,-169.644013,-197.503297,-192.808525,-165.868931,-144.591043,-124.588699,-91.98265,-103.818157,-184.142562,-228.864226,-244.808687,-210.481676,-117.918816,-82.85199,-100.872427,-162.251385,-197.88092,-311.234406,-350.191414,-249.778429,-64.186483,-2.544885,52.655647,24.640303,-123.30502,-189.089719,-175.343926,-102.026997,19.250292,51.013224,39.536715,-33.538052,-60.385142,-89.979692,-106.796379,-130.64485,-162.820977,-156.341423,-86.945241,-55.663821,-38.506525,-55.191263,-83.871679,-62.503158,0.839884,13.09439,4.951686,-74.566018,-128.231116,-148.397538,-123.816394,-112.424621,-116.236005,-92.730468,-104.807459,-174.757887,-257.496929,-219.568337,-136.969041,-125.421187:131.966838,191.719782,252.714332,227.263517,144.924956,-56.659534,-138.808724,-152.028624,-4.329825,83.107426,172.193705,142.332194,28.678742,-9.991221,-31.531641,-10.767486,53.894921,67.040062,74.920766,157.636662,199.885974,147.819098,74.70956,42.00983,139.927947,177.782196,269.162644,318.186794,326.027471,276.308428,166.21494,167.819221,263.895844,265.468281,189.789367,-40.242901,-128.190688,-218.929224,-268.929799,-375.533897,-334.989858,-259.953014,-133.3165,-110.742855,-136.274055,-183.9484,-288.351352,-291.572967,-175.716307,-69.145682,-68.455958,-160.760927,-226.344831,-314.194549,-321.028368,-300.379112,-290.258854,-247.686014,-62.567414,19.654264,92.781709,106.985566,189.143971,264.19785,398.610936,477.915762,486.778205,412.371205,355.56181,265.162778,226.90028,174.949709,195.530032,210.155364,201.775101,182.374053,151.851404,151.642494,153.093451,153.629249,152.235944,158.314784,193.380096,245.35508,234.165614,256.42323,298.862083,298.052557,223.641139,240.754073,348.994315,364.824508,324.58004,344.272621,507.575565,566.764163,462.319242,294.061138,293.903597,320.561453,277.347429,111.401603,44.766852,1.085802,-3.343943,36.847397,218.29683,279.050174,246.505429,196.193218,114.565652,90.891387,46.891705,-7.076597,-21.057849,-62.881499,-94.065274,-122.186946,-108.099415,-9.098979,111.478543,157.875085,216.550879,204.484799,131.863293,102.662661,37.294426,11.027275,22.532221,105.431607,158.493377,199.891758,153.812928,-33.771483,-98.15333,-63.050531,-19.998096,-28.683291,-1.178105,20.468759,7.391145,-0.564532,64.738069,127.901383,232.699609,282.414341,296.259113,303.534263,306.764726,270.748791,204.864931,105.158274,224.681627,314.623602,382.191649,363.048369,362.641683,400.946574,427.913827,387.483577,356.492544,486.326298,526.946573,453.115415,374.816707,235.262459,185.907677,127.232374,97.187436,98.383091,151.740271,179.486139,150.657671,87.595651,-12.337798,6.540588,81.824731,23.386855,-4.081036,-2.02423,-9.422052,-71.015045,-102.406114,-116.566173,-100.210235,-104.662995,-138.393259,-150.832551,-128.173369,-95.481896,-61.779265,-52.154371,50.294405,116.380846,89.977249,-5.667126,-49.946967,-116.947208,-150.869281,-196.003173,-116.52168,-46.348698,50.42192,60.216259,53.030356,42.034166,-13.352235,-42.118338,-69.263072,-62.96019,-65.521954,-96.452478,-109.857364,-162.008624,-198.632466,-152.923206,-34.584977,-37.541977,-101.810383,-99.524677,-17.177297,18.882008,43.492833,62.156823,150.667647,277.752799,321.700632,312.442691,281.21275,186.448437,138.934031,161.954927,250.312534,237.892758,86.628712,3.810792,-36.85211,2.160114,67.168726,49.560836,-58.536532,-55.765108,-2.648279,44.718821,22.740196,-53.273283,-90.803648,-153.838618,-217.441039,-250.591765,-251.97885,-190.612536,9.722041,76.004513,42.873005,6.174155,37.942392,134.351638,173.659543,185.757179,148.373449,19.797143,-31.110465,6.50363,106.852266,101.356102,33.198562,5.51263,-2.555236,10.828172,-15.162565,-59.447099,-106.067738,-61.728685,-64.578636,-186.336862,-253.91205,-288.650038,-272.881724,-220.107569,-142.92659,-126.949995,-167.782964,-174.086622,-113.049006,-107.009551,-179.238715,-193.156143,-88.820945,84.073785,116.32475,32.945161,-32.304475,-122.745925,-139.486611,-93.741239,-35.156095,-45.50703,-119.35439,-160.213925,-199.240473,-204.585883,-232.121854,-233.43023,-148.718608,21.500608,85.847378,83.75844,49.586549,0.889942,-40.611911,-187.864971,-242.336864,-176.624744,1.664055,26.170451,-45.791142,-99.070165,-196.193012,-207.19733,-95.332033,103.974199,183.266653,210.768384,169.65196,57.410157,-1.976398,-51.454463,1.245597,29.599378,104.079294,137.949032,113.995452,64.21714,-51.306527,-99.210112,-111.446692,-10.875486,18.85098,-55.63502,-130.859591,-268.643928,-323.155422,-345.584666,-269.749757,-220.776036,-90.761937,-42.131821,-60.538116,-108.772249,-194.345225,-215.562339,-210.37598,-138.875262,-106.785244,-124.727641,-151.106438,-194.579037,-221.408649,-220.008766,-101.742491,-29.440908,50.276112,33.964257,-90.362662,-165.407741,-242.621844,-219.401343,-86.641889,-45.87194,-99.343518,-171.422033,-122.398605,-27.205411,-64.047325,-172.562609,-145.070294,-105.379294,-67.823532,-85.1599,-122.542072,-118.500628,-79.928647,-47.911993,-13.405579,-74.290007,-86.442799,14.362512,89.424602,157.365623,134.754328,13.80588,-87.344351,-92.845265,-68.336047,-71.893133,-97.921078,-122.454557,-198.544186,-211.029863:187.306925,166.747721,202.815835,199.38443,120.703197,-134.107326,-222.474111,-181.089404,-43.702471,-17.100872,-40.7039,-74.749261,-178.827894,-236.89494,-270.208404,-220.568069,-31.686058,125.713286,127.611452,-15.754424,-101.247719,-205.714818,-221.826735,-143.0069,30.34902,70.379562,40.182905,46.501696,147.752691,177.597809,147.847164,139.919333,192.52084,177.169495,104.446046,-80.315759,-157.022059,-280.86567,-324.468299,-330.102772,-242.030276,-159.813595,22.656522,56.146576,-48.973232,-161.4161,-360.753638,-370.482524,-211.416938,-75.230288,-74.728495,-178.380098,-251.374643,-340.368326,-317.798622,-195.219236,-109.383839,-48.745268,143.237793,234.201495,282.882555,231.37339,195.504864,288.651797,514.255214,518.055774,461.760774,331.044017,256.76797,103.64059,48.227825,28.2839,110.348139,179.853387,294.066331,276.726658,81.001362,-25.975798,-61.864917,10.261557,131.833152,180.333968,223.070463,238.752877,189.525543,136.90842,157.921364,192.223823,236.465111,284.151661,341.035221,321.915318,261.085011,250.446113,287.530337,343.200155,433.904178,400.453684,375.388514,300.669259,234.868608,114.413469,89.821107,66.772021,3.285271,6.477848,131.304558,203.019342,222.646154,149.514779,-36.427978,-75.902704,-45.929854,9.529831,2.736134,-98.137912,-152.240319,-218.074517,-215.845254,-83.522916,92.766429,153.371629,234.760068,257.046409,235.447693,188.529117,72.781413,32.02376,49.476736,158.606821,192.084316,173.570465,135.347102,16.833768,-50.06476,-112.359304,-17.794159,61.25906,140.603351,101.46615,-27.407044,-46.676507,9.072967,47.514576,121.91545,209.344046,240.255643,227.387096,188.582745,114.835473,99.603236,136.633424,222.756551,245.208566,231.211032,223.506592,260.490822,281.406543,275.298856,266.669693,312.424586,427.231409,452.548604,367.570573,287.379155,130.883166,66.189637,25.835635,88.889206,131.13611,220.445906,233.760768,128.378538,34.829986,-89.732756,-70.501502,88.466921,167.052646,116.788415,-47.256873,-88.542764,-101.618982,-90.320828,-0.346536,68.017375,61.493193,26.845239,10.87423,-33.815901,-75.839951,-149.598286,-127.421936,64.854704,245.048032,240.334797,81.797694,0.291632,-89.290179,-101.098653,-74.237628,-11.347812,44.85577,159.315183,179.440383,154.606066,125.342896,48.262006,30.707564,73.630844,96.588736,81.89236,62.100868,53.830132,-46.833163,-117.606061,-126.119187,-15.662827,28.634762,86.553989,91.338134,72.561437,74.953953,96.57837,120.875647,251.719406,388.77623,394.25039,336.036467,316.695859,255.947459,219.121601,240.247008,278.328819,258.81476,178.900761,144.444752,156.412662,196.938348,244.25045,224.718728,146.582556,137.919389,151.317666,103.337962,39.411782,-49.49538,-40.429497,9.005766,4.406427,13.976738,103.299051,158.826721,210.914923,188.20189,113.567676,104.279594,121.680196,118.84416,124.183705,155.889196,157.14631,87.44561,44.519294,46.162334,95.390713,105.02455,97.070838,73.64114,29.9815,12.155645,-69.927254,-115.031821,-119.863509,-55.528162,-55.83714,-183.74098,-267.758093,-343.240334,-322.305465,-197.086265,-80.094691,-36.14573,62.052304,109.377574,106.199777,33.039539,-108.547229,-99.252415,51.836608,175.516403,177.610397,105.948491,71.97209,10.546606,-35.731681,-90.225691,41.902252,110.55972,63.359119,-24.019856,-147.262551,-158.213417,-134.706495,-108.606565,14.99935,170.223584,206.558317,171.313378,113.699466,-60.207536,-162.778042,-255.973248,-136.599081,-63.428996,-4.442776,-18.676302,-79.555927,-121.67764,-191.783133,-165.798243,15.514798,215.759325,277.041284,244.971199,163.439911,-17.418154,-74.122573,-70.234878,4.948801,36.850645,56.023208,45.175877,36.939742,24.08663,-50.039025,-65.916863,-20.198105,-2.371357,-40.126805,-150.894479,-176.340331,-194.435822,-227.129286,-292.849465,-247.443546,-183.712538,-63.984951,-47.508325,-139.091163,-217.895239,-310.108165,-302.431535,-220.761861,-125.854085,-95.845798,-118.385673,-155.919845,-219.198614,-242.250011,-246.541068,-147.589337,-76.059988,-20.889043,-69.219734,-172.247505,-166.014431,-101.591093,-77.787339,-39.893661,-0.551757,6.978844,-40.608921,-72.67737,-98.808362,-114.903413,-151.137056,-120.255484,-78.081723,-0.287795,15.649491,12.276887,-6.637498,-53.51562,-50.738012,6.250207,94.744786,133.842158,119.588484,63.632826,-33.612707,-54.687192,-92.3999,-145.474731,-165.136719,-187.622363,-220.253023,-279.206247,-264.091075,-198.830217,-165.773744:55.114233,86.946388,120.117682,99.20128,45.020897,-89.9716,-144.351978,-198.086154,-145.294532,-60.603692,92.943001,93.247804,7.931612,-20.716314,-8.052342,32.890146,118.790455,125.808505,121.132659,154.366523,180.777569,178.449483,159.040221,203.691011,301.808919,318.813029,301.438597,284.439903,236.99954,196.749461,109.809989,100.061337,150.840817,161.564523,136.374778,27.678801,-54.409859,-197.640596,-226.907391,-201.804197,-83.431579,-11.689473,56.037885,37.033554,-23.614707,-37.266998,-39.499005,-18.711907,87.433614,150.33307,91.85385,-121.025911,-170.399878,-134.254581,-128.118703,-170.356255,-164.131372,-134.256375,-85.018613,-86.006832,-63.906385,-7.354363,138.916695,212.081525,383.598031,474.86477,458.615744,409.362184,414.03225,408.562366,370.983217,290.67363,223.917399,213.370211,304.311876,364.959384,417.03313,411.793525,338.334457,282.006809,188.800655,148.288883,136.742684,106.247049,116.257352,208.714578,231.161051,153.168049,67.40397,80.122762,178.890358,217.120115,254.687619,265.27459,274.219617,284.1976,274.101125,154.494682,82.83226,-1.294328,-1.139238,3.930286,-33.198176,-154.16617,-229.030104,-238.33239,-188.887033,-143.099961,-68.210023,-51.920493,-85.107354,-121.438129,-184.532798,-255.964841,-295.493232,-367.581001,-386.233695,-351.107605,-295.360138,-155.092326,-87.932711,-72.240725,-1.111528,33.742988,18.957615,-26.864677,-106.570876,-104.900539,-38.245492,25.025624,33.322644,3.917179,-18.162111,-75.871488,-112.548883,-178.564503,-193.193457,-159.303404,-77.631158,-72.923703,-118.432478,-132.74699,-98.65095,-62.410136,12.946931,89.405731,126.438606,165.186508,160.25018,101.305612,54.217278,-14.552625,8.05688,53.57645,134.996073,124.186845,62.074087,78.126654,176.414968,193.750084,149.654138,157.93865,197.636592,231.130991,200.399074,102.702491,47.342244,-78.715417,-170.239055,-184.735636,-184.279414,-193.458434,-216.43297,-214.381437,-181.236944,-160.377829,-131.926149,-99.611117,-76.224744,-76.136543,-108.501696,-165.461879,-154.401309,-56.725878,-32.181968,-65.327395,-95.855431,-77.677249,-15.166022,5.822713,-23.738359,-50.414969,-51.146175,-4.992376,8.821714,-22.644118,-48.857603,-110.863301,-158.526981,-184.647864,-85.860489,-37.138208,-15.284199,-46.672925,-101.101051,-107.652984,-131.969708,-132.662035,-54.934552,-16.807558,-47.839605,-126.084829,-148.74489,-182.049934,-197.022086,-208.830635,-203.653014,-190.005996,-128.134647,-104.517123,-78.811017,-56.939395,-11.792293,2.48047,49.049657,176.088665,247.297542,330.548116,342.480695,282.295472,219.321293,128.811874,77.360093,55.38028,34.686964,19.988303,-14.822935,0.205975,66.670505,64.784437,-18.755355,-56.79315,-19.010621,82.737607,87.991266,33.957115,15.018061,-30.045577,-167.698115,-244.618453,-238.855518,-139.282325,87.541158,134.503827,55.346843,7.858337,62.705589,168.580582,192.52048,223.278419,224.724486,149.802638,79.121146,-26.460743,-58.870854,-71.469812,-28.19262,47.662214,224.400106,252.301057,121.117158,38.82488,15.185102,65.053571,48.252394,-35.729225,-50.998367,-38.362338,-38.936022,-10.103498,34.154681,56.409874,159.898216,216.387466,268.575522,275.687762,259.631832,217.889692,141.822607,214.079316,263.87819,280.494251,279.390325,306.900089,300.33563,252.680873,265.18478,279.791694,231.558915,176.805738,89.744363,52.733442,-20.565309,-24.855208,33.991468,99.171827,147.425465,272.864436,309.810769,223.151848,108.821551,-103.453505,-147.243981,-95.590583,76.504041,128.188199,73.700998,1.206393,-91.937775,-68.459912,112.065601,308.665025,348.907377,288.999904,240.391435,151.067946,80.851237,-12.361164,68.523221,97.476374,74.086742,61.227098,95.75992,131.035641,139.667502,107.539513,41.374011,-5.246201,-32.64721,-87.109039,-114.140319,-228.112577,-307.848636,-339.480166,-161.595389,-73.905667,50.839387,103.73581,176.686131,175.669048,96.324129,45.987742,-10.698049,28.452845,57.771133,65.462296,54.743635,15.505505,4.881101,73.932252,102.165192,55.046687,-50.529858,-64.354781,-49.133501,-67.167688,-132.040831,-137.661314,-123.184664,-198.729007,-254.566661,-266.899853,-201.371018,-51.313183,-28.424208,-71.747813,-139.300474,-136.577455,-36.161117,-10.078153,-82.606288,-95.569165,36.266054,94.779516,12.951747,-159.714855,-168.320318,-14.787607,86.40119,181.642595,135.959453,-50.584226,-136.43642,-134.387948,-116.942922,-111.300054,-104.795308,-112.307559,-162.155394,-184.723639:48.702403,218.547874,259.413123,155.460654,69.38429,-46.126917,-78.948721,-97.56165,-25.431661,20.215822,70.164813,77.473757,54.011402,23.668438,42.036439,110.257943,206.632959,182.198336,181.957946,279.387315,326.355321,275.932176,233.752494,251.978565,263.290339,265.30148,359.487593,407.35974,315.937581,184.830097,-34.475117,-53.512086,34.01782,57.173534,21.504314,-73.702592,-125.694424,-247.112723,-293.501198,-279.161868,-135.679596,-45.012011,63.200967,40.828345,-66.231676,-106.621736,-150.831493,-131.450033,1.560947,90.333016,70.335876,-41.400313,-103.618034,-230.310196,-267.832497,-204.688537,-76.611229,-48.45687,-50.023226,-42.930679,65.332271,128.491644,162.098008,172.115207,284.719657,453.01802,502.179048,504.975753,497.764192,489.15648,466.801927,381.947166,281.111494,254.14452,259.65482,269.926555,309.438485,341.731377,368.409,346.094533,233.801392,122.762063,100.293824,136.826828,190.079558,255.897652,242.092928,224.235188,302.094609,358.38933,398.661794,350.526732,271.832067,308.207602,383.796161,356.874017,247.958731,185.170087,166.690653,108.650072,82.995277,32.652252,-7.84726,-52.012989,-36.429047,-21.60295,16.949916,19.318198,-24.009328,-47.219788,-18.559348,33.91632,87.691214,-11.717318,-76.489624,-175.269415,-199.310552,-189.725858,-179.279839,-154.120785,-109.360137,-86.253268,-38.710933,-20.233102,-6.95284,-30.897423,-156.442333,-193.501817,-93.23212,147.86616,252.328595,263.923338,186.707668,40.474075,5.493177,8.518998,46.302818,59.161104,59.323498,49.988459,67.747979,104.876269,187.345754,224.58749,295.664917,334.759215,347.901876,357.42957,341.649148,251.886882,183.19633,71.156957,116.748327,207.7669,398.877749,435.99076,358.880101,296.211402,255.905772,271.545739,318.14551,402.254416,422.722771,316.147884,234.658166,122.692116,79.016304,7.550965,-4.881411,8.696381,31.737753,21.223566,-48.517489,-91.826639,-130.687452,-98.779208,13.909125,28.311283,-2.28561,-52.436416,-46.329483,-20.250701,-31.084262,-74.573459,-94.227412,-81.244351,-25.724357,-16.187704,-49.405435,-66.589558,-61.86416,-35.556449,56.853983,146.99774,167.457481,133.543926,90.857762,-11.623921,-75.533375,-184.988915,-176.128689,-127.837628,-28.202594,-18.00735,-69.073339,-92.172868,-95.352164,-79.053887,-13.40504,55.110007,61.553024,-23.424154,-96.787905,-224.1432,-253.121487,-199.949023,-79.208515,-51.86367,-94.509723,-128.661338,-117.605728,-70.774997,31.764865,58.163895,83.520012,163.613078,198.916601,220.054499,234.509915,232.575474,179.790836,91.18906,99.918431,82.955836,-15.359118,-74.55421,-107.361278,-55.263232,30.910196,-7.794288,-124.9939,-47.097506,27.186034,61.408741,24.085868,-69.684269,-121.676855,-210.765927,-266.758855,-312.594029,-402.505988,-389.501833,-212.358002,-124.35875,-118.544205,-159.378235,-155.000245,-85.902198,-56.976723,1.409111,25.103568,-3.019406,-75.842542,-228.64162,-188.473691,-108.731261,27.321406,59.234542,104.826683,120.730976,74.888786,27.578709,-29.782413,-23.999965,-20.256658,-51.756978,-79.844781,-160.97729,-213.937409,-257.22742,-193.706935,-150.207367,-58.046075,-24.98622,-1.137035,6.846265,-1.439804,-35.222961,-98.263939,-66.876048,-55.495348,-94.761019,-101.108885,-62.132907,-52.735835,-73.905999,-104.271226,-102.8359,-84.322039,-107.105521,-194.142276,-202.880413,-197.852659,-230.541495,-258.549269,-91.113882,1.929176,75.04132,81.644569,75.302057,47.724648,-32.819208,-100.386793,-89.489214,81.593854,171.270811,170.530902,97.641519,-60.351899,-97.538645,-26.416558,161.692375,249.345961,309.926391,269.390442,106.673948,20.146906,-64.563078,-33.684362,-14.485652,40.081794,78.33021,136.320315,150.739125,139.72962,104.149059,-1.230471,-32.630955,-27.736298,-76.475273,-120.462664,-220.343004,-273.497329,-241.282897,-57.534877,-10.3904,3.295339,8.158774,5.243208,-21.932235,-109.262922,-145.49097,-187.502955,-148.905028,-99.576414,-55.880504,-80.034737,-154.039961,-175.347778,-138.37524,-33.353329,0.389973,-28.673366,-59.858001,-44.825983,-34.627094,-142.677992,-210.740552,-229.514293,-219.645279,-230.527613,-185.693469,-119.719499,-47.918454,-75.835277,-121.740331,-135.833099,-148.60492,-111.430712,-89.061222,-118.507592,-126.634254,-52.657987,-9.60457,-36.465155,-135.203379,-128.737595,-7.656618,55.373354,72.108292,15.937616,-97.304853,-122.115281,-129.821631,-127.944628,-110.980692,-53.920432,-27.477839,-44.112448,-68.528346:297.688197,332.434904,346.40602,264.039055,167.919846,-13.671697,-46.631106,-3.933186,56.103299,84.110778,95.134073,51.830296,-44.197258,-59.592318,-43.769775,-20.439318,64.891342,167.838615,187.369841,127.516045,79.754397,45.352489,63.706403,110.342523,119.8413,143.890804,224.302962,226.821549,175.429504,200.008906,326.693212,322.886822,165.155125,90.082727,89.695099,54.817761,13.469719,-120.373991,-214.52125,-353.391747,-274.679787,-179.136506,-50.197849,-52.772277,-100.066379,-114.432014,-144.590598,-135.466433,-48.615373,-44.082374,-98.679612,-199.202808,-220.469178,-303.63138,-368.459874,-392.422196,-245.794135,-152.41405,-5.073347,22.04026,-3.996464,-20.027154,22.408096,95.847163,275.812121,328.975564,298.487971,236.972198,231.232537,213.477408,185.361306,88.813965,7.726323,44.106713,208.186399,241.365647,192.816054,162.50889,142.352187,148.899671,145.105308,112.38529,101.098919,84.601592,82.120364,116.802478,141.838372,136.979193,142.49636,188.553764,255.170698,230.466993,184.577544,217.935793,315.228739,341.023569,333.138138,220.303393,163.274611,163.338281,187.458088,113.499021,31.967256,-78.615203,-153.314292,-177.595134,-103.098095,-25.756682,28.869892,-25.371802,-164.125837,-189.868262,-196.00162,-164.636616,-125.20411,-133.589989,-186.471497,-241.468313,-208.234719,-66.646431,9.416778,20.00592,89.7687,138.07268,194.681081,193.35309,106.821268,43.443201,-11.980484,7.013597,9.203729,-14.879652,-51.223901,-148.689031,-168.062342,-142.751381,-162.0715,-180.321636,-156.783131,-132.573367,-113.940828,-116.366694,-99.770595,-64.07904,4.097541,50.035534,87.490936,110.452778,76.419585,-15.880237,-24.207178,78.771643,133.914643,110.841929,48.253803,21.213203,28.2127,73.549224,156.173067,173.457985,193.511432,220.88003,241.31793,254.249832,230.39225,97.703877,1.481858,-107.041381,-62.745807,-19.317774,42.535965,22.557066,-80.927283,-103.429544,-46.08717,6.284929,52.182517,-24.242127,-73.0443,-105.693428,-84.035221,-36.910134,-45.012356,-70.339646,1.131301,49.120638,68.564966,27.742308,-76.543246,-110.459869,-118.188005,-78.316363,36.633358,84.571925,94.870423,64.884806,17.59672,-72.274421,-104.027495,-121.000911,-41.163607,18.624137,67.279659,39.853364,-6.285819,-14.762642,-56.718213,-78.070193,-139.519068,-210.073873,-198.62294,-109.64986,-84.298669,-141.612544,-190.890339,-197.49729,-104.870756,-52.75841,-16.066106,-60.389467,-137.624549,-107.980599,-4.443454,26.459199,121.966897,316.332262,382.589416,336.095336,273.617254,199.479018,179.643416,183.982692,189.648278,152.0221,84.525902,99.533267,193.347608,232.843042,236.861886,196.056254,70.652513,54.253978,81.521775,94.807564,101.545966,100.164359,51.281957,-48.419495,-49.968463,-64.701809,-113.196256,-88.634507,91.83691,176.286748,158.115065,90.927218,39.701779,93.273188,116.803928,130.696629,135.90497,157.381363,140.230729,87.014372,114.08178,116.974545,51.225295,18.911065,44.470166,72.580939,4.860725,-78.723648,-147.88543,-33.997889,3.725014,-56.090327,-104.733237,-169.031833,-198.503366,-209.57194,-108.019682,-28.410585,93.120989,105.695378,100.406139,107.725592,82.442412,38.108384,6.419798,138.883694,195.338696,169.888654,142.503959,134.409042,100.418586,1.484544,35.213952,66.07138,39.007802,-9.405675,-69.472124,-62.625614,-63.863495,-76.388647,-41.302924,-4.012684,-3.347751,38.501049,77.552349,51.4819,-49.931575,-271.445591,-250.66904,-166.122255,-26.885246,-14.552307,-64.05832,-100.873657,-173.946946,-162.804115,-59.648281,46.526572,145.098511,320.516749,314.147217,139.880658,39.336989,-49.09884,-10.983357,27.832604,124.888253,161.442935,182.551502,172.748944,107.726945,70.824383,39.891717,-6.772376,-54.822401,-160.254147,-184.284136,-172.986183,-177.762203,-216.563012,-185.409151,-116.09875,54.98575,86.689104,45.278254,8.690373,-96.964136,-158.13433,-243.335323,-205.258936,-142.2305,-67.977057,-78.782483,-112.998352,-126.194268,-161.718885,-102.249998,-20.621627,76.694603,51.206358,-50.542445,-87.557184,-125.457936,-125.17076,-115.552342,-171.271195,-187.084149,-109.812178,-59.63103,-72.405494,-113.378143,-139.532546,-159.289411,-161.596371,-88.460618,-65.488652,-86.526742,-70.929731,26.22841,56.26637,16.962071,-44.037729,-38.40589,21.964836,56.302227,69.084787,21.587797,-121.594619,-176.983563,-167.311439,-123.282155,-96.188123,-87.504351,-130.65153,-210.996559,-183.292519:backward
-170.74375,48.67759,147.491534,163.867201,92.202057,-60.596771,-97.926957,-85.586879,-35.528578,-31.163013,-32.237518,-10.642264,19.313844,0.667155,-60.002215,-67.383296,13.386305,121.785226,130.239943,98.300636,117.193761,265.074532,344.416567,376.297812,248.714069,158.995933,-2.30089,-29.201475,-10.514164,-39.614696,-146.463675,-153.317458,-100.577727,-136.418347,-184.120938,-195.167667,-127.733986,38.439192,79.603314,52.539211,-47.841177,-86.460385,-71.77515,-20.833623,89.511906,137.523467,182.979505,152.317495,57.552659,38.498167,44.202796,70.490144,75.839787,70.357417,92.983941,185.865139,290.215205,321.812831,292.487501,272.126049,303.656111,311.972383,208.212108,134.106906,101.081527,156.987476,173.125798,209.85591,218.371623,197.068227,183.659218,99.361,-24.177369,-46.384386,-36.583073,-16.712485,30.315403,38.492789,7.150542,-19.835336,-65.569276,-186.202277,-258.893942,-258.865315,-207.256825,-141.260543,-122.713339,-80.37375,-77.449542,-119.072411,-198.413722,-175.819997,-78.113461,-53.354277,-3.10522,33.8264,70.351429,27.707677,3.891609,32.855894,83.856478,163.870268,144.890816,1.651524,-70.514808,-68.937174,-65.511209,-54.726992,-31.754111,-41.353824,-63.311779,-53.806487,-15.178683,-57.536712,-99.418417,-63.30021,-0.715437,37.953318,12.94436,-61.614764,-141.442517,-159.629298,-119.883607,-62.982013,109.306089,188.272692,232.524447,201.805532,125.70215,80.723253,56.017265,44.476754,53.501655,18.063714,-16.003734,-42.401982,17.935199,40.45033,-18.665247,-56.312778,-56.339705,-39.685366,-3.455339,14.57566,33.231529,24.710063,11.422218,-7.062404,-2.208409,18.52081,13.384522,-58.685796,-141.316406,-163.469767,-153.99724,-107.437257,27.61037,62.434825,27.274353,-4.845285,-4.12975,15.442438,-7.19709,-41.927894,-22.231799,40.596854,37.818822,-51.12744,-85.89695,-71.875123,-55.034283,-27.661128,88.79376,142.750589,229.702928,259.298192,261.61923,228.422139,216.017033,203.99623,197.626767,173.059803,167.854961,156.453475,64.827866,-2.212918,-63.097121,-28.387981,86.334529,141.769266,327.415525,447.715479,585.46781,512.209828,442.996694,389.579195,408.967293,430.948755,403.050508,276.724343,151.780475,81.958574,-98.60707,-150.425863,-102.541122,-37.986923,89.469014,134.827343,198.028006,196.941955,144.937183,14.199258,-15.111899,14.635806,36.640175,-0.258339,-106.361452,-144.19173,-173.367519,-170.64851,-144.466388,-109.134296,-28.873696,-33.87206,-107.754561,-146.590907,-148.874605,-93.552615,-41.203409,50.639945,81.5908,80.593562,-27.205715,-105.012804,-235.390886,-247.430378,-174.386069,-140.256342,-125.425384,-125.940037,-104.419462,-127.614758,-189.173864,-294.682323,-289.949767,-175.885981,-81.051104,54.078361,-23.0406,-98.180791,-170.401142,-146.06772,-71.854679,-68.673118,-82.591014,-51.45433,19.700987,-75.213039,-127.61006,-99.378771,-75.881258,-134.918818,-180.420026,-220.949675,-247.565056,-274.984959,-320.582508,-312.422235,-230.779092,-178.950529,-139.017955,-158.323116,-147.456877,-76.665843,-71.259261,-53.838927,-24.976274,-0.378403,-14.914358,-58.248416,-79.897648,-89.066318,-118.802469,-129.212436,-138.914764,-136.421874,-115.287299,-129.120017,-237.331244,-308.004473,-287.175535,-155.266744,-99.183895,-99.869134,-119.488587,-110.648796,-94.258458,-98.574892,-88.827987,-75.36278,-82.835107,-90.115242,-42.796546,-15.03925,-53.64897,-190.329132,-259.615179,-306.586373,-257.112917,-41.197446,51.39108,42.60164,-59.948812,-85.386964,-141.644853,-148.398492,-51.313048,-6.242357,-36.867572,-83.062862,-155.293221,-171.636567,-148.485617,-51.001192,5.478072,94.981046,106.566101,26.025581,-149.093247,-245.043715,-321.315616,-266.838332,-121.948962,-107.362066,-125.417393,-107.555746,-120.266261,-232.271059,-238.717744,-81.001231,18.359939,79.496476,45.267478,-60.310434,-128.244479,-131.498181,-85.64844,-56.775399,-56.348971,-76.778143,-110.555385,-130.536168,-217.328149,-314.157425,-311.276189,-204.766938,-155.688557,-139.071291,-133.235525,-51.231017,-47.597115,-130.256206,-259.356005,-220.702931,-40.40859,16.846884,27.992031,15.340649,23.908353,106.910088,166.603658,273.103128,297.991718,286.817993,275.28904,252.638786,158.115847,97.036903,38.693322,48.951296,79.557061,86.196195,108.558707,128.07675,147.368472,64.324553,12.833575,8.824855,27.937237,3.024157,-19.882378,-34.232814,-102.726789,-179.129923,-248.739853,-185.075246,-51.996238,-61.315547,-148.633264,-183.300145:-168.813223,-83.962942,-49.938007,-39.153349,-29.886918,-10.927518,-32.055084,-88.078954,-74.456478,-43.987315,20.410014,28.909928,21.628884,39.261131,87.961229,77.224555,-27.385018,-80.197795,-33.72929,125.956284,193.91739,302.053143,334.375137,284.495147,117.908786,47.375358,-13.913385,-8.026776,63.203943,96.056201,73.44849,21.775311,-80.295082,-125.071802,-113.347354,-3.485666,56.269609,102.991552,91.776037,10.842799,-92.185454,-117.369977,-97.646363,-66.185983,45.847126,123.087476,153.750107,65.841546,-108.986789,-52.929748,11.180586,76.004317,69.03865,34.369623,38.863404,105.093778,184.025544,201.361223,192.080708,186.522336,203.874184,217.681311,199.546817,160.680597,76.270097,23.210365,16.3623,72.414471,117.800707,168.818177,159.972392,91.547072,11.272219,-32.676741,-76.870335,-56.561013,4.657115,15.932942,4.283773,-10.105095,-58.082916,-168.387967,-245.6104,-349.545803,-339.832756,-184.39643,-78.855615,44.771014,-17.660456,-91.321664,-150.517347,-108.790157,-23.749977,-5.902616,38.230412,49.329589,29.354824,-49.911667,-97.679396,-60.559076,0.415148,23.083023,-12.13401,-76.384401,-83.936908,-75.682351,-8.291074,58.920768,129.201652,96.910031,7.28829,-1.887812,48.859343,66.426816,44.359317,31.296905,41.137623,47.613633,39.150605,-38.003441,-96.083323,-95.616069,-85.492726,-51.372064,106.957032,190.250287,248.076571,211.727935,107.55728,53.121379,34.135072,33.070552,43.022906,41.134485,35.924598,28.185755,12.212433,-2.288541,-8.775706,7.951245,37.906049,42.075567,66.027038,82.829689,98.25728,58.698345,16.287721,25.482316,88.433787,159.278353,128.676909,-17.184738,-155.049585,-184.435537,-170.290393,-142.160505,-61.880168,-19.876008,45.491372,68.063762,93.300033,74.582096,54.097082,24.821346,25.140996,51.06283,51.917195,-38.574128,-137.600879,-131.68458,-53.399812,1.33619,133.148016,190.412506,240.570128,246.141494,256.333673,208.722234,160.28219,101.184444,104.903061,128.907838,135.258091,88.436053,-23.258376,-60.854645,-56.274574,-16.631124,91.51732,159.337039,348.954916,435.426923,495.133196,416.172412,366.965623,359.877085,386.198569,371.927222,304.456568,135.542963,71.578076,41.193814,-99.985708,-167.144276,-209.863785,-186.420206,-83.932625,-50.038768,-52.190103,-10.513543,29.911541,64.744288,74.141551,108.489004,95.643249,-12.160052,-108.291594,-145.61019,-197.961535,-188.952852,-123.060412,-79.801718,-6.184152,-15.349958,-105.706008,-188.130771,-209.210059,-150.898522,-81.388982,59.646788,116.452627,134.201727,-11.950967,-89.930535,-145.41731,-131.67124,-86.598843,-59.867696,-20.974982,-48.91368,-216.736448,-331.514909,-313.168694,-257.487391,-290.967944,-364.272292,-326.180947,-156.646091,-73.868294,-106.316446,-168.016348,-114.704166,73.128045,119.963614,93.12,72.852705,104.2194,82.331979,23.695622,-38.571029,-39.826219,-104.827808,-157.965053,-190.718459,-197.65232,-236.179832,-285.594319,-260.022026,-183.30276,-161.623598,-125.744313,-99.368772,-78.026823,-174.79056,-211.621859,-140.053647,-65.470016,46.044021,64.464778,45.393048,35.918693,12.529306,-81.877186,-106.735368,-78.806684,-49.19621,-58.413345,-107.73898,-170.128955,-184.998098,-208.309087,-215.391248,-181.457014,-105.683311,-87.68494,-91.535531,-145.271196,-185.783826,-194.310163,-148.283026,-81.366152,-77.55457,-15.703875,31.029899,-29.068898,-203.446546,-237.097261,-204.598279,-167.687395,-51.682944,2.427467,-3.119294,-73.055925,-86.701748,-35.674184,27.994526,138.317399,155.456162,112.829323,52.070276,-114.338168,-221.047839,-213.334029,-111.229693,-81.721663,-123.360583,-152.217111,-147.466354,-132.342437,-164.706461,-258.252247,-281.35723,-245.855523,-183.562094,-46.015399,-30.078846,-137.329003,-250.355722,-245.013951,-124.077564,-54.495205,4.689885,-1.729478,-27.177483,-78.241235,-130.927632,-200.7442,-179.79062,-112.833028,-105.191179,-114.122549,-129.751041,-212.748161,-313.788341,-345.320416,-326.959094,-279.990141,-170.483184,-120.30658,-90.758501,-175.832519,-209.052912,-223.685665,-215.278129,-117.587291,-29.379899,99.361803,99.233183,65.134736,141.786951,189.449586,257.582555,286.750433,316.109152,293.317093,164.172937,27.051239,-26.869082,-62.209892,-23.165538,55.193686,47.228677,32.137342,51.136037,25.457754,-95.832473,-115.566464,-21.016196,27.720187,11.536372,-27.963067,-86.495308,-147.681459,-224.080707,-355.247093,-320.492459,-122.667334,-62.461838,-59.948368,-66.402327:-198.499857,-193.718571,-155.546382,-122.926361,-138.872636,-175.721705,-175.763817,-153.406941,-142.46947,-141.686896,-144.206095,-136.492959,-71.183284,-13.744835,66.07186,42.436672,-72.898691,-66.804627,-14.977758,46.564654,63.730534,224.679037,334.455134,351.24357,116.991178,14.340275,-32.031804,-2.086386,87.973103,144.421829,207.837653,190.401232,83.753017,-23.639189,-19.177379,124.952692,207.626053,288.340391,281.314606,170.396793,13.892546,-44.263881,-79.152113,-41.294349,103.422754,172.328701,210.274714,154.74937,-36.968109,-123.620167,-82.39277,90.914007,148.209915,142.844979,126.241904,120.862,108.666614,91.279396,57.224634,50.586619,56.77744,74.522144,123.125414,118.282536,32.152212,-44.527568,-53.696607,-9.297989,35.990931,116.781571,140.718479,160.894168,75.419549,0.511251,-11.393908,69.161001,180.790998,164.700227,67.870648,10.450068,-103.258408,-200.778794,-248.799243,-305.293883,-284.108709,-144.738558,-63.254772,58.04386,37.839361,-31.051118,-136.781543,-137.393857,-62.102541,4.600943,119.966938,133.256199,83.225906,-39.846368,-86.132374,-47.931896,-3.985399,1.870336,-30.48447,-105.731004,-171.834512,-197.01063,-156.54868,-87.107666,20.234769,40.540601,45.662509,34.754771,33.141233,17.083451,-17.419208,-26.658293,11.089049,51.941317,26.726762,-70.354514,-102.733255,-92.473762,-37.200723,32.061928,189.422577,221.182807,186.26319,157.907848,113.80792,10.231271,-45.296492,-45.516732,-0.635784,47.314763,24.102999,-14.824853,26.528856,25.566428,-28.730863,-35.113143,12.759052,43.877948,88.367395,81.571276,1.689204,-44.026771,-26.11001,30.841644,34.409735,20.802913,36.969234,49.885405,-77.193167,-157.548146,-213.449177,-163.554577,-12.744754,29.676661,34.901797,19.81085,22.679401,55.793207,51.718661,34.832001,38.646169,40.197108,31.635247,-2.050341,-48.888207,-71.73621,-77.28584,-38.159344,104.244967,171.004404,237.299814,246.76281,209.730527,69.537503,0.903134,-55.052466,-35.817465,38.339227,32.012179,-95.294647,-151.138359,-119.908209,-57.900065,-53.632056,-9.697738,72.855096,287.138014,349.252025,331.437564,232.028647,204.087761,239.780781,288.096458,343.381037,318.434199,174.704206,6.250851,-57.158645,-130.402858,-146.890819,-138.304964,-111.656611,-64.57794,-65.771735,-72.304647,-21.992944,10.651721,102.065774,165.369338,266.691556,258.554942,99.57564,-27.848145,-48.753445,-128.749794,-179.245345,-159.813278,-91.800857,19.760923,30.623631,-39.665233,-161.842283,-187.308626,-112.919366,-41.660792,103.613115,161.45704,127.259652,-94.584125,-166.765782,-136.859215,-111.326765,-164.682999,-183.160954,-108.114472,-73.364983,-131.445839,-228.092052,-241.879011,-251.304773,-258.490578,-228.105485,-201.416061,-213.405475,-274.940766,-273.196325,-163.297435,-74.996048,75.760355,106.576619,83.392954,75.013045,116.248449,90.944726,51.434176,42.178238,76.124528,110.286004,76.80102,-23.66101,-106.076563,-152.26903,-188.008075,-161.113756,-71.943192,-26.504045,15.423938,-8.636681,-82.86419,-129.414433,-133.184902,-58.230104,-7.607712,48.601851,69.048529,93.544981,26.631447,-30.380054,-90.35955,-78.485041,-13.930946,16.075448,-27.008646,-108.35583,-241.330887,-227.592283,-185.647072,-114.173988,-100.355031,-105.750813,-120.690662,-129.008401,-92.129353,-88.148964,-96.350282,-87.604176,-81.670013,-84.688788,-58.269383,-57.999144,-150.809075,-248.809128,-251.500472,-163.829939,-100.641248,-3.661364,2.625145,-77.386462,-136.402741,-134.300387,-77.622514,-21.129867,65.183382,66.614268,16.080092,-16.295797,-67.922015,-132.758629,-160.018474,-145.347193,-110.503621,-60.234984,-74.82098,-137.469457,-130.951978,-144.265556,-243.782564,-273.144149,-222.712321,-167.996487,-88.669491,-89.259592,-156.804817,-213.140343,-210.203973,-188.884293,-173.603013,-81.24747,-29.179335,-7.859162,-77.265831,-130.065765,-202.173867,-196.214307,-111.551778,-65.4301,-93.078805,-164.280671,-262.513417,-239.991184,-221.853515,-227.783382,-229.167764,-132.356062,-56.465099,-2.450486,-111.867432,-180.660475,-225.01312,-201.138195,-129.363271,-77.641333,-0.697398,-14.385235,-56.472433,13.253416,65.965121,188.604405,258.162598,311.790798,270.053238,145.949799,45.573746,-17.963825,-82.799124,-39.746767,106.530017,149.889532,138.781305,100.118644,-13.451367,-137.854727,-148.860185,-36.266369,26.361597,77.581011,80.205705,33.137394,-133.973822,-245.833503,-363.773392,-312.449106,-78.947698,6.770461,-2.595975,-62.692019:-200.952931,-218.563804,-181.878221,-94.278266,-73.52179,-102.014227,-129.381736,-163.963303,-154.242361,-124.853808,-44.562559,-14.360311,1.352954,-15.008383,-78.128678,-101.760644,-73.920335,7.201531,47.015552,117.808305,144.126141,202.131661,238.425794,262.285057,152.199019,75.20253,17.781272,47.054035,99.255083,102.245575,121.74152,133.171132,57.524395,-107.537854,-125.567597,26.890243,131.614362,251.734305,252.812032,151.145133,17.827935,-25.471518,-64.44403,-54.86682,37.270803,101.985,163.827452,150.147164,112.923223,47.481754,3.465047,18.487485,76.826904,164.256823,175.912292,152.865764,119.006767,128.02502,143.704673,132.538286,117.378192,125.807816,137.291083,116.071943,59.44338,74.030686,91.068979,125.434445,139.6945,132.707004,127.863828,142.592814,106.686571,54.121,-31.49084,-35.56058,-30.929938,-43.459944,-54.112685,-54.161098,-83.013955,-160.990706,-219.64135,-300.268952,-290.77372,-175.186274,-91.755166,14.917012,-39.494079,-89.543345,-105.472938,-56.516974,93.677099,148.034365,128.1133,80.891603,32.722367,-2.159211,-31.609092,-27.694556,-2.202486,7.265445,-7.50353,-40.484641,-39.565933,-35.684961,-45.893609,-53.088445,-73.681759,-82.36974,-61.356801,-48.121127,-52.023163,-68.384253,-80.942749,-71.074636,-48.908418,-24.63774,-20.201979,-36.09862,-119.609131,-163.188693,-132.137327,-37.466449,185.567309,247.35907,238.423571,198.226436,146.596944,111.971678,80.062639,50.372299,52.707784,18.139158,-10.144557,-14.622076,47.332944,41.718212,-63.487862,-92.511308,-49.634435,-0.51305,84.064403,77.61315,12.085081,48.176297,76.18838,79.631806,72.39526,54.191918,30.346637,-48.329446,-96.887598,-125.247687,-204.049641,-199.729044,-78.137672,-25.799502,-23.435076,-31.52341,20.902135,95.535324,110.023649,104.232011,96.166665,76.411864,51.554431,-36.56632,-51.382835,-21.204132,26.094594,45.209329,123.108294,181.461668,322.17141,362.274182,277.601985,92.466938,35.563583,35.417021,64.141941,85.166808,59.176705,-47.045253,-106.051063,-98.874786,-60.280688,-37.970089,26.521698,84.514418,267.453777,363.112296,472.623123,438.157953,386.417874,310.880185,309.119869,332.998995,331.01478,264.496458,158.294522,114.284217,40.903938,17.533992,1.321622,1.010542,5.602941,21.650613,115.573012,176.343723,153.959157,80.240329,67.6562,103.583463,125.447681,100.605171,-9.305962,-74.000818,-193.251534,-228.155591,-203.680546,-149.003817,-46.899543,-49.707978,-158.697984,-224.250778,-207.664672,-163.345244,-167.237058,-123.716276,-50.928365,9.787946,-146.893507,-243.474612,-332.995374,-303.560337,-201.134578,-172.953812,-138.748463,-130.30622,-173.720583,-283.289696,-319.836029,-295.724794,-267.250713,-231.808504,-214.707957,-200.723028,-172.211582,-137.55767,-73.620934,-40.993662,17.68306,22.35896,40.595236,90.476171,214.713115,204.410065,157.11148,103.729358,106.672642,91.708503,45.088844,-55.859538,-40.789138,-27.173567,-48.214162,-49.361412,-34.518133,-38.875933,-47.864395,-55.811438,-87.374427,-99.340778,-97.651247,-77.729553,-58.6341,-1.868963,30.090376,38.183166,-7.799606,-29.142303,-52.641325,-41.833255,6.249974,22.776699,-0.900654,-50.110855,-171.88452,-248.936249,-251.311075,-187.019287,-158.619453,-143.131822,-133.345559,-99.195719,-72.616771,-87.119312,-157.450101,-181.088193,-179.705608,-156.288589,-98.865093,-82.886873,-105.210437,-191.68667,-221.443856,-204.246245,-174.980834,-92.30227,-45.664434,-32.213001,-72.9896,-84.956496,-129.501246,-127.852649,-34.258583,10.197146,25.397584,-9.01015,-155.106176,-239.784534,-206.554908,-79.802123,-46.736184,-57.215992,-74.550287,-110.348691,-163.224628,-220.172038,-344.633792,-348.259861,-252.453504,-217.691684,-213.890031,-219.500809,-220.958471,-251.365642,-272.219013,-238.403748,-185.102425,-94.274662,-69.883918,-69.959135,-71.867863,-68.594072,-100.887579,-109.396648,-80.213337,-64.424686,-61.7023,-82.39531,-165.400369,-284.526821,-324.38623,-291.144267,-243.139451,-171.19377,-139.674241,-69.017268,-72.57934,-131.963972,-275.907371,-293.801773,-182.881841,-98.471229,-10.789628,-11.104475,23.6185,102.693346,122.109703,174.229701,222.704746,298.009059,295.697677,189.507884,62.140558,36.588204,33.535947,41.880354,83.755353,127.937353,238.309288,262.202935,206.746859,94.039985,59.550488,60.061624,66.282272,65.14772,73.192333,50.493735,-82.494158,-145.735822,-133.7139,-57.031088,59.212646,40.662336,-54.268406,-68.009514:-106.68418,-119.187486,-118.245955,-118.328691,-107.901106,-87.233308,-98.166517,-135.336091,-113.408594,-96.216693,-107.747623,-121.001755,-120.178526,-105.738121,-79.37938,-78.124488,-75.413052,-69.162723,-69.265523,-34.859194,9.684148,139.715413,194.528494,186.009193,60.254542,-7.196001,-82.488043,-69.699075,32.697282,107.536772,260.809541,295.171046,184.744636,-19.442942,-47.258928,71.163698,154.607523,260.694857,263.049775,158.973788,4.715591,-84.386159,-222.115604,-209.427014,-14.754999,96.650822,173.955235,141.911132,33.594033,-99.314343,-131.552785,-43.163394,29.811364,122.114341,129.639246,50.856301,-34.519215,-45.486216,-17.325111,11.276588,70.821877,105.326687,130.696653,93.362436,-6.516801,-51.621774,-60.646564,-8.342505,43.922257,124.016323,154.745802,187.746936,90.31412,18.239105,-32.103209,-12.327031,28.414698,50.300653,73.334542,36.862635,-107.592112,-218.116233,-246.783194,-285.409624,-296.829249,-235.271407,-156.186614,-16.881954,-74.247274,-172.707762,-251.394323,-174.335331,47.537794,130.674548,203.171439,187.669656,122.504692,23.475133,-38.050157,-76.279809,-41.79364,11.157959,-19.007834,-161.445889,-250.690039,-258.237201,-219.094311,-171.733476,-75.236216,-61.266018,-115.742188,-150.361352,-179.218431,-188.147697,-173.938586,-75.884249,-29.273819,-2.602576,-7.761628,-57.996727,-127.075197,-135.541016,-53.302846,28.479431,181.393638,232.631363,279.598729,267.619179,179.336975,59.804396,25.10441,28.990738,47.168392,103.974361,127.288309,90.809153,-4.98052,-31.68061,-19.991166,-3.200708,17.797439,36.33911,49.715317,19.738011,-21.488804,20.800173,28.626787,10.496242,27.115172,136.897069,165.648573,56.289893,-80.491972,-111.820589,-147.072834,-138.173375,-71.757209,-40.251404,-4.572486,-2.354225,-7.547735,27.36939,48.612339,33.216707,11.231154,57.176401,106.470354,87.508778,-15.227099,-45.318536,-47.991844,-4.073095,156.041627,230.7399,292.13418,273.769953,164.19145,22.935294,-10.374733,40.160828,76.400646,69.763982,34.035958,-37.058101,-84.059229,-106.611781,-105.211318,-58.770662,61.569226,113.496746,242.096244,320.542076,428.088068,355.293266,284.078146,249.860749,288.87473,340.983724,321.173076,224.734254,103.956244,39.232203,-23.658213,-4.089966,59.575208,95.165192,175.418476,172.638641,72.627137,41.365511,77.174814,170.725856,194.117058,218.85646,230.496766,158.859682,-31.202946,-115.522581,-186.477235,-161.490498,-34.683249,35.200664,97.253408,71.869956,-43.011411,-176.685521,-206.46286,-131.368954,-76.190243,2.756507,37.838419,34.32235,-81.500491,-142.914882,-221.663495,-233.55649,-203.5351,-164.997259,-99.068761,-99.014518,-148.375478,-230.219144,-276.953565,-320.768648,-301.543268,-215.671602,-180.839445,-143.321567,-155.180139,-189.39618,-194.196426,-114.887847,102.818902,159.075668,150.013341,156.332987,258.293843,254.513553,199.214076,150.063536,166.703102,178.428811,147.417225,54.045028,-7.058692,-23.56194,-27.023955,-20.312532,-3.043862,21.963423,57.181486,34.100211,-41.53846,-82.326385,-80.326678,-36.715885,-4.14525,77.74177,102.334488,49.729776,-48.01081,-73.427343,-64.86696,-45.082803,-1.785068,34.115877,77.647635,42.278804,-99.011185,-175.751576,-177.552698,-171.860474,-170.889381,-142.52434,-126.573595,-141.113233,-144.60683,-126.765152,-132.668429,-160.054675,-179.870292,-152.757913,-55.141631,-27.344423,-114.949407,-287.377955,-312.606764,-216.018354,-148.250961,-22.18477,25.138679,14.59898,-69.262382,-115.968453,-160.046505,-120.488497,27.613929,71.90577,14.953884,-54.11346,-150.177878,-209.983367,-227.350407,-172.168301,-125.062805,-94.915563,-100.128986,-71.176894,-98.851892,-198.537763,-392.478735,-375.439379,-195.256885,-131.72933,-127.709278,-150.714542,-154.636669,-154.889674,-150.746855,-70.698346,-20.430619,39.805503,34.34559,-77.60023,-195.580764,-212.494995,-147.541202,-96.992627,-43.016832,-27.562349,-20.616889,-58.190057,-182.042431,-235.791755,-234.216429,-182.207218,-130.825223,-37.876866,-24.119108,-46.499222,-98.441565,-138.655864,-227.396662,-246.752199,-203.583937,-162.669742,-96.250677,-73.165776,-48.957497,-58.164263,-44.198458,52.253383,102.692166,170.982563,191.574276,143.235236,1.917185,-53.889108,-64.651232,-13.426858,102.884095,131.712752,170.051994,181.604914,131.679621,36.415328,10.918415,3.209895,9.700322,72.769154,113.97167,109.598177,9.030733,-46.189472,-83.502027,-41.908612,69.870436,99.124231,91.528124,59.82716:-26.786128,29.088251,94.460398,126.848418,84.222528,13.285224,13.871567,21.113679,-43.047133,-76.31469,-47.550004,7.587371,37.946675,-12.901271,-128.558362,-140.291406,-43.043664,29.244557,12.262308,-30.800893,-9.415226,124.693363,186.801298,217.527708,145.641405,66.895133,-101.339786,-119.336882,-48.602214,-35.993984,-76.674246,-89.870227,-79.848132,-109.081923,-141.885481,-113.170163,-36.878018,111.736938,146.980326,130.042099,37.154718,-11.206705,-22.966411,36.624773,188.313197,219.136828,162.733794,111.993937,84.462365,147.13483,152.430292,125.046225,133.629413,181.606786,195.758804,198.090669,216.83521,227.875018,216.061251,211.845855,220.539014,219.078213,205.990747,185.918708,162.980246,252.709295,300.856457,295.463865,253.348002,192.69235,189.965837,170.705935,92.075965,60.92931,34.615634,30.141262,16.301683,1.685978,-58.876914,-100.456547,-135.139186,-141.561762,-154.453425,-125.775923,-99.083421,-81.99431,-68.876601,-20.382136,-46.297361,-98.180534,-158.540467,-119.530489,40.087482,89.377116,59.30891,32.185549,57.311507,71.636232,57.026322,73.223442,111.112748,179.085505,171.006865,10.483781,-171.289299,-187.380393,-97.272945,-40.09242,-14.84287,-61.613827,-159.657843,-159.206541,-98.176702,-126.214155,-166.522808,-164.662679,-130.464459,-89.314708,-72.476691,-42.079565,-86.778966,-119.347284,-128.487664,-85.030234,34.878655,76.182653,146.143846,156.858166,111.292965,123.978922,140.255933,107.379484,52.625679,-64.873676,-77.913973,-6.971102,27.064144,1.23799,-77.243987,-103.326596,-88.728176,-36.905186,58.200441,39.031346,-72.501186,-104.100764,-89.884726,-40.366537,-22.945555,-44.827093,-72.67498,-134.452324,-215.311717,-257.475164,-267.475476,-201.522432,-9.384137,31.02977,-28.177384,-50.105362,-7.285412,10.56114,-3.338323,3.951791,34.717777,100.478346,116.317196,71.194618,-56.730289,-98.096149,-68.322888,-1.135502,127.480481,144.86043,168.408603,202.594809,220.073543,121.340481,68.675331,69.686785,101.011562,104.808482,82.354501,23.309449,-62.352885,-118.144003,-152.69429,-86.125505,107.438077,190.752497,366.844887,439.769511,457.986295,375.624359,346.417248,340.615546,371.744336,469.555325,487.451754,417.661126,333.36529,279.976437,137.667897,109.033137,198.41729,278.622162,381.264477,376.870465,324.428786,272.009124,240.386343,215.337301,210.873356,134.001006,73.380363,-10.800729,-54.750242,-83.65698,-175.073394,-204.380276,-128.488004,-49.985658,-2.033494,-67.80514,-254.925602,-306.561927,-258.897921,-79.317104,3.529022,70.052988,51.875809,-43.431091,-170.357067,-235.634815,-277.446686,-220.715438,-50.370735,-5.096999,-32.894494,-69.345198,-66.737719,-31.110737,-67.59078,-193.453725,-228.786325,-202.87584,-160.748201,-97.034903,-79.127974,-80.458795,-75.739507,-36.829894,75.258239,94.959932,53.944288,17.806092,-40.748492,-51.454095,-29.132882,82.536735,126.455026,59.91033,-14.673492,-91.530998,-95.080788,-101.816115,-93.597109,-49.884357,54.164433,56.211142,-49.013829,-105.347847,-115.264636,-27.2427,0.65869,35.807192,60.266771,39.413246,-1.909736,-12.911997,3.375393,-31.387985,-132.815951,-154.490213,-132.228023,-112.126207,-84.193353,-105.921388,-226.453619,-259.122266,-223.233895,-104.082633,-62.039234,-49.887763,-33.399463,23.769411,-10.375999,-28.503452,-4.689414,-5.176335,-97.551759,-146.055454,-137.204777,-102.602368,-90.475486,-186.158495,-240.790434,-206.771368,-106.641599,100.640517,135.761716,32.55061,-81.542719,-97.20235,-136.55898,-150.850023,-102.749313,-79.353136,-96.586486,-115.676071,-150.136659,-188.821862,-191.135037,-94.152576,-12.026449,89.542556,87.590739,4.491556,-133.693222,-210.709691,-306.637543,-282.125509,-181.848898,-194.315934,-297.767716,-313.474583,-299.612779,-338.600298,-346.718815,-248.771282,-165.39264,-34.484518,-3.330813,-13.665474,-9.890646,19.914932,57.062962,54.341273,29.715393,12.804213,-74.29489,-140.685741,-213.504551,-228.134886,-233.43128,-173.109353,-117.83842,-68.473408,-81.960061,-108.701273,-112.883201,-121.213364,-130.937947,-141.105467,-161.420373,-132.696913,-50.652908,-63.910833,-137.197054,-49.862448,28.465068,108.27334,99.040423,84.993053,123.165954,221.834848,214.646006,176.185866,91.737564,65.830228,17.510644,1.457032,56.278559,99.274744,125.740478,104.306083,93.250422,92.350568,93.651057,77.094743,73.029689,69.60323,-13.559701,-73.699933,-108.424665,-69.092606,10.581217,13.444869,-58.629768,-123.103688:6.258411,-13.269708,11.887371,42.388826,30.540051,3.98831,2.698662,-3.51269,-66.69309,-119.071661,-171.5609,-150.945709,-86.670354,-76.129412,-99.77519,-121.830478,-156.142742,-151.532593,-127.11708,-44.16048,2.091289,104.522531,140.253123,69.593989,-81.705062,-102.910165,-47.228106,-17.467616,-10.825829,-15.444608,14.59703,34.226201,-25.3701,-143.609801,-136.050992,12.157906,93.395735,182.333744,181.518745,81.380103,-72.318005,-129.065539,-132.754926,-70.285436,71.090487,109.666797,129.333705,121.180705,84.453928,-0.02307,-33.338626,35.973045,118.751976,238.831381,260.396991,203.427872,45.518286,-2.854266,28.961257,83.141111,161.369904,178.754664,194.32417,171.596928,84.464165,74.796281,100.021217,162.619219,178.55889,146.822172,131.72716,131.130052,32.335649,-41.484706,-73.784342,-19.776293,84.178716,80.236176,-4.35808,-28.116275,-27.648602,-123.055552,-202.056027,-281.292631,-264.691196,-159.943229,-93.729045,-34.629043,-119.757601,-176.529895,-183.18251,-108.533155,81.089858,119.406735,53.028607,14.968762,16.172757,-44.139035,-92.284873,-81.677396,-45.725018,-0.11453,10.68221,-46.812394,-204.012683,-250.896683,-195.970886,-128.692677,-75.909679,-99.487923,-143.172989,-158.268044,-222.830098,-287.630388,-274.360598,-170.003941,-134.070444,-119.742863,-102.252568,-62.666265,-104.794053,-135.597962,-141.698137,-106.153076,66.402633,168.671672,194.940361,117.654615,-0.283236,-2.868193,-4.929411,-0.9683,14.522188,40.885073,44.601118,28.409162,-29.792424,-93.163503,-212.631847,-190.52255,-3.855171,77.188047,93.223919,37.392298,-58.271815,-50.960067,-30.845672,18.518679,22.167027,-2.43032,6.30718,1.476637,-150.909231,-237.39199,-290.815717,-245.940171,-100.854265,-46.083179,-12.486635,-26.233585,-44.135682,22.713793,61.027511,76.27736,73.176966,107.545675,110.803128,5.336714,-97.56434,-90.563256,7.298979,55.379317,132.364231,191.095163,299.612652,289.161004,139.275506,-26.608576,-69.259982,-27.287203,23.870292,77.381106,60.841099,-89.97889,-244.077706,-262.798668,-204.35958,-127.767891,55.766649,108.389311,174.957406,235.751231,347.589927,294.915796,238.588264,210.678892,238.410173,303.566475,324.251851,304.09854,187.455094,112.399915,18.103025,27.606042,129.699536,191.818792,268.026323,268.976461,255.602167,244.985617,232.258712,185.569218,145.289384,119.098273,146.325836,114.637231,-68.842673,-140.958382,-202.573587,-198.294789,-92.072152,-9.460164,62.537863,12.548426,-149.684681,-179.017854,-150.432291,-111.174284,-86.535972,37.91217,95.749148,60.154965,-131.588359,-229.948315,-303.316432,-256.000662,-136.313379,-109.09662,-70.791571,-50.878574,-71.756834,-187.390425,-235.639025,-259.636993,-247.902828,-195.988721,-172.805166,-173.959487,-170.430557,-155.151582,-92.38008,-30.60578,76.850606,91.313521,82.859525,67.040934,15.342266,2.566302,34.869465,179.64699,242.352996,222.976417,149.563631,0.27138,-43.563832,-48.064117,-48.302311,-27.13304,0.914183,-6.582318,-19.875979,-29.288028,-89.618617,-178.25671,-196.737386,-121.450315,-52.086156,18.164453,7.809195,-47.425,-126.033218,-168.766902,-199.953495,-168.50833,-44.903383,9.146764,-1.742751,-67.793534,-213.030416,-320.216317,-348.292461,-292.093453,-229.570334,-152.536835,-146.988323,-152.992336,-154.024749,-163.038447,-157.404572,-122.296653,-58.005757,-63.003093,-105.282878,-118.556078,-166.02632,-226.30859,-234.825252,-180.09393,-111.625182,63.085164,126.000085,98.012361,-29.648814,-61.967394,-72.091686,-60.541177,-24.872186,-6.781335,24.934871,6.380576,-140.836822,-258.030768,-227.909209,-48.678784,20.5339,35.750698,12.366057,-37.391399,-172.366764,-282.693298,-414.140261,-363.222902,-158.691426,-114.57643,-137.743497,-140.527242,-135.227562,-199.38267,-218.693055,-105.834177,-1.954423,129.187173,146.017957,141.111346,93.144904,47.322918,-7.821458,18.12849,126.100309,164.442349,161.172984,122.041512,-18.339302,-187.443654,-213.045885,-106.119646,-44.381487,-24.224664,-39.714887,-66.789037,-94.176669,-118.633581,-166.105148,-152.696693,-52.823951,-4.51067,13.87345,-17.271598,-73.844514,-65.03397,-31.005715,120.410639,204.581102,276.595721,256.057243,145.817743,58.023462,52.635935,97.91919,131.592807,179.64452,201.946945,248.837682,224.227905,84.110244,27.560813,45.071799,132.680688,170.315348,177.348725,156.85179,81.47278,6.904771,-18.745321,-3.889626,61.639751,177.847469,155.447576,7.863359,-57.397441:88.685337,237.884286,334.431201,426.815662,387.163001,216.595766,166.526101,192.746883,199.467541,152.524267,69.454265,83.476167,133.978292,116.065291,40.719189,19.880433,-0.648889,-63.992749,-98.647742,-55.195503,-0.209017,21.870068,4.644768,-13.154995,-37.267535,-55.845188,-99.956117,-110.218058,-100.591528,-103.704898,-140.713404,-159.948538,-167.309323,-169.259905,-182.711205,-149.428203,-89.433626,3.421825,7.022396,-60.088461,-118.595888,-115.671778,-101.095338,-85.615244,5.647773,62.095745,99.56059,72.143608,12.66078,24.808738,45.706923,98.312437,123.649457,143.683786,144.670233,156.187144,195.957179,234.322094,317.945333,341.213137,302.788425,255.003135,196.564265,184.906684,182.537307,246.534462,282.803688,316.486186,301.222502,182.48711,112.074669,53.065135,71.998402,65.917369,-4.69935,-38.641979,-69.142098,-80.777298,-106.368404,-115.25976,-74.62188,-9.902068,-25.670272,-98.284439,-120.062176,-136.763722,-120.432704,-75.975052,-123.51845,-160.598969,-158.505979,-102.820859,-13.966724,-32.735018,-87.937123,-84.08989,-57.079313,-23.773564,-7.282562,20.462854,36.232998,47.382555,15.469834,-137.716008,-232.94372,-223.756664,-221.402953,-248.147857,-256.573309,-220.694311,-144.657121,-129.541076,-115.830508,-59.966668,-22.610432,32.955314,34.99997,6.908835,8.875635,66.549159,96.661722,73.097117,2.173378,-18.513754,-30.805216,-16.420785,85.248588,124.374986,87.596819,83.271007,117.315032,93.625948,27.06905,-45.575633,-16.897788,29.894382,-43.272132,-59.352489,-56.163078,-74.520942,-109.072871,-106.956132,-77.958085,-75.74808,-115.376744,-110.347278,-99.791036,-123.877747,-135.22542,-131.828852,-147.414771,-214.668422,-250.299464,-260.550598,-272.162346,-255.566511,-212.858155,-220.873273,-240.9471,-219.899442,-147.544656,-112.556995,-107.31575,-56.332914,-11.418149,47.514254,37.016357,-114.573292,-285.1916,-283.324322,-151.158793,-72.695342,9.987132,8.06746,56.918873,120.422567,171.603304,70.971602,24.471236,26.554685,46.023589,53.474231,50.114489,31.496614,-34.451314,-76.389656,-122.913136,-104.597803,24.843366,119.063881,286.307998,322.509588,314.865622,280.725351,252.495787,237.489397,275.632135,371.383677,395.923747,408.306401,421.976036,401.384623,259.652906,192.982499,170.743666,214.087823,388.665753,463.760386,464.29241,353.593437,287.913849,181.106682,148.596126,124.226125,147.053203,187.524078,70.659289,-8.862134,-81.074602,-76.434574,-50.955441,-18.812171,96.148641,112.534337,-20.361627,-157.635406,-167.446054,-75.710263,1.581706,100.000824,79.321917,-50.387534,-120.365413,-119.3541,-66.65236,-0.645234,179.041222,239.033944,252.389037,221.358907,145.481254,136.286754,133.127781,48.665686,-17.306958,-85.689535,-60.840849,27.678551,30.194543,3.46586,-52.338173,-54.67984,-10.241527,-1.72491,-21.330167,-18.237729,27.555042,47.799027,48.022814,86.879859,107.543402,57.457031,-4.883077,-78.10243,-19.2812,16.064602,39.070417,54.294382,94.479806,83.436618,15.593895,-6.744605,22.226167,94.810422,105.097493,46.163608,-11.512999,-125.771699,-151.097276,-106.325091,-37.91285,-27.439288,-10.873023,-3.009235,-66.762819,-122.767863,-109.334327,-46.889075,-44.533569,-186.738836,-203.518273,-94.779675,-38.939216,6.120384,21.379263,26.635784,-14.521433,-7.472241,82.214223,122.986256,120.799709,92.471728,30.51183,-11.054308,-66.808835,-32.853273,-14.517853,50.9792,98.619118,145.806354,142.448139,106.890699,71.035577,54.126298,-4.016473,-35.954554,-73.868791,-88.537464,-94.281771,-66.115318,38.746344,144.87188,174.27077,194.738197,196.345336,173.791425,160.511647,120.501239,-7.571815,-79.378666,-146.129487,-130.645942,-76.486001,-72.145,-69.38016,-59.06062,-91.845871,-143.438407,-128.247592,-43.216222,1.939953,90.838192,131.192582,125.701998,-8.872418,-58.195769,-37.50381,25.466055,172.672721,205.607856,107.667042,-3.346081,-199.539353,-212.015779,-157.848547,-76.525329,-82.404545,-103.891442,-82.683823,16.448098,100.616977,89.100639,-43.733397,-100.609339,-108.317864,-103.359413,-127.398997,-144.902155,-196.183302,-183.623588,-133.874913,-15.553355,18.798501,13.573943,-2.247255,0.655401,37.589673,33.317245,0.117625,0.141617,-45.970215,-88.505063,-29.687559,48.213471,42.481899,-124.145493,-136.937539,-40.070283,-29.250951,-76.970839,-57.227935,36.335139,-8.139826,-61.661968,-142.137104,-171.863113,-175.395734,-150.575563,-150.992435,-187.859893:94.719703,308.97442,366.46436,291.693735,223.076077,160.882492,167.63586,200.269088,172.157995,128.866287,78.568021,107.351156,185.140442,170.314432,44.542323,2.786869,77.342269,134.13066,71.493456,-31.092839,4.378955,112.191805,140.099246,208.252141,258.62764,223.506702,26.214657,-64.565095,-141.717965,-162.83691,-220.670556,-240.642327,-195.226914,-144.426593,-183.431375,-278.404303,-250.846771,-90.938689,-31.560668,-24.333902,-115.281244,-156.838766,-164.836805,-125.774827,-25.114575,8.431876,12.955522,-20.517519,-59.640836,32.635535,59.278864,-1.146179,-38.860802,-10.191736,62.5802,248.338114,359.517341,346.074245,243.227611,235.096107,320.687176,343.122258,294.892045,259.855577,277.198747,375.806305,368.575979,231.392301,181.125184,177.51411,183.013293,142.308618,90.85207,75.611848,23.054452,-9.80422,-63.366307,-80.918656,-88.776386,-83.496916,-41.712286,-33.921886,-77.310469,-162.544154,-165.475625,-95.655633,-36.040874,41.834511,-42.080268,-119.824536,-225.101856,-215.009166,-102.030175,-50.597949,0.79488,4.086901,-11.894252,5.459213,10.025081,2.613608,16.644813,61.399934,59.752731,6.175863,-30.366398,-51.440073,-144.956813,-192.932494,-234.399134,-228.02057,-188.603509,-170.326384,-128.397668,-89.470474,-93.073899,-100.504487,-89.024386,-58.865468,-30.916865,33.011684,14.052181,-27.044793,-95.759503,-79.567481,18.415355,47.191879,81.422591,106.151799,115.94066,120.188379,152.898969,168.802885,94.610979,-93.228183,-91.014792,78.683697,106.760619,42.151757,-88.116363,-105.248371,-53.598435,-26.09684,-18.445352,-29.081674,-56.249334,-83.234765,-83.590273,-52.870409,-36.542371,-10.524282,2.753857,-14.357972,-98.183764,-142.524045,-172.485611,-136.843569,-9.866346,27.294539,14.013537,-1.642038,-6.391724,22.21743,23.637574,-10.871547,-17.883689,-12.250295,-16.040633,-51.261609,-133.371317,-178.576006,-176.561048,-115.216511,18.5018,64.323112,151.739936,187.913157,232.241988,234.253632,195.249229,143.982891,175.071022,220.773391,196.971581,134.928825,72.986121,13.375979,-81.405721,-68.296955,33.950701,94.646039,242.812348,319.916144,404.035637,333.967757,264.47292,228.727733,278.262895,373.605053,380.371001,339.308673,300.178337,254.833662,87.476242,35.940216,98.155805,169.75424,319.834759,392.698252,468.704752,358.91164,262.326795,165.585254,147.526306,32.596761,-16.905847,18.911211,61.793743,21.989675,-100.982703,-114.299654,-37.300562,11.285336,92.914755,98.645175,-12.453449,-152.665226,-176.371603,-86.925381,1.927737,115.77404,101.943684,-34.793309,-128.810374,-120.341613,-93.384348,-93.085765,-67.128312,-44.419201,-33.676211,-29.904595,40.123512,93.175089,79.773782,28.872388,0.78832,-30.462946,-8.02285,76.144458,110.892737,81.37827,-52.873778,-87.42248,-29.979879,-2.874582,-59.929958,-107.898789,-145.502584,-162.812461,-171.044715,-119.453498,-81.754026,-74.387984,-97.230013,-140.507283,-160.389622,-189.887029,-284.098355,-285.405263,-165.597772,-101.087592,-54.31051,-55.655551,12.745658,125.524276,126.153346,34.598841,-23.028308,-110.428461,-107.404135,-30.138527,-39.789469,-80.313377,-128.132521,-127.61038,-134.330748,-134.890573,-100.311191,-100.741222,-141.354586,-97.247191,-71.969113,-82.953774,-89.487562,-52.906042,-21.370607,-2.859989,-74.911717,-119.622277,-131.933482,-85.093817,36.955358,70.318072,39.515429,-13.914792,-103.62222,-109.756196,-103.417147,-87.89745,-75.479153,-24.615144,9.875567,15.612899,-52.062287,-73.299492,-107.069428,-121.172578,-90.745785,-55.667465,5.171355,12.701237,-36.790743,-30.059785,25.861212,135.448361,137.097692,70.30491,42.136645,-31.812136,-167.053495,-223.027725,-212.075869,-148.23621,-94.817472,-135.44178,-174.10193,-152.346604,-170.761228,-252.723427,-261.560358,-190.00069,-127.753398,-18.433466,3.944775,-34.231716,-92.550934,-101.140073,-67.502762,-31.144861,-21.538133,-65.988515,-171.29654,-212.559394,-275.790808,-275.299994,-243.60261,-180.401065,-171.283854,-163.54222,-135.802221,-42.219899,-14.131456,-37.387852,-98.263145,-119.069243,-132.404426,-108.47226,-14.193085,-2.475499,-100.804023,-167.253753,-135.166821,-26.239324,-3.090816,12.671469,33.819542,37.36179,-18.814047,-39.819361,-65.10255,-81.497892,-137.82894,-138.106996,9.906561,94.752998,67.239922,-90.080721,-112.832383,-68.072818,-69.09302,-142.857623,-155.155737,-99.041288,-94.931701,-118.258465,-126.702862,-107.065864,-81.629157,-88.330749,-140.976492,-183.904617:11.496695,45.249306,76.807863,156.813747,196.697764,175.164512,119.709102,13.744176,-42.136902,-37.67256,33.164651,44.081252,-64.432197,-123.05737,-129.538408,-116.988304,-132.308071,-143.357409,-153.254593,-134.034849,-89.247434,-13.761134,11.499357,24.645091,-96.591859,-147.596404,-119.045874,-72.378284,-51.506822,-75.166376,-60.194855,-34.060593,-59.501222,-146.844896,-187.504849,-168.695395,-100.196706,44.490471,81.670742,37.752331,-112.981734,-159.135202,-93.087145,-19.059097,89.662757,134.960151,207.845942,200.234138,127.412214,122.952454,146.2753,210.431212,235.659698,227.134321,196.088469,150.587369,177.124288,178.028715,118.189775,101.888193,145.756065,167.212384,141.758847,116.309472,137.030729,199.748898,199.030104,198.320655,216.857668,222.422042,206.766644,130.072928,-31.558198,-85.417698,-57.415769,-16.070893,24.601739,22.78095,5.725059,0.41716,2.791608,-66.420868,-141.334884,-203.172501,-159.940121,-25.791899,12.077569,-43.900932,-106.055722,-80.134805,-13.644613,7.519889,55.1806,56.642517,-9.039461,-37.273324,-24.78757,-0.830352,-0.882072,35.067614,63.365673,71.935007,66.150298,29.78479,-96.81475,-159.351933,-185.673663,-146.908783,-100.959639,-148.2256,-268.613181,-252.456047,-98.371767,-69.57318,-113.692478,-143.097856,-114.540002,-31.531031,25.175756,68.633009,-47.226351,-87.877975,-75.971342,-45.722868,19.019344,34.053174,34.304846,25.307446,26.181854,89.717925,98.675609,68.346625,76.711011,109.861208,93.05449,31.633338,5.345876,-12.320104,-84.373963,-110.243607,-74.508445,-48.737318,-63.184397,-87.872948,-111.155797,-63.576995,-41.338207,-60.483664,-78.154674,-45.911869,-21.212409,-92.175336,-262.44586,-315.200412,-330.733911,-295.160979,-186.43398,-163.511298,-155.407891,-113.27392,18.243419,10.693822,-42.405058,-75.732625,-39.01681,10.032633,-1.864116,-46.602899,-77.158169,-72.409071,-40.285691,-21.954399,39.12526,83.783638,166.677209,172.5208,96.881056,-11.012154,-59.416355,-42.870513,31.292845,92.292611,21.104166,-156.965608,-141.30014,-114.764528,-136.394602,-133.84982,-31.289975,27.050313,122.356686,182.9734,279.867626,188.322519,104.027507,81.811234,151.650527,276.627118,305.708003,339.760753,294.286907,228.315373,64.613901,22.438539,119.913682,215.955446,320.644372,308.763666,281.110719,280.08036,233.941233,88.596516,30.386211,-13.884411,7.959477,64.412725,14.493713,-34.928157,-115.02296,-144.733472,-154.751537,-119.234154,-34.240071,-15.02684,-18.206515,-86.697464,-117.630434,-50.105178,19.191576,61.796282,31.59396,-52.889486,-109.130306,-126.614607,-136.207966,-119.132249,-51.729211,-9.421289,82.656256,110.388557,37.203195,-100.530776,-127.748414,-135.946187,-134.115745,-109.721261,-107.844332,-155.370054,-149.818575,-113.952367,-53.289035,-33.780974,0.965624,23.220446,90.443151,98.124381,12.400589,-8.183069,38.772895,105.235071,82.958764,17.179966,20.948397,58.199641,56.00481,47.483173,35.756106,34.071725,49.953665,56.807446,-3.215348,-50.347247,-42.513075,26.447989,26.368829,-5.040468,-18.722768,-40.03015,-22.280901,74.161115,104.504798,59.823897,-83.789138,-115.930409,-56.489231,19.002163,164.106057,152.69581,-42.598018,-201.901753,-226.796713,-203.21398,-167.026621,-77.025903,-40.672918,4.0562,-4.059772,-24.290238,-6.602301,29.602153,3.489155,-55.820188,-113.17977,-117.678469,-114.252867,-21.174339,21.626565,42.271431,59.543832,181.461462,247.042955,230.227358,118.902486,85.042389,7.036342,-32.836892,-53.83867,-56.114668,-97.927205,-118.824645,-112.90125,-31.471046,29.949436,121.051192,119.561729,76.505469,77.984843,76.767837,-39.978282,-120.249706,-230.643269,-226.906597,-140.434999,-110.941029,-72.587326,-53.533461,-76.277805,-94.260847,-84.426336,-64.847492,-32.621625,89.930806,149.63004,214.682184,223.740322,196.524222,110.335893,109.423329,140.741283,125.342458,85.436876,54.193119,-76.524137,-157.557589,-148.760454,-66.978719,-23.906257,-6.767629,-24.245425,-26.445812,0.040133,-11.64594,-85.977613,-103.818026,-52.170494,-32.744113,-91.876593,-145.769991,-248.695931,-272.211792,-192.70156,89.157638,189.82077,179.135314,126.261119,111.143876,161.603218,158.61062,100.81448,70.600388,42.261621,48.418921,91.549173,95.323155,46.927857,28.697649,32.727223,40.351707,34.51745,47.68135,83.532731,138.257427,68.360262,8.282626,-55.645611,-28.413194,89.162416,100.793253,-34.874355,-133.181608:backward
-50.884746,51.730619,126.598103,244.508039,252.167054,99.294441,-11.892354,-98.341839,-21.339196,41.844642,154.624045,149.937522,-23.505299,-126.002034,-198.565622,-180.529883,-89.730178,115.400372,230.26361,336.60477,306.301252,134.365198,47.329151,15.617822,114.537927,169.025051,279.01286,309.523029,266.215505,197.42091,36.730541,-6.752672,67.062204,283.444862,355.469139,295.063876,199.269103,48.674485,25.233448,28.138148,-6.149395,-12.777193,13.306666,16.948717,-10.38823,-35.927075,-125.974896,-192.576003,-325.245373,-309.756453,-222.776743,-65.051498,-55.613278,-147.01253,-206.563923,-271.861507,-223.367466,-163.728852,-17.917567,36.440679,42.201511,2.163885,-55.657923,-25.929168,121.338122,235.380389,277.737751,373.299116,405.279689,312.253153,195.105865,16.527264,5.129705,45.550496,174.46834,203.445056,62.571634,-73.816711,-234.29615,-200.783234,-54.275047,13.985446,56.937466,168.655327,193.668832,156.466535,118.10493,57.546997,79.823095,135.92913,237.982014,229.615115,125.519585,75.927798,-0.91974,-23.736932,17.708873,155.620733,207.177683,169.110388,106.596225,26.335041,13.447226,-5.938038,18.05476,68.696017,159.966461,136.675388,-29.053768,-120.406577,-200.832366,-150.383377,29.360936,93.809227,68.451716,0.6437,-6.85616,-25.026325,-46.354881,-47.225402,-18.953743,10.028534,82.788766,76.002949,4.31037,-13.371097,-10.333212,-3.236061,-7.13743,-5.666564,12.636188,67.549059,78.800825,-22.610764,-105.75334,-133.66638,13.336294,89.787051,192.557642,212.124004,194.068282,173.644159,184.704891,222.150788,283.339283,297.88492,331.223549,410.288539,385.390904,194.751803,101.708806,27.491232,18.573701,15.122123,16.987846,23.107359,25.928711,-3.378765,-75.524935,-63.899335,3.492625,39.168434,85.17136,227.364566,279.45064,291.733641,272.909507,273.025732,380.539858,449.028103,525.24422,549.224399,606.732606,600.524374,520.226854,506.117784,547.43934,562.287458,541.419658,458.893927,415.467415,291.284919,184.233191,25.717664,134.892044,230.433011,280.617949,232.829545,147.150079,125.738091,111.105253,136.394764,212.866432,273.368617,306.838275,346.242326,358.055106,353.703113,321.957014,316.375605,437.804653,474.736045,425.582508,358.240728,244.31243,227.008302,231.859787,223.591322,150.320912,142.055437,193.523198,211.622166,128.940894,-48.564196,-50.904169,80.318895,61.372856,-15.082195,-59.898297,-15.121928,-7.113738,-96.084632,-275.91159,-279.578671,-174.008191,-105.22138,-108.020462,-156.498499,-185.170867,-258.673261,-300.191235,-324.019532,-279.033298,-256.051877,-202.563587,-185.002166,-227.595472,-281.695783,-396.283936,-421.640428,-350.274213,-189.724571,-115.501509,-58.319419,-69.73325,-106.464021,-119.665666,-118.835829,-155.004525,-179.267968,-112.039161,-30.223975,72.798892,56.313347,-53.745919,-98.148415,-124.17136,-72.266467,-47.545121,-78.256156,-113.339918,-193.676999,-231.912625,-208.004253,-114.279022,-114.013406,-142.068461,-99.836962,56.640071,70.434403,-65.185171,-118.140198,-62.395645,65.418703,93.139708,58.818341,28.324705,-49.340473,-128.967856,-298.318771,-307.337903,-265.152046,-201.96272,-212.712833,-282.822897,-316.169497,-385.670796,-419.4762,-439.929531,-347.421816,-292.274117,-238.605656,-224.247646,-251.802697,-292.376907,-264.05705,-122.061358,-100.39685,-162.301161,-200.908458,-247.820076,-274.847267,-327.151987,-310.554559,-217.507189,-168.102119,-147.815568,-95.36086,-77.158034,-105.701031,-141.917817,-169.277812,-147.676866,-112.094743,-23.389813,-30.364735,-167.751496,-250.345125,-332.560349,-320.015426,-235.303168,-96.592062,-35.390654,-26.602642,-66.21614,-173.881197,-228.763323,-238.693216,-83.83244,3.523535,63.672468,7.338912,-210.080956,-314.47283,-399.691065,-361.67747,-187.138945,-29.360661,0.219715,-59.828219,-118.854235,-222.360235,-252.047017,-265.736221,-282.34365,-275.860895,-200.037282,-172.332123,-241.452592,-328.412167,-463.145928,-482.272739,-490.617076,-412.224236,-333.368292,-247.288823,-269.65446,-390.189285,-438.567988,-421.042708,-288.030425,-194.971169,2.718681,68.543537,58.534772,-7.409931,-147.697462,-172.58862,-140.913836,-87.149247,-43.932237,25.520973,10.621281,-123.859905,-204.406843,-222.45512,18.628534,153.763072,269.538713,252.007258,191.850789,172.677585,138.614361,121.463657,48.020809,-25.038711,-13.353906,55.802514,83.786557,134.575945,171.195949,252.074006,200.297641,120.863463,24.95125,35.535834,54.326834,3.593507,-171.788931,-212.438916:93.384511,206.289246,249.128232,242.006586,184.394626,9.827734,-54.08249,-87.240013,-74.871754,-26.190215,120.299754,117.216755,-103.928537,-214.392742,-230.104134,-185.823892,-149.497008,-32.567211,65.646513,142.983475,93.24774,-77.001635,-142.942488,-147.647108,-37.110625,16.89412,73.046774,77.209917,44.527903,-7.71366,-134.292784,-155.020829,-50.381279,131.364194,170.426635,142.898081,130.875287,123.633677,110.006867,90.473654,104.443518,115.218186,81.7559,32.334158,-55.871292,-83.432749,-149.625319,-204.589874,-303.980747,-258.378365,-219.209923,-261.676672,-323.852868,-403.566298,-411.873265,-396.653408,-322.96404,-238.131548,-56.180524,-30.892369,-124.768778,-187.980497,-211.886808,-150.83606,32.371983,164.183097,198.098526,217.262369,204.852449,93.234236,12.377814,-48.04008,84.095581,173.621515,250.402397,213.691438,59.967386,-23.541879,-140.757741,-151.777037,-96.895493,28.162542,107.744207,196.739345,183.725727,115.763967,91.367816,53.857943,55.365151,68.836212,57.39326,44.386295,38.761939,27.714145,-20.844256,-26.508166,54.798209,158.089269,163.133122,95.840731,73.891184,83.48224,87.210945,85.140663,157.613407,228.684659,300.89975,266.990445,126.673094,50.41325,-39.571886,-21.136459,92.407567,171.781995,176.776327,114.639337,55.256677,-74.722213,-110.312554,-62.182358,66.184174,130.164535,187.987391,148.14998,-14.63296,-78.787265,-89.382272,-41.494464,72.830656,97.351623,66.550495,18.797889,24.020722,-18.696608,-71.362968,-74.88329,97.684512,193.108603,320.287461,357.124483,359.625372,308.961647,216.239199,226.12599,308.474996,432.521963,504.582609,508.80372,432.741014,322.438895,328.870416,369.146523,358.619314,363.402291,396.442913,389.893832,285.2566,187.061228,-8.309235,-42.511358,35.224551,196.22169,287.91536,412.325193,400.377001,268.68675,224.338768,234.687224,258.878664,281.203201,363.151196,402.399761,439.790424,422.654431,347.003622,335.069944,380.502996,464.432273,513.653989,569.984908,556.255358,369.524195,205.889348,-2.214532,151.323725,259.266917,267.745932,215.518127,193.994428,193.02323,170.848905,191.614423,288.01854,408.415967,458.62297,465.549308,428.035808,336.090783,301.868107,320.572536,423.261577,467.980549,514.713125,494.287501,359.017658,279.443532,173.98418,167.881488,226.925774,284.40427,289.548439,241.491291,190.526317,85.243557,55.143459,48.553946,67.075228,67.517292,53.22953,54.650888,30.191239,-43.032085,-212.890127,-216.637465,-99.512481,-71.764267,-86.974301,-69.832344,-64.493946,-157.937291,-228.238564,-277.180983,-172.323969,-95.481456,14.059991,18.228334,-79.825563,-160.996593,-290.289146,-292.838562,-160.161616,12.849342,47.643449,41.816474,43.92543,58.341161,76.302404,156.264166,143.964654,88.194569,27.775285,54.078129,117.001961,92.823708,-45.837477,-92.604515,-69.354968,-15.756,-31.792027,-122.810915,-158.201823,-186.825309,-178.134581,-110.979699,-98.633556,-135.838533,-209.24683,-194.421662,-87.958142,-64.731106,-65.066879,-32.758355,100.184967,132.337865,64.016936,-109.215283,-151.687628,-150.066364,-143.283689,-162.700998,-223.459938,-242.564889,-247.604425,-268.703589,-342.471499,-366.927008,-388.932278,-387.426648,-342.553867,-275.109293,-254.426548,-227.428827,-218.269309,-229.513105,-232.99663,-175.875438,-65.930084,-30.854096,-45.646027,-61.29653,-101.850189,-172.513297,-309.399973,-295.315355,-175.664749,-47.005747,24.916779,70.091599,20.054873,-89.846845,-76.813194,17.219341,0.420671,-22.683468,-41.68389,-50.75001,-116.738899,-189.668327,-290.850576,-243.788256,-26.921778,84.323414,75.832873,30.945275,13.611648,-77.355965,-142.222812,-186.656295,-92.24731,-25.297882,31.803676,-9.681345,-212.163754,-337.168967,-453.889826,-385.251579,-137.398695,-11.506076,5.067699,-35.540802,-78.525704,-150.949298,-179.985163,-229.181077,-237.974934,-222.066547,-179.293497,-175.911013,-276.217273,-367.737136,-472.950286,-461.426583,-429.773061,-392.759587,-326.849877,-219.943295,-241.927591,-356.746996,-378.274179,-305.169663,-131.784886,-36.23571,92.672413,116.91187,75.901895,6.333658,-121.834171,-115.99316,0.782497,60.383176,54.099816,32.133648,1.589137,-144.283664,-211.699093,-160.610624,66.059707,150.975306,204.516315,193.829144,136.652865,85.05786,-16.386077,-31.726472,-18.101917,0.58888,-0.612263,-55.779083,-78.537937,-30.539637,23.095578,73.236397,38.807938,39.924909,79.036588,93.429624,67.868852,6.80946,-148.4245,-191.960284:44.990038,140.787836,174.207515,125.868929,56.737848,-63.697209,-86.035811,-57.716461,-8.337491,27.748652,89.209061,56.310459,-160.646628,-268.339948,-312.40848,-258.970932,-87.085628,62.327861,67.41079,-16.072832,-39.910459,-37.751503,-42.906559,-81.984098,-94.970356,-69.032744,2.481878,22.195434,-22.325202,-92.862223,-206.81762,-189.05342,-29.268106,111.795712,136.826586,123.876678,96.446193,25.864403,19.314813,62.340282,101.436289,145.715006,181.15678,96.468655,-180.182842,-281.582175,-344.078753,-336.56,-286.727974,-187.800439,-154.205676,-205.575975,-300.10712,-506.793577,-535.76847,-431.367024,-299.124573,-244.93282,-162.892876,-145.014051,-180.766108,-229.449822,-302.717684,-297.174791,-165.897814,95.086568,209.909379,289.549212,238.287004,1.512555,-103.32387,-111.196555,83.512727,183.236073,271.014846,251.924946,129.176401,52.043132,-55.596766,-74.299278,-32.775146,98.089102,157.3384,224.131216,230.578266,151.465676,95.567538,71.054488,113.327209,119.184934,86.606341,55.188258,-15.866406,-37.728987,-21.137249,6.381117,52.017784,110.124274,144.436638,165.53604,141.56757,66.383214,50.658498,82.105862,188.359175,251.117665,285.821418,251.641631,140.659212,74.432712,-7.444785,18.452841,157.127477,245.574709,220.8931,47.305043,-48.631072,-155.90174,-146.353664,-46.684333,49.381139,106.545108,203.257106,188.020815,20.590407,-73.47188,-168.635554,-183.760823,-190.67954,-105.943493,-47.361948,-20.489951,-69.746438,-200.679265,-211.456854,-99.360069,45.077993,120.019969,274.365492,333.243258,337.162069,283.571794,194.741207,201.447833,332.198306,504.522491,537.681113,482.187294,443.30842,431.582127,443.455774,475.055645,547.496957,571.651064,516.060934,437.779004,253.90184,185.929591,153.257051,174.307241,210.372066,261.185874,304.227655,324.196831,275.197647,132.537859,95.010497,140.562853,237.815951,275.015923,312.685454,308.764798,251.331917,199.654289,110.826124,113.923063,249.001559,441.744711,499.373173,496.004759,451.704614,282.265615,174.451001,64.602291,208.315766,310.354854,349.311648,300.629322,184.511768,102.663675,-9.567111,26.162129,175.081347,264.463187,283.289018,260.982439,234.255376,175.904761,148.722694,171.606844,320.868863,386.563138,396.115491,356.181478,275.262493,241.441149,190.773829,185.588236,226.19426,323.556927,349.886269,300.289215,262.253404,198.682212,167.898425,134.263027,110.271435,112.722459,174.403188,182.470876,57.563312,-45.831534,-167.12263,-146.602467,-29.070374,61.217182,89.826854,90.646365,47.064193,-91.24272,-137.703386,-141.86324,-92.840259,-50.100639,60.397432,94.288123,56.382335,-1.35721,-96.312791,-110.521429,-51.338615,98.733025,147.646709,182.880432,205.731543,207.703604,182.233192,198.368215,244.996316,227.30866,164.820588,157.087952,147.975664,110.127542,28.096052,16.515608,44.702656,112.349515,114.798084,4.747678,-71.868377,-184.199651,-204.177434,-178.596408,-144.655417,-125.119744,-60.573239,-26.436976,-32.073246,-84.030361,-154.104734,-132.833544,-17.7794,84.258916,60.375119,-152.830441,-250.849463,-295.091498,-270.279855,-198.363396,-160.431091,-181.497475,-287.662692,-343.475733,-363.828686,-334.225215,-299.761349,-288.522898,-195.244933,-110.104059,-127.146252,-183.290462,-186.982825,-222.490963,-249.669645,-199.982257,-51.991076,17.40039,77.036569,57.882241,-47.865291,-118.937198,-186.620442,-151.961675,-30.95862,64.539771,106.948149,132.332186,83.024308,-104.324051,-157.138073,-80.423022,72.998539,126.06676,127.733494,80.090963,-39.930916,-83.503078,-85.390072,-49.144281,44.22089,124.509741,135.776919,103.058534,73.869833,-39.860622,-88.999691,-33.133444,112.350743,160.899276,131.131311,53.955088,-145.356989,-243.064935,-307.029934,-249.708458,-137.293493,-130.159841,-102.036409,-0.652391,7.81925,-92.11144,-140.802491,-158.79,-161.96232,-177.659815,-225.272014,-251.674262,-352.599348,-445.542278,-601.635443,-600.370771,-458.190617,-247.225028,-159.199349,-135.105892,-211.255881,-401.787048,-429.866577,-297.968256,-123.207218,-83.77469,-61.578971,-44.256099,-20.223384,-40.700655,-83.549155,-65.325605,43.963215,168.922028,199.985165,181.274556,148.095818,42.822799,-17.730899,-82.104817,49.026722,181.375541,377.222236,380.409522,208.723157,85.040082,-78.161962,-95.081846,-71.486048,-49.991586,-40.59602,-55.485807,-82.609655,-88.185687,-42.836351,46.94564,57.44597,78.366939,126.812504,112.523954,20.00583,-49.659071,-191.176117,-210.139711:41.191603,156.975892,205.554364,242.380546,230.596947,135.023523,72.608199,5.266387,-18.366198,-2.714199,86.411215,95.902008,-67.691113,-197.444151,-323.528859,-275.269926,-46.762771,187.008984,258.798606,243.688875,163.701153,-20.756724,-51.544769,43.480442,117.60971,141.030568,260.016932,311.776732,244.859553,145.649574,5.63792,0.461432,57.484384,170.57648,224.103261,179.326134,89.51616,-64.838457,-82.875187,1.766372,80.280992,73.088913,-3.565772,-48.888145,-158.088332,-240.796988,-373.693165,-374.086111,-330.165601,-323.540176,-293.8093,-215.571779,-222.578504,-320.752677,-357.996539,-344.551754,-257.013812,-183.61327,-33.822938,-4.398417,-31.088264,-57.716702,-112.786832,-123.18274,-46.65696,120.530886,194.187102,249.604859,223.285412,74.313936,-18.948824,-104.436465,14.380134,101.49796,205.514626,207.182013,122.414869,43.83263,-120.396941,-145.296485,3.042934,246.940965,313.347253,279.49575,224.756841,156.04394,138.148456,113.62886,156.751927,213.584724,281.000931,254.815741,148.602021,96.062463,12.124014,-7.31639,8.159501,99.601057,144.242505,139.592574,88.964262,-57.776545,-107.19911,-71.535489,73.965453,148.948601,203.333168,163.711008,28.345076,-22.425229,-31.904379,-0.415926,70.747424,134.015659,154.407117,93.778231,13.939543,-128.221136,-157.196175,-133.8514,-14.5073,69.349891,133.515009,75.75323,-81.459716,-127.198756,-166.335032,-161.315633,-91.472753,-8.557681,6.617273,-22.967327,-50.443695,-126.22522,-174.599904,-222.296474,-93.393481,17.599932,167.463679,193.332187,193.217351,157.068196,94.738902,109.147738,170.451852,289.860425,391.960237,501.542926,440.980407,221.493067,169.025152,245.932413,392.58374,434.109623,399.146517,326.521517,182.563548,140.995957,96.383694,97.015561,150.880619,187.241581,196.30953,227.479907,221.079914,98.466559,38.895973,114.838365,362.827277,452.654112,468.403431,436.695891,432.213716,446.134131,427.226794,412.489945,428.845955,489.386556,521.999832,554.989645,538.703887,373.949034,225.671618,6.307365,162.844419,307.841066,375.906914,296.85319,141.111747,83.097861,-2.651268,3.057475,111.945141,251.928908,298.602859,308.838916,286.73031,205.006963,168.792525,217.109346,356.216046,398.844738,454.387881,473.546462,427.269667,369.107266,282.861971,274.726281,332.325418,446.58023,465.104685,354.079284,265.492346,176.954198,199.618207,281.109251,240.348336,192.432495,150.29986,152.956312,116.025705,50.023249,-74.817533,-70.546144,19.758359,55.693649,46.433378,15.330264,-2.15891,-92.475457,-155.452092,-214.065386,-153.999654,-105.8214,-49.082012,-40.593041,-69.644349,-133.099637,-287.805834,-299.850956,-142.385925,48.601898,89.613995,68.758909,34.016315,-73.743772,-125.312806,-99.088378,19.544249,54.924341,98.87599,115.030286,89.5777,53.303709,6.753153,1.742167,24.10602,84.562631,68.958982,-81.436239,-163.571566,-298.304321,-340.833275,-292.015054,-176.857616,-153.53782,-101.890366,-52.775591,-52.665793,-138.612103,-270.039552,-239.511319,-105.715632,-61.687621,-77.218949,-168.084415,-230.347229,-334.400808,-351.720577,-321.041222,-311.484778,-311.081517,-320.858286,-354.249145,-439.141259,-458.827719,-440.047498,-412.288359,-348.434907,-289.705922,-271.797739,-267.097946,-277.392853,-308.195245,-307.277887,-223.77488,-85.832084,-46.183467,-91.050082,-144.46745,-186.12469,-189.266738,-224.997356,-221.341239,-134.994229,-47.397375,-32.746592,-72.499466,-106.194204,-161.302714,-187.668387,-185.29072,-50.870362,23.015654,84.917301,56.647806,-88.347533,-168.435768,-244.237156,-215.527699,-68.471909,76.060956,92.838836,-7.845721,-65.976056,-92.262866,-64.468453,25.930629,114.864651,160.852678,187.732723,133.250253,-94.137194,-211.938461,-281.370416,-225.15916,-63.386713,65.740916,88.864312,21.913812,-34.360602,-124.306513,-150.494329,-168.596611,-194.503328,-202.32894,-185.480054,-174.437426,-228.051037,-319.962176,-538.567151,-589.963416,-544.721317,-377.945372,-282.812558,-206.674219,-239.298648,-372.393153,-429.548003,-419.229642,-306.918306,-245.202165,-96.95587,-47.333784,-88.751095,-147.267895,-206.549402,-191.972308,-120.823687,-7.085272,33.7384,23.528311,-5.234064,-113.609721,-186.498767,-196.685541,22.650778,130.981196,235.341281,236.037802,161.967568,83.955806,-95.119236,-127.284371,-98.24415,-100.77727,-95.886694,-67.059027,-60.447356,-64.510105,-69.003169,-97.102344,-104.807404,-59.863524,43.246623,39.655549,-85.663933,-171.148066,-282.224539,-280.21909:-20.824688,195.181701,244.755299,204.015942,151.967251,12.580113,-47.3551,-49.057321,55.068912,93.952331,74.232058,14.158063,-167.825343,-254.998426,-311.459822,-272.192418,-97.71594,154.493669,249.726535,272.099281,217.196723,75.915267,23.092987,-12.856236,52.998386,127.336877,250.593932,250.420027,134.712422,61.675158,12.707905,33.617545,92.934327,251.047894,326.462788,260.131726,148.79953,-26.357714,-53.141698,7.648765,116.469237,135.034787,41.782993,-33.644731,-201.902879,-321.683507,-505.393271,-497.011845,-350.880451,-224.259423,-200.713095,-212.405667,-238.626833,-334.481863,-383.002635,-406.168512,-310.945169,-225.124139,-56.628777,-19.974514,-75.020887,-140.620957,-224.972647,-215.868305,-99.145062,115.23748,200.889729,195.361119,123.116174,-54.103536,-137.002345,-167.969365,57.830403,190.211154,335.643774,348.064912,272.080306,180.95015,-4.940748,-27.408203,134.925279,385.95897,441.48885,378.107228,305.615423,183.098466,155.550934,158.477815,221.615932,272.933843,316.083748,272.221922,106.167692,29.863004,-54.080206,-54.055659,26.383142,145.810345,182.647713,176.527246,128.696746,-22.004562,-59.561487,37.162286,183.823761,210.999861,163.863633,122.284393,59.929473,12.426742,-60.360384,-23.126224,141.529397,212.195636,180.452772,10.226289,-90.804357,-201.962925,-189.343278,-108.326574,2.413574,85.882098,194.498712,148.175681,-96.129221,-204.798412,-286.288388,-267.141619,-151.431196,-18.062602,18.630006,-1.596874,-51.65804,-210.525452,-286.606212,-289.751147,-65.861486,73.039454,238.791245,242.788509,129.085964,31.210764,-79.336516,-32.110447,171.845714,329.7773,383.348797,410.885953,347.526652,144.050303,109.772209,264.113368,453.618892,499.090989,483.853061,403.673456,138.830261,35.473213,37.06513,102.876934,170.263878,177.398293,197.66349,192.72217,131.583157,-80.552431,-156.556822,-59.537892,295.341335,450.538727,504.134416,415.277409,213.718453,163.48081,144.612384,148.804504,230.244631,397.94105,442.587721,449.405178,438.518804,347.278724,268.331549,152.070607,194.646949,264.686689,361.48517,349.612737,181.04547,40.546477,-139.752494,-106.904599,107.201469,282.892682,304.26889,244.122295,199.171373,106.537563,81.576893,178.560227,399.970908,473.893194,517.01418,506.442897,408.975873,338.181586,267.298097,292.475697,410.101411,523.634711,555.213136,502.301886,419.35601,255.057243,233.59777,306.413067,367.878097,359.854853,307.920648,288.733618,205.200412,119.780595,5.075261,29.920868,137.597126,169.820306,177.694847,207.452756,188.895142,10.362598,-98.446015,-198.018404,-110.597327,-1.874805,197.491842,203.406531,3.783871,-129.34223,-226.200448,-161.502187,62.049478,253.694223,298.826692,245.241291,177.757183,56.06012,25.464886,72.855075,186.519021,235.025863,283.003532,273.460035,180.498438,98.178936,-28.455638,-17.333915,137.047315,260.055903,235.726701,41.482368,-77.856244,-275.752581,-310.178316,-213.0091,-75.793341,-25.069123,50.127346,51.846628,-102.522231,-231.611119,-341.500013,-283.267538,-110.822547,-33.685324,-56.54027,-215.6685,-312.141023,-433.573217,-426.334384,-327.660351,-306.086547,-322.967422,-330.599025,-316.905883,-300.581231,-324.262832,-389.562983,-388.616767,-286.985292,-138.469113,-112.501133,-166.267991,-210.079225,-304.927701,-333.537591,-249.901185,-39.672836,32.763307,46.785243,17.671282,-94.718635,-196.241412,-326.967217,-274.877909,-50.046454,70.902734,76.069159,26.059361,-29.546184,-214.695651,-280.898418,-208.751241,16.202542,110.431659,142.691019,90.975802,-44.348374,-114.804257,-187.151967,-160.627601,-23.813236,128.193888,158.017559,100.20907,51.203289,-47.910161,-74.195195,24.391339,224.840536,278.188,222.063043,143.753985,-50.033381,-170.235246,-306.428438,-257.30889,-60.742293,33.014932,28.000355,-54.865536,-116.620515,-220.735413,-230.730559,-179.155206,-143.451079,-117.0947,-34.691752,-25.268634,-182.941919,-338.990873,-595.883276,-605.68164,-440.442146,-281.289895,-233.654395,-210.808523,-255.852415,-454.32486,-536.640753,-505.655997,-321.162097,-246.34127,-182.786242,-170.218198,-189.869426,-238.68657,-280.30758,-225.471601,-29.173183,128.365273,140.894377,73.718186,40.282346,-51.327087,-118.115469,-182.179906,-17.81867,119.585078,304.336877,301.471371,133.834282,4.429453,-203.008801,-214.97841,-89.763258,24.033284,29.130785,-47.446444,-89.541226,-125.130696,-124.490491,-83.359772,33.430701,94.410633,115.845224,67.235499,-79.348617,-141.112088,-178.13066,-169.084875:36.283441,117.794878,152.344365,199.605752,206.10751,110.83278,20.331275,-79.967914,-39.440949,-2.035736,74.573126,60.008197,-128.572585,-223.651652,-293.172736,-288.329474,-150.612781,216.84615,376.474925,428.273813,378.720515,271.921401,197.807211,113.891914,281.854347,404.47314,527.312281,496.315967,332.342904,264.896447,213.585902,195.488351,195.375538,343.063464,390.06728,289.973246,201.661007,63.269756,20.815504,34.785929,126.037096,139.24665,43.38638,-25.751254,-92.807195,-110.481923,-207.64234,-269.855414,-312.07341,-133.478103,-6.660968,113.192792,93.966198,-32.777487,-107.125523,-144.77837,-5.197303,68.817348,183.371621,220.345644,198.538413,149.942826,89.139891,96.393187,153.16574,258.498695,319.998712,405.993047,415.508245,274.378481,123.760069,-99.715248,-36.812939,30.951604,98.270348,104.031425,57.473568,-10.373335,-126.303424,-105.781445,50.112774,154.628542,169.973327,203.991947,242.384103,279.53317,247.252007,186.474553,255.179932,306.129857,313.925621,268.803318,154.994988,82.683915,-62.495182,-86.038572,-38.29835,45.394911,88.274901,99.267018,58.965922,-65.065159,-135.565425,-222.092516,-70.783858,76.152506,172.003331,58.259394,-184.920829,-220.14833,-198.690061,-164.754687,-46.339896,94.971566,139.471777,110.271159,55.24909,-76.85309,-136.426896,-154.885743,-63.58911,-26.248592,4.534369,-7.656164,-122.506587,-203.876458,-269.196159,-237.65308,-151.050263,-92.636198,-78.737012,-71.126883,-62.049206,-84.242685,-135.199821,-228.584488,-162.84069,-66.30258,82.000029,88.773115,33.01288,-5.868232,-31.985952,6.519476,106.428785,183.456035,250.595674,349.770541,288.859043,-25.772585,-160.499353,-193.755256,-24.956898,57.545081,120.324026,78.507988,-88.842248,-150.604326,-174.581988,-159.779903,-85.931963,59.705745,109.921908,52.856904,-5.486038,-33.27832,-19.568881,10.969214,158.393516,286.222849,424.590186,395.290561,354.940626,388.308325,413.106657,396.123552,420.409263,475.877915,464.824612,382.468695,348.302482,272.825023,182.267929,-37.566061,11.310335,150.877176,323.244421,272.825979,74.039765,5.137943,-14.789734,35.504833,140.178826,171.337985,222.766366,349.706389,342.873087,186.293516,115.338619,152.376668,372.305974,460.876928,470.379734,413.215164,347.463492,353.442862,311.962432,254.35279,158.660425,182.852392,231.892582,244.384803,169.163174,-14.633754,-33.916548,87.033435,124.139606,90.397413,109.577279,171.871571,219.34478,141.773873,-66.378024,-96.662738,-34.724863,52.134034,91.830076,127.637116,87.870212,-104.118974,-191.77399,-263.167881,-244.382355,-211.210866,-120.798858,-86.427315,-106.076838,-184.551084,-365.441237,-367.020072,-192.108647,-20.188902,34.103275,89.551099,101.579609,31.221354,-66.424155,-196.097027,-95.191239,-3.15389,116.408797,117.507164,76.827598,64.403137,63.289624,81.450216,143.306041,199.075884,197.657437,73.661188,-32.217704,-243.016826,-304.650493,-277.554997,-173.495403,-120.264731,14.047771,69.252667,65.908486,-2.694852,-211.342611,-277.261578,-196.102426,4.511425,62.953366,73.838062,44.533371,-94.900787,-192.54018,-297.923564,-262.826156,-234.436802,-196.578987,-195.270085,-274.061111,-359.330719,-453.058735,-437.262012,-439.286078,-415.321651,-348.444387,-233.641607,-232.319349,-340.160276,-407.621284,-366.538458,-87.323121,-4.994928,-96.668133,-182.193973,-213.659193,-189.78856,-192.871288,-201.903084,-156.495292,-40.673222,23.310337,94.263717,65.234904,-119.804863,-224.105626,-304.412926,-200.129195,-119.862725,-18.467583,-39.181563,-184.702964,-265.72263,-372.866326,-385.263203,-311.785325,-127.179606,-59.561662,-123.431726,-217.581479,-342.166016,-337.007882,-194.203181,-16.377734,33.544287,34.252711,-10.720139,-156.196868,-233.642937,-321.100213,-296.741567,-115.502361,58.936868,80.476012,-5.646359,-82.39617,-237.202509,-286.850586,-316.488045,-294.797465,-277.455382,-255.179408,-242.86923,-242.660474,-301.144255,-531.841684,-618.414093,-572.070664,-363.489869,-289.623126,-267.031895,-313.344915,-490.948575,-558.341188,-478.746333,-302.204295,-262.208251,-168.522936,-87.674431,4.209849,-34.16317,-189.62689,-227.463355,-188.285137,-96.054397,-44.17498,-3.815193,-36.298344,-181.276307,-247.946234,-223.759934,-10.070842,110.873722,256.765158,257.740324,157.113115,93.106695,12.115741,-7.7516,-88.833252,-130.476535,-60.144026,115.817799,126.009824,26.036616,-8.104549,31.050207,108.187927,121.856293,68.424595,16.832479,-36.221401,-42.229205,-92.878849,-124.788268:35.642666,152.01545,201.669735,240.889587,202.150036,-32.577867,-164.898185,-210.583585,12.998866,113.01779,113.404729,25.048326,-207.010133,-324.885987,-469.904812,-432.178965,-82.056377,364.406233,485.522595,448.821884,343.014435,133.819141,70.206076,64.992946,228.43141,345.474364,525.493745,535.288859,357.495772,219.375875,57.92475,66.097299,201.595243,434.474242,510.77073,413.266499,272.705705,3.252915,-70.530414,-54.743708,75.790414,126.829254,106.952558,29.54733,-201.50839,-322.860446,-470.282213,-470.034017,-370.661408,-221.230604,-151.642753,-83.773612,-103.676346,-257.269253,-347.424423,-379.177663,-141.254494,26.146943,236.882605,234.57709,104.145761,10.96076,-146.421973,-159.235418,-34.077627,195.789469,304.691967,384.079008,312.325827,-24.469469,-198.204697,-296.704891,-31.360818,131.444965,293.473319,280.113644,120.799996,-6.875845,-210.415306,-197.074371,75.685091,373.778215,428.588623,381.24669,340.520907,227.652999,159.222139,158.358637,316.823781,381.45543,407.4975,363.484472,170.026357,44.100331,-123.268152,-122.840192,-2.353801,175.252583,245.314617,199.509026,62.67143,-227.371106,-269.72374,-134.683188,89.208766,181.910443,244.853467,205.123907,29.880838,-76.065754,-190.603975,-159.051104,36.122171,227.034354,252.545411,134.317216,21.714036,-208.142304,-273.467154,-222.472917,-3.4487,108.93253,182.358605,121.677998,-130.845894,-278.561474,-428.300325,-386.819605,-180.919191,-5.788874,35.52971,7.319206,-57.462987,-239.431122,-311.346833,-292.538435,-85.751548,36.165609,186.491643,171.819208,-11.771028,-133.115623,-270.845435,-245.695984,-53.363456,224.489994,346.455108,402.466213,307.308621,-5.186228,-102.286904,1.514443,254.946965,329.94976,326.509835,243.470399,1.541177,-85.368929,-101.194535,-49.643391,64.266535,139.692519,162.418649,109.787821,13.929807,-218.446894,-261.98609,-90.208299,208.578236,326.277155,452.733311,446.806955,297.331745,185.742992,55.863909,81.570056,243.679367,438.846841,520.83926,555.510539,487.67216,232.897636,102.021982,-4.866602,180.663616,326.389234,463.046007,417.253174,195.857044,57.29893,-122.621445,-99.802025,104.770005,283.044032,329.405936,350.869183,312.364642,134.677419,53.097333,75.069503,297.377298,403.158293,530.211625,559.283875,519.597493,439.637354,245.010344,186.394641,239.770781,487.097103,587.017854,508.383452,352.208027,94.725405,77.59856,210.657847,347.673851,380.898098,363.906807,320.488725,171.849617,58.523113,-119.055404,-107.712292,43.76563,156.466545,186.456261,163.062052,86.452015,-138.990563,-227.200868,-248.884157,-107.762913,-14.040811,140.861359,153.703887,-14.32968,-170.917585,-399.282984,-372.294322,-77.027512,237.66942,319.513964,268.098163,154.761982,-121.943128,-216.510023,-172.057028,67.152813,175.97353,295.165166,285.547427,118.794129,13.24222,-73.313958,-43.906029,111.377523,301.193212,331.158643,149.003991,-30.410566,-381.575209,-462.349149,-328.987094,-97.138484,-26.544125,63.797488,75.864074,-57.722445,-198.226999,-417.628576,-413.316084,-212.689427,-5.491821,29.45964,-79.223325,-193.219744,-388.387674,-423.206074,-394.565114,-294.320878,-215.552994,-141.179111,-202.193552,-406.726697,-464.847785,-425.8996,-372.788925,-304.534599,-223.681783,-168.472723,-140.286997,-201.701851,-420.63844,-502.825466,-399.577076,-34.594144,94.02397,87.776777,0.119016,-169.681238,-233.390142,-306.954876,-287.807308,-124.748856,91.354109,173.178879,174.216046,59.70519,-309.671542,-449.418357,-417.178712,-130.595849,-5.626376,98.874051,64.192694,-141.910115,-270.485152,-421.812899,-403.185901,-216.066654,-16.409129,9.288091,-91.153371,-171.170961,-304.679921,-311.246087,-145.905495,77.049943,164.466082,254.201033,215.722634,-55.565114,-233.156995,-400.547832,-332.967542,-59.161383,208.587843,290.91317,189.733156,32.438371,-244.622992,-306.390122,-289.574353,-150.695386,-62.020626,60.714479,45.680619,-197.515202,-382.302565,-619.815432,-604.092071,-401.015197,-174.132616,-119.62721,-190.270958,-279.511611,-456.923036,-503.796252,-440.273498,-246.211358,-144.316617,5.15903,17.351681,-107.703462,-203.070022,-318.255519,-302.655866,-132.245858,91.460082,146.300867,80.726979,-16.779771,-261.508383,-334.853499,-242.710459,-3.999128,106.169249,244.045932,237.548175,76.804697,-52.763846,-248.760398,-241.697946,-102.302504,14.781627,48.393301,1.161983,-79.962782,-210.704063,-205.911916,-93.803373,60.835784,147.341374,200.095898,122.357731,-127.825467,-231.375286,-304.370425,-270.988741:-136.884614,-45.150018,38.301451,132.503159,126.506929,27.440786,-51.934288,-173.49899,-187.756529,-158.7234,-54.532606,-16.319668,-37.28725,-78.636214,-152.604637,-183.802715,-165.748625,95.192623,231.773093,288.090839,231.684472,102.085766,61.88351,65.826611,159.582845,224.466949,352.647759,378.337688,309.756154,248.551734,167.152617,165.268028,220.228267,295.210994,325.032994,330.523595,321.302739,278.047083,214.300944,59.009744,-24.946412,-32.414624,36.068173,83.991725,112.394975,79.619001,-72.094025,-149.637262,-167.704593,33.18013,170.346526,375.03613,400.380775,256.07786,133.771005,5.74201,79.017357,138.26718,207.43015,216.450831,221.700887,215.212139,193.159826,185.317893,135.885151,133.294884,209.287696,394.430059,423.584009,289.674458,158.653781,-71.166902,-117.57134,-73.764057,29.005298,41.899776,-5.067184,-43.070476,-113.147849,-106.528132,40.790119,204.286924,257.416978,367.324722,405.562634,327.499837,224.356886,80.229228,129.094588,187.658361,273.897748,265.810734,83.177866,-70.735394,-320.443031,-360.128656,-282.994826,-169.475836,-181.029981,-337.973667,-406.726679,-412.861304,-389.707827,-376.053426,-325.737544,-270.065498,-200.523107,-220.502903,-283.014882,-290.815527,-330.408487,-359.15065,-265.402236,27.979194,137.128908,169.77263,137.210965,36.009522,-36.209946,-148.387765,-149.661148,-126.040892,-60.484345,-45.896702,-118.326847,-187.40589,-287.700574,-287.433658,-214.870733,-147.347194,-121.741536,-61.99183,-38.208478,-58.882,-102.224062,-188.870215,-166.108131,-82.657518,101.166092,116.859757,20.183319,-18.854855,-17.090276,5.365706,44.189582,94.021669,135.314228,125.720432,26.505694,-247.868179,-339.920719,-365.394544,-288.712654,-248.753819,-174.567953,-163.2474,-225.659727,-275.86529,-358.214136,-363.650571,-260.352722,-137.343942,-131.461946,-225.678567,-282.316824,-330.262795,-321.838072,-251.831329,-112.34283,-41.302009,50.625433,69.911174,102.705932,104.029579,44.399914,26.055951,38.175211,20.708627,-2.652578,-73.190793,-95.67161,-74.095694,-80.400241,-212.784169,-286.589574,-207.583655,66.03808,122.749855,-38.968933,-163.681979,-199.044863,-72.341688,201.366721,179.420256,144.385765,231.582106,275.616467,110.51277,-35.916582,-68.470342,169.24248,208.680417,104.280553,62.22752,93.073271,113.788782,31.802872,-64.005729,-178.701591,1.346468,126.704384,135.302007,20.241677,-143.492723,-124.139713,-19.280046,-18.092733,-16.738898,102.417925,181.306615,222.318985,174.210238,70.69885,69.753542,154.48108,232.52372,229.843359,136.543386,91.647371,70.392499,73.767433,42.650133,-74.596975,-121.994491,-74.023952,2.094222,86.562185,38.677295,-160.58669,-208.763748,-109.292182,94.722029,185.097413,231.827332,184.913169,54.493063,11.517815,18.419262,52.617475,64.471178,168.26589,238.68567,274.582892,249.889865,234.037173,255.780208,327.150172,426.999171,442.998385,252.599009,86.912142,-117.245734,-114.626297,19.178494,104.570842,80.336068,96.536429,187.180139,275.584942,184.247233,-71.672129,-122.361278,-81.109911,-29.689957,-15.910618,-16.711332,-39.539981,-132.135068,-200.814629,-292.596078,-168.557622,-62.048749,18.661431,-39.901665,-199.500522,-244.575581,-275.482421,-270.031552,-234.888001,-192.434862,-171.360363,-128.564645,-120.612598,-200.47037,-249.346124,-159.758688,99.748503,174.185961,120.863773,53.957769,11.700984,29.065962,14.734812,-14.612875,10.453976,160.76506,218.61376,233.227249,194.339522,24.600023,-59.048787,-74.107061,46.301397,102.524444,131.199935,104.253159,13.802285,-54.732055,-204.781219,-237.00802,-190.676985,-170.051478,-192.568883,-179.597366,-131.345786,-92.437165,-115.841855,-91.966944,45.614791,103.071929,111.466187,65.259478,-41.636165,-89.197468,-161.100371,-168.466701,-128.111533,-26.500505,18.296118,12.860659,-39.898548,-187.293895,-244.264628,-314.258444,-296.689814,-233.69824,-146.963663,-166.032968,-251.136172,-293.883012,-406.410162,-471.27105,-535.280977,-428.216181,-342.936192,-282.536553,-314.878277,-391.255879,-418.381497,-421.245433,-330.603958,-275.609298,-171.815451,-122.230561,-97.056699,-135.56005,-234.5914,-262.81402,-246.275497,-144.039396,-96.082619,-74.505431,-106.815554,-237.971101,-294.466451,-257.849014,-96.917648,-39.31627,-20.235732,-27.579267,27.90219,65.353322,73.92081,65.369265,84.949173,164.238533,219.208011,290.399817,272.013443,166.389621,137.278644,155.343256,152.282065,135.529962,99.212948,77.26868,44.193615,29.057697,-24.405479,-34.780571:-79.306806,-12.993847,93.439849,255.550451,252.38999,104.461266,12.41874,-102.483211,-68.049715,-12.128071,82.774513,100.018294,78.946655,38.816192,-110.854056,-170.607523,-76.184538,220.5134,324.639707,344.096616,306.579016,224.31217,193.815006,208.710144,284.67891,330.99758,422.601659,444.489865,423.765759,375.386917,206.746713,142.854137,182.33473,294.761123,299.305049,242.09531,225.304264,203.781078,185.01274,147.220266,83.526089,72.683379,142.762492,187.398462,187.532444,125.30113,-54.418661,-131.961827,-229.099107,-124.979427,15.313459,220.037737,213.212997,54.678498,-44.461634,-172.386495,-117.811099,-40.488628,122.667454,167.977064,170.32853,160.146999,159.27578,154.881839,117.148697,159.317089,241.488424,446.486315,511.988844,438.868503,308.054948,19.412516,-127.155287,-110.575159,65.03979,134.923479,50.989212,-63.149727,-162.150215,-80.085615,168.154108,196.643542,179.042108,260.865358,307.450715,251.42153,195.238217,171.618509,201.7626,233.127201,332.763704,338.799058,183.268237,55.065637,-141.658139,-142.005344,52.143308,218.06281,195.43221,15.727647,-41.845703,-46.694007,-55.419101,-138.749465,-170.341354,-133.386284,-56.36703,-66.208035,-187.924102,-263.863858,-328.054935,-294.682016,-148.907086,35.608409,96.633669,135.992254,132.805088,30.176947,-58.056644,-169.137145,-178.596281,-165.395778,-77.418623,-31.871957,-30.649438,-69.119245,-159.032556,-186.527396,-191.46431,-157.080908,-132.564068,-25.280849,48.917049,68.878193,-15.086809,-149.246139,-42.205922,40.231125,105.329716,81.410315,12.712682,-0.506541,14.276694,19.521418,9.188566,85.746094,154.488109,199.943214,150.633413,-30.859344,-128.322756,-272.135656,-319.099576,-310.735454,-283.8457,-294.182948,-347.980776,-376.466284,-428.793427,-427.029762,-346.900293,-240.017342,-194.264192,-137.24014,-130.231761,-181.485275,-222.442643,-195.153792,-41.429244,4.1346,41.01316,62.616487,85.026702,75.7776,77.067938,103.212262,153.177852,170.53974,155.520581,82.601406,63.914114,52.631735,14.42686,-101.14502,-95.461233,-35.417421,69.356897,70.15434,20.118597,17.479225,90.364321,148.673069,208.169866,181.618546,207.426258,332.360169,350.822656,234.244339,167.578026,171.062574,287.530441,316.541605,207.821621,103.956779,11.742037,18.331919,-47.686892,-113.361327,-181.371151,-103.730717,-46.710246,-81.390877,-174.541244,-292.316489,-241.509137,-29.738593,-66.654872,-170.41248,-231.152979,-156.7207,-42.990962,-83.646119,-227.228816,-247.04389,-171.054624,-87.408234,-91.611941,-137.27198,-133.15671,-100.789841,-121.067347,-244.959077,-332.289867,-320.966055,-181.626306,-90.726756,-49.140065,-130.338711,-327.486055,-353.585054,-254.091299,-103.176176,-54.989972,-61.579289,-74.21022,-64.428374,-82.167257,-153.701678,-187.784884,-168.466673,-3.080614,106.757574,212.510256,199.403536,182.531673,207.485415,241.685576,249.607392,254.959546,183.673067,107.224886,-43.173252,-81.36821,-45.548526,13.939322,30.331476,95.979606,134.433852,148.308189,98.321389,-41.963756,-65.154798,-18.974913,35.956928,63.295324,68.566333,34.172332,-40.592415,-79.889594,-210.360451,-266.07556,-212.486725,-94.723387,-110.316153,-226.914207,-277.214026,-349.084783,-367.903471,-384.016148,-352.64184,-313.822589,-240.499164,-202.704231,-164.904665,-183.991537,-167.426599,-27.443684,4.180588,-60.261089,-105.043252,-80.343429,-18.601529,26.518868,-6.391808,-20.804255,98.079387,154.184498,204.119589,206.258129,150.89163,108.862918,73.842273,40.446619,29.631879,48.078369,57.340681,39.270481,-16.074308,-200.214606,-250.301081,-181.71043,-93.076377,-93.216802,-91.318927,-55.614312,-10.95057,-40.476904,-116.636341,-78.997901,-28.87745,-4.61238,-50.826297,-162.913476,-214.063776,-323.268734,-343.80909,-291.67194,-263.398319,-262.682425,-248.997293,-271.24868,-419.132839,-489.539484,-522.472584,-494.091557,-463.044951,-339.526034,-279.535302,-284.021013,-359.168444,-525.404108,-559.003258,-531.805434,-429.977598,-362.00213,-285.541898,-311.932271,-439.647429,-473.494921,-417.091757,-340.545319,-307.185701,-145.087901,-33.302377,75.434841,55.397155,-49.518975,-106.702237,-179.376557,-123.72454,-54.352559,40.36451,22.856621,-103.181004,-164.330542,-196.600421,-53.587898,58.798079,226.955464,255.797989,263.861213,254.70599,184.727089,156.018068,175.866586,260.672008,298.936532,318.494963,305.566115,279.686889,284.021494,337.504715,356.7689,329.223878,242.272751,202.197842,139.120029,89.315481,-73.859973,-137.261653:-45.494899,20.106922,80.599643,125.057747,88.797716,-59.695973,-134.163784,-180.646854,-103.53383,-58.246806,3.68793,-4.127835,-136.796875,-236.332656,-361.367023,-338.016843,-112.912059,157.737491,251.692225,385.775669,414.270427,320.568948,235.417882,158.340278,207.796018,247.418483,338.490984,362.336584,312.284869,275.150071,271.267304,294.81704,334.415302,392.528929,417.640153,345.607151,252.730282,36.990799,-34.18517,29.823192,165.248057,153.485995,47.142384,3.58046,-89.063887,-154.868573,-284.495142,-321.793523,-280.457366,-71.036904,20.800951,61.058049,52.825844,21.655623,-19.68415,-89.513442,-60.512503,-1.488509,173.595011,222.789819,147.659603,82.917298,59.293249,88.913405,147.520544,251.839803,317.236592,338.690573,266.264805,-10.190465,-145.418523,-208.587969,-78.407758,-1.646416,109.61942,103.89893,-10.181825,-84.299211,-178.021166,-142.540386,78.200431,236.918072,252.718173,253.641711,253.901269,176.235522,108.892748,77.262849,193.339073,246.935296,251.722526,182.49346,-48.877328,-163.697153,-309.522493,-311.872052,-194.926676,-90.041488,-82.866224,-197.059472,-290.406954,-391.511497,-390.038841,-371.019642,-254.186413,-149.23805,-36.217172,-51.336667,-117.767288,-160.470558,-264.792729,-290.662851,-223.451613,-14.551456,90.443884,175.587503,129.901261,-117.985422,-233.690859,-263.132177,-126.662578,-38.507435,91.651278,75.135678,-151.721653,-286.948468,-373.133239,-319.909925,-190.49864,-95.700457,-55.799076,-95.002376,-157.994674,-226.881512,-249.96454,-338.06221,-290.801134,-163.337986,108.402222,145.356396,30.40319,-43.989878,-150.869618,-168.755105,-93.376246,80.572677,159.425529,200.665548,165.518252,-2.503102,-110.753821,-215.961556,-131.138995,-61.488505,28.65618,27.215121,-27.50888,-78.395291,-240.139079,-288.469936,-162.603353,74.708376,103.680502,-50.648557,-147.832925,-237.371638,-225.05773,-92.736878,61.940499,121.240991,217.51498,231.296114,196.19991,158.500043,64.77641,71.525953,230.425589,298.099327,266.975173,172.488794,133.704738,80.582561,39.298912,-69.281591,-48.432982,20.694616,140.698274,157.386609,82.207345,-4.477658,-151.12472,-144.784274,33.198536,211.832322,247.323318,255.777175,238.971131,116.933424,36.616267,-8.576238,66.37334,108.021882,208.143161,251.009457,288.395356,262.544099,92.437525,17.520154,54.796469,263.292481,344.831949,303.631638,197.239731,22.172949,6.066301,81.586448,155.010827,164.216961,209.928353,255.016211,275.122333,206.032411,-0.212932,-43.52331,52.862909,209.596528,257.302983,246.285362,188.207535,37.635604,-24.772292,-77.986619,-40.06848,-7.141275,73.894029,97.198807,7.484853,-92.113797,-212.181001,-177.378417,-3.176053,150.444281,210.965499,248.145549,201.127414,15.515098,-70.770977,-84.040856,124.357849,241.138563,324.59534,270.047075,117.542567,85.769727,90.022554,99.372342,170.989884,313.08786,336.504787,154.125442,-7.940271,-239.726759,-261.418214,-171.285336,-66.469797,-18.063375,136.813253,195.751299,121.492711,11.1259,-182.020211,-215.320364,-126.772193,51.039369,98.645308,57.697154,-7.920167,-170.644499,-236.431841,-257.280096,-167.459069,-123.143859,-90.895962,-110.517203,-202.541151,-245.12872,-268.589389,-256.009471,-252.374865,-263.59835,-222.434991,-91.185719,-61.731173,-143.539349,-206.75578,-181.640106,-26.106087,11.579533,-3.018999,-21.950804,-61.022862,-89.948469,-139.833763,-126.158018,-24.39998,49.433342,69.809901,107.66158,100.254735,-61.731909,-192.597895,-342.016362,-229.695549,-130.475407,29.714331,60.213857,-55.328681,-175.476883,-316.371367,-301.445952,-211.604003,-103.854171,-63.643334,-153.596008,-250.02912,-324.924504,-291.803923,-190.416294,-92.564466,-27.972561,66.878674,50.230607,-76.261011,-144.659303,-207.745738,-161.965115,56.858044,227.932231,258.284117,209.378964,136.652851,-37.847715,-104.934629,-148.036501,-76.373426,-12.119584,39.09026,-4.163611,-119.714071,-188.139325,-364.280244,-413.362815,-364.529878,-231.064195,-186.863711,-207.253762,-248.823452,-371.676282,-435.771835,-413.143146,-204.017857,-107.395275,-12.86573,-11.313483,-76.296623,-141.701786,-269.707446,-279.593606,-198.953195,-119.801024,-71.289182,9.406009,-20.695855,-213.214288,-289.472414,-251.876783,-98.61484,-56.96349,-26.881346,-22.881377,-49.056509,-86.081342,-163.116344,-142.335442,35.088288,153.460695,145.040139,71.134172,37.731959,-5.589623,2.72542,83.413464,120.303747,118.169971,110.512091,83.490732,-25.172155,-80.348811,-159.544817,-156.5367:backward
-171.193627,-202.17457,-164.707733,-41.504544,5.326313,16.476569,-2.880135,-33.152909,4.681396,68.485678,183.718055,190.382287,134.65899,96.994387,23.999368,-5.875067,-27.434816,96.259664,172.705174,178.134391,113.693752,-14.03679,-17.900213,96.500001,121.028176,59.498042,-36.526382,-13.425974,69.423015,57.427231,-48.546288,-100.839376,-179.810123,-104.483918,-13.790167,114.675895,141.864178,173.752632,175.256359,98.667554,-76.162993,-130.063097,-71.475245,-1.932683,63.993634,50.779089,19.789398,14.495291,-34.65543,-129.767121,-147.972102,-79.50716,-27.257246,22.230518,24.827618,25.206002,39.449399,59.566288,94.261749,94.729586,69.866852,37.595689,-42.265783,-62.979193,-84.493754,-75.434136,-55.874523,-62.535871,-93.11569,-189.035594,-231.488667,-225.636617,-99.105297,-14.29385,107.549772,128.804408,101.125614,59.666546,-22.91632,-43.783153,-76.509732,-145.265113,-167.820871,-138.671152,-111.532976,-83.473209,-73.236008,-77.551737,-81.792611,-52.840066,0.877148,7.425111,9.103095,-0.932853,-65.00888,-109.200079,-188.639323,-190.688725,-136.803818,27.789263,83.077674,86.987512,62.383874,16.4261,-8.649638,0.731475,53.435226,72.066453,43.391667,7.520228,-31.389495,-26.327665,-4.419553,4.342936,1.4958,27.407677,62.259848,81.525803,57.99011,8.069248,-54.888472,-75.72289,-29.951886,16.567016,41.12664,8.679809,-33.304036,-18.51638,17.877322,15.345847,-6.368572,-61.66323,-73.542691,-68.87248,-62.982282,-64.692686,-110.574037,-125.793245,-103.583524,-91.117362,-93.534585,-95.921025,-90.356467,-91.028614,-112.762208,-60.13153,-3.008758,62.611544,44.358983,-81.634621,-132.307388,-121.633591,-75.787465,-58.767287,-49.673652,-66.414999,-69.051363,-44.299097,-39.879876,-78.999487,-139.324161,-56.26411,-7.610783,-0.776364,-11.968887,-3.028483,-11.748797,-113.875696,-181.362485,-140.596376,13.798424,69.217421,99.68582,84.787775,7.08952,-45.397538,-127.253064,-129.596478,-103.147196,-11.738478,36.935091,45.180755,-9.063512,-152.333737,-220.414678,-203.981146,-92.030247,-25.071862,37.599232,15.086973,-78.0611,-113.135143,-118.170332,-39.86256,20.399585,158.667216,206.09955,179.898802,136.136251,111.686514,105.82585,80.66938,70.610911,105.470155,162.939071,137.524639,7.262432,-52.775685,-107.337939,-26.552547,36.416362,122.732355,136.660441,77.669855,27.608043,-15.750358,20.05873,53.609936,109.83794,119.552581,72.466471,22.115005,-50.577128,-53.487031,-9.913452,20.257979,-16.43197,-164.268462,-203.520644,-156.588363,-123.775519,-165.641187,-260.707061,-265.601294,-252.43735,-274.784055,-319.262469,-300.37589,-188.1231,-147.093577,-170.128349,-138.952067,-67.27894,34.719556,24.840992,-82.11306,-136.051994,-165.196344,-113.623273,-68.845172,2.939168,16.841502,42.452437,58.789052,86.827802,97.760206,83.227204,73.353804,99.667504,163.080092,168.329813,65.635039,-16.660003,-87.268569,-12.439673,56.806572,189.308271,203.560894,120.142181,77.259248,62.849033,64.053744,21.759484,72.263614,166.45852,292.901238,249.983725,32.99023,-57.486042,-98.687318,15.076462,86.612024,164.586768,177.490912,199.701192,192.210784,140.884275,128.077851,140.210965,172.762684,175.951942,165.190863,188.520116,269.255808,279.203365,207.711179,81.638049,20.715797,-99.538029,-140.110719,-142.340955,-142.57714,-193.868598,-208.64564,-141.279198,2.961141,58.715549,62.334855,10.419128,-88.716255,-81.212645,19.193914,77.091839,105.907207,211.331417,238.288509,148.464812,61.803686,-77.2403,-94.632656,-29.870725,16.88297,4.679395,-52.070599,-77.067471,-77.673781,-32.003003,79.640323,52.87869,11.345074,-36.972915,-36.298395,-16.421885,-31.882891,-129.348187,-186.416434,-240.578061,-146.943272,-73.195678,31.180857,30.694172,-72.254149,-126.822072,-196.658718,-282.720866,-295.408526,-265.939747,-274.820449,-367.397413,-429.622947,-453.545889,-395.701323,-256.180985,-145.25243,-87.441708,2.195161,1.584976,-88.616058,-134.806694,-151.643652,-70.136137,-20.152777,-29.245586,-92.653134,-190.726646,-180.111749,-33.064008,44.168462,42.576986,-36.911848,-41.115867,2.994187,17.972241,-18.832554,-53.592289,-136.460784,-199.353437,-159.895442,31.207479,100.024582,67.457853,-1.877683,-82.675698,-77.084701,-40.484269,40.258237,92.899217,193.612195,229.788603,171.598953,82.243189,-54.746666,-37.947076,10.129977,99.410505,141.733092,282.551151,351.159933,373.544376,316.482891:-95.710925,-81.034776,-47.395812,7.222948,0.221605,-38.896991,-57.250899,-107.253699,-39.831593,75.171455,320.667277,378.2297,347.392462,311.521774,259.973173,217.322006,94.984647,80.1516,105.995403,120.70651,111.570305,94.427951,87.91247,90.364635,147.618565,176.959831,166.084253,130.546356,64.685766,53.227048,52.292977,23.599628,-74.758373,-29.689353,49.096753,180.800482,205.19576,200.06002,181.923913,101.698598,-6.972136,-37.108424,-3.508065,39.257151,50.447946,15.72888,-7.848361,13.609709,13.005071,2.988044,56.33985,171.774645,146.546557,-28.162523,-79.268529,-44.928183,-8.663538,-23.498714,7.037744,76.319508,149.95841,106.655351,-20.378582,-49.939372,-49.538578,-0.175853,21.219637,-29.913972,-86.728379,-166.557546,-167.925644,-107.348022,-86.559761,-74.604249,46.422471,114.343093,93.371439,18.185071,-90.400039,-113.090139,-143.355115,-102.958826,-59.223639,-39.47873,-88.892887,-204.200133,-212.97669,-167.854784,-133.059688,-104.130913,-51.085178,-38.25852,-9.078852,5.960778,-12.743949,-62.166104,-198.81992,-244.707955,-216.701464,-80.798276,-13.517787,-14.219244,-62.016277,-132.565325,-125.859468,-88.863354,-15.351747,-3.401995,-35.870419,-74.369598,-117.638102,-104.763028,-38.08959,19.71101,18.521109,34.813982,74.161938,98.942295,52.140594,-83.538219,-106.388913,-60.76784,35.907361,45.03987,-28.080979,-67.631345,-45.808194,-8.76181,-2.598564,-74.085098,-108.1333,-93.878154,-56.490318,-52.671007,-90.972124,-184.708999,-203.768029,-163.18462,-70.414834,-55.614125,-89.84875,-111.965323,-120.358784,-121.087316,-120.506125,-45.854485,-10.302893,-50.418095,-124.080369,-276.847604,-311.396875,-276.403214,-192.345436,-151.680566,-55.147199,-9.760046,20.152614,0.953886,-90.246696,-151.827743,-203.389883,-88.987169,-39.490621,-35.639462,-28.066597,48.051248,60.467871,-29.585182,-80.447143,-31.534063,108.958477,136.329704,93.587996,51.828632,-44.011197,-109.868844,-235.176091,-223.137532,-172.697552,-104.038321,-114.761558,-163.259372,-189.903223,-329.263884,-424.572779,-369.034522,-154.860754,-60.378801,11.350326,-28.910646,-212.021814,-303.620524,-345.717876,-233.174388,-176.6025,-98.069919,-68.000976,0.577517,29.394251,-2.198237,-125.679075,-153.287034,-82.251354,-15.625934,30.257231,-25.215518,-178.309855,-217.019062,-206.239554,-103.626322,-27.359712,94.865966,103.847069,50.606788,35.981092,35.801192,57.005812,99.7213,176.282089,181.969597,113.226948,40.645942,-102.323536,-155.095027,-201.1227,-112.85665,-72.957871,-138.598018,-201.921858,-222.86037,-185.835112,-152.01582,-233.688402,-259.74444,-218.543439,-175.669869,-98.048515,-71.025289,-27.80778,-25.752583,-65.965669,-26.934995,20.268169,73.724591,72.926732,31.883866,3.471144,-31.767536,-21.329304,4.119139,54.036067,66.338185,79.073599,77.162992,80.446865,110.342019,198.542255,224.2932,214.973194,206.892032,203.153582,116.646365,47.300973,-30.262472,5.310627,64.751646,195.703692,229.795131,231.881819,199.522557,55.476322,-27.287427,-55.366328,135.511741,205.181329,175.21191,129.621043,47.979953,-9.192226,-143.858968,-126.743536,-33.545962,160.175888,207.597184,226.127464,223.04598,194.690277,155.295931,71.940322,109.648386,145.236825,135.39659,114.762439,129.687181,134.017998,34.746576,-69.871429,-82.244616,-110.932475,-123.804391,-134.263458,-163.205094,-233.236952,-235.633924,-158.59391,4.617398,82.937826,145.849495,116.643464,32.335378,21.302229,23.76112,18.561756,42.926876,143.949309,175.359851,153.640965,139.275884,87.323731,19.992761,-81.24208,-72.374634,-65.458534,-26.865113,9.04937,57.768002,72.899413,85.277367,73.14694,78.576363,87.772129,68.138944,-10.028599,-54.401763,-144.46222,-193.293027,-237.216874,-79.443559,16.210603,64.386764,28.608179,-65.183511,-110.438735,-213.434205,-278.685848,-275.380647,-256.94549,-259.082966,-292.543728,-327.680719,-364.372668,-330.573825,-207.139672,-110.990164,-83.911447,-48.536181,-30.773235,-1.528437,-7.608263,-99.980781,-148.598747,-103.623283,42.580566,94.359007,53.451186,-22.810446,-104.011353,-91.041413,-73.207576,-68.107419,-24.978317,115.634291,147.585599,52.621036,-35.365222,-157.014151,-150.514498,-115.733865,-33.032016,2.189521,-5.147885,-48.045105,-87.629293,-59.894922,15.646048,83.567207,122.94973,180.39309,190.123633,142.979605,74.081797,-99.075608,-164.517161,-129.3507,26.857252,109.249474,179.141849,152.938728,60.058885,29.369031:-30.184205,-32.003576,41.816811,149.216745,136.670567,30.230581,-5.76511,5.509424,107.236928,201.387492,414.199981,464.78867,384.468411,306.708017,220.216933,203.458515,140.163343,108.318861,129.21433,180.829732,176.057907,107.194491,86.93867,116.873151,156.350817,160.650265,150.242692,149.396098,103.573419,44.757293,-33.687408,-47.949171,-84.591556,-31.48539,32.218479,152.443717,203.733778,257.106296,234.121901,132.058115,101.376002,106.31987,118.119375,136.015347,165.456043,157.454438,93.62018,43.181083,-28.340613,31.489312,98.577871,173.836594,144.483082,30.001478,-0.250385,4.994499,31.238457,59.29009,158.093463,193.801647,148.148497,82.531127,-28.32968,-65.342385,-109.056945,-55.514685,-11.29744,16.710606,-3.769234,-82.104241,-122.192988,-150.009502,-102.911019,-72.200151,13.440308,70.942209,122.471858,75.022421,-125.272125,-201.012577,-175.468087,-56.436774,-33.002896,-44.072243,-61.521224,-125.469504,-159.337337,-175.78087,-107.611085,-46.239934,93.942378,135.785225,86.115833,20.852942,-86.841018,-125.812203,-195.131114,-226.697905,-212.723794,-144.702756,-110.74803,-89.530111,-100.55391,-108.865985,-70.773111,-42.889452,21.118498,50.995283,35.334641,-21.286091,-114.831124,-109.176314,-21.556943,44.814223,39.176927,27.876282,43.528085,55.991934,42.666471,-3.754392,-24.713608,3.529744,110.823595,151.494391,142.490542,104.506448,45.939412,23.183506,-44.966491,-77.41838,-91.716475,-135.304203,-142.701284,-178.672722,-224.728535,-265.351086,-182.498993,-150.690568,-142.41815,-146.952819,-143.689919,-126.868093,-128.97893,-187.104989,-325.647785,-278.807285,-205.240156,-125.33527,-147.977293,-247.432801,-279.301122,-292.075312,-268.342209,-235.577299,-101.428561,-25.026279,9.050816,-44.940132,-195.804792,-251.535383,-246.86076,-132.853289,-86.167777,-25.292491,3.436091,24.885659,-3.003822,-118.607937,-140.569911,-85.511232,35.702288,69.465544,86.763309,68.519642,-6.586164,-49.550232,-104.410724,-82.922981,-50.624773,-9.44889,-37.928183,-171.565828,-242.770212,-368.216802,-357.637353,-286.819072,-180.221707,-171.166859,-164.777476,-170.159611,-271.432481,-350.655967,-398.118975,-246.449414,-161.832372,-66.103314,-59.186162,-71.446607,-56.282701,-32.719629,-127.751566,-174.651383,-135.806249,-63.134109,21.09517,-16.114123,-148.752617,-182.756136,-173.863667,-111.361933,-71.31462,12.888335,37.780664,21.579081,14.750747,44.220961,89.416677,126.47551,176.569573,171.543186,93.733534,26.145417,-100.31064,-147.675629,-188.268158,-146.038802,-137.060785,-178.897196,-203.762207,-232.716899,-242.233774,-269.712659,-270.219084,-238.146919,-165.937682,-148.551211,-124.608168,-120.604829,-162.130164,-190.751284,-182.047082,-66.9059,-11.329,18.149276,-3.865064,-83.827186,-122.84153,-156.753735,-127.134946,-95.849698,-11.545268,27.18361,35.359946,10.352221,-13.74255,2.271392,47.991065,52.916904,58.42564,118.942587,146.5286,87.327831,1.934312,-133.935691,-47.915422,47.078348,153.375295,138.024123,62.587863,47.08635,32.76803,-6.813331,-112.628326,-69.756167,0.532671,70.017667,41.176139,-39.365182,-62.296629,-126.240864,-100.721933,-13.004749,159.404278,197.690258,204.962466,191.346792,130.311509,73.971396,-20.715909,37.180497,95.250389,159.05742,161.928256,156.616812,139.542082,5.187663,-132.278382,-141.254753,-96.734122,-64.975566,-52.475015,-88.635983,-166.31843,-171.101624,-88.560298,16.236935,45.172208,86.266149,105.563762,101.008105,63.451188,-10.574403,10.63605,41.840227,111.191773,152.272267,201.520241,179.917162,42.925669,-35.977524,-92.943357,-35.514718,-15.974571,-8.451072,-4.378306,27.01766,47.17451,26.074652,-8.853567,16.422055,71.15894,77.42643,69.935029,35.864888,-133.000716,-213.816181,-229.907125,-124.026821,-64.489297,-6.127091,-34.90701,-134.82706,-159.826373,-194.602123,-260.840466,-262.502613,-183.963365,-150.204881,-174.926187,-209.852049,-239.340111,-232.851598,-187.899788,-96.643474,-50.620364,31.270419,59.351743,56.604718,34.151437,-18.032373,-14.066419,19.912236,109.864566,157.308837,198.103934,152.309375,-9.358002,-59.505331,-30.01028,89.38359,137.951178,157.537734,111.787105,-23.478021,-48.938353,12.17889,67.446892,53.182863,19.328246,50.109224,122.425011,91.407056,-40.106239,-60.411393,14.880063,73.388977,86.262805,185.517403,246.977321,169.317556,25.340041,-206.032025,-168.731336,-96.950142,-9.046981,-4.901539,12.165034,43.895574,75.240665,41.605:-44.504577,13.090752,62.012284,132.727668,140.316811,135.39369,136.644446,93.947303,66.699989,122.781673,241.327561,245.762435,229.122347,226.919696,163.91226,103.505428,35.137505,155.932445,220.128286,179.051944,106.89753,40.52098,72.545273,161.807663,170.231364,165.714747,170.703674,161.27507,84.878657,36.770031,7.625232,24.310576,26.599668,26.743657,60.300165,142.785204,160.989328,149.80315,131.361296,57.503036,-55.576437,-88.731769,-28.000589,48.111328,102.834968,53.525396,-13.750598,-0.690157,-40.992901,-140.495521,-130.882251,-31.423476,5.336843,34.895702,47.519396,55.595556,61.070074,88.189372,126.04545,112.314102,66.316466,51.545989,27.947785,-5.400619,-134.579431,-186.243576,-149.279889,-65.856926,-63.871349,-139.164589,-171.169602,-123.918012,17.421974,79.176559,120.065303,113.064484,100.676595,90.766756,55.123215,26.109145,-54.102455,-89.693703,-73.182198,-15.292802,-10.191057,-80.568822,-123.395328,-144.271691,-41.060804,49.43275,165.683956,151.090949,7.636024,-83.529483,-176.875615,-163.751204,-148.074877,-179.774779,-161.196631,-60.625859,-19.275435,-22.722442,-48.290135,-67.524621,-47.465366,-33.732937,-0.399769,14.96955,35.679239,46.980138,52.273472,42.439512,38.537797,59.203613,56.012736,35.892173,48.750233,89.979156,71.973107,-25.992039,-27.522855,25.924999,112.127393,100.672514,37.645804,35.715541,54.670848,28.793617,-69.626632,-77.04438,-62.02651,-59.643048,-61.54742,-70.134719,-69.810438,-56.550184,-72.226406,-73.180228,-48.545441,-33.396873,18.164119,42.030792,15.716864,-30.354773,-104.870405,-33.319114,40.866902,91.079544,39.378517,-116.150103,-160.139778,-150.816065,-96.748266,-81.490129,-129.754736,-168.835117,-133.700505,-75.970976,-75.989308,-145.23719,-231.76304,-142.434945,-107.375906,-108.613666,-94.954193,-78.809434,-129.155717,-273.361324,-237.207009,-132.055849,114.099491,186.65347,184.091401,141.094009,52.765895,14.418439,-50.088937,-63.681205,-43.461967,31.53673,47.132785,-48.719569,-130.096933,-211.581733,-184.460669,-169.996337,-120.263998,-59.205006,42.888006,16.537718,-142.362335,-195.798405,-180.428006,-83.61543,-27.847652,87.546657,131.999124,139.903068,123.785331,129.955531,112.553866,89.645547,88.159235,119.720157,162.903198,123.324503,-30.740861,-77.610148,-88.143153,-46.741542,1.335972,116.892452,133.009182,46.088179,9.596954,55.930816,158.491119,189.47063,164.8445,130.508372,79.435949,42.910495,-69.677894,-117.585709,-148.325229,-123.279883,-115.900635,-168.393268,-226.732557,-291.034382,-268.014299,-234.793828,-290.891238,-282.428769,-173.245151,-138.269,-207.191912,-276.218621,-316.088552,-289.503682,-263.240121,-202.40458,-138.724173,-34.801794,-21.39476,-57.775116,-78.406126,-117.042684,-155.407274,-144.670053,-101.622208,-92.634962,-76.647087,-79.832425,-124.094931,-121.461585,-28.247201,41.711018,46.394352,70.300409,92.735097,61.269109,16.987365,-52.125253,-94.878805,-61.232003,70.610382,85.478527,4.047074,-34.893037,-62.014968,-73.463524,-81.919456,8.853533,59.765622,117.581842,119.371464,37.300465,-21.102363,-74.787396,-29.104406,23.346025,145.231784,192.221893,220.49239,191.548166,95.426239,66.459072,85.441394,143.700385,146.43869,114.963159,116.418639,173.2294,194.528055,133.824516,-17.31384,-64.932024,-69.15766,-51.346157,-36.464043,-44.327413,-47.409196,-38.244971,-35.358587,2.501008,44.323661,45.378282,-19.005236,-104.510179,-63.047004,23.972371,-40.724141,-39.634253,98.129242,143.475512,56.905251,-20.332387,-118.00861,-141.742798,-120.803797,-58.089693,-62.731385,-93.301609,-96.586153,-117.876588,-123.860538,-87.08679,-29.311513,-11.227956,-18.462963,-20.23305,-20.170622,-67.728953,-249.703545,-320.712112,-324.235243,-193.762152,-131.233892,-91.623411,-115.232598,-184.067514,-207.116654,-266.361678,-339.968854,-326.591751,-252.994689,-256.613859,-335.087026,-372.259576,-379.975563,-345.966172,-254.708584,-176.486992,-143.48144,-55.534192,-4.338405,21.896313,-16.573331,-96.897037,-31.302557,29.769863,67.660242,55.246582,27.951633,0.435205,-19.948033,21.581652,128.462366,142.14207,126.113089,128.038996,147.032732,111.424297,45.249075,-81.8936,-78.459062,-7.668441,173.334664,223.843727,171.824512,88.957154,-52.647015,-75.116182,-20.460801,113.787299,160.118408,167.388456,148.812791,75.419056,11.008235,-147.509139,-206.369813,-153.203068,6.045732,48.862107,103.489261,137.238243,125.837845,79.423236:-83.821463,29.704846,120.355127,212.689823,185.728653,58.817887,23.229312,54.945415,115.757669,154.437505,238.318574,248.51022,182.426725,124.609716,20.439475,-11.838467,-15.971849,63.746068,110.657043,176.275727,168.774997,77.38164,59.740734,139.987945,205.867278,193.981548,137.100511,121.517894,79.486647,49.837068,29.311764,10.93582,-68.268424,-8.116384,77.056503,220.909053,257.82201,247.299288,186.357365,4.297448,-70.342337,-46.663828,32.105492,69.05609,147.847556,162.195264,64.915033,-17.949138,-108.839646,-36.260199,11.491396,46.581832,39.598214,-12.511308,-38.794153,-39.950362,17.1258,72.393138,204.051042,230.275082,130.212973,42.913112,-69.312097,-95.557811,-156.405516,-192.506274,-177.648426,-121.882199,-103.240998,-105.976301,-122.340875,-161.535906,-143.218842,-83.251888,68.789772,126.875855,174.915466,142.614348,13.265453,-28.923281,-36.784625,-37.939243,-38.167856,36.254515,90.205733,86.436492,6.092499,-169.056042,-71.579108,53.576601,181.868655,166.460665,99.369248,70.104294,-7.598004,-64.391099,-135.28139,-133.740755,-154.518547,-179.451827,-152.140902,-81.465316,-63.977994,-74.190332,-62.135686,-15.879438,96.625569,122.873504,92.603619,62.209941,25.338984,11.00893,-53.581758,-114.001432,-110.504811,-32.97025,12.712853,63.25103,61.087903,-22.437923,-41.09453,39.182434,211.006464,220.494456,102.812491,44.905572,27.789859,19.14221,-77.348281,-89.166176,-51.230743,-18.618355,-36.284611,-79.34744,-82.998922,-85.165752,-113.495621,-107.591043,-25.865295,21.808526,67.401692,63.378046,-0.505023,-69.574879,-198.891697,-144.531527,-66.734892,60.200556,64.515039,-71.135871,-161.623836,-266.017355,-252.215432,-197.656275,-41.360588,2.903845,-48.18056,-119.308504,-247.630862,-264.855494,-145.322542,45.499253,86.300645,39.606275,-14.188267,-104.506823,-138.640703,-169.457873,-75.291754,-7.417223,79.667937,108.950842,173.043892,183.241234,114.057892,49.768351,-38.246693,0.602746,29.823071,48.487137,36.832203,-31.014405,-90.065368,-233.236102,-256.727073,-212.632089,-116.167854,-67.535229,-1.813104,-15.40877,-90.61471,-130.171119,-194.553935,-133.423209,-51.188429,69.261091,64.862478,0.559721,-0.240345,11.231922,-82.911814,-106.437573,0.293953,87.981577,132.291815,72.514947,-60.120568,-102.640006,-151.413458,-63.509195,13.964642,110.384066,121.814252,71.60387,27.390671,-3.592082,69.159847,115.516635,161.972287,163.303017,123.654378,72.419117,-44.264575,-95.666331,-191.055946,-214.342979,-189.879861,-165.249909,-191.598027,-231.486815,-198.391628,-144.585232,-203.004427,-188.561896,-50.01008,-2.587028,-76.752448,-167.053042,-268.499282,-272.899098,-279.594942,-230.540949,-181.413079,-78.545152,-28.413755,30.412371,23.153586,-39.617035,-90.290172,-95.646443,-48.357669,-9.346397,-13.338076,-53.654759,-63.846911,-33.035052,6.525006,25.85402,43.774993,89.597626,87.857727,28.669988,6.295761,-40.13706,-82.714739,-61.903139,38.507932,81.959348,62.026009,-4.366445,-102.323567,-98.963659,-67.941835,-55.62026,-30.476582,44.953061,47.005155,-41.58751,-76.045642,-68.318032,-27.89547,12.191569,113.302616,138.120682,115.518636,96.527851,133.728351,177.709414,209.649106,186.70557,169.029164,113.82961,97.214632,118.29723,121.092994,24.166298,-66.856815,-57.756876,25.729052,89.064566,160.759376,116.372052,-12.597955,-36.334857,-41.792419,38.295518,107.851227,171.240865,136.844559,12.317176,-30.61327,-80.835392,-65.723799,-7.710793,119.708619,150.695718,143.036085,108.346218,-8.296087,-64.06558,-82.341237,-36.087111,-29.943912,-13.773109,-14.422139,-54.76774,-65.243068,-66.955297,-46.05381,-22.483516,-5.472894,-12.711221,-33.797218,-65.003262,-218.977419,-304.26507,-327.506013,-230.673264,-209.58674,-199.325037,-191.66699,-173.652122,-167.367248,-220.208075,-288.486292,-266.316347,-149.221929,-114.035727,-151.225159,-182.568328,-184.448159,-181.81663,-231.592645,-206.72253,-124.461056,44.072714,61.610038,-6.867871,-39.358236,-91.792897,-121.006023,-98.066617,12.157122,73.17181,111.955485,79.833416,27.410214,22.28826,20.8691,64.234022,104.095745,193.401518,209.06383,107.20503,14.733971,-133.323919,-117.278756,-30.795179,175.952559,232.659713,193.233108,123.009683,-9.386764,-48.610642,-21.582349,108.531215,127.797888,81.808716,76.166259,42.657267,-32.101209,-214.571567,-273.245018,-245.6928,-99.283246,-11.378537,92.248236,105.063243,99.455931,94.734694:-74.937042,-66.510076,-23.243731,113.122706,167.309645,184.119957,154.726218,86.639157,61.461871,72.621251,89.729254,91.878235,108.26242,106.039556,80.081708,83.250546,121.856846,186.610175,210.082706,165.985865,105.204782,-8.629189,-3.683117,111.986691,129.985812,95.337263,20.247098,1.784925,28.168682,34.301328,-79.561254,-172.896647,-230.716069,-31.397286,72.133057,125.244409,115.480053,121.640958,107.176783,-16.361335,-159.229947,-176.520503,-67.486764,16.098584,72.618342,37.987017,-20.985232,-43.794142,-158.685198,-218.713179,-172.393755,-53.604938,-21.759457,25.490097,52.870745,76.054849,113.853519,151.31472,145.935313,102.697295,49.192347,41.942172,-28.672241,-101.059422,-212.838449,-180.492676,-135.36377,-84.705109,-99.20441,-188.289478,-227.014458,-202.885941,-69.223587,10.805897,163.712006,204.939883,193.734052,167.640737,93.873607,47.781422,-18.956419,-41.433833,-54.848265,-75.867346,-69.946925,-66.591315,-79.844892,-66.130494,55.876311,113.496168,126.908749,94.122969,7.286605,-51.2047,-179.973608,-210.998186,-204.04871,-195.483157,-199.421379,-150.160914,-82.161451,0.01057,-10.133352,-26.071617,-7.180834,-0.053176,-27.627185,-40.760175,41.223522,118.942065,239.677816,258.387334,149.714472,-10.846308,-28.565037,56.761041,118.913257,128.678918,63.12749,-43.22503,-2.491312,38.981378,86.386067,82.908737,19.004662,-32.358245,-99.515456,-104.891654,-95.098651,-60.019516,-35.939522,9.542748,13.340168,-29.511878,-34.30851,5.081604,-35.395833,-50.318782,33.437135,78.122135,70.364259,53.630192,36.4584,18.105171,-14.493702,94.778575,183.376769,217.230479,142.748027,-44.478038,-77.614709,9.254972,34.180231,-16.52058,-114.573768,-120.580916,-48.625251,-8.74796,-29.383656,-86.230124,-144.748333,-76.428172,-56.322146,-83.57427,-100.336139,-102.566294,-90.887146,-98.029463,-148.659619,-125.844767,48.501205,129.830367,154.106414,108.561869,7.568192,-11.867623,6.659096,32.930896,32.548754,55.907893,92.915772,114.918466,66.649947,-74.392909,-114.275669,-92.553558,-25.18762,26.756107,111.521315,102.3247,32.152322,22.867028,66.733056,125.885395,175.172088,293.186254,303.309197,212.864767,182.046367,211.800597,229.395066,224.309014,217.724048,221.903166,239.697045,220.940755,121.022906,74.939473,58.788721,152.575438,202.371841,234.799648,199.913882,61.518665,10.519943,52.330773,171.20382,173.192385,70.286367,23.699457,-39.829868,-79.390157,-109.988683,-91.838538,-85.984668,-138.738014,-168.594219,-218.193981,-221.755624,-183.829876,-167.709723,-199.424929,-219.23639,-188.106056,-203.416228,-289.639813,-448.5879,-459.69169,-382.773832,-338.439133,-287.269435,-245.267584,-211.401421,-130.279267,-121.321904,-251.71193,-336.40436,-351.701248,-246.120892,-202.72903,-149.994208,-147.979736,-184.339425,-202.207925,-167.220593,-112.268064,-32.250049,-3.372571,26.582674,105.403527,134.130122,113.049152,69.518492,-10.729589,-34.247028,-6.457591,68.798327,61.940922,-20.311511,-43.976861,-9.972791,25.566996,49.677062,106.086527,174.151359,239.995526,203.523151,63.397204,15.079858,7.834019,54.003143,102.898001,243.085878,292.941716,255.395595,198.107519,156.302715,170.552551,226.092541,291.101706,283.49492,236.164656,261.256081,381.135651,407.490845,333.255272,203.533477,158.911329,68.033445,16.324964,-49.55647,-61.090159,-68.419209,-80.126213,-87.608236,21.907696,79.723547,55.477211,-8.262062,-111.735661,-127.138215,-91.980487,-19.54015,21.703108,105.963696,131.758898,89.314903,20.662779,-75.495387,-54.79225,8.825951,-66.916962,-121.168675,-129.216488,-93.362707,-84.516388,-120.925415,-187.926883,-156.586415,-101.71468,-12.978902,9.69322,-2.795111,-63.642607,-218.287426,-256.045094,-247.81944,-168.494029,-109.594115,-37.983989,-58.404006,-159.816396,-186.593123,-159.649144,-123.041426,-125.721388,-168.792507,-200.594031,-255.312497,-278.774261,-353.288283,-383.141852,-322.535951,-136.830931,-61.064709,-14.325236,-34.805477,-118.105512,-158.838126,-203.209219,-115.777851,-15.655284,100.458801,67.547889,-51.114464,-70.390058,29.74896,110.829009,172.514311,122.63406,98.741465,80.71896,78.821709,24.22965,-30.764528,-100.094474,-62.481249,-19.153642,64.375259,105.621627,169.900156,145.328098,-48.138701,-150.182549,-181.836738,-6.872266,75.506256,132.904839,121.6389,30.471675,-36.066751,-129.07055,-124.565407,-89.832292,-8.475991,42.53545,190.121155,245.102766,236.203472,191.916006:-74.08116,58.688537,111.962519,144.845713,150.746066,164.741791,149.260395,67.348281,29.847301,49.363781,72.905647,51.104688,-23.756477,-61.99219,-112.158706,-109.376072,-1.880991,199.645417,250.318319,168.891005,86.838415,-8.319557,2.622667,81.187699,122.303044,113.618401,64.717773,49.966558,52.841514,39.261727,-59.482948,-104.879834,-80.788,44.212292,89.817685,118.180045,121.055935,104.973335,57.811001,-99.117883,-127.918958,-63.311282,76.060796,99.41514,64.686811,34.722495,-20.118586,-55.781138,-123.178574,-88.78231,-42.207886,33.939161,52.094427,52.439905,42.091435,42.407537,102.626863,135.013936,145.41077,126.621065,55.338209,-3.57812,-155.37421,-222.362419,-252.00543,-148.552235,-108.279087,-98.812196,-94.654155,-75.565297,-76.740883,-47.562278,56.453617,113.234317,185.814772,194.655822,177.087133,151.530934,56.650618,2.536457,-25.927503,34.017385,27.395918,-41.062677,-49.650312,-25.898363,-26.685255,-56.897817,-7.618029,73.625379,201.217381,181.719786,-5.88431,-119.109592,-261.176265,-276.069213,-211.258116,-111.940003,-107.519014,-154.702376,-154.702676,-95.803468,-74.695328,-102.144155,-89.037308,-28.796068,91.078266,115.531425,94.185357,57.28104,-14.736518,-35.216985,-52.950386,-15.643877,8.767764,29.913236,35.011085,21.880435,7.542527,4.07593,25.193764,49.64896,132.980534,157.93174,123.77938,88.471589,39.040904,12.127298,-64.286144,-63.989143,-39.320025,7.477265,27.599779,18.847195,-10.241145,-65.260243,-57.577828,-19.100284,78.70286,114.613203,112.846422,74.220782,11.184928,1.251258,15.950326,143.213277,211.328782,221.788556,173.585715,70.07256,43.667923,19.849415,-6.663347,3.450384,60.561317,68.226889,16.741675,-20.864877,-107.936758,-163.430689,-232.357524,-143.689994,-87.813941,-87.734568,-112.568923,-117.970411,-113.584703,-153.271528,-166.345583,-115.701213,41.978599,111.887291,170.54432,153.707969,63.281661,-3.261362,-89.435278,-5.281108,48.081735,95.808761,93.318406,-12.786701,-111.557052,-252.148334,-190.783391,-123.004515,-27.647888,3.489922,43.227789,32.275969,-52.851935,-95.649934,-94.941803,20.407777,73.161167,126.643095,153.089904,180.889235,156.260601,96.903181,90.698706,87.027263,105.765933,152.462013,207.138312,150.648132,-65.631118,-136.341191,-110.717336,-11.773045,15.348213,45.599666,63.21081,77.867888,62.083576,13.963344,-0.968047,9.762406,51.148807,65.246408,4.876499,-80.849199,-223.75148,-231.552897,-172.106636,-151.621721,-163.844114,-154.229101,-134.326179,-134.38595,-152.099457,-189.402596,-183.295222,-128.805097,-24.228673,-61.818139,-304.586013,-412.795341,-434.605259,-371.195479,-233.116188,-127.865184,-83.292402,-8.269762,11.880388,-36.789555,-97.064798,-167.065138,-104.306012,-50.879907,41.581694,69.728812,32.756422,-45.353894,-189.911145,-194.455778,-87.216425,23.59584,48.976154,79.513328,104.154386,127.183965,106.180202,39.000147,-2.782317,7.281856,50.110848,50.153215,-3.110953,-52.768311,-156.081202,-176.70596,-117.69737,7.498259,64.63142,135.640746,128.412809,34.326188,-5.791266,2.991703,117.224406,192.241534,307.396774,340.716676,341.426407,298.070517,204.471464,197.688544,270.712291,362.365547,366.874539,290.169149,252.113168,251.551196,268.278584,238.327437,145.612168,107.537533,112.246415,159.091789,191.011763,135.656054,18.774823,3.591105,4.240631,55.336474,103.084312,146.434013,116.234845,-3.523102,-46.214773,-55.090803,-9.424686,34.693724,146.31438,179.717894,142.842684,80.60205,-67.179611,-120.060441,-130.539783,-85.55297,-77.925507,-53.380155,-32.912597,-59.475366,-103.73168,-160.215034,-117.035325,-69.844408,2.657649,21.209184,20.79025,-25.736794,-182.068223,-234.597565,-231.206961,-157.239983,-113.087321,-31.611036,-26.326633,-125.840983,-204.070522,-300.051049,-245.881738,-187.622316,-95.818274,-84.468746,-142.429583,-189.327282,-234.91604,-233.891247,-198.171001,-66.746286,-1.051754,29.216564,-7.252615,-94.624088,-108.887791,-130.196337,-117.415982,-45.608455,84.041943,64.331487,-85.956564,-139.441468,-99.479653,-39.588355,8.917672,-37.551477,-51.743963,-31.190925,-15.667211,-58.323343,-126.373756,-250.180102,-231.379279,-142.827572,139.626597,244.54158,194.615465,62.117976,-173.063266,-205.941513,-145.89054,-49.17565,-10.639136,16.756119,1.470284,-85.713564,-133.492766,-211.873233,-253.134285,-193.11241,67.256699,169.347222,194.926242,155.468235,100.596266,107.932804:-83.529482,-106.108077,-103.152282,-56.475557,-11.501558,67.046925,88.351713,125.686184,138.525341,141.329252,128.358149,91.001561,-2.285871,-26.452176,-6.509068,37.582483,148.385937,213.144064,220.774745,159.896849,86.734331,-61.455182,-80.92764,-10.27806,13.99614,-15.729782,-123.121174,-178.86305,-222.437578,-219.303929,-251.332751,-284.521015,-297.089334,-182.598634,-119.916634,-77.563086,-66.979442,-21.334878,-29.753946,-142.474153,-187.4466,-141.627281,-35.270163,-17.215525,-11.520059,-8.903711,-61.213914,-114.478046,-183.723005,-166.496721,-146.186364,-102.284496,-72.528577,-19.466561,-1.181299,57.610747,169.921276,210.261485,172.167532,122.265287,66.718529,48.573429,-16.82469,-51.550105,-96.273639,-94.121226,-80.604786,-91.789682,-133.965699,-255.64677,-290.894062,-221.175453,-55.541425,5.078094,77.747671,109.084197,152.300456,146.136389,86.386541,42.631308,-60.41121,-151.727749,-186.307731,-209.607243,-200.705516,-177.988543,-148.58274,-11.413356,71.655937,57.398116,-12.610768,-48.37556,-109.979474,-136.105791,-187.605777,-223.915848,-306.06137,-280.805382,-209.073213,-14.08024,46.277786,-17.865244,-84.591278,-99.857573,-16.685434,4.721628,-41.275936,-78.491745,-60.674498,-9.817737,91.054949,117.54996,88.142749,-7.398608,-51.564966,-52.188717,14.371838,154.265882,150.013094,39.652386,3.497336,25.111611,59.638428,47.548161,-11.449347,-28.971826,-41.169876,-65.673221,-103.381154,1.772676,56.964633,37.621536,-11.855673,-57.597023,-21.991333,104.883515,132.293424,130.497602,155.865799,140.952143,38.613933,1.410709,8.075409,31.914188,84.235884,123.207173,129.497844,143.144651,134.398621,44.067984,7.342759,33.804607,88.416857,97.592339,87.355052,83.504069,133.13626,179.089371,210.247166,158.052724,3.085624,36.331087,107.531726,172.811231,165.750722,141.59042,123.595212,83.802413,84.732347,76.198672,26.384509,30.802621,111.953818,126.263757,68.592233,40.181197,3.716798,10.372235,47.807955,114.753253,113.999517,86.783246,78.711307,36.103112,-27.169099,-18.007912,95.831898,152.671858,188.612437,179.53993,151.358685,137.758941,106.659328,105.604971,131.200402,164.272757,133.221334,25.83409,16.731862,119.957947,181.204249,157.88724,76.584825,51.659972,60.579536,66.94946,51.754277,41.244156,4.744429,-13.270431,7.470551,36.963091,-0.967001,-122.46905,-131.080285,-27.562683,40.985862,35.325942,-24.601645,-61.269052,-80.168107,-58.345702,-17.139388,-18.623635,-55.987805,-96.551212,-119.261993,-171.892209,-183.530406,-152.526195,-126.345485,-120.975062,-163.870586,-172.459901,-203.820078,-255.917383,-416.135611,-485.717229,-498.975742,-452.364826,-420.649387,-431.676533,-372.503708,-229.589593,-226.085464,-327.19059,-354.142565,-283.753152,-186.231054,-155.627578,-165.08942,-198.085185,-201.850218,-160.792582,-52.852514,-14.468498,-9.366159,-10.499986,29.212005,170.005857,228.051991,221.023041,174.478243,88.376682,12.325564,-7.539749,25.786298,47.325851,50.335849,49.869447,30.80823,16.269578,35.240248,71.883568,92.025867,173.817996,209.417055,162.407963,89.577842,-26.157318,8.411601,88.709755,252.843937,270.524746,233.981297,247.962178,352.414308,392.391431,376.801373,349.060026,368.248199,440.492755,471.193557,523.108748,542.441169,518.753631,438.056508,385.998743,235.10368,165.497386,115.841157,105.010858,39.940619,3.789493,-9.21716,87.826096,138.446212,150.025068,117.904319,65.253732,60.86329,67.403882,111.201508,169.509145,262.397379,223.671658,-4.198288,-113.655283,-175.270071,-116.77649,61.672122,81.17433,22.087044,-79.389304,-115.154199,-210.156112,-232.11562,-157.196033,-50.558596,-1.834519,99.495778,117.25945,58.237086,27.740095,47.420208,68.29725,39.834388,-0.62699,15.861247,84.997869,104.031313,72.435372,57.967518,121.245169,174.250309,144.329642,14.884302,-41.109853,-103.92168,-148.928081,-267.61156,-278.794909,-136.056162,97.801895,169.801878,163.893629,109.485239,-44.502332,-104.338911,-112.270974,9.500786,80.421277,86.223913,34.242534,29.452376,70.623044,79.986205,56.704375,72.757501,153.079621,155.827294,36.348813,-37.477846,-92.739831,-93.353546,-108.496474,-109.06921,-91.174195,9.916704,76.412844,123.320627,89.952319,-18.546613,-64.277596,-89.817401,-50.739591,-45.454856,-73.55859,-90.271574,-79.323009,-44.266025,-17.391299,-86.133984,-83.808385,10.141663,63.048002,163.533775,209.167582,280.32565,296.62467:-221.03676,-203.60612,-113.274096,69.682812,109.507184,103.322823,94.759976,116.821878,138.205719,132.777826,96.011093,80.176605,78.563461,74.444528,40.05781,22.455419,36.556891,173.72643,221.891608,163.418189,98.116968,-36.365992,-99.663543,-159.459596,-115.516487,-91.205997,-75.969352,-71.505075,-98.120645,-155.502453,-298.39409,-345.397951,-365.83503,-195.472477,-54.737247,123.178741,130.875449,57.288626,1.548026,-114.621287,-202.691812,-218.511839,-190.252621,-159.346804,-105.039093,-88.230275,-87.164449,-110.492039,-158.197044,-153.183328,-151.62283,-129.546561,-80.90268,57.993401,112.361566,169.187354,222.874479,257.841511,288.588576,264.494262,157.464643,101.725131,19.739328,-13.87988,-78.104225,-102.720674,-103.546088,-130.751012,-162.214848,-234.135091,-247.084401,-205.330105,-152.401813,-113.607064,-4.526853,34.758003,28.898394,-4.922798,-55.381983,-65.93684,-121.727312,-218.242879,-243.435885,-217.720204,-180.133731,-112.148201,-84.059312,-50.244894,-64.856107,-67.498835,-77.633513,-90.526012,-95.658959,-100.86237,-157.795138,-191.611867,-221.624534,-174.430436,-126.797364,-10.99487,35.772109,24.771833,-21.521025,-36.726541,66.465165,92.888032,69.440527,53.748983,41.052676,42.551886,79.102532,96.539914,79.692252,82.307233,85.235212,59.212593,71.718458,164.585617,195.30743,176.767976,90.477688,47.180986,19.452061,31.575869,50.655227,37.349426,-21.532013,-41.763662,-19.404328,32.951424,45.800744,57.232075,44.679863,1.70331,2.320613,22.5584,5.254223,7.754597,60.009098,84.337808,82.259048,42.096708,-68.670971,-82.762171,-34.479389,34.674896,65.328001,92.322161,84.754209,22.942909,-18.409965,-77.914592,-100.32748,-99.861841,-50.368268,23.004195,218.64446,259.145412,137.818616,42.830333,-17.669225,61.820198,76.007875,8.496864,-12.773454,37.025858,51.207664,-32.219717,-134.638367,-138.227818,-64.494391,-19.674649,35.847004,38.349454,-3.182526,-23.468221,-29.216462,-15.395358,2.12883,42.502889,53.159898,40.00346,18.606806,-24.999787,-51.600194,-32.035304,77.225006,118.230004,120.064911,108.697886,114.36374,116.926616,95.730796,106.238259,133.084398,188.676951,194.81196,161.868259,137.457142,99.06089,114.159734,129.644588,114.963347,100.140033,129.550365,159.569532,146.100587,94.674545,20.413203,85.225838,128.287586,139.719912,108.859287,15.774199,-12.22525,0.31251,55.587019,92.873472,108.646408,75.462675,-16.246077,-65.69675,-96.739838,-54.421853,12.384329,-31.194965,-56.222578,-82.9779,-90.327211,-119.359492,-128.784376,-115.703605,-138.619365,-158.972531,-227.851107,-293.490704,-397.578235,-397.525831,-317.057292,-280.983545,-282.917675,-266.195587,-242.176324,-235.711363,-236.762787,-206.894513,-191.94267,-188.015589,-173.436719,-156.312012,-115.840607,-94.418524,-89.649554,-100.499049,-24.647305,56.667851,92.307542,-39.661304,-31.200989,193.106292,288.693876,231.1644,137.592006,51.000863,54.108546,50.709341,56.353886,60.364986,50.343117,47.995214,82.157838,90.182079,43.749898,73.695898,131.264839,207.016441,182.665965,26.116213,-46.078842,-94.741245,-87.75486,-61.820421,48.179999,107.984308,179.001966,178.712088,163.065732,189.501419,278.748796,277.977063,249.318914,248.119354,299.07343,428.689059,462.931906,433.961584,269.133082,165.190248,53.33734,66.434385,134.530446,127.730686,6.159934,-63.756359,-107.579705,39.318454,125.215142,150.511325,81.861091,-76.250459,-85.442724,34.349511,114.247237,141.674697,258.977728,298.128105,190.949546,70.10771,-127.815757,-154.274033,-86.284437,17.155444,44.828722,9.557133,-52.670181,-186.080935,-200.881282,-146.142236,-113.27029,-76.537495,23.935347,40.815647,-12.724153,-62.19573,-144.508365,-180.124928,-250.432229,-153.13284,-28.433919,124.651209,83.591389,-95.914191,-142.824748,-61.584596,76.825264,70.364222,-48.281557,-97.708789,-184.368528,-257.790935,-384.726244,-371.22251,-198.23775,-22.505083,19.627723,1.373043,-48.715323,-137.326408,-131.80809,-53.762895,19.908375,49.839934,25.099928,-20.094011,-27.174872,13.910972,92.699523,118.440559,142.799046,140.49732,119.839815,50.086193,37.589868,73.973439,69.356921,-54.35341,-144.258221,-117.454941,36.118066,126.957849,231.325698,211.831486,93.262417,35.180937,-47.488845,-12.267619,34.882869,89.631553,103.380112,114.720665,101.588868,36.022602,-14.710494,16.006545,149.959222,203.497305,288.742116,327.242558,318.528517,269.25081:-8.688412,-64.79666,-70.358615,45.771333,129.04642,162.29503,121.766945,61.217041,67.727593,67.170891,-31.844624,-85.886674,-78.415426,-56.002636,-56.119479,-45.648054,68.902962,217.02072,238.548657,165.449616,89.249836,-47.655423,-36.51507,114.312721,160.33674,120.94947,-19.727906,-92.143079,-142.443096,-114.877043,-60.238032,-77.277806,-165.47726,-143.784112,-103.714296,-41.051393,-2.935194,58.905459,60.316966,0.945446,-96.689989,-105.763923,-7.134332,48.930556,72.172976,38.733077,-64.308296,-100.329783,-115.975238,-102.078801,-93.212926,-80.107739,-64.613768,-13.143973,-4.733722,22.582853,127.509528,166.636443,183.398809,171.817662,91.760195,16.353439,-101.355546,-110.451038,-151.872767,-211.072584,-169.725594,-65.615514,-76.749484,-153.070981,-152.422221,-103.878643,-87.882112,-61.548103,50.527872,113.519234,202.364145,207.022228,135.190571,81.382895,-28.893052,-71.882221,-66.973204,-87.371925,-107.068102,-95.135306,-62.43828,-11.050622,33.548115,93.239859,157.679316,110.632557,-35.944079,-86.349852,-156.298858,-209.158779,-344.146586,-346.323568,-291.525007,-169.208457,-122.899057,-99.885611,-110.335308,-130.857546,-129.765735,-74.379191,69.787368,82.094234,44.950208,55.961497,141.286974,165.349645,77.298698,-40.409929,-57.3452,-47.540024,-41.156729,-21.876026,0.542093,29.768936,-13.17813,-26.981399,-1.748612,5.456054,-10.30363,-13.165316,9.221622,11.605772,-44.659789,-38.960238,1.353313,17.839629,-5.465707,-12.507451,7.239486,39.469027,56.779137,84.182191,129.598284,103.500823,26.360449,36.910287,112.805437,128.346329,122.164673,193.82573,228.08969,153.400453,73.906215,-8.346801,12.451574,107.014607,115.974615,79.535499,-8.493277,-38.742931,-33.507814,-0.704755,38.823128,5.319847,-103.860012,-53.922436,17.831153,86.000781,75.539866,61.436578,62.909278,6.757061,-100.430423,-87.444114,124.91428,231.616431,234.735336,149.498724,5.248459,-10.570161,22.447183,59.782759,80.931009,104.507437,76.744894,-51.877858,-106.494311,-84.511891,26.75559,49.188036,67.212593,98.12293,131.752234,108.929019,80.30649,90.467926,85.4559,67.707204,70.641703,96.520984,119.738329,132.919381,137.242935,226.59391,271.353979,237.642967,143.605426,95.412862,1.80265,-21.524367,-29.352366,-41.948098,-34.040192,81.097648,124.494014,74.910246,6.885963,-41.610801,-1.148561,48.149395,-46.175864,-79.921181,-71.156459,-60.997239,-68.029815,-93.255421,-166.415427,-191.424953,-201.1509,-157.406023,-153.926182,-240.311428,-267.297742,-188.906316,-132.935598,-96.692917,-134.117371,-141.555734,-142.119554,-189.275214,-346.80329,-383.765819,-363.678919,-353.959833,-352.609372,-304.763534,-255.714366,-131.747052,-97.944845,-179.969047,-251.802395,-275.705849,-183.697804,-141.29822,-132.807682,-171.181172,-227.48546,-223.410608,-180.988779,-142.130267,-70.2764,-39.626903,-6.194879,103.644528,134.589296,97.340194,74.604241,78.779434,33.998602,15.455501,31.713675,33.214159,24.939443,29.860015,59.140253,91.461456,117.873189,72.785992,70.682729,106.322004,108.435606,38.256618,15.998481,111.074704,235.127488,245.896087,214.646664,214.194069,217.423207,201.761399,208.068312,248.470232,318.087342,302.606581,290.72008,315.401079,353.846167,418.662553,407.918189,319.570731,261.374578,241.949801,116.604749,26.354949,-55.659882,-40.375381,31.33372,61.14262,56.74039,86.813047,134.837178,144.600336,78.959758,-12.164126,16.747562,74.791025,49.623017,72.908017,141.297751,112.137033,-38.876185,-104.450821,-137.599725,-100.227221,-1.467416,6.895676,-40.892455,-159.674091,-188.696483,-204.653085,-215.027255,-218.776602,-127.501604,-78.476811,-106.25703,-154.345606,-144.216394,-87.441166,-24.836065,-52.529267,-170.638502,-220.278955,-188.390212,-44.464775,22.013414,28.995485,-8.178859,-34.947508,21.455209,63.765056,83.143608,45.918443,-69.871032,-119.720515,-140.399104,-130.037154,-124.279351,-37.080595,14.379954,-17.179723,-74.35455,-122.230502,-100.224921,-42.996334,-51.363836,-56.530481,4.181379,64.761021,125.750834,94.704984,20.041856,31.161247,124.733668,164.698314,132.81877,6.293771,-50.455098,-131.70269,-149.14883,-78.217816,24.304389,38.850002,87.586586,143.618618,180.808627,117.965328,-55.690714,-104.142488,-110.020393,-74.488749,-78.375935,-93.388497,-73.540297,-60.927774,-98.605582,-159.106621,-170.572658,-176.546153,-90.462708,6.424809,146.774142,161.472763,175.147687,195.936324:backward
-269.643047,-278.879644,-206.709041,-104.467114,-118.819235,-251.053179,-331.217019,-380.835678,-223.489837,-131.828401,-29.767258,-8.67946,14.690485,18.851319,1.520251,-3.332064,48.653546,74.027851,34.188226,-82.162689,-112.948261,-89.676131,-63.422223,-35.929807,1.081068,50.678454,258.317316,372.046815,400.047496,321.534636,178.684703,137.036217,78.315437,113.44699,166.182662,178.784983,125.017273,70.510623,100.50153,196.809466,240.002649,235.651248,259.560984,314.661887,447.698668,476.459293,422.918815,389.931203,450.256752,585.558303,626.674684,647.108066,638.981327,623.239117,616.022775,587.653463,583.988644,606.574629,666.035143,653.488297,468.851671,353.481039,238.478845,226.062097,196.187342,240.061383,321.511132,462.497678,459.207801,368.236887,339.55293,338.525053,437.300938,515.200838,614.270273,604.816764,499.381482,438.800239,299.809428,214.141199,126.983043,216.397948,260.277647,289.068208,300.563828,300.622248,249.998542,99.001659,64.204651,86.067586,162.191916,212.952294,289.689474,298.65813,285.647133,285.638867,298.906413,303.021391,299.687576,262.639932,218.030375,90.159889,41.549394,70.213808,248.98574,321.064598,334.567188,303.189105,286.248732,325.16936,410.216705,424.427483,456.358138,423.008365,348.1112,248.7805,265.139436,278.756499,214.133708,48.138603,65.585546,99.377302,91.529566,71.221343,-28.319779,-128.257492,-290.300403,-299.173169,-214.458382,-104.217853,-51.849499,4.450879,-6.787017,-22.390935,4.062293,70.753462,120.339335,151.191706,296.563696,405.84586,484.468635,433.417979,345.191248,346.37888,389.60924,433.558055,442.925516,434.257143,423.868478,391.652277,374.62659,354.766449,388.699963,409.17703,373.52888,324.29312,210.5231,143.900255,-21.633955,-96.512413,-126.196735,-2.165036,73.485184,204.892744,254.641041,296.360733,292.205543,282.725361,349.887537,412.270901,497.932043,491.688324,347.6184,245.051231,175.211783,221.166276,328.838743,326.36947,307.306771,328.948073,330.694697,223.075622,161.683782,166.029935,280.954855,302.793888,296.836741,308.274038,306.215416,282.747099,261.173049,269.960726,312.748683,358.862486,370.120861,390.762213,400.616331,413.981536,401.159619,239.821141,4.470731,-40.53293,-3.796533,-1.815742,-120.076885,-195.516212,-250.841638,-233.03233,-129.258034,-12.512097,-2.657385,-25.051548,-12.493992,13.966748,-25.18184,-161.767815,-159.386625,-125.507456,-88.706815,-73.513037,-52.123633,-49.876251,-94.625124,-146.127299,-156.018066,-33.597912,-5.315998,-23.993793,-38.461691,-87.31309,-126.08689,-182.914407,-206.987351,-201.096249,-159.299791,-152.143579,-167.269415,-163.349376,-161.646801,-191.996896,-222.999224,-189.245421,-198.342243,-204.703193,-182.633485,-143.024088,-138.995172,-167.76539,-219.776029,-235.12891,-194.136498,-149.642886,-132.860305,-162.447203,-192.985795,-169.731582,-39.15604,38.311031,23.702775,19.010347,16.910954,-103.110484,-191.867248,-265.906658,-222.769579,-228.862402,-242.582454,-195.224518,-97.298135,-95.418746,-140.331457,-162.956132,-135.170369,-13.63706,5.365506,-110.707136,-191.897362,-296.365585,-329.23233,-365.007586,-316.55827,-253.840224,-63.018664,15.097161,12.30704,-33.428842,-106.247363,-143.386592,-172.937167,-129.197878,-128.141708,-135.396483,-122.628219,-110.108952,-123.262059,-117.802688,-47.533569,-51.392152,-116.888712,-103.028778,3.615823,28.241358,-14.034348,-39.990911,-16.248739,44.202861,49.783201,11.181253,-28.180087,-120.026852,-146.457089,-153.517187,-134.300466,-128.307687,-161.295133,-167.802875,-93.865331,-45.312065,-26.781743,-78.856391,-229.572842,-270.276036,-262.891672,-258.384625,-240.042665,-153.247674,-137.042964,-232.332279,-277.829613,-227.812096,-59.593166,19.742992,42.707893,-49.23874,-314.239449,-384.171122,-343.760822,-243.702615,-185.712121,-40.141462,-11.312917,-129.405277,-222.661166,-314.37489,-243.261128,-203.182297,-174.101052,-164.895554,-170.650671,-182.164733,-196.847036,-210.899635,-217.692213,-123.540395,-55.457184,6.154523,-48.562305,-276.664861,-371.397743,-451.276227,-452.734423,-449.67333,-401.356201,-338.007903,-239.076667,-239.196069,-317.446376,-367.752753,-370.899812,-256.532622,-202.430114,-154.39002,-184.204197,-312.049611,-356.048267,-335.170594,-237.812188,-213.208987,-238.719201,-263.208688,-285.296331,-274.770396,-276.840615,-318.135589,-390.689625,-323.765116,-256.979969,-200.980705,-262.416982,-433.555287,-434.692878,-255.276469,-100.709897,-73.01878,-37.512234,-25.774436,-73.126777,-115.693696,-221.267043,-293.478542:-42.462799,46.295036,102.190454,76.597413,2.306994,-144.601218,-181.29501,-142.86911,1.837655,63.897373,94.446968,47.629493,-76.440539,-60.88312,84.794913,115.328511,85.443385,66.387397,56.236037,-4.302389,-50.274354,-126.074471,-132.015056,-69.120113,-16.862143,-2.999667,123.593801,227.645413,289.59116,224.385276,89.942749,69.842575,64.715087,58.312061,100.497503,211.617416,204.344573,93.366486,64.377863,121.920899,167.26941,161.999234,208.436877,256.521245,278.518914,245.360925,187.339291,199.060024,334.251148,537.598982,598.78243,601.128769,569.814419,493.232503,462.395842,401.477547,369.001063,415.751127,550.198351,535.870323,316.786642,214.296899,166.878948,176.483164,165.363764,257.228421,346.756438,426.087739,404.236813,315.226919,261.82274,233.505309,416.492471,536.701777,624.747064,560.119847,395.810184,357.271684,280.503381,236.242302,245.430477,364.124879,406.992186,439.122883,460.131188,449.575092,360.96986,122.332209,68.581197,116.030746,266.453683,317.188239,295.757097,255.79299,204.421314,207.507596,264.399341,294.777258,286.82053,249.711875,224.388299,132.429859,63.984994,9.992732,177.077437,273.741054,319.073692,269.963368,166.411116,157.736977,218.010484,261.438409,339.983506,311.383758,252.420099,199.70874,223.119687,224.113634,158.916983,6.473407,44.39099,114.90026,161.372512,112.642405,-40.698735,-117.649923,-202.653276,-187.297613,-62.151351,98.657203,155.821633,179.817683,150.445382,80.540595,59.951295,54.020897,122.015358,187.70216,336.571716,379.746066,339.871783,287.426107,230.670223,242.348828,319.544404,383.594863,388.910085,321.0459,278.771219,253.503533,248.539719,243.024029,323.512197,369.320381,383.174342,353.940463,251.321588,186.535135,44.203982,-18.52451,-37.953456,73.688836,133.390439,226.224966,266.772663,309.412533,296.668941,245.245379,294.865029,369.934084,457.796681,416.798448,202.031027,99.212336,47.877098,68.740828,104.587404,181.169409,256.181908,363.695931,311.292399,91.917599,39.953157,54.9155,73.99917,85.865425,123.90277,138.567382,145.84107,128.139127,45.517917,22.974227,101.42512,218.047653,238.757674,224.719255,203.210798,184.056742,188.997008,105.170682,-39.235874,-24.212112,112.927817,98.131131,-128.341938,-210.126583,-203.907786,-168.68403,-74.553665,10.730329,25.337632,52.249422,76.381053,48.390847,-26.274304,-119.338547,-50.883211,-42.901295,-58.650277,-20.992324,76.148571,76.171079,-29.092874,-94.581231,-112.32856,-31.758328,-21.230873,3.936636,49.669613,56.576384,-15.11384,-125.83422,-96.197005,-62.901364,-6.974122,-9.83349,-74.017994,-101.145636,-144.084648,-170.834466,-184.596626,-122.723512,-78.170661,-39.007946,-60.235379,-96.729049,-93.534536,-99.238673,-180.448466,-225.41126,-162.054703,-56.476527,42.964152,-12.103992,-122.958202,-78.171564,176.55646,237.699304,164.215717,87.500059,102.695914,74.156242,0.261011,-132.470793,-60.842751,-22.554199,-48.024428,-44.835665,25.977273,25.774845,-79.438206,-96.784212,42.200425,155.967804,146.216585,10.863001,-95.084561,-267.632123,-308.248388,-305.592658,-226.209845,-161.946932,53.585401,167.731586,231.899691,168.719711,-38.032283,-135.3612,-195.303937,-122.878321,-114.085852,-118.325178,-115.433093,-164.781569,-207.160665,-169.353785,18.068484,63.350539,-5.636886,-50.147609,-38.422784,-27.658595,-92.761627,-115.971446,-49.144295,9.806905,2.563279,-17.508588,-12.080588,-8.88995,-16.694902,-66.12162,-119.416201,-99.617216,-21.168223,-29.372817,-147.40912,-179.381546,-149.184136,-161.920436,-258.540886,-286.965037,-261.997617,-203.146743,-201.247022,-224.191573,-241.994111,-324.56443,-406.472074,-408.137442,-311.135016,-236.771505,-166.887603,-229.308783,-508.815427,-605.233167,-558.842343,-313.08299,-173.68269,-77.511297,-134.71765,-271.543865,-306.172185,-304.23512,-238.000668,-200.800434,-124.004112,-94.793225,-99.047829,-116.458649,-156.728437,-183.271962,-205.884952,-129.472426,-54.665903,53.447605,9.056693,-239.59224,-347.161352,-405.65618,-371.247406,-379.259984,-339.143446,-273.359275,-203.525549,-223.373983,-344.227462,-405.252027,-408.459972,-287.813164,-211.490491,-133.575669,-154.713755,-254.415574,-312.169453,-360.121053,-250.167767,-190.129426,-150.401718,-164.890677,-233.919978,-260.665291,-302.415462,-339.754238,-382.400414,-317.073267,-247.366094,-181.183494,-246.075905,-435.11037,-471.139305,-378.994145,-166.905999,-103.790996,-122.141528,-146.737009,-186.610619,-224.486137,-302.422784,-299.492621:5.683496,92.349455,155.436828,175.817433,94.161918,-93.5873,-114.145378,-31.172302,63.498812,94.59785,139.823302,147.142336,115.481837,95.36367,77.38706,85.551078,129.235145,112.841666,59.914008,-69.381151,-107.230593,-135.255975,-126.185457,-45.85619,25.402693,58.648086,177.486854,234.77952,185.200795,77.87513,-66.815758,-39.941306,68.605619,135.774065,202.23086,322.57684,306.677488,147.294262,70.991618,51.862333,184.025251,262.622779,332.308424,302.982126,205.071399,171.062921,133.336256,139.865091,252.407751,443.553325,504.897511,485.079335,435.947874,389.065143,400.706113,399.75239,358.206046,385.314388,455.834151,399.217014,148.665456,50.854433,-30.694569,-32.350651,59.400267,249.812845,340.614473,410.287657,369.369093,250.018812,217.787194,199.403059,299.32641,409.08454,524.4562,459.307434,292.055745,266.422458,195.86042,148.016709,188.291558,301.827059,322.09492,361.474641,412.93884,458.315099,368.465703,113.69293,101.544406,136.295134,191.418385,231.504466,236.57653,164.366936,18.955578,18.500726,139.493398,242.168083,255.692144,228.446734,198.273694,100.674378,41.467003,-7.906483,127.16318,219.137894,269.831659,205.183011,6.308962,-57.468469,-32.369513,38.316439,174.999627,152.184637,103.8653,64.482927,71.087789,60.403461,19.693049,-80.112487,-63.076869,-25.237173,38.823104,58.440524,26.324499,-25.486866,-105.081899,-106.96919,-54.279616,49.369066,111.142738,198.575224,215.127274,154.020601,78.357981,15.974162,133.38305,177.962939,246.293187,306.15574,367.305889,311.650015,137.284842,101.678239,118.348763,172.944859,227.106029,319.550275,330.066622,286.97274,239.701966,149.707691,200.768789,280.85904,384.687702,365.54295,262.028253,209.74167,97.690066,57.895328,73.018987,140.936325,172.044943,242.207652,273.638412,278.027105,257.043069,262.001279,303.717443,292.671708,285.446485,311.542208,271.206216,181.278034,16.361438,-22.463975,-30.216759,129.699518,286.772322,499.591955,435.764274,107.377554,6.313914,-4.063551,29.612761,53.368198,120.153544,135.497866,77.636809,13.224153,-94.82213,-79.097725,82.727024,147.119072,125.799325,112.364081,143.849531,201.828419,179.302322,48.575475,-0.322442,40.797863,117.841225,76.749045,-139.908124,-220.644946,-234.304629,-205.650161,-107.279441,11.751528,32.93324,20.552725,22.929621,39.335571,40.32395,42.88545,17.514287,-1.097558,24.144553,54.645408,46.003255,-29.792786,-267.627884,-315.620341,-170.191349,-57.049043,-69.830032,-94.625496,-75.993531,-96.135057,-160.379308,-196.28515,-20.82113,60.30896,61.345442,-18.504907,-147.685917,-124.851783,-24.899777,-30.069081,-109.231093,-105.138401,-58.676365,52.709452,76.236859,46.02265,30.829153,6.142256,-95.079635,-122.71859,-7.448707,84.569206,151.508922,116.616282,26.199014,24.905798,124.366485,167.3041,167.948904,201.966242,170.341617,7.132602,-42.763556,-41.956,10.863238,27.062125,47.284721,63.182916,39.112302,-20.170436,-164.201058,-197.040093,-163.186653,-73.144254,-20.850516,-33.972126,-119.400086,-255.281153,-250.774441,-185.674426,-156.935331,-130.072317,29.468836,123.290542,134.785545,56.921219,-66.528224,-91.100604,-131.877707,-162.129957,-151.261244,-65.457901,-33.233168,-73.769268,-117.217002,-116.952581,8.967973,68.229894,95.798285,74.146162,68.611131,86.881233,72.683048,40.965325,5.539421,52.525924,86.171733,62.881279,10.738036,-37.077862,-15.284955,4.105334,-50.994397,-39.846287,84.550626,117.697129,34.273771,-12.811163,17.904132,36.4985,-73.948786,-166.247252,-137.539735,-77.944443,-92.408332,-188.789243,-271.341648,-394.148762,-295.146933,-235.424422,-195.262805,-194.835686,-235.964027,-280.216907,-398.654836,-452.210118,-463.948884,-283.661375,-158.913406,-35.686152,-51.284809,-115.53084,-138.256035,-146.174438,-110.47671,-86.889458,-24.007443,-7.032155,-19.23161,-21.447121,-106.974555,-206.962719,-274.898793,-128.799016,-71.978775,-58.524678,-107.150984,-244.731245,-296.82694,-359.847565,-388.793942,-391.964258,-322.169599,-254.525095,-175.660081,-204.658838,-389.347628,-469.180562,-439.136327,-270.667991,-200.289535,-168.026003,-201.275376,-315.016378,-390.313776,-457.073166,-275.194578,-150.46588,-52.324662,-106.164456,-288.211183,-333.991382,-325.849537,-329.369515,-364.621364,-348.922469,-300.488246,-253.934551,-330.922757,-532.47316,-544.812748,-410.850603,-218.27123,-145.66715,-98.467069,-95.197538,-104.50552,-146.939288,-291.629913,-325.797205:-203.778824,-72.03772,15.946946,86.597851,66.246862,-30.471085,-95.494799,-169.892303,-81.053358,-21.706879,64.972984,91.911051,59.572457,16.577989,-12.651996,-5.805437,-10.730576,-20.599169,-20.321721,-51.547481,-77.380226,-85.68545,-71.408532,-44.80951,-29.326227,-8.942106,126.972041,208.801263,223.964147,171.063877,123.771803,137.244942,146.996407,163.467114,208.656464,288.141609,268.43758,160.671675,126.107912,161.259542,261.846878,296.409872,357.70664,394.093937,418.061893,379.820324,268.371572,257.162898,363.233943,473.490002,497.405342,504.669733,494.809094,487.542699,492.057619,485.330283,513.801662,560.301845,597.45859,551.105348,390.536412,306.927223,166.629327,115.616976,79.962364,187.86178,273.652427,385.898097,390.366712,352.113694,322.177353,252.314941,326.990164,408.137522,474.290887,444.475328,363.718702,337.382904,220.622108,135.220606,131.671488,341.860332,412.266213,431.319004,425.809075,405.960558,344.386266,165.175364,166.47104,212.354806,262.573174,258.445578,185.030988,131.615128,66.569037,77.3741,198.29045,296.663262,267.207944,112.326152,58.219669,44.981807,40.184137,-25.565547,-24.977773,15.323283,57.086912,43.321639,26.403379,49.550754,121.00441,138.891785,142.452382,138.749011,130.008693,117.090486,116.077364,87.434401,42.665308,-37.189035,20.128287,57.349369,65.417188,42.886636,-34.36217,-72.185861,-126.931113,-143.431852,-109.533764,-16.0106,36.276359,166.676054,211.295089,166.263782,113.391619,122.866187,236.330954,263.19195,323.304446,388.126655,461.639169,420.871801,286.959304,262.707786,315.639118,401.319529,441.876401,490.317273,472.450834,404.696718,395.787709,427.423783,465.914105,456.122324,385.468334,352.872164,276.437714,210.80076,43.469355,-33.396472,-86.260832,12.741505,85.451765,243.327857,305.697022,321.660914,288.36836,238.066577,281.549552,335.328692,474.675787,536.974466,492.9573,379.013393,204.522743,203.625022,269.942257,260.898638,261.792501,346.810052,377.381598,291.933785,202.549522,92.288201,133.747491,170.884483,200.518336,207.015646,243.731117,245.564797,194.172067,197.844673,299.031421,335.064426,314.14285,286.501861,294.807135,329.753884,328.219152,228.3707,92.763115,61.063439,66.074992,61.610219,-3.189364,-44.464217,-136.576657,-164.826284,-74.518341,58.591463,64.295142,31.208516,29.857729,9.574138,-34.369596,-117.828858,-123.302612,-125.071642,-116.032627,-83.802585,-43.266726,-80.602548,-233.917897,-277.616596,-204.312964,-111.807997,-115.675535,-134.452487,-122.916776,-139.573417,-185.86216,-224.394,-132.483541,-85.773013,-56.447179,-79.924114,-149.584269,-152.226924,-100.572445,-81.061908,-80.45678,-104.043888,-84.971361,10.447223,28.939115,-3.246376,-22.893805,-93.831549,-154.083684,-132.471338,4.219903,79.914032,119.343519,62.523993,-86.05224,-94.949258,55.214981,163.875342,177.165555,207.681308,185.968523,6.622099,-84.121402,-94.986402,-13.108662,-31.47167,-88.70949,-68.69814,-25.571499,-53.412016,-165.612645,-200.370703,-185.447424,-126.882468,-108.103927,-161.309351,-242.751103,-393.675175,-417.470555,-366.768779,-264.131204,-202.434205,-51.825759,4.985534,29.833942,19.401471,-31.04486,-81.951701,-174.705241,-184.715487,-168.586978,-129.644365,-119.303524,-85.463095,-60.562223,-48.731583,-19.037594,4.686163,16.473974,26.493619,66.774302,73.241909,44.229008,21.094497,-11.205218,0.536237,21.561994,42.565973,34.622505,18.554039,24.090235,23.177396,17.04844,27.918619,56.850597,82.492602,147.198141,157.719055,76.704054,-20.99617,-193.588337,-155.185612,-113.685522,-81.548156,-67.664749,-65.771676,-107.921223,-211.044494,-183.607259,-149.504958,-92.364825,-47.038887,13.025395,-31.828053,-247.879641,-330.304886,-304.669378,-166.294736,-92.312201,40.018454,54.708977,-27.100312,-85.432794,-178.131781,-184.869593,-162.155019,-94.76295,-74.079168,-132.777164,-186.017523,-266.560671,-298.098743,-308.451671,-241.686993,-195.303074,-116.156848,-139.615053,-343.869467,-460.162834,-597.264707,-582.467009,-546.067076,-428.46926,-345.609999,-260.346283,-291.22747,-419.464037,-455.390244,-382.714587,-246.386683,-193.930978,-130.355512,-150.962462,-312.818009,-394.700669,-401.374544,-259.571965,-223.455726,-240.687106,-235.141412,-206.754085,-231.579703,-345.866311,-410.189633,-493.939305,-420.531958,-337.755696,-277.228721,-341.264493,-491.904005,-499.709762,-375.944273,-218.843814,-178.936657,-163.820468,-153.272043,-132.714875,-163.431069,-313.813037,-369.027973:-100.148684,33.290636,118.879162,157.886723,99.626249,-29.630782,-59.59322,-51.172808,36.65021,100.621617,206.020267,212.993331,97.148658,6.505682,-109.450834,-103.147351,-6.135991,16.651287,2.210927,17.495888,19.749105,-54.277544,-90.223736,-66.083758,-22.970084,-18.008343,42.027264,88.838996,82.46168,12.65189,-131.252871,-138.040504,-3.904947,152.103471,199.818214,199.988311,155.199141,54.831013,8.339495,-19.692272,115.500403,205.489488,351.372028,391.314644,393.154836,371.751555,309.90882,281.605707,284.265067,360.460477,401.730217,390.505127,338.774153,262.25489,242.241155,229.745801,332.61035,424.944447,535.356081,482.50806,257.560752,181.254745,126.127364,123.537626,194.02286,289.426643,326.320532,388.005873,383.513139,293.891132,246.834213,238.41014,352.074276,413.220837,451.832214,423.806368,328.405569,270.438614,130.912872,91.574254,140.131479,263.13825,339.763039,446.601837,446.133432,361.924402,271.477011,96.415353,133.43568,192.889861,286.549772,321.025375,296.430651,209.787891,15.419859,-11.749555,95.482951,188.616139,170.631853,55.521137,10.120128,-12.428909,-16.032073,-19.272462,-7.918276,-12.18596,-10.89398,12.622539,30.608999,-11.118367,-124.920131,-132.55391,-33.678217,53.243316,63.903527,30.787343,19.063423,37.597707,14.464259,-104.078767,-134.060832,-102.237912,44.380728,114.334987,99.894722,23.357866,-148.266422,-185.370527,-106.359597,52.060644,129.353741,246.822129,257.574165,160.968429,92.420568,68.238788,213.16824,293.995529,406.35423,411.925215,298.690207,211.471686,78.6683,61.322032,100.069293,229.78783,340.700276,490.371671,458.46115,295.60325,252.65371,252.869913,227.484039,222.375351,274.739093,274.455439,155.752137,84.134286,-12.761145,-26.377876,36.91039,137.90659,166.667659,227.669068,276.285926,293.871616,236.679156,162.453765,278.58836,349.592588,446.506564,473.890297,412.806375,321.768562,205.236691,221.858995,285.988183,328.760413,386.749711,432.961717,331.275431,11.934786,-85.531293,-55.885594,80.649305,114.304777,131.699516,152.474044,198.940459,176.32465,74.918069,78.037823,200.425456,260.387273,270.706717,279.2664,262.827865,202.822874,163.623437,81.436296,55.989355,70.726317,144.199109,158.895809,39.629444,-43.371106,-124.485479,-134.664897,-63.411317,114.246286,168.525457,135.310479,81.558926,12.277121,11.755014,37.46752,-20.25283,-61.636625,-16.931257,46.501014,33.163642,-75.558407,-316.578283,-344.758604,-192.294726,-56.327539,-56.655082,-99.374516,-114.927721,-177.360256,-207.91186,-141.968554,41.772502,106.472945,92.034922,24.600641,-88.180395,-102.0714,-138.352188,-171.280272,-145.1435,1.263666,73.844054,148.960672,131.084583,11.724144,-57.424088,-127.233306,-68.945532,-21.495405,66.866096,97.343958,82.247289,34.456475,-68.362928,-80.792442,6.330326,165.626587,247.362605,317.697091,264.670254,43.988917,-58.262465,-121.869406,-9.766103,58.580753,147.416863,150.31617,80.31676,22.207392,-108.005536,-132.212092,-54.647409,13.074734,32.249833,72.274815,51.635681,-116.555524,-211.548552,-236.420556,-117.694425,-88.775472,-18.659149,49.359916,98.624251,58.13179,-28.838328,-41.428427,12.989258,94.133546,108.6627,52.010864,-7.582685,-79.859662,-80.090092,-52.23492,-0.687937,30.908803,104.13116,129.243547,86.125326,30.028944,-65.148941,-86.236563,-81.138894,-18.534613,35.549341,104.444958,110.89193,101.14994,68.415946,-37.553026,-25.953471,38.118731,150.740237,141.627721,28.965736,-1.048195,3.651835,-26.961033,-159.740849,-188.069534,-148.662917,-88.747959,-100.21876,-198.080945,-269.950061,-344.305929,-220.773141,-148.610344,-107.387054,-118.49576,-156.515099,-189.536438,-260.465024,-263.957594,-205.135064,-163.546941,-129.141596,-9.426649,23.682448,-43.301306,-101.81209,-133.495749,-70.389174,-58.093269,-62.40495,-63.33797,-112.941225,-172.217171,-340.536432,-401.331892,-365.703162,-281.540163,-255.088298,-217.316136,-241.166906,-361.16479,-415.389133,-478.087558,-466.902785,-418.717353,-264.144543,-210.838494,-225.933662,-280.892784,-455.573993,-518.216095,-427.174029,-181.562841,-93.595295,-83.16962,-148.31409,-298.401697,-347.894432,-336.03643,-208.472274,-146.625615,-39.705046,-15.334844,-123.753131,-227.212385,-375.318039,-400.059212,-383.294459,-319.68531,-264.462005,-181.875371,-203.485269,-319.12571,-361.183636,-339.716009,-175.140216,-94.370541,2.375674,26.78236,-4.281048,-72.305509,-229.04744,-253.468478:-286.103812,-252.358636,-192.530233,-108.206959,-109.286182,-199.43961,-272.810866,-381.252505,-288.737135,-192.927003,-58.693411,-36.977045,-44.154509,-41.831386,-8.843372,-7.840975,-50.783498,-58.859731,-35.2077,-7.318131,-9.413323,2.207263,2.64011,-16.663177,24.719554,95.81276,316.796193,386.70068,279.45051,158.499408,45.335929,76.399789,157.290463,116.475905,76.689242,35.531097,27.13511,14.381505,19.368063,70.491842,151.163879,192.295931,294.635959,360.611218,451.882561,445.349771,380.043715,369.821516,425.74967,480.22462,490.150489,551.259694,588.608299,570.155887,517.655907,448.103658,494.100916,515.547178,498.777057,473.660742,415.377907,379.290371,264.442005,188.014051,65.148369,91.305982,141.801823,182.860978,176.826432,186.611887,183.979584,126.735875,216.704741,332.481498,503.157529,504.399517,422.378673,397.701904,316.438366,232.199732,129.961802,176.448049,204.741548,272.571162,302.986726,254.462225,181.172532,82.499272,82.083281,83.283695,140.128783,206.383312,263.844958,207.241817,50.709574,34.613916,120.997592,102.566258,33.210632,-75.19072,-96.975276,-144.651404,-174.068524,-155.104584,-2.346091,58.838931,81.17548,80.673804,96.556614,94.861023,53.050802,27.748704,70.462849,154.223796,135.066055,53.720555,47.953785,71.089707,42.912438,-68.801154,-34.887675,19.844164,54.470637,29.859548,-73.025446,-153.434437,-334.842136,-389.6592,-356.311758,-217.721523,-144.162625,-27.41931,7.228041,11.586408,-9.881509,23.128006,192.483695,259.822895,328.889031,358.18094,372.742186,339.718908,246.603304,222.039395,239.258169,255.773201,255.791501,301.709522,334.282169,348.782421,331.277163,301.782169,369.687806,399.452658,333.484022,265.561772,88.740811,-32.061029,-222.371034,-239.700055,-169.82205,-112.739982,-85.05652,48.735835,139.843647,236.472583,214.39723,101.641469,142.595093,256.178096,516.336502,587.333897,466.570875,301.678565,95.304092,135.101752,310.252437,321.76019,292.159236,300.066283,321.651498,315.938527,297.092335,251.249145,224.059939,248.469332,352.071453,375.440428,297.918712,230.612253,157.105776,176.927231,292.86935,361.754369,365.196293,393.477728,412.37106,382.254678,341.634089,235.48481,88.480403,25.64502,5.848339,42.802705,44.644211,-28.397512,-200.323016,-228.282036,-91.728936,107.264442,132.585609,67.989243,26.437479,-27.623123,-42.518736,-55.147617,-68.383333,-85.892202,-100.110507,-82.607856,-23.218163,-2.035768,-46.772935,-91.0586,-58.472379,54.145442,57.762467,-3.811882,-20.314883,-22.758979,-36.409171,-90.369655,-103.87456,-94.826271,-68.541579,-57.524446,-69.041329,-76.431975,-73.763446,-96.49388,-145.509773,-83.409635,-51.103968,3.965809,48.738641,72.71812,21.294468,-80.841903,-41.561322,-15.31712,10.5794,44.167314,98.427307,86.915966,29.068453,16.51975,98.579296,243.1302,290.944609,287.17542,215.008809,35.616768,-1.967721,23.143959,58.22846,69.005693,81.114822,82.781569,79.624499,57.602479,-62.008172,-125.360532,-134.92226,-14.923007,58.45137,114.738885,51.808907,-138.016243,-190.979586,-230.651624,-214.275084,-159.405749,-2.96055,52.169095,75.095079,67.997348,44.107162,11.486302,-78.217662,-146.36739,-159.153017,-133.006653,-116.537625,-92.947358,-88.88217,-83.196884,-35.351234,-32.919464,-70.406146,-61.758469,25.51599,57.498055,3.694364,-52.780098,-85.609862,-87.030088,-100.182624,-54.38769,-10.296122,-33.186269,-96.68495,-184.19479,-121.559091,-66.216609,-45.802162,-70.534041,-83.863653,-70.107288,-71.741232,-105.530179,-194.152219,-246.568228,-249.642975,-187.355264,-138.782869,-115.945854,-161.644582,-275.782879,-256.538687,-198.430307,-62.50663,-4.317983,-34.684779,-151.683504,-390.37402,-406.566602,-275.17796,-178.105024,-146.281737,-80.790189,-73.538159,-142.184388,-197.491851,-286.802899,-327.6232,-341.400207,-322.584288,-287.019558,-294.151923,-345.22333,-393.602965,-377.306326,-310.725272,-196.488547,-134.078657,-77.732831,-127.409883,-359.371225,-455.532459,-477.489179,-423.094914,-420.383529,-382.260721,-321.935932,-241.348116,-266.606164,-395.090152,-438.030366,-357.367614,-203.538199,-164.401588,-123.187689,-140.757498,-245.529166,-259.674535,-168.001305,-67.799531,-42.218108,-52.525395,-75.514944,-81.258318,-51.924661,-42.541319,-103.896003,-230.233617,-177.396633,-114.946219,-71.222625,-103.484345,-138.253079,-104.08259,-23.869527,-9.525762,-15.168432,12.380544,48.694741,34.204951,-37.502871,-170.284392,-191.802444:-196.154969,-51.13983,49.803004,131.287211,80.731054,-116.939317,-200.933652,-193.821317,11.630488,88.278865,132.088595,134.172413,79.737296,6.318568,-142.759028,-159.88946,-62.433126,56.853465,89.913255,68.21992,12.725071,-85.359231,-111.171204,-147.346813,-91.158757,-29.292046,63.286396,69.879318,5.844114,-33.107979,-65.129087,-59.165071,3.324926,79.153566,94.951009,81.401329,59.934648,-14.37125,-67.614492,-83.162903,111.461237,218.524008,380.421662,451.777484,500.782086,458.985145,358.0096,336.144156,346.48132,389.221636,406.979374,387.827888,350.900038,290.221252,273.350432,265.92673,331.011897,372.186953,445.51782,478.004033,464.34804,401.02898,222.426754,143.03352,72.608603,162.536488,257.921692,415.051018,409.487087,249.451356,161.545423,101.48837,204.738216,277.164648,405.207643,429.935698,334.176516,243.047835,102.323609,86.652106,189.440535,339.061774,374.740048,357.352451,310.34776,168.152496,89.579454,0.373078,114.705438,214.198734,340.866801,345.594071,233.170992,123.237506,-91.38255,-137.458154,-40.301792,132.700062,151.673032,62.80699,2.169632,-115.68122,-184.287327,-251.887756,-115.107895,-27.307744,66.989284,67.155224,-26.333771,-90.842178,-173.796766,-188.243097,-120.595409,23.60302,70.375633,111.539352,98.646098,-12.981958,-76.348879,-123.879343,-80.668361,-33.351964,103.108677,132.956577,8.964724,-85.720829,-179.296027,-173.647235,-92.789867,29.860683,108.329256,245.154007,242.400806,86.324927,17.961616,51.023646,211.784871,281.174461,413.456771,471.38739,419.838724,304.689992,108.571463,97.881492,195.972668,311.057458,376.910254,455.168117,419.158427,259.483095,209.582927,250.265868,352.307962,366.28359,303.29245,242.04768,91.348357,6.879972,-164.256242,-215.372068,-150.662817,15.790052,74.493802,169.75161,211.045867,192.557722,128.510517,55.755318,172.605313,256.460254,409.853354,465.159771,454.539682,384.55404,225.888984,172.005769,155.625757,266.98039,336.151315,363.50832,296.288485,118.847125,56.271618,7.864276,76.224948,138.49279,247.396761,270.415837,214.820035,155.475699,86.856688,97.610673,171.054618,269.954232,313.259484,319.769304,289.691708,233.627553,208.946358,141.859543,110.271881,123.462407,156.097641,138.3857,27.850762,-23.2357,-87.618768,-106.490118,-23.207201,188.634176,262.181115,281.771882,229.382795,31.143702,-69.886653,-113.599587,19.148664,48.918941,10.024477,-2.864745,-30.762909,-86.934453,-228.432848,-245.842008,-144.423618,-82.027289,-97.296143,-87.873201,-42.278319,-17.389351,-73.547192,-126.95367,67.195614,162.401866,159.033691,94.789111,-8.374842,-30.782208,-76.605841,-114.887935,-137.50286,-60.779086,-13.968271,92.168199,137.995502,148.447933,102.223264,-29.27883,-68.847895,-50.724493,47.436573,135.69493,253.983254,210.58093,-13.030733,-91.585135,-5.65333,287.241357,401.91572,401.758528,289.659071,17.200831,-80.716407,-117.225624,-2.672773,41.373991,97.415286,116.495549,44.992472,-45.109602,-183.206616,-186.394823,-107.285296,-43.732521,-10.993831,15.55972,-31.763322,-195.61484,-260.9741,-269.472703,-174.752743,-122.122517,27.408542,94.858118,95.186672,56.136312,17.204468,11.225461,0.271114,48.994106,91.62396,108.030664,57.954561,-76.573876,-117.238415,-122.672928,-20.686584,61.172767,199.963134,209.573447,68.292127,-36.677897,-156.339046,-147.489129,-65.510847,9.513221,42.909822,51.62567,11.414452,-81.184126,-108.008871,-138.284253,-103.227987,-66.250091,-17.489239,-7.333128,2.957145,-3.148284,-65.957314,-115.026027,-167.350372,-126.796444,-105.59907,-120.898365,-153.438725,-241.03848,-298.401544,-374.541585,-259.015312,-165.047139,-31.932917,-1.267297,-44.761157,-132.148065,-334.746052,-368.179306,-249.536775,-94.661728,-48.404756,-7.599161,-20.908462,-115.805207,-171.188469,-237.492604,-259.25862,-254.623708,-192.048699,-170.360995,-236.897156,-289.925224,-338.462345,-334.385599,-275.883946,-179.242373,-142.969977,-146.428889,-188.354699,-347.136365,-460.453234,-605.131716,-450.799824,-328.113307,-187.911044,-171.911711,-237.726944,-300.689867,-389.442865,-408.5051,-379.043004,-220.075142,-131.90529,-65.601608,-95.826403,-227.181904,-294.006981,-304.1508,-110.684175,0.136231,96.921221,57.250486,-98.659835,-146.800511,-202.844619,-248.173707,-289.149987,-165.111345,-89.698855,-77.242337,-146.440444,-254.826108,-243.126397,-147.063742,-42.849836,-12.251403,9.473435,13.492489,-44.72023,-109.31931,-210.076514,-224.111299:-177.016145,-143.30456,-109.673221,-69.047662,-74.135102,-175.287819,-255.415239,-336.871299,-189.485941,-104.916574,-41.374253,-11.452417,68.03351,93.774384,127.678766,125.56238,104.435436,176.011652,218.669966,212.897431,175.387477,146.379864,166.776183,170.797214,122.692817,110.956881,110.519671,114.260642,72.857113,18.726729,-118.500355,-194.71257,-348.949769,-457.303635,-464.154817,-376.598646,-314.047795,-214.042736,-197.36568,-184.304258,-61.511269,6.510225,118.007953,186.478512,307.420902,334.160173,360.042403,388.235178,474.983868,526.660638,530.705333,541.184656,549.697766,558.392777,547.119228,458.460818,390.05265,404.589423,453.887783,458.945777,441.455007,421.914129,324.73484,232.195134,13.238406,-112.033698,-115.180918,-20.596645,32.856579,65.502192,67.864605,155.081195,310.380192,325.412598,241.884656,212.634832,230.991038,248.815403,211.059779,152.046603,50.13228,23.707056,15.097867,0.067879,-6.342148,-18.115974,-28.922566,-83.837987,-64.012158,-6.383556,99.081378,123.598058,153.71238,157.250505,60.988664,-13.451116,-78.274718,-117.407523,-174.815077,-298.363823,-332.831496,-390.54234,-437.020054,-457.126621,-266.041272,-172.766679,-97.955622,-81.170041,-53.291504,-44.078629,-23.450457,-30.988294,-53.925748,13.611638,48.192561,83.423259,110.067914,148.552685,121.288795,12.968877,-15.548036,-12.035388,-43.361106,-80.878395,-185.688361,-233.800553,-323.326688,-381.111733,-445.889624,-377.318545,-336.916806,-334.551174,-362.301364,-361.685074,-301.394584,-118.111995,14.782148,44.997249,71.832147,97.270386,153.786537,148.762168,72.386252,38.471885,44.306684,64.555434,39.756165,1.971905,31.817029,140.612867,178.742885,200.005097,209.197573,224.826824,214.848186,164.893224,11.813564,-57.378372,-148.740032,-170.791604,-146.788686,-54.58709,-25.289227,-9.352172,29.742988,166.313146,197.436206,168.821293,204.560997,257.315097,363.204758,414.569961,430.395902,349.186581,123.480086,81.604209,190.227813,267.735917,248.293959,273.253725,330.312191,345.006321,274.95553,161.088964,239.501743,284.742915,254.698313,196.60733,96.785177,71.299335,48.501412,43.950171,66.884783,126.549335,153.975327,196.566138,206.79718,238.943245,258.746371,185.64029,29.89146,-12.433863,-10.433003,25.281674,25.804448,-54.754834,-236.313409,-243.267338,-84.783505,29.532832,32.61002,42.23264,67.05101,117.445293,126.19365,120.194802,116.417951,106.308578,73.954918,69.661567,107.236947,144.623475,177.33883,147.490259,97.777454,91.608575,69.538574,52.379292,73.773174,52.387995,-7.423634,-110.100609,-133.413855,-114.375486,-46.347412,-31.715056,-28.144094,-0.24084,60.679561,36.995245,-51.776259,-66.138796,-70.263455,-71.91258,-59.804239,-48.331671,-66.462492,-94.650502,3.090159,65.652286,122.077641,118.877564,56.610395,-0.777643,-91.878144,-92.043892,29.857805,216.008813,274.236656,280.171924,220.583012,44.587793,-14.067835,-23.734102,17.795873,17.22251,-6.696072,-19.209236,-69.909558,-101.136374,-131.161502,-129.975022,-94.656483,-5.423669,41.869968,100.074727,108.127712,68.34309,20.734574,-46.068657,-3.556115,23.798528,68.215518,106.145919,162.34603,149.512045,77.915506,41.593054,18.46973,51.883232,50.272261,1.558642,-31.406286,-70.084925,-61.279317,-2.327341,15.6264,-16.311173,-63.156789,-49.990562,-42.444858,-67.972688,-99.172749,-84.478987,-42.867236,-67.879266,-71.788187,1.667039,27.966088,4.286248,3.514281,30.446326,-7.266975,-55.709962,-151.802573,-152.384918,-79.686809,-58.312336,-102.560206,-164.274895,-282.446744,-335.521492,-377.757672,-443.509768,-424.988688,-378.80717,-390.559482,-388.117434,-265.181677,-181.967578,-23.312383,19.929228,-20.100129,-76.038074,-195.764541,-247.661324,-234.47452,-161.437595,-177.535988,-206.534732,-179.069026,-155.158423,-203.401174,-334.77497,-324.846465,-261.813672,-173.952802,-191.050663,-278.15601,-291.706175,-218.258817,-154.225421,-4.10469,104.362295,111.458927,66.731251,36.512844,-5.843201,-19.321305,-56.849803,-92.805983,-87.089821,28.454061,122.693242,224.825134,200.228418,73.736869,24.129375,60.253011,122.54167,92.246337,10.300103,3.020626,24.37685,16.758295,-18.724194,42.447471,82.630027,59.812945,16.332702,-7.047721,36.193869,118.112418,85.274447,-67.273085,-98.553338,-53.381199,28.775901,18.553841,-14.19831,9.634236,54.574862,-13.631619,-73.122097,-111.193238,-62.779309,49.937145,64.865816,10.145621,-52.34635:-283.583442,-249.656243,-223.514914,-177.960327,-173.173003,-220.855059,-251.782284,-273.503787,-204.008554,-141.657771,-19.962405,24.279581,65.559665,78.064551,93.446958,73.72341,10.612962,9.753107,52.680348,179.83332,207.126912,149.031314,97.122591,22.890022,101.787921,193.571433,345.283013,376.524752,337.089183,276.59788,118.283043,31.637564,-73.027473,-56.346474,-33.671882,-5.748691,-5.276591,16.565203,45.160139,83.763455,68.485641,70.589134,192.289593,298.048903,427.454666,414.108247,347.486298,354.170567,443.966858,477.444328,476.198162,543.731352,589.490611,622.152662,611.472378,571.475316,575.070637,587.27022,545.721572,482.3176,343.008129,295.679372,259.096001,261.10963,244.627852,185.290205,178.992052,219.505168,221.257185,175.190762,181.516956,301.14172,435.529712,482.328118,544.646028,552.64883,503.394174,445.215597,249.914064,138.200165,26.536002,42.051708,44.579419,-1.739498,-36.159293,-51.258409,-50.077691,-87.952019,-98.378268,-89.879743,-41.940419,12.163938,145.417014,193.052959,181.025791,137.868408,91.172208,40.686695,-10.429077,-76.744185,-89.013338,-151.434363,-193.831013,-193.273907,15.753391,144.511121,236.376333,216.698695,215.150533,242.345312,263.006054,250.742167,267.942652,254.828376,200.606577,148.420783,183.560874,233.059068,193.907711,60.706053,37.978765,49.919771,-12.378296,-79.36904,-227.414246,-289.918233,-337.486523,-333.936561,-299.096305,-172.668517,-96.383208,-90.304766,-167.018159,-208.772633,-104.459441,133.878897,99.793978,29.765635,69.688017,203.310589,420.538633,417.403484,308.895762,273.512032,257.375322,234.862584,221.592011,238.131582,260.628958,288.296075,283.683035,265.358492,344.172434,400.371602,384.60197,301.462103,73.772747,-19.675497,-109.753776,-108.685564,-31.191863,39.468591,51.942671,103.245872,160.750777,268.754454,280.304219,224.523085,234.558338,296.951913,451.249522,500.77684,440.860441,335.559939,157.640471,145.079064,259.868044,321.338936,286.590763,238.058799,240.962583,229.424619,214.780454,201.098594,238.971123,261.735867,293.962779,309.272534,263.531042,193.122422,120.080199,155.601847,231.996816,172.16749,143.567553,237.209487,324.358855,408.925344,384.491129,190.251622,-35.145731,-78.837371,-68.348146,-68.902719,-136.923428,-180.850136,-237.97254,-262.004578,-258.789565,-103.802538,-26.379026,15.609239,-5.416959,-40.496775,-37.591722,-18.340425,-37.048878,-61.915381,-103.89079,-107.271773,-40.40699,21.774662,49.69779,-4.672479,-66.834753,-8.156867,19.445968,52.861425,49.200136,-21.50818,-69.636747,-155.609948,-241.63859,-270.241289,-212.344624,-145.378803,-92.336623,-107.409648,-157.51824,-198.887722,-222.231588,-115.290262,-95.075527,-145.015473,-163.957622,-147.070619,-130.198486,-129.517272,-164.411493,-171.474833,-140.278916,-131.749888,-198.142357,-241.611583,-274.800594,-259.772377,-86.859688,123.969934,126.601341,25.430849,-8.855745,-48.28731,-68.626854,-103.48706,-128.29099,-162.961991,-242.348911,-239.041044,-159.019717,-119.843834,-116.063626,-152.390964,-183.040732,-106.647908,-75.250964,-90.854011,-126.821411,-207.390793,-248.596212,-315.794996,-331.942914,-308.230959,-155.657339,-71.547832,-29.482774,-42.541311,-48.716252,-73.779087,-164.281956,-173.616553,-166.352664,-152.549985,-126.025366,-54.172694,-35.227265,-15.559348,-0.523139,-32.035732,-96.451953,-70.650151,15.107395,27.558268,40.791296,61.371834,101.885675,94.525901,83.513698,46.585826,8.910594,-36.651779,-13.104392,-1.059105,-141.389641,-181.339771,-136.801889,-108.461356,-80.634761,-71.607586,-125.200763,-189.727818,-263.257015,-259.133227,-278.179799,-310.07489,-285.215931,-162.387272,-117.195494,-163.12289,-214.257077,-159.059791,60.365719,143.462769,92.505501,-29.113709,-279.581265,-326.845266,-208.231284,-86.150116,-95.512189,-131.48859,-115.703279,-49.637023,-57.619484,-179.294331,-212.477631,-199.220772,-192.364326,-163.776956,-85.338406,-74.587734,-77.140975,-66.362823,13.115432,149.546869,193.755114,182.327833,121.342154,-76.037612,-153.416762,-177.586254,-127.435688,-116.295836,-89.154299,-69.249529,-85.855619,-120.685211,-190.95659,-218.02692,-179.015435,-28.482359,12.485769,-8.180711,-44.539869,-146.45747,-204.159042,-272.679275,-234.521726,-205.014737,-224.612761,-255.879919,-224.259928,-167.267415,-115.099005,-124.107181,-111.763236,-92.142217,-111.038854,-175.156957,-204.622293,-201.070037,-162.748285,-119.725763,-164.114535,-181.735764,-172.962666,-146.984267,-92.211112,-90.785277,-156.023729,-214.254629:-51.732888,-50.848888,-22.470102,45.69957,36.930255,-78.752487,-145.470072,-186.765795,-98.751113,-80.118658,-129.290768,-133.81007,-46.396211,10.716818,45.038934,21.768811,-19.359619,-9.688168,20.61566,97.973965,101.581812,30.0639,-6.948417,-46.992279,-23.713329,17.457821,85.674887,91.823396,20.301248,-50.709475,-158.578282,-160.7715,-131.762829,-189.594855,-232.088087,-254.361939,-221.57183,-103.917543,-60.113734,-21.749145,41.522465,72.891575,188.327328,295.941636,482.043556,507.745031,451.77836,399.534369,318.643631,333.63191,373.813474,450.498786,447.019534,370.649353,340.253134,328.473951,349.578242,366.86931,417.213063,444.317526,411.13519,335.732452,193.055071,149.976676,74.115556,25.133181,36.768998,95.114764,111.5159,136.757792,158.807993,189.30534,162.451407,139.300655,169.368146,212.62164,213.608652,175.948584,126.565736,117.164906,139.996222,217.111387,237.514498,184.192037,125.01132,27.259168,3.208501,12.405472,105.224495,154.419526,200.594428,209.102831,189.132643,130.835686,-55.907167,-128.770259,-149.546943,-75.769648,-54.952709,-111.202148,-188.153104,-347.566173,-383.024135,-335.450791,-181.896406,-103.101735,-25.987305,-39.763139,-75.191041,-75.689577,-145.766184,-205.267367,-187.631628,-53.159589,-23.754544,2.908971,36.268278,71.914698,27.448442,-110.459164,-77.106832,-19.735954,4.844744,-10.821418,-21.436034,-51.337169,-188.003595,-258.468254,-323.990809,-235.779987,-147.177795,6.509682,18.570965,-47.085739,-61.758208,-9.749292,88.509918,143.023828,288.37946,366.420769,394.132222,312.096906,99.275373,54.775316,122.027678,231.579311,258.459372,234.427393,195.564197,199.392956,257.57664,324.371835,288.49845,271.671699,229.143528,188.266927,61.101425,-4.673376,-103.523065,-154.023241,-226.936012,-129.309825,-49.004807,12.093848,7.866076,33.082616,54.38184,89.213728,197.567497,268.724863,355.421358,373.369766,372.349119,339.835348,205.637507,129.004589,78.618587,188.5581,236.960181,235.211508,189.088164,88.22593,75.038716,84.109651,96.881784,122.663937,171.22438,172.871562,156.230218,153.762543,126.316352,109.59958,152.930196,199.382784,182.398701,169.79393,202.879394,290.39108,310.098024,230.521697,50.37856,-0.89306,42.476892,100.107253,138.431256,94.263028,-54.29726,-102.819926,-16.2258,171.81178,185.893044,79.748329,42.388033,68.041387,86.961274,87.659147,87.945865,71.183681,37.330868,60.365086,93.17138,34.765849,-114.348388,-106.272039,35.980711,17.867509,-63.217915,-161.653366,-151.907618,-94.047535,-87.884913,-94.610405,-17.171964,9.657881,2.356892,21.553618,65.336049,33.651935,-66.440956,-96.622746,-125.947917,-120.32511,-104.779567,-28.819599,9.416781,19.88704,7.99302,-8.304042,-0.937494,11.547312,51.216957,80.608589,98.983374,80.88211,41.716079,27.684202,98.370707,304.934341,365.545189,288.093548,174.958197,-43.434763,-109.914194,-183.813034,-169.29894,-120.978603,-22.194932,-2.156861,-34.949455,-66.812218,-104.071311,-113.290674,-119.064805,-87.208645,-65.283626,-58.140016,-91.126566,-198.327765,-238.304617,-224.764155,-99.842219,-49.897947,-34.498219,-21.545682,63.359164,97.810014,90.983317,63.84836,80.616716,142.152973,129.565522,35.896896,-36.031143,-142.296664,-147.640473,-109.217502,12.879339,79.935958,116.568011,91.24155,19.969786,6.361246,27.906081,10.136024,-83.247152,-52.07317,3.004502,47.287593,24.821818,-53.102454,-75.18137,-67.399374,-90.073112,-115.908699,-117.055093,-103.582018,-134.314402,-149.059832,-98.377498,-66.884765,-64.852242,-179.515079,-256.636815,-303.428999,-276.648428,-243.941454,-235.146098,-210.638384,-239.165966,-233.095673,-74.967118,24.158769,30.437788,-54.429274,-214.342382,-241.684646,-158.393867,-88.257504,-103.700384,-120.443234,-120.86622,-188.511618,-234.72027,-255.961176,-198.625894,-166.473462,-140.121951,-140.09044,-140.309452,-161.408044,-253.791417,-272.68957,-185.693422,-24.917309,32.536272,25.354993,-20.163434,-127.925692,-202.652477,-358.506919,-301.157945,-190.484359,-22.267324,-11.612728,-64.389951,-82.844319,-80.174351,-76.127708,-66.559509,-35.626666,-25.570031,-48.802309,-66.576962,-70.271969,-72.176522,-111.35391,-78.315946,-16.766728,65.035697,60.687075,2.499845,-43.815031,-134.069524,-150.176813,-114.49672,-57.558745,-66.065159,-122.610565,-125.915649,-67.979288,-29.20637,6.06254,-5.483899,-6.68097,16.021839,21.405326,-29.855613,-54.620755,-60.225309,-74.464277:backward
399.286824,372.473744,377.365431,395.142608,354.164435,188.02906,155.400719,208.810912,240.264581,242.621779,262.642636,279.185079,234.13327,168.589104,71.252697,65.699986,137.572779,235.73416,249.968714,156.814162,72.121623,1.220599,21.65995,56.603953,120.898949,153.872154,149.154787,139.441715,112.182838,66.264902,-14.589563,8.662406,180.658585,313.003521,312.997683,261.649656,234.221526,125.609954,52.877194,4.122368,126.697886,178.374257,138.534802,73.648206,-41.688552,-75.740658,-89.524201,-79.895005,-56.357098,-42.208262,-46.441617,-58.876764,-56.294368,-42.677096,-37.066233,-48.855143,-65.44924,-68.770467,-87.684227,-90.939562,-67.278307,-42.652885,38.113747,79.153888,111.299684,62.464844,22.63271,-17.370633,-32.577281,-76.562627,-75.174217,3.775208,105.552447,110.041482,10.098037,-55.150676,-150.704464,-168.26324,-125.94951,-101.05165,-76.621733,9.601607,48.719785,24.339203,-26.405671,-84.823688,-63.076686,57.144411,150.524719,119.55234,-81.496971,-162.009791,-177.59188,-149.073929,-43.072897,30.134616,129.497252,66.222081,-33.390174,-217.324491,-246.655652,-166.757467,-76.248971,118.914925,269.794481,322.985383,350.789724,316.656351,182.891752,141.449392,237.820347,347.085805,460.565079,307.830948,228.527578,203.812492,191.949382,122.678554,124.237499,166.091565,133.640227,98.668569,49.157077,59.921286,109.69784,97.620787,5.10328,-22.633827,32.120614,153.417558,176.097125,76.971543,-25.136711,-162.712514,-150.549995,-93.689949,-115.342527,-123.399532,-112.015029,-112.379347,-112.793403,-75.769638,34.959784,48.536086,39.357438,124.067609,163.394973,124.606011,48.877287,-97.939929,-125.511762,-117.870193,-96.129727,-91.67853,-130.479898,-168.404209,-256.432624,-303.823024,-361.153665,-348.406955,-249.028943,-149.59849,-125.486514,-105.955427,-107.207981,-123.80474,-112.636753,-50.102673,-20.661216,-27.863669,-104.977462,-169.001625,-249.366285,-234.290022,-103.030031,-12.42345,143.138839,150.223742,100.482804,29.904959,11.119147,-32.419437,-17.894495,61.999559,-7.82234,-79.452725,-122.995488,-98.066509,-81.872803,-95.096365,-85.778179,-68.073607,-62.854417,-109.934966,-150.713743,-259.067569,-308.396674,-329.208578,-298.026251,-244.488462,-253.489998,-260.1279,-275.33583,-286.371197,-313.314951,-316.673433,-224.62975,-140.137604,5.098867,26.718812,-4.358154,-46.30766,-63.25426,-133.525478,-144.493876,-72.029992,9.59335,18.408584,-41.985638,-90.997557,-192.542635,-226.49956,-185.527151,-138.259491,-122.251758,-217.695246,-258.190553,-239.926868,-209.745892,-179.296815,-189.166546,-244.177129,-167.98721,-83.171346,40.456992,78.79896,94.856347,50.314533,-77.959196,-125.904678,-177.244388,-206.006263,-221.556986,-239.032461,-257.217624,-344.739169,-383.562751,-377.995197,-256.6853,-163.061741,-0.245721,15.983175,-132.648098,-245.327122,-352.07683,-322.7439,-189.114921,-117.82538,-123.5809,-124.737927,-103.830628,-68.384695,-64.160286,-76.431662,-45.403324,-26.778858,-96.249006,-158.047298,-219.037931,-222.223243,-179.234979,-124.801051,-2.458616,11.319714,-41.796098,-186.767663,-244.587611,-301.885305,-301.354929,-240.287112,-86.061457,-16.597383,-37.655431,-105.788356,-198.498772,-197.240325,-113.368627,-65.41937,-27.357178,-79.509019,-158.917763,-309.978117,-321.511682,-303.326845,-322.650212,-331.224345,-254.268836,-250.01976,-283.099073,-257.511025,-175.856103,-173.531547,-193.509078,-179.17339,-115.825376,-48.812796,-25.354833,-36.183477,-79.963215,-132.831172,-76.19461,83.52782,65.359958,40.666784,75.827527,102.694611,112.085752,115.857771,147.632595,163.887941,212.555148,245.100244,225.682725,170.142552,140.169549,69.545238,62.051188,110.98685,125.785416,104.253212,87.057225,103.37849,91.495342,40.120235,-119.129706,-182.38585,-126.757656,78.678507,132.198014,76.991023,-6.542346,-147.700046,-149.22834,-26.878122,71.20029,66.407719,-40.799206,-107.739939,-144.089138,-101.607735,-6.810943,12.235873,54.997182,84.201632,40.629435,-82.187645,-96.690608,-34.536672,-9.163671,6.370446,96.513294,129.590025,25.829303,-54.038736,-105.14168,-83.184783,-6.264736,20.605295,45.844309,106.892186,145.907857,134.24408,45.837106,-151.433679,-153.920772,-6.63253,44.285787,1.912533,-101.386643,-101.688311,-8.800726,26.760008,20.419668,15.237896,125.899888,272.620467,277.028081,212.59646,189.187865,186.634233,200.556721,239.100409,282.875438,292.121171,272.378606,243.935717,153.436251,123.524636,154.757377,170.126683:303.857676,347.979104,338.741415,281.00313,244.964631,184.010186,147.560762,38.721647,29.825914,65.572818,46.571207,-8.944155,-89.989847,-81.297506,-6.801857,21.195464,75.693964,122.434175,104.766474,-29.483868,-101.839604,-125.128965,-81.438402,45.36898,165.109957,172.692924,96.724631,64.059242,49.360871,53.262617,70.472306,86.166826,180.630122,301.462218,285.683656,174.530705,165.831978,250.688778,282.718089,227.889578,104.157227,64.675154,17.098182,2.51638,-4.112677,-6.979983,-10.461005,1.976187,71.627131,54.478746,-45.126769,-223.285672,-206.969526,-90.314132,-79.350177,-124.711939,-87.776722,-46.333755,-5.485907,-11.751633,-53.861458,-52.270085,34.474227,81.00904,126.240952,91.617598,61.498567,50.87663,46.7254,-21.909566,-48.52827,16.529396,176.818672,222.086211,176.540024,110.578316,-14.616891,-40.454796,-3.555973,36.46576,123.199891,159.429648,134.036193,37.801203,3.702373,20.1263,56.208212,130.763843,176.609872,170.662626,113.356178,79.212879,16.134054,18.157856,127.421115,175.322638,160.382055,83.970534,31.132731,-73.140401,-94.521334,-71.85039,-36.658981,96.519907,300.00323,353.336302,244.35902,134.752152,-17.555546,-5.63692,178.496178,254.12171,244.066982,189.336284,175.862882,87.39049,11.158102,-8.004894,86.726919,275.459041,251.663862,195.141355,136.04509,156.239085,199.463551,173.181859,45.392722,-4.245563,20.290692,88.221656,59.451219,-99.58294,-173.769724,-203.366365,-166.897968,-95.650373,-45.122068,-34.082869,-60.850965,-90.439497,-112.467967,-63.593543,112.325708,156.729595,76.11787,-36.576465,-47.387665,-30.221998,-48.375142,-121.712818,-126.16851,-80.197297,-57.620601,-62.234982,-100.342817,-141.567881,-233.24744,-245.506594,-185.786431,-138.946406,-65.684981,-60.213637,-88.586613,-142.256222,-131.893662,-39.49952,13.561919,82.765585,108.626863,89.246052,-8.832234,-52.414213,-115.27536,-131.671636,-39.503771,61.593924,238.598566,299.050062,296.517452,247.616052,174.452991,5.926968,-4.909405,73.94064,37.725259,-21.320189,-86.660531,-84.62888,-79.693379,-73.679904,-13.138374,16.052748,4.334545,-83.293801,-125.407141,-171.331801,-201.715596,-265.117408,-260.822981,-173.913042,-116.771781,-149.807772,-283.016863,-329.558533,-340.245589,-316.492783,-224.587436,-163.058535,-59.172565,-41.338479,-43.699362,-34.993466,-42.910114,-88.49803,-96.791035,-39.538362,29.907011,13.392337,-130.485759,-225.073934,-339.38382,-319.909633,-149.795392,-50.636735,77.722163,44.133128,-21.276345,-126.684617,-159.973863,-198.682811,-183.658663,-89.376677,22.944513,49.422987,82.861681,127.735209,179.151851,147.023235,30.96832,-22.614572,-81.280563,-108.60934,-115.35177,-91.618875,-89.977679,-167.722543,-211.120405,-216.090137,-161.819139,-136.987513,-110.054373,-105.973994,-121.588939,-149.317579,-218.26881,-224.868732,-130.44661,-67.088647,-86.699725,-111.29434,-104.49615,-112.045422,-119.472688,-70.367486,68.314443,114.463716,80.749041,23.220797,-109.986673,-144.059487,-98.218082,-45.3838,65.62077,83.495806,40.791055,-86.672363,-161.321765,-271.330555,-257.081704,-104.086901,37.751851,49.108222,-64.862603,-128.53077,-102.084755,-37.360663,24.15385,5.409815,-30.699013,-58.142928,-119.868952,-289.965969,-320.580999,-228.348825,-180.158805,-256.066389,-403.748462,-405.97591,-279.931464,-207.426888,-172.991838,-204.122205,-222.030492,-198.564868,-191.116997,-194.745874,-162.108728,-148.93724,-200.058598,-258.907132,-213.810481,-51.136242,35.882415,43.31419,76.751594,103.939458,78.978741,35.626593,8.103598,14.600928,17.063254,45.291611,55.293227,9.887574,-22.237649,5.880003,57.085349,122.636755,111.629814,81.111554,34.308107,33.485082,12.451177,-15.917187,-72.753015,-83.947187,-11.165831,126.384768,164.110788,113.719563,42.663566,-24.441421,3.821933,74.474746,73.938751,52.104216,-6.255257,-29.4269,-66.751939,-75.615668,-20.814559,28.709563,68.270566,26.659388,2.797155,-46.238983,-89.086305,-222.67714,-278.513681,-235.244816,-8.910412,50.03558,-52.070967,-125.039528,-120.035861,-46.613601,81.035741,96.274056,139.385752,184.021451,156.302864,32.875609,-50.183658,-175.785407,-178.366345,-78.844277,33.92584,34.202383,-48.844925,-59.222183,41.167328,100.173186,109.709963,84.09735,142.457828,274.071276,276.340193,180.175332,146.203484,162.858074,179.484375,194.441648,250.062497,277.681982,283.395947,261.388438,143.634116,75.540571,39.569054,45.786899:206.842389,276.615048,282.26998,261.134848,247.627862,206.520978,174.395786,78.896505,-21.054002,-56.790367,-80.990479,-68.384579,-57.896214,-75.66806,-102.437864,-83.202526,12.883421,17.080563,-34.873952,-118.906385,-124.819178,-76.470218,-38.852962,27.737496,66.905588,49.322928,-14.963105,-18.027841,32.432892,48.000227,25.63234,37.125864,213.055016,376.813987,359.934336,221.509152,179.531114,221.608013,263.985524,258.235607,132.528809,56.401604,-48.509101,-46.451002,1.243183,-17.149324,-105.314564,-105.315557,-27.626182,-77.106679,-161.064793,-304.538856,-331.218187,-291.891301,-247.453609,-155.700927,-68.805739,-55.746172,-124.417207,-182.368734,-262.408715,-244.922316,-71.972047,23.234472,94.572358,47.362404,11.473707,-60.202995,-82.060809,-25.324223,45.691748,144.2479,172.076879,185.478464,191.83842,162.485514,53.367962,20.078312,39.970624,64.804055,117.97157,128.304382,98.90344,-6.852815,-57.003506,-51.945485,-2.528287,97.321288,184.680148,237.775522,314.521942,289.628272,125.460713,76.298934,158.46343,219.223501,228.848541,160.19785,110.06243,-15.806137,-62.683536,-47.880379,2.110442,90.91616,162.270245,169.618383,83.678505,32.136569,-7.050457,15.422207,85.229025,86.458486,66.595005,65.503865,33.108053,-90.62818,-136.321283,-74.608396,16.172173,142.748373,119.020368,84.32864,13.794297,-21.884775,-43.355868,-20.461489,8.09279,-2.804695,22.2791,102.113729,92.590374,-39.994249,-111.853454,-166.39657,-148.48299,-61.212155,-5.541942,-20.166239,-58.445738,-59.214604,-57.338968,-52.943134,-8.687975,35.013474,125.15395,98.031106,43.581806,-70.966506,-120.893041,-159.261854,-144.78324,-112.055545,-77.083433,-62.756418,-63.335444,-81.062085,-141.02996,-162.638759,-153.566707,-126.005253,-69.941323,-71.986629,-56.631126,32.855305,50.952398,27.336014,52.637017,162.083765,118.127171,24.784151,-145.640143,-180.070031,-156.298638,-106.898749,26.321943,100.661653,260.325754,297.355882,250.653131,153.021202,118.429689,79.155866,77.517249,63.328556,27.728527,-3.674778,-91.206844,-133.196925,-183.944992,-176.493114,-115.243996,-86.499862,-64.282712,-143.448987,-195.622447,-240.179386,-249.280196,-251.198773,-225.198481,-145.976043,-112.576305,-134.646786,-211.306281,-240.691039,-301.980796,-312.383467,-183.482591,-75.517483,40.919486,-25.45197,-57.9333,-48.807903,-32.494233,-0.825699,13.685516,26.506572,-17.37968,-74.695253,-201.105693,-245.788038,-268.409247,-235.358257,-91.159632,10.3151,190.733932,154.300247,63.513061,-76.987194,-86.258841,9.871493,76.136716,127.595471,106.776316,95.937397,67.780214,58.097813,81.56639,103.008303,85.237118,48.46922,-0.438741,-53.871091,-82.836273,-82.948695,-79.352493,-104.701051,-109.527987,-81.492756,-21.779338,2.464611,-39.526519,-105.055273,-200.741927,-184.758833,-113.996417,-109.291171,-87.597388,-46.017311,-60.013793,-151.320229,-195.543795,-197.416909,-159.260467,-72.233487,10.883575,64.352702,144.691499,106.766439,-103.674018,-160.797661,-43.54136,54.070462,115.087295,18.968886,-38.116949,-160.71361,-224.114786,-287.024533,-268.643725,-163.940385,-57.590709,-30.256947,-36.494353,-54.377881,-64.67296,-33.672668,87.412951,136.020162,150.952722,58.435098,-15.60201,-162.457113,-202.693208,-192.524162,-171.079996,-156.919719,-175.244228,-193.971811,-239.795513,-235.940615,-145.686386,-96.404844,-88.479708,-128.092107,-196.602079,-188.451648,-158.827797,-125.820565,-166.124778,-252.304607,-218.716322,-45.854029,82.605951,112.864412,120.651923,102.321765,57.654213,48.136286,25.959025,12.183832,43.157236,66.67428,38.563322,-55.949517,-91.055126,-68.229545,-21.427304,26.568307,18.653076,19.301971,34.42226,42.821862,-4.40959,-51.401113,-72.355653,-35.656824,68.754923,159.625982,178.232131,102.560126,31.727605,-1.831589,43.294866,88.627431,71.573581,79.174702,84.881907,62.921667,37.257335,59.922921,99.36683,94.41763,66.467625,30.299031,7.900219,-78.461462,-147.533172,-248.736075,-248.869886,-155.049323,4.507319,57.500984,46.339787,6.873226,-39.950226,-18.932674,46.750722,61.160707,128.485303,224.178998,233.936394,129.964768,18.932409,-141.745361,-130.366909,-16.729662,9.349561,-23.916206,-72.552672,-55.573368,46.347486,103.100667,136.728558,106.22245,86.691524,182.184793,214.660658,153.893524,77.155225,26.851167,77.577194,172.594524,165.484358,123.741139,47.795101,58.724821,78.893497,43.048329,-25.058246,-21.184131:340.845756,369.181697,361.054864,388.19786,380.95684,229.21655,139.689508,84.293726,185.646283,227.516585,212.01469,195.255118,150.076015,87.069455,-15.514798,17.592859,183.404204,178.807204,117.076864,16.585124,-41.175816,-135.475882,-114.887593,8.10537,76.292807,63.011104,-19.21007,-45.855105,-52.47589,-53.270686,-30.286904,10.249611,131.101734,221.739983,221.14795,158.633282,136.764145,172.977127,205.72614,194.864894,143.844067,113.936896,-1.798402,-61.293716,-99.647455,-94.028136,-104.748021,-113.244881,-115.586764,-157.145003,-203.109764,-261.613104,-255.966036,-265.861841,-288.637081,-247.672844,-157.027694,-175.874531,-274.084296,-291.52865,-287.209319,-273.77359,-180.433967,-117.142149,-19.22965,-17.834141,-61.128157,-150.20855,-166.281801,-137.435982,-92.093821,18.172807,74.776105,81.368305,56.07652,13.562923,-101.625181,-123.861547,-75.406918,-56.975268,-12.782993,96.288637,100.103166,-9.567184,-56.784035,-52.766001,-9.188796,148.777984,294.286766,279.902138,116.183173,51.727028,2.99985,-12.445546,-2.173342,38.776586,142.656467,146.791114,75.013056,-121.395027,-180.93609,-183.547588,-141.521208,21.588211,225.519329,274.244229,205.694882,129.914129,23.468701,23.560294,121.380065,182.881899,222.52793,142.559196,95.589205,-2.12067,-50.913232,-54.764635,-7.428939,24.190188,-61.411078,-80.215179,-55.961046,-51.171936,-55.385395,-47.044296,-28.915478,-22.336391,9.238707,35.84635,36.622621,-7.334011,-60.866157,-150.826746,-150.975886,-96.711275,-35.975865,-26.220024,-46.843867,-43.686931,-2.332277,25.862235,107.901237,148.167361,199.743768,197.736516,169.417564,79.081851,17.16054,-65.62382,-50.34947,-1.005895,-2.551095,5.14687,37.652784,34.03591,-56.740468,-120.650905,-184.184454,-178.429766,-131.763573,-91.330876,-98.822974,-156.056811,-164.704641,-66.411758,8.119114,55.638585,17.222386,14.067322,-20.171021,-60.120628,-138.185695,-161.369348,-117.794851,-50.352751,119.471681,240.924128,239.249597,134.502166,62.570165,-45.817054,-58.112308,-47.815916,-68.845705,-74.697358,-57.550402,-63.139233,-121.047776,-134.823026,-102.005105,-83.621375,-79.489971,-112.562491,-138.83072,-232.131622,-309.87564,-387.789514,-331.402847,-169.709216,-174.987282,-221.917962,-286.337575,-302.865375,-323.974073,-292.800473,-135.266747,-69.251492,-12.338605,3.053863,4.675505,-1.313036,-30.353439,-106.993771,-107.119195,-23.940453,43.857477,34.496419,-32.164367,-59.24823,-109.510329,-131.784413,-112.179805,-68.427121,28.947092,23.183535,-25.391526,-114.879763,-127.614686,-79.624235,-47.034123,-5.976086,95.943049,130.269725,40.996011,-32.539479,-92.772491,-80.003909,-57.297839,-75.586177,-136.119617,-200.323556,-239.776773,-280.827728,-280.794377,-307.366516,-341.693813,-374.307125,-255.658069,-180.585429,-168.886012,-227.793649,-328.459814,-330.116578,-284.813885,-275.689325,-250.731172,-169.033837,-145.126771,-177.014997,-203.559636,-192.174618,-149.361251,-48.669645,49.546125,103.842731,152.735676,109.211528,-81.057529,-146.233896,-102.409108,-26.40425,143.554133,156.555484,57.79065,-179.761815,-248.114119,-279.342027,-261.526747,-163.590384,5.166595,74.135905,51.160961,-26.739206,-179.658811,-217.160874,-148.327501,-57.727946,99.586195,83.083052,-2.950094,-200.697528,-263.623428,-312.050533,-302.024362,-255.522058,-240.326017,-247.712782,-279.456096,-281.84046,-238.559864,-204.11876,-130.93154,-118.158178,-146.813186,-133.656162,-115.648209,-125.425859,-154.021026,-157.839044,-93.840483,66.561276,122.823289,135.835211,199.921854,228.742497,182.717683,134.489686,131.024835,158.365769,190.346351,228.789931,233.685591,165.99982,103.445688,32.981679,60.559672,148.29074,119.543935,83.25182,58.280532,51.388157,-20.50982,-70.490115,-146.410379,-164.231079,-82.83779,156.360854,245.82866,201.545078,98.1093,-68.347119,-91.350873,-38.851776,78.558543,111.943571,70.478387,20.440964,-53.369911,-45.117775,42.741201,80.35867,119.345119,97.19233,68.960507,27.994842,0.538961,-45.499687,-51.167598,-63.358553,9.080351,62.460558,59.404435,14.311303,-49.272412,-43.595186,33.629961,92.409239,190.0519,174.093018,140.60575,28.851975,-58.068209,-159.261072,-137.808767,-84.583805,-85.86645,-79.672975,-76.064165,-70.2984,3.000211,43.294732,57.026043,53.673181,109.523474,190.056187,200.377586,162.679811,134.266846,152.744437,196.306963,221.194776,148.589595,110.238375,85.055941,98.265591,80.733799,41.140075,5.987422,25.561275:337.238897,313.521427,281.152166,244.837137,222.729856,171.194059,166.343102,156.044267,125.0226,110.862731,106.824617,130.580254,152.479591,119.609712,42.652148,46.405892,142.483063,161.492757,103.996716,-49.128766,-112.07556,-156.444677,-132.070451,-38.559351,65.359681,66.892749,-71.716962,-125.573443,-98.995831,-70.335705,-21.980374,27.629976,187.298156,279.306602,266.571879,167.033702,108.09171,123.667597,213.627334,331.836548,234.749173,151.659593,-2.786732,-48.034056,-84.770083,-115.858698,-193.695258,-182.574111,-70.13524,-120.605868,-224.520833,-384.402165,-400.562599,-344.416336,-305.88008,-250.902081,-198.000997,-195.525122,-242.95477,-260.239707,-254.756248,-228.326287,-117.047344,-41.301086,87.28356,52.070886,-28.731967,-202.836932,-250.351042,-193.31873,-87.364938,183.861016,303.877947,285.448308,226.14665,189.150772,55.897468,1.98617,7.509139,58.16604,206.731909,244.559881,187.378956,43.804293,0.253559,-4.361348,30.141598,164.176117,341.241448,391.985137,328.511664,242.464974,92.488542,63.819898,131.067912,202.270694,321.89627,292.676395,193.434368,-53.55579,-123.337802,-113.809814,-68.908007,37.208209,123.579215,131.994294,59.172782,-5.508205,-124.801675,-136.691494,-30.629534,30.971585,57.699267,7.931187,-15.536305,-50.849914,-72.587214,-88.706892,-69.195103,-16.587712,26.334132,28.373212,-33.043674,-81.654604,-132.94699,-103.921904,-12.225901,0.388628,15.537296,85.291217,105.294289,84.553343,55.765563,-7.749497,-23.571737,23.580562,116.792209,144.294447,162.212627,155.157024,119.479642,124.030692,232.145723,308.637677,413.887643,364.839846,290.15737,142.526028,74.65212,-9.232707,25.654685,192.511153,227.493244,177.580677,79.841191,65.695454,35.552038,1.964085,-19.227684,4.600554,73.915789,122.765945,105.818526,-31.253556,-100.673078,-82.799437,0.797735,156.570099,139.231273,58.710603,-113.048904,-151.147681,-165.140983,-158.246701,-59.805598,34.53706,190.900222,192.662734,176.619257,128.050283,48.031671,-136.906059,-162.261663,-84.54193,8.913841,24.618385,-7.5118,-47.335931,-166.360767,-199.969076,-118.359427,-42.341613,50.141368,-11.079253,-105.339918,-322.541178,-384.73315,-319.258934,-220.844141,-49.692098,-0.463947,-24.424948,-103.772356,-144.202634,-218.383173,-214.493368,-56.927893,63.380088,207.739987,98.722528,18.011905,-25.305568,-2.587791,63.962513,104.086204,185.7664,154.703354,74.089999,-71.68437,-96.224631,-97.238944,-77.306109,21.033402,81.84868,166.100529,163.34426,131.577462,16.204036,-38.176219,-17.730261,50.528053,159.446874,202.411468,194.74368,108.809074,55.001205,-27.187634,-32.101849,27.55301,65.726581,103.987927,-16.84629,-103.513533,-169.485538,-163.773116,-197.299281,-235.268367,-221.519988,-72.527094,-30.261832,-105.675736,-193.803125,-310.061733,-289.887698,-198.325191,-188.672907,-180.783216,-133.86485,-133.790731,-159.291943,-156.542913,-120.876188,-89.69116,-4.01605,88.163618,138.195427,179.809768,126.087477,-98.683408,-178.262947,-117.80678,-20.021294,118.090604,35.188274,-63.348863,-211.348284,-254.929075,-326.321208,-341.375408,-269.221917,-105.092728,-50.592364,-50.484942,-96.79619,-220.702342,-254.029661,-180.420826,-86.41447,73.084765,26.364509,-65.4526,-223.967558,-250.945022,-249.957581,-258.282764,-268.13477,-228.488258,-237.117969,-305.219438,-327.043205,-361.240898,-367.933584,-282.432245,-216.565996,-178.692546,-223.118057,-217.024595,-195.026947,-222.489783,-238.638515,-165.701311,8.904679,33.273142,26.026637,46.313838,46.174868,-1.411032,-5.026381,76.833751,142.719007,248.296511,161.730564,65.326451,-38.58667,-48.424308,-69.697388,-46.329515,91.802242,76.039646,-14.028977,-107.826279,-85.6051,-83.264792,-111.457827,-111.686408,-83.686429,9.621326,114.099081,135.987346,85.550391,10.593507,-120.927469,-107.782039,36.158739,98.383178,77.954697,-0.91171,-59.9509,-139.721882,-102.305381,28.583542,55.511631,88.701596,105.906113,69.916,-70.419278,-139.324883,-173.738051,-150.438209,-84.224736,54.220921,113.185514,87.864963,7.303228,-162.147539,-168.365556,11.897009,123.221842,249.305416,208.043354,137.614206,-27.512312,-93.189847,-102.207984,-47.103777,75.505241,102.458663,65.229303,-34.032354,-46.96477,28.476177,82.45638,109.67881,80.750114,84.460397,122.735768,84.424802,-16.433772,-19.719135,84.383137,139.536634,127.870392,72.145984,62.773053,30.997004,0.970468,-68.407237,-80.114701,-22.459331,29.883321:335.715852,346.498662,335.410006,324.520582,297.870532,168.191932,123.108609,161.310474,252.562706,269.383755,238.592709,209.732999,144.289609,109.141484,74.569158,82.130856,149.024462,222.6341,216.944256,143.123286,95.058003,-3.252616,-31.706525,-6.596661,105.610537,162.350438,168.801925,117.997897,34.200946,23.377983,12.396917,12.448356,103.860428,268.175074,301.263022,240.446281,191.0443,132.754752,121.784238,126.546401,173.166281,190.828151,136.271743,57.248528,-121.501475,-180.556973,-177.203929,-119.195289,-16.683639,-46.274437,-72.744125,-79.171132,-85.997733,-161.709617,-187.933138,-122.542277,-71.10744,-113.333646,-230.250621,-243.81157,-204.211126,-185.384613,-144.23021,-113.758553,-68.043963,-146.110639,-212.553983,-246.455111,-227.34608,-181.261593,-140.355876,-55.767061,-18.124519,-9.987629,-18.665503,-55.062839,-203.558488,-262.986854,-231.888479,-178.842592,-99.906991,-40.137749,-35.586402,-104.528118,-153.377166,-175.089955,-117.975557,49.901716,78.495823,38.509633,-70.331168,-128.356748,-206.420394,-192.399763,-49.227665,14.271581,44.534536,0.061506,-76.116402,-288.570136,-351.924522,-296.8588,-200.510842,18.425772,194.145427,238.219721,190.014801,117.512824,-27.732223,-52.234519,56.317931,151.630407,280.165569,262.414966,222.525857,123.247779,75.060843,47.940472,58.955556,1.184301,-73.962449,-49.437143,44.201093,57.757553,45.133879,68.315793,155.995761,160.583027,68.273822,85.416065,145.512965,155.009562,77.721442,-91.559124,-119.918622,-66.322971,-12.350755,-9.07244,7.890274,35.949854,96.799725,129.28259,183.069455,180.716016,194.000821,274.719968,274.273808,155.362946,84.652246,39.079225,49.673957,27.197721,-17.974094,7.261406,110.602999,112.343698,-6.657774,-50.250105,-36.742726,-23.280287,-39.172651,-48.803,-47.769855,-108.173714,-158.259181,-156.064995,-102.007902,-44.275863,-48.757775,-34.52293,-72.791458,-144.310493,-282.878214,-314.402328,-275.706647,-211.8757,-41.511958,72.601611,65.625266,-52.696054,-122.888,-196.268105,-178.906251,-74.804579,-15.756461,-18.041423,-66.445338,-100.000034,-149.367079,-160.814476,-140.288097,-106.974354,-72.762671,-145.286796,-185.939092,-266.468353,-333.478023,-389.766287,-326.660058,-193.749275,-207.857544,-223.76929,-223.763266,-213.885219,-201.160271,-192.094218,-127.168423,-85.083686,2.857426,111.409109,142.314769,114.663508,73.314445,14.735205,21.923134,79.072615,117.500125,109.281154,64.953824,48.233133,-10.050022,-34.562477,-4.230962,2.889869,-33.292826,-34.397398,-50.059731,-153.862872,-195.645253,-144.683931,-91.183308,-62.080947,-17.279312,33.604487,65.297945,30.386277,-65.415362,-92.03074,-105.930817,-138.596174,-249.159047,-233.465951,-197.382996,-185.606069,-211.032093,-309.946688,-362.315047,-375.250487,-223.934588,-129.169271,-25.207068,-35.072548,-166.259572,-235.72607,-251.684442,-218.205158,-158.584563,-81.789356,-37.704647,20.608339,22.475357,-7.827938,-6.372951,31.709565,41.680683,35.337163,-7.592597,-51.089591,-159.864617,-195.091307,-149.549949,-79.486736,52.188908,34.876747,-26.924426,-140.317197,-175.318112,-192.366372,-158.686783,-58.85998,-44.439577,-74.879565,-162.402505,-198.807974,-241.78832,-221.529489,-59.025753,34.212167,130.005993,82.202631,6.024061,-168.732245,-228.923363,-263.976061,-239.398783,-130.678728,-72.657953,-103.608607,-213.965656,-225.442364,-144.603649,-118.889244,-126.896838,-119.671678,-62.04806,-0.61417,2.249707,-87.336584,-126.626861,-62.222797,10.883037,91.054993,72.076033,80.238994,144.580237,170.883979,176.713589,170.772864,163.821222,148.856106,181.088148,303.622683,288.446071,88.404867,14.681292,41.775479,69.984903,16.756386,-81.274716,-119.986658,-125.458499,-82.945559,-19.144594,-43.386436,-163.526234,-196.483576,-88.573797,116.481506,143.901977,6.924219,-90.001241,-181.715168,-173.46654,-121.941353,-21.669389,35.741343,51.401347,13.246363,-48.80558,-57.040652,-18.854795,20.743127,102.980595,169.213026,172.812107,96.713089,48.165041,31.60962,81.77677,242.885101,300.968108,249.172011,94.802878,70.007195,112.88798,128.641694,133.036479,119.055131,98.990536,180.397471,214.790423,125.767333,7.69987,-140.63722,-93.286013,86.192359,52.847428,-28.021112,-130.233668,-115.123139,-13.023981,28.669879,97.448501,148.088238,238.593731,204.182686,166.575658,165.625058,191.329412,239.035136,253.169186,230.371711,137.197243,82.63605,20.91674,30.801428,91.056478,118.497796,164.667573,165.1978:361.207967,446.623396,437.827934,307.856556,218.422871,97.463,109.453628,252.06515,381.30862,388.232186,269.272929,185.2799,58.866078,32.955663,88.417755,146.334081,235.486389,242.015895,208.771156,76.020252,0.243178,-42.814537,2.636229,128.327655,236.194096,258.94269,169.509289,91.609749,10.424547,1.623344,29.208616,94.832558,269.888036,279.968516,219.272376,117.186957,109.526374,175.718678,219.436161,253.321756,254.142928,218.895578,29.969977,-67.636325,-175.474656,-196.563766,-174.22891,-130.381783,-33.690853,-34.130196,-87.757325,-212.688108,-241.502154,-222.198011,-209.245824,-217.102405,-219.428578,-237.581454,-304.247341,-323.166796,-329.359418,-305.127982,-161.374325,-80.256148,-2.779264,-55.367035,-109.874463,-211.569829,-239.191474,-193.501917,-126.737251,23.47053,136.272654,149.060453,71.524967,-6.886817,-158.588656,-167.714438,-20.087864,74.452868,194.110482,187.5748,127.018859,-28.40608,-79.272666,-78.627319,-15.730847,191.690552,330.296622,327.204711,183.103458,78.878974,-89.057063,-121.111565,-47.227769,32.898646,172.903506,163.769582,71.27373,-199.745951,-303.40878,-317.674845,-246.11679,-53.304966,172.706265,231.167891,133.516994,33.77628,-111.703018,-127.325604,-23.563797,64.557502,182.963037,147.600335,89.373843,-38.271827,-83.33356,-81.455844,-52.766446,-58.74451,-98.740718,-76.470476,-15.743727,-42.066846,-151.547852,-132.828496,56.613327,127.986795,131.015434,114.449887,140.07074,129.364308,55.179952,-92.827625,-117.088644,-62.622096,90.120221,149.312247,193.01764,196.231338,175.088762,183.249857,328.891594,436.365727,535.219004,401.618938,304.621444,109.858651,3.916953,-75.407639,4.832946,248.374014,358.80935,340.829326,206.156746,130.075351,11.138584,-23.632385,-32.843064,-4.090166,106.313762,138.221369,83.646515,-89.947691,-157.183291,-163.678096,-105.641263,30.562835,80.86906,48.433211,-79.65912,-128.184337,-179.646271,-198.967674,-199.141998,-152.735057,55.671397,241.621586,248.489538,83.796549,-45.003053,-200.701809,-178.916602,-42.935043,35.602847,45.45299,9.147833,-43.880607,-187.969929,-234.812448,-211.702449,-164.739824,-74.149053,-92.876174,-144.075474,-248.08141,-295.039776,-309.32668,-241.741906,-49.892955,-5.940728,-72.475638,-237.172283,-261.412614,-204.573386,-157.888734,-46.612917,16.771073,107.967848,125.410178,115.021656,30.545793,-30.992719,-75.073851,-30.684809,115.1606,180.462732,171.824517,119.019852,71.184992,-67.077432,-92.472689,22.366091,96.931989,159.996339,134.364398,85.683542,-80.295534,-153.024394,-119.001971,-18.8645,152.324349,226.13716,228.319361,98.719458,-5.880541,-148.65865,-154.27851,-79.035549,-45.509821,-37.739457,-64.145897,-90.482649,-217.552402,-299.514924,-405.01001,-409.487772,-324.91986,-189.616289,-154.244121,-193.925901,-244.835115,-337.394758,-346.955313,-255.502654,-187.251164,-96.039625,-75.901719,-83.014631,-116.965226,-134.011169,-154.936067,-149.558025,-48.028944,136.946093,188.920393,142.462508,62.631322,-140.515253,-200.426823,-132.809362,-51.705404,86.201239,97.972378,20.083788,-217.507857,-301.870106,-307.936715,-264.900661,-157.856331,-11.144249,35.2444,-4.346509,-81.696254,-288.013275,-354.440269,-289.78812,-187.407923,4.513661,45.781326,10.221293,-121.795937,-221.795874,-406.358529,-419.0658,-327.138146,-281.540758,-285.571208,-304.528403,-301.173505,-303.489874,-318.684317,-296.243869,-243.385747,-146.892287,-153.665735,-177.502131,-235.704846,-270.07688,-267.635625,-185.545555,70.920856,185.36637,165.190833,97.718509,65.18867,-12.326678,-5.714218,132.274575,192.842373,227.521963,187.584466,142.363008,48.820096,7.334482,-37.236804,-21.800133,35.040401,23.777564,-5.404771,-49.260659,-68.278278,-148.118183,-188.463671,-191.378129,-155.752728,-25.256189,122.942753,136.854633,-4.868576,-110.818383,-203.896915,-167.624674,-16.801115,102.647568,102.94877,1.463709,-55.659991,-136.476456,-149.464769,-77.099375,-5.509255,138.897528,218.87264,203.635326,75.586726,9.5728,-34.87668,-24.409185,33.1906,148.36657,177.533811,98.816525,25.557705,-79.875811,-92.630129,-22.684493,53.862558,223.71709,259.843615,203.68082,6.957391,-106.102156,-193.929628,-107.065533,163.000304,188.726759,103.59621,-67.27371,-97.488808,-65.335965,-36.312196,15.087816,49.398297,137.834626,155.562589,129.54483,35.151298,-14.29441,9.204944,84.30882,174.960996,109.199979,55.917901,-13.91844,-24.398707,-42.147568,-33.592026,77.525925,143.68424:342.049211,282.581579,261.441084,213.325467,150.721669,-30.648419,-84.973234,-27.802587,125.745476,165.147635,139.717223,102.480401,18.099415,-16.268331,-20.538813,13.724275,142.597271,242.916401,224.175619,101.89851,45.509184,-41.173663,-58.28798,18.306405,193.497364,266.862407,312.071893,292.741151,215.57076,164.591257,82.334531,70.804895,113.723516,232.507335,281.647113,278.861299,234.763184,131.415345,105.830128,113.07535,165.488194,184.07602,104.457808,17.593742,-109.443201,-120.194866,-80.050492,-60.43356,-36.423719,-36.659588,-48.191236,-32.222814,-22.114601,-109.573316,-179.380892,-201.863551,-83.81379,-65.300638,-171.129151,-207.033825,-144.671524,-101.051877,-57.208913,-51.778544,-83.289713,-191.008267,-257.343141,-316.117916,-300.200834,-238.093033,-198.799188,-141.946727,-135.677765,-136.960342,-166.819319,-194.830476,-250.071054,-263.84697,-251.233539,-238.906573,-147.374199,39.053027,59.424591,-118.355754,-220.406157,-264.974948,-234.094025,-178.275707,-113.377872,-97.40318,-177.108081,-238.753894,-273.516595,-243.121307,-128.050962,-70.25176,-62.268842,-207.637162,-268.874404,-282.660696,-268.457407,-242.130309,-200.313027,-60.485942,-16.929886,-58.024275,-156.231974,-157.067889,-71.261899,-38.402331,-23.120014,4.962262,135.891442,252.734181,267.556558,204.539053,159.416623,119.473287,122.979039,117.361533,73.843786,51.983965,66.061099,100.146305,98.698728,68.933285,90.158667,121.175801,105.003515,69.656588,73.647198,49.107385,3.344396,-99.100297,-115.230251,-67.424554,-15.014924,8.781418,44.398018,47.924546,80.549575,131.520383,245.406047,268.719445,269.128092,299.907308,298.583344,219.765519,168.977339,116.967319,135.759808,233.029379,273.221247,245.352815,190.932601,206.955798,243.814617,224.94064,195.619287,217.739122,296.746932,339.738712,329.617295,247.667489,183.300808,105.816789,114.40561,83.332638,-22.110386,-31.715133,-22.501281,-58.424663,-198.762369,-259.854682,-276.231016,-232.848064,-108.708959,-35.490717,-35.833401,-72.435919,-120.587256,-254.992002,-261.656309,-97.868524,66.445861,93.834716,43.412862,-9.334645,-74.624342,-70.847625,-37.489744,-29.020589,-65.524786,-146.847366,-150.373782,-110.807472,-137.883707,-259.741082,-261.522275,-156.172136,-167.943372,-206.122516,-198.881844,-156.103978,-143.139184,-185.986207,-201.668956,-142.954565,16.557475,106.743571,106.86308,46.963461,11.225154,-34.031565,-35.104183,-8.033593,-0.548223,-11.696953,-36.328647,-47.225241,-104.981883,-127.30841,-58.760336,-13.791339,-33.731558,-140.075602,-199.172016,-234.365492,-220.479781,-238.259776,-251.91543,-188.751238,-60.603523,-37.945124,-85.371954,-93.171395,-45.275432,-49.770138,-139.74792,-169.527864,-161.430992,-156.437616,-170.862092,-200.892432,-205.891727,-200.532411,-190.354324,-136.029054,-42.098242,-3.007126,65.74679,89.262196,7.117352,-86.173102,-154.381095,-101.508422,14.046786,47.894262,62.307715,81.753353,63.730098,54.106539,86.591188,103.909306,9.93905,-42.786911,-142.999826,-186.808179,-245.971053,-261.456021,-221.795077,-157.151342,-19.0542,-36.570948,-116.591475,-261.676984,-275.40186,-178.18781,-98.772223,-65.594524,-203.232081,-232.917461,-183.03787,-149.808984,-124.550793,-102.499014,46.843664,128.90247,160.214414,119.601345,131.157177,107.448655,40.480763,-91.086681,-119.832114,-84.495644,10.617379,34.784956,54.256295,89.357701,184.271139,202.418165,212.82294,227.466827,241.289731,266.753232,275.15143,185.803923,93.249127,-57.128234,-67.710142,-12.002896,52.491558,99.970612,151.772289,139.883623,116.520279,102.825123,38.772926,14.07269,44.248855,112.336149,106.756804,31.050268,-14.418326,-99.464534,-132.072732,-205.216104,-246.003827,-218.604274,-158.244528,-170.248851,-239.693589,-259.071031,-250.060469,-236.71271,-182.698689,-73.75921,-30.654988,-40.614556,-100.413779,-286.578906,-352.362843,-274.449753,-57.771961,-0.833487,-1.267164,-22.57885,-30.668038,-16.189622,1.593522,9.6267,60.470412,72.571628,49.799916,29.084628,35.228798,45.547489,74.310313,219.298335,256.359774,187.906792,70.292887,82.472843,134.898394,108.968884,36.147151,59.037319,191.126222,261.604374,244.006894,116.320785,29.974606,-58.488765,-13.035307,110.091356,22.952037,-66.530529,-185.351417,-193.202812,-156.769427,-138.373837,-79.765625,-32.492978,44.954566,18.908072,-27.81975,-84.487071,-66.033748,42.922997,95.261307,64.042351,-144.864864,-216.584181,-152.083675,-80.461355,-22.357966,-12.022857,46.581775,81.296823:341.107047,348.141656,316.362358,196.776857,133.24934,31.104065,26.244304,96.869676,200.662403,265.801337,327.253749,295.667365,179.007564,136.593389,132.594215,158.731417,230.931936,304.442104,310.211494,230.755617,161.067552,11.642884,-38.570121,11.781557,237.691823,328.589009,374.294425,355.862772,239.956109,140.092221,-33.596635,-65.637147,-1.586426,196.71295,289.383201,305.455306,231.033469,58.729571,10.365545,6.360451,93.49394,148.181013,155.136063,91.00055,-64.749435,-105.853791,-90.747415,-52.14026,24.708761,2.969286,-31.613454,-13.672286,26.592774,11.38554,-32.977324,-40.398129,16.683274,-5.175643,-125.376612,-139.844161,-45.494423,-7.47391,-0.945554,1.061876,22.924473,-13.487425,-71.423446,-176.172389,-186.201038,-139.950012,-108.972588,-69.094527,8.749129,53.967388,20.703947,-35.188745,-105.737191,-139.617829,-220.75484,-230.175602,-150.173672,-24.268457,5.124307,-90.674943,-199.804811,-317.960191,-265.705356,-100.473909,-111.839449,-170.814865,-280.284116,-313.11742,-333.073044,-303.97407,-143.450646,-60.566777,-35.847233,-171.294939,-230.494416,-252.385044,-238.507228,-200.061934,-164.144477,-36.628968,121.508203,160.310043,97.397376,53.774968,52.022819,64.469529,106.228743,156.260146,254.766929,267.664904,261.997117,266.857391,247.507618,175.509874,175.857714,198.665428,126.310388,114.260396,188.057665,214.645029,184.878465,163.843878,176.728458,199.389014,220.094931,187.71074,146.633658,15.018341,-42.735153,-73.419975,-59.441931,-36.258539,-21.854359,-21.623763,-60.529686,-63.045275,55.969406,131.344691,173.551414,161.853944,178.300978,232.965098,251.295108,232.229772,174.80254,14.109715,-30.28338,7.021991,56.501159,23.786552,-47.760024,-34.878889,-15.02354,-33.024999,-29.100161,-10.339768,-19.990913,-24.056333,-2.429403,46.673953,63.063202,111.658216,137.283301,96.72323,21.998832,22.327983,-11.427956,-81.784788,-253.942289,-297.463158,-226.044764,-154.136774,-58.857387,-44.085166,-61.530334,-110.462561,-140.710483,-203.358394,-203.430987,-136.497538,-69.645514,-53.808756,-104.336859,-147.373564,-180.626455,-168.964696,-139.859135,-153.786081,-190.21249,-122.148014,-99.561125,-210.494399,-304.577392,-365.616006,-319.094571,-223.487247,-222.857934,-228.781267,-186.422311,-155.57662,-175.449852,-205.245705,-182.820314,-148.016295,-84.315791,18.958451,64.346378,72.937724,32.14611,-58.64988,-58.862198,29.651956,103.698464,87.843614,-15.708113,-51.052321,-64.465295,-70.113134,-143.089188,-217.3995,-343.5042,-304.721323,-251.593525,-239.515117,-293.703993,-356.717224,-320.406149,-211.031234,-133.948744,-84.7297,39.051065,76.876592,36.88197,-18.65382,-125.093452,-166.99647,-227.524711,-269.069952,-286.102782,-292.301129,-287.8663,-311.209368,-320.044432,-268.823727,-154.742706,-104.60817,-57.495183,-62.991428,-173.96188,-266.780575,-388.308903,-384.263382,-293.884273,-179.168241,-140.608745,-147.125912,-175.408692,-152.155956,-97.160162,-65.884088,-172.226499,-232.383959,-329.568421,-366.961691,-450.701045,-496.546149,-483.990976,-395.114714,-166.641644,-123.357653,-178.117404,-250.298956,-242.368583,-198.90003,-180.852785,-204.720417,-237.914329,-212.858477,-178.871191,-206.556075,-232.202304,-181.487078,-39.482903,-2.594279,15.858053,-4.544376,-51.866704,-170.289375,-211.566778,-254.596851,-248.022464,-160.284502,-95.907517,-116.477192,-149.067125,-110.138134,-8.07593,15.401527,45.88665,56.530174,63.186752,113.159771,134.665213,102.12451,70.039255,55.518526,75.203784,73.607205,57.602535,101.22193,180.065879,175.947371,157.960182,158.295715,144.308975,141.748753,218.889286,302.554078,269.919981,114.523872,45.884657,-50.684315,-72.583152,-69.639041,-81.321353,-103.283881,-98.845501,-52.416327,24.694104,6.391617,-121.22559,-185.516957,-198.561116,-71.010815,-16.628392,-24.920564,-100.035521,-270.891804,-293.19306,-192.852959,-55.181855,-32.228291,-120.671533,-186.940781,-191.88008,-133.404869,-62.444699,-73.709761,-32.008587,106.108945,95.565085,-64.160644,-111.500181,-14.092213,91.882291,239.262001,207.958621,146.786526,46.677466,36.76171,26.045347,0.622465,-42.452495,-44.385433,5.057855,108.747642,157.673822,173.805325,103.956734,-82.926251,-81.054934,108.531305,118.434434,1.244343,-233.198075,-249.97571,-146.561161,-118.449085,-98.718823,-47.178593,88.891824,112.807379,107.776512,153.566479,173.204422,160.327604,153.534875,169.627956,172.676055,158.43943,125.235546,110.462211,91.958045,108.14967,165.546692,167.343226:244.153897,367.255821,385.418317,305.479782,209.512277,16.496875,-2.412312,118.721284,247.900759,261.786434,208.814334,178.798481,75.911524,-2.760299,-35.874356,30.230162,166.177832,254.184942,286.198043,273.609953,225.827926,140.358464,143.995379,214.198117,247.369877,224.562757,158.00103,148.403145,168.95924,171.103007,140.871259,122.357544,124.870565,224.086853,271.096673,252.176249,202.930786,125.243215,123.136898,175.237555,232.185895,243.537765,176.595958,102.47713,-17.968144,-37.940059,-38.582173,-38.797739,-43.431722,-104.454679,-146.167129,-144.601826,-117.457569,-139.583084,-169.689398,-185.366529,-206.089341,-228.513858,-293.103355,-331.735278,-347.134866,-296.114295,-163.731682,-137.581511,-129.234036,-160.534917,-227.156379,-340.422796,-344.360073,-253.267477,-163.963617,-42.277098,-126.137089,-175.213325,-176.186818,-171.423431,-237.63081,-266.734844,-203.49601,-146.000915,-95.612798,-94.251434,-108.171519,-167.918687,-198.605052,-218.816934,-194.318274,-67.716872,69.678621,76.614485,-52.18558,-127.315676,-171.083031,-161.950449,-165.686073,-157.417332,-102.706257,-115.904249,-180.763798,-334.762779,-350.564909,-236.897127,-177.644212,-132.656941,-79.097028,-68.380611,-126.781254,-143.202979,-82.512529,-42.024834,-3.447729,11.450091,62.587832,85.503137,82.290023,42.336938,-15.741187,-130.867494,-120.988715,-59.132797,-122.845504,-128.655247,-67.610563,-56.747294,-31.5055,15.865128,108.28953,107.162676,52.539126,123.044267,180.693516,181.216072,131.062406,50.458839,41.043505,56.480723,83.95229,108.512774,188.099211,215.641102,183.508398,150.55321,173.243948,233.074024,327.570069,287.779942,243.164677,141.993798,81.127662,21.899389,43.280223,80.075197,93.405131,116.396584,132.324127,101.178361,6.293511,-6.534302,65.397529,107.568049,152.550993,129.779224,87.765168,-17.769389,-71.339232,-98.500336,-45.222882,52.833257,-26.591595,-98.265215,-150.699322,-127.487816,-90.087864,-93.47532,-97.358734,-81.455854,-46.467665,-20.243245,0.830272,-8.560896,-68.962111,-183.795492,-173.37881,-76.371884,-8.763623,22.032814,40.579281,20.947317,-5.107283,-12.421621,-50.80865,-72.50322,-84.604307,-51.302464,-46.021565,-89.340784,-138.062877,-239.423114,-255.549688,-285.219113,-309.407417,-260.883828,-169.377336,-184.171264,-241.450399,-241.858118,-201.640618,-169.463035,-63.390376,42.46763,41.73968,-63.641416,-130.199492,-178.746623,-134.103716,16.205616,64.290934,25.623362,-91.218015,-124.974448,-138.009656,-121.02853,-32.636099,-1.983737,26.815757,31.418771,-29.898732,-172.184667,-177.381242,-71.678948,-7.045702,58.99239,29.452205,-1.541746,-61.213129,-74.770649,-59.059345,-57.964369,-106.619495,-137.490968,-157.310169,-155.274077,-180.09619,-234.275004,-239.087541,-236.214459,-251.333387,-290.529041,-195.691783,-108.460319,-19.851998,-36.856926,-116.741769,-163.726415,-239.606784,-239.002322,-144.981214,-44.117238,-7.987371,31.183286,7.841668,-51.2564,-22.384602,109.990941,132.743474,96.677873,2.203348,-32.744933,-112.020411,-158.594351,-148.39717,-83.604185,28.687821,-11.210158,-50.484798,-66.563558,-67.617124,-95.281336,-99.908414,-87.343678,-76.746686,-81.257695,-102.581319,-108.650105,-168.548135,-218.347228,-164.858411,-52.138826,108.164161,58.404142,18.854015,-37.388305,-95.937377,-222.880309,-223.373445,-155.847099,-125.696519,-112.637605,-82.424244,-40.754939,76.820997,92.882498,27.978523,-2.459739,13.219632,59.762838,42.861074,-47.171901,-68.159672,-43.896421,-24.785278,56.190119,194.651484,231.659966,210.467152,184.497324,144.768717,139.803377,158.693723,151.612708,116.978891,179.06887,189.653179,94.390596,34.562328,-55.190194,-77.860619,-82.702774,-85.962836,-89.159191,-106.025162,-121.929689,-137.923874,-141.430544,-171.373071,-187.461263,-157.182582,-31.966745,3.260923,-53.991619,-107.954482,-171.054059,-165.552697,-120.348482,-41.527867,50.357422,225.1015,217.413422,43.460014,-14.414593,48.952064,92.895243,90.18559,89.283652,106.109579,98.647584,67.149887,70.116016,115.373051,157.237161,150.396444,174.579489,203.217072,187.452233,165.703739,155.706294,82.551178,59.777417,151.99698,253.578945,225.155253,47.156942,-44.649307,-107.501533,-56.748321,87.41437,76.650084,29.852102,-73.812727,-106.451925,-98.995182,-56.890389,94.846004,148.500491,115.439058,6.294681,-30.152726,-11.327193,22.116706,57.203721,67.131298,23.851492,-134.934932,-186.948559,-138.671891,-75.118206,1.718437,5.966455,37.780971,84.294128:backward
-2.699621,52.902396,56.454421,-8.519028,-50.033539,-73.826503,-41.221206,57.116388,108.556295,116.010541,105.669198,103.40391,85.274341,37.704904,-45.530411,-17.464206,167.122096,374.981654,436.648413,380.096392,270.534505,95.272213,98.244939,214.779327,257.764331,236.599237,154.798325,116.555138,73.961045,36.96328,-111.827349,-165.126113,-88.953936,87.945384,103.909955,-55.481724,-160.142106,-263.297282,-258.289502,-225.60045,-182.718886,-115.461882,52.033928,85.982398,28.599075,-21.066024,-73.600557,-76.654141,-67.085295,7.989328,75.37196,152.374371,132.351454,73.200717,67.518024,28.554187,14.810667,62.84078,85.808606,12.232267,-183.480813,-265.125777,-383.864261,-422.137539,-432.283353,-272.036836,-179.689223,-173.320312,-249.656366,-372.186632,-374.861894,-302.804027,-205.860764,-178.926731,-198.847172,-208.723201,-178.439613,-180.500857,-257.21471,-285.745196,-311.878151,-373.088531,-394.745094,-384.614707,-357.960121,-268.1239,-188.001998,67.652173,278.914053,312.786149,290.835077,276.256465,249.843071,216.742215,176.306191,201.956904,256.601692,228.126407,196.253499,145.114041,132.093578,72.718357,25.51411,-6.238122,90.276885,126.913255,46.69377,-17.778101,-24.082639,-5.660729,-61.709614,-105.81193,-101.004509,-45.606729,-54.297247,-135.621388,-184.121685,-256.594021,-263.218631,-178.32215,-11.849906,61.271924,138.507849,147.524119,111.080327,64.510232,-0.494861,17.287991,136.037997,232.737295,209.925538,48.677919,-26.127999,-108.936355,-124.02552,-82.588256,17.56653,72.084404,156.580245,177.684137,210.283625,217.225715,192.328027,202.365794,328.643622,426.825818,410.408642,274.269697,197.438206,141.839991,179.504832,283.936605,244.523374,193.525977,199.998095,267.45316,356.934265,292.235769,15.640126,-61.939594,42.356522,222.420486,234.403809,138.016449,99.976332,100.507019,103.394218,102.953975,191.991116,239.95989,214.575156,158.349589,34.374804,-34.827868,-91.940128,-42.28659,64.151823,82.741958,100.415836,116.475328,71.13676,-80.716963,-102.085401,-5.932536,14.222172,-24.393166,-75.684845,-69.981253,-59.49956,-80.269676,-129.930261,-140.095724,-142.940797,-121.141687,-115.154438,-145.039459,-192.501863,-324.250755,-342.703406,-228.647101,-86.722906,-29.264987,47.938346,53.24888,13.996089,-12.559692,-35.019677,-23.715244,0.893871,36.317083,69.956075,77.713324,27.885,-106.095781,-149.760973,-198.528736,-243.628256,-234.521002,-176.539136,-184.707803,-269.37687,-294.899335,-270.682582,-213.849861,-27.577994,70.432952,43.231544,-83.401811,-135.770456,-198.967904,-194.235301,-90.341574,-63.524839,-101.393163,-127.228453,-85.035532,48.478559,87.038755,86.473188,97.963334,157.729742,150.933315,117.671588,47.248257,26.230693,7.77602,6.276969,-11.727572,-70.485761,-94.869696,-124.566163,-143.783227,-227.107919,-289.258819,-340.005099,-296.376899,-202.432216,-202.706971,-188.875726,-104.254209,-81.099475,-157.109085,-218.801221,-226.277172,-121.182377,-92.08985,-121.490881,-158.020977,-195.299811,-206.208225,-246.185696,-244.534091,-176.292603,-103.636446,-102.222233,-160.528582,-177.905951,-134.590262,-83.441487,26.020509,67.471702,69.020358,113.096474,161.957199,227.482444,207.966482,150.290276,162.972346,173.422121,110.232827,108.99485,107.135124,46.529239,-169.873394,-250.574232,-248.317626,-99.472147,-19.608655,67.207135,60.631406,-26.357755,-75.929569,-86.807736,-47.360007,15.626386,79.55334,126.311332,157.154198,112.3896,-41.637907,-84.168607,-59.389332,-73.669606,-118.038985,-193.092545,-200.464379,-194.010348,-212.734685,-263.765409,-251.663974,-120.154966,81.929365,142.905481,106.622895,42.324628,-105.02992,-153.536781,-117.112351,12.167138,84.467008,141.530939,98.558085,28.892554,36.984636,54.124552,55.321416,125.303217,271.124185,304.919332,248.567086,210.948597,190.009195,175.984249,110.479269,81.466106,97.037718,105.761396,82.599995,74.286249,95.217043,73.974396,38.508258,41.494351,109.340369,124.188457,114.865991,102.001262,46.637121,9.658909,-2.398517,56.340668,94.188235,189.212911,224.338714,204.374242,136.062695,-76.546566,-157.395487,-122.985276,56.605669,109.556463,68.43897,-10.063685,-175.551431,-213.428125,-181.080883,-113.629119,-76.147598,-31.530276,-49.563523,-112.662065,-131.952818,-137.449757,-120.75215,-90.003679,-90.471416,-70.900732,29.901678,58.636155,-37.779426,-100.957244,-59.572401,94.556171,135.197044,96.706927,58.808945,37.766729,29.558996,-13.654885,-10.086053:153.65408,219.893508,210.791224,152.359079,90.334105,-44.457957,-61.538707,21.934414,194.009583,267.15911,257.492353,175.754361,2.146514,-44.911949,-42.416002,-4.522575,127.516963,289.480976,326.912802,248.585505,150.785752,-5.646063,-0.548961,116.325477,232.568173,282.273951,257.863971,189.882517,66.151316,12.346254,-79.404407,-95.297159,-27.373812,66.861273,50.0222,-59.246453,-85.824058,-53.803663,-34.536634,-81.322737,-133.669672,-85.372684,70.77257,99.397042,69.029868,56.575168,32.271657,-0.444446,-29.351988,120.84255,212.634037,210.541305,106.319878,-105.637835,-149.494354,-141.207492,-74.675593,-16.745005,41.111717,3.340089,-165.873695,-281.326494,-449.142433,-451.294779,-355.037751,-220.157203,-156.111442,-119.343554,-172.715692,-328.875126,-340.833638,-154.786106,-2.080359,-48.228497,-243.583408,-288.510247,-274.036613,-291.716702,-357.193359,-322.352406,-176.45209,-222.149203,-308.343825,-432.312957,-432.150182,-342.256101,-282.509747,-153.23579,15.331658,86.537242,65.559894,-7.114164,-81.828553,-66.978397,2.538776,50.626327,143.923142,123.70426,50.716694,-128.828055,-179.704272,-167.090965,-131.683078,-58.753731,-5.255362,11.015548,9.20711,-7.880297,-84.839794,-139.791321,-186.709948,-171.396897,-140.515327,-158.441481,-182.933255,-218.791259,-240.158965,-335.69758,-368.872183,-258.491846,-33.10827,35.157513,47.659603,32.832719,29.564325,26.998305,20.302052,42.034485,132.860663,169.719814,139.004578,42.377106,0.634773,-70.538069,-83.007457,-27.161872,50.234338,77.564209,77.044956,38.675406,-33.213598,-38.294195,0.74938,41.637521,176.371465,303.018206,306.675917,205.723579,152.290561,127.478146,155.430005,219.205771,239.469114,236.471782,217.137139,212.23318,159.413135,80.778755,-83.954618,-104.661177,-21.155276,88.319177,111.449427,83.017701,70.199965,97.170376,103.280139,83.966381,111.699308,142.486756,166.887683,141.137613,29.336484,-42.785174,-133.880036,-122.354918,-30.875419,51.021797,56.361655,-39.668292,-129.209211,-239.691889,-196.879416,-31.616654,17.193667,9.313448,-30.789285,-56.285667,-111.556198,-146.683712,-185.08563,-161.800827,-89.257998,-54.439595,-39.30155,-45.170645,-88.781674,-205.958437,-225.44735,-135.024529,62.325964,141.912114,124.149549,54.994027,-30.961082,-20.413839,57.889087,85.558332,76.343659,77.441985,103.438052,115.955945,72.111313,-56.402445,-102.902602,-152.609146,-187.872476,-186.092222,-161.717101,-180.207263,-261.822848,-261.872175,-163.673796,-128.198604,-109.155653,22.833351,90.15028,50.110875,-11.026508,-66.757642,-70.525241,-60.980913,-40.102269,-34.656432,4.735057,33.129061,38.244635,18.84123,57.721452,133.107279,243.256537,199.757225,159.22287,99.113655,80.568407,67.428359,78.601037,106.921279,58.592033,17.580138,-43.245166,-71.750476,-154.997128,-195.81202,-203.241742,-167.609662,-90.057954,-41.677613,-13.632061,27.181356,-5.691336,-143.652655,-171.104653,-120.752716,-55.396478,-15.234643,46.550617,33.510129,-88.471429,-154.555373,-211.525525,-211.7779,-172.721711,-69.435299,-40.945931,-81.800894,-115.893126,-126.962867,-96.718452,-7.722985,34.281254,46.369792,89.688445,106.952559,71.863013,37.90108,91.541171,161.682178,159.172254,51.39164,38.79873,-6.326208,-71.96646,-199.695525,-225.841432,-185.525382,-35.18252,33.234724,73.901495,55.63785,-50.422417,-113.299154,-108.125065,-36.521572,67.054254,69.062062,80.936534,131.751132,135.239907,46.768695,-18.131708,-74.992287,0.370399,35.603222,14.277812,-22.751826,-106.858458,-138.5738,-106.163585,-54.091376,28.38594,84.243089,127.065042,190.143975,159.960858,7.370689,-39.88719,12.346581,113.852634,135.881302,108.992847,82.465168,53.889568,39.345451,18.725615,53.944049,245.852773,401.573346,401.505718,344.096146,332.43563,297.337277,265.475364,227.548588,179.466033,138.983577,80.733167,67.560795,54.626221,64.390267,87.426278,78.340317,34.260013,13.991832,6.69222,-79.065816,-149.58226,-207.268706,-178.094077,-91.134011,10.203896,77.314461,183.841224,190.424731,127.822988,69.510884,-68.017094,-105.020644,-67.2246,42.668418,50.517502,-107.364719,-213.641491,-323.771036,-323.326674,-263.372138,-190.4281,-166.028803,-154.846359,-154.482011,-147.000457,-166.183578,-216.184394,-184.950543,-29.953971,23.997976,9.979062,9.890029,5.479072,-69.794301,-87.171806,7.948424,83.546022,82.298845,94.430573,110.145379,60.541327,1.41175,4.35541,71.605258:105.852777,120.378584,90.728435,-14.697377,-70.616037,-108.166077,-78.586471,32.870787,201.388819,271.973268,221.905175,118.640854,-28.324824,-34.9072,21.077918,47.170843,61.419275,100.257861,138.257439,161.641703,114.592279,-43.403105,-86.242818,-13.264192,152.090147,203.666012,152.514259,68.515376,-92.530277,-158.269161,-238.696326,-207.546232,-30.841504,64.631678,47.17258,-27.675661,-46.094175,-84.636069,-113.559367,-120.439606,-61.716687,-23.443759,34.131816,34.164341,-22.96079,-56.072574,-61.552672,-27.69951,55.658285,103.057433,119.370962,128.416514,97.031908,-64.504314,-151.454062,-229.899408,-160.214012,-84.075074,4.528254,-20.582852,-190.314007,-319.196186,-508.421708,-501.023017,-314.28533,-142.460063,-141.487484,-233.611125,-259.76433,-267.401962,-259.697701,-196.519375,-122.729509,-109.785124,-146.680276,-178.615436,-239.618991,-266.149424,-265.427079,-224.891395,-125.175813,-160.235663,-241.197863,-389.224432,-417.223022,-374.218264,-313.871009,-178.135907,-33.776249,26.9668,-4.49362,-75.239192,-121.309234,-97.774215,-68.061227,-50.402008,8.872477,-17.899926,-72.890803,-168.140433,-173.435889,-102.991619,-66.514938,-44.491557,-15.035175,18.039143,76.692723,67.253079,-92.408141,-190.317572,-216.571074,-153.227954,-30.653094,38.12258,29.627625,-80.394057,-136.873717,-191.576514,-196.069843,-150.924329,-29.152916,24.27115,51.703931,41.537673,-10.707967,-50.019812,-64.216516,-23.745012,99.446489,142.476439,86.283992,-101.123997,-170.675716,-224.60027,-219.422626,-162.952178,-55.127605,3.153093,39.348595,11.490386,-51.137053,-58.37921,-11.399136,32.447387,133.118983,212.05168,215.658436,143.992434,96.389601,41.766939,46.052653,100.707325,162.766536,179.788507,152.343504,102.350674,-14.630534,-58.15328,-126.334271,-141.609654,-92.138,18.932366,62.597962,76.967902,42.460926,-31.686101,-13.846976,109.851232,143.201808,119.50972,100.789922,111.086915,35.551776,-61.977615,-159.791422,-115.085858,33.001908,135.846789,152.046157,68.354868,-19.506824,-145.45111,-126.630271,27.375606,113.65829,112.204116,60.639678,14.695762,-101.218322,-154.780242,-170.919894,-132.456742,-75.811677,-37.399092,-1.454244,-2.809847,-67.455321,-182.004,-168.7432,-75.103657,-18.505682,20.986673,99.245735,115.409802,109.75945,98.487789,137.562994,193.475804,237.78455,168.454625,123.937278,2.440017,-66.837717,-145.618565,-141.554678,-88.984028,-51.999371,-47.431337,-68.254545,-107.528512,-231.040282,-267.228045,-200.256663,-128.105094,-8.71136,123.88205,169.495887,125.511383,80.166509,79.188402,113.282196,156.41885,161.328692,175.236939,222.670468,237.770365,201.850624,166.94922,187.377465,242.335982,323.953724,301.210624,251.543659,171.437845,182.449529,268.676224,298.78813,264.645085,171.38024,152.955182,127.129531,84.231464,-33.853092,-77.975217,-105.936414,-90.891006,4.08083,147.084047,172.604738,51.695955,-39.558259,-60.832537,16.775386,131.042306,88.632566,66.163887,27.1138,-13.98313,-55.6883,-32.85957,30.184069,46.483036,62.231692,66.456675,36.884467,-40.285694,-63.823174,-120.727639,-126.15984,-2.002012,145.631584,183.124066,248.327088,279.009931,220.831024,132.705996,45.198466,81.894275,209.075846,308.550489,313.981349,195.243723,86.632858,-124.272507,-151.669622,-4.250945,157.824666,178.466673,131.740858,70.602983,-129.801414,-205.350304,-149.43851,-67.415944,18.580916,36.520489,41.186051,18.136712,-3.545863,-60.324661,-89.23057,-82.482158,34.932468,67.576167,-25.906903,-99.701281,-173.806602,-173.165965,-89.701274,-25.428731,71.426209,186.58461,232.543371,171.782886,72.255799,-83.242872,-79.795523,20.008751,123.20873,184.782063,296.194093,307.928336,208.786963,135.050501,74.547578,99.016281,207.815175,330.303965,365.993417,344.561494,289.613528,203.808348,229.491749,349.113168,363.939936,331.037514,210.854578,130.444679,13.061767,9.846822,71.295033,98.171929,118.215369,52.694548,-5.934744,-101.927495,-155.796021,-264.232693,-258.693883,-105.075752,93.941745,169.059282,201.470755,167.04566,64.829309,7.750247,-103.186301,-148.529187,-190.400278,-137.332008,-113.54292,-201.170387,-306.669992,-443.741287,-412.513182,-274.3106,-229.612098,-214.118667,-182.517421,-207.475164,-327.673103,-367.581058,-308.508573,-224.600623,-64.471583,-11.620636,-38.303597,-123.428013,-146.282338,-152.694036,-137.684957,-29.16692,164.778491,222.469741,178.067553,117.559555,20.16608,-3.236153,-3.263454,6.709266:14.739189,105.530388,69.184249,-77.092456,-126.955733,-141.622149,-127.784668,-99.805692,-52.213996,6.596055,113.14172,96.493602,-45.890825,-95.136259,-71.560615,-33.806193,65.710248,242.277727,305.493894,249.506186,156.817724,30.395892,36.006635,120.125331,137.401365,101.96841,-2.412092,-43.854696,-101.154981,-137.07541,-226.385521,-253.448268,-197.783685,-56.173667,-32.995402,-117.853256,-173.015318,-240.945497,-260.941396,-269.66267,-244.588113,-205.628091,-110.50366,-94.400745,-65.686701,-14.656686,68.079635,51.688926,-12.631076,46.329672,116.52862,169.586169,99.96086,-92.931543,-130.960999,-118.921345,-89.435647,-58.058062,-69.957409,-136.681133,-277.712355,-341.234186,-469.912401,-492.462774,-430.986331,-335.818301,-283.63366,-237.581688,-274.990242,-342.775447,-311.374145,-197.957977,-165.241141,-166.343039,-160.622121,-144.972107,-105.308545,-115.611258,-174.747157,-179.869608,-156.292034,-164.353028,-177.966329,-232.027681,-270.804698,-282.216305,-222.094332,-35.181952,138.540127,205.088834,210.621271,172.832337,167.359963,191.879569,210.421964,208.150812,208.403789,176.003599,137.12989,76.014929,69.33355,36.74385,1.981262,-46.100507,-30.865635,-6.069521,2.569304,-19.03129,-57.806197,-72.860278,-107.203976,-112.414681,-58.199538,24.289791,28.035375,-54.418364,-121.864183,-231.161722,-243.512702,-171.912408,2.529274,102.14034,201.896554,179.982884,62.788658,-14.51818,-136.330555,-119.831761,35.784095,120.622024,90.94702,-52.19764,-111.819982,-177.762905,-193.374551,-136.630048,19.650364,91.180824,173.994431,174.88622,128.559438,115.041335,117.310419,127.330409,206.408565,327.132947,337.122004,252.502529,210.249218,178.509547,195.931319,256.006576,207.315914,166.175611,153.019493,169.086239,164.026312,108.250103,-79.970419,-144.114799,-110.425738,14.821228,44.453667,62.577777,76.328024,68.110677,35.543666,22.401889,134.952376,184.924472,186.563821,145.600999,43.189827,2.984446,9.283647,61.174687,174.45373,223.410713,206.853709,117.341956,64.145575,-32.586757,-31.381054,90.352802,143.342051,114.862043,43.823666,29.039805,6.265837,-24.155252,-64.498734,-60.497717,-59.59145,-26.723005,2.297077,-7.908091,-60.779406,-151.972829,-134.220754,-23.746929,40.594873,80.993197,177.648926,179.973997,79.378932,35.20126,60.253691,107.819801,148.811292,140.221541,162.851049,193.59882,153.193503,-13.772463,-71.10283,-38.859358,-10.198279,-46.87013,-121.528132,-141.245808,-185.508205,-203.345079,-166.501286,-102.672992,59.613462,194.614833,223.713181,164.011548,100.279174,5.361653,1.795523,54.358383,97.815815,118.931149,155.034849,159.338563,157.933321,165.704629,212.358976,240.774215,261.521779,245.230305,227.47421,168.009537,134.790054,99.286277,115.437768,182.630728,157.648656,111.480168,28.602095,-7.488492,-83.44173,-120.543666,-193.169946,-202.624271,-107.288371,42.602734,72.515614,11.919485,-45.930779,-121.922436,-112.65444,-27.646068,-0.703371,-25.522841,-107.724357,-134.819775,-121.894252,-114.089273,-130.777509,-112.566607,11.46981,87.088094,71.451445,38.133602,30.112187,-58.570535,-113.901462,-85.769731,97.7825,182.236441,252.941811,250.842209,217.061598,190.60917,224.384776,290.408768,325.128372,262.024703,243.539472,139.155269,59.36748,-56.609505,-75.650067,-17.347195,134.912781,205.050039,213.975366,147.800459,-10.171523,-67.916673,-92.150411,-54.68199,31.528197,107.603058,150.935679,140.355108,59.999154,-120.291552,-158.382271,-146.309333,-162.978377,-189.489012,-202.600762,-195.772666,-218.229719,-252.636258,-280.288471,-230.96918,-86.42307,-21.848208,8.573667,74.123144,67.957835,-60.222051,-134.375617,-132.584583,20.038988,102.160495,208.43848,192.017103,55.469842,-6.436006,-50.964188,-23.54547,116.481449,233.528641,245.626294,218.831301,213.03328,209.869393,196.73432,156.099074,143.776941,157.607872,142.270882,85.162242,-32.474535,-47.936639,-10.257636,19.983616,55.949183,62.624967,54.289137,3.444293,-39.555001,-146.498917,-184.243491,-159.791084,2.904235,99.075934,221.729974,233.835646,159.095891,74.059192,-119.254066,-178.957953,-154.569693,-13.803525,22.835759,-65.211667,-168.901455,-341.819572,-350.719128,-235.656431,-105.578044,-68.893505,-91.230098,-133.152267,-208.006196,-237.237176,-258.757157,-240.20158,-177.867566,-96.368218,-39.864643,41.31818,29.403023,-75.908499,-102.804745,1.4688,167.280839,193.984328,137.679081,99.44788,35.257873,13.489638,30.71502,49.23355:-92.005226,63.210867,73.071204,-61.84019,-156.20472,-246.942132,-214.777702,-93.620497,1.784969,44.522104,66.207079,33.01922,-59.647532,-84.994997,-60.601438,-38.459085,25.467338,195.747073,250.239988,167.297041,82.221691,-12.651886,-3.867369,78.269338,117.93724,103.716036,26.463905,-11.316312,-67.073845,-107.732583,-190.023709,-203.000061,-147.565387,-36.401166,-8.459739,-68.042624,-144.106678,-304.006317,-342.200374,-264.048273,-76.894676,-22.138644,-37.007173,-55.948381,-38.693292,-17.744634,15.67881,26.920599,49.041491,132.953321,179.544761,150.99539,65.676836,-107.86614,-144.538355,-153.65522,-89.160307,-37.477112,-25.51803,-75.947292,-247.401709,-345.299936,-433.244533,-405.240927,-313.230143,-224.619186,-171.205652,-94.843071,-117.439072,-259.33806,-285.382432,-169.067239,-33.972325,4.505494,17.026253,-12.99786,-91.911753,-108.707579,-74.16615,-49.465219,-47.468533,-66.934581,-68.553938,-99.514529,-144.708782,-219.01376,-200.734983,-50.140847,187.732483,294.17464,312.802314,226.768605,32.97914,-20.63963,11.781999,70.166089,138.17981,153.479786,172.445332,134.52165,43.989665,-136.571222,-152.879291,-102.167966,-30.410175,39.475621,101.174578,47.480632,-73.103206,-76.574189,-8.749797,9.760856,11.610339,61.887648,79.303434,10.634503,-70.961091,-197.97116,-188.52919,-45.862922,128.934809,186.722919,177.141393,128.110419,15.545343,-50.152376,-134.467242,-102.157671,87.240314,205.863622,184.516114,55.80611,-15.960564,-132.069363,-150.811036,-79.321599,75.068971,156.570523,255.739111,247.971813,152.395647,116.547474,147.071515,181.440339,212.835521,265.835266,284.989542,256.344049,219.026093,140.677401,145.719015,274.369862,319.563355,282.390616,223.077047,209.746298,84.425267,-44.317698,-246.968707,-233.925606,3.14855,167.096561,148.346037,32.42979,-13.29154,-15.132955,24.106315,99.329464,189.435265,244.378654,245.733051,190.819139,81.692051,44.790328,39.880008,91.270507,237.639781,312.322383,302.406703,167.805026,67.415483,-58.30603,-34.825763,148.26418,288.453261,296.494993,218.574997,167.255553,73.140086,33.297032,16.034317,31.803112,60.069713,119.221867,158.001826,166.310329,103.913092,-74.825562,-105.044494,-24.208783,31.740113,55.506078,134.08577,159.319344,133.83608,103.475221,109.114627,148.799156,199.60677,205.743508,206.745914,123.081816,27.001208,-118.997008,-96.847243,73.745097,126.421526,94.432775,10.787778,-37.020822,-147.932544,-182.423439,-103.469931,-14.1214,96.225899,199.009023,277.953329,317.961521,235.511809,27.2026,2.108019,126.343891,276.490865,309.672003,292.333047,280.952948,272.707911,257.575035,276.179145,329.317817,416.888195,393.333486,351.698711,247.905623,204.11477,160.935848,161.762263,196.109628,260.091461,273.706167,194.735419,120.88014,-36.908148,-93.017336,-83.429087,-27.281797,101.430893,156.913306,136.911266,27.811981,-42.575854,-131.150865,-105.893446,39.832448,110.362664,76.765461,-75.979536,-137.236067,-144.560785,-109.093026,-2.941126,68.903194,177.631547,178.748014,159.314968,92.741397,26.054499,-135.349056,-157.560511,-51.508243,68.067085,118.526939,212.970921,238.971676,205.029319,165.737594,149.231961,173.361261,251.718428,322.364534,308.402585,156.223346,57.701955,-70.259729,-81.90926,-7.90841,130.302518,170.841877,112.717864,23.370963,-205.949269,-295.216788,-305.541028,-239.812265,-69.146276,28.470483,20.853302,-74.966228,-154.602903,-337.788813,-387.889023,-330.637835,-222.401172,-215.670123,-289.885716,-337.55043,-400.010646,-415.073392,-377.8026,-320.779169,-167.567076,-7.888126,24.390463,-45.644082,-110.73602,-206.833887,-221.192208,-166.93087,17.968838,134.699071,236.224954,181.935607,-30.125466,-100.298734,-70.859481,-15.840528,72.59477,138.079144,146.594647,82.58713,28.654271,-44.4855,-38.432452,41.199907,132.209995,168.126575,124.459875,37.130304,-98.129785,-95.443261,-8.734334,28.42007,43.910123,10.329222,-13.555422,-82.650529,-125.174788,-187.879715,-203.82114,-194.752974,-13.440563,145.706041,363.750567,330.665201,50.204111,-86.91271,-194.43865,-182.572867,-125.531205,-51.00617,-23.706814,-101.228618,-219.785183,-438.025604,-451.169841,-323.667744,-163.212872,-92.595414,-43.538742,-86.219546,-247.863467,-319.378952,-320.626605,-241.036375,-42.948253,52.193328,51.983575,-24.688068,-83.518049,-155.520249,-140.969856,-40.066861,52.812226,74.648032,40.890238,-7.295447,-115.430581,-148.902862,-106.561792,-38.80387:-40.580194,57.123873,49.636501,-71.764275,-158.627863,-286.838136,-282.873392,-141.440135,1.068324,37.368447,46.987485,40.411877,31.474278,18.616989,33.586812,98.974751,265.942303,337.973048,364.621013,401.691181,367.150241,199.920639,141.852948,189.435705,281.725593,262.677274,101.23035,22.864668,-37.529019,-53.121532,-125.198602,-153.439065,-118.370197,-9.152446,15.494909,-75.606335,-156.706565,-257.943802,-271.82571,-257.218307,-241.990285,-233.080484,-159.946112,-120.527622,-109.59252,-114.694444,-68.534195,-43.573246,-64.003149,-17.27291,56.63012,137.181893,112.165508,62.240216,78.303784,72.367596,-57.156458,-85.957832,-44.669459,-45.54186,-156.916488,-240.321765,-351.679171,-338.803998,-213.861978,-125.971614,-108.808587,-113.871386,-157.435921,-283.329662,-301.067247,-181.010661,-79.568453,-98.608996,-120.05663,-67.378002,41.624574,24.082229,-70.945752,-80.350339,-116.91348,-202.96979,-199.27122,-168.278027,-179.302041,-167.748253,-102.692203,132.631013,405.06403,497.050232,517.850344,476.520261,376.807269,329.041445,315.452755,355.737753,407.290341,370.75071,342.13874,292.476125,255.0125,91.868443,-0.469684,-81.77521,-40.861867,-11.369764,-4.00896,-27.546959,-72.939833,-95.418659,-124.629612,-93.112107,18.715023,56.501964,51.110535,3.736516,-44.187569,-154.166367,-170.020206,-29.538477,193.159644,249.736333,223.559308,170.687656,55.065188,4.863657,-16.77679,31.712247,141.356451,120.31137,77.538743,1.778976,-36.62331,-145.212935,-184.490062,-108.591343,106.536484,203.731763,322.331958,346.558671,354.413349,340.498131,303.803224,322.389879,448.634082,491.17316,425.669505,192.398528,103.666856,98.487758,165.907137,288.351143,214.330308,152.850293,151.46186,208.681536,301.379014,283.910693,151.834998,87.718994,62.119791,157.145093,187.153865,176.60386,158.428206,145.519546,168.034794,247.267802,282.758318,291.936,293.697243,263.356629,176.977755,155.703449,157.520409,154.860325,164.683109,316.751325,402.196013,368.326665,271.190717,147.234362,145.408316,168.655441,152.600923,153.694119,175.039395,162.108556,79.817156,42.660337,31.351507,29.88626,-44.005417,-69.050465,-23.398168,5.924945,-62.488141,-209.82694,-218.483169,-165.304928,-104.518952,-58.530318,25.552827,28.160744,-57.257752,-87.725325,-10.746202,43.425168,32.786022,31.519514,77.77832,91.661746,39.488961,-35.26189,-25.18036,-0.768679,-23.778105,-29.067163,-93.21788,-146.821739,-181.810241,-170.869668,-128.320943,-74.555866,57.656618,113.06672,123.356036,111.37089,71.00935,-56.324113,-77.812149,46.729537,124.779532,103.768894,76.246527,93.234679,157.711613,159.733469,87.793141,80.265454,142.63955,164.42741,157.987961,134.146312,107.447481,27.664546,-1.001771,25.055779,100.530456,113.179795,40.311702,-39.382726,-209.803671,-274.913588,-340.504452,-332.968472,-250.212382,-142.087418,-102.550549,-132.383293,-192.401108,-275.887125,-271.446406,-184.592504,-131.644242,-159.182103,-278.635824,-327.552767,-318.575678,-281.811361,-227.534529,-204.028654,-137.71178,-51.661658,-29.804459,-69.290277,-99.729734,-79.516246,-24.087347,69.147895,60.905102,72.337879,193.700694,268.886263,317.203761,275.550904,184.73181,193.55875,272.964506,261.794088,220.657149,106.599064,29.794317,-149.241666,-208.749784,-184.509928,-2.473197,86.241711,75.835481,-14.544254,-183.757103,-216.082755,-162.130672,-109.661389,-51.558589,4.551032,38.646939,21.255782,-41.824781,-206.173133,-269.275653,-321.353522,-336.330629,-383.635251,-530.548902,-549.000955,-440.933978,-399.153523,-395.695686,-357.109198,-158.131482,15.051845,47.711549,-27.55084,-111.450202,-243.364633,-260.001266,-158.82425,53.618263,123.391076,134.159579,106.66327,36.814739,-1.034039,-42.481965,-31.254087,55.709774,147.783593,168.604561,197.968379,215.827426,189.455778,141.605637,88.771667,105.982539,106.245861,62.536519,28.010785,-10.288964,-17.045091,-28.898103,-12.69203,85.848887,165.805344,151.448546,28.953181,-17.331306,6.138158,45.941862,92.117516,88.339813,106.051772,196.722883,234.563107,230.302314,162.112277,-53.926857,-113.80412,-62.437569,45.211847,74.645739,71.411567,37.278373,-71.856906,-111.622077,-69.292349,39.188268,45.643953,-8.407239,-29.215063,-95.416063,-168.095647,-263.168512,-224.304595,-69.71748,-4.039147,7.721499,8.425583,-24.835881,-138.921689,-163.633933,-82.97776,-5.752652,-13.977066,-81.716098,-115.7142,-150.293743,-147.10175,-79.020704,-33.659248:-8.839637,181.064698,183.057501,-16.438351,-151.076808,-287.115556,-261.530404,-104.008206,101.111266,183.634059,161.629603,77.948434,-50.456498,-75.795426,-53.38677,-1.279754,142.567835,291.316774,344.133503,302.291192,202.596046,6.979948,-0.160716,157.823654,214.031122,158.540195,-9.362636,-79.806987,-162.33167,-190.516998,-225.302337,-207.226802,-65.572126,71.396336,62.342809,-103.579304,-207.487463,-347.97751,-371.292031,-336.129981,-233.089311,-172.165646,-105.647658,-111.60405,-128.270787,-116.039793,-75.482968,-60.280535,-4.147177,108.767968,158.734133,155.18979,73.994598,-119.304673,-140.967054,-51.049342,11.144845,35.778672,75.54396,38.709477,-187.980164,-322.406261,-426.333136,-363.012464,-160.519492,-62.855375,-48.400361,-87.926538,-148.703337,-260.191514,-264.901982,-159.296258,-17.837563,26.923674,58.10863,56.57352,18.096178,-17.374577,-46.502479,-11.230557,101.7902,132.981616,102.604243,-29.787458,-101.845029,-140.235319,-79.133884,159.3803,409.843023,493.766951,492.104346,409.631918,245.228616,206.212088,204.641611,236.640877,317.747155,334.922876,314.435201,230.226747,165.477949,-11.751101,-86.42575,-121.233125,-82.771521,-45.972311,35.44135,39.668852,-59.567244,-130.075437,-187.333159,-154.111991,-4.394014,128.172903,116.723025,-52.563217,-159.116747,-289.990682,-270.385146,-78.575265,138.758744,210.093934,210.04008,145.939255,-20.540287,-112.063003,-210.864849,-157.722559,89.779583,247.945085,225.325466,48.955913,-39.340317,-169.956283,-201.411985,-109.380375,128.703855,245.61472,386.895097,380.862481,234.106094,156.857117,197.734365,314.948789,529.242472,579.364607,548.461308,383.701067,275.153475,134.241776,140.356149,254.6001,300.176474,272.493563,206.262221,199.626644,184.344947,136.22085,37.752084,47.611084,163.473952,281.615453,313.497532,293.883678,242.733856,105.47168,70.110323,138.397293,293.710743,353.908365,335.117891,248.847301,31.850921,-49.130144,-37.199266,58.93192,267.091121,361.863327,350.065736,211.197722,135.528791,48.81538,35.298163,88.587535,224.310544,283.00499,284.14048,219.958438,39.685941,-31.764964,-43.403676,7.364008,105.50857,160.712851,156.473368,5.808192,-100.27226,-208.436122,-195.832091,-106.600454,-35.437934,1.00759,63.235662,52.372063,-42.84155,-75.434697,-35.333413,24.713944,151.979447,197.097311,162.951447,33.349139,-18.235297,-59.824966,-45.135574,56.85788,134.376686,131.024885,58.537003,12.553437,-80.068991,-133.885056,-146.028395,-63.448348,140.842662,272.776551,320.468461,281.037089,173.719648,-51.413378,-67.389967,112.712347,242.832891,256.379756,287.186347,296.080646,243.853371,182.035202,107.92853,141.051952,258.403859,265.197201,235.808528,206.897846,196.411841,115.554453,75.771058,102.323165,187.814618,190.744781,60.901373,-35.850974,-153.632156,-176.987013,-201.191657,-182.709252,-48.119199,96.081979,102.416548,-56.148285,-171.167163,-275.094798,-231.138806,-78.75725,-45.087203,-84.505384,-191.599046,-226.629744,-252.641539,-252.36845,-192.511528,-124.865092,42.179059,157.036432,154.731297,66.173032,2.881254,-157.419044,-197.621393,-88.316726,126.571596,210.621682,240.299165,179.587397,26.997167,-26.55851,-41.676044,20.280958,218.175859,321.089628,284.275614,37.411078,-89.114487,-166.264811,-136.142697,-29.479451,135.216179,204.296838,175.966571,73.742387,-198.015225,-301.567935,-315.656265,-251.298494,-100.975403,72.819026,123.324832,0.29045,-141.416035,-339.534404,-372.074595,-409.20137,-352.636449,-300.812833,-328.050933,-403.406607,-555.651792,-615.284179,-633.561129,-550.584223,-244.982921,-31.325198,-33.792834,-177.738923,-257.110199,-356.400211,-361.019174,-230.034594,33.249197,134.352539,123.720633,32.113577,-151.120978,-207.328124,-216.419567,-157.254904,11.365086,118.961083,139.12538,93.015954,31.106849,-87.353305,-105.645349,-11.767293,115.40909,117.953956,24.994952,-26.00647,-115.988056,-169.367508,-205.125252,-138.674944,91.021099,203.90437,166.576833,-20.472642,-108.860256,-173.012015,-143.695221,-41.239711,85.115693,156.07747,241.115462,260.416669,239.305556,154.302633,-60.333276,-82.591234,36.553201,116.779171,98.518364,-54.130019,-157.264773,-278.401267,-272.301961,-156.599666,10.310677,57.615841,-14.653616,-102.225544,-215.460315,-222.630978,-208.799563,-201.124508,-112.482613,49.540407,86.155769,20.314435,-39.224186,-119.88078,-124.34596,-31.021092,104.074566,124.381726,25.46993,-43.915024,-108.790225,-120.801192,-97.310917,-40.74538:41.311442,106.121236,100.438186,-36.63037,-129.922066,-227.702844,-205.73394,-96.119595,-66.030204,-77.12093,-84.842045,-66.611833,29.788046,90.57783,158.616297,164.210054,177.646195,225.960052,272.604782,381.101652,411.063394,402.216343,384.706984,350.767774,293.213673,263.109314,218.460533,191.872042,106.341973,48.608665,-23.758142,-1.383373,92.246773,50.766119,-17.964586,-137.844084,-168.427665,-162.077547,-129.858682,-39.35619,-1.553562,-8.550428,-1.306709,23.20705,83.423108,102.041257,145.775073,181.066079,182.301112,98.241787,88.23081,117.195868,111.633256,39.635504,13.076055,27.531076,24.386108,13.013673,-13.504541,-55.500948,-190.836875,-237.312258,-208.169467,-161.244201,-80.978078,-10.710225,15.925513,-1.012973,-51.329441,-122.795189,-96.023445,5.951395,11.909016,-7.27905,5.640554,44.493872,110.247167,106.878905,84.727282,98.052512,111.756995,58.001284,45.481498,79.480331,107.295702,166.014665,214.272399,383.930476,553.573194,595.212347,590.521407,546.723551,391.187229,317.766194,281.231802,309.794296,352.40309,341.8257,341.124464,328.268305,272.270447,19.093362,-119.072982,-233.309445,-204.389314,-193.380761,-156.337534,-133.849007,-122.865514,-130.321754,-126.575712,-112.757087,-108.61308,-40.758264,31.678735,71.635953,27.334411,-54.121141,-58.807577,53.482303,260.348988,332.671894,343.844759,298.315064,205.227961,170.01613,93.163354,68.912388,128.007373,254.149139,254.647507,98.653441,12.036782,-86.730346,-106.894311,-58.07057,62.460042,123.057272,301.716024,388.871584,423.834607,389.911936,353.58494,375.378689,443.900564,381.730778,285.849609,85.91833,38.928511,66.742905,111.97663,193.568532,174.008879,132.816154,140.143143,220.401596,391.523848,382.272048,194.26847,134.838614,188.364723,285.24379,297.731568,256.842012,239.937121,263.495215,288.442746,351.048649,411.572783,420.448815,375.833982,331.079006,277.808589,275.283373,263.220986,253.516862,249.857247,287.692915,315.584246,328.491575,303.867908,224.469415,198.373227,183.23199,143.332994,128.836415,149.229114,160.84332,121.456499,68.414631,-57.856052,-108.747153,-166.122698,-167.819315,-160.07864,-168.126,-185.945896,-233.793689,-251.376545,-243.746463,-208.688136,-183.411937,-130.344355,-121.347487,-118.164211,-110.826585,-110.725651,-123.337755,-139.512312,-111.958812,-113.67793,-151.494619,-146.100549,-71.823773,-32.423868,26.491796,54.327542,33.854342,-32.185376,-28.720349,27.473974,0.555493,-174.642609,-216.711215,-117.074282,43.621981,96.145527,64.935566,-13.155081,-140.962332,-124.44634,33.999919,58.074904,13.090272,13.489886,57.617736,82.313022,48.965419,28.820679,80.70466,191.480466,193.547753,183.92867,179.658248,181.648075,151.651177,116.829733,72.106686,40.325821,12.343064,-16.92706,0.534759,30.420036,-10.531244,-136.311093,-147.318321,-123.216367,-148.126206,-113.987213,25.415117,48.795417,-54.701097,-132.235527,-216.146915,-239.684876,-253.147507,-301.720641,-347.132837,-441.717073,-468.209992,-450.809216,-419.556451,-387.355685,-360.133057,-324.396096,-216.522742,-143.30152,-22.34908,-3.607459,-2.642469,50.007367,108.133133,236.986918,253.723887,131.078083,40.627117,-7.935551,57.243995,196.1272,174.304947,138.164471,46.416137,-23.705202,-196.822857,-278.827337,-365.214852,-218.0354,-79.438721,24.779046,-49.537277,-222.943485,-257.25996,-240.892087,-212.474399,-186.889586,-155.823354,-95.538925,-11.244143,-58.15468,-300.861694,-414.77692,-506.986597,-511.014979,-510.10792,-514.629064,-529.371563,-545.377923,-525.085093,-470.868366,-426.99117,-224.581043,-7.674169,20.821566,-79.756843,-143.295987,-182.11002,-160.818371,-92.621709,-23.73264,13.248389,74.035333,91.403952,114.443934,105.641237,33.273128,8.539988,63.741653,216.078576,283.610787,311.50365,269.114063,151.737356,109.634881,62.78229,39.665699,55.994642,94.277558,87.906966,49.895574,16.194329,-25.893121,10.999456,124.306897,179.695584,195.778871,181.979638,161.169607,155.292967,169.590526,176.334317,134.099385,133.062463,195.870645,224.868683,215.016816,146.235743,-72.448166,-134.066921,-102.869558,-56.638616,-42.890025,40.680302,86.663061,76.789813,50.995054,89.605244,134.306607,99.498966,-17.386415,-43.857462,-37.451378,-62.045875,-170.749505,-194.253928,-166.114094,-168.26281,-171.162133,-143.711143,-148.547256,-252.788179,-312.924525,-330.032886,-234.401714,-190.58427,-209.743782,-257.443555,-278.597929,-239.753226,-138.525742,-87.521504:-100.005574,26.088499,32.455512,-34.790907,-51.311624,-61.90697,-67.754078,13.38243,114.110583,91.67039,-12.202862,-30.338111,23.078767,57.25084,83.696911,110.083062,238.092057,354.985267,387.770819,377.717259,340.037265,304.638862,329.894723,389.185898,322.126112,251.774353,137.771873,109.884416,100.794858,101.937211,101.805087,100.197256,61.284528,29.52778,20.852197,-59.380225,-121.567215,-188.323456,-172.556942,-102.542052,-69.03562,-41.415404,76.026516,119.384134,94.304122,52.933515,-7.006091,-39.625536,-139.997825,-119.557036,-44.204841,81.893778,97.164675,64.162946,43.091648,2.018682,-47.386142,-37.426458,19.542469,5.328682,-147.59759,-228.985988,-282.471113,-283.765443,-291.917433,-209.563825,-156.565513,-164.072121,-220.506383,-317.636353,-319.112433,-232.311161,-132.930267,-116.021502,-119.794912,-107.450597,-59.339184,-69.89512,-160.351336,-186.840725,-199.996631,-227.776377,-219.841492,-124.177979,-81.204627,-86.242765,-70.914982,154.73728,468.877734,530.361556,416.769346,330.313539,236.108686,199.114944,142.00334,171.633297,308.001215,359.108349,329.131911,246.002283,229.22002,178.507208,113.049544,10.426268,78.304731,123.64919,115.128992,82.554185,49.936607,38.722799,-2.084536,0.592147,57.584447,73.177502,51.592364,-37.079256,-78.906417,-137.828078,-136.377173,25.350089,247.036138,298.966883,302.927747,280.639476,186.842616,119.422675,43.133612,52.003784,90.453125,170.867397,220.95787,200.850648,123.771292,-29.399212,-56.13806,9.104827,111.276967,146.513897,232.003265,282.862891,324.77802,306.085045,294.485398,323.362511,363.016075,337.406889,300.602735,156.517019,74.187112,-21.298315,-18.471364,54.352369,69.787198,57.623537,144.464119,238.33477,328.71656,273.29321,105.287684,98.999743,220.512563,186.129929,111.522157,78.280001,126.259683,195.362156,200.639169,252.73576,351.42201,353.612927,277.665803,255.823952,239.120598,210.689313,146.360688,137.620628,161.152888,234.160466,278.844809,298.658377,249.871959,90.684791,39.327846,25.865087,13.260577,3.498814,46.263249,94.971197,101.349474,34.33896,-98.792669,-126.251182,-176.683574,-187.823664,-139.568921,-109.0671,-169.375801,-291.887526,-304.660494,-262.162676,-187.450257,-140.393563,-96.534626,-121.126742,-181.590415,-185.569703,-171.466002,-170.505504,-176.584696,-135.4164,-101.812506,-75.567795,-78.812522,-105.767828,-130.554251,-183.514392,-186.707289,-151.47487,-78.476354,-86.928675,-188.446803,-225.11915,-209.212802,-178.541299,-89.804882,26.220879,50.438001,-33.088583,-109.953896,-202.83091,-178.191487,-46.269933,-44.590681,-78.048822,-63.750522,-22.394215,48.939942,58.338849,82.726798,135.079854,228.40861,179.505429,134.269453,50.925409,9.014007,-62.655917,-76.89064,-87.003063,-137.702366,-163.165385,-181.569875,-176.921433,-186.049698,-229.365389,-335.539118,-333.332136,-258.985902,-231.64581,-202.661484,-152.336476,-177.583205,-249.060301,-252.413771,-264.881719,-328.543963,-335.467892,-327.069719,-339.605948,-377.329543,-401.942751,-443.490201,-437.694618,-387.337058,-312.636096,-273.463434,-244.210921,-245.927135,-173.922806,-98.043462,14.522619,42.67363,65.508743,169.242253,222.993197,228.337727,188.664318,168.954066,202.128349,223.922844,162.010341,138.600341,58.860249,-22.920646,-241.929615,-330.698145,-350.992928,-187.659163,-95.064542,-56.55772,-123.484464,-224.776267,-207.092276,-127.388106,-102.977449,-93.836072,-39.671654,22.225448,95.481067,63.258139,-103.254491,-185.936897,-287.727541,-364.915511,-392.899337,-396.906805,-379.818901,-350.68737,-357.64894,-381.70129,-348.88592,-168.363916,13.201563,62.824017,58.81624,2.3967,-148.745123,-184.260644,-139.826865,-72.968854,-39.095702,69.755759,105.99319,87.013023,71.263371,94.171142,119.696301,172.439714,257.205856,305.25141,334.925193,302.093149,179.109522,118.475158,68.088001,105.51399,140.604775,201.747455,203.449541,147.39096,117.575592,123.033891,155.760034,213.721313,250.389689,293.082235,381.892834,379.597417,324.481765,322.187985,321.342429,195.053983,133.228241,140.038352,185.570052,196.100771,116.242725,-127.643789,-217.839666,-240.922584,-68.566405,27.784748,105.103526,94.521012,6.126843,-63.548518,-144.255053,-80.836494,-18.228861,89.956305,112.050447,34.735508,-77.217526,-267.101604,-249.722152,-115.903816,-124.239377,-122.684437,-15.385615,13.27558,-122.003922,-219.468634,-240.056594,-97.866601,-61.431999,-121.900011,-155.433847,-112.509602,-82.672258,-53.8811,-15.234582:28.739232,76.987872,47.2772,-62.256962,-127.772048,-266.317097,-300.95107,-232.183635,-142.637891,-130.505467,-136.706762,-133.835801,-67.330689,-18.250614,40.821341,40.881493,23.418442,109.552312,197.230921,312.866004,297.58455,159.82132,102.28377,130.427919,172.68532,150.899396,97.442338,73.913922,26.929267,-10.080559,-117.218405,-140.215615,-53.532187,43.28292,26.945428,-109.132003,-154.626369,-109.849077,-87.330297,-167.542757,-255.727566,-245.908145,-196.144611,-202.729872,-207.735906,-173.979755,-76.703483,-32.129481,32.303215,109.454379,117.678773,40.918466,26.677575,58.575022,57.085487,33.051229,60.436547,112.44563,149.359246,83.541926,-81.43489,-133.502169,-162.210773,-126.086145,-11.699742,50.230994,62.417806,54.19189,23.883443,-70.213028,-93.729567,-50.151356,9.369182,34.366683,79.347625,73.567399,47.717838,65.623682,134.100942,155.318312,132.591927,64.893404,55.567715,87.723138,104.523478,163.062846,220.478673,349.949993,469.397188,521.069441,554.628557,513.071747,364.976298,313.475392,331.808879,370.684005,340.969706,286.270193,315.519887,308.480502,217.515645,-19.723083,-96.514407,-123.720389,-104.877236,-91.819562,-20.826126,3.567162,-56.549361,-108.853523,-96.680185,-37.567875,43.597072,79.721158,91.186808,51.043241,14.201723,-61.290996,-88.912231,-39.929601,146.257855,250.838929,319.655972,253.010585,71.342832,13.868522,-22.139004,-0.362559,114.972517,234.378302,225.262814,61.358487,-41.837175,-193.480669,-196.563174,-43.028496,120.898072,198.201421,366.377325,404.159696,331.497487,278.247049,298.184325,357.120588,447.715317,484.580515,461.302277,290.076437,202.992435,176.083841,214.875586,270.908952,222.850141,201.219517,227.161043,244.063231,276.491447,304.486984,348.066231,356.951323,314.103731,220.910082,221.263748,299.428519,318.13476,233.458148,170.167783,177.049641,359.49894,433.260051,379.861373,278.978585,153.969336,156.359954,200.326339,221.337022,270.626499,345.019976,368.500216,314.967853,249.984406,117.582422,90.660593,161.201188,243.085141,252.101902,217.272456,173.292982,70.721216,28.220176,-12.233265,-10.497863,-22.507855,34.388981,90.757775,33.986014,-65.302456,-156.908118,-132.199613,-83.548038,-67.674222,-14.744738,110.212134,97.235087,-52.160872,-124.02225,-141.237762,-80.872285,37.656237,72.330755,63.085591,-13.895978,-48.891056,-36.320014,-10.952763,10.682358,26.417733,52.139886,87.675092,79.218645,52.166469,36.111452,26.06865,52.97774,91.485255,64.94613,65.712496,80.459156,54.912109,-85.727358,-133.28353,-82.000956,0.272135,32.507188,92.673033,107.196495,104.939436,78.381015,7.449147,13.127435,103.631183,145.275969,132.090985,99.427423,101.006323,128.777615,144.370277,173.776024,157.339194,135.318514,84.968319,38.106894,-99.444873,-172.730542,-255.037982,-240.03601,-165.515582,-111.738404,-95.504525,-82.941601,-66.984841,-36.08438,-52.526042,-99.807699,-82.591716,-73.184994,-122.635907,-173.400874,-245.56268,-261.364509,-284.811271,-264.233377,-104.713337,40.18332,61.785278,92.769187,128.524589,148.754635,97.957111,5.883204,120.00173,196.562144,219.567455,171.812951,58.009447,23.904369,61.52722,134.107381,242.89711,210.99829,180.428239,82.330777,12.748522,-92.165009,-117.847676,-130.4068,-49.99537,31.675704,143.334156,120.722823,-40.002587,-132.066798,-233.986856,-223.341338,-111.597971,23.936546,44.418975,-36.108194,-102.836101,-231.082746,-287.734637,-390.563793,-431.319376,-413.703283,-420.800475,-461.385979,-502.621824,-485.734308,-391.234322,-314.992536,-146.071179,-53.053215,-65.345573,-176.601833,-213.466776,-160.352485,-116.993487,-98.270969,1.591663,109.621617,220.522057,166.82647,-15.741358,-69.454507,-86.364681,-65.01618,27.675822,162.000421,211.854787,212.477949,159.01881,-19.359555,-83.247346,-58.762366,-23.44567,-47.604802,-85.216196,-76.766776,-36.36684,-23.489519,-12.814518,12.424081,115.058361,143.8432,89.493031,-39.86326,-52.569886,-34.184152,-57.505251,-107.112023,21.454671,133.225952,242.42836,202.249997,40.75753,-39.98754,-184.966423,-223.578934,-144.633572,20.215175,33.090482,-102.515353,-160.431748,-102.774316,-28.358643,26.730749,-55.432267,-89.127908,-87.011304,-77.772215,-130.66663,-184.245938,-241.722883,-223.515807,-153.246764,-212.257619,-251.375415,-144.033931,-63.807863,-116.711581,-202.375799,-266.324503,-276.29248,-267.054071,-161.031667,-121.505409,-157.057698,-189.735328,-152.476508,-82.571804:backward
-99.155967,-180.602222,-192.109617,-63.358684,22.033874,45.1041,-24.244035,-180.595964,-252.700646,-253.248008,-179.895121,-147.035876,-148.441972,-159.589969,-154.489912,-122.419269,-52.742833,-164.073388,-249.779669,-293.03605,-263.566051,-216.692001,-218.564217,-234.399231,-246.900173,-274.75635,-318.443772,-285.441951,-98.286282,0.239357,56.18411,23.035934,-9.098713,80.651794,134.051276,174.517129,189.965145,305.405463,384.443475,442.974736,324.577811,264.785448,221.533455,224.244951,244.26095,238.718526,161.092742,114.081245,72.126289,126.984544,166.474626,217.579299,242.669793,263.843882,233.403027,128.416652,73.429282,84.742809,154.004672,194.648912,280.445221,305.482693,239.422367,168.895388,77.36294,51.112672,26.458578,-39.633435,-29.535026,116.822872,180.937129,143.304186,-43.628956,-138.685817,-226.224523,-193.145517,-51.224421,-15.474966,-91.230688,-154.016369,-203.656319,-203.815911,-218.85134,-253.275757,-260.340203,-251.040086,-227.329918,-203.822248,-357.39553,-450.973024,-510.071904,-487.722887,-415.921232,-384.913862,-387.794583,-425.640091,-485.205235,-399.084809,-307.02809,-115.973675,-46.227468,-43.985515,-133.182345,-345.79163,-382.938794,-324.35819,-104.325071,11.161717,186.584646,231.648112,192.202979,143.934572,109.313996,137.428813,152.093056,158.320482,141.036635,58.455896,23.293479,25.253161,12.877965,-23.236455,-42.272422,8.847053,178.712931,245.681886,269.020515,254.888496,236.211515,159.458093,108.505217,59.088725,55.223326,6.485758,-49.692469,-125.370416,-119.081491,-123.628779,-118.759982,-87.516131,-8.915089,-0.905829,-52.268498,-77.32661,-117.403622,-147.291506,-138.032015,-107.80083,-91.149753,-19.167264,8.206676,-27.581726,-122.779677,-177.848994,-263.486793,-274.528802,-276.724873,-286.640634,-258.291439,-190.346697,-56.324274,-137.790314,-223.770713,-269.365859,-197.237827,-1.239023,52.599027,93.286484,73.670915,31.938618,7.339823,34.753239,65.066854,59.846529,57.753669,55.972302,19.089202,20.236775,48.98649,60.678204,46.984783,82.502808,135.012175,223.022385,154.119761,62.438654,-80.442091,-79.316461,57.282135,144.564952,243.194915,238.788609,144.307392,77.508572,103.081962,206.03093,245.346533,264.758478,246.245923,186.005358,66.788358,0.280054,-6.038873,43.561417,113.561681,145.874701,241.164377,244.704961,78.965867,-61.423768,-30.377315,107.595034,122.924953,52.222098,27.429908,27.716877,11.954288,8.106068,33.584905,19.671338,-97.278443,-135.975165,-110.406508,-111.62032,-230.276184,-268.775049,-202.326576,-40.692091,-7.609569,-85.991002,-155.981139,-165.24922,1.605209,72.3321,81.35274,26.107686,-33.464001,5.35556,49.903911,-0.192825,-112.567499,-69.875427,-14.616398,59.153648,88.116069,159.52533,178.139609,158.050246,44.683042,-14.381612,31.586283,110.591244,150.892935,92.251978,-47.208678,-93.906191,-170.084098,-192.071663,-172.040172,-119.036092,-78.18586,56.30641,96.372688,21.85025,-131.630665,-170.483513,-96.23553,-24.613198,30.226375,17.656461,-37.44251,-81.566854,-163.221865,-152.459813,-101.97325,34.286151,98.117567,179.000723,180.66505,158.627634,162.709912,141.145939,80.975151,85.439184,143.834041,155.560941,113.531542,86.069611,41.157087,-1.362314,21.072515,160.333506,238.760743,352.086415,373.169991,349.361819,243.697106,141.602683,-18.982041,-1.133637,148.11432,181.072935,66.215842,-20.075654,-81.481991,-14.818343,48.312455,156.60944,163.529384,126.076744,108.762526,25.311365,-194.710688,-285.117092,-265.58044,-186.540749,-53.257209,-31.404842,-89.461197,-143.897874,-214.346343,-265.785127,-299.219438,-319.519979,-294.30186,-239.083517,-232.546891,-214.478482,-212.88181,-230.611427,-188.513249,-117.879872,24.529573,47.632375,-21.213186,-55.006529,-3.986531,97.189549,119.037752,70.977093,15.855146,-13.620211,30.139714,62.796919,-133.630246,-225.869243,-195.585854,-126.927148,-55.311474,-39.468992,30.399554,79.355052,134.245913,72.468439,30.76953,-17.642237,-19.723782,28.536039,34.132487,-60.174714,-152.132736,-149.957697,-68.385381,-19.783672,62.570534,91.149327,85.112425,40.576334,-128.774344,-278.459866,-278.328209,-170.130789,-127.784849,-121.752299,-118.218483,-42.000954,-80.551748,-173.887418,-301.560156,-298.063375,-211.073935,-157.035743,-125.5377,-150.914142,-204.685952,-199.945519,-164.899942,-73.43917,-56.869226,-152.688825,-249.469157,-380.484697,-330.043911,-263.993397,-124.410693,-89.584082,-121.949509,-152.607532,-163.161685,-144.353879:-73.147333,-172.066991,-165.122458,-12.015595,56.502459,77.075849,51.412045,-57.851916,-201.392285,-227.148372,-208.765747,-218.296575,-248.182521,-224.433329,-162.397539,-167.608857,-205.119477,-224.416634,-242.9952,-251.970572,-214.568489,-159.54224,-187.917378,-254.640065,-288.075933,-313.050007,-282.506087,-201.25404,-18.063207,18.271226,-38.499225,-96.897471,-199.248445,-184.482209,-130.678825,5.428109,88.071783,273.521326,339.744802,358.054455,249.502797,202.022781,201.670629,220.258132,212.337389,183.640529,108.401586,79.970678,67.724307,120.685713,146.660445,131.8919,130.565671,160.834582,128.107755,-15.313198,-52.359486,-4.769525,142.9857,208.892678,297.124905,300.300176,254.422598,244.673688,175.373115,18.947814,-8.972263,71.441041,134.025122,173.40268,132.613341,-29.727684,-159.63277,-183.384355,-187.90998,-154.735916,4.545736,65.188746,20.159687,-38.791872,-125.933264,-223.827497,-262.175023,-241.32499,-193.27636,-154.933724,-206.882092,-382.460914,-466.222295,-442.579547,-364.58557,-350.46592,-342.05297,-334.366261,-351.132567,-380.977312,-446.068799,-437.773489,-409.444499,-352.239179,-300.395376,-189.629494,-199.880288,-338.573671,-383.308545,-316.727879,-129.906297,-66.475379,51.235953,110.956447,102.241781,42.733617,-11.531414,104.299978,175.923574,172.491421,108.839161,-1.960779,-39.159345,-95.139901,-112.778036,-95.281998,-22.156084,2.379324,36.117692,77.960461,162.224379,160.789875,58.771328,-59.097974,-73.264025,-23.542649,-1.22882,-70.776617,-152.897251,-241.387571,-163.186246,-124.69111,-97.683483,-78.803898,-35.207914,-47.057694,-132.032147,-162.43911,-187.675262,-221.287282,-236.565823,-256.101352,-253.510654,-236.21771,-249.170346,-298.272404,-286.045204,-267.695334,-292.167414,-324.051822,-339.12647,-322.529199,-267.312776,-236.11636,-189.485499,-145.183827,-126.379278,-85.720087,-49.2652,19.415289,29.890791,26.045088,2.166864,-13.812239,1.719353,15.128896,-15.693238,-42.722997,-85.072613,-105.774349,-142.245568,-131.801708,-106.362574,-38.967072,-0.376106,19.649557,-0.816703,6.572708,-8.263381,-80.957165,-228.684743,-232.304642,-125.653205,-85.280424,-103.07898,-126.1803,-158.241879,-198.118995,-186.979888,-82.683289,-23.557461,22.067922,10.155028,-18.029007,-95.023425,-145.699109,-144.328178,-82.788182,61.905501,96.559558,31.137673,-40.336827,-137.51452,-118.040528,-76.148395,19.168576,54.104777,95.896618,107.316282,59.574017,-95.347259,-125.832538,-3.983158,70.858531,71.664898,15.742581,-91.25383,-135.853338,-221.623895,-212.61356,-149.511582,-15.766947,5.211332,-22.153425,-47.602309,-123.169269,-102.338714,0.284967,210.705533,210.915419,47.57326,-25.972403,-88.331069,-88.639199,-75.437862,-87.171089,-68.477298,49.840703,116.561652,159.788618,127.513523,53.646695,-28.621105,-84.607089,-94.221393,-34.772381,62.952449,49.205677,-87.895578,-156.442116,-189.539979,-126.449999,-96.717051,-7.311264,75.630429,209.624218,206.503747,92.455994,1.617134,8.413172,104.283383,145.05345,133.886685,102.539828,41.447541,15.478491,-15.490505,2.071421,41.984738,160.222273,222.990124,325.467729,340.217312,280.254971,171.170927,130.178855,110.507533,140.172401,273.329214,327.013434,310.850352,284.082051,250.159416,177.40593,168.62247,286.78092,370.627237,404.259254,341.528132,199.18532,116.355046,86.69463,91.359256,119.70479,199.307332,252.060066,281.856523,241.268415,161.14967,160.658769,169.756038,182.012878,206.357255,297.194993,330.446261,264.131695,4.918683,-110.494719,-158.817762,-105.615654,56.177679,107.152958,69.198677,24.977042,-23.553601,-56.725898,-67.932736,-62.913541,-45.797025,-36.446151,-52.824504,-83.285519,-154.41051,-173.804581,-75.791326,-0.544106,104.574357,121.675365,64.93692,26.74825,44.719078,110.221026,116.857696,78.336243,43.731954,-1.756095,-3.732126,-46.545008,-155.706875,-166.886547,-85.301532,-34.688947,84.580431,149.693893,211.858678,201.442577,144.754514,116.465973,119.176945,118.618378,127.090013,180.971054,178.482236,73.500641,-62.415005,-114.439653,-143.703174,-119.43869,-3.541355,74.134842,133.492838,68.47724,-135.420167,-176.532776,-126.982228,-14.231014,23.794221,38.674048,0.938886,-154.859165,-279.641617,-291.684261,-278.102194,-267.232784,-212.482599,-189.457858,-219.126605,-242.623025,-225.973038,-139.428121,-82.695886,-20.435133,-25.655591,-78.474391,-117.652358,-183.145806,-226.647952,-214.439594,-95.070722,-48.989578,-58.926972,-84.068,-130.296269,-147.229805:88.011438,-42.183573,-93.048123,-29.167778,64.027993,134.260841,59.059618,-132.649844,-171.126251,-161.627581,-172.77788,-192.964932,-226.916992,-236.137644,-223.838211,-189.363346,-121.384364,-180.453897,-228.836984,-222.70608,-163.91213,-58.99739,-44.501946,-62.428491,-122.029435,-164.736755,-193.871438,-144.119323,11.340067,44.91537,-1.709616,-41.864686,-125.924676,-179.524804,-153.397766,-8.720055,67.925095,185.144361,229.62539,235.455596,134.562775,116.924137,166.247698,195.659327,224.245286,217.393179,147.944416,92.149427,-1.84682,25.14513,61.36925,77.440231,72.837877,77.407043,53.897395,-99.060975,-202.468287,-147.03161,89.005492,182.070437,249.31095,232.977897,158.003347,143.947222,161.265441,147.99225,142.227218,151.146104,147.851249,99.977638,69.704605,4.30605,-82.892019,-123.332415,-194.407122,-189.101132,-62.645821,-8.507757,-44.395108,-108.289632,-210.865371,-240.316957,-239.573788,-177.992216,-113.415916,-33.347266,-63.449748,-227.83942,-334.393538,-327.220475,-307.745481,-324.104603,-323.577292,-308.001413,-363.095561,-431.755643,-523.80838,-456.583821,-403.743227,-336.128644,-305.416999,-283.971558,-315.29059,-402.736758,-401.270806,-339.431007,-213.654037,-202.970635,-186.613109,-147.672845,-92.860393,-90.745813,-85.382789,-48.874462,-26.476666,13.742963,27.349736,0.963657,-47.551378,-162.333756,-228.051958,-224.293395,-159.049326,-127.287531,-76.629766,-45.35709,22.416135,35.583179,-55.907095,-205.941009,-221.455256,-118.861324,-62.799726,-52.975648,-93.742019,-206.346349,-259.734832,-247.000783,-176.155485,-129.723902,-40.139968,-21.197231,-80.587695,-146.859556,-280.708077,-295.01645,-245.094061,-126.91531,-109.842062,-228.056875,-333.616567,-450.642239,-381.496226,-346.641969,-372.512198,-401.600353,-363.579196,-310.552685,-267.799218,-278.341177,-285.771047,-216.866613,-167.869037,-78.41756,-19.30192,116.751121,149.915571,70.798618,-138.185393,-224.373874,-237.533339,-180.859848,-84.776818,-85.936711,-173.121599,-224.83331,-272.180556,-231.676984,-213.761674,-186.687415,-126.215085,49.554988,80.815394,-17.975177,-160.057078,-195.938632,-227.979844,-246.515345,-273.477674,-266.306848,-213.162389,-208.217446,-307.117387,-366.01913,-330.252387,-222.517492,-175.38408,-119.041012,-122.729198,-167.480458,-240.40068,-247.745139,-105.643786,2.775487,112.347231,95.259017,14.259726,-19.781833,-93.085702,-136.076108,-99.597174,75.574655,142.577086,101.158964,36.565277,-28.446426,-33.392918,-11.669065,75.150567,96.931937,81.39876,63.423553,-18.355279,-88.300314,-196.820141,-119.369317,-55.154668,-15.211674,-1.739791,72.555913,86.766139,2.829516,-60.690085,-17.783544,133.46953,180.958796,161.876146,106.652972,4.001867,-23.59633,-106.753438,-191.218276,-175.152041,-18.838922,80.618634,175.026316,150.109585,63.438838,-14.69752,-53.531964,-63.555634,-18.331896,70.464882,52.948403,-77.200082,-127.538124,-128.350706,-48.408972,-11.432334,99.484525,197.238943,336.48416,316.774817,182.416076,90.172717,83.685383,147.817023,198.187282,254.171327,230.739958,128.691153,105.982104,123.106167,137.438814,172.394923,331.820117,414.552178,455.996389,415.954657,319.659492,176.419365,99.967467,73.573449,131.856757,326.888083,397.42956,365.012728,296.105627,164.445189,120.131616,128.496126,179.641778,233.550807,316.788529,296.475156,186.953216,120.758863,107.40274,97.90355,105.622378,184.77175,245.32327,281.194446,239.600507,169.051246,238.279876,271.531843,267.480724,285.498342,381.755646,394.651634,245.265929,5.576525,-66.310821,-95.686478,-63.392804,74.000159,128.7178,92.231356,50.939478,70.516267,118.248135,116.707722,146.418604,175.981455,97.370108,-5.91933,-118.060872,-112.514057,-109.828815,-68.878959,-12.718159,123.477151,141.073735,45.819368,-9.710629,-72.162113,-54.617478,-9.117823,105.384043,145.091246,114.410059,58.092536,-57.369918,-173.528798,-176.770069,-17.239035,93.413677,283.260005,340.592618,326.852524,280.979108,225.230387,212.630828,203.90942,201.743382,208.092225,188.422329,168.532582,116.406883,-15.647652,-78.814353,-109.744689,-89.365191,-2.636043,63.587077,128.142444,70.45688,-149.015724,-210.778084,-177.507665,-126.191259,-103.327573,-46.086782,-24.363389,-65.243561,-246.109198,-302.920914,-247.061458,-170.944435,-41.042071,-23.180771,-105.919815,-171.774716,-252.220174,-255.663492,-210.930495,-14.954496,75.123701,92.309002,32.477515,-88.105452,-126.23083,-94.086555,73.908524,138.205695,98.934793,28.716227,-103.002205,-146.839147:28.435443,-123.827584,-173.107423,-110.765579,-25.400534,83.955021,54.900659,-109.939646,-233.63288,-252.157598,-222.641299,-201.602185,-162.997192,-139.912669,-95.163506,-70.417542,-62.636391,-190.739285,-250.431782,-248.269685,-212.525042,-177.787912,-187.928123,-192.212512,-190.381,-214.950724,-243.343354,-216.39227,-112.755014,-71.716694,-53.260328,-75.659354,-179.831128,-233.06441,-183.682786,-26.829555,33.336264,143.357353,200.009943,243.37613,157.157408,123.862852,150.674271,181.90932,216.305596,214.706604,173.831192,141.061367,94.01677,113.03319,131.610143,137.452266,118.134378,48.427932,9.206502,-62.165392,-102.421096,-88.936627,23.795416,88.291586,137.066224,127.555316,86.508091,67.111456,39.234879,43.390767,80.052894,185.016933,220.784838,236.307654,213.622301,95.105213,-73.332984,-145.698847,-211.244716,-191.629713,-60.381249,8.022019,0.906064,-67.980708,-196.189141,-233.88115,-219.554826,-152.655284,-117.48686,-108.286659,-134.658792,-211.227103,-361.787876,-441.195132,-504.415071,-481.419834,-362.692719,-312.368856,-351.115294,-428.06956,-545.706246,-484.290304,-401.596021,-235.287289,-170.152728,-130.633266,-192.411392,-424.870848,-537.304846,-495.349071,-324.510074,-241.103791,-71.791697,-4.628726,17.867777,5.769561,13.437943,18.507941,14.550878,-2.537073,-9.443645,-25.015673,-26.414736,22.995788,31.170512,0.021143,-33.684655,-10.91615,103.582961,167.307263,207.827567,182.390797,95.894453,4.482861,5.643275,107.145711,150.022702,104.149592,19.936678,-115.185085,-130.76738,-138.408945,-159.447139,-147.003872,-65.158113,-23.973482,-20.279976,-49.363262,-91.642565,-98.760584,-89.832691,-90.014117,-108.99116,-75.848707,-24.504563,-32.862678,-183.759249,-230.036059,-227.940434,-226.698787,-259.019657,-268.448724,-245.636681,-203.504524,-110.718955,-167.630284,-224.384339,-241.260139,-180.23077,34.079159,130.79417,174.381317,20.489584,-61.898629,-72.29162,-21.571825,57.561278,75.555634,19.73218,-42.472865,-105.995853,-104.071211,-81.259834,50.42113,128.842688,165.247834,124.75629,68.509491,41.632106,10.592087,-42.155602,-55.1661,-37.85794,5.426032,94.150218,91.110118,-16.562461,-60.91111,-12.777769,138.150832,192.338965,189.418863,154.402092,116.67242,71.9182,34.917747,43.082353,101.199365,230.596371,271.248184,258.332803,197.347962,51.059276,39.065833,85.997751,169.996056,177.867007,128.713207,91.00427,51.975053,60.987962,78.561919,118.572147,111.13236,50.948048,37.059488,30.537664,-2.85718,-145.324704,-218.644846,-184.883596,-63.297212,-11.567808,42.590839,42.081412,7.041539,29.788072,79.301351,130.308161,96.888062,27.552883,24.359075,-4.475886,-40.534362,-108.519685,-134.379751,-108.114466,-4.648453,47.552949,111.26445,101.244099,37.286236,-21.991364,-28.485536,46.308982,97.758561,151.674241,143.525209,14.145585,-85.233391,-195.346838,-145.778634,-100.434556,-1.093731,66.643953,193.923321,205.735324,123.868119,52.04326,50.605144,86.265185,107.367733,154.798815,162.59276,112.405231,96.676208,100.370967,51.635163,43.390565,105.11274,159.891753,266.665641,300.455252,312.094281,228.404157,184.21917,164.107632,169.670707,187.185616,208.131796,226.87079,198.928953,56.535234,-78.541214,-62.932773,110.274005,201.651456,320.397651,344.865813,269.364826,80.683817,19.009795,16.853741,46.574291,109.825004,141.546435,167.68482,151.6551,70.388796,25.856558,68.82201,201.868354,244.340586,257.902619,232.104219,115.315206,-81.091319,-174.606549,-231.831639,-186.75102,-34.498809,31.570816,41.97735,-12.196224,-106.823064,-102.762061,-89.375259,-108.512673,-125.375507,-133.086873,-138.639801,-147.555566,-163.427754,-161.885315,-85.506465,-38.646445,24.928484,46.258207,11.692245,-50.392639,-154.00414,-132.767345,-87.925286,-29.312755,-39.309129,-85.604322,-99.133604,-172.654811,-329.871577,-349.447331,-209.979562,-120.392745,13.937903,68.185387,144.489615,158.971269,112.809223,9.183648,0.688619,89.395104,135.85601,143.923801,101.944802,-18.477548,-132.81809,-167.012204,-134.594028,-98.640242,-51.332288,-19.519328,32.278223,10.419126,-167.293017,-362.500004,-375.914316,-283.918056,-246.295635,-204.955036,-176.25494,-122.393212,-127.372402,-161.460211,-274.649689,-310.476849,-257.275687,-200.303991,-185.692825,-231.004976,-298.611825,-224.1815,-144.415679,-38.343005,-43.623394,-112.153287,-142.180705,-176.978709,-186.838532,-169.918459,-83.016902,-29.423401,36.222782,21.85426,-71.095059,-100.078871:28.129796,-127.116788,-130.970675,28.433611,125.874953,142.253646,56.875025,-108.276738,-224.36333,-267.278006,-252.095386,-202.394361,-80.205508,-30.487527,-2.82615,-20.908784,-93.794254,-195.181522,-229.705716,-186.94411,-107.10976,22.306155,23.157191,-48.779524,-116.048957,-132.862248,-81.226092,-17.867839,72.716896,71.958876,8.539889,-46.81582,-217.552619,-293.368343,-228.861772,-37.537144,27.520877,95.073995,107.714315,121.91348,131.33208,127.891622,128.171451,151.473286,210.646893,205.928222,139.964018,99.468895,-21.492148,-71.308292,-25.465959,105.486291,142.509829,87.443894,-4.753255,-208.400215,-252.088216,-194.667262,-18.965037,59.764313,150.2708,137.944945,28.007184,-18.946388,-53.287018,5.502204,72.280245,171.405333,169.640346,117.378999,84.984717,-43.448752,-193.870836,-197.549087,-101.686913,-68.258576,-15.531207,3.143559,-98.472515,-200.405906,-341.474768,-327.758108,-280.8378,-155.232054,-86.872741,-44.49496,-95.042479,-250.241792,-374.647139,-391.34249,-348.450518,-322.482979,-255.205915,-228.033205,-297.44797,-377.953982,-473.768199,-452.316127,-441.470946,-383.323717,-306.012511,-220.062511,-296.963494,-569.520192,-643.115071,-568.710968,-385.656188,-346.812608,-297.427927,-242.690776,-137.6948,-110.94156,-87.16088,-85.412482,-90.590933,-73.996218,-36.323114,34.106021,30.883886,-35.26298,-128.213604,-141.588663,-70.582354,-28.814714,27.503548,54.514647,69.443172,23.881666,-152.391403,-223.249025,-165.936038,16.484213,72.353844,59.945787,1.645434,-165.606799,-232.669817,-196.082553,-93.963799,-64.66363,-28.302652,-27.810416,-74.39993,-100.639185,-151.187372,-168.443168,-141.560726,-79.730399,-79.732525,-142.114468,-185.885582,-275.360885,-359.707425,-368.960383,-310.371782,-276.93818,-244.397247,-249.122183,-297.374933,-313.936266,-244.537732,-132.999945,-129.107447,-129.694582,-61.90878,126.471606,152.99396,28.592526,-155.304975,-190.576648,-120.928674,-71.10698,-28.363936,-40.583526,-126.925579,-184.268424,-265.472447,-213.541319,-138.810449,30.406898,97.526249,140.284968,124.890013,58.591624,-42.280896,-67.920361,-61.51368,-57.078167,-36.903545,-16.004623,-30.662571,-89.212809,-209.300281,-130.025663,-31.137287,127.932228,169.580614,189.134611,156.278615,9.982021,-93.470701,-64.313991,114.793905,209.286959,358.955786,393.577442,302.90221,192.20661,-23.734016,-41.12876,33.034215,176.738224,202.322218,182.542568,161.464461,96.674699,38.878169,71.688762,229.344946,281.967549,254.325688,190.839949,88.94647,73.939041,33.344278,-20.329532,-30.647337,-13.196974,30.852595,90.395938,51.459376,-48.299417,8.770589,89.48314,226.480845,242.167857,223.310106,207.34692,111.860195,31.678945,-119.903447,-118.694292,-53.770081,105.093721,179.343198,227.936037,177.367667,57.031659,8.662401,1.76949,34.713168,76.697198,170.380942,180.878873,46.897533,-84.687273,-301.552011,-225.983893,-122.533538,41.783185,121.321752,251.948445,243.559411,127.011768,92.742062,111.621034,159.623524,194.074499,274.59239,291.570366,264.704993,241.674832,186.750262,198.463939,264.446777,391.633845,412.617794,396.410024,375.532296,349.182062,287.895568,230.728021,177.565052,196.357711,282.102023,317.773488,266.110443,201.270362,102.91369,52.318655,54.43118,132.740868,194.066408,256.791739,223.19402,92.461662,-20.405769,-51.444185,-13.126845,51.037933,181.706873,208.027092,173.469267,141.241098,68.63018,30.066575,42.259671,108.705705,169.594413,250.067917,198.301707,-23.973888,-144.625042,-162.136097,-203.211706,-198.268361,-39.205204,48.083063,20.231126,-73.231398,-191.159354,-82.92446,-14.199854,11.102909,-8.706043,-95.909043,-164.810495,-250.992687,-264.601489,-231.79795,-54.496323,28.586191,90.100714,72.750494,-52.691667,-138.620686,-275.579722,-245.989964,-168.289723,-44.213641,-25.810734,-28.787533,-46.152923,-173.993614,-349.53828,-355.422344,-185.291593,-55.941332,231.532526,311.520392,199.463329,88.975272,-2.985293,23.691202,30.300904,87.829279,151.474461,204.934648,154.521146,13.38718,-115.056837,-192.054751,-296.312078,-286.080929,-141.33641,-63.299555,-31.108892,-75.950298,-241.735626,-393.241883,-410.364052,-299.32428,-210.886273,-126.735715,-133.687087,-170.905781,-242.813934,-257.36019,-232.910014,-220.294772,-166.315106,-135.224967,-171.52532,-234.858528,-331.097601,-264.032323,-166.274782,62.452398,137.751456,108.187638,39.008387,-32.338223,-44.871739,-34.860813,54.695643,98.963359,108.208584,65.292074,-91.571042,-157.133404:-112.616811,-209.44913,-212.723195,-65.233683,30.079491,74.54617,5.703436,-184.596511,-272.706711,-261.38873,-214.713374,-232.53061,-277.778972,-229.249746,-35.07178,19.529913,-51.943127,-225.585361,-261.780921,-189.194027,-154.02633,-191.93897,-223.963173,-212.315141,-183.110784,-206.915405,-258.886986,-243.411061,-118.213343,-46.782147,18.404542,15.77564,4.778111,47.791854,90.068407,112.539304,89.631816,110.78248,155.860708,177.606426,102.937785,95.216993,124.407269,100.528367,4.732198,-13.426625,1.510996,6.522003,2.269894,8.400193,22.025521,42.612603,52.771681,125.992363,164.422694,124.992376,13.603009,2.930835,67.347331,117.133111,204.843838,205.098714,117.317276,77.884807,50.073374,40.808611,48.924571,98.281428,126.446852,176.699509,208.065293,245.157734,92.725413,-41.007296,-197.650886,-178.150235,-44.512528,-11.125759,-98.887601,-152.233992,-150.016342,-147.072425,-177.926509,-202.208405,-168.478118,-88.103697,-56.773617,-36.323499,-230.620555,-357.764971,-383.038844,-295.37293,-156.185943,-140.738466,-234.709501,-334.600209,-442.776263,-308.265726,-232.43447,-177.76327,-176.021962,-203.374021,-254.507663,-386.515343,-407.487411,-375.416337,-265.790689,-191.64198,-17.139468,51.643729,76.673508,57.495306,39.856494,35.847077,25.723764,-10.946466,-34.558206,-72.797021,-69.670047,6.978605,57.306201,36.762132,-32.256289,-46.643024,45.231303,145.932707,254.160507,227.92897,132.501124,88.971503,99.041537,111.358084,86.616214,11.238202,-24.349024,-100.104905,-132.232991,-113.734114,-60.077423,-31.894676,62.283774,114.238715,158.344244,141.92452,48.912543,-37.882323,-41.953142,30.714711,85.374503,177.183551,188.891705,132.884822,53.937228,19.781001,-53.341541,-112.494683,-278.325127,-340.253374,-330.877706,-257.334663,-99.64036,-175.336449,-291.009657,-412.906142,-349.582602,-128.672061,-58.040913,29.470917,70.43155,56.473833,58.039004,88.192219,121.486892,113.261538,86.599488,71.68982,33.775191,15.660988,27.936675,99.705055,150.055725,191.270784,162.486034,118.790186,157.453831,157.109284,114.133879,112.642,158.725045,186.693261,230.287105,234.842595,210.465524,206.946642,231.119164,298.818888,322.488024,338.217809,335.181061,298.517184,240.132094,238.509161,286.002675,303.180802,306.598151,315.133904,321.826444,287.089825,148.566056,76.206445,117.188357,261.104512,297.5771,216.590139,129.752161,54.611076,89.598687,95.628499,112.761126,117.723878,75.44202,41.365501,-11.545831,-34.354872,-122.174635,-154.03212,-82.228028,80.770212,82.7992,-49.082484,-111.315845,-79.376918,103.845648,157.766753,110.442207,45.537101,-11.675485,12.923349,71.093673,75.701642,7.279509,-53.400918,-16.546358,124.793348,171.416463,177.314003,143.696578,52.785603,-37.015641,-63.061634,7.783523,72.556425,137.302796,131.436023,58.697356,12.669524,-96.335714,-250.308795,-285.758591,-188.075384,-78.183023,103.694247,107.132705,-24.690752,-127.929172,-149.102704,-108.487014,-43.016152,84.636085,115.347673,104.461169,83.572997,80.175258,138.215333,172.33326,179.529841,163.795799,185.553191,197.873038,186.577323,225.528768,238.323706,182.049814,148.552118,181.091867,205.454765,107.833655,27.955264,-26.631688,-5.93279,22.174438,122.139019,186.089066,339.025451,385.207842,311.725828,186.20854,153.219087,105.383768,102.453281,178.136248,207.990226,105.070041,1.850113,-112.971208,-35.770582,31.340679,116.909045,139.906245,197.230463,199.360481,55.961099,-130.352915,-184.861605,-233.442932,-210.478457,-53.204852,13.066015,-62.264246,-168.163265,-260.85414,-203.059526,-206.026281,-262.18309,-280.586027,-321.039648,-341.000382,-283.97078,-148.657872,-120.51361,-137.960937,-143.648203,-78.795187,-34.268346,-65.620328,-120.281038,-145.715003,-101.330874,-88.076185,-129.475732,-173.738568,-167.822212,-115.758321,-88.035733,-256.229825,-336.656937,-325.310258,-251.731547,-95.252735,-49.095901,4.384419,39.475508,93.998992,67.250645,41.121769,8.860343,-9.476645,-58.476919,-76.246318,-95.809374,-140.457722,-169.178451,-137.010198,-70.597009,70.970342,108.865629,91.988608,55.145779,-81.333924,-289.535671,-364.538927,-388.967298,-355.862221,-271.41769,-235.828575,-148.170941,-86.791996,-113.719457,-251.328008,-310.537741,-300.823623,-236.973073,-124.125096,-113.015674,-124.77558,-62.987933,-18.484331,34.276631,36.520812,-40.501365,-111.529858,-206.800639,-222.431342,-230.198793,-230.077507,-204.087788,-103.318771,-61.778377,-43.444871,-42.226044:-190.260452,-252.153646,-227.495495,-63.386405,32.106411,107.695695,52.469791,-178.30921,-329.099389,-330.282811,-253.598229,-216.858559,-139.573065,-83.952726,-22.823951,-56.494204,-196.291399,-255.241529,-243.420068,-199.704076,-158.262078,-82.367023,-97.010331,-170.693228,-174.846816,-173.418221,-163.701046,-138.817304,-39.417621,6.502628,-11.659784,-68.536145,-199.120461,-261.274186,-232.596706,-94.805406,-19.807836,94.603116,127.947226,121.100309,-6.132862,-57.958407,-29.193799,25.705444,119.266134,127.986551,49.942368,-3.251241,-63.722339,-45.199315,-35.034299,-35.145672,-20.387017,2.702299,-23.504347,-127.880162,-182.195215,-159.336784,-17.722943,70.121082,187.160855,185.414718,93.721134,53.215282,17.502107,29.587363,74.551666,240.500964,306.912158,289.569621,233.539629,136.784201,18.805705,-47.450036,-81.779987,-40.370082,52.188196,48.078529,-79.653185,-138.80317,-142.952573,-119.520906,-111.346872,-63.025952,-26.840822,33.550028,35.70728,-96.478575,-342.884023,-387.703783,-237.492471,-136.690265,-65.42125,-85.770079,-192.410188,-270.948182,-422.65082,-415.256018,-350.284117,-219.007391,-167.983439,-139.406403,-192.6478,-377.822518,-512.675495,-518.552273,-410.141376,-326.031328,-134.182806,-61.446823,-55.581721,-77.580905,-54.92815,-29.494382,-22.205909,22.726896,66.234386,121.095152,93.360356,3.452094,-37.543815,-38.94905,23.113353,77.615478,198.895676,249.348532,246.304851,180.105396,21.224315,-9.418266,22.369498,105.315332,136.668082,127.568254,83.680116,-52.071672,-163.747119,-171.033733,-115.292161,-63.534064,77.941917,124.187167,96.876806,45.062583,-84.884744,-160.125931,-138.166164,-4.400357,61.341985,88.488969,56.950626,-24.237361,-109.30488,-137.216072,-162.416154,-173.646698,-204.382354,-233.926193,-293.707978,-296.040397,-262.719318,-228.424819,-218.842491,-215.057874,-192.418606,-61.786669,20.532554,106.581901,-22.715166,-105.845772,-54.628644,56.193493,188.304622,163.96995,31.847831,-31.86222,-119.267629,-79.797097,3.385876,225.888868,305.433528,239.773584,123.091548,0.465343,50.577657,62.422082,93.705838,136.105162,190.302059,204.135788,234.250951,197.507016,-4.194514,-62.379263,21.212535,245.772973,323.550711,383.319094,375.755864,277.53522,151.881376,152.061963,236.716665,276.732949,376.345354,431.401022,424.572064,347.786995,162.879188,105.905194,154.16227,313.708589,374.719522,381.333795,329.254014,183.972757,64.419174,67.577896,206.573898,274.719185,300.080308,274.275612,222.500484,180.741602,0.168405,-119.102669,-87.534777,61.341919,120.122925,104.706387,38.403331,-44.819704,48.154553,132.404832,213.078246,165.550694,72.131695,93.641755,128.494165,72.813634,-115.205356,-113.372202,-24.023372,122.047434,156.062283,173.511824,137.038873,18.039147,-72.927263,-90.839732,1.114425,91.295548,209.994651,199.050811,47.154702,-52.036077,-217.480981,-273.733045,-232.066254,-42.936998,58.569004,135.795094,95.64382,-33.807999,-110.179048,-106.36178,-20.644285,41.750891,187.197259,252.808665,264.455132,198.304743,21.325601,-27.098035,28.04573,189.227014,263.613223,346.245278,324.462832,241.95219,250.829495,265.832332,247.126328,232.427048,256.060933,263.70392,170.892543,96.501456,-1.489395,-33.655201,-36.266997,28.729481,102.667673,226.94301,226.190952,102.058751,8.083901,15.002432,49.641461,61.728357,117.414626,134.590219,58.438423,-3.751599,-77.7524,-66.059615,-26.338192,61.212961,96.858406,149.398001,137.981097,13.326994,-156.347618,-217.672931,-206.793006,-124.61752,47.491032,57.593795,-92.601413,-178.108659,-206.020714,-125.034347,-93.363257,-35.132027,-0.555767,-4.068342,-71.738736,-214.719118,-223.442548,-198.854956,-98.961623,-30.806748,81.908787,79.440164,-122.212343,-261.774904,-393.678537,-303.501771,-237.318198,-143.464008,-111.664786,-93.043632,-122.022875,-256.660864,-459.63126,-493.523389,-330.288228,-209.917858,-23.526872,25.604287,19.155525,-4.724398,-34.997752,-56.311143,-37.261207,75.270126,119.667171,101.645813,58.801666,-60.382582,-233.427475,-282.679524,-223.213453,-168.936578,-103.958974,-73.793107,-31.492599,-66.236558,-261.220843,-418.796603,-451.87595,-435.717201,-375.765737,-193.757428,-111.139955,-65.285174,-138.774989,-158.39697,-167.505345,-178.006385,-179.570485,-167.499059,-206.610761,-264.49852,-323.523139,-199.491248,-111.13557,6.88022,33.406668,16.143421,-30.376777,-108.163343,-111.559161,-95.298261,-20.903523,13.624091,41.520648,50.616688,54.981816,31.03775:20.017429,-126.504567,-158.652826,-79.931859,-7.768313,110.658935,122.978482,29.932366,-90.187993,-102.821329,-75.455195,-93.835542,-166.290071,-176.525946,-196.826876,-225.118887,-291.94638,-365.141304,-376.407223,-311.4755,-270.230004,-241.087146,-232.50406,-157.506114,-93.606337,-111.283011,-164.132146,-175.22103,-172.180886,-135.535932,-12.537997,43.466784,120.217579,148.622259,159.06974,116.12567,61.87041,37.279197,69.144858,81.005539,22.066235,-19.921898,-142.98109,-217.175598,-324.140225,-322.977978,-245.496841,-211.469632,-167.686274,-143.974222,-138.068262,-114.804638,-72.780578,83.404633,150.527503,186.295425,164.164184,163.344306,195.026639,211.436972,234.210117,246.603068,193.278302,107.792822,-39.455799,-63.922237,-48.618158,36.05811,86.815521,155.009096,180.880779,205.24625,94.665816,3.750555,-127.549999,-140.619229,-78.749301,-51.696707,-91.374955,-131.888951,-141.734916,-122.452168,-168.672711,-275.303388,-235.143816,6.677969,90.31895,51.279035,-96.118215,-141.818015,-128.418855,-95.924992,-29.508607,13.198288,29.887401,-27.288333,-147.463668,-111.405068,-80.814384,-132.029979,-175.576003,-204.120012,-218.509772,-299.004991,-367.485852,-361.270923,-255.058994,-197.693826,-115.650988,-70.361843,5.190504,28.77147,68.072293,73.336544,64.587542,67.773859,68.183838,15.494234,0.96348,102.648941,229.687538,229.329684,124.107719,82.935037,136.196979,203.316881,257.648554,225.748488,128.924507,138.775368,177.040855,183.872657,159.669913,117.876618,87.350765,35.428515,52.087452,72.585679,120.741114,143.891849,229.032762,305.607054,440.67776,448.796832,349.701166,242.213942,204.091818,120.059223,88.273249,168.136551,263.665055,342.82825,188.891397,91.992371,2.595287,-4.624961,-73.772383,-133.758474,-213.043524,-205.350703,-128.701814,-187.565038,-281.323427,-395.196443,-347.748883,-95.975318,12.661014,56.441429,13.412098,14.016797,38.572277,54.533657,120.504182,160.714339,171.24405,147.654056,113.414351,114.560408,147.886567,249.288032,274.437425,213.354238,149.453351,105.975609,160.082857,155.575179,124.223431,129.273554,167.491052,185.035762,146.044313,87.506962,11.394887,80.61263,139.154186,177.007301,155.364351,139.856831,150.152232,138.813197,87.19778,78.351934,119.795825,139.813643,159.05671,188.190493,248.815505,236.383192,144.914949,112.562659,136.686366,190.755724,223.019619,324.002113,349.308196,312.726137,247.692059,209.17276,159.876257,158.065487,137.679776,100.641292,48.870251,66.836623,101.870583,30.593914,2.169604,26.969161,41.664665,-1.431459,-38.09843,-44.34116,-12.234148,-23.839984,-71.481595,-78.140146,-22.837726,14.768247,41.848237,48.177289,73.410658,37.911852,-2.461952,-68.732285,-65.391019,39.245474,100.849379,115.191309,-0.579924,-24.845714,44.557814,84.945556,137.066348,142.99881,48.500051,-20.348173,-105.341457,-211.318954,-259.446823,-235.465011,-158.244218,57.104708,134.58756,153.303557,54.794162,-9.737579,-40.483376,4.158975,104.577577,139.056886,150.923234,128.85845,108.161431,131.164333,162.576173,207.365743,192.412099,139.26103,117.509244,142.091002,271.174779,312.045663,305.191608,260.280321,116.059661,70.397425,99.324474,140.365418,189.543385,209.136605,239.161926,303.891213,312.272098,338.134694,366.762092,413.525842,417.474689,380.821092,239.873752,187.268752,210.52636,257.008572,270.50358,223.852266,123.951326,108.575933,140.831785,229.857015,266.316593,311.044658,306.128298,215.030554,16.431614,-72.655658,-109.738183,-64.854138,47.59269,70.392596,-28.900843,-119.921054,-231.37929,-236.066791,-228.391666,-235.719096,-233.742969,-191.532683,-184.522481,-200.825372,-228.936179,-244.105374,-180.202118,-115.041253,-34.549519,-24.592848,-62.808472,-103.933828,-171.795491,-163.055628,-126.153062,-114.040493,-158.956793,-212.696418,-188.300301,-120.623143,-131.915111,-161.55404,-226.122422,-251.717185,-241.22135,-188.855535,-50.276929,-8.226991,18.45828,14.437509,0.673462,-46.360644,-78.57223,-121.447169,-117.13996,-74.272998,-54.47228,-53.918341,39.363711,143.564495,311.960567,321.910632,230.489234,165.127086,15.238869,-122.314578,-174.262796,-280.937839,-314.64225,-260.700406,-193.260098,-54.960798,38.02238,28.501416,-132.05515,-233.555802,-271.53796,-177.007473,51.703425,100.116253,61.252988,-5.914663,-2.227656,37.297671,25.324466,-73.773017,-132.414599,-213.599471,-173.092519,-129.692305,-77.837955,-59.467031,-28.919875,-30.408676,-35.617505,-16.542445:-107.206108,-114.406846,-110.711705,16.086757,109.091849,152.561124,89.54503,-38.739887,-120.817356,-163.017009,-209.668108,-223.275184,-250.565518,-232.852981,-123.876899,-77.545507,-71.902495,-118.72164,-124.783471,-112.947981,-122.660185,-168.050905,-180.705477,-135.637645,-61.823439,-79.644434,-173.419263,-187.98025,-89.785028,7.095437,145.563994,145.970611,126.364222,280.920389,380.472501,389.221282,318.218928,283.024436,341.804064,448.854388,389.917715,310.130205,152.297518,82.429174,-54.239073,-92.238558,-21.958229,56.720985,88.736118,-19.956191,-16.999758,121.202224,190.896006,252.422879,252.592576,232.452539,185.96934,150.191179,138.037109,179.892596,284.198153,301.41216,222.877564,152.949749,31.604925,-52.952695,-71.856021,-36.472933,19.552366,154.587759,200.128839,216.124094,99.804409,-9.19241,-206.344678,-235.101879,-155.870527,-121.474663,-198.213713,-272.124132,-355.758574,-378.758025,-390.471059,-371.073245,-323.993526,-208.930711,-165.953067,-140.331709,-222.219281,-273.235317,-287.643946,-254.778777,-169.914839,-126.912042,-114.139949,-171.091019,-298.373075,-237.635672,-150.932891,-16.118099,7.020318,-37.325794,-114.67791,-264.350401,-221.516985,-184.878694,-171.030597,-144.947716,10.335385,87.718993,109.612134,90.266396,87.608153,57.153037,58.376305,116.751834,108.043745,-58.14959,-145.881588,-137.438978,-31.472169,-37.085262,-89.854656,-70.219165,76.296349,160.906209,241.01855,236.014462,173.960538,88.110499,92.088811,142.50428,120.951991,19.90922,-1.079652,41.586766,76.787415,75.833589,63.866852,48.149037,54.553092,102.546884,200.774948,215.366786,187.554553,107.218874,66.374206,37.059353,52.573488,131.783193,167.314068,160.376042,57.013148,-13.131964,-91.735279,-89.154834,-84.500494,-90.062193,-58.478557,-18.245835,59.304814,18.737901,-65.969693,-206.234246,-188.434911,-22.153812,51.241949,92.034337,92.697558,104.226561,134.004496,148.246694,152.864815,136.252438,66.955401,30.562053,8.527659,65.171323,93.562565,87.289884,86.58315,119.12121,118.575325,123.398922,126.875207,90.525345,22.063209,28.113644,139.837446,223.126517,300.638186,269.356098,158.020649,124.432938,155.055912,237.04014,255.614087,266.476479,275.55027,245.097639,73.118137,-11.68623,-45.87946,-24.98503,38.536136,102.773445,227.440677,237.316564,121.027896,-25.841779,-15.384819,116.674798,172.445494,212.725632,190.508343,98.045652,-4.679022,-52.984249,-79.583396,-49.030395,5.775666,7.146274,22.531136,55.013562,82.182631,-19.192769,-70.310068,-90.215591,-70.146231,-57.085074,-76.890912,-78.932049,17.906023,48.936757,-8.715772,-63.226765,-46.235445,40.272695,190.646755,199.288955,103.564711,4.548043,6.048886,30.658284,38.575765,84.182416,86.859251,28.022328,-48.007713,-79.395373,-41.995118,23.272887,117.59957,113.404942,6.480706,-63.751077,-180.509002,-286.143593,-321.527498,-276.926379,-175.577395,78.640642,146.504193,102.42172,-101.180159,-210.37616,-260.728846,-205.585793,-90.709221,-53.239716,-32.290296,-52.167762,-94.115936,-64.81713,-19.038721,62.938826,80.4528,97.636875,99.662095,122.020178,163.201951,149.942765,84.909733,66.556291,32.6653,12.309964,24.546406,59.571163,137.503351,154.394643,138.03598,138.224798,187.907849,314.358033,334.518589,329.523925,319.001194,274.976091,120.217257,63.914228,97.766275,149.581424,157.364856,111.593698,14.767393,-3.281853,35.257807,110.613692,119.508383,166.012455,186.320935,61.326907,-151.13881,-193.27278,-190.675312,-190.343219,-150.081493,-104.794444,-114.166948,-189.946312,-332.093961,-379.998604,-383.014322,-345.027887,-307.773484,-261.80059,-264.038371,-228.035721,-171.0782,-169.719804,-145.890932,-118.567652,-81.30749,-70.151951,-67.093344,-65.474852,-14.170867,34.697947,35.9204,-29.564814,-84.378427,-127.82114,-87.167989,49.618723,63.332447,18.05517,-52.842167,-68.17488,-87.002091,-90.429162,-70.660393,-33.180025,64.417635,52.121489,6.310514,-74.751694,-93.33645,-83.955561,-63.464783,-23.515967,9.349929,34.612614,114.386125,165.713632,268.907571,276.336794,141.414853,60.335922,-17.727809,-60.529524,-84.31674,-118.367742,-124.089935,-128.15599,-122.902696,-41.914866,14.216887,-50.594592,-259.846992,-305.353674,-218.859934,-142.527203,-56.508277,-39.019451,16.746749,44.309014,24.601617,-33.074445,-62.922158,-141.465976,-177.342518,-204.617243,-174.136527,-142.112732,-73.992247,-65.076519,-125.031385,-146.350116,-59.089937,19.54369:-113.407937,-190.614013,-222.42895,-182.94696,-107.116523,33.672544,31.992664,-84.640483,-143.975919,-131.29933,-90.835637,-92.439561,-129.774705,-136.223996,-120.508624,-125.240563,-213.864855,-304.906996,-284.536103,-151.810945,-95.290508,-39.386524,-39.917224,-103.762646,-173.044808,-172.839279,-114.58029,-93.732203,-75.293018,-56.018391,-23.104599,-20.208925,-21.677987,-48.062941,-54.876055,-15.630375,6.273073,50.659679,82.652198,70.558364,-39.798948,-74.852613,-77.699136,-68.304985,-53.418011,-52.523116,-114.258845,-173.531513,-227.404069,-156.372273,-122.24426,-102.739917,-74.225261,74.093748,134.344669,141.138476,50.867052,7.441342,52.020105,122.840158,186.578612,149.20515,47.241602,33.794258,25.463242,5.138764,44.166194,145.345369,169.834327,231.877728,264.869031,262.639737,137.195577,55.170799,-26.659847,-19.132568,13.534223,6.560633,-63.076331,-100.895659,-151.031535,-157.985488,-140.23163,-89.971559,-65.552261,-8.393317,13.291729,-9.756433,-124.815393,-181.39363,-165.872518,-107.16727,-46.614797,-44.236465,-56.455968,-106.344039,-252.758007,-237.421606,-182.139917,-136.587135,-149.334499,-180.752119,-200.928348,-237.264662,-254.511315,-281.144683,-294.559166,-231.196892,-41.738848,1.782691,-49.006739,-70.742945,-41.110539,-47.787117,-40.060407,50.145917,93.697946,144.548908,153.800327,127.991631,29.324602,-29.543808,-53.183264,0.055113,155.074574,198.909262,163.480532,118.103161,73.078674,99.451734,110.513981,76.925061,56.178947,62.408476,66.258942,89.238846,147.536926,146.022893,60.458767,20.374006,39.478565,88.87273,179.955362,199.851795,202.196276,144.361867,110.577793,94.910545,104.545201,100.822656,85.819909,112.55098,128.696385,85.192589,36.443227,40.730214,-56.167442,-155.829317,-255.811807,-217.981262,-140.807762,-236.139924,-296.554037,-317.495077,-267.726498,-104.427717,-50.693618,-70.143965,-104.599695,-83.011218,1.482483,50.183963,132.854446,136.950843,53.607765,20.096408,59.676076,108.863621,118.047869,178.46859,219.592251,243.454642,214.676566,105.819176,14.910886,16.812511,144.494538,236.240588,304.874395,252.575013,96.658608,46.053865,38.481741,138.891844,194.673147,258.186808,283.444264,360.097941,396.4308,364.182511,222.565285,205.928063,279.672294,293.841731,260.371539,256.679152,270.191946,261.804229,196.614485,172.655208,224.761438,348.453802,376.975747,375.981087,337.661301,235.521473,213.493967,211.71972,173.144389,138.70999,92.366152,113.08592,209.94466,218.003272,80.411011,16.31275,61.704334,90.745584,67.60633,46.424059,23.77886,-14.269686,67.990485,111.189805,92.402012,39.954761,-7.384156,22.404988,64.30716,43.002075,-40.103901,-87.039526,-69.260373,46.994704,118.191861,177.199592,142.191636,14.402617,-114.516642,-157.161935,-125.245777,-65.661048,44.834928,66.40791,-19.307643,-110.426731,-253.73402,-299.257784,-295.173507,-221.400164,-162.485745,-48.1682,-10.863864,-3.628673,-72.644892,-97.066037,-43.786058,6.022244,82.286346,123.996447,163.902942,139.662428,85.638437,88.462772,103.788129,118.294464,134.987463,221.313243,234.347309,182.201357,228.352511,278.808391,306.502158,263.98908,145.652088,110.521925,52.488584,15.793105,-12.582972,29.172055,59.816406,116.858877,146.476716,257.287276,305.209649,259.421018,178.733343,166.726266,90.264677,23.42803,-19.710268,26.091587,77.954825,40.12248,-37.643474,-9.460969,43.588638,178.913352,214.382309,157.750392,99.293535,2.692565,-73.612783,-107.737779,-139.786851,-110.134105,-17.416087,3.22283,3.289687,-3.082848,-45.199353,-98.51054,-108.833473,-131.785641,-141.108515,-143.266521,-179.853969,-296.783076,-273.666723,-227.668934,-175.994408,-165.556761,-70.191919,2.341873,-7.408869,-97.00161,-206.637985,-148.44776,-122.479719,-100.252266,-79.229038,-51.754262,-75.908032,-176.996223,-302.060019,-342.766363,-278.421979,-191.588922,-59.16809,-42.820562,-62.311691,-57.876674,-10.478455,13.213809,13.218318,24.236616,39.015669,44.78789,17.413099,-81.906143,-184.826969,-209.876038,-150.122688,-78.255306,30.707147,47.965209,17.224862,-23.242776,-131.467466,-238.403967,-269.850126,-317.109902,-331.251996,-238.582459,-141.065342,-1.257185,2.229928,-24.607155,-107.968456,-166.398537,-241.047972,-209.970283,-85.672096,-68.316124,-143.998861,-142.198776,-79.745369,43.649736,59.30922,-36.798287,-107.858085,-154.793116,-135.342877,-141.207184,-142.487056,-121.999158,-48.844764,-7.670058,51.039966,65.712877:backward
202.334522,241.712073,214.801346,133.261986,95.564117,79.889931,94.100156,63.883921,-3.276076,-20.414261,-86.459615,-160.805376,-275.808283,-269.705218,-226.797505,-216.007442,-147.633111,-96.143693,-116.629567,-173.856323,-161.906456,-28.740738,46.201554,156.10683,264.968853,292.772643,261.165696,227.056095,175.368929,163.772799,119.845195,77.890608,1.251411,-54.883278,-99.744795,-254.888354,-334.499511,-335.298994,-259.269592,-140.546871,-176.361247,-228.184154,-281.668625,-259.086489,-148.348247,-83.649746,42.051498,106.325655,161.528739,45.211572,-12.440394,-12.379714,25.724212,131.105562,183.182017,178.41167,-34.627018,-130.051896,-136.96218,-112.697826,-136.186109,-142.345254,-46.934601,54.002616,227.272016,157.527411,46.659919,-175.178832,-230.404985,-180.651484,-111.679826,-29.668116,-76.631339,-113.104392,-123.874794,-106.629738,-64.334845,-29.847907,28.334273,34.596017,50.964733,100.916174,119.772441,74.703695,28.19668,39.127175,97.578559,140.018622,-13.360447,-98.404971,-166.606563,-180.430695,-253.388183,-294.495858,-311.942746,-265.565214,-125.223887,-95.648329,-88.501179,-32.907714,-26.098782,-32.173154,-8.443717,65.657976,116.248546,120.412401,74.681054,17.998297,-146.430266,-204.097601,-174.466255,-103.520248,46.54202,86.724691,47.268122,-106.446091,-169.740201,-165.048436,-125.092707,-79.9751,-27.277348,1.616063,-22.520495,-71.696998,-124.319008,-83.876967,59.228502,92.329292,43.537064,-54.865471,-82.319195,-106.057993,-108.483437,-55.040198,-16.160107,-6.410079,-79.123064,-104.669212,-75.06344,-45.771483,-40.525434,-48.045175,-31.267493,-8.263596,8.30092,-93.889365,-152.176684,-183.246276,-151.087169,-11.633858,77.826002,212.220547,209.673634,169.057142,108.778648,95.952286,18.670913,-39.371497,-117.54361,-139.977434,-195.288545,-251.649374,-254.049058,-214.880818,-185.452164,-89.605353,-37.190545,22.946764,28.888008,16.971171,-0.045281,-2.397974,-8.360747,-12.902863,-44.069743,-48.75564,-3.713961,-5.875495,-24.555466,-73.725414,-110.225286,-142.028844,-122.288779,-53.965526,19.110778,37.40465,32.899293,26.455055,-18.509679,-66.726298,-152.338129,-154.891709,-117.929545,-181.247467,-226.69522,-240.797751,-223.03474,-189.816376,-186.23252,-196.45778,-171.465528,-162.293905,-218.692799,-283.05999,-400.735489,-408.272394,-303.358399,-231.184011,-162.851953,-187.588809,-178.96568,-132.908644,-136.833973,-150.772191,-123.845579,-21.200199,40.721015,38.967127,25.17456,16.298858,-22.454569,-23.98041,36.731581,83.333048,152.470433,108.223737,71.485102,-3.016906,-51.206652,-99.331422,-80.023204,13.373981,64.325063,45.009943,-23.571739,-40.916513,-8.992883,18.376365,36.479779,42.925227,79.938188,11.012593,-78.702331,-188.417505,-157.629089,-21.969061,-4.429365,-92.201137,-116.8345,-71.659765,84.168346,128.308087,32.183796,-58.737169,-157.323323,-151.033122,-110.644051,-60.398291,-26.877916,-64.252883,-154.626983,-246.048726,-174.251525,50.810707,101.151215,44.28299,-105.717472,-146.212479,-128.680552,-90.661344,-55.03751,-85.085329,-151.549976,-140.389613,-120.005513,-79.719031,-77.298245,-96.040952,-93.628849,-59.490321,-78.242045,-122.009361,-166.772125,-145.86396,-114.580683,-114.989141,-75.327328,-24.002122,76.030276,110.400935,116.361964,96.370496,74.941757,64.465719,66.769603,77.177158,109.854258,112.363032,86.672934,63.681424,36.00384,67.210457,214.774659,269.85466,215.40359,51.7555,21.905116,67.424817,90.714088,99.732125,80.255874,21.839738,12.089721,17.86539,22.917715,19.149208,18.975719,50.007427,170.869929,222.180865,270.444218,252.568958,216.254145,125.284744,99.606241,142.778797,196.14724,288.059491,365.096248,376.733108,307.768732,271.523997,232.443192,201.061018,139.079102,147.617659,244.402286,262.281017,189.05007,-34.232866,-96.756187,20.910359,163.30793,362.838282,343.862942,309.472587,280.124718,267.886748,203.451604,181.460607,217.299632,257.53795,294.285818,209.223332,157.621891,148.195658,188.280051,246.03605,228.128214,159.167806,170.28767,206.494461,280.547926,272.9575,147.34901,85.556966,56.721405,75.396628,132.412052,181.45666,187.215181,121.502349,72.457728,69.776973,115.527449,227.376733,347.291697,365.863996,248.919466,148.323916,40.934934,97.16383,340.598242,419.347881,381.050363,240.308513,209.790575,268.53387,323.380909,397.625664,392.183638,302.731175,234.671081,216.832054,151.275742,106.207253,84.298122,126.705047,220.013739,232.854922:151.177133,215.698994,226.40704,228.392154,215.915318,161.929899,137.152631,149.734886,192.554207,172.817117,23.228418,-88.571424,-275.560354,-295.94894,-197.856108,-139.790382,-100.284407,-101.711822,-95.906978,-89.688035,-75.991283,48.424824,146.576947,295.798268,324.948391,302.750412,246.174581,235.071053,192.704119,128.501349,-24.790698,-52.392774,-34.444479,-147.570803,-257.201402,-446.546795,-480.205637,-373.773811,-279.744216,-156.885927,-130.437713,-154.57058,-217.593134,-203.133429,-74.125599,-2.056999,92.503422,108.830351,73.307271,-7.137446,-40.461943,-80.526036,-78.912817,4.51774,88.176773,242.368411,163.464216,58.683746,-54.072256,-53.372141,-49.338786,-54.582393,-4.245764,68.201197,206.781748,168.229668,110.973412,-0.28331,-53.873134,-91.331976,-57.781945,41.656218,44.105084,3.149827,-75.633772,-96.653086,-82.197629,-31.598578,92.076013,124.563194,146.908704,91.510286,15.942725,-66.068201,-10.991577,153.711456,185.943996,145.028938,52.215691,17.55421,-18.529161,-48.416004,-150.350818,-184.430731,-163.60644,-128.265222,-55.287823,8.398438,28.633744,35.226376,29.19995,70.401106,124.420985,172.803299,84.87621,38.26952,-7.999643,-28.904502,-101.201716,-135.726729,-124.840342,-62.447521,95.393045,148.386803,120.667136,-6.388822,-56.681834,-26.413385,23.728824,87.367935,128.205753,143.260609,65.495388,-32.726733,-156.023747,-125.449966,-34.124719,-28.943187,-54.781339,-99.371751,-117.205198,-159.837442,-167.832923,-105.916649,-75.400931,-5.488348,128.256565,137.335402,-9.757883,-91.909181,-109.116541,-42.399468,88.513152,92.677255,-6.829679,-103.601439,-121.321419,-146.079337,-163.867748,-119.614809,-22.097013,254.238855,358.275416,289.379672,81.18627,14.45058,-26.926741,-16.734748,-14.403115,-53.468623,-186.729498,-254.467567,-231.426663,-163.479635,-142.540192,-90.49875,-56.22829,42.25696,134.184768,128.951191,43.638718,7.690107,-16.503175,-12.825167,-17.504466,-33.787675,-41.604896,10.619729,11.308444,-115.818197,-188.744372,-192.275058,-139.696813,-36.386442,8.906461,4.197372,-29.593459,-59.645596,-115.164403,-106.536136,-57.601485,-46.241734,-78.16811,-195.211821,-241.681239,-272.606067,-266.505554,-215.83631,-192.262544,-189.777252,-209.776374,-212.196061,-209.566441,-224.037266,-289.396354,-313.729338,-276.165443,-220.666675,-148.563506,-157.70975,-155.139192,-154.606171,-175.140522,-189.723919,-148.460241,33.506394,145.048879,117.439609,4.958457,-34.405422,4.115892,85.064541,205.341295,206.106835,141.820085,88.10931,79.22884,20.113753,-27.621581,-11.772257,64.249241,170.38203,91.446841,34.983658,-9.50265,-7.649766,7.029522,31.097969,131.831296,170.960297,163.312913,89.471076,27.266412,-107.617434,-122.556095,11.165266,89.573382,99.758076,86.383866,137.596589,226.769056,190.926829,22.741724,-26.171698,-56.715859,-78.752345,-99.599182,-39.109868,-5.090833,-43.41692,-113.358594,-182.779078,-146.12588,-16.844309,23.304331,-4.775413,-104.979364,-160.094542,-197.387372,-149.981954,-26.39952,-24.493979,-120.148621,-135.465704,-102.840983,-95.04449,-117.721845,-79.991526,-33.493542,10.231235,-6.022833,-36.049671,-112.364951,-142.659111,-173.09327,-156.972186,-46.597212,23.01974,113.079267,144.000843,150.151926,121.268217,96.570982,79.89747,96.443448,186.069522,218.64223,177.838382,59.69921,1.78361,-31.945446,21.073321,156.496538,185.812929,172.166232,55.899378,-35.390759,-157.302076,-143.278955,8.598977,75.386924,75.867709,12.167942,7.668393,30.414406,26.592815,0.969128,31.076216,206.50975,288.069253,322.574101,262.696353,227.319946,171.650266,163.479954,199.127699,239.957157,345.626048,403.748764,374.335719,249.459757,197.937966,149.85659,152.876463,180.947153,189.375992,172.585088,80.545856,-4.060828,-167.857479,-175.615344,22.22585,159.334275,299.461658,267.251797,214.136657,83.392364,50.779151,87.211897,125.091511,197.304658,235.428749,285.848779,245.011659,199.995826,117.177073,95.950782,104.526765,127.198572,177.206189,203.03015,202.156113,157.535296,115.412466,70.603677,96.413135,190.704931,221.314075,199.991319,124.901828,102.187346,42.399491,24.495454,115.301761,185.492606,257.693942,267.328202,248.328305,140.690444,62.19554,-16.026049,41.619259,247.930885,301.683031,279.224909,254.950602,244.218263,177.334703,178.543409,328.351185,404.24884,413.182686,331.736599,290.606968,196.795651,155.206103,151.591397,186.203975,227.687206,221.113695:91.301167,209.619952,214.115206,79.909174,25.841963,107.949046,183.063972,229.311767,148.74614,82.168802,-84.085745,-178.402363,-285.912085,-259.930979,-129.32058,-85.964503,-67.064029,-25.225124,17.451,97.477322,138.897933,256.507296,331.389802,452.934014,450.236655,410.933954,304.79442,254.394875,169.565805,128.759175,64.389735,48.405413,0.733784,-133.112863,-228.51535,-416.680427,-458.147054,-385.897919,-310.037973,-155.834926,-6.124198,41.116978,-10.033796,-81.053601,-127.130717,-77.620421,43.169009,72.385415,69.039721,-4.437088,-59.300523,-153.548757,-153.026663,-4.670845,113.954016,250.965273,102.359946,18.280211,1.834102,-0.169388,-84.314616,-107.394409,-29.819652,43.722736,150.459904,137.129623,87.918715,-62.92213,-126.394535,-131.051328,-73.100685,79.647785,119.36331,70.214412,-21.118595,-31.719483,-32.064791,-9.612611,122.868739,185.045585,149.54703,10.162365,-21.295786,-38.61736,-48.055317,-32.768814,-0.456066,52.297143,45.344178,38.915481,-21.557308,-78.231822,-113.398304,-80.445367,-30.919626,-36.00633,-67.37996,-97.260871,-99.712761,-88.954503,-80.364228,-4.933861,67.654356,157.56646,56.670974,0.86731,8.846528,29.45287,-25.392705,-65.132652,-7.35619,82.354696,207.514823,158.847768,95.328372,-20.0091,-42.091262,-12.032631,28.371579,137.075266,178.405072,151.050617,21.501593,-61.248321,-167.765208,-172.939194,-138.479092,-98.447171,0.984245,-35.397883,-105.964865,-197.244257,-157.179025,4.747964,38.306537,20.002102,38.133214,54.51631,27.773611,-13.133808,-37.60614,5.923068,75.405716,47.483943,-77.9067,-175.394428,-191.168737,-158.973611,-140.776397,-80.551741,-4.543429,195.52941,262.072904,222.867451,77.477205,-10.094733,-93.160381,-46.406711,59.091725,41.738988,-53.573048,-51.571606,-18.074401,28.227938,33.972855,68.692443,101.775587,136.556788,77.920071,32.254338,-28.11736,-28.162706,1.53718,6.764088,0.153661,21.668308,112.627615,97.648045,42.05738,-55.825004,-69.475496,-17.563487,36.563991,151.395039,161.844442,129.692745,80.146342,55.019936,-2.278698,6.641941,91.242097,101.729688,-11.87466,-158.36275,-184.689928,-175.801587,-164.51118,-130.999724,-112.842019,-74.801747,-82.715825,-126.555714,-226.523529,-245.950252,-220.109703,-205.181915,-197.94321,-182.727782,-114.84701,-90.209425,-112.097136,-149.595588,-142.863396,-109.927832,-83.848661,42.971707,121.577568,93.272139,-1.54441,-27.401369,18.782758,77.580991,158.081915,163.626432,119.586363,14.558596,-42.488852,-105.965129,-94.330107,-8.44075,32.874351,79.95154,90.443038,79.545748,10.958647,-19.522232,25.961266,90.072138,207.458171,244.923616,214.102468,-18.532143,-141.106429,-194.840561,-113.141312,93.254292,129.77783,66.800845,57.716062,103.639394,142.210598,76.199635,-91.172114,-96.980183,-5.827378,14.154791,-3.242733,42.679624,71.38482,-6.639479,-100.486427,-222.066881,-207.469108,-82.800049,-18.577286,-22.351176,-34.800078,-43.80015,-66.730485,-65.7564,-42.280502,-27.843957,-10.719272,-42.670909,-67.933306,-103.705745,-100.228273,-15.262171,44.909573,90.034829,21.239135,-16.960715,-75.077042,-111.796818,-175.522952,-165.165905,-46.994671,21.045151,69.203335,71.639029,95.630041,108.257015,96.594782,108.879854,133.508349,218.269666,263.951812,220.585843,31.13072,-53.466738,-78.505088,-28.422,58.04266,72.390514,79.21539,30.620092,-21.151544,-110.857094,-97.055975,40.546421,94.260565,92.778082,40.712164,29.288393,16.845304,5.66333,45.674515,100.330617,200.978964,241.882486,310.468043,327.279442,289.608164,144.464197,112.451352,198.829816,250.745619,278.916191,253.056755,234.767974,199.235285,176.771315,165.639563,197.678106,257.915966,245.723024,163.222666,73.699274,6.012206,-129.53137,-121.562379,36.59769,107.950613,148.636149,125.547959,126.741795,132.46183,116.155916,95.666523,131.981707,287.077927,334.146804,270.658002,148.845555,99.742619,47.376632,63.439624,135.692942,163.342816,188.484035,151.072507,107.063382,31.506623,17.185239,39.526831,77.095975,140.816004,140.399621,135.906557,160.135003,135.517137,12.758557,-19.971032,57.217376,135.400705,269.355409,295.299583,251.018704,88.78467,12.992283,-5.737466,53.560177,206.520693,264.671727,274.70489,188.953861,160.714705,150.22297,166.34866,246.011806,280.591562,284.045755,282.88015,288.29659,232.294024,175.917322,129.923997,155.375406,206.871048,216.738677:211.233253,288.731519,244.818682,71.621131,27.688747,83.796707,104.048206,26.173038,-66.760975,-93.117008,-112.478479,-131.951464,-216.186191,-232.895101,-173.717732,-135.552503,-98.848132,-88.645507,-70.018134,-3.809466,40.108155,157.227349,213.085157,292.917884,354.813753,366.14548,344.480082,319.979976,256.445342,229.059339,198.837289,198.522239,201.941063,78.422685,-33.635102,-207.42573,-232.308453,-184.305377,-149.156044,-87.539458,-50.148844,-76.243639,-198.182574,-246.992851,-208.8533,-121.399439,71.939331,122.950887,86.546358,-25.477856,-60.152777,-80.261357,-70.93778,15.550104,80.367906,130.428625,0.46434,-61.624533,-56.386089,-32.358007,-49.519993,-73.565058,-42.213867,27.849473,159.820481,120.923453,51.133312,-68.19911,-83.696631,-31.808371,-4.03011,14.374263,80.354217,115.504642,126.407117,117.746395,123.092207,149.686842,223.770039,249.597054,251.068408,171.247028,135.64659,133.445746,134.239653,113.453525,133.209197,217.785178,149.405317,63.183133,-58.425363,-79.893749,-91.245732,-97.456897,-124.640825,-122.02867,-46.491635,22.695728,32.374305,21.722556,9.577337,8.099748,33.944673,87.72507,25.565962,-11.478043,-13.123094,-2.795488,0.964141,-1.389794,13.738147,56.232061,188.227815,207.110082,143.719622,-34.690639,-70.085072,32.722147,93.064584,75.38026,2.734995,2.366862,-10.611152,-69.23477,-170.865397,-153.022788,-50.321854,-8.019189,11.321502,-81.074102,-136.102725,-167.144441,-121.471953,23.090813,51.735494,-1.24186,-21.656555,-2.37273,8.029455,-10.537923,-22.731664,0.79316,63.761725,69.300623,-41.891937,-224.193828,-275.387455,-272.343417,-226.888707,-58.614857,43.55702,197.035381,222.976894,197.921423,129.248382,74.544697,-79.33551,-121.367945,-97.000884,-85.33071,-118.203556,-150.473526,-143.118432,-122.534278,-136.70944,-136.498478,-81.222759,58.3259,64.009728,27.904665,-27.591703,-42.202508,-13.958762,40.763836,125.544513,127.227629,88.459863,53.492478,57.517269,70.28209,56.62411,31.487175,41.928471,88.124064,98.163747,101.170029,99.158185,73.546999,25.569817,34.291618,65.80864,51.787301,-35.95858,-105.06684,-109.640318,-113.525731,-120.349806,-86.041794,-66.29591,-101.708871,-123.338262,-104.595834,-68.702756,-68.831675,-125.502588,-164.758213,-189.543883,-166.236695,-84.008266,-36.396896,-62.172274,-182.736981,-200.056785,-63.384665,26.704213,104.999092,46.162217,3.832198,-34.359608,-45.119466,-67.647525,-52.755735,20.745858,49.01996,50.346055,-7.968738,-41.961389,-132.115003,-187.194678,-216.970706,-176.461224,-76.595834,-48.885583,-74.200746,-142.436229,-140.617775,-44.866996,5.530525,36.542525,43.699985,55.309917,-72.116941,-155.339841,-195.042644,-156.953475,-57.234704,-17.345154,49.563843,115.162349,123.54776,79.161981,34.752131,-60.236141,-84.156575,-53.82684,-8.003576,67.803277,67.491048,39.479732,-81.984013,-134.492852,-118.315014,-70.691867,20.20506,48.892616,32.890041,-29.639215,-56.879847,-42.215011,-6.888443,2.040275,-37.679707,-80.978278,-54.288776,-61.183428,-116.333448,-137.073191,-108.504438,-78.669601,-59.597103,-76.210861,-98.909682,-157.254909,-175.670285,-163.537567,-127.407854,-35.345443,2.972909,51.659825,60.649252,66.226803,89.717506,93.032904,83.635565,83.606673,140.389788,215.441112,191.327692,32.888603,-42.53736,-70.821617,-24.278279,92.305291,131.810943,148.520818,103.755409,79.718626,14.900845,-13.114867,19.86554,60.091278,92.309846,77.968938,67.430431,27.299179,-0.994003,6.930843,60.371798,195.905486,252.64423,316.191515,273.896111,226.312799,123.019581,94.985438,160.5677,216.103209,234.370787,238.81471,263.314376,241.575498,193.370853,130.112424,121.739054,115.016816,124.438394,171.370024,145.280743,57.951025,-191.712959,-237.908882,-49.485194,90.77459,248.117268,280.601631,269.224719,179.325937,125.080077,99.510145,141.132395,265.572871,303.780365,270.544743,164.997794,136.376292,149.922473,175.303056,183.527548,145.692674,70.606162,84.248792,108.33694,125.2323,102.913352,44.161128,37.947104,76.726122,90.853945,35.712285,-26.118111,-3.223663,53.309558,49.581089,51.541218,70.186592,110.206612,154.093628,159.187952,84.209304,0.124357,-120.904022,-80.616341,102.770916,148.207725,127.894426,141.600889,180.959701,224.284877,217.659919,228.786321,252.106708,280.941903,232.784818,173.908574,50.996639,8.619801,-33.827105,-11.690008,114.669465,170.195543:187.226664,172.868737,117.435331,-14.138913,-37.846813,18.259866,54.201217,89.025913,10.597993,-81.783356,-228.209408,-251.983642,-241.159594,-208.954344,-116.66868,-80.546808,-68.395459,-84.285523,-64.944077,4.438971,49.172494,184.9713,255.132344,349.709832,399.747773,399.478096,318.877005,255.525373,182.72765,192.209231,234.241578,241.642974,224.041139,89.470462,-18.124241,-185.614891,-227.163147,-263.256668,-254.108879,-145.109667,-40.45192,-47.737372,-141.042974,-184.014783,-183.508268,-128.447451,38.012092,101.791311,76.428907,-66.840264,-99.886676,-90.481641,-62.311593,42.070838,95.070529,153.014195,100.304124,44.316884,-67.65268,-123.689371,-185.104793,-160.618628,-2.259116,96.831757,193.129167,109.13284,26.356567,-119.735412,-119.982635,47.43862,139.828378,209.118756,164.27795,127.50201,74.371974,53.194138,54.069491,109.333409,273.476721,323.346156,256.364885,57.888831,0.616436,-4.819607,12.122538,38.847291,68.011432,187.875824,205.190099,140.370953,-21.47587,-66.66229,-40.74732,-12.219555,-23.899006,-19.071084,86.661591,138.625071,105.175975,-8.348429,-39.889231,-13.4356,34.336603,151.150037,149.524801,100.477249,15.701051,-21.136479,-58.970852,-27.008975,106.140662,171.404772,242.000619,188.348434,120.236829,-5.953524,-14.249733,64.841478,107.653786,175.897904,180.81924,134.770162,-22.10693,-98.134526,-170.804711,-164.59594,-100.58865,-42.833599,96.124279,94.774496,11.68812,-149.167157,-141.517707,25.584871,108.635672,185.226953,135.063862,88.329597,20.833632,-10.892692,-54.151016,-40.474337,42.865144,73.645312,18.79164,-131.741076,-192.016613,-255.485715,-241.638079,-93.78165,7.87371,137.67179,131.097908,107.924363,28.529612,-30.61141,-92.14666,-59.552777,65.867806,89.289942,8.371056,-75.500581,-89.481326,-122.117308,-131.136769,-49.476738,26.757918,122.937373,34.625356,-44.147683,-105.396808,-73.415205,45.600342,97.729134,142.469552,155.219181,190.554465,178.448349,148.053181,71.303421,69.481261,171.704158,218.289949,252.728305,252.83503,235.245517,138.848863,70.083148,-14.277915,0.211391,123.180043,185.365873,156.41425,-9.64777,-50.83303,-48.486913,-37.846553,-6.562569,26.97003,76.852197,7.436034,-33.516632,-69.561977,-81.788878,-74.344911,-44.698441,33.895668,61.202984,24.627063,-63.261092,-82.816616,-73.153388,-51.420068,-17.112176,-4.861626,78.781601,128.933227,95.731001,-24.281386,-80.812951,-100.525154,-46.986813,91.607336,125.528157,96.185728,21.105928,-18.680703,-128.020996,-160.215114,-75.479452,-1.180209,76.973235,53.441395,17.491066,-53.482855,-74.79731,-54.942296,-5.456425,101.09071,126.699054,111.143884,29.704658,-18.573414,-89.845337,-88.886006,-3.705733,52.058981,143.967338,153.935243,114.958226,27.939533,-3.261106,-39.933866,-36.563875,47.592904,122.867945,195.284374,120.074615,87.511777,-10.267821,-84.871987,-127.407228,-68.190275,78.322352,66.53532,7.460576,-114.210843,-158.175797,-119.786696,-30.529694,97.172479,83.276428,-1.647186,-67.163879,-101.978261,-130.636704,-119.530178,-77.979587,-32.483024,87.952673,53.789813,-22.542974,-143.160595,-170.577416,-176.345029,-141.370984,3.259042,80.840893,156.111068,110.259653,83.732768,79.891336,91.608755,97.10581,95.248827,139.293025,176.872934,136.065075,-51.293283,-141.851127,-129.523566,-24.894096,153.061294,166.202724,97.36436,33.051911,-1.922686,-124.390908,-163.870239,-81.671151,-6.636778,74.768327,76.890591,60.699311,6.214536,-26.019229,-28.539489,39.994193,251.601512,333.754287,378.643284,292.647097,223.427295,74.059723,32.68529,108.530993,184.768718,262.681397,237.074034,206.349087,151.556146,133.928446,147.55298,184.272314,269.90426,300.256112,279.352579,96.895173,-28.86124,-205.982149,-193.679642,5.195221,122.070569,294.820758,298.186555,231.199188,84.563925,47.2645,105.576026,188.114965,314.66189,322.483147,252.712775,148.713848,105.630293,60.694074,65.960162,129.505152,163.191024,177.541178,143.475495,141.315229,170.555688,139.837027,-42.543475,-104.933737,-65.586766,-18.152459,19.477715,32.189787,34.190392,-41.569695,-78.909011,-18.413317,56.688313,154.646974,131.051622,118.277297,112.471955,68.045911,-62.625182,-53.884049,107.081968,166.962122,172.188479,169.218548,182.196992,179.249308,167.375342,155.292979,146.704534,140.00286,183.170865,176.39888,31.629727,-59.631076,-110.283858,-64.813142,40.033862,68.719524:384.334093,303.693172,216.172174,59.457134,20.858523,23.887918,22.763542,-58.555007,-175.791954,-208.958135,-208.488413,-211.978243,-215.888031,-169.534639,-59.354775,-47.607101,-72.915966,-113.592375,-133.243172,-108.107109,-48.171062,123.433695,184.566236,223.862877,288.857892,338.181521,393.000549,369.948865,259.950341,244.101886,319.776172,347.703143,310.274901,192.43643,120.516465,-7.389463,-38.942039,20.961661,78.919563,121.602758,66.930041,-5.403731,-188.014047,-234.223641,-176.341915,-102.441998,41.465336,76.371805,14.131297,-74.77175,-57.525615,10.757915,19.865417,36.980233,52.224644,39.964246,-53.128441,-79.681734,-37.325752,-34.073776,-133.912347,-164.890673,-78.75789,15.781616,180.983063,141.145378,53.757657,-96.98732,-129.232102,-92.806588,-40.409708,57.449979,132.034472,147.456633,132.613244,114.271251,90.927741,105.563856,179.76433,215.909158,213.9592,123.806337,107.834253,142.15128,134.378219,80.514384,81.039909,92.178102,-21.740191,-85.458053,-105.264838,-103.138272,-164.248163,-172.256242,-79.023466,-16.615292,78.68072,117.771942,109.402124,43.280639,13.633362,36.146362,81.046537,155.17944,163.896611,156.249924,122.942543,87.635389,6.241275,-20.858018,-40.40072,-7.731301,150.054202,148.836013,33.098589,-231.911839,-284.588028,-167.344509,-68.739731,-1.684722,-24.461651,-23.120127,-87.258024,-151.666526,-194.518779,-144.487424,-25.90698,-15.843326,-69.879752,-132.068898,-166.559784,-221.421802,-204.413516,-64.500522,2.143745,46.049597,23.727518,-6.668896,-64.987368,-75.014169,-59.649635,-52.322894,-42.468222,-13.851284,15.730272,-88.080913,-121.254288,-129.015811,-135.2615,-78.698505,-5.088555,136.614832,241.364733,273.911458,218.753766,134.16421,-24.712682,-60.142571,-61.820635,-57.14813,-100.885007,-196.488706,-232.472377,-245.774984,-212.393845,-113.785901,-79.995598,10.321226,96.508994,52.363291,-89.42021,-75.789183,90.97811,140.585053,80.272486,36.858512,72.398165,158.79966,155.459709,39.655381,-22.758725,-23.987241,17.57557,85.63685,118.747087,118.409788,110.162759,126.983682,167.591317,144.526848,-2.104639,-66.281832,-87.649137,-95.744606,-94.850246,-54.936982,-47.455898,-46.797991,-36.718319,-10.492492,-16.984368,-30.743956,-20.846937,-20.085408,-109.487841,-153.998518,-138.680097,-107.769591,-51.661653,-3.158154,-5.839731,-75.852276,-101.369144,-62.658732,-18.425298,68.950199,91.51241,66.127702,-0.977055,-46.452154,-148.322558,-154.202632,-71.744638,-28.600786,15.879953,10.14679,-1.801484,-72.989755,-133.508244,-207.454295,-194.578062,-82.036503,16.048222,3.584639,-95.75647,-127.380934,-90.009477,-46.633691,-16.769196,-34.094041,-62.835116,-61.179461,-72.770434,-134.088423,-147.978844,-66.084163,-0.673172,92.774687,136.072827,146.017677,120.750671,73.057228,-35.130507,-60.667514,-72.38589,-75.608445,-41.829607,17.144759,25.656874,-17.633291,-67.576849,-118.740815,-69.943813,113.603106,164.498419,124.272463,39.222647,22.184777,38.356282,47.395945,3.60566,-23.773731,-7.046284,35.867071,52.158091,104.020282,119.789511,58.905423,-3.660863,-54.038412,17.438988,29.792731,-53.537169,-113.365274,-149.942534,-102.789582,57.500401,126.645587,169.408701,105.559166,92.749651,100.652009,76.156118,13.829111,13.249217,63.25525,103.243232,89.976626,25.377991,-0.850129,-6.63715,25.912235,165.388642,233.730589,215.499813,64.712826,52.953067,147.806175,160.892029,62.746177,13.162938,33.309101,127.013965,132.524075,28.161085,-47.015165,-83.303604,-14.551994,177.462688,234.804773,246.05219,194.42208,176.46531,156.787371,121.305138,70.336484,106.79278,236.151081,288.752729,258.17788,155.68374,133.387147,103.52469,56.385798,-24.099621,-0.676296,87.915984,2.844335,-87.101278,-216.247442,-222.506863,-97.79279,13.277873,218.61281,253.094615,219.274935,183.714361,184.778476,197.919346,218.716246,255.419393,257.299672,221.288445,144.099256,109.973142,62.364668,57.523773,101.474886,127.1273,108.97557,33.543192,34.312348,132.592811,151.058745,20.28374,-55.268533,-105.780537,-108.431633,-63.366806,61.697971,98.634555,3.78429,-92.297099,-159.334398,-115.389603,38.448965,216.697297,256.001709,151.49408,50.32046,-40.481793,21.814301,222.099321,256.457656,144.277764,45.113722,67.507243,168.252304,194.157553,169.92199,155.668575,164.593511,60.456554,-45.872623,-228.30572,-276.596926,-314.642882,-297.949155,-159.329385,-62.381112:257.419934,213.56618,172.762392,54.214397,17.41048,55.948909,74.410665,4.997995,-107.846576,-156.376589,-220.016527,-239.552682,-238.517468,-212.345379,-143.027065,-86.536526,28.009578,-31.500006,-81.526466,-52.930857,23.203536,207.10491,269.565832,326.157122,356.213194,348.066356,309.473134,293.511171,287.43321,306.571509,343.199602,359.8884,424.832783,352.370618,224.938591,-3.980431,-33.044463,10.635566,29.34943,61.961381,79.396193,32.956155,-145.398901,-227.527367,-283.10679,-232.945266,-23.152691,66.358279,63.771418,-75.979033,-107.227358,-104.490058,-90.042863,26.445898,114.699177,216.926029,99.444946,2.556075,-58.552983,-26.430558,-7.76179,-30.72891,10.092171,104.227348,270.558763,209.030003,122.986313,9.62537,26.801806,145.00342,178.234569,172.509822,207.763289,217.220666,155.968706,121.453353,155.233302,219.059161,306.281292,298.610206,250.093303,211.400951,177.072238,113.380922,107.76682,136.257478,166.388096,242.467371,233.678621,188.560956,68.568474,-0.068154,-75.248849,-38.109491,130.704738,205.650681,278.767233,242.777982,195.905582,111.066296,94.752,145.604593,201.033194,279.554513,240.20162,205.005407,142.934377,113.112505,122.786468,166.529253,253.672677,291.243885,343.910031,270.035921,173.004247,-46.593562,-101.297689,-48.081345,12.616001,93.445312,72.455725,36.086054,-32.315239,-78.848319,-179.551116,-175.215722,-16.6122,82.450657,136.609914,-53.364245,-154.532282,-197.378127,-140.559433,56.698767,152.287336,227.832249,148.862022,92.548983,9.301082,-20.421942,-47.484628,-35.43051,25.073058,57.572271,48.445628,-90.361939,-172.16489,-303.676169,-308.897645,-76.15206,102.331028,254.021956,102.711936,33.30508,9.175302,4.638914,-44.368044,-41.150578,37.221283,49.335898,-36.982477,-167.606229,-224.342532,-265.951316,-223.893237,-52.821028,22.001959,92.77103,72.826818,31.278159,-77.971553,-112.826348,-39.211998,51.881673,177.848278,204.898722,241.704279,201.69522,146.860425,20.414846,-8.266304,77.278367,157.676663,254.104926,222.210637,187.282558,122.86518,88.877228,52.574275,56.100978,69.7164,82.697035,102.249658,21.549126,-28.442813,-39.859178,-10.038122,43.217456,54.95266,76.369376,63.699266,33.162148,-27.02111,-50.994703,-88.939327,-81.186091,10.580691,75.167719,161.888209,120.451659,64.701473,-43.879553,-56.248945,26.896067,81.700114,142.478929,101.983336,60.422922,24.229945,9.34174,-61.069095,-78.536913,-55.318767,-29.864559,27.89303,-33.685467,-107.844962,-218.704137,-229.142547,-189.799259,-159.281366,-59.399246,16.385722,-16.981981,-183.601932,-236.448932,-165.580587,-73.147657,69.637677,95.103879,97.831662,59.238758,18.374437,-102.370838,-144.595939,-85.224502,6.130492,209.319099,300.392784,268.030396,128.828881,71.026261,23.536525,34.226188,72.483217,79.846938,74.24366,55.705799,46.502226,-2.595807,-52.394,-104.6035,-63.766302,123.942968,234.975091,196.26692,47.348831,7.525312,-9.050399,-15.32164,-15.453427,3.865186,56.194642,61.817203,40.996816,-9.500878,-14.47807,30.458928,64.594136,131.721045,132.732329,65.590465,-145.797855,-223.975959,-234.411539,-166.227127,27.402777,108.311238,217.250274,208.442361,156.737738,44.67711,2.548055,-17.676026,14.510422,126.17656,163.989228,132.574612,22.156867,-41.628469,-136.377301,-136.139034,-27.493444,48.753238,134.723498,106.238315,79.752504,4.632688,-31.505613,-3.984466,53.464371,127.948723,90.292176,53.724978,-14.6605,-42.88334,-28.480555,31.683573,185.37538,258.800074,389.706766,392.525594,325.905701,130.953413,63.40847,119.725929,219.762996,358.694871,269.701972,180.897783,72.409782,58.837176,68.696338,89.978641,129.59706,142.121949,162.731846,74.58904,-29.203741,-233.472859,-259.342401,-86.323544,68.842264,303.567559,255.604284,167.637812,58.816735,64.305236,181.546966,257.89981,335.625283,335.069085,268.800848,140.501265,77.977473,12.122896,27.680966,110.207838,145.866371,179.882677,139.718395,107.829676,51.254921,11.164098,-93.438432,-122.14675,-73.101308,-15.98311,58.022848,31.144002,-8.429338,-126.048724,-166.626063,-114.254934,-50.696133,34.427568,64.578622,62.813308,-7.273223,-80.323915,-194.572355,-177.240318,-19.730336,59.9671,110.563716,117.944593,139.44286,90.002744,29.020285,26.36645,92.655577,206.308912,158.606116,73.057109,-158.850706,-265.441396,-321.687169,-253.479,-58.911955,15.984902:353.321749,314.21134,274.479509,139.589685,60.258647,-11.045535,15.910539,80.588439,23.858775,-31.575604,-85.862037,-79.254775,-47.11221,-24.078184,13.515581,8.458719,-41.778198,-108.510174,-135.146154,-145.347456,-129.929496,-82.429264,-55.650844,14.556681,130.320624,176.66899,193.484089,189.157771,223.222427,262.474503,325.415158,343.01673,374.732584,297.580849,241.618582,207.908118,201.962755,217.412973,249.194851,278.880112,246.720769,208.053212,83.238168,3.061319,-104.879526,-73.31722,100.449803,152.91337,147.915661,130.369009,145.321293,188.66024,200.564349,240.953149,270.254083,257.435293,116.395013,55.730679,56.774427,75.416374,13.689298,-38.275518,-56.623112,-26.25801,55.18911,83.018409,67.067642,-7.308288,-79.540929,-184.280631,-155.939807,-27.250708,59.768965,92.534203,107.148582,70.584097,-12.523663,2.408928,125.659789,159.025306,88.61585,1.531088,8.530092,66.161027,90.03105,123.992238,113.631662,38.659511,38.386317,57.437034,15.326812,-43.762169,-120.575004,-106.240421,-42.19317,-14.879748,69.918053,91.073245,43.07156,-84.469058,-118.043152,-66.221245,-0.112251,112.27587,100.656086,61.966115,48.593022,66.686677,24.962818,-24.158459,-63.855864,-48.092269,-5.902431,-35.822711,-77.569305,-172.433055,-221.457601,-278.035271,-254.658162,-111.91369,-22.248668,-44.251923,-135.534746,-158.701499,-127.628041,-92.080659,-53.672866,-59.733966,-106.656488,-191.678423,-215.040846,-203.113414,-201.707281,-214.253564,-206.801831,-184.992972,-215.980944,-235.268473,-195.348586,-147.803878,-102.366764,-113.151818,-121.997212,-79.283869,53.220534,45.076629,-6.754304,-97.943079,-106.004215,-19.105672,50.52851,163.348464,197.51975,182.027089,111.714635,80.445149,88.506942,116.747742,119.305158,75.657671,-45.344289,-108.611601,-139.45726,-227.595127,-228.660071,-114.770197,-65.582375,-48.097536,-59.142861,-69.961787,-79.514311,-68.834322,-34.509642,-12.939814,13.978833,14.933997,55.835853,126.797679,153.565728,142.228346,87.556032,3.806029,9.49712,59.228099,104.316861,97.177678,60.089501,68.091713,65.580093,28.863813,-19.170397,-15.515837,-33.489765,-61.243347,-41.080217,-29.666288,-71.800554,-128.95506,-115.787988,-64.049411,7.098323,40.329271,70.486012,60.718594,-3.063897,-18.676299,38.156773,69.685731,55.826441,38.347588,57.02004,79.17197,62.252864,9.241766,-13.479546,-26.756827,65.851722,128.730783,159.851576,101.191952,-77.450408,-134.906866,-157.319456,-139.804258,-61.33112,53.788268,103.575246,88.15523,11.958678,-133.68838,-146.396942,-66.21551,27.077555,45.468323,35.221499,11.752569,-54.624198,-67.553209,-35.405232,-15.892063,-1.903939,-13.506078,-13.936271,3.806018,2.953016,-25.376848,-33.188728,16.881398,103.182262,103.35723,25.66662,-3.483913,-12.533893,-28.099913,-120.436698,-140.761723,-13.898398,155.373743,182.314223,140.468356,109.876023,86.921044,82.23473,64.73363,60.800778,50.916598,21.576884,22.26542,33.451637,37.741005,87.070743,121.088906,155.422279,199.772033,214.843914,202.858634,199.50589,230.092468,250.619418,258.168143,203.665129,184.138774,196.845744,184.305138,71.712615,23.373853,30.501781,64.293126,107.247918,84.114221,95.173046,151.298229,150.092756,125.279906,123.956021,121.411778,142.259737,158.275732,124.112082,61.865844,-61.55405,-66.18074,74.142245,171.154233,242.698084,116.249198,64.02914,51.594532,55.237295,57.871198,57.1332,49.523867,65.412661,67.26538,34.153517,20.9607,4.494517,-8.359658,-10.310866,9.83025,111.4029,229.719468,246.024287,190.959488,161.646103,219.709589,283.766242,352.851594,341.781455,298.636252,164.054044,100.080934,40.053328,66.686062,147.055672,160.302488,164.836558,107.720357,37.275978,-155.35887,-242.291667,-258.367803,-188.236004,-41.393041,17.454851,16.959882,38.173538,76.188442,84.671571,28.277956,-92.688629,-113.763646,-76.982795,-30.556215,-9.992412,-8.682483,-36.49374,-33.791104,-8.216371,-27.744475,-107.508241,-134.221342,-126.284474,-93.476422,-38.609927,-54.271294,-153.763705,-183.450836,-144.884866,-98.2365,-107.019663,-158.945908,-174.142815,-174.602391,-172.845194,-110.492754,29.411726,66.341916,32.023998,-2.9797,6.388966,61.218023,156.094749,148.04066,46.815884,-3.896307,12.466253,42.386953,38.525509,29.209357,11.778778,-119.479635,-315.276663,-387.643535,-462.385616,-476.921749,-467.282686,-452.773883,-440.950484,-408.359095:344.433787,340.126542,288.148752,123.915548,57.22652,35.222576,50.798544,-6.724688,-130.304119,-140.841355,-65.624738,-56.499641,-136.134566,-152.190472,-104.037705,-92.805653,-144.519234,-222.280654,-224.420548,-153.209113,-115.80397,-87.329717,-95.594362,-78.929435,70.681921,152.54932,229.413073,226.154132,167.566345,142.957063,162.546883,186.39821,170.094692,28.1322,-41.008135,-92.64799,-93.196598,-87.406349,-84.486307,-66.208527,-35.973426,-41.897439,-98.472311,-124.403535,-139.880751,-104.24658,39.686362,88.840444,106.473283,89.778867,98.612534,188.274437,226.933002,201.609773,163.138603,101.061755,8.382431,-32.658389,-61.23922,-113.242225,-291.504277,-311.44016,-154.547732,-40.738433,148.758752,138.643014,53.396827,-127.458908,-173.115395,-130.538296,-77.666984,-67.422116,-139.851533,-149.688804,-136.702913,-140.326612,-145.742257,-126.478671,-71.457921,-54.719168,-41.590312,-18.983391,3.381049,42.246704,50.568732,83.144228,102.714355,86.114498,-11.13014,-77.524763,-192.266789,-235.615749,-290.325839,-282.007688,-193.227284,-130.894178,-35.344649,-73.891438,-120.888911,-163.362079,-147.830882,-70.513084,-29.411351,52.599748,131.115846,130.97656,31.279319,-41.42699,-184.083643,-229.447026,-226.006934,-198.634649,-142.794077,-143.333751,-178.59341,-258.246898,-272.540308,-236.062622,-212.026732,-180.059344,-135.809416,-142.807088,-226.535013,-242.846608,-168.663569,-121.768605,-95.937093,-104.704054,-96.968522,-92.261203,-106.702298,-165.262112,-200.795957,-202.468614,-154.260497,-57.203734,-69.075891,-96.792894,-92.836521,-54.547169,-0.340964,-0.121982,27.559887,78.213913,183.562365,163.394417,122.009574,66.230965,53.470376,74.3783,130.256792,269.101939,268.932815,212.38022,115.98583,108.600091,151.79241,160.694416,87.171872,33.549204,-32.662714,-73.783827,-97.751289,-120.867649,-98.855601,-18.179058,-4.219612,-16.136429,14.514647,17.677452,-18.640381,-28.310179,-5.814104,-1.048392,-46.021805,-66.930986,-67.353392,-96.36964,-121.875047,-111.42322,-78.907541,-36.073329,-39.366159,-33.764989,42.327169,67.720915,91.81999,98.416767,50.241217,7.721818,-44.626509,-49.638754,-52.523408,-93.482375,-123.939463,-184.488204,-212.882179,-236.738399,-221.549848,-168.431685,-135.748151,-123.714062,-114.297677,-143.789906,-220.0685,-192.099257,-41.884948,-14.014073,-86.472995,-123.610569,-95.098271,-48.734339,-62.836536,-98.654311,-92.050833,-50.575563,-16.228542,1.803501,54.256443,62.863247,9.678338,-20.693214,-36.485523,-20.33517,32.329461,78.956157,117.511362,117.08496,43.882538,-65.094279,-40.255933,98.196701,143.132392,85.227844,-53.468338,-71.253504,-28.315443,-15.740369,-74.750661,-115.074053,-107.55837,-52.189189,-54.066209,-107.626487,-128.220432,-100.749205,-73.155053,-58.540366,-98.505193,-109.851746,-64.922626,-39.812646,-68.859637,-112.441974,-164.065481,-146.549814,-37.853561,97.968433,142.401739,101.43022,24.824213,-54.134461,-23.50285,56.579819,104.972024,125.246081,93.03818,36.67759,-62.180119,-65.099123,-10.089194,5.980362,33.72524,84.128702,94.685024,76.305348,71.913166,131.325264,162.184222,154.951387,144.404389,153.810323,140.450208,94.513789,-45.899598,-87.556605,-56.788711,-16.975737,63.258304,128.933126,135.016317,128.646204,144.504369,175.103126,157.125438,115.868474,183.011077,209.068569,130.629536,55.433699,20.607055,86.162845,220.662865,229.725959,167.398719,107.469496,93.687053,77.383238,74.449698,94.106163,100.912843,113.521404,115.163724,68.479919,-71.850319,-111.793685,-78.962957,-15.617025,95.579906,118.698356,169.625008,185.849531,144.483958,46.915166,31.607934,109.099696,186.325468,301.886387,275.163156,216.640437,123.845314,122.274313,138.366077,108.914705,0.3103,-2.452752,129.679373,141.949288,73.175584,-87.649932,-141.044619,-72.310991,44.692504,217.165178,194.938935,175.534143,176.326853,167.640549,130.115633,120.623136,86.609239,72.501025,139.566174,228.356898,219.706838,126.185653,84.702233,95.478464,143.664749,212.025192,153.095204,115.126513,117.988716,136.365237,96.266906,42.863502,-54.265224,-80.095512,-59.171716,-21.310483,-23.717411,-60.885486,-85.522374,-99.777778,-86.008174,-21.554538,69.643309,82.619833,30.688803,-12.562324,-67.767949,-33.754708,139.335741,195.952488,160.854506,112.217493,130.833397,184.198974,196.542633,216.929122,217.272546,145.003276,-39.223409,-145.590451,-210.574242,-162.147211,-102.422148,-115.271655,-118.809652,-90.000358:248.210822,313.243942,265.188084,38.594925,-71.725317,-106.795029,-33.259733,70.574561,-72.849824,-178.306634,-228.623683,-183.077921,-134.595256,-125.964612,-71.010288,-49.338381,-54.093813,-89.957448,-100.981724,-55.262821,6.646737,146.897349,186.580359,176.612191,156.432664,167.458028,217.996495,263.056511,397.615019,456.050099,468.583682,433.783127,401.816125,397.800118,371.868734,273.18566,209.399381,128.3256,134.917067,183.276722,173.262852,145.595018,57.213098,-20.434824,-171.710594,-167.069522,-11.895818,45.990479,18.966922,-9.468058,28.296939,105.641857,103.447891,87.238913,103.779612,123.912153,87.452451,64.647332,19.502514,-2.588783,-13.959388,1.149942,35.570144,67.612463,152.943736,130.717376,96.709379,4.940427,-52.492637,-76.546374,-29.197896,90.468173,174.982915,207.282862,259.88123,273.15039,270.531766,265.533644,228.166722,207.534265,231.871743,197.266428,133.887993,61.069657,69.233632,109.77255,133.215327,190.779332,182.579323,134.415348,22.230616,-12.178048,-8.023647,17.27599,40.520072,55.43995,157.16263,266.816476,263.438496,101.950854,24.942558,75.675383,156.096988,199.082917,144.984195,150.948936,195.024751,187.228018,105.859106,86.265425,133.894878,167.238154,187.295279,92.493758,10.64505,-142.34476,-192.349041,-177.843919,-123.832893,-85.329981,-155.52292,-168.894268,-141.848305,-136.551947,-155.036967,-167.917388,-160.879552,-112.022554,4.926332,-70.620703,-151.157627,-226.75392,-212.439429,-107.660801,-40.121211,38.351074,-7.584328,-53.826404,-135.0364,-175.149416,-210.303066,-174.691501,-73.435438,-48.69255,2.257608,6.394809,-75.786406,-281.649504,-294.471339,-120.931199,-26.374793,34.036205,-0.971849,-16.351379,-42.176104,-63.888267,-86.493963,-57.44096,-1.972323,-21.374621,-94.196362,-160.154982,-215.172467,-318.278473,-318.673056,-178.179658,-86.569924,-29.176467,-38.12811,-28.222674,-54.587796,-71.919141,-19.014193,38.014654,81.406885,58.603218,93.683687,249.367905,268.452226,99.247331,-9.015035,-43.318608,5.915728,60.270657,23.413381,4.874596,34.368695,53.3633,34.818292,17.456827,-17.041203,-27.242348,15.438586,57.127777,42.072265,-9.995423,-10.459683,63.311822,102.680811,122.892508,76.973443,40.659567,4.735753,4.903202,-10.056752,-3.498184,54.8511,71.687047,88.359766,110.583052,95.439132,45.06719,38.294021,42.196806,52.946363,122.10638,117.626858,61.169108,-8.402018,-16.889195,-118.466916,-186.408869,-204.999214,-155.468,-32.725824,-0.058425,-16.137828,-92.118533,-146.363467,-200.404293,-185.188126,-93.797333,-9.30547,-15.1615,-92.354508,-117.082709,-62.934379,3.195487,75.339314,57.188845,8.05744,16.450559,24.756007,5.735644,-15.47522,-0.928426,45.370795,143.982036,156.341475,118.445758,22.710421,0.633937,23.44474,42.649503,1.516747,-46.429201,-68.768943,-30.091544,-18.244393,22.876438,47.080402,79.817126,78.895353,39.930636,59.990091,94.371443,111.519896,95.540799,71.678269,67.719054,69.884366,67.911231,37.775144,-6.079442,1.885365,70.309579,91.703266,83.105367,74.752533,100.467123,110.929414,76.275612,18.477876,14.730992,-9.191308,-11.784069,71.098639,123.103791,151.652567,28.279228,-45.073353,-56.459669,-2.65192,102.362514,125.305913,103.708666,48.143397,34.743829,34.690762,26.896783,-5.735642,-5.449092,81.757543,153.932345,231.518157,141.261121,82.612232,41.743302,46.703882,60.550576,67.699408,110.41321,107.151616,46.772778,-88.031295,-115.256313,-103.822822,-73.5179,47.059591,126.120967,231.181603,186.954516,150.499285,130.391588,135.365072,162.780543,184.96837,224.777876,273.63781,271.862117,187.515672,141.159374,91.690503,91.475275,104.069088,98.005597,52.577993,-38.75227,-90.908379,-163.785777,-171.465789,-105.309093,-45.310864,49.212402,88.02319,84.001041,70.93666,86.915844,99.975308,68.054662,7.358136,13.295753,47.255469,-22.89803,-82.877805,-113.69737,-85.231591,-18.502183,17.038556,56.085391,-30.579079,-85.983166,-75.430208,-41.468866,-84.092071,-129.059796,-136.242794,-112.466916,-88.884455,-117.677397,-115.658363,-68.144426,-71.611841,-146.460197,-167.21743,-113.835328,4.610124,63.217874,89.60817,20.593431,-130.788774,-108.911221,66.004943,110.570443,69.481796,65.123696,80.164081,5.310153,-61.704362,-76.237951,-31.034271,4.990965,-107.144434,-206.371124,-393.025303,-443.877403,-403.810944,-313.062744,-124.990824,-64.089568:backward
33.30435,180.017328,196.493204,79.703734,-2.462257,-61.524843,-29.90954,35.087491,50.035125,75.512935,118.068507,87.189941,-49.330205,-91.713334,-44.265585,3.286045,52.697449,100.67488,132.405384,206.296689,228.413177,199.294333,173.276858,180.586772,271.794991,308.295145,266.00684,210.840462,115.815974,73.963464,14.061574,9.51617,97.109279,204.634357,165.276887,-61.182128,-153.000162,-180.320795,-133.977021,-0.9979,120.855686,147.428651,88.940092,16.05703,-159.145036,-230.097324,-284.620934,-274.29605,-197.706506,-75.225876,-31.695854,-21.378784,-69.337994,-251.913201,-306.789107,-202.654606,67.954446,178.797521,205.291412,149.184468,45.23832,17.772418,59.400316,121.66705,177.720438,109.753806,91.118865,145.481901,176.132214,139.175123,99.763398,73.964932,87.446937,99.806686,140.157232,158.112369,127.713671,69.505636,-23.558527,-16.269982,70.993635,198.830912,250.025439,241.848617,178.024559,26.026089,6.197858,142.516452,283.752965,284.332683,230.837581,228.691787,247.49405,221.84709,139.461823,130.128071,174.446793,212.079524,193.902113,131.804038,133.913297,178.486641,180.840155,152.260016,181.419425,204.002404,147.632282,82.252771,18.868747,29.506758,81.195671,125.51613,230.303848,222.925349,195.723288,192.891005,179.461466,34.132143,-43.497231,-45.232758,39.481001,51.028027,28.223938,23.773557,32.667425,32.673151,93.547257,156.421249,185.610253,65.994724,7.011762,-75.523614,-111.695512,-229.099497,-296.381659,-309.460745,-118.955163,-22.097236,20.570707,-12.090329,-71.982013,-86.309303,-33.550411,27.585508,129.484534,212.812385,242.788743,222.811878,187.983768,135.03588,130.631246,173.476315,229.180975,238.908223,172.225301,108.849522,28.575654,28.633802,93.282574,156.99134,312.292737,344.604679,303.698327,307.583096,363.564417,337.812499,245.138343,175.764816,300.499667,330.630028,265.038885,221.907876,142.5072,72.327969,-37.530111,-16.312251,106.071757,120.540956,50.038134,-139.35715,-181.255893,-137.47648,-92.482195,-50.20587,3.204234,79.908081,125.308266,41.210535,-152.572325,-208.133145,-274.204632,-297.434414,-346.208917,-420.827237,-465.629405,-545.941599,-556.800384,-491.5869,-434.92094,-313.84656,-144.079284,-52.885953,7.439087,-36.704121,-151.108511,-171.465685,-88.879266,-8.221905,75.978645,-37.561748,-118.641413,-180.662084,-142.75415,-20.213396,11.903645,-17.290307,-52.960336,-37.138729,47.671119,92.766568,104.87412,86.558439,152.138269,215.404194,219.40944,156.596598,154.26235,165.285359,158.358479,82.51601,20.383799,-69.786103,-3.80921,74.691916,146.627276,128.803703,64.646467,7.451521,-131.036779,-168.395783,-137.597134,-43.817146,-25.82655,-30.406709,-42.460478,-140.582549,-181.633289,-120.044143,-46.03225,-61.405377,-150.740661,-201.505771,-274.793447,-282.184128,-233.841279,-199.977182,-166.320539,-178.358128,-195.543579,-198.554966,-181.224774,-176.882617,-193.887717,-263.896804,-360.879805,-384.615998,-406.160272,-427.409929,-477.443698,-482.78783,-368.127731,-250.191637,-20.34807,65.713722,57.378221,48.924244,43.064988,-62.106302,-121.839211,-98.791526,74.514737,174.799734,288.592575,271.692806,148.70136,82.774607,24.514156,28.598847,35.558636,65.933156,75.4084,5.505918,-64.91878,-208.834449,-234.511712,-116.057341,45.878745,49.50531,-74.473093,-115.969818,-79.922378,-58.874087,-49.288839,-33.474725,38.484633,129.446257,148.942634,81.933453,-1.20931,-174.816293,-209.296269,-177.876275,-151.423573,-127.848789,-26.591788,14.89861,-36.124465,-117.862447,-222.555054,-213.484415,-163.082737,-141.220458,-139.624787,-158.699106,-184.982883,-268.317776,-282.974977,-188.604903,-17.496549,50.533861,103.177831,99.756306,53.836537,12.523975,-47.54645,-38.359046,59.583404,157.211831,164.492463,136.90716,123.908949,28.933671,-39.737219,-86.064298,-93.837025,-123.935761,-169.342208,-172.343247,-205.894935,-244.786163,-284.040015,-277.592601,-266.971087,-203.477445,-140.07838,-35.283538,-27.549336,-128.051471,-201.173383,-231.987915,-51.279535,58.892903,135.028457,95.145932,15.291627,4.980197,32.417825,71.351782,140.60076,107.408059,67.056531,18.430562,22.496215,32.201835,23.737735,-5.903947,12.104308,56.078821,118.831841,116.319762,119.326175,136.14516,143.32627,125.973769,81.432164,28.850968,-1.676329,11.963132,51.57516,43.377207,-1.172238,-20.849055,38.468126,63.736195,105.502134,126.412843,149.14311,129.785911,47.739555,20.582833:-39.010031,40.938706,27.071618,-32.598651,-74.892583,-158.866803,-168.501963,-149.443086,-109.538518,-65.970175,-26.766845,-55.059409,-113.077968,-96.38655,-0.459185,29.853983,67.677019,168.744104,209.258687,196.151676,159.674551,83.324969,59.563441,63.868186,113.579009,146.415846,184.030947,170.456724,87.758566,46.866915,23.922464,44.146576,117.14759,119.518203,56.584374,-131.266768,-205.591255,-283.553312,-287.568718,-217.97124,-105.696776,-66.502456,-55.216035,-77.851708,-178.664559,-233.308619,-242.7558,-215.874038,-187.136606,-100.794473,-55.959412,-122.556454,-225.411886,-357.524396,-324.794725,-162.841977,-51.03824,-22.615727,-16.258548,-31.668741,-87.2709,-108.591551,-51.868428,32.716137,197.067993,197.974627,158.8281,133.701352,119.846328,-0.427285,-54.085923,-22.840971,89.640838,137.035219,213.357522,204.742306,48.559417,-24.193663,-13.510181,36.013953,146.089296,247.58017,260.220246,207.750214,154.239127,23.123458,-7.0777,106.151595,287.361132,314.504598,272.134004,261.648106,250.571054,202.453792,108.090831,116.846159,176.827435,168.877865,142.517841,76.909813,38.20784,3.284625,35.8979,144.026484,181.922358,165.008728,93.568362,71.577933,79.248461,85.993932,64.891147,56.255147,133.439193,249.740197,261.382346,199.960995,141.673321,1.029446,-35.14658,45.695908,115.593716,66.494424,-72.607284,-78.008977,-5.747362,3.931762,37.076855,112.355198,258.112953,225.102343,158.667821,-2.629226,-62.76894,-80.400105,-45.857954,33.436925,92.975873,106.455412,64.794316,37.831044,62.155792,98.30056,140.214509,149.826896,173.369868,182.549567,175.836057,181.126325,199.338654,202.095406,183.56828,174.866175,202.52974,184.053817,54.109604,10.331757,28.389706,38.627136,37.463208,60.552768,168.77257,220.324648,203.893474,205.156242,216.384805,147.375028,103.279599,128.284706,185.358094,162.424258,54.999392,29.528319,15.835281,-22.475382,-82.373163,-41.331631,83.461207,24.60362,-52.566713,-146.132549,-160.26586,-193.799878,-189.858326,-56.386115,149.532851,198.032747,96.619117,-20.218032,-247.559803,-306.387892,-288.694885,-281.733779,-362.230041,-401.279041,-404.425535,-440.672095,-443.864814,-358.505128,-279.87997,-122.236481,-25.532981,20.195776,55.059042,-14.844186,-232.629908,-273.360493,-167.994129,-88.682208,-1.134283,-14.030229,-43.080764,-80.206421,-69.509097,-55.881317,-79.377871,-105.306647,-1.083502,46.396617,43.297667,38.372337,73.753594,86.155697,135.784485,184.830096,228.521666,172.267825,148.518179,157.899475,155.451031,65.815895,4.392838,-91.082637,-27.392145,57.280609,106.639426,74.125757,67.310088,73.637685,29.498939,29.423505,156.98998,246.969299,198.221646,7.753576,-75.106238,-155.094051,-138.142642,-49.664028,-37.65481,-76.316301,-188.228902,-223.356027,-183.828693,-130.052297,-94.836167,-126.915507,-177.327606,-178.061026,-179.75614,-115.733883,-62.382434,-40.384481,-60.719165,-93.137721,-131.048978,-142.151167,-153.681202,-183.497067,-279.483401,-302.275346,-231.446492,-151.893429,19.428091,79.738402,45.415425,-56.610799,-85.141742,-84.555357,-58.169998,46.158352,217.130489,301.032818,327.313377,272.238449,166.20238,152.656676,169.905058,172.875776,204.436295,246.995151,218.81963,97.894693,50.253592,-30.39524,-60.832246,4.026277,181.368051,200.855493,11.630428,-100.187064,-141.149296,-120.564504,-156.43842,-169.418821,-79.314299,7.464098,-16.846778,-118.143344,-149.37487,-188.500164,-194.517765,-132.245326,-15.714305,26.29913,42.05213,23.549653,-43.692601,-83.213711,-122.091221,-111.807706,-63.12706,-36.891403,-50.018105,-114.470719,-149.869512,-167.04915,-131.246486,2.964453,175.729702,245.990701,241.264335,173.503434,44.732964,12.868745,24.259614,53.132063,111.492824,167.888963,156.389022,68.245077,53.453064,33.914925,-18.73887,-118.103448,-86.178386,-56.804538,-81.213242,-124.200976,-195.06116,-225.972188,-269.161294,-250.870055,-135.39984,-36.971046,-15.199749,-20.326224,-50.709523,-154.614064,-204.685667,-228.371288,-113.479468,-30.704162,56.550269,50.10033,-5.987229,-33.594498,-7.124443,42.060129,119.704314,132.145054,110.137196,13.895968,-51.282991,-168.919012,-194.526601,-157.649963,-20.690403,46.843528,77.932329,56.041276,33.165629,41.885257,69.675989,76.408497,42.172019,-49.45787,-79.307408,-26.171271,31.718395,50.990555,15.43937,2.593182,49.086111,29.858412,-83.158551,-118.10066,-114.989317,-98.651457,-24.014932,41.681337:-212.750785,-71.138834,-59.828412,-129.294722,-181.906583,-266.725812,-272.776973,-230.026262,-153.86091,-131.322807,-157.330182,-175.516162,-144.405221,-106.506806,-51.347465,-38.45265,-10.765782,15.919195,34.101199,111.618795,138.823423,137.305775,151.410706,193.110451,114.21294,60.437859,40.049833,58.897963,53.477346,20.962267,-10.831943,21.327338,135.755214,156.072959,109.756997,-40.261442,-146.623606,-339.930284,-347.315782,-212.383133,-90.175376,-60.18565,-72.225872,-107.14692,-180.881421,-193.614734,-154.355971,-116.220213,-41.150555,4.771948,2.189991,-99.899898,-183.722789,-271.490525,-233.507005,-40.419627,70.211399,31.024334,-76.613917,-77.795089,-96.480211,-153.549335,-200.365134,-134.766156,94.657772,229.257393,227.849305,162.440039,110.431456,-11.629485,-34.058632,58.119125,164.983508,163.407829,104.388109,83.981323,67.304005,71.345535,106.122771,115.414142,79.689527,37.438155,52.091669,143.942078,162.531381,84.761712,32.934399,7.897316,126.821463,195.925627,201.132312,147.341954,76.214389,83.877519,100.537541,76.868117,62.677209,142.376345,143.538079,36.360313,-19.446341,-13.354174,46.405813,118.591747,80.688265,79.553225,105.30304,106.693541,66.580152,37.312087,18.851273,37.286867,115.659344,215.650799,244.322628,205.246194,145.264711,27.031898,9.147046,51.78838,65.48559,30.734922,-70.69271,-94.783387,-85.013928,-72.070397,5.553288,83.063794,239.761287,313.118571,307.106272,198.499549,112.081169,-1.886557,16.797754,132.242126,176.292843,169.745375,159.851741,177.090476,192.929734,162.493106,141.852246,169.892358,198.564111,181.122691,163.797594,151.715227,158.42894,131.680773,120.410671,188.913939,230.714154,193.778675,78.66755,49.727448,66.246996,77.406315,72.754894,77.757922,113.81452,116.971493,99.870563,76.118292,64.757836,18.960733,7.223817,45.582403,120.663622,129.944559,44.232644,-11.973023,-77.229425,-102.794442,-91.647368,-41.075996,13.346577,-2.1574,19.640804,51.823272,8.552928,-107.49623,-104.259489,17.002031,117.719224,135.18459,70.042335,-16.822757,-199.488654,-243.143328,-238.773955,-231.842674,-232.678174,-175.631272,-145.61436,-198.93707,-276.301125,-361.675914,-315.811588,-94.040372,128.847946,165.443564,26.867481,-104.17486,-289.500936,-291.618488,-167.427046,-100.475275,-3.373868,26.180939,-20.497735,-144.676581,-151.743798,-98.18325,-96.599089,-107.752807,-26.853206,10.933193,56.300839,97.056961,128.882128,83.629292,46.634843,110.443038,241.374191,175.154206,128.935442,141.889447,147.441253,51.032558,-15.725258,-76.714196,11.18418,65.756566,103.252587,124.678124,195.119054,192.950896,120.268758,92.309152,99.217973,174.766124,178.741985,32.686268,-75.116839,-175.410225,-129.550818,10.568781,38.204728,28.999163,3.143184,4.153068,7.7612,-28.671281,-120.209851,-117.775918,-53.529146,-69.016643,-85.609655,-50.136569,-42.684092,-106.952602,-113.933113,-20.233296,48.919357,41.729143,-75.248372,-164.718608,-256.407828,-235.141562,-104.320602,-17.818519,109.834703,83.770806,16.58738,-94.772239,-98.469549,-31.487192,18.274045,126.726886,250.70442,295.46745,326.758394,324.564645,216.94915,136.030004,115.905254,167.287413,234.743295,243.837911,238.878565,165.319341,105.381338,73.461378,119.900717,226.321617,249.931753,200.421554,-14.152449,-100.096795,-114.116555,-101.316631,-144.792299,-143.986828,15.094097,109.640099,27.027642,-199.103215,-243.891337,-244.913723,-226.500736,-96.298954,69.81675,119.028373,178.330344,178.796222,49.779923,-45.147952,-115.290609,-82.735607,5.641503,21.660048,-18.898791,-162.330218,-210.345407,-156.39312,-83.124089,24.937187,79.052786,99.338692,86.414718,47.787741,-17.589951,-16.224305,-4.569622,-23.451566,-36.645753,61.959837,100.903043,55.177847,8.5564,-69.673112,-116.055478,-141.490437,-34.902527,-10.57731,-84.218895,-128.499691,-164.453584,-173.088394,-180.213273,-165.337191,-91.123241,-69.457273,-103.059775,-147.840041,-152.422853,-189.867166,-206.440201,-214.831826,-178.865,-115.231388,30.051786,61.541954,10.934177,-33.657136,-54.321849,-39.604741,2.518631,63.41386,77.323582,32.798802,-17.481448,-126.193103,-157.887225,-119.043164,31.519321,93.823446,57.86532,-15.516208,-72.578854,-30.571244,55.913706,57.995949,68.427139,99.432526,66.37949,-26.076545,-46.225128,-94.209462,-131.875753,-124.236622,-0.814247,17.079459,-60.540935,-88.519862,-96.754909,-111.537419,-117.100561,-79.743518:-119.787652,72.476104,86.908383,-40.230863,-111.369907,-150.495365,-118.958844,-70.355035,-67.290112,-40.116955,-28.783844,-89.561189,-227.092664,-246.808578,-197.056655,-145.198874,-3.191515,97.178588,97.048018,89.961335,110.635887,139.845074,149.33011,207.542011,302.011955,330.003376,285.09468,224.04351,99.385494,65.114575,76.371369,101.622827,172.999002,203.246667,142.787861,-100.364,-228.580675,-359.266395,-325.541108,-142.873308,4.353071,36.553341,-1.653964,-69.376931,-231.909565,-281.588987,-234.695921,-162.518791,-88.927159,-63.061157,-18.304535,10.386672,-50.33936,-207.799633,-219.259122,-68.859896,111.873937,154.837168,122.418436,70.532548,-21.385206,-52.545806,-44.918465,11.32306,163.342347,256.239893,263.257137,215.414911,167.488817,72.625611,62.505685,91.50587,92.493783,84.870226,29.334729,-8.562976,-19.011575,6.384339,65.532804,88.497992,121.115585,131.649993,130.715709,153.233419,155.621803,61.134201,4.075197,32.022492,199.130547,254.466986,229.544341,178.004751,135.43783,160.738239,173.174184,126.175954,50.725479,84.697113,87.138627,63.76612,57.110833,29.965773,26.926767,83.920826,157.596389,169.448233,76.063773,-15.954277,-130.875932,-117.041601,4.704986,63.34796,144.312408,251.289478,278.998497,217.376975,142.846938,-27.357096,-73.939187,-34.279909,17.905923,-6.935465,-102.453103,-123.234269,-106.321611,-105.34302,-89.442745,-33.719948,111.60501,132.619239,97.1136,-2.41394,-66.149938,-195.146379,-215.555637,-149.600295,-65.18486,-34.048713,1.618139,16.870231,20.934519,-4.116672,22.404297,104.044924,253.648543,237.269891,176.429275,76.627296,75.075226,113.214797,123.71927,164.024951,275.078937,305.650249,247.46721,208.659602,153.679851,105.267472,56.796459,106.750959,259.745829,313.069511,301.959332,286.12132,279.995115,190.898013,130.386244,137.387166,282.710162,325.152281,273.265513,221.345007,129.936336,74.857178,44.061969,103.318369,219.640268,198.482534,157.070752,62.66896,8.760625,-88.571572,-72.882439,102.777688,222.388242,233.790449,187.551141,111.53041,-140.322605,-255.126572,-296.236497,-231.433556,-92.176497,-109.108512,-180.798514,-299.987926,-306.331445,-261.394416,-226.748537,-97.694142,91.214149,156.4007,121.480423,25.462585,-220.471324,-293.701384,-173.566639,-24.193072,173.056119,104.759076,25.90242,-34.548241,-12.190424,-23.012231,-72.079579,-125.221345,-64.525189,-21.880427,73.782148,130.797169,172.737342,144.110939,140.587484,188.429023,234.19679,187.924098,180.149612,175.804975,158.77701,128.509164,112.194934,45.414908,108.088933,197.020328,267.300387,246.174282,202.544332,159.60871,18.613036,-26.069417,32.973838,117.308025,80.484398,-46.406076,-78.765826,-98.076066,-94.291727,-58.321337,-28.106024,-37.325039,-122.001413,-159.765443,-156.00649,-148.360387,-168.770159,-180.896163,-183.99463,-168.549061,-171.721866,-147.867494,-106.820946,-51.793468,-64.033233,-133.264182,-143.163589,-126.089564,-174.677171,-236.701088,-299.245574,-278.64643,-151.541069,-60.097785,100.512188,143.072556,104.221889,-37.943649,-94.828332,-149.028763,-146.526969,-47.541837,128.7829,198.250797,201.917716,146.987856,61.721252,59.667414,98.674761,120.141104,167.485616,188.708436,152.516521,13.915949,-49.693453,-107.205454,-79.86465,44.770923,104.270306,81.253498,-52.220454,-105.547675,-86.933083,-62.004776,-63.855561,-56.454213,12.690787,57.276372,39.460131,-69.963446,-148.003387,-304.608021,-332.814106,-225.94146,-72.198739,-26.985245,-14.796104,-44.577445,-141.479624,-182.252178,-176.569198,-140.968579,-104.010023,-137.330409,-160.106121,-188.292581,-195.626855,-222.396435,-243.14051,-238.745081,-101.180969,-14.432381,92.929753,107.755373,50.117607,-12.566701,-72.364421,-37.393281,67.37203,78.22104,52.279907,2.270421,-7.896683,-60.107193,-111.969114,-161.769732,-120.694257,-125.765615,-215.121222,-252.997551,-285.015716,-308.131308,-332.890615,-308.144888,-233.700896,-206.830817,-210.482494,-195.690849,-190.92378,-276.923242,-333.096688,-326.066534,-212.777112,-146.035768,-74.808642,-99.339286,-203.994761,-241.999756,-252.776229,-223.637559,-98.130258,-10.221807,-15.679705,-73.789092,-107.588474,-169.664687,-182.470378,-123.705932,0.373471,47.341336,35.167368,-8.390082,-35.768229,-12.852731,18.147315,5.814065,-48.910799,-74.009854,-74.897883,-45.408996,-28.610581,-84.70164,-147.263211,-192.530917,-60.121368,4.524044,-18.934784,-60.918698,-77.011199,-70.613142,-66.869622,-72.753485:-146.755687,48.218457,59.398023,-127.343818,-227.43167,-306.740564,-303.23195,-236.345701,-59.15622,12.260139,-25.917398,-118.334774,-289.346169,-320.833311,-272.183033,-207.577131,-47.814341,-6.525245,-21.318723,52.309514,117.865218,157.777018,166.311499,277.493764,417.52628,433.497187,290.396711,173.22188,25.007658,12.874458,65.081771,108.670995,156.708822,98.564854,31.986386,-175.936213,-300.151052,-469.066862,-462.821209,-268.617776,-46.550191,-24.827338,-154.414346,-227.980518,-289.074971,-280.203984,-168.917529,-82.636989,30.56302,48.15426,39.844845,-87.695776,-201.940158,-288.458113,-211.782423,28.289809,181.729155,194.677897,149.896761,111.009989,-46.6468,-137.423755,-146.889175,-43.164445,216.847177,259.069455,198.041087,104.192008,79.01346,28.597951,31.464742,69.758706,61.538686,65.296763,36.315871,-30.333512,-167.35044,-166.979955,-1.165128,96.161651,155.261444,102.496052,105.508452,168.909113,163.50234,17.516929,-50.595729,-24.676452,121.437352,154.083624,109.129595,70.233806,-5.014733,-35.811593,-74.562828,-94.43409,-87.459175,11.073276,31.033718,-44.678082,-96.212844,-122.092046,-90.934008,-6.761002,59.015244,77.107003,10.611198,-58.651819,-143.083074,-140.068657,-73.039864,-27.673237,101.046436,231.088154,242.615737,153.585365,77.731195,-47.96399,-56.386514,14.569545,42.96963,14.89822,-96.123692,-149.334417,-212.35956,-218.221315,-133.84533,-46.703693,124.800352,201.330692,197.423456,113.051065,30.428423,-118.920234,-119.450477,31.648776,160.998548,158.468287,84.823719,81.278675,139.805924,148.358198,173.448772,216.502623,295.402777,304.377626,272.414498,179.106108,145.662125,126.365627,149.331823,259.26124,342.013807,329.43403,182.423396,105.651853,56.431113,49.998573,63.726921,121.719207,284.415127,322.001805,274.037298,138.42641,84.605025,13.11779,9.296673,92.555148,165.112356,162.876509,115.514256,90.128937,32.243277,-4.950042,-15.181036,38.628414,173.662967,184.777287,148.884156,92.408926,60.633102,-83.903354,-135.792542,-14.293584,202.478003,217.461575,68.964231,-26.397347,-182.303603,-227.874062,-215.740212,-170.241374,-72.807574,-44.277431,-75.867682,-211.871376,-287.99674,-340.943905,-281.365925,-46.266011,168.506496,205.064054,68.525243,-57.754344,-228.799382,-227.592646,-69.260012,38.239515,196.068965,200.213865,129.6387,-43.019937,-93.947845,-148.25419,-156.334921,-73.980799,82.585516,114.242697,51.03687,19.098502,43.148754,76.146334,140.889577,160.778352,178.117861,204.173565,200.629737,119.777564,49.017105,-19.668004,28.333231,159.929655,218.918417,253.859921,292.157077,270.723325,203.204012,170.787044,81.720758,43.441372,99.063966,228.051335,193.836074,-71.098494,-185.73366,-184.702781,-95.867673,84.041945,151.663019,120.298901,-41.674164,-105.882875,-148.084229,-146.288547,-60.395185,2.497302,9.677633,-93.171608,-123.690182,-133.068369,-133.442855,-121.984335,-97.130732,-28.300084,49.074472,75.128396,24.716978,-43.520277,-148.815808,-152.699132,-61.332697,-1.605735,62.093336,92.676942,71.325438,-71.814737,-130.077267,-127.613565,-87.959693,34.413715,208.177935,252.57207,198.668568,161.25432,113.084993,90.691,115.702178,164.763868,271.275409,314.67654,283.729074,144.923392,71.904624,2.461361,24.865428,156.839099,250.957477,218.093067,-1.825903,-114.305222,-190.46997,-155.049397,-29.272278,15.791823,55.010031,41.404167,-12.364234,-131.513713,-162.040884,-231.213344,-247.534105,-104.115515,74.515219,95.603764,52.404783,1.808324,-133.738226,-171.823837,-123.69249,-62.69566,66.683584,103.33744,37.571859,-171.531713,-231.296637,-185.571863,-118.785863,-28.985003,-16.33856,-22.136069,-54.248101,-67.868729,-84.686689,-89.486813,-90.102996,-100.264655,-76.615106,50.279604,99.788138,91.626475,26.618118,-156.731903,-212.818172,-171.701484,-50.901711,-51.039312,-183.283518,-248.403642,-321.758228,-333.057143,-260.308078,-201.52176,-162.010474,-194.687882,-201.35022,-202.458028,-231.355737,-322.898341,-320.523654,-215.204636,-125.546755,-115.774935,-184.952505,-222.646922,-255.333549,-270.690407,-267.919351,-236.392395,-131.897774,-34.829727,-22.146089,-63.974204,-98.435515,-162.875163,-178.280723,-102.682148,48.826245,64.910521,-44.646274,-106.958977,-126.005662,-83.218076,6.962461,20.0922,23.168309,27.644133,24.010733,11.079889,-31.054709,-164.472155,-182.179433,-77.42152,64.127845,80.714579,-23.765644,-78.754477,-129.50307,-158.847659,-187.956601,-166.857993:-30.322006,120.946679,199.681488,120.495469,-6.686658,-150.767415,-102.670965,61.17012,57.555402,33.003704,0.166804,-50.374266,-220.98609,-282.393653,-198.996681,-62.42851,136.308882,81.08207,21.865585,-27.893135,-15.131171,11.339928,24.110983,147.498444,414.837281,512.843822,447.832926,335.156596,183.063148,146.547273,72.039919,45.11851,101.550237,219.847328,209.468546,25.745468,-96.185875,-219.456478,-162.98457,99.538128,297.635349,321.607015,193.17603,76.529932,-110.453382,-165.062698,-191.258192,-147.668776,21.592728,157.165708,141.982091,8.688998,-49.113666,-160.288243,-191.209844,-80.428163,113.437192,177.798019,248.922421,260.828476,196.386501,122.051521,36.562934,74.552368,234.19527,335.429921,310.589497,167.478807,132.309632,163.854175,175.856163,119.631566,42.519428,37.678738,41.466386,34.531296,58.712248,69.811979,47.312861,40.097274,79.853542,201.659615,248.809111,220.50652,160.708904,28.935318,16.226575,160.149408,314.667612,339.532607,300.82756,274.554275,259.797081,238.654946,122.328545,64.686709,60.930621,120.022588,114.963145,82.74725,94.342807,140.628249,150.265433,177.583288,217.13635,190.714976,-50.51329,-215.402876,-367.894846,-327.67932,-140.002606,-30.32762,164.955467,267.611396,267.342081,142.910468,26.288565,-181.349876,-191.157909,-20.500313,99.750321,75.832302,-65.788889,-127.04866,-150.073776,-119.485396,4.844414,79.908924,160.769946,106.981122,41.615194,-115.282471,-181.077093,-251.958659,-250.404325,-170.815617,-76.532191,-46.774269,-23.508927,-16.530812,-7.534676,-25.869212,-2.013362,83.31683,274.651254,304.346461,267.690402,222.072548,223.665404,213.875304,210.689626,261.720192,345.6998,364.6217,283.065144,210.603326,122.526043,112.002329,155.979966,208.076222,335.890982,408.962597,402.130601,366.38798,357.045263,307.565585,264.732668,209.724189,263.078783,313.193309,328.831526,283.813975,128.989193,38.043877,-27.897861,13.65592,108.52846,111.873958,69.570055,-36.621225,-59.404312,-60.449108,-44.669213,9.82201,25.190706,45.269831,118.172047,116.95636,-42.143166,-163.264019,-264.979652,-205.524339,-80.5025,-183.756122,-278.378144,-376.276145,-356.370298,-245.67188,-197.049031,-167.370656,-130.788156,-59.202955,78.897776,76.681392,-52.736775,-119.398173,-78.270228,34.996587,185.142355,43.666179,-65.875249,-186.911564,-182.709503,-129.156534,-118.298249,-135.109355,-95.133574,-59.740646,-36.431574,-20.294285,24.869388,36.371301,134.009683,204.933537,214.740206,84.355378,29.084697,15.54109,41.269912,9.211478,-57.478392,-115.34867,71.3425,192.003777,261.731635,203.239162,28.690918,-51.427278,-150.855111,-164.316867,-163.200753,-170.117522,-185.318919,-265.58613,-300.79486,-261.22858,-190.75218,-69.057802,-69.57311,-89.232628,-149.595254,-199.954063,-290.485719,-293.8353,-196.93672,-147.838739,-161.985029,-200.97559,-197.294464,-134.565261,-70.869667,-6.11033,-44.725127,-177.380715,-245.329084,-236.554512,-231.097463,-270.372868,-365.610764,-367.517507,-210.139979,-103.598906,34.092294,104.06878,77.754253,-77.793714,-129.587921,-139.016702,-121.895513,-39.13053,94.749884,142.319351,104.195149,28.473073,-85.140077,-94.306122,-98.683336,-109.59576,-74.171035,-57.74377,-105.436704,-176.89969,-179.53156,-218.064648,-229.695776,-134.887215,-35.074649,-37.399521,-113.130373,-136.319698,-76.787652,-31.254243,41.898609,76.005707,119.74261,170.610205,193.823358,160.735816,86.86002,-141.660921,-226.406456,-257.426642,-265.329509,-250.46775,-94.888549,-4.933455,-17.743781,-122.075773,-256.311853,-220.159285,-73.66213,-25.935209,-53.975891,-152.709717,-203.830559,-271.292973,-267.874681,-224.630123,-161.166855,-82.090179,113.369256,141.669696,4.976526,-98.971851,-221.258976,-225.727568,-163.13492,-81.069845,-53.480536,16.063291,43.895742,-23.371393,-96.961101,-147.581769,-53.740266,-45.235735,-177.893898,-245.486088,-283.890919,-294.2455,-319.408332,-313.865536,-303.728205,-273.430279,-217.048838,-107.171939,-122.355969,-290.930904,-358.794046,-321.321185,-164.976855,-109.894353,-110.584382,-134.68867,-153.064508,-159.580215,-169.017072,-153.336908,-104.539782,-111.898353,-124.944677,-128.642035,-132.551384,-131.538576,-103.317445,-35.048398,6.166925,38.407022,71.982776,56.964196,33.077002,46.233754,112.224391,137.322733,92.008736,-26.51304,-55.870526,-6.419471,28.984408,-24.095816,-78.905726,-76.21959,30.844734,90.543191,154.721896,136.873862,27.274613,-57.299667,-205.426212,-204.801936:74.925358,150.456661,118.726329,-13.181978,-78.76171,-182.199307,-187.126524,-70.316156,89.698655,125.161382,18.211939,-99.998317,-294.226498,-317.180405,-191.362929,-78.240143,120.158058,145.814249,99.896267,29.299811,18.035153,19.100948,53.740146,253.810568,500.598775,540.446515,376.713888,240.133352,77.217195,69.000387,95.565391,104.980721,151.61832,167.104948,88.398343,-227.327507,-383.958164,-470.293092,-367.783877,-32.976173,183.130533,191.718228,18.346179,-111.312988,-305.469073,-328.740266,-162.905814,-26.115963,115.679814,55.736883,18.594708,-6.956493,-29.837345,-90.377689,-61.227679,116.053783,247.803214,276.602201,246.396281,195.313822,63.210761,-3.73909,-27.436665,48.518202,285.593349,386.021458,320.263678,74.401053,-3.448121,9.065239,52.422983,98.311375,68.51319,60.089376,44.221,2.116074,-137.181034,-184.984605,-117.064051,-16.801264,170.207813,246.156506,236.112669,149.87983,89.760795,-47.975271,-76.591586,69.762869,313.271333,360.271306,250.885397,159.175356,39.515345,5.316622,-30.857374,-24.451611,37.126922,81.264201,55.762798,-68.305575,-119.094701,-100.522121,-45.148183,59.72101,152.168433,168.0777,0.352407,-163.240863,-425.872686,-446.350942,-242.049569,-85.709403,195.005508,356.268289,336.511131,111.664076,-34.617442,-223.388359,-199.826484,29.831835,152.959329,111.193627,-51.132301,-111.10876,-176.718846,-192.476276,-123.537819,-38.330624,88.007736,84.811973,52.910267,-32.603846,-77.776794,-156.130033,-167.002305,-103.632413,27.713533,72.476526,25.766432,-15.853759,-0.020682,19.670287,62.652417,138.029899,331.945169,349.845921,292.582595,184.212721,153.739699,109.542876,119.701898,286.914634,493.460823,519.351518,384.51854,267.369457,41.107773,-14.40251,108.632049,239.163466,403.011442,379.788495,334.801465,225.235777,151.949119,15.489103,21.515627,187.357683,311.311848,310.5079,218.651078,159.885455,48.415033,-7.844266,-34.526645,19.232158,177.676507,210.925949,122.403168,-125.198696,-198.325522,-202.823061,-134.404386,96.577568,242.813747,239.719433,134.371305,64.719443,-95.310537,-174.557489,-185.443222,-89.488346,126.556029,60.897404,-70.551274,-264.691993,-277.913581,-208.81415,-163.934119,-73.319844,59.692554,128.913883,144.254314,62.602928,-166.493974,-224.577024,-93.75132,58.604512,308.523089,285.295337,164.039777,-91.490067,-124.847391,-68.805299,-68.245169,-96.782865,-34.493106,-11.629871,-31.706506,-36.358975,-33.420348,-31.272975,95.063852,206.258594,321.085906,199.146444,93.007777,-72.320947,-101.498941,-55.932227,-2.661239,110.155166,231.468396,284.556173,295.923305,254.259161,120.097256,46.222536,-26.516126,-0.065117,126.927665,133.228357,48.785781,-125.638121,-156.797545,-118.137038,-65.897716,69.381877,150.085838,139.174794,29.25861,-54.836742,-216.898265,-252.016353,-186.86835,-120.503342,-41.569236,-74.04724,-116.336628,-170.061068,-166.108283,-122.780819,-88.279385,-55.617583,-77.352928,-67.9543,-67.625864,-106.776366,-199.184669,-212.528609,-85.616218,30.215575,155.174351,72.949839,-6.547219,-159.342365,-223.5745,-283.0983,-246.28424,-96.141138,60.23588,139.30384,125.02678,14.72453,-176.137972,-200.935845,-153.522532,-99.477713,67.48171,168.936129,129.857716,-40.234307,-120.115425,-212.594859,-181.83551,17.020345,164.670582,153.32845,-52.569979,-165.042945,-231.511104,-206.482742,-118.5443,-54.550028,124.066634,205.191528,132.044684,-116.613222,-208.127611,-283.433732,-254.941104,-103.69764,-31.859194,-26.123129,-31.492032,-71.295255,-241.041753,-304.123897,-196.099837,-54.269306,134.863924,67.525306,-12.238679,-142.178181,-190.155046,-272.395847,-289.031926,-231.45149,-60.758262,18.951682,43.81975,-12.440231,-187.061104,-256.245277,-242.514935,-174.185891,-27.625783,79.101243,88.314682,-35.013595,-143.97757,-296.111505,-285.662216,-136.83554,9.646476,19.324951,-156.469317,-270.758748,-379.489748,-400.676617,-397.82933,-341.790833,-201.827845,-196.222183,-224.014007,-246.504334,-272.510867,-414.012457,-447.868365,-300.858215,-122.650005,-104.616921,-199.773601,-279.371613,-411.893489,-450.113245,-423.425189,-347.76132,-139.387183,-38.625283,-69.429056,-172.913631,-190.211247,-139.353449,-104.168566,-46.789797,26.739841,41.45867,-26.555109,-80.839896,-129.252106,-118.012128,-82.117672,-60.975143,2.918697,5.523488,-34.722685,-121.829949,-162.116956,-267.86158,-293.157628,-175.732486,60.758814,126.547906,59.536782,-28.649381,-209.759821,-278.728324,-265.525253,-182.978694:11.050431,235.464222,284.965793,140.488869,41.634582,-23.103994,16.077031,135.187453,181.606828,198.252073,185.923655,115.454895,-93.643817,-159.347481,-72.321526,43.807194,149.210965,75.663194,44.368259,-24.055207,-87.778705,-201.985238,-190.720868,-19.387944,200.440636,286.141707,305.725063,245.546953,107.564313,42.179775,-50.147755,-49.923138,24.043723,83.733451,74.229533,-7.269118,-46.307338,-62.159106,-19.579088,156.870667,326.614063,359.994675,248.347114,128.268358,-41.510938,-50.589943,0.075019,28.658322,140.769087,323.927054,379.058902,343.091776,263.227421,53.18379,-12.709399,49.70494,203.984911,252.11931,302.125938,305.89545,268.75004,262.538417,342.75969,384.271812,330.392211,203.305872,165.026978,121.405668,122.735309,134.455243,97.988603,-34.44598,-136.395473,-160.586011,-158.401305,-143.838415,-103.414877,-82.970388,-44.536004,-16.667034,69.110718,166.479664,191.521004,164.226727,130.558447,85.65365,99.22789,223.763932,319.910847,310.182421,235.305175,194.190679,96.029869,50.864459,36.139734,47.067101,27.506844,11.707437,6.433971,-9.300704,25.334933,166.544556,188.633337,82.655719,37.689757,49.272581,-112.382717,-275.317528,-436.892532,-378.578186,-176.006071,-118.066516,-69.83658,-17.007205,-11.133399,-70.209969,-115.303656,-198.107504,-213.295987,-82.375068,178.396771,238.07719,140.901987,62.529146,35.955672,79.320287,171.466417,205.109559,232.067943,171.751883,115.527102,18.943547,-17.097628,-114.298838,-159.190903,-161.209083,-46.417212,2.517616,-22.223981,-64.192981,-77.744765,-62.108711,-19.349937,35.272751,187.500811,319.549593,383.058541,465.949466,463.409849,384.795698,331.215298,255.059873,257.273327,270.246135,199.280987,106.535203,-98.900525,-150.871086,-67.687341,13.155106,125.002477,250.902101,301.852902,232.184245,130.495961,-1.562711,5.53174,11.837843,-53.61834,-36.960232,46.618158,36.556707,-81.96976,-142.569661,-217.063488,-231.98282,-203.340014,-99.370105,-65.737383,-92.353989,-113.070774,-92.002523,-77.348466,-130.998994,-152.575676,-84.963453,18.239619,6.842323,-4.280476,-2.145655,-74.984522,-119.371061,-173.239993,-271.109363,-310.840308,-299.959101,-266.439682,-176.591459,-127.545299,-84.069898,-129.056942,-148.718068,-196.732535,-238.663132,-291.810915,-276.170879,-128.478278,-27.689668,55.486396,-51.12136,-120.160622,-138.480927,-72.879425,47.676876,59.011345,42.779933,79.652941,110.093997,76.632415,17.259375,-22.837939,26.047198,144.511673,135.696597,-9.29672,-53.867974,-43.503851,-66.177957,-69.143295,-27.841574,-15.350298,-47.932641,-100.769103,-97.673371,-95.259866,-130.286947,-203.386713,-218.495164,-267.036019,-303.001795,-313.913468,-272.128218,-273.487931,-292.708111,-290.929182,-287.412186,-268.767073,-185.771874,-139.43192,-108.808102,-24.254276,-6.370102,-55.711315,-96.023784,-85.791628,-36.064737,47.029464,114.258608,140.350311,150.885226,154.432754,143.205664,113.834568,18.122007,-89.195521,-96.661186,-28.94237,-16.43627,-84.13428,-126.600451,-120.520005,-79.662449,-10.840433,5.862224,-29.012062,-156.780154,-193.74767,-144.040509,-86.29404,43.478605,191.480729,224.054618,129.380318,46.132907,-48.091889,-61.136043,-84.643522,-93.940835,-57.101021,-32.880686,-76.548601,-162.014157,-160.915739,-166.706274,-186.246392,-168.992476,-125.453546,-125.53098,-130.324247,-121.344668,-56.293544,-7.848352,91.487755,150.803576,265.622964,336.234359,336.957519,259.301137,190.843684,-23.942511,-128.48986,-190.212275,-141.447405,-88.636052,100.175826,205.444519,272.395675,203.601347,45.816258,40.304835,161.636074,256.521561,231.031537,91.792149,46.350463,26.347751,10.395855,-30.567825,-0.959175,49.537427,168.449665,191.488944,115.103221,28.520025,-130.197603,-147.222736,-83.040779,-4.021583,29.757502,79.829939,85.995519,26.600139,-18.062949,-34.130137,37.184036,31.949278,-112.405312,-173.030844,-150.484031,-129.960777,-163.25822,-189.270653,-241.033218,-159.177063,-45.615436,111.351649,84.726672,-131.513661,-230.438638,-234.778616,-97.601775,-52.505395,-62.002144,-88.906897,-55.895642,6.390975,74.023015,47.47149,-4.314574,62.409337,85.186458,32.30335,-3.532399,-13.581786,11.893262,96.859027,120.753319,94.517254,35.137152,30.261332,84.434599,113.564227,115.946026,109.689274,137.334697,113.660522,68.029203,19.239548,29.509477,-14.133807,-88.176616,-198.56524,-129.841831,-52.394157,62.89194,87.527803,76.821373,30.200108,-108.907049,-159.841823:45.334429,183.30114,236.004217,198.005276,149.437951,96.981923,90.436438,76.731065,92.314738,122.979521,130.46199,77.860777,-50.686571,-80.732668,-7.506356,72.914873,123.736019,51.193123,38.150797,43.935581,37.357711,-16.257648,-33.418661,46.569644,190.130931,221.375911,182.775582,164.416846,171.082083,135.139756,-38.156083,-93.850739,3.95997,174.97513,165.603062,-1.359174,-77.104793,-117.212551,-80.881775,53.537719,156.706446,170.280132,145.136842,119.904215,43.587184,-15.411163,-175.364957,-241.805817,-189.289119,76.554572,164.85662,128.472281,46.243051,-139.68673,-187.558777,-94.278034,111.150107,191.050359,240.623582,240.643252,265.301,262.0898,220.616823,205.383458,141.544933,74.608663,80.257823,129.118784,147.041304,141.288907,114.913814,41.658036,-17.925695,-19.231891,24.671099,47.726309,64.129856,47.135008,-9.320613,-26.085862,30.470408,212.974551,270.740158,239.232093,185.865626,33.271519,-31.284636,7.047085,167.284938,223.088001,261.389575,244.478514,164.946515,140.201275,180.139955,214.388565,232.444736,208.069157,183.658109,150.995342,167.358103,196.543291,177.0286,113.013664,114.944339,128.823813,62.284217,-13.827876,-77.652745,-32.256017,79.165592,93.656028,71.547962,67.679044,78.278909,71.967583,16.004562,-202.799756,-273.892951,-167.219184,35.168634,84.246313,93.640205,76.721565,38.708078,54.582158,235.747723,331.102758,297.759339,95.463679,14.836096,-108.597431,-164.952428,-259.395485,-285.203355,-261.834073,-143.533849,-98.519025,-112.009627,-129.486019,-88.95978,-57.387779,-7.298393,30.496493,133.727433,245.393016,286.75379,310.250099,309.847066,309.322517,280.573439,180.88813,156.413832,170.252031,147.414916,108.440151,53.773077,43.239409,81.210935,155.962399,347.502201,386.483968,357.527948,349.981506,378.469766,383.473262,334.187065,189.328731,92.812433,83.771136,112.710479,127.649894,99.837746,31.727347,-148.660068,-194.159084,-142.448474,-34.794347,-23.077186,-101.127759,-135.910742,-118.897798,-101.951508,-153.485178,-185.242723,-127.848055,-47.019284,-75.345851,-143.947159,-168.325149,-242.052638,-269.484615,-295.538726,-339.177089,-359.772343,-382.816097,-384.870553,-346.653899,-301.94574,-223.162507,-193.047182,-161.228404,-88.601103,-91.439132,-147.360868,-165.15097,-112.885112,-44.350897,6.72429,-121.282417,-182.897084,-162.711495,-84.462952,15.87891,1.552133,-44.226279,-19.512237,8.210414,22.894015,11.186404,18.531104,48.638038,136.773035,152.217557,64.940153,-26.925589,-31.510943,-1.825269,9.647116,-46.275312,-119.416958,-244.117999,-224.976157,-173.38736,-79.618513,-61.397343,-108.119415,-171.665793,-307.886855,-356.357515,-409.019184,-392.532557,-365.147549,-309.08295,-295.146638,-314.451893,-328.534521,-300.750819,-203.207648,-158.301729,-143.290487,-153.908294,-127.09645,-112.810105,-116.305482,-108.208934,-102.066434,-122.433952,-106.358107,-36.320074,-13.553002,-13.480376,-25.702344,-110.886287,-244.919555,-273.597526,-294.282578,-324.080972,-422.470136,-464.835657,-446.641785,-374.024267,-134.575283,61.826078,56.47242,-69.717322,-105.269159,-95.156624,-81.103602,-46.435243,42.252603,85.981094,84.123746,58.943723,52.884713,49.367224,-24.332123,-63.686642,-58.113454,-5.672869,-19.771073,-108.99109,-158.496927,-262.851192,-277.286805,-195.442335,-157.610007,-157.786896,-127.766774,-97.17744,4.17019,63.473563,163.644511,192.592454,208.474597,291.343918,348.081153,350.053619,275.960122,50.608327,-35.632674,-113.754045,-168.118164,-149.675647,14.30162,106.229613,171.886673,128.840888,9.673853,-4.809862,56.214865,125.769708,123.038847,45.105804,3.260458,-55.204952,-69.912363,-42.129602,41.728369,94.356007,200.250154,217.34049,108.916528,19.127412,-63.827184,-60.253881,-49.968967,16.891046,68.735331,148.507362,161.795446,117.843655,89.484552,104.413361,101.773842,54.528551,-56.261968,-97.072641,-162.650271,-193.085451,-215.396936,-217.182528,-260.14516,-228.830432,-144.169445,34.228828,60.860895,-49.151539,-149.571058,-260.763447,-113.737694,5.753011,82.733485,22.110496,-43.386636,18.059159,221.290735,283.488569,236.966902,119.256422,106.409148,150.675106,165.40614,154.205919,152.113738,166.737535,188.379961,191.484647,147.187461,126.772618,156.160816,186.623417,237.994843,247.356591,184.139107,141.3772,174.854482,226.746165,190.746993,47.948205,-8.109823,-46.788114,18.044452,90.159724,251.078608,291.902652,221.199064,133.2575,-2.957797,-20.253386:38.267982,214.022337,242.766181,102.040827,4.968576,-32.093013,24.529265,83.851754,62.722396,85.217349,96.77325,17.261759,-239.980045,-311.300655,-161.768332,2.101796,148.599968,-24.995633,-107.013741,-145.509552,-136.508221,-122.828415,-82.468136,140.596424,402.973019,455.299141,344.401917,241.582231,59.968768,-19.376531,-128.232181,-142.851591,-90.330405,16.048416,22.88105,-88.697432,-154.392323,-210.649736,-172.727509,9.90001,170.254608,218.051022,158.162745,33.018834,-219.67299,-259.811388,-152.913189,-40.773954,198.898405,263.964089,220.535908,157.877533,151.67056,103.5048,91.024832,130.920547,156.422346,186.183516,276.762932,297.567733,240.126958,177.05791,162.854575,237.735664,340.556897,253.647976,186.950937,104.786915,97.257059,109.391696,107.20394,57.017463,-41.916986,-88.185066,-134.365412,-143.086347,-174.802337,-177.91675,-41.70822,75.401001,214.461269,237.980247,247.135116,224.471609,175.409579,76.530628,93.898167,268.06276,364.095565,352.516501,311.14838,292.335366,220.317328,164.092513,58.947374,33.591229,30.422737,41.080927,34.827758,-24.189168,-54.301503,-58.482912,-42.676969,16.987683,108.142862,110.895115,-62.079989,-202.92282,-373.69963,-351.801886,-174.988174,-88.663684,11.379363,96.413077,142.556606,129.125769,34.542382,-183.896062,-197.256951,-27.151995,68.950328,58.079831,35.299685,8.254796,-112.861567,-154.976123,-57.864676,56.929639,187.388369,73.79916,-8.870228,-66.723325,-49.284299,-45.835765,-63.171467,-74.071894,-65.696049,-59.370444,-49.28301,-39.436746,-34.735736,-51.943244,5.425584,117.727242,325.378909,282.173869,214.825009,194.592554,240.553872,266.841537,240.008356,249.803332,341.26462,372.404244,295.116701,187.552453,-4.859528,-40.196295,43.331238,127.163731,210.93014,237.77026,261.756121,213.060041,138.878632,29.468216,29.475231,95.43253,137.873111,131.972037,80.359225,54.95712,32.932558,29.363748,34.89816,43.383552,46.098925,-3.564253,-55.681899,-165.872955,-198.213368,-209.039712,-167.485672,-3.476022,80.830404,80.101763,55.193206,44.300007,24.407493,3.63226,-37.983192,-35.864675,-23.040004,-93.576532,-146.908889,-229.835142,-244.957521,-203.842556,-157.428192,-110.04729,-121.425469,-94.334091,-28.672243,-35.376304,-85.014125,-86.750713,-7.179924,60.272719,159.927918,81.764875,-13.354141,-103.248741,-44.921255,73.545729,28.490339,-135.587859,-76.772692,-16.109246,22.402095,21.306108,-45.325228,-89.670186,-9.099004,90.196369,177.747467,119.323738,77.278097,-21.294471,-83.347639,-197.138188,-187.118738,18.42898,239.655733,297.30236,291.296935,220.559589,6.979126,-84.879489,-166.012645,-163.390337,-137.242049,-101.359016,-96.892844,-132.324532,-159.458001,-202.768096,-189.920526,-69.939043,17.980223,11.525184,-46.239732,-64.498855,-106.95223,-147.561526,-160.864463,-114.246266,-21.068234,-0.906298,-27.138176,-86.760642,-75.582647,-9.935504,3.683156,-54.795508,-139.550698,-123.368256,-59.703427,-74.476995,-150.491437,-175.061997,-127.992887,-35.732716,178.871244,179.471041,80.625975,-138.424413,-204.910713,-257.519172,-254.073989,-176.597364,19.266935,111.997681,77.887768,-30.807921,-151.395717,-134.327627,-95.435911,-94.801261,-84.978603,-115.427214,-165.202981,-261.738623,-283.412012,-253.218339,-197.977013,-40.210713,57.670081,29.894845,-146.492925,-199.185596,-106.478697,-32.357551,46.581474,74.999765,149.688379,242.121061,233.626882,35.116623,-76.34791,-153.876081,-139.500333,-129.600567,-157.210573,-133.492154,-6.317248,24.11661,-76.055862,-146.545361,-125.583943,-37.42294,69.719417,0.492353,-31.135809,-52.334646,-56.527982,-69.021226,-99.810982,-183.466181,-80.98588,37.826472,159.408725,123.173579,14.685749,-18.228483,-79.828652,-94.505971,-70.957781,31.404346,93.162197,127.905668,96.104085,-19.944302,-64.185395,-49.56365,12.496105,15.859213,-102.708462,-186.392265,-220.159214,-179.410386,-132.976824,-137.20567,-120.223092,-40.639179,-4.798814,-21.055464,-79.934772,-216.286104,-232.914586,-146.897385,-141.682062,-185.517835,-235.988772,-238.021624,-266.821882,-281.929016,-245.985297,-201.852959,-58.302302,65.560211,39.770008,-116.179279,-151.653789,-69.78308,-13.185109,16.724465,36.398932,54.558507,0.307643,-59.181336,-97.415039,-67.674506,-2.634037,0.984746,-30.258147,-9.267304,-1.694508,-72.55709,-133.334121,-219.603336,-222.220199,-161.271631,-114.433041,-109.448134,-83.544613,-60.495218,-86.367878,-153.981022,-252.942292,-244.851575:backward
-62.430163,-45.293608,-37.261107,-81.759482,-127.587341,-172.517733,-180.417106,-245.522182,-297.76884,-268.412113,-127.789943,-71.608458,-32.883262,-42.905964,-88.98186,-93.138214,-95.407676,-172.598697,-227.280019,-314.670032,-309.066,-200.192059,-148.171533,-149.061656,-200.685866,-189.195551,-213.357035,-290.371773,-341.929884,-252.78013,-33.985078,29.093685,35.957515,-41.434977,-59.307501,-24.536125,5.053353,1.157739,-22.244006,26.686449,144.588082,178.22861,231.244779,257.219028,256.842906,205.873288,25.111477,-50.75892,-57.568061,110.485044,181.481588,155.911561,121.347841,164.711263,185.111933,117.512965,18.757442,-9.045047,-14.120099,-7.234431,13.621137,25.332365,42.179273,48.187455,28.616092,28.513368,49.626156,1.167524,-83.526098,-248.93833,-288.453415,-285.320328,-214.027375,-133.130876,38.731219,69.657817,48.973348,40.506248,11.097132,-30.058798,-66.258283,65.665949,154.354797,282.395147,290.524825,134.790832,24.601849,-50.626192,34.205988,86.470361,175.661627,196.848005,154.20934,67.712827,-128.30999,-109.422714,187.097692,378.012262,341.222949,126.755828,33.528362,-95.85484,-155.007395,-187.063401,-39.637895,65.88925,193.730421,178.290669,98.366697,97.163153,120.48931,101.721742,43.376357,99.078466,148.498524,135.96618,82.768872,-5.803519,-22.056935,24.502815,71.553592,25.808223,-121.777083,-134.212472,-30.532759,12.680443,45.610544,68.467071,83.755528,20.594006,-10.565561,-59.094652,-74.701948,-118.050544,-159.0733,-184.159014,-71.722334,-5.154215,20.449452,-35.964131,-148.308705,-166.00961,-196.583173,-201.451512,-81.573267,95.566694,107.122553,-4.499352,-33.621667,-6.984468,-33.898729,-179.992443,-167.794823,-73.757941,94.130764,98.676706,-4.673918,-65.118751,-115.799622,-83.503362,0.571791,-15.519012,-49.800797,-86.699761,-73.982132,-57.523505,-78.466697,-130.821914,-113.175186,-74.718344,-14.10885,-28.707778,-117.759606,-162.503319,-207.214256,-181.462103,-70.985084,31.870948,88.557667,149.6159,117.416071,-16.267111,-51.708852,-28.485287,-5.48238,3.852107,39.602857,48.96332,82.626236,132.313223,207.945482,183.423988,30.324805,-33.094972,34.31872,198.196605,198.770248,72.462179,40.181482,91.750577,77.663803,59.532257,143.101295,195.029982,153.176848,61.523389,-129.521065,-156.975875,-128.040759,-175.285435,-179.888515,-139.448955,-130.110581,-104.619539,-85.103666,-36.9889,79.112908,137.955951,134.663384,74.882762,-44.723059,-75.788127,-89.451287,-79.606824,-53.048251,-26.801735,-18.228465,-63.628281,-99.846468,-116.221571,-91.567846,-20.857066,-1.717859,6.910959,41.547216,28.80237,-79.647859,-142.226195,-174.280955,-126.377605,-4.624572,57.446717,66.498297,42.414701,43.593707,73.975123,47.124252,-49.944491,-35.512567,1.888293,19.109772,-39.596812,-212.988863,-251.554883,-206.182076,-169.610059,-100.238934,-7.716945,19.395963,23.718574,32.449149,63.900991,66.322355,60.407137,52.169626,51.13626,44.735785,12.570674,-73.775623,-96.604159,-99.359283,-91.742714,-103.649882,-114.227056,-106.489469,-131.277135,-146.492453,-68.928741,-14.475017,-2.013238,-74.773761,-128.93169,-222.67838,-253.737721,-275.88535,-237.471836,-96.028395,-52.037997,-41.561995,-17.473775,15.840885,76.931512,90.275134,89.170996,66.924634,-41.361993,-136.857136,-130.300213,-22.870351,53.575757,171.422178,179.219395,90.247028,9.545501,-132.620512,-92.446524,-44.251736,-44.779058,-67.634701,-109.634928,-146.309961,-192.525814,-125.660147,-85.707583,-50.693953,-52.169848,-81.841743,-117.316062,-210.951485,-211.007299,-67.42822,38.98526,39.787859,1.728973,-31.111313,-160.770549,-239.390244,-312.681831,-243.080219,-145.891457,102.927482,164.37977,126.245487,76.814104,-69.440568,-143.271658,-168.833297,-104.546691,-67.771495,0.925412,7.438545,-66.64686,-133.262735,-250.893156,-294.993964,-298.972524,-292.374554,-284.55943,-250.016354,-203.9293,-95.686249,-90.341008,-175.350624,-119.049338,4.471738,200.305927,185.596163,20.709885,-49.476525,-97.043991,-57.68762,-10.033248,93.317358,132.46688,180.809475,163.320276,31.255391,-24.329514,5.408786,103.863417,118.120038,124.170218,167.883465,296.55302,321.441238,289.036405,269.787476,277.939987,273.813917,247.684698,225.518164,255.049664,310.97396,305.259035,240.344072,190.71374,201.589579,250.70061,263.00041,207.545667,146.996256,146.369714,332.914949,408.343889,442.223832,399.100924,281.371792,237.212086,143.752919,99.858146:79.184234,21.172945,-39.610666,-126.123145,-120.161794,-90.590384,-107.204423,-141.992981,-117.914714,-93.0599,-23.914242,-9.237199,-94.744085,-166.556058,-216.237507,-171.951916,-83.685228,-124.240027,-161.821771,-241.188247,-267.391766,-248.936632,-226.397006,-197.107292,-156.134124,-144.12085,-219.467579,-283.557364,-294.097388,-230.447021,-93.47925,-54.245616,-53.300709,-50.594206,-17.514431,5.55035,-36.108603,-125.22131,-117.960275,-7.929206,97.467867,127.369144,134.38766,110.157604,46.797428,23.920958,-10.38486,-38.117782,-83.315629,28.349527,107.00798,76.080337,5.921682,-31.058822,-30.775364,-75.238664,-59.403244,-28.333844,-0.360172,-15.967921,-77.507662,-104.680797,-80.90572,-33.767525,-11.988781,-51.678914,-51.571063,-124.590696,-212.406115,-328.058158,-333.955652,-307.6384,-214.893044,-149.745092,-66.766185,-66.317126,-101.755331,-110.202006,-125.422648,-137.974205,-122.95133,-24.508298,36.230324,89.227921,67.574588,-32.160751,-66.69553,-27.920103,54.127058,72.549758,61.150685,38.698352,-4.178192,-31.811061,-122.147875,-139.771967,-27.133981,142.030161,162.546209,18.020072,-93.045025,-236.040264,-241.741455,-115.322653,29.780337,56.587981,66.350028,60.68926,51.815072,56.252265,27.975886,-8.410479,-48.582811,25.84232,57.810351,4.807166,-36.562445,-94.117361,-133.744942,-175.512425,-105.267559,-87.872815,-137.293708,-148.767234,-82.40305,-40.922717,33.960511,69.921409,46.818,-69.287417,-88.443144,-55.039101,-56.722016,-145.162912,-190.567925,-158.987355,-17.38951,26.971168,-11.937094,-76.60443,-156.71502,-147.528543,-147.755269,-174.104218,-107.27692,150.341298,210.74563,67.136086,-40.469853,-143.346953,-149.3977,-136.59829,-45.671183,44.252505,186.978749,187.417126,60.954883,-19.924773,-61.61115,-5.034105,75.175413,27.822697,16.75295,14.933558,3.834027,-7.426491,9.718295,59.815286,97.138083,125.081373,150.664305,142.237945,120.584171,79.406376,-28.225924,-12.689279,148.323446,228.942599,208.348759,129.352262,90.401853,13.125363,-0.646927,38.421649,116.818115,154.417143,171.290299,159.595976,140.690285,121.144836,80.530221,78.880037,34.667176,-72.419236,-70.573796,40.178339,71.651284,-5.577267,-46.471639,35.777077,125.354804,90.378764,26.50576,41.380048,31.744385,-14.909959,-85.778912,-90.844532,-81.102267,-81.995559,-68.339013,-36.167559,-51.929097,-109.370385,-110.256385,-13.445321,146.092941,196.109761,186.801823,135.837726,20.041373,0.017422,50.497958,73.830271,21.828622,-42.99323,-31.674656,4.159695,-14.035866,-113.144933,-145.684022,-107.053893,2.879887,46.124212,60.026651,16.887755,-106.595368,-140.88514,-130.147601,-88.188598,33.037623,42.46558,-5.489032,-19.67424,49.445965,118.954911,35.508836,-179.073957,-87.074629,39.304554,83.178448,-50.757063,-303.381588,-317.102273,-234.026014,-191.881546,-79.523602,54.403713,96.263237,108.101888,97.197759,56.978742,21.792709,-3.242286,79.165892,112.367947,70.978755,12.731934,-68.223542,-80.23226,-68.391657,-46.981722,-49.827976,-117.407564,-138.765206,-179.42356,-181.031257,-77.476511,-23.14034,-31.006196,-70.75817,-67.377133,-77.071696,-102.375631,-131.213535,-126.350125,-76.17555,-36.80518,11.417465,51.793671,77.080648,173.185611,237.285593,241.166968,176.044953,74.259262,107.553657,154.838099,206.026516,185.412906,111.23034,98.637083,108.898724,89.213884,-32.350977,-104.610668,-69.490598,94.497496,152.781125,81.067156,-10.012759,-83.039579,18.407872,44.500227,-14.716453,-48.856935,-82.483454,-117.023258,-178.463259,-152.632067,-23.692146,72.816031,83.907396,35.166683,-13.491013,-136.927582,-192.82693,-229.42346,-179.356372,-132.802118,-34.43361,-2.731417,40.150499,43.590724,-93.364455,-203.142029,-212.745588,-61.731644,-55.22494,-70.70416,-46.053587,-77.317354,-149.536091,-238.468381,-251.412926,-270.637276,-278.372383,-268.487134,-261.579145,-239.440564,-158.141999,-127.95366,-67.008089,28.924251,83.843421,183.33494,189.599087,64.063673,-22.970261,-102.625352,-9.217789,78.523414,204.143908,221.723747,214.713523,176.457783,61.800856,38.51824,87.101978,136.865446,118.629056,71.272081,96.004007,199.85404,239.055,307.420345,365.046859,361.912429,263.729165,200.704433,170.346401,199.815994,224.603117,214.545445,237.9031,260.597607,245.86552,248.341038,279.449139,283.547318,219.491377,116.279288,235.532716,324.912656,373.99353,320.32414,212.182991,203.201763,219.132625,222.236976:-35.435016,-31.842713,-36.336639,-109.813707,-162.297962,-193.475046,-160.241983,-56.24023,15.183227,31.688286,32.029025,0.140014,-135.82396,-190.390502,-153.617851,-91.312998,-50.691085,-130.154157,-154.411892,-143.816469,-130.17973,-108.349336,-94.785254,-73.057621,-40.572323,-14.60971,-63.404535,-129.940341,-164.536679,-134.302032,-74.920546,-38.872408,14.504728,-46.74203,-93.146182,-119.617785,-112.39821,-143.358517,-165.181505,-109.360232,62.456069,124.599672,66.545971,-32.170457,-182.348116,-192.732661,-88.962111,-20.420833,2.078612,-10.059903,29.926729,85.638461,55.711262,-86.494244,-152.321147,-176.776851,-52.524731,22.536093,63.775804,13.453164,-132.95258,-195.264977,-245.007255,-212.421336,-141.675338,-225.265402,-276.121376,-260.969794,-232.963829,-263.09783,-296.809598,-288.061664,-184.364412,-142.413505,-104.497044,-83.735186,-57.897366,-66.931948,-81.710495,-80.36598,-61.651744,19.613854,75.171805,126.840812,84.621196,-94.622729,-143.877516,-85.730192,24.572935,67.631292,65.161268,12.548175,-86.719603,-112.011064,-157.887255,-173.384452,-147.013406,-31.344999,16.255922,-35.927944,-119.576442,-226.017034,-190.037964,-9.345953,38.008982,17.88794,33.211587,43.994994,-0.0799,-21.86353,13.550585,38.014995,-25.489444,-97.599638,-65.329338,15.668268,-11.075549,-157.286508,-188.280488,-127.617459,-59.361421,-39.741262,-21.484698,-37.114203,-118.537953,-159.845062,-163.049326,-115.199303,-12.129568,22.931636,11.886398,-99.507976,-176.317456,-268.20144,-271.081342,-203.513182,-99.803429,-93.044444,-198.340853,-238.742716,-200.935499,-189.300242,-310.823412,-363.986175,-251.751058,-13.001502,57.118201,4.190252,-74.360439,-181.023291,-191.072027,-157.050814,-79.638476,-6.595737,132.544855,124.695489,-39.592069,-90.244004,11.290439,75.194417,42.384053,0.007111,21.484909,43.958921,42.089023,86.002161,140.402872,226.884966,218.290238,218.101238,206.530019,175.966302,132.381036,128.626433,158.013411,190.912671,215.550319,195.437084,208.692494,231.99494,198.303952,83.185723,68.565713,119.245687,138.676691,141.583515,135.828998,117.576859,54.317994,27.126327,55.39695,111.645898,123.269762,-38.280151,-63.988503,14.82743,34.912505,-39.569675,-70.233833,43.831214,134.315447,66.318716,-83.423374,-63.075051,60.521114,54.801243,-126.879975,-199.287709,-108.973716,16.070179,-12.500341,-69.528421,-45.63917,-25.515947,-48.666839,9.114551,225.97216,298.910125,265.913738,160.470314,-101.709832,-156.594897,-44.048094,32.457068,15.471251,-58.539853,-45.344208,-29.413898,-57.226586,-106.670352,-98.918194,-70.666147,-66.655838,-39.433039,52.562302,54.883648,-59.823959,-123.070813,-165.84186,-130.962942,-7.459572,43.52623,32.920953,-11.999421,-45.318099,-137.856066,-168.015165,-174.337257,-109.107489,-21.724668,63.256803,-23.382035,-226.991995,-246.848577,-232.732138,-237.483904,-175.916829,-17.502733,15.018898,-44.891366,-81.023653,-102.661441,-94.811741,-66.146893,15.270248,58.361744,33.505772,-11.435941,-73.910934,-106.266266,-151.120377,-130.541079,-55.454413,-59.113062,-82.377015,-118.910471,-114.776833,-61.840519,-47.827988,-56.763465,-23.957503,-12.37825,-89.069586,-129.243426,-50.644883,3.923906,19.661618,41.578568,145.853821,216.205717,238.160627,283.537547,286.148608,167.47427,83.098863,103.490869,344.66785,422.668982,414.260695,365.36118,244.243393,185.037238,124.713616,114.297802,20.126929,-46.205755,5.295579,185.195027,229.546827,89.101197,-13.98309,10.045377,134.13127,143.299697,99.994802,58.210318,-26.950017,-48.705226,-47.180094,-27.191282,69.194711,165.927015,147.227988,43.525118,29.839797,8.205602,-59.127181,-218.37615,-134.721764,-22.593173,82.061016,62.289515,-17.818829,-84.352594,-200.707709,-185.331021,-18.952417,81.245034,58.424528,-41.957088,-88.131226,-183.424932,-222.286784,-218.477064,-150.917879,-120.600677,-59.607387,-54.933775,-167.045356,-229.695399,-209.979353,-146.572477,-23.595824,75.979928,113.183108,109.621802,84.33025,62.974088,58.258107,50.500128,137.695796,213.322404,278.522084,256.987357,251.615663,252.827505,153.468711,113.108099,165.487832,191.7599,157.1924,69.730524,40.0495,60.461425,115.422643,217.472514,258.800976,306.065401,396.658444,374.042466,225.115447,175.114346,160.355475,147.517765,140.449254,237.572532,270.851016,259.087538,252.928292,286.757322,290.98395,217.26116,228.484926,305.166157,373.887575,295.133825,91.905142,72.229052,165.646973,206.760906:48.654689,23.425989,13.383738,-32.81587,-70.219375,-158.505575,-216.216726,-293.559323,-249.068238,-200.147815,-120.578216,-111.513375,-140.664542,-166.380839,-200.529254,-178.590457,-107.317946,-102.939865,-117.309146,-188.762264,-222.171752,-203.297161,-161.109096,-88.325033,-69.355026,-65.669001,-103.920598,-146.44858,-127.783659,-66.695595,-1.533594,13.726544,75.136057,75.265125,35.654879,-58.009256,-88.390805,-122.101426,-132.227424,-107.916775,4.225076,73.418968,159.489327,153.173698,85.139479,68.068511,57.373519,26.891858,-68.898735,-27.012947,47.878551,113.462314,91.160033,49.328007,44.317934,41.059871,42.224723,74.450686,134.635656,86.206035,-126.913144,-218.345597,-254.005364,-192.961393,-105.363285,-236.400908,-302.731754,-301.073536,-276.173188,-309.805314,-361.060567,-388.751528,-261.288643,-184.830795,-85.236018,-63.525531,-42.114959,-34.691188,-32.300545,-39.051614,-37.542253,53.11774,124.315761,195.322685,163.938211,52.633571,18.382074,-16.000553,27.594081,104.670513,203.253102,159.452538,0.933389,-52.997073,-89.096073,-68.385051,24.563512,71.864848,63.901119,16.692593,-9.722574,-78.924914,-119.313201,-128.598409,-40.24225,17.858296,116.595918,135.013723,131.180629,120.496176,79.591049,56.729061,-13.835827,-39.860327,6.180493,130.961704,159.700122,108.470528,60.236772,12.335377,31.889104,40.3151,23.838033,8.472889,27.005339,48.830466,33.814525,7.205847,-44.561849,-28.352927,23.780761,43.204616,-30.237285,-176.073857,-188.262395,-121.78852,-29.868423,-1.143457,-32.850638,-83.598122,-148.583494,-158.652458,-222.842887,-257.964407,-196.129348,14.959746,96.236094,54.125012,-32.085151,-159.679035,-184.72782,-168.328667,-84.955075,-26.587717,88.615434,104.282728,56.310081,35.027663,7.959368,-7.5731,-29.245744,18.166179,54.776447,47.60169,1.006439,-84.88072,-74.715768,46.872593,91.831876,100.87237,175.946147,192.381862,107.593429,37.937235,-36.253924,-18.178261,73.042798,185.536046,240.735213,270.491088,230.714685,96.635198,48.589322,73.161116,123.90092,109.269733,85.896998,102.497719,135.744638,132.172705,126.808639,144.032123,119.627214,0.343588,-2.456973,95.441881,115.793955,50.56533,11.795168,39.80176,115.520922,95.936921,50.833543,81.435337,124.348035,79.719686,-62.301643,-90.307059,-8.555404,32.000462,-22.201363,-135.223089,-130.866253,-71.746614,-75.192,-70.646134,54.419524,120.298002,173.390716,143.309723,15.416704,-33.859584,-50.046588,-47.338399,-117.56586,-144.417881,-97.950193,-26.332492,-35.750903,-76.65001,-63.662153,21.751992,56.774433,65.16088,93.250047,58.026506,-132.783111,-218.127831,-259.471991,-213.921842,-51.89243,53.473179,55.107281,24.829522,24.275704,3.552374,-40.780544,-105.072314,-8.815299,68.263614,66.208821,-36.221405,-222.932638,-239.758548,-215.012553,-214.784995,-169.253721,-28.764442,18.56195,9.543563,-5.585755,18.256524,40.452445,57.58175,49.282443,53.983505,70.801044,47.11359,-68.411795,-110.282107,-106.461645,-88.981803,-98.241933,-133.371464,-123.311501,-77.395683,-68.856052,-83.721056,-95.972536,-100.251658,-82.880449,-84.224929,-117.787045,-136.153516,-120.684512,-95.062145,-56.398344,-39.564062,4.983042,86.701603,127.202336,162.465814,158.650333,109.42961,70.758816,37.102737,81.681918,102.689273,121.111254,139.413472,178.64284,166.123596,67.039487,0.959556,-147.827556,-232.825733,-196.338935,-29.110597,17.835273,-66.761763,-139.471933,-144.105091,-43.281023,-5.12691,48.594374,42.525995,-64.213055,-136.77587,-231.931925,-233.828798,-134.980437,23.396065,61.26869,55.167705,37.637715,-66.567126,-148.057488,-241.946365,-153.250021,-62.532711,47.404561,37.89319,-23.733173,-68.337116,-194.212948,-225.965224,-111.179557,62.433779,64.846356,-73.80369,-133.583496,-175.988412,-202.826634,-278.409908,-265.377295,-227.958597,-192.695709,-213.599555,-244.94363,-219.816952,-135.061478,-99.100892,-50.242659,6.978092,38.821599,69.752011,81.995162,106.638826,93.132366,44.099091,50.709946,73.955834,154.646101,200.66428,248.997761,212.295464,16.531323,-57.552257,-14.984707,96.910231,94.125071,27.037792,30.150635,122.54725,163.621116,195.601052,222.409254,235.628149,224.516597,201.529327,151.516622,122.948465,69.254212,68.628714,135.622068,181.479763,160.721379,119.554252,149.915478,251.088981,262.83533,220.915361,233.618609,286.431122,344.711416,296.974052,190.888168,179.524823,143.331496,117.276691:-24.757284,63.062469,89.176993,44.652587,-20.623234,-143.737813,-175.103835,-166.253606,-115.881142,-83.014492,-13.787251,-13.480382,-137.582319,-223.927242,-258.282798,-181.967429,-34.361737,-57.933686,-77.476908,-90.092997,-119.349546,-182.22925,-163.214432,-61.248502,-3.384501,23.771441,33.793541,-3.181387,-60.495201,-62.974092,-47.85222,-14.590757,91.618844,95.072844,56.392665,-16.392038,-70.842436,-214.084653,-231.983587,-120.70459,-11.593026,30.088841,80.228403,58.995526,-46.157331,-86.653381,-91.531774,-78.085261,-80.676403,9.38631,103.534475,178.706543,120.769956,-45.525631,-82.898967,-16.345211,96.817585,124.594653,111.004986,75.806116,-41.372533,-130.443427,-287.078764,-284.917063,-137.633058,-114.907109,-193.380969,-294.533971,-271.34217,-256.677952,-311.424338,-434.189292,-369.243527,-264.471162,-84.95731,-50.054795,-101.583183,-172.120279,-239.939853,-194.877444,-62.984848,1.421038,45.356322,114.755518,56.259463,-197.220221,-256.998107,-148.383542,30.843826,97.625165,82.190762,-7.942476,-194.411371,-231.642918,-184.317665,-131.667649,-41.663624,-25.095046,-49.520198,-125.890327,-170.38589,-251.637144,-251.092991,-152.414434,-59.57776,-12.829919,85.794875,100.135518,36.538512,-35.222745,-193.467465,-215.374088,-126.843793,-51.27796,-29.118999,40.332229,68.249687,50.41767,14.275758,-51.497628,-38.217323,-6.234839,20.75743,-3.275226,-106.370871,-168.153541,-221.93769,-192.388015,-54.560869,92.331474,117.858984,2.863842,-108.093051,-274.059895,-295.862208,-240.162185,-180.503338,-174.434263,-173.0137,-193.601119,-306.943384,-364.778264,-407.276372,-379.432419,-243.616368,-101.511205,-38.392087,13.589303,-18.103546,-136.902627,-179.421423,-182.433203,-113.786209,-44.537851,120.23683,151.184924,62.825358,-1.444464,-32.705787,-13.839384,-22.986898,-51.497122,-30.445319,34.405132,34.657488,-17.783761,-7.888705,129.203,218.174974,216.404938,181.158913,165.740905,127.458591,82.769509,22.451834,60.871478,207.263208,319.131716,365.318289,362.877323,295.267736,133.157579,89.398312,132.711672,223.440709,218.7699,121.092001,67.32689,14.129333,3.427545,-4.2896,19.944402,93.591757,106.925371,108.939036,111.695364,80.886949,-65.694345,-118.140653,-0.286617,143.884232,114.028896,58.212461,97.925429,153.658375,95.615491,-104.041776,-147.401772,-34.564368,82.221038,59.261543,-15.549993,-11.156559,-5.961076,-33.56629,-37.907775,74.532866,136.714401,178.684654,145.476677,29.298111,-27.858898,-95.150464,-91.771682,-31.289896,81.927851,111.636046,42.981297,1.56637,-21.895699,-16.626889,40.942366,142.47213,209.587184,300.457283,257.277198,42.686498,-31.498695,-41.243778,-16.63658,65.987829,201.629222,229.996571,131.079328,44.628662,-45.556211,-23.984082,41.854109,76.823199,139.50928,238.54351,187.580127,-27.746973,-111.199736,-189.986875,-184.880035,-65.796099,49.176985,47.772508,25.615821,25.865842,-13.998548,-24.641856,30.081889,76.344765,90.497818,117.15961,104.726269,-10.66533,-83.845719,-130.230188,-94.132418,-5.64098,29.378672,26.270718,-2.412312,-23.384048,-75.300904,-89.075915,-66.057906,-8.56321,30.565653,66.911966,46.970169,-6.947511,-38.666281,-61.636319,-21.672095,103.830971,211.685743,232.176631,170.902855,102.945114,-36.308583,-56.396057,61.00859,228.940118,280.598721,276.185332,232.500812,142.505843,84.701846,-88.972821,-147.222717,-126.867365,-66.371279,-56.900751,-64.07298,-84.449174,-188.778973,-224.032094,-129.173992,-7.484669,7.949088,-1.480745,-7.840988,-46.062375,-107.408596,-252.824859,-261.90518,-86.638054,126.451228,124.235578,-34.147273,-71.391238,-54.419102,-75.157434,-164.746576,-119.056633,-36.370558,30.434175,-29.71396,-196.219492,-259.312586,-336.588501,-318.712543,-114.434067,71.878936,38.880036,-170.503449,-241.773279,-276.750748,-286.016831,-306.600575,-226.894699,-159.849094,-101.829886,-119.000133,-174.196122,-200.470937,-209.56761,-165.061547,0.659843,120.545277,114.796057,46.664005,47.265237,84.305863,75.706957,70.369642,167.15308,219.466813,273.992121,276.486497,236.02532,193.264167,111.113221,104.539306,158.741304,246.115106,258.878254,116.013564,22.215467,33.424118,120.095608,215.114743,217.330871,268.731125,374.415795,337.213678,132.948343,63.296594,79.622938,116.004968,157.398556,243.861008,285.114289,300.703861,294.319367,267.957897,258.551195,280.264288,338.060409,390.427018,490.357843,485.696438,354.667469,287.517018,242.590934,243.88228:-2.703649,79.294818,70.373296,-17.955039,-74.535918,-170.460921,-202.06237,-259.33106,-301.380896,-280.041529,-137.247388,-76.243876,-93.459068,-129.002551,-107.660691,-52.079393,15.322843,-41.563634,-101.735632,-232.63847,-245.128622,-130.029445,-64.586121,-41.143059,-97.824375,-82.712744,-12.25492,-29.608181,-73.419388,-31.826147,41.398015,29.563918,21.739616,82.034168,107.25449,94.232602,55.378215,-29.329515,-56.252136,-39.932096,73.591343,122.260226,179.254652,207.345218,210.73231,145.724871,-45.09763,-87.982942,-3.924216,153.827114,198.604719,195.612923,192.492274,253.786889,284.101697,261.649311,197.047044,186.39725,149.722865,96.719827,-33.329936,-88.918893,-133.516758,-111.933923,-55.931237,-47.129909,-58.463893,-138.051298,-185.093869,-228.816522,-244.702314,-277.263165,-227.863374,-168.044815,-39.161942,5.184459,59.753106,64.119143,16.61337,-1.658987,42.992171,184.469815,256.476944,300.178081,266.360088,131.034441,48.722922,-42.404107,13.503155,53.054775,77.557239,48.973009,-25.30585,-27.743245,33.291748,89.273499,226.282953,302.957713,288.515769,159.182416,93.329218,-4.672433,-58.895528,-107.871845,-8.073422,49.302496,123.357136,170.069743,317.869882,364.442277,267.544701,167.677702,67.856387,97.227621,107.882131,102.208201,110.967518,163.775649,173.807217,125.743381,65.2292,60.861741,107.764758,114.041773,9.275363,-59.076589,-67.231615,-21.224922,3.100826,-29.732232,-35.885568,-77.779058,-113.111498,-193.867197,-240.467837,-252.837629,-88.220058,-5.454699,29.396763,-2.772329,-84.228201,-118.188209,-192.049919,-236.883835,-249.261627,-57.468094,42.987318,32.404932,-28.894602,-86.822126,-112.832073,-190.581731,-142.392227,-61.090829,96.202205,132.312806,109.927782,59.89284,-80.553184,-136.713629,-177.021414,-111.0579,-57.231993,-17.326968,-51.530223,-202.108922,-253.435881,-185.228194,-81.444136,-46.218135,54.756559,70.360488,-40.763224,-103.806562,-84.390759,-12.806538,93.134961,105.809332,135.005568,224.988272,224.082802,108.657289,49.863254,46.283923,174.399818,212.780729,123.448366,53.91374,52.720282,97.578631,122.86019,91.006214,3.989177,55.211586,140.537261,236.326357,189.773441,-6.234115,-53.670713,22.112697,43.419459,18.109746,55.267768,108.581116,121.660078,46.589534,-136.362195,-166.592813,-123.743759,-129.528834,-158.936468,-227.989126,-251.42816,-244.717845,-226.913462,-173.710877,-66.278665,5.827031,96.31966,69.866834,-96.116248,-177.160808,-248.703956,-238.197242,-147.976238,-3.638607,45.761974,32.905729,2.839604,-5.164621,19.264573,83.820172,143.016384,167.294595,170.157806,120.392531,-41.024726,-96.322347,-97.722665,-55.299957,71.077367,168.807194,167.040427,84.845067,63.436273,93.546418,101.688993,82.023962,61.286543,60.040833,59.401419,32.846306,-62.883255,-79.497783,6.866288,66.155195,107.254874,81.471732,72.706834,71.924128,95.312267,169.798392,187.202759,168.081577,149.762477,156.981265,146.66186,111.918353,16.032554,-23.771213,-62.92321,-70.485653,-62.496609,48.997113,113.671819,109.996481,67.412506,31.419273,28.691525,19.978396,52.50198,81.054168,83.181852,41.679007,-35.968125,-44.792915,-41.86004,-33.671854,9.761739,19.84512,1.202653,-17.625823,-4.567724,-3.517621,-29.754738,-33.474033,41.69056,52.233181,-1.432997,-26.571453,5.284563,27.066545,-9.30178,-60.148416,-202.455138,-276.364596,-251.421425,-198.673442,-216.403198,-290.449166,-309.359305,-292.560474,-222.400114,-173.05351,-83.297175,-71.139533,-148.983942,-222.387072,-340.18028,-330.926666,-166.133263,-1.686701,29.290371,-33.583976,-98.696868,-182.423635,-188.019033,-169.102391,-158.783075,-136.564489,-8.752349,42.756203,-26.98986,-109.979748,-196.908857,-187.027078,-135.35181,-114.697776,-117.751527,-130.997771,-148.807791,-241.216632,-303.141588,-401.305381,-421.301124,-387.646594,-302.507536,-278.326073,-193.373227,-124.750162,-71.754483,-100.143362,-155.313475,-120.090633,-61.408674,43.03537,45.72156,-15.744486,-28.832082,13.531662,31.866702,48.34093,151.127273,189.150056,182.47713,149.917559,53.30772,32.283601,76.746766,92.829863,73.304715,44.716988,66.396689,142.346005,165.830995,195.664931,228.981618,249.955892,242.374852,199.408777,137.809811,151.656426,196.38663,187.878865,113.42838,36.698083,29.706054,126.219946,193.13834,227.124641,197.277239,174.093361,249.69852,298.422181,333.372553,291.172073,193.438212,179.09961,155.681215,137.813571:1.05817,124.393095,121.576441,-0.160715,-74.017962,-189.679962,-241.265929,-331.816762,-314.529174,-242.627551,-86.430747,-53.882959,-81.290786,-133.130008,-223.940832,-195.324063,-51.765476,-29.528389,-62.787124,-154.931498,-187.880024,-187.933527,-158.689671,-53.901008,20.17858,15.036971,-36.594668,-51.818727,-23.964061,-2.242265,-13.049512,-19.459751,37.956947,108.301121,110.363532,43.289245,-12.923958,-129.3954,-163.635633,-127.131446,38.403978,124.287771,183.494848,149.324434,39.038061,-10.081453,-76.309719,-77.141017,11.945603,149.543805,181.034467,135.483672,108.520312,115.418304,120.578676,109.068143,130.441057,159.467975,158.830257,102.684181,-62.947941,-157.371384,-302.913933,-290.93679,-151.476746,-135.973903,-175.989666,-216.685551,-222.320482,-290.031103,-338.007015,-355.997434,-280.289032,-248.393013,-189.579443,-147.417684,-73.271786,-66.697643,-90.643156,-86.927267,-35.436099,54.705315,103.447551,129.729732,80.329623,-105.508508,-172.237416,-141.464504,-9.231077,48.973667,95.852,57.828164,-78.073217,-113.706547,-84.84788,-40.304296,71.081318,143.563511,145.368119,78.556858,25.46846,-87.711225,-135.070462,-135.625592,-8.602968,65.512849,189.700933,221.55884,177.703604,108.752612,-2.72301,6.900906,109.910683,162.81653,152.693125,97.073209,68.403657,3.00823,-23.76034,9.112643,78.117599,82.143194,72.710809,61.233352,-8.616193,-45.790985,-57.470472,-46.728358,-51.498663,7.565122,45.714789,-29.595432,-120.922095,-278.105171,-331.303118,-300.251852,-79.282837,12.42826,7.763146,-71.762966,-227.592528,-274.666744,-326.16928,-312.729944,-179.00716,46.059371,142.153672,123.676013,29.947488,-142.333311,-196.873817,-222.31454,-134.374391,-53.947904,109.303038,137.398835,38.651015,-57.953508,-211.620025,-218.219038,-102.67572,17.621368,51.277851,60.374293,20.627767,-133.94594,-183.043394,-87.588938,103.925132,167.980516,204.563537,164.397182,23.417921,-23.629567,-18.495507,26.37242,154.472772,296.629515,351.77898,307.705923,213.729587,62.004169,55.116565,150.460011,221.546968,215.371323,160.863615,130.096525,99.307211,94.091058,56.176576,26.646657,20.994682,130.581729,197.519629,231.777024,175.578422,-1.325535,-60.541145,-40.792607,53.456158,97.006863,222.92289,282.745586,219.092565,83.293472,-166.315085,-185.281491,-26.704724,88.555399,65.629721,-31.51545,-49.006993,-54.532474,-69.381236,-23.898198,163.192701,227.590555,186.848649,115.273143,-9.68928,-45.490469,-83.657068,-93.585117,-88.654858,-15.953166,27.982454,42.620294,22.237471,9.624783,29.617751,110.246528,203.131438,256.2192,323.302648,285.576767,100.474128,6.875114,-122.411735,-127.078442,17.686295,182.081774,221.62423,238.997034,219.573162,135.114099,93.025065,40.048498,72.340523,145.839925,251.165305,207.277822,-12.399825,-104.230761,-136.140519,-97.328183,-7.347578,48.02863,45.456671,8.777962,5.390352,7.746124,11.080209,78.744664,145.473739,148.508354,153.702231,152.471736,75.828355,9.094702,-80.915058,-72.62688,24.702692,94.501188,104.539399,108.449836,91.800478,8.637134,-27.68598,-34.155629,22.670442,73.539416,131.038735,94.956646,-34.992473,-80.859226,-100.864552,-73.750952,53.138317,178.706055,184.889522,94.69814,38.924753,-61.051099,-95.341558,-87.710412,-31.736148,-3.429983,20.750818,9.812191,-18.809981,-52.0368,-197.414627,-265.038004,-290.245728,-218.065478,-189.254999,-200.297438,-233.639645,-323.340292,-347.612327,-264.568165,-101.029722,-42.820978,-34.099495,-75.506775,-173.298918,-238.565629,-390.764346,-408.274154,-231.891896,17.419753,60.098574,-25.235824,-82.87264,-175.10497,-215.567165,-211.786882,-116.592797,-53.272515,50.46308,39.221185,-125.278023,-233.930488,-365.610024,-345.85784,-143.228488,16.820691,-9.294838,-160.828063,-207.86071,-267.438058,-322.984937,-433.56988,-401.074632,-336.454476,-246.578763,-247.214952,-258.663762,-235.854041,-153.562027,-122.99369,-79.528467,21.612948,62.168808,64.606198,40.246128,-51.468858,-94.735187,-55.138593,119.611658,215.641316,323.679171,304.672483,187.174088,114.33854,-27.067269,-46.97284,68.363423,201.956645,210.724357,125.912245,64.182307,-11.398281,-11.719268,70.36496,229.918914,288.756071,294.688367,255.418264,147.225695,90.509415,47.909472,70.805603,137.379656,240.59798,284.332873,242.496524,185.665813,142.244159,156.246698,212.163498,317.155336,382.451688,420.798743,372.584668,273.848643,261.199814,261.057232,255.906533:-2.874364,100.072087,102.323433,12.409615,-2.97163,30.108154,14.368593,-99.496583,-154.598036,-120.245328,14.621263,78.603991,175.535445,209.752493,216.20045,201.407496,177.086281,90.127533,26.157247,-32.519229,18.145685,219.265469,292.69364,327.754536,280.512049,242.215008,134.92256,71.270733,30.681612,68.258449,132.616608,141.908948,178.180719,188.057324,161.497529,114.829945,117.249457,96.082804,40.351967,-37.573666,62.652369,109.12161,83.921283,56.781581,57.331191,49.731248,-42.587343,-90.737564,-83.149846,34.43242,87.85912,131.230784,142.102761,206.652982,243.819903,241.949709,184.397706,176.54791,176.969029,175.983337,197.438544,201.061378,181.485088,186.53967,197.776232,129.279787,76.837217,-27.301474,-47.630832,-23.286601,-15.8983,-2.763576,52.538747,77.588977,101.156724,112.799382,166.209367,190.160505,180.5505,159.315411,131.447801,161.612071,204.377322,278.495671,280.613204,183.169637,94.93195,-8.729405,85.471363,145.411933,174.109586,152.253233,127.138239,138.601667,204.919731,263.455123,353.795799,356.38584,356.030932,317.374976,263.837893,144.315243,93.294012,17.330822,19.367703,84.442902,307.829605,390.939681,436.013984,430.917086,413.020498,398.612314,319.695174,225.386292,219.156609,239.647434,243.417428,210.213746,168.162883,107.382518,91.776294,77.212607,45.987982,35.804839,-12.286298,-61.56338,-132.806746,-121.850589,-101.668272,-163.832601,-187.75144,-222.105848,-249.660805,-339.037397,-392.641944,-397.281243,-173.188697,-42.981619,57.777289,23.059747,-64.930575,-83.514694,-154.245489,-208.294505,-209.468487,-111.314839,-100.820624,-123.242214,-95.288724,-6.362381,-26.531898,-188.573561,-231.231378,-151.712819,69.389947,119.90047,29.88616,-69.280253,-201.817208,-183.246582,-73.312992,-70.061555,-83.14103,-62.463233,-49.384753,-76.732303,-116.043152,-204.824802,-258.201006,-231.990946,-73.611626,-37.884872,-177.468118,-254.888566,-218.387402,-142.61661,-25.167593,18.161325,35.058218,41.471812,20.900269,-32.738665,-58.720213,-67.059759,5.292939,13.346586,-53.706621,-85.201567,-86.280634,-58.333913,2.16187,11.721503,-36.482341,-112.829311,-99.992147,20.244358,42.270325,-120.526029,-219.214404,-226.251074,-156.962556,-136.333002,-40.424203,14.284484,14.334904,-51.487244,-205.483085,-235.007402,-202.757696,-173.477288,-160.677249,-134.566511,-139.090662,-183.803804,-190.898234,-125.481328,-57.458586,-39.66744,15.063997,35.567608,-11.240134,-81.375951,-231.526147,-247.113688,-104.269902,99.987497,150.174801,117.177018,82.328737,72.902339,88.938035,137.517065,215.311275,246.313607,186.378288,79.724814,-136.208843,-172.172813,-101.634712,-46.075309,33.890015,56.781222,40.215032,10.064351,39.149916,151.584324,168.741981,94.807432,50.165411,44.873517,29.106748,30.911184,80.669819,128.702633,197.580381,200.367904,179.270798,154.484704,154.975496,225.758343,282.624237,323.399237,312.940646,312.602737,228.730951,175.486079,183.37898,206.699634,178.395807,137.848184,82.134029,91.880985,166.715841,225.754511,240.820199,277.117031,311.239398,359.892405,343.976825,240.487563,124.832102,94.560365,122.689603,174.375405,258.146225,242.67017,133.40343,107.689109,128.098414,62.149208,-4.06923,-78.231285,-77.311775,-90.157658,-107.266996,-93.350612,-97.33169,-124.12476,-90.386376,-23.881713,41.434156,2.381117,-140.962438,-193.941645,-245.231943,-293.163288,-294.470791,-241.758766,-222.499572,-242.576533,-260.372263,-205.261377,-74.814099,-45.008638,-58.687266,-81.577976,-152.135203,-196.063318,-277.443964,-289.249594,-222.020584,-102.773212,-53.149129,-63.799721,-106.134237,-134.084191,-133.374769,-157.688186,-106.96506,-31.062615,112.596515,123.648339,56.343584,23.178628,-49.402538,-93.443119,-116.77492,-104.606468,-129.04845,-200.475007,-236.029869,-316.878128,-364.312555,-460.296797,-460.715599,-405.233671,-304.175365,-292.509232,-225.604313,-141.524718,-36.476934,-64.637294,-175.211596,-147.317235,-71.395073,23.999121,0.783751,-76.960077,-89.609594,-72.869863,-35.768288,-4.770875,70.903939,87.210505,74.189816,58.470324,6.276089,-25.821974,-58.175767,-13.95082,24.321202,55.797193,52.641013,77.120739,96.552743,100.501351,86.663479,85.607456,94.209482,97.338258,92.374803,62.93463,-89.536794,-151.969026,-101.924431,19.101611,58.234197,103.95063,111.938259,104.275956,77.23763,39.105432,136.186991,189.169599,218.141485,195.018965,87.202547,28.931652,-22.481066,1.21602:-19.50491,28.515227,34.957019,-0.617801,-16.197885,-19.909013,-31.852428,-105.833227,-142.446182,-104.550133,36.682634,87.8832,137.205612,154.430683,147.92999,126.100748,84.514873,15.034842,-40.681786,-124.036596,-107.561743,61.376634,170.164386,291.20608,182.73321,70.800863,-119.529095,-153.10639,-75.797104,-11.994411,70.731246,118.343261,229.497084,222.011484,194.675028,218.957892,253.138452,187.293278,85.466446,-5.698388,106.352109,158.524569,205.670995,213.284184,226.116843,216.080752,79.977591,-26.972226,-134.523916,1.212527,90.867696,159.676184,168.72377,205.885393,203.376061,124.805463,35.535906,30.120358,52.856357,39.733394,41.009569,93.961085,246.537179,293.297843,247.474376,165.806129,164.833933,132.572043,91.684466,33.866215,12.976076,-8.656675,17.248488,52.149431,166.306907,233.485025,350.68375,364.903349,241.841939,152.297935,98.721741,208.53367,256.167338,304.790999,324.823983,318.80199,277.405759,151.550662,88.988077,125.65785,240.343058,255.263626,233.897967,234.657844,272.6319,315.416301,403.449437,411.337278,370.535854,205.686295,133.439916,71.569274,37.180637,-22.02468,107.844412,201.640719,295.371962,315.399991,375.399743,398.314442,379.446954,343.200003,238.647724,185.524672,211.108366,285.851576,281.067393,163.506604,102.87619,71.632023,40.255468,13.993161,72.148526,135.337292,174.819726,148.550476,106.315119,110.865982,77.788269,-37.516398,-75.129429,-146.184288,-200.607173,-282.376564,-291.098764,-247.023961,-136.983665,-75.641375,12.688104,21.822745,-36.663607,-90.318882,-207.333061,-242.61635,-206.501226,-123.506677,-121.980182,-130.82244,-76.14888,28.794278,-31.041852,-261.279049,-210.910027,-101.50841,15.718377,22.77727,41.32424,7.10279,-177.407682,-220.283887,-163.126153,-123.055998,-89.064389,-10.642313,-16.456044,-122.090798,-178.305505,-232.068563,-263.017907,-273.109375,-239.741583,-223.336185,-253.51881,-287.601083,-300.365027,-248.066156,-140.038211,-103.200998,-54.498079,36.440661,20.170004,-92.035262,-134.541081,-120.652474,-54.40633,-57.052049,-126.604019,-166.396755,-174.200135,-108.094691,51.503991,44.0732,-118.765103,-126.626366,-46.244019,77.58745,66.542755,-25.427339,-36.856608,34.502919,36.934156,5.478654,4.778971,27.730212,-11.654811,-89.507774,-253.80205,-290.963887,-277.54836,-260.812473,-266.895958,-297.209711,-298.406711,-221.389545,-157.662792,-63.378317,-66.153068,-63.77939,-11.066015,-12.025012,-69.127377,-88.648742,-174.909729,-239.220497,-253.640603,-101.651772,-20.831819,28.374193,-0.564793,-61.836154,-68.983916,-33.70131,-5.526683,-2.860992,-11.978239,-42.605937,-133.950488,-151.827073,-122.248215,-105.50499,-78.68319,-17.077447,-2.809854,-15.158008,-7.596387,7.206567,-13.268439,-50.387319,-20.347108,-13.117686,-55.526336,-106.506553,-182.82016,-164.525055,-95.425321,-88.887021,-66.366523,42.072381,76.920975,52.484778,45.432863,112.722893,145.639645,129.148235,75.429532,66.510285,69.950687,66.174208,39.50853,16.515298,-37.659152,-47.908442,-8.037007,59.78349,64.017648,-20.379379,-47.841997,11.696733,27.745463,-48.89889,-113.667286,-136.981194,-165.032399,-138.62555,-6.127466,52.984491,45.936461,15.41065,23.987603,38.773448,17.847858,-34.494195,-40.064227,-6.121847,7.5181,4.15676,-31.29119,-58.358582,-85.672511,-64.852769,43.533904,94.158034,81.984101,12.546824,-154.81132,-198.580178,-176.372476,-151.557099,-167.748135,-222.87948,-227.842296,-158.357625,-90.727794,-73.167928,-27.14709,-13.872496,-48.254042,-80.685935,-160.918073,-190.877926,-166.922074,-68.279249,-27.178681,-30.590816,-62.561757,-131.575149,-171.716666,-217.431704,-119.03677,-7.308193,209.282777,245.177416,184.171218,133.97583,27.567908,-24.54143,-69.587656,-59.839678,-36.458067,26.987807,15.179802,-128.723569,-199.129238,-255.722938,-292.876897,-300.161485,-257.468829,-240.086285,-203.333053,-139.980591,4.990247,21.442291,-34.04922,-3.087159,51.567238,71.419821,18.87679,-83.900794,-94.025958,-47.667969,-34.877346,-24.191583,111.363906,198.239064,225.108858,166.435769,66.054731,49.707405,12.188894,-13.084873,10.663546,104.598811,154.560341,188.83458,175.302735,194.550797,238.749011,245.170681,240.057574,211.628406,135.25707,137.88281,200.775415,194.856899,75.136722,2.522554,24.535608,88.476513,109.372621,124.928592,99.07113,47.220338,68.730576,96.115497,189.641289,210.417995,123.761654,49.801451,-63.018893,-76.758564:-5.431958,97.437016,101.227759,-5.634518,-79.673805,-207.588421,-250.67095,-264.627659,-256.093255,-257.289274,-181.977361,-107.521204,-5.117492,3.48247,7.394402,33.88175,55.735966,-12.68002,-31.556581,-82.683833,-112.874891,-67.372179,-3.515202,79.616287,39.251757,17.169681,20.467148,12.547535,15.785261,58.396687,127.084529,108.053244,34.173494,34.49431,44.734996,-2.875142,-67.944937,-205.181076,-227.989818,-107.696329,82.612309,125.410135,110.003946,97.782446,98.023782,54.984117,-126.921187,-158.834459,-19.017734,124.20784,142.53569,122.469201,132.3928,221.464851,259.186747,261.035211,197.632219,192.136349,252.850919,233.465992,35.109125,-52.576398,-62.082702,-11.610886,22.761937,-97.436672,-154.091027,-196.351313,-184.157149,-138.211692,-141.064186,-160.283122,-92.70315,-57.374037,0.914503,30.651428,33.221471,8.823931,-13.380527,2.786302,55.170115,88.204348,93.765407,69.596081,54.184624,47.981851,29.367965,-24.860009,14.591991,39.438643,13.112884,-20.137695,-37.479933,-6.580492,86.539559,132.240008,217.359167,219.963575,181.14021,118.380628,106.967297,55.436298,15.875454,-5.377176,16.591253,18.605838,86.959041,160.070675,297.683757,328.029043,288.414842,255.14089,229.054119,204.404797,175.385746,134.112086,150.729208,201.104675,198.578353,187.600226,186.877624,169.247457,128.862135,109.759704,47.288964,-4.794379,-127.083841,-174.886229,-205.546587,-86.45414,-18.995768,-40.031541,-103.015516,-192.088977,-209.384103,-205.072599,-116.318584,-40.859322,88.387652,111.853966,72.990623,9.390442,-164.113818,-204.946576,-139.328048,-72.117422,-55.823408,-2.963374,17.41412,-54.564051,-133.849112,-187.56041,-57.564954,-3.535152,50.276887,75.430527,52.812209,-21.173983,-189.83299,-218.649592,-158.523841,-62.636138,4.708645,76.521419,22.425596,-179.880341,-242.297276,-231.813674,-135.327895,-44.70464,146.371096,148.274144,-61.280785,-163.985506,-166.966498,-94.89288,12.52847,47.699292,99.356049,198.314679,180.988545,66.89246,38.338305,96.220232,111.849357,63.987915,-6.580837,-10.637421,18.805016,32.566208,13.780205,10.574829,20.362456,3.376315,25.804907,71.671354,29.199512,-139.588076,-200.479599,-165.609113,-35.897836,-12.729462,32.079337,73.564691,65.401552,-9.804621,-227.723199,-294.902388,-213.049306,-21.373222,14.67549,-58.453281,-99.59293,-92.023804,-86.265655,-103.056265,-31.851465,18.411175,81.137404,89.970123,18.90502,-69.752895,-210.174618,-197.591985,-96.198137,4.91858,58.425625,97.907906,88.230347,90.169858,111.656208,173.968375,177.949602,166.65233,180.709008,161.48063,-23.837062,-126.185437,-142.349145,-63.84671,77.319588,81.960246,66.084803,54.08001,48.223506,0.895029,-31.980979,-68.311197,-12.577931,46.649664,113.045032,90.739329,33.935968,42.791484,43.859431,0.872393,-61.150945,51.092181,153.71335,306.5181,313.144748,174.13094,91.840687,78.414282,135.729823,140.996951,136.792682,115.82301,56.141197,40.18345,29.37986,41.873659,131.324338,259.301758,306.117598,281.716905,224.869006,174.459252,188.294484,186.981282,180.008897,175.040035,122.601911,100.328623,90.854165,69.316986,4.979318,12.595128,74.981807,60.492674,39.322586,23.195894,21.10581,-25.651591,-51.101228,-24.587063,-46.69924,-107.011259,-167.81596,-136.3707,-60.630741,-59.123207,-107.499863,-137.439298,-197.186651,-198.423117,-166.826638,-107.23283,-101.057748,-146.317118,-164.728526,-142.800312,-107.644476,-75.127593,-19.227899,-36.957845,-153.154128,-232.832617,-352.913127,-342.962322,-163.909823,8.706326,26.711223,-0.668952,4.690081,9.863481,-24.20841,-75.069064,14.68907,88.462326,146.749041,106.655988,-35.927498,-100.553109,-151.331503,-129.53675,-50.797147,-13.625732,-21.640904,-87.854795,-144.01394,-274.81393,-328.975058,-392.393113,-381.088714,-339.258984,-240.321111,-202.648141,-105.150061,-49.901119,10.424451,19.169857,21.355713,43.063747,73.984507,95.93505,63.498387,12.179814,8.370321,-7.39551,38.891167,93.688019,178.498699,178.194473,101.987597,57.244523,12.575447,11.094906,-1.037042,22.053581,56.980436,79.703638,77.844309,103.677797,101.934702,75.338097,130.295471,172.97086,188.055137,143.961232,32.456641,0.892358,-8.601944,3.975759,46.159198,91.601479,107.794666,142.027605,161.232755,133.14611,86.95032,88.640701,225.960696,289.35361,314.264792,236.44662,51.791199,49.590433,152.484296,170.550278:backward
-198.513441,-100.916539,-56.289815,-10.695831,-4.525646,32.952048,53.478494,56.312087,14.520483,-38.690336,-146.808069,-164.993895,-127.32042,-91.587634,-57.1771,-65.683829,-87.857482,-38.630288,28.373893,94.252751,45.809746,-40.879195,-7.076025,143.20321,213.114669,189.577396,63.528464,-20.253451,-193.676116,-251.220158,-254.175605,-215.457133,-88.731216,56.760046,98.792236,101.729169,72.544716,51.853563,100.069703,246.8669,336.892557,350.985725,341.027862,331.415641,272.642419,220.776915,160.42029,172.546896,184.975616,49.271526,-19.506367,-94.451295,-151.330786,-269.898344,-268.554354,-157.070785,-36.833758,-10.432112,-8.349179,7.795628,80.776305,124.574338,203.962029,220.271251,180.749061,64.413151,11.92175,-25.999845,-36.504434,-113.311108,-157.461077,-108.435774,65.911138,83.697012,-65.085111,-165.900898,-281.126568,-270.677616,-176.436062,-135.890577,-63.284332,33.398034,59.004615,-18.406901,-104.870172,-205.535158,-194.178055,-134.116963,-40.661596,24.214366,135.313385,156.747686,120.282123,97.337635,141.194703,191.547009,231.322906,144.103705,101.9641,126.899765,164.746856,158.410857,132.071497,163.250825,248.773774,249.785625,167.106222,128.303891,69.750726,27.484167,-13.498665,13.748255,111.948718,196.621794,205.607525,139.969631,84.844409,3.679423,-9.624195,-14.757854,14.880635,28.51518,6.056976,-22.035584,-95.345756,-118.977132,-84.209372,-45.350211,-6.068514,-50.740206,-82.538229,-134.702172,-157.937405,-128.017192,-65.02621,-6.121768,-104.920419,-143.729546,-93.987793,-43.372988,-95.528679,-176.521559,-193.426439,-129.235384,-26.772302,1.451016,11.187154,28.81067,16.843688,-41.689895,-84.235543,-187.277163,-173.454074,-103.936462,41.472282,50.372353,-106.204931,-203.172309,-270.657232,-241.133383,-170.137976,-186.66657,-181.647801,-82.532792,-40.49738,-10.508425,7.247564,51.039328,132.841518,194.388812,266.848163,234.777186,77.593698,44.208624,141.128889,194.575662,188.268761,125.689793,102.718556,47.862978,29.901757,56.979953,73.959725,61.961308,59.198085,64.24478,27.413935,-9.009517,-57.716911,-41.720566,66.54396,119.951402,211.625738,274.410561,263.310656,136.267197,34.548496,-98.418508,-69.683388,126.232664,270.56575,261.846792,195.908282,191.848695,179.444693,164.144491,189.530633,222.737457,226.012601,88.773277,5.749308,-88.34712,-88.9419,-26.989854,7.011279,32.482097,12.315874,-19.373534,-76.8595,-73.71509,-7.588218,50.678379,183.313418,229.04759,256.76672,173.597135,90.861968,-35.026287,-33.284116,66.06288,117.168499,219.093152,360.662136,371.169262,233.782287,176.061324,204.396829,269.754542,395.726157,422.11633,423.006162,377.140871,330.229487,247.700581,222.554931,212.297433,228.516918,254.317843,215.847211,173.859817,125.548011,128.205186,111.964339,104.299078,126.624136,131.452221,103.711283,36.206063,-11.456028,-133.564768,-214.843622,-338.90891,-329.017547,-149.904948,9.584775,-4.580351,-89.752067,-99.391197,-169.663321,-248.107156,-317.959631,-284.024343,-198.234758,-213.893267,-238.105908,-201.376253,-149.163756,-77.780657,-79.237181,-152.062511,-184.209837,-166.811512,-164.166991,-199.427485,-310.142233,-340.462955,-301.319542,-255.917592,-141.333021,-72.814683,-109.969107,-263.48237,-315.885599,-336.921259,-337.437841,-352.303453,-248.302848,-163.642219,-112.740736,-172.650733,-371.748043,-429.800674,-395.694474,-357.829352,-294.90884,-193.568367,-130.830527,-84.662527,-123.886501,-190.72574,-164.002879,-45.24877,28.416697,25.775878,-4.183025,-3.765058,-26.922203,-48.963812,-7.100887,53.83107,116.138566,7.504218,-46.359116,-56.248464,-46.01605,-58.222706,-72.185386,-77.802854,-15.916107,13.182657,14.168936,-13.790817,-130.348005,-172.554595,-105.486988,-34.814938,27.382627,-54.040739,-113.065202,-201.132939,-239.99664,-272.645023,-236.944757,-121.61458,-67.337515,-55.005574,-37.068486,-41.465624,-50.68436,-46.283785,-56.591677,-68.246551,-43.841898,19.901748,21.002602,-70.372801,-126.021488,-147.882154,-111.55884,10.175107,101.206874,98.577918,46.741205,37.224917,53.009497,56.165651,71.471876,113.692894,254.297144,311.801959,276.429079,110.742999,35.908786,37.538783,79.42305,112.307595,112.623021,107.412004,71.983749,45.921189,-14.666158,-32.144992,54.459155,157.352069,276.912377,120.686167,30.511633,-6.263864,-2.239177,-4.013082,32.690858,148.965092,173.825851,155.32395,138.872964,139.976185,88.995183,59.631788,99.737531,158.91534:-42.31071,-81.533148,-104.134524,-51.567568,1.320308,32.042305,-0.809752,-47.109376,-37.602695,-46.027937,-37.763804,-19.648609,-32.750607,-41.346635,15.211087,60.661206,109.029364,112.049478,130.702988,91.943958,-17.1188,-207.995058,-184.199888,25.543592,156.521477,158.620452,115.782177,77.47896,-104.217828,-219.002512,-275.485629,-194.210857,-3.363478,7.215517,-26.810407,-35.616967,-31.198149,-58.666846,-40.937081,127.707338,296.054299,336.628278,327.822807,261.036645,96.089604,79.463606,133.805961,124.564612,30.196993,-46.66809,-73.315832,-144.71349,-201.918512,-271.78089,-237.906302,-78.706478,58.499469,88.972466,46.986163,0.724034,-23.335673,24.642873,156.603248,189.238996,157.005681,43.19268,7.030134,1.641046,0.146621,-29.482965,-44.242947,5.088237,133.239402,130.554175,-65.3993,-185.367673,-313.821907,-304.197218,-210.803056,-167.99597,-99.976537,-72.513156,-83.426541,-165.367692,-238.865333,-320.224899,-273.268306,-75.733328,76.078488,104.758107,92.965831,81.384832,69.557199,61.66233,65.04409,90.442015,130.856628,69.582559,38.527334,28.674385,32.747455,55.863563,90.826916,215.661577,317.661893,298.884553,112.772983,-0.132783,-142.757059,-150.699349,-27.270902,66.434063,165.334782,129.196821,81.572466,-33.641664,-78.298076,-146.311079,-182.444552,-203.901362,-93.460336,-28.579159,21.895718,7.541038,-17.801503,-3.035259,21.643973,1.756154,-51.975356,-75.527314,-77.094244,-84.99201,-112.371459,-155.742822,-127.510149,-16.429924,10.427433,-17.383125,-105.490784,-152.258438,-207.613964,-195.922605,-123.115302,-86.997203,-23.016424,-21.095028,-47.238498,-84.26066,-87.335465,-65.506856,-58.51859,-83.34727,-89.35112,-73.557416,-56.629093,-78.632164,-153.168909,-178.280836,-193.745126,-177.101067,-108.102038,-53.634131,-26.09116,22.270429,41.389401,113.714069,149.388154,163.808711,176.472771,188.347608,194.171164,174.884162,72.83005,33.208089,70.520128,109.690564,153.797169,179.477575,161.206878,37.384215,-24.800269,-16.819947,42.54473,162.181706,232.966369,226.363131,135.465168,76.154242,-17.010079,-7.017205,140.828789,238.880468,395.188136,361.7197,272.387289,77.572361,12.087521,35.29751,128.035945,323.55628,343.054195,284.231803,162.125888,145.444709,163.664594,157.611998,115.664278,114.526657,185.717327,208.42245,157.897063,29.591643,0.795258,38.794036,78.416347,151.57693,174.293669,137.483835,36.451982,-0.062199,-46.675732,-40.911612,16.597628,50.059114,94.190688,69.496911,44.927902,20.608258,41.249823,133.909796,171.019812,241.333125,360.563822,365.645344,223.949004,157.912081,167.154044,229.272246,327.087786,339.397794,390.097631,401.192348,324.215447,116.056534,69.03861,100.625519,117.090015,133.849156,204.342411,209.64183,105.676414,39.36286,18.166412,71.083275,165.517342,167.889109,115.871953,82.267986,84.86736,24.575851,-58.997632,-172.079681,-138.065315,20.318488,36.205541,-15.712213,-84.730358,-91.393805,-129.361616,-143.053711,-94.276586,-52.231201,15.198423,27.742533,-3.779157,-80.050131,-77.489346,4.59069,34.781295,32.344079,6.107544,-6.231785,-47.941613,-112.171016,-306.299467,-341.859362,-221.365832,-142.051622,-74.531872,-111.744742,-148.78558,-234.683069,-269.084614,-280.852149,-268.868821,-248.401056,-210.35251,-187.256057,-163.158823,-193.315453,-358.810118,-425.123439,-410.083822,-363.944059,-279.087514,-227.047515,-211.853361,-232.569668,-264.789389,-243.334176,-182.828126,-41.80333,87.951345,100.56324,36.525114,0.038124,-89.970593,-131.303338,-86.629335,0.118119,104.992892,-19.490864,-97.626541,-169.584077,-162.614665,-38.409319,40.02384,84.207702,57.717241,40.237857,-35.237936,-86.079182,-154.857942,-147.084708,-63.784609,-12.055081,85.264556,70.323343,5.507055,-146.980767,-209.866269,-251.601876,-219.714353,-116.260658,-0.633902,49.541431,58.200749,20.870171,-13.785662,12.255096,54.21905,41.335235,-8.001693,23.403887,56.762662,-29.492718,-139.813947,-192.280109,-104.069572,51.947169,92.352995,116.04333,172.369011,174.586228,93.915768,48.32754,58.815172,109.043171,212.304881,188.761199,110.796825,-99.005748,-166.074444,-115.69622,-45.804812,26.966053,6.709583,-16.58869,-99.174678,-153.826032,-179.078166,-139.107883,-60.343271,-30.739931,17.314303,5.77605,0.266899,9.988151,-6.057922,-36.777807,1.379985,164.596126,221.642997,181.392498,141.484137,156.689822,113.113495,69.653204,89.802938,160.199436:41.774597,-5.170253,-19.712071,-80.907392,-138.772996,-168.159539,-113.652586,1.734165,-6.592778,-28.05165,8.126779,31.324984,1.519272,6.702579,115.506461,155.431645,130.382211,61.33768,39.55517,-3.748869,-42.27375,-116.084363,-127.764169,-69.328993,10.379719,11.631959,-17.896293,-40.10577,-160.048957,-234.558369,-273.794637,-235.890185,-149.494798,-130.299406,-136.117293,-144.236818,-152.753753,-136.811471,-89.708845,36.015281,156.47079,187.62767,120.495237,45.118138,-53.413178,-46.879666,-13.70935,-18.829773,-2.671872,-17.71644,-82.830323,-223.729388,-263.177169,-283.315257,-262.643337,-148.484636,-5.268894,33.938862,31.143896,12.250737,34.169512,101.601867,277.740245,338.396515,322.52651,149.168989,75.308676,4.860216,-20.022035,-76.244746,-86.942866,-21.600193,32.294307,14.533207,-28.503403,-71.523656,-230.28941,-275.488141,-261.73692,-244.782096,-150.385861,-10.482084,5.257237,-71.27362,-129.071082,-225.092911,-229.745796,-98.454492,61.832758,91.525346,102.252512,102.627865,77.872161,75.743592,149.683239,178.49309,113.356358,51.278442,62.714224,66.341778,59.040257,128.546511,201.498758,292.054583,234.027562,179.560704,54.411526,-6.773675,-50.222874,-29.16961,38.792562,79.071207,150.217338,105.806586,46.7808,-59.313282,-100.884296,-156.379343,-156.724302,-81.884932,11.248165,24.552396,24.347548,36.924147,62.709795,70.895157,86.8133,97.827485,143.139502,116.918816,58.332807,-60.706244,-96.785765,-100.184447,-69.739242,-8.295055,0.330946,-1.842064,-34.206596,-86.050915,-193.020395,-201.291533,-175.339744,-178.000646,-145.695958,-65.469725,-69.554471,-145.779551,-171.225109,-142.493825,-106.425475,-40.955422,25.226391,44.453403,19.063864,-11.441357,-74.858502,-106.865062,-163.330143,-175.285591,-145.047433,-98.7224,-74.739873,5.551642,50.865022,88.411466,76.028243,76.485469,122.829035,126.558115,97.656642,80.175747,57.528678,58.519699,90.67799,112.005825,128.97973,100.403139,66.980651,-22.5196,-50.270963,-12.511188,34.063095,90.753359,97.817124,84.252325,-10.563018,-64.220151,-73.420186,-27.54106,96.524724,161.774327,253.396761,208.220552,149.134535,14.401998,-30.05451,48.988374,147.79997,301.293055,364.193159,361.972065,296.166398,236.809558,123.397225,102.568963,113.854556,129.654252,191.622746,228.224866,209.085804,132.481386,101.142447,127.932756,185.056204,287.111393,288.557311,254.116191,166.869165,113.690655,24.434666,31.906767,122.174956,152.858092,148.345865,130.07382,115.482925,44.708478,29.348276,125.087178,192.34948,243.0849,254.370602,259.051652,223.024989,185.260209,124.949215,135.72506,234.338185,280.80304,333.606129,302.154773,250.753273,166.14253,158.720712,188.864261,191.289772,156.854481,173.202882,196.685044,173.547022,97.69043,-38.341924,-7.93907,157.716973,189.554342,132.716124,103.292246,109.176507,52.587288,-16.644663,-113.247642,-99.365954,43.137057,149.434283,113.420451,-30.451458,-53.532004,-10.94531,10.276344,50.1135,81.020636,136.566259,110.734529,85.505843,93.360126,111.453936,96.306037,65.190833,66.0101,101.515498,52.950824,-116.476235,-166.319637,-181.24581,-183.555862,-182.500141,-157.95287,-75.719879,-57.919629,-75.12268,-130.805667,-174.518007,-273.657825,-309.378468,-288.467983,-147.515118,-96.048758,-111.529507,-167.982174,-325.704917,-383.239571,-371.468531,-311.140852,-155.375874,-80.922001,-94.736679,-188.826497,-236.554195,-209.30315,-130.257604,36.853009,118.996682,109.260945,6.266206,-46.153517,-78.767167,-64.159241,-47.668668,-51.300067,-13.015626,36.164904,21.232395,-91.056621,-153.577136,-149.284956,-74.702138,46.3553,-1.315001,-49.662351,-71.19155,-57.055959,-91.70107,-118.705194,-67.992788,9.021424,140.680199,135.605633,98.759361,-41.993382,-127.519154,-182.51876,-148.358581,-64.765562,11.726375,43.915068,55.305946,25.42008,-32.402266,-22.046835,23.433367,27.869821,9.223008,7.767959,25.365454,-10.45089,-82.562656,-131.371442,-62.368192,111.461651,173.145109,151.564349,22.180708,-53.817364,-86.284667,-32.822641,71.858863,90.58785,107.268342,86.858254,44.327144,-88.231866,-143.21709,-140.050807,-85.712348,45.573509,82.073702,42.053568,-117.849383,-210.031235,-317.161594,-278.988383,-69.447095,9.549638,27.360583,-52.602437,-77.924431,-66.448399,-57.411376,-43.470045,-16.317377,82.40175,135.274348,113.570785,52.182023,43.31251,57.80366,82.402174,169.080867,220.326756:-72.405843,-60.089905,-45.712506,8.452954,14.111947,-27.798751,-43.538379,-46.462261,-98.721985,-152.297859,-198.944176,-184.683109,-204.948155,-235.11843,-222.06496,-184.199896,-153.183759,-160.256176,-127.88601,-66.942191,-90.19389,-161.252004,-148.077967,-40.457211,53.176696,53.628954,-31.617671,-82.554288,-190.793255,-250.296849,-322.918985,-298.837688,-154.021808,-120.139809,-147.833038,-191.460536,-209.890443,-173.951544,-87.789942,153.522932,273.946116,234.946978,104.671779,85.789158,105.479297,104.811313,60.611697,40.707842,79.275785,81.623699,11.05154,-190.611867,-277.199661,-347.477576,-321.902268,-202.344788,-91.340688,-69.561723,-65.880912,-60.973072,0.510679,83.919544,281.087973,320.621103,246.540421,101.675793,43.647872,-55.131796,-98.436048,-137.73932,-132.732559,-66.399215,58.77304,79.932175,-40.849805,-134.342235,-243.5381,-228.19116,-96.465225,-45.477483,-44.202667,-57.104635,-47.070821,-86.529373,-152.272504,-242.623131,-217.613356,-75.272336,61.566125,118.088402,214.869865,226.407512,133.938695,84.925228,139.075545,212.542726,267.345869,149.384279,90.788879,94.745193,131.527445,179.884769,193.410007,244.66703,320.919928,332.872566,281.948042,243.94444,148.64894,82.280203,11.635643,52.531212,182.612178,190.278051,159.108205,81.528903,38.514858,-31.334405,-56.167669,-72.207677,25.630048,94.04199,166.763473,153.87156,56.569173,14.268532,10.049749,46.620565,140.865662,101.477137,40.10771,-10.109434,-6.610863,-27.046485,-34.983835,-21.688625,-16.183587,-14.044249,6.852413,8.553927,-38.054872,-64.051288,-75.87933,-58.731704,26.511153,97.847333,105.431507,109.236317,103.293263,55.006846,30.183099,24.1683,73.124342,94.761918,89.140366,52.75358,-78.179691,-130.045562,-156.866602,-161.200697,-171.134581,-165.435811,-153.05726,-93.82076,-65.108565,-35.772551,-12.926114,77.38685,140.990688,144.62204,125.531564,91.106896,-31.132551,-46.665705,89.805051,154.59266,150.153624,112.479588,120.289267,113.217745,69.978429,2.304729,16.70778,94.846679,123.241202,93.495896,-22.681313,-72.25206,-92.860916,-64.298148,20.313079,70.79021,209.933428,281.283287,251.366709,101.675566,23.122586,7.449618,65.804366,174.402645,246.169787,245.846031,129.841073,60.194624,34.680296,73.472272,140.377264,143.600355,137.542403,140.768829,114.232015,10.239492,-21.824066,23.987897,79.289433,152.775254,141.452425,115.229589,64.988598,36.424714,-25.982397,-4.093644,150.656751,192.96142,139.081962,96.490077,97.152831,63.842473,33.441151,25.220061,54.822708,147.295658,277.682155,309.336089,219.550754,134.73622,68.653778,130.266225,322.566621,379.871158,390.51948,313.789217,273.584306,225.610217,209.781518,188.116058,179.77684,212.59774,314.953226,322.404199,226.524093,181.848077,170.913905,200.60751,257.08493,243.553097,171.603102,123.515764,91.183443,-46.416178,-131.528206,-188.272101,-146.806304,-19.206765,56.14847,32.639138,-87.296695,-128.465486,-173.31604,-187.594976,-146.758304,-98.490774,-25.472183,-22.773587,-37.065535,-26.605113,-7.944132,-48.437493,-101.101125,-116.286041,-47.186322,-58.188604,-160.161562,-214.957685,-320.803083,-339.779046,-236.721902,-171.994823,-122.197911,-131.983908,-148.204866,-209.47789,-259.486754,-322.110706,-318.719168,-320.071125,-275.087539,-217.153712,-174.009863,-229.356116,-413.597037,-458.455105,-351.83489,-246.813193,-100.948454,-86.11912,-104.191616,-186.269352,-229.700275,-192.628435,-128.446276,-30.682296,45.429063,57.017127,-20.833489,-96.517088,-215.041882,-201.276102,-35.339346,48.715194,89.816893,-32.234958,-89.347513,-112.059167,-121.019679,-133.791799,-101.302751,-30.080036,-6.203355,-10.412015,-47.653359,-79.301668,-171.121517,-198.218645,-140.778281,-66.211536,73.94257,24.807439,-63.979552,-192.2349,-219.660214,-238.207667,-214.349098,-116.690772,-43.793379,-36.779053,-73.633759,-105.549322,-145.89219,-119.888705,-5.384352,33.294532,76.390692,114.117679,107.720115,-6.159763,-77.131856,-84.633083,-43.048941,-31.310755,-27.918102,1.847723,-17.867017,-72.438907,-115.851177,-78.927073,23.887011,54.619479,93.841416,138.66237,147.941121,65.43619,-13.881228,-59.608632,6.905238,161.51688,108.273499,9.402434,-174.828872,-222.639127,-251.353023,-234.210734,-109.012837,-17.812859,86.545707,-9.101093,-58.025329,-35.356195,-3.471128,52.015226,91.958325,151.965081,109.884489,82.184572,111.224576,140.907632,113.979578,90.827518,133.606099,175.281159:24.910073,-34.696327,-26.58819,-24.462648,-41.004221,-13.743338,30.707797,72.442972,17.271067,-15.624802,-64.077469,-94.934944,-193.196047,-240.075444,-247.594194,-197.062287,-65.141035,-20.262127,-39.099243,-117.093111,-154.315815,-169.663199,-141.844833,-38.39454,58.793557,66.015724,-17.058064,-83.089595,-209.900606,-257.357899,-332.026163,-346.21907,-246.603491,-127.052274,-130.486339,-192.706675,-202.304131,-131.32325,-74.90817,58.307712,189.158625,176.003605,-16.553509,-113.469637,-177.324112,-149.028907,-56.650914,-22.467686,-0.496028,-91.965184,-172.753064,-295.013359,-320.134288,-344.243322,-339.889585,-215.446424,-17.851431,18.420286,-79.524788,-149.432915,-114.169091,10.098204,265.841399,317.270173,304.038529,227.269947,166.173288,34.138634,-25.185806,-135.63576,-172.316347,-119.703243,-2.665518,-14.847807,-182.533516,-272.311851,-304.055104,-243.462746,-139.848062,-123.846938,-61.5494,-7.300097,-31.676686,-120.889334,-145.579746,-167.62351,-177.951607,-111.022907,82.086628,154.135474,170.557427,116.114347,-23.811299,-33.424325,108.81545,196.893402,255.549071,175.451612,145.739556,124.314615,109.898453,79.584963,85.340985,158.081404,196.527858,178.739157,118.946221,87.997641,27.675087,7.207515,8.418608,37.306622,102.217476,59.334132,19.438233,-37.740001,-63.231479,-100.030272,-94.004403,-18.842896,34.301265,11.784264,-45.713924,-39.400354,26.848901,61.162155,118.471741,152.596577,185.19733,88.026979,33.333286,-35.598972,-71.211211,-82.377993,-27.761601,97.570838,48.337035,-20.875923,-72.349374,-75.344434,-139.227265,-162.265902,-126.500962,-82.498581,47.833135,135.379752,112.767002,-29.602816,-102.915938,-117.634512,-59.36774,65.782366,157.532697,176.011,117.94729,59.212296,-36.676178,-47.025999,-28.37272,-37.11323,-71.023057,-97.322303,-107.079053,-111.312599,-112.348374,-44.748555,39.160551,189.565203,183.640927,136.565715,54.521029,21.528807,-68.511142,-81.372867,55.415633,153.779317,230.76856,169.112571,132.526164,48.744877,5.984418,-8.298462,21.421531,115.873461,168.436224,133.426662,-4.746221,-71.127103,-127.579484,-73.761264,149.555489,227.743154,240.403775,217.445143,198.066901,79.350799,27.830029,89.042065,181.794915,366.126403,429.39854,391.415609,223.055146,107.219773,-55.380628,-21.158593,193.975493,264.465591,249.891675,170.751658,155.081933,135.496329,102.021393,57.219725,83.42575,200.976026,307.399894,322.413773,250.06686,184.310324,125.224554,161.31354,241.576251,234.375805,176.366394,126.075319,99.573343,44.023717,39.542361,132.594304,202.027043,302.715172,337.180974,316.3053,251.434901,239.186728,218.380127,211.833153,281.739299,354.638572,448.252361,375.178663,328.416794,290.18761,286.753702,285.648129,289.86755,348.102842,437.238663,428.818981,291.98587,209.365084,94.177766,95.242562,236.231293,326.063654,362.835237,195.897126,121.74488,32.811802,-13.622236,-67.293198,-38.150913,109.167115,174.773129,128.425166,-15.932894,-70.567108,-140.790804,-148.414025,-89.002158,-37.418327,41.106427,13.422146,-20.053674,-48.926154,-33.539755,18.09658,16.704956,-50.890184,-88.431982,-74.033021,-67.676245,-129.629172,-326.626846,-367.583646,-263.743969,-184.843384,-94.830547,-101.022939,-151.36127,-327.798118,-386.614814,-346.042791,-316.474426,-362.807825,-330.466182,-251.51525,-174.980996,-231.106283,-388.127614,-396.008115,-247.129434,-152.907546,-47.892355,-89.229264,-145.448246,-268.712753,-310.455461,-271.775548,-207.492272,-94.582307,-30.630779,-27.163509,-98.789373,-170.230243,-298.087045,-303.682278,-205.796454,-153.535587,-83.077416,-35.879221,-48.537133,-170.364495,-235.161491,-230.992463,-158.362782,-1.528884,19.4645,-13.008055,-42.204808,-47.028728,-147.838813,-206.5773,-165.22806,-77.731106,38.502777,-9.165263,-34.15344,-86.17483,-147.148445,-234.414144,-210.075151,-86.295469,9.001411,18.721555,-36.154499,-85.228648,-164.075593,-146.343683,-8.278353,51.543563,95.704557,108.535936,106.081017,-4.549993,-98.119008,-138.001419,-48.372008,109.586933,69.269345,50.039737,58.605475,34.67143,-43.342668,-28.364648,96.45772,144.079673,162.04001,138.495427,110.27473,-47.89235,-147.206949,-186.45264,-111.819069,64.130456,71.081641,-1.440257,-213.772864,-312.954042,-372.242586,-307.019809,-114.124331,-49.370181,-16.973818,-93.54668,-141.207798,-188.753397,-200.596125,-163.97199,-81.557562,135.71973,196.383347,163.747783,116.673364,101.333582,70.754488,88.784521,164.537015,201.358344:-324.08784,-192.522348,-122.761534,-22.387825,-14.198702,-17.691146,-7.698102,-23.137725,-150.442163,-245.090343,-395.975181,-423.630044,-396.57149,-362.494684,-301.478863,-285.774342,-271.805569,-222.194034,-173.14021,-72.815864,-57.269201,-88.433168,-79.135733,57.279294,126.264935,65.460445,-66.145299,-85.438628,-158.055884,-228.431643,-319.325615,-303.1841,-135.014005,9.76378,10.652356,-28.786475,-40.771395,-25.088676,10.654322,66.338245,68.042442,57.295964,25.599848,29.121803,78.04705,106.267173,131.000244,129.144731,139.280968,62.141022,-14.1561,-123.772749,-169.853092,-284.6624,-315.62084,-267.432483,-164.046826,-120.977166,-20.237296,46.347689,165.353249,203.335732,235.686158,223.921077,135.820419,6.430907,-59.933615,-187.11597,-241.846698,-284.399687,-263.874074,-136.171026,73.241487,124.383354,9.805745,-86.835668,-137.593615,-82.482697,34.587582,51.683337,90.957212,173.070836,170.015519,70.801466,4.461553,-109.223933,-136.493806,-87.722197,125.406815,240.738558,333.690966,309.63761,233.38639,233.3392,291.568308,308.947667,321.435278,278.481432,236.307138,211.493639,218.258832,231.579691,266.305714,343.228875,319.33413,297.706945,255.846718,221.825843,165.117255,157.294478,133.509241,110.567557,145.952831,280.980731,306.216256,205.778555,124.15278,64.405146,96.715489,181.698761,246.006297,237.865935,150.691866,125.578905,104.43199,68.120696,-18.387885,-12.85387,90.434325,121.547007,80.811766,-12.253836,-15.929377,57.353737,89.35432,47.791032,-50.68959,-51.12169,54.618119,99.160435,30.037862,-30.139139,42.309725,164.316486,351.297527,283.805407,197.985327,120.206988,131.705791,131.863899,97.506932,13.6771,2.063389,17.851958,75.618793,105.527459,55.6704,-21.367206,-131.141305,-145.184795,-150.599191,-198.041671,-235.073654,-219.810942,-168.142802,-81.190776,-51.463777,7.785048,57.899752,74.809952,62.293084,-2.719403,-186.718784,-199.914232,-26.292576,68.637641,145.627091,127.634223,100.50562,5.96851,-37.706086,-36.157689,-0.555655,10.394253,-84.660502,-134.021949,-216.16439,-235.380982,-192.548916,-146.584184,-59.239178,-14.321727,102.176849,188.791552,202.513307,123.320543,28.037053,-64.581821,-15.189706,168.861243,352.612326,386.199229,309.023837,257.267426,221.34831,228.839097,247.154173,243.294277,194.82146,102.278178,60.022705,22.481846,25.615977,52.903154,49.606757,12.524853,45.107724,70.909058,50.959039,5.395722,-47.676182,-11.977447,124.1258,176.456009,208.153783,119.323044,44.927118,-62.942119,-83.252144,-82.109603,-58.552296,48.875874,205.873063,231.820384,124.084836,58.727886,40.408271,112.278784,311.955137,360.821069,400.843965,417.439402,381.303256,255.42849,176.281028,101.607802,169.524952,392.707449,452.897385,409.005411,294.277612,276.157101,294.127259,298.048115,295.448424,286.299915,228.810216,160.04196,137.918462,27.74346,-86.948241,-225.407579,-157.780478,132.172583,193.259616,104.844426,-91.717731,-167.664017,-326.178566,-390.036416,-387.388541,-328.38964,-191.533712,-152.586822,-171.384933,-172.697149,-159.685481,-181.501637,-209.790295,-240.200009,-158.610557,-105.479962,-118.992907,-189.080633,-357.007483,-389.215068,-294.48551,-225.621039,-166.937629,-180.604921,-193.719601,-229.690342,-244.456056,-219.835133,-207.61057,-284.686028,-331.104373,-299.888947,-237.575699,-251.603477,-359.129455,-372.74629,-249.192332,-203.428564,-227.801353,-192.111022,-133.126863,-99.497468,-150.478843,-189.187377,-129.582095,8.729644,44.728134,34.043921,-6.754374,-34.352038,-87.520151,-74.219568,58.570278,116.20479,105.86415,4.511812,-47.806321,-106.44393,-113.928708,-126.059582,-122.575024,-53.301353,83.687589,111.963837,-2.289624,-97.098741,-237.937317,-258.053671,-160.730903,-82.620092,6.035913,-20.857377,-67.599599,-186.669895,-228.357475,-202.620783,-155.617052,-143.148508,-169.299368,-130.836362,-71.222129,-100.866269,-153.214262,-108.168596,29.174992,41.993055,0.898037,17.658134,23.473795,-23.030664,-63.174039,-87.137703,-51.511823,41.535465,65.790233,42.505911,-17.333508,-27.080884,-11.041324,9.45971,53.350937,70.25119,144.004446,206.66104,181.507651,81.372233,50.815941,52.346508,72.103145,117.992191,104.790275,60.153395,-16.439321,-33.962711,-112.302561,-157.68824,-98.545231,3.547849,154.665373,68.453018,-16.114692,-116.127345,-126.369259,-49.26075,29.349174,147.59183,135.739078,81.983034,-13.339804,-21.055516,-14.525831,-2.545984,120.360758,207.12318:-59.452447,-47.778834,-35.467692,26.993267,19.380919,-63.527781,-72.451889,16.542426,47.344638,-16.387775,-187.879716,-241.80964,-308.916763,-333.361394,-328.494101,-298.842473,-223.929525,-193.069233,-190.729557,-176.909557,-171.386144,-150.292931,-100.527654,96.865495,217.44405,166.312181,-68.986109,-173.395327,-315.35175,-357.073432,-342.921931,-289.545004,-170.818399,-147.085165,-170.850743,-236.271086,-247.918738,-142.102711,-43.894314,111.517894,160.873204,131.304519,2.947704,-38.505885,-23.973883,-3.39243,-16.22321,-27.522839,15.759539,-3.246704,-70.139559,-209.608962,-255.703369,-286.208189,-272.246153,-190.786309,-61.353832,-35.640411,-107.993328,-158.915585,-133.122945,-37.82852,174.463367,226.427374,238.123791,185.318325,116.452572,-114.323297,-226.222336,-303.239428,-270.003922,-115.243132,69.8731,106.004392,-4.672089,-102.754181,-190.447895,-154.030722,1.144784,83.165457,163.786906,86.004428,42.889996,-21.194013,-85.507295,-208.255508,-187.938016,33.771147,254.647222,275.408974,162.616928,89.382026,1.929866,6.309234,152.752702,286.211445,490.4678,338.713127,168.867255,-34.292365,-10.667437,155.499435,221.538675,251.879894,218.479069,200.136488,177.414215,162.947522,79.749132,37.228099,66.770212,142.119174,282.549139,239.996861,169.410844,12.414369,-48.625791,-28.723883,45.626429,172.235879,188.162382,156.197068,81.075789,58.874946,-11.178238,-49.531047,-15.429145,64.972495,244.410076,235.690651,156.602993,44.130817,38.401566,67.537036,93.00281,122.970596,89.843071,78.297552,61.265473,26.507623,-85.756793,-101.351123,35.065261,129.208494,215.319761,204.14336,194.514317,132.451358,82.664296,54.729818,76.748772,113.635988,167.52852,187.853482,140.71453,84.739601,-14.945025,-22.450016,26.062705,33.873699,-7.02153,-106.96305,-162.481723,-186.470434,-152.189455,-50.414749,13.015969,162.805689,230.891099,199.647274,76.828873,7.64908,-106.422301,-103.583719,42.486149,123.450051,213.628841,210.396416,180.650082,79.482011,4.38883,-86.406096,-51.048158,82.937421,89.52342,33.158891,-108.993541,-164.857708,-210.027085,-169.542643,25.624883,111.81525,185.795502,195.628369,168.728125,45.879451,0.253097,57.957083,135.544591,285.93242,375.845429,350.905703,169.324247,69.363166,-17.298569,26.14019,212.160049,284.828636,300.631156,154.023565,74.519318,3.712247,-24.161859,-72.220997,-34.630357,162.768104,262.957158,224.59939,108.256536,61.864924,-22.696642,-15.589513,143.813949,212.836932,201.948201,113.800592,76.617172,22.488525,3.479785,-16.606261,2.94252,125.977642,238.725793,239.270401,123.626315,50.759694,3.20298,57.805751,232.082867,296.756169,378.804502,360.900036,304.845601,183.892753,138.320304,139.559974,207.724145,394.252338,502.327181,489.689048,344.971165,255.663403,144.126713,167.234603,359.258351,434.220189,366.01175,141.098634,55.09839,-52.413059,-94.917716,-103.761483,-27.307017,226.646958,283.488452,175.862236,-119.975309,-212.406538,-286.518722,-295.045756,-224.186311,-160.981406,-98.827361,-154.236772,-177.809087,-140.122603,-118.565001,-153.397192,-175.238196,-120.030615,-25.775035,-41.266376,-213.415295,-324.85993,-493.190496,-498.361873,-319.387284,-208.909084,-129.839011,-215.966164,-254.926783,-275.213762,-285.275624,-301.662048,-288.380705,-261.047042,-240.414201,-228.008776,-261.702171,-318.288989,-454.661612,-477.796862,-344.18148,-233.871124,-92.699797,-93.115608,-135.163209,-281.781116,-342.699046,-287.604525,-185.417888,-15.964551,-22.451464,-91.379307,-264.344971,-341.614998,-417.3808,-370.657879,-142.663823,-36.172792,25.583077,-100.289912,-166.90594,-208.235621,-193.574812,-127.086114,-89.808672,-55.818421,-50.92725,-65.829027,-160.134442,-229.990375,-340.720584,-336.216142,-186.850762,-90.332338,26.008241,-2.099768,-44.470155,-152.679515,-237.895777,-379.535344,-360.009759,-135.683543,58.458635,49.67851,-98.833467,-160.010305,-186.220624,-151.869516,-13.163006,63.935889,166.132118,166.090927,139.308067,14.631874,-83.358533,-159.455593,-94.911784,61.122445,78.496683,56.426658,13.435547,-8.016546,-33.42228,-7.968677,104.096312,158.641463,235.811585,216.324452,169.19166,53.521258,-3.466114,-57.831919,-22.308167,135.173975,160.712266,71.999939,-172.951119,-254.4534,-303.576671,-284.41039,-146.389813,-43.214485,91.417389,23.970422,-32.354736,-72.116706,-62.360484,16.759252,90.329718,215.655011,205.64475,155.027255,62.642861,40.664789,-8.160542,-16.845462,63.3116,127.558453:-180.847586,-193.312519,-179.47394,-69.824434,-41.655308,-77.230163,-94.942904,-122.755497,-221.097949,-267.212282,-278.810218,-278.791003,-327.022961,-332.996891,-286.770642,-280.361797,-272.392174,-159.106556,-92.378824,-41.368771,-60.343411,-79.916629,-32.986625,133.753121,214.702789,192.865452,71.074891,10.609033,-58.511858,-68.374872,-63.266837,-69.9104,-75.383702,-14.706514,24.783211,100.355277,114.867755,54.809088,15.987059,24.520381,77.969078,82.189239,60.834892,61.226819,80.705832,85.518596,111.095509,129.345952,133.439453,110.338795,92.976125,16.45426,-63.439881,-231.055871,-235.560517,-59.960496,129.344652,168.104376,166.816562,170.79428,201.100719,196.214023,169.563569,173.19291,146.266318,3.274276,-60.506036,-89.743402,-94.86374,-170.759233,-205.307793,-132.208725,69.417785,125.736675,62.560682,-15.637446,-109.314498,-92.170562,13.727777,65.451131,168.197375,233.757053,241.981864,234.528699,199.370758,86.70511,67.971131,150.81297,248.825778,268.007481,280.425735,280.935111,253.123731,223.25826,147.604609,130.426721,187.612649,230.230844,210.836894,141.326249,115.264953,142.654911,175.914442,169.225941,132.832825,139.449336,145.723766,112.681657,13.315373,2.613113,59.277798,77.885148,109.252504,170.670655,171.899946,117.949015,96.589688,126.074917,164.165699,204.822125,164.654085,92.636629,-121.002232,-184.801075,-170.063082,-146.503017,-139.908184,-129.422712,-12.459803,106.034254,86.421028,-38.125052,-55.128021,72.665893,140.443051,59.778412,-87.676833,-51.675528,149.903857,214.105891,131.155483,49.114108,75.87047,164.449983,288.202371,266.423464,207.315068,104.399602,89.826029,107.905861,102.869788,-27.582988,-141.548938,-111.98399,6.148329,11.95525,-109.998214,-168.541338,-185.945937,-181.918377,-198.264321,-172.833467,-151.47965,-179.799957,-221.923403,-208.829924,-131.580396,11.246917,46.324234,48.654829,5.941345,-50.459492,-154.780491,-147.148285,-9.603808,57.52438,90.434498,12.865276,-39.45591,-115.007297,-141.838758,-182.50034,-189.776896,-188.029936,-193.907531,-218.595486,-285.529595,-292.032853,-282.664264,-275.281217,-162.319608,-77.398536,27.44566,93.900666,125.030832,133.222646,87.684482,-6.119452,7.813915,139.27142,296.239005,323.2689,268.81072,261.678046,284.75984,267.186572,212.462853,200.977989,225.459308,248.033036,237.685886,213.196752,190.06724,84.709704,34.774853,29.556845,65.914388,87.133051,131.972077,115.447757,24.170878,19.043291,134.266096,195.771811,247.603469,189.802367,121.939383,18.539823,1.821081,-13.764712,-24.183391,8.117635,121.356359,142.656572,60.22317,-5.492448,-88.105945,-55.770461,151.647238,237.703802,291.733709,347.103332,377.95651,340.112364,258.169853,131.064678,158.536027,298.767902,390.323123,411.798294,386.286483,356.594574,328.486657,330.278188,345.962933,348.128652,310.451025,256.378829,240.900145,208.386875,170.301963,104.51736,127.541517,280.477305,345.958221,282.871225,63.413676,-32.946285,-179.535419,-235.756329,-261.627834,-230.740544,-144.227206,-96.627224,-91.459268,-76.938522,-82.849292,-166.823523,-226.981923,-305.602461,-275.286842,-251.88465,-240.743581,-231.351004,-214.963477,-229.049577,-279.367886,-302.674445,-333.846295,-263.984491,-196.417102,-118.391423,-127.695149,-163.433834,-170.581801,-210.41255,-253.453218,-259.924509,-296.046758,-329.944468,-361.482355,-331.832643,-229.134179,-202.806565,-185.932391,-174.871759,-164.190702,-111.943126,-106.148733,-115.73795,-74.628294,60.783176,90.196809,58.362024,-2.597052,-19.226962,-49.205895,-35.167999,87.814669,145.003474,157.247825,90.031452,58.840212,-16.538432,-81.032644,-159.631975,-137.150779,-88.388621,-68.597814,-60.840666,-143.618116,-199.376014,-207.611331,-187.267774,-148.781947,-112.848267,-45.696336,-124.567782,-205.553982,-309.615264,-325.732954,-332.199684,-314.464925,-227.466003,-148.145691,-127.397954,-91.278485,-82.354925,-106.82287,-120.463863,-90.687632,-50.419004,16.785644,12.349755,3.98108,-3.83752,-40.86444,-155.018752,-162.530755,-58.061499,-3.541682,-42.976564,-150.881922,-160.65567,-107.958813,-85.710764,-97.592048,-110.034847,-30.216296,102.208343,108.629273,19.177464,-35.889073,-107.634538,-118.460835,-71.062981,32.456887,54.778328,55.777151,35.292957,-104.882656,-163.548826,-72.083968,20.532138,63.197913,-37.414092,-87.545456,-170.60479,-196.25484,-185.299757,-150.836536,-67.571273,-44.528965,-53.599923,-50.273266,-37.415086,-25.924562,-6.09613,94.742156,140.940697:-332.690026,-263.411874,-224.800612,-141.408567,-100.771411,-61.744087,-69.052091,-110.156528,-177.634521,-232.616625,-286.932531,-251.832193,-190.30102,-207.077861,-266.263703,-283.446208,-264.501731,-154.48959,-89.80521,-28.529659,-51.121688,-127.017422,-121.60806,-1.816036,122.518773,134.583156,73.84804,36.435992,-59.935051,-117.933076,-154.554069,-116.935081,22.146285,116.6717,133.315259,207.266191,251.47389,238.300418,202.503811,188.165654,237.456985,256.918497,268.286692,250.684452,159.591547,131.725282,171.657851,201.166768,210.557498,128.963696,55.77292,-101.101235,-162.295269,-191.092798,-161.267932,-109.420033,-95.372479,-74.49255,21.091225,79.545461,119.814777,96.654768,68.436003,84.786117,98.942962,-7.149214,-71.281265,-118.414436,-123.222776,-187.402008,-231.030458,-195.256072,5.923766,59.334502,-35.082918,-126.33437,-238.895777,-226.736736,-88.660917,-4.49909,115.930542,146.599899,151.592286,133.649505,88.544284,-12.877008,-30.6002,-2.224315,94.898863,162.535245,280.066762,316.760927,294.786333,243.935773,225.072877,279.44009,388.448118,386.609575,353.500368,281.674122,248.122506,194.63434,178.840041,152.046946,165.120052,177.216243,137.164878,89.992238,7.894757,4.771032,65.864541,86.455756,85.415516,59.298228,49.34967,53.415689,45.843847,19.779302,33.92222,91.648349,75.896001,42.616112,-3.999986,-22.242942,-82.581031,-93.910341,-29.30524,17.339638,45.03618,-60.611899,-130.338282,-200.607834,-191.544657,-85.310517,-20.944732,-25.401356,-112.235121,-97.739265,39.666779,87.41354,-11.900557,-101.19888,-86.835939,12.019752,157.380335,111.300236,70.990491,89.08637,125.875008,104.108499,28.858978,-171.303763,-269.817356,-233.386198,-60.284099,-2.466441,-58.147939,-128.380783,-193.307917,-178.331605,-129.026397,-109.409515,-93.402471,-86.150995,-130.880419,-198.607724,-156.231153,-13.748939,66.96111,118.288927,207.960499,161.918708,-74.134179,-132.750399,-38.520693,33.777712,113.333053,112.955425,77.968269,-45.658405,-98.946067,-114.544408,-103.661655,-147.288325,-211.831912,-232.25549,-259.786128,-244.933088,-166.452474,-134.274613,-74.64462,-37.094428,52.147053,156.804098,195.896187,169.512533,89.160861,-71.624689,-94.270906,-5.412367,218.249449,294.663829,270.800877,228.804722,220.60428,261.433868,341.074837,323.419308,214.426689,197.395007,209.559803,134.949127,47.703024,-28.852903,19.45775,116.998016,66.453177,22.089853,1.685453,30.711234,103.774285,128.206582,185.458904,236.237092,325.474927,242.83933,156.960092,48.796046,36.487855,59.121775,76.640619,95.205409,199.828459,267.321872,254.527468,182.208565,85.66439,129.272267,329.510485,377.490805,329.480769,300.153792,308.873502,288.336061,230.75481,113.895534,132.167317,294.75039,356.044906,321.517978,252.992014,247.629425,246.07809,245.745836,290.837642,314.813861,289.588866,185.213924,134.089668,55.016996,-9.773698,-163.012516,-181.146565,-43.330013,100.474035,96.092185,12.145261,-19.725247,-98.986928,-161.559744,-229.860624,-209.713249,-140.774635,-143.220326,-170.904341,-171.930485,-142.216914,-121.805971,-153.078674,-270.060223,-288.118369,-237.68241,-168.038082,-181.544146,-217.116425,-203.01153,-177.500392,-208.34858,-279.883821,-213.109041,-167.544917,-177.36856,-220.014375,-242.580854,-220.710816,-277.987634,-388.108285,-360.160493,-224.741576,-210.734972,-293.610422,-307.335918,-225.668165,-191.720892,-186.20371,-173.705977,-135.672436,-44.637384,-53.738145,-127.577787,-96.714712,120.340295,243.515423,200.308057,69.777437,60.002182,109.021622,132.743139,170.141258,170.923862,144.566069,115.725814,91.862635,31.179553,-8.672228,-90.077704,-113.734989,-116.071611,-19.505129,32.669092,22.107499,-28.71512,-127.839019,-144.58224,-114.636978,-102.019281,-67.815317,-23.335208,-55.337871,-239.229921,-321.653937,-301.57842,-223.053862,-120.031546,-114.143854,-101.305425,-38.304083,-9.547143,8.764432,4.669389,-31.18395,-61.919677,-61.018634,34.131147,66.029608,31.152122,-31.976784,-135.195888,-117.073349,35.20562,146.176437,132.337678,51.180207,40.708804,71.559976,98.23057,162.940917,191.581252,254.427263,244.342607,189.610208,106.751183,102.567127,80.601972,35.700931,-61.045035,-14.684029,57.722946,178.440962,193.321516,110.836559,50.751322,55.617175,121.823091,214.458108,69.257229,-52.379971,-181.543819,-196.185656,-200.917469,-176.311386,-72.071665,25.639174,41.176196,36.211549,32.373591,-23.642084,-55.895971,-10.903737,57.171539:-99.159729,-75.062711,-38.645035,6.454082,-12.732574,-69.230311,-60.890198,-22.075906,-119.360287,-203.24766,-301.59933,-295.315659,-252.841981,-262.844518,-322.389641,-325.668994,-249.347403,-164.221251,-134.010774,-112.02819,-144.274655,-191.346882,-135.874369,46.634358,102.609236,79.214767,-4.745237,-57.838441,-167.64517,-207.168416,-205.567157,-175.838003,-134.496466,-120.040438,-117.577574,-126.493718,-127.311472,-62.654622,-3.887715,52.543924,35.115259,29.091575,48.891335,73.213034,59.937909,33.888747,70.804006,95.444769,43.048732,-3.220754,11.390427,15.59234,-40.229602,-177.675179,-186.057911,-101.665627,-66.77586,-62.177774,-15.670578,2.715164,13.218822,37.867291,108.235732,110.833321,84.437788,98.357206,78.343846,-44.773312,-106.921089,-176.144056,-172.24828,-44.44108,115.712931,121.041665,8.88094,-55.823532,-137.22791,-117.439963,43.706305,118.78927,176.301461,199.944167,229.665389,240.781271,193.813726,109.035337,103.073124,110.832096,164.49328,200.104539,208.466137,168.471638,35.649322,-5.578968,38.599921,94.830359,191.798496,167.79113,101.214253,-0.549774,-0.755469,65.796664,107.828785,151.132278,173.09427,174.15701,139.598797,119.34325,85.583226,72.49585,73.901757,99.081763,178.651479,201.834785,179.462546,130.580877,122.205901,120.932451,117.919914,102.911689,128.926796,140.266389,75.533624,16.542384,-96.531053,-142.869652,-177.893114,-150.956026,-17.031159,85.897643,81.328417,12.798029,-17.556798,-5.172267,21.450818,31.924655,52.824632,60.347519,27.864738,-0.177908,-82.839952,-98.952122,59.608635,192.958297,352.812681,314.500803,269.268603,202.87573,159.053456,69.715271,48.462085,-4.3775,-22.811776,7.083087,59.218249,46.568453,-52.816409,-109.436167,-139.776768,-112.552661,-88.810531,-162.486635,-179.955503,-110.315003,-78.120638,-86.79177,-84.836566,0.475624,104.337657,99.710173,17.65906,-18.813793,-89.776655,-95.395372,11.894456,76.107752,140.325312,136.593709,102.960869,-27.102142,-97.301823,-134.890545,-94.693641,-34.114356,-131.374209,-196.506442,-202.328824,-170.01682,-185.994669,-184.243256,-64.69253,-20.997408,-33.792414,-49.014514,-28.51769,24.524156,25.954641,21.603496,43.285675,129.023699,255.022933,290.747608,250.854202,202.737414,109.471282,96.772922,173.19911,209.618203,223.054536,198.415655,164.520067,76.724639,30.440512,-48.742881,-64.825832,-25.708237,72.885571,115.055258,103.56318,41.221759,-51.609105,-12.467128,153.295594,188.396873,127.470185,51.846775,38.785779,4.198484,-45.084234,-114.341594,-95.849902,8.346307,140.767939,157.722029,10.883357,-94.845213,-185.759077,-130.100378,118.662126,217.887925,272.944959,263.205561,244.83103,181.820647,151.818534,145.281202,179.351261,264.854704,308.178041,304.145003,252.05919,230.44554,235.579949,263.456714,331.877532,333.650473,270.595051,224.99264,207.402951,137.086548,86.681383,42.636561,57.238172,107.29979,168.658413,149.216711,-61.307333,-181.46922,-281.705273,-262.505469,-176.922704,-157.724464,-183.78435,-135.214344,-72.385932,-46.174026,-111.394898,-218.256859,-207.178204,-127.597252,-41.688491,-23.416208,-98.267446,-171.915256,-286.928973,-306.436253,-268.239883,-225.636748,-173.831691,-200.218673,-210.896991,-190.519442,-190.122481,-210.846223,-202.825297,-209.240954,-296.794559,-339.726062,-392.193658,-393.466457,-336.956563,-289.843779,-192.910966,-166.2839,-187.783004,-198.173367,-183.985504,-188.250256,-205.599365,-197.873514,-157.370439,-53.569463,-29.381027,-62.862153,-196.403532,-259.464604,-300.88135,-286.110022,-207.00843,-148.644409,-58.581204,-123.35029,-179.140257,-166.722622,-122.285311,-89.816154,-92.216232,-70.713095,33.377003,85.38371,41.191363,-40.670143,-184.544746,-214.92408,-164.157817,-97.233288,0.243168,-46.510416,-84.822769,-140.9899,-188.881313,-281.696505,-260.813145,-113.14765,-86.141869,-130.672788,-188.09452,-173.650496,-106.713224,-75.552593,-43.571002,-42.713109,-27.580202,14.430934,24.894596,-21.01752,-76.864129,-111.796617,-49.678849,82.269967,27.91048,-29.539194,-103.078938,-124.072487,-111.601202,-63.529657,34.600301,46.822629,26.710535,28.396041,51.263813,49.684834,-13.829525,-112.442701,-73.17319,92.034603,120.310601,53.259762,-138.781878,-205.838962,-242.270091,-222.71518,-85.166402,24.01797,196.444404,159.55025,89.443351,-27.33223,-79.207126,-140.312949,-92.191054,107.774598,136.086045,83.155699,61.111567,107.88006,168.167171,161.100797,183.473577,233.669107:backward
-238.5141,-81.492499,-33.635545,-78.768891,-146.28175,-249.893298,-248.670822,-144.195784,-81.198389,-109.107755,-216.18869,-237.476864,-195.377403,-163.453977,-85.075915,-43.330532,10.379282,51.786499,63.39375,55.068807,30.189544,-52.341732,-65.330326,15.365198,93.380362,94.177628,46.368428,24.910723,8.295128,3.476234,29.5063,61.635639,111.175477,122.47723,106.567713,57.112402,28.916399,-40.319218,-58.353775,-22.289702,24.09228,6.409105,-94.607123,-142.761947,-189.984744,-192.754734,-173.777705,-153.683189,-86.859704,-15.764678,-18.288508,-67.745729,-68.871609,-17.682249,15.463559,46.463425,25.415843,22.133306,18.260099,8.76155,-29.150504,-41.290608,38.192827,104.852058,133.829012,91.848022,68.938365,-19.872274,-68.839793,-130.305981,-125.438335,-15.292701,88.197915,83.088441,1.110434,-27.522232,-74.182033,-123.93836,-142.898976,-55.43892,186.244793,271.708495,228.275768,116.76748,114.288095,172.641197,186.753313,174.030142,163.181359,157.79096,94.244881,41.981804,-67.375934,-110.439701,-91.891795,-48.78332,-20.839216,-48.819506,-54.947156,-49.01368,-63.021396,-124.341848,-126.51737,-50.024197,47.214046,66.073112,1.272886,-40.74542,-21.85159,4.274063,-18.548579,-32.481478,20.395942,99.208776,111.723242,162.331662,213.334622,241.097153,218.11176,209.788892,248.593289,268.406585,281.712618,257.403324,156.036299,108.908948,78.700358,103.719214,187.526206,155.480648,102.033145,108.32631,160.471571,162.415428,112.809059,81.396827,170.096707,197.558072,148.313021,99.873291,-3.58763,-60.101115,-91.563365,-31.714111,175.564574,329.060934,340.821998,226.637059,150.299599,110.912534,152.946884,270.919435,349.028781,355.351669,282.272601,209.77798,54.636484,0.133693,-20.857842,2.998096,80.250814,164.320731,207.69238,210.781884,122.149226,-122.780533,-172.967555,-53.757255,124.769301,142.979636,46.364767,-1.866125,-59.845334,-108.331062,-191.118848,-178.366635,-48.403689,58.102725,47.305758,-26.614505,-57.281641,-108.260061,-117.324755,-103.109906,-107.005827,-98.424449,-63.621132,-63.247582,-105.367024,-134.498122,-163.516431,-151.533566,-69.04338,45.534764,71.765106,-0.576831,-87.373017,-223.804299,-222.114456,-148.145657,-86.374116,-39.941768,31.14406,8.661358,-168.697268,-268.317431,-292.249173,-199.145023,46.290807,166.966872,143.696442,0.5751,-78.711152,-192.752127,-188.804021,-36.212421,144.757781,181.475457,95.06639,11.078899,-93.986839,-84.924716,24.503587,68.319015,70.259766,90.534814,109.141064,99.596241,76.240661,5.736409,-20.426336,8.065187,119.56776,167.580185,124.959045,32.322178,-126.287718,-140.037388,-84.986899,-77.833151,-151.838933,-151.362117,-94.657954,-53.484173,-116.027381,-277.606483,-297.967025,-188.080813,-62.21845,-50.463131,-108.399216,-137.422974,-162.381488,-178.349067,-196.163738,-171.8325,-59.660016,3.299476,-31.953254,-169.013553,-217.667987,-236.190679,-218.291836,-171.761319,-144.544667,-129.494104,-113.79625,-131.317922,-219.253626,-267.887016,-274.827193,-213.40532,-39.542792,84.205048,90.223908,-2.209168,-55.566879,-117.25464,-127.698457,-112.945224,-31.098871,8.825319,-17.872425,-69.88173,-80.232214,-19.529682,97.690158,120.244952,135.65818,76.006988,-6.085978,-144.2832,-155.082257,-124.035718,-125.273384,-144.534882,-120.778731,-117.732053,-115.318693,-97.928041,-117.697612,-172.812629,-252.806647,-240.814628,-140.283444,-76.801859,-111.89781,-238.550588,-270.692108,-238.296137,-188.959438,-64.665852,41.395791,65.335675,27.045718,-7.028645,-10.461566,16.456045,63.627847,55.152332,-22.577113,-41.758247,-26.281247,-18.65802,-35.5336,-98.117327,-119.991658,-111.121959,-49.755737,1.800016,77.518964,73.448206,-17.964417,-81.671051,-144.103308,-108.969737,63.759292,163.006056,129.362212,34.402303,29.304669,5.20127,-41.612682,-95.848482,-31.798388,4.392783,46.411698,53.259896,3.723146,-40.411852,-75.376166,-60.969519,5.172562,118.519482,172.348269,183.912328,133.961086,25.197566,15.438165,40.367906,-2.258933,-31.216524,-35.050552,-12.858303,9.799393,13.219799,76.198249,128.968979,234.409857,293.80632,264.984153,123.159104,72.976619,66.373219,72.908189,46.222322,73.651657,114.381233,120.987628,90.598515,50.407118,28.982729,17.634654,67.044626,220.078857,227.488946,157.132877,39.349066,32.382687,36.085296,12.218008,-30.782192,32.682176,70.453307,71.151546,62.194841,78.137501,90.761722,161.236367,232.708571:-73.060904,33.495717,37.735651,-32.965575,-81.888752,-158.126733,-182.320745,-158.696013,-51.052744,-40.870086,-117.676077,-142.208213,-157.511648,-169.29775,-97.883052,-2.411904,162.301185,141.483745,72.688647,-52.843521,-84.915847,-130.669868,-142.156324,-63.045211,66.325811,74.115568,46.186666,69.452123,97.246659,68.224437,29.558274,19.689197,-24.9377,-20.337387,-7.555239,9.508267,7.749629,-15.460558,-10.285099,66.633917,71.864405,-3.898317,-182.702253,-228.112345,-240.314779,-222.35467,-166.403826,-144.589466,-72.507273,50.699832,75.873262,-10.341985,-87.856953,-147.294718,-104.932633,16.850596,48.901963,22.362049,-58.116441,-100.074394,-163.220577,-151.653832,-40.002148,21.076112,124.550722,188.85719,165.618572,27.082973,-46.960582,-123.726302,-108.509601,3.573789,130.807182,161.907171,103.3276,37.792304,-23.581968,12.658265,158.104692,223.131484,309.413203,313.481024,265.780153,188.146801,193.221364,208.362458,203.187555,180.021771,153.161474,160.021128,175.82802,146.161231,-24.966779,-127.601037,-194.990359,-152.42418,-33.121279,11.693048,-14.669133,-103.151227,-138.316775,-174.020792,-160.442899,-55.816017,82.149722,125.852414,112.980943,82.935206,65.400275,63.20819,15.390208,-5.575435,28.05425,96.966619,107.281566,87.19152,80.537195,120.595771,164.531641,233.161588,258.006601,269.934003,255.596215,197.964918,-9.843962,-86.288423,-33.416044,49.07359,147.260973,92.277567,36.494897,-31.806982,-57.732433,-115.498276,-113.709716,-37.752923,54.032471,84.181292,79.150713,42.160539,-68.502521,-114.908295,-106.132594,-35.858536,147.166075,199.112179,170.198593,95.529209,72.272411,67.397675,82.89033,151.730647,254.298008,288.122518,308.076652,302.410334,200.106441,105.051849,-16.240139,-4.839651,135.215627,274.678332,269.205302,142.660802,79.76007,19.573953,17.710848,36.283052,69.577094,100.246778,83.86673,9.628493,-109.459548,-105.95035,-59.191312,-36.352858,40.456807,100.884641,96.867006,15.284935,-48.192372,-157.701666,-179.230715,-168.05149,-131.348435,-121.03856,-138.825661,-143.60263,-176.45864,-236.893021,-305.170753,-250.548901,-84.953672,-66.541908,-97.800107,-160.764045,-207.43875,-306.658325,-298.913216,-156.900411,-35.461792,-9.011598,-1.434557,-31.528911,-159.060493,-200.727493,-136.259526,-62.210529,91.161203,203.13629,189.720396,25.391135,-69.77791,-154.56366,-120.981254,11.66249,103.166131,124.115905,81.685069,23.384125,-94.635626,-121.841962,-61.634258,12.088017,179.531624,231.927091,178.307608,40.694996,-4.201852,-19.938121,23.191151,103.51672,107.859389,137.853112,186.979317,150.143955,38.465765,22.604016,8.835963,-41.883867,-149.300958,-121.350986,-94.731089,-118.85398,-167.756179,-241.381404,-224.510486,-100.702944,34.135313,77.283389,60.80721,12.204919,-59.559392,-74.692113,-99.25351,-90.4579,27.581019,111.248919,63.40298,-109.720853,-160.457924,-143.563918,-98.060165,1.883129,60.118897,51.454567,-11.483501,-21.119814,-21.177074,-42.303163,-65.702446,-37.116416,74.539178,152.06432,147.820656,52.205081,-12.613961,-41.881325,11.575526,103.01108,84.614883,64.41012,14.488744,-14.246167,-38.306727,-9.861522,115.202085,173.843374,186.473369,5.846978,-118.198291,-281.970567,-290.92278,-190.284278,-132.104585,-92.378923,-80.868971,-75.478899,-72.46684,-60.148461,-60.471415,-91.518423,-140.009819,-132.300289,-91.941288,-125.30759,-153.409066,-177.917894,-212.160625,-264.675175,-207.417294,30.722688,210.767556,211.478145,13.034039,-110.983256,-195.259727,-144.992918,-5.728704,33.422417,77.886847,102.094343,74.94497,-15.571049,-29.157468,-0.615502,5.361129,5.188321,71.323779,129.891629,170.880739,131.503438,34.180734,9.687685,-10.512232,-10.3325,63.095532,173.755797,174.011641,58.15243,-6.965088,-67.791863,-65.801965,-29.565849,14.636802,14.856874,-41.706283,-65.876253,-83.136875,-103.35071,-117.586572,-61.354121,133.452746,202.668069,177.897289,110.263962,59.347083,-75.58129,-98.560122,-11.388772,15.172891,-28.779722,-95.239641,-83.660165,-55.272138,-66.883959,-48.931596,-3.222835,91.478669,181.628775,220.10134,231.839799,187.395555,26.131445,-25.309221,15.137009,79.203926,63.245677,1.758782,7.119457,72.778207,89.271805,103.119113,138.713397,266.297457,283.733543,231.801055,129.050224,87.587163,0.816348,-14.929316,45.849434,83.14131,65.892418,72.139044,106.571652,118.65635,93.863059,123.596633,191.526179:-104.733723,-104.720802,-116.257471,-107.910859,-124.75566,-220.394353,-249.708316,-212.821456,-149.655912,-154.99774,-208.741619,-225.223418,-252.356585,-263.730251,-210.057626,-139.559974,32.582287,88.461246,29.399639,-145.037874,-191.050686,-131.779363,-60.461394,30.981311,38.345946,14.60376,-60.535926,-78.718417,-56.485388,-42.446731,-58.013347,-68.151467,-4.500186,114.255404,137.404216,85.261143,15.583335,-78.868035,-43.30977,63.289527,25.075652,-30.404315,-143.801687,-180.761209,-210.731673,-214.114996,-206.416909,-187.227585,-86.555528,26.095318,32.825444,-47.934615,-96.361312,-105.480118,-60.137803,26.944022,59.029914,56.042602,-21.952346,-77.434053,-118.408405,-87.95199,5.221429,48.628528,167.567584,236.02879,196.097235,25.221445,-58.447689,-131.91705,-109.395144,-27.750117,81.103009,145.822014,182.452701,136.321287,31.817637,34.492909,192.786579,290.561903,349.57426,288.884393,258.956973,214.086134,201.741965,215.326793,237.986422,243.039689,172.317909,141.732132,103.408686,69.939373,-51.961313,-111.156298,-154.945441,-142.716277,-98.445953,-64.072824,-62.223202,-68.714213,-67.087435,-75.976031,-65.28095,68.082239,189.625875,173.582884,61.472922,5.512937,-79.077241,-83.028829,5.689938,67.534225,167.117524,220.386814,209.845463,107.494963,67.580952,130.366255,202.528197,285.040283,294.292032,288.231593,233.295239,168.571262,-33.259267,-118.024137,-119.57526,-65.981803,10.621225,-22.487942,-75.461755,-152.27182,-163.674908,-165.309666,-139.748164,-25.546334,78.818718,93.338672,30.194337,-25.844416,-134.969285,-170.226468,-143.049386,-83.410967,41.818046,108.802425,97.437444,-10.423131,-53.743481,-25.718178,24.969319,105.46939,161.400403,198.709109,226.573913,176.372843,7.719206,-44.546478,-26.663075,16.968822,109.306979,226.302022,273.40637,227.157291,141.934177,19.996794,30.432905,136.345096,172.829351,142.498226,75.64051,58.372813,-6.785434,-61.70988,-86.14739,-17.866585,169.664486,204.159655,140.698661,-7.811163,-45.400433,-44.929173,-31.586513,-28.834141,-22.24115,-15.160556,-45.051725,-76.077001,-161.104376,-200.604431,-186.181065,-140.464726,-57.345711,-4.849172,-10.518607,-119.044489,-190.228603,-267.421456,-271.650608,-254.024391,-160.00235,-91.815713,-24.659784,-49.182797,-174.505648,-215.398319,-153.632587,-86.251014,19.98047,14.94893,-28.815812,-121.762865,-170.124407,-227.334875,-196.066958,-64.793842,46.585514,86.374863,69.105596,-3.705743,-134.998988,-122.008275,-0.17298,34.656356,50.273986,97.117746,100.10943,12.215815,-57.220138,-105.693794,-49.775392,110.929628,231.037885,266.311195,211.043911,133.828063,32.29345,32.019741,26.760883,-20.899304,-109.71449,-88.069904,-93.690609,-182.28497,-218.49927,-182.35216,-140.358012,-96.120595,-10.407694,32.607785,-12.581497,-67.099488,-87.823465,-62.869421,10.310477,58.870744,139.652915,128.483879,89.464644,-6.214975,-48.343313,-80.516095,-56.273223,24.032244,41.783783,28.803942,23.31767,49.211771,95.930383,90.141534,94.284972,131.060482,215.130422,202.193344,145.368191,-14.535893,-79.737013,-104.971834,-54.38161,109.458333,214.128627,212.243279,126.655193,82.044627,25.72471,9.717585,42.380178,97.37467,198.066543,146.470022,65.961677,-66.096074,-97.963201,-146.772797,-146.259233,-36.481747,98.64862,111.395128,34.192774,-5.87605,-22.606613,-14.141437,-11.248057,-23.32505,-45.564273,-42.696894,-66.288508,-204.622092,-267.246626,-207.009796,-86.322741,191.443987,303.49557,257.947267,89.868502,28.701593,-47.138423,-76.02814,-60.136728,16.408309,250.929616,286.44049,188.462499,0.509422,-30.472397,-1.878005,34.673076,109.501453,180.203587,203.145583,176.977218,142.433904,108.34479,102.865435,32.783132,-3.327713,72.545304,167.58917,117.668532,-85.204719,-145.569544,-95.652322,-28.231046,70.159452,144.762093,150.575375,36.897099,-35.016088,-70.336039,-36.552549,33.032042,57.777037,143.111999,222.875327,215.808345,127.733374,70.925661,-5.548501,-13.845565,-16.451401,-11.98561,2.096213,29.233959,37.145081,36.025702,16.862363,-22.246963,2.553269,158.013608,248.121761,213.632559,87.513565,60.858568,86.325338,97.597135,78.36897,83.096429,105.266871,107.307088,80.242645,49.096404,48.286776,49.221451,79.491475,234.604164,281.859073,215.476592,53.155081,7.337252,-38.224146,-60.02963,-60.113482,11.931052,28.182452,-4.914128,-15.488907,20.866189,45.16064,72.38114,99.396654:-261.325136,-174.780221,-151.661168,-230.641604,-287.770703,-359.812573,-365.417975,-299.019872,-194.594786,-178.504078,-268.718745,-328.32107,-338.450289,-287.940458,-146.131856,-80.715356,-7.64515,-23.04312,-50.79448,-93.183974,-109.770763,-126.410764,-94.507912,22.848818,14.397277,-43.939288,-105.24043,-83.753802,-49.504929,-60.463604,-64.45292,-33.123188,86.420221,178.407834,171.705878,80.52031,30.046169,-29.291783,-34.490569,-41.927805,-39.667793,-26.108748,-62.235909,-130.230372,-259.098082,-274.294688,-239.802792,-225.992125,-168.576215,-67.037082,-44.680159,-56.638828,-72.924673,-101.651143,-91.294724,-6.177096,88.909907,125.108589,113.991196,50.975237,-95.886951,-122.697478,-70.809026,-26.3748,51.716008,74.399428,38.993136,-99.877733,-177.001746,-274.89474,-256.41562,-102.872031,35.135708,69.012159,63.709099,28.095162,-83.493173,-129.149529,-86.696319,-4.585536,148.082953,189.360075,160.763835,76.269739,61.576371,110.418757,144.93224,162.008129,157.428204,161.952548,127.893797,72.417076,-63.90538,-101.009801,-93.397419,-83.307871,-48.708093,34.750039,41.238712,-22.268404,-51.128983,-42.488008,-0.310432,129.27083,209.799872,185.465601,75.577676,47.012561,39.387008,36.899005,56.54727,84.512701,163.342351,232.84909,245.999775,232.570319,202.92816,137.510461,151.047839,285.850093,402.074952,410.387355,309.088952,228.086515,121.897451,113.750783,131.192606,130.678795,125.701962,115.824014,87.363376,46.863423,44.645593,19.653969,25.601046,118.913691,169.765171,152.865772,59.412044,10.401052,-77.342838,-122.273626,-124.058871,-64.292267,91.635837,187.222593,195.693563,146.801323,106.66804,70.57973,101.196894,216.930239,243.268528,225.137511,199.104994,179.826234,76.183708,2.178575,-95.466133,-88.490292,51.65605,232.099188,262.245267,201.20376,145.100291,20.39115,-21.523384,32.160563,161.909153,177.650915,89.184985,7.88962,-166.68957,-211.195092,-122.595927,-37.76386,69.585577,149.521702,173.192559,121.156922,66.51567,-7.788206,-13.18229,-0.697917,-0.173076,4.526433,4.699221,-11.116156,-80.990527,-113.644173,-123.831502,-111.632789,-34.948175,100.41504,120.887909,28.204428,-46.933784,-156.27929,-154.924692,-69.977581,9.726319,34.576248,35.190361,3.689105,-143.303522,-230.013753,-264.368167,-202.880957,-56.066679,45.368362,69.160371,7.537237,-78.116906,-219.984179,-206.043728,-44.309182,63.944113,57.946012,-68.313808,-150.29259,-219.656811,-189.751051,-59.914846,-1.434149,33.226314,21.387238,19.975122,-16.786887,-59.216414,-125.274267,-118.348053,-33.103069,64.901591,98.47568,114.877708,99.303851,45.912222,14.189372,-47.187227,-79.338854,-130.197855,-117.028709,-105.27406,-109.535975,-117.600134,-141.998217,-158.478447,-136.441863,18.932741,84.231318,25.969998,-68.133567,-148.801308,-101.119944,14.362528,45.48788,101.205494,83.314017,5.353943,-174.200307,-220.46511,-242.218667,-236.097639,-186.188741,-112.263928,-88.600823,-92.927428,-101.738032,-86.082817,-86.586614,-119.515266,-112.155396,-6.068065,143.128284,168.971798,62.55938,-32.60766,-183.240491,-193.191783,-71.106259,51.814312,53.595411,-10.14762,-20.542003,24.75692,47.970483,80.247915,108.791039,162.217289,114.050886,63.25591,-11.78461,-52.111149,-133.863285,-130.321294,-72.294431,-74.499062,-88.016134,-95.262028,-70.345062,9.07392,2.593925,-103.089312,-128.287035,-75.009701,-55.058785,-93.757967,-212.742618,-261.74758,-260.315845,-203.44025,-63.530254,39.706537,79.294033,64.531138,4.443264,-90.228003,-82.323728,10.309846,58.170605,124.338853,135.72203,109.197581,32.260218,1.632536,-46.348631,-66.804936,-53.565572,38.348033,76.170273,98.786594,89.914534,26.222743,-9.046544,-23.075423,-3.045077,83.953675,149.868626,114.826636,-27.123199,-50.750365,8.151612,22.372082,4.527344,91.088633,147.336079,134.176094,83.374484,10.838456,-0.653947,21.929154,43.664403,108.871631,210.463543,227.077033,140.654801,57.654432,-65.54029,-56.084514,39.449852,64.560409,50.712795,-3.048524,-38.001536,-95.206792,-96.486447,3.353905,77.628692,168.189352,190.65452,162.685565,18.417038,-43.247293,-53.604764,-13.308059,57.226949,44.974287,33.122924,46.35552,70.588481,91.134104,70.08969,53.614993,88.670618,177.939872,186.89099,167.082964,116.204871,79.756173,-12.051755,-51.442449,-103.717483,-60.831257,-8.395066,55.09178,61.874695,49.936388,46.931899,111.094739,160.947594:-156.972956,-156.19638,-166.534718,-239.337175,-292.807864,-370.348684,-366.139858,-266.201381,-146.013281,-144.937629,-262.665061,-326.514979,-398.15998,-380.585035,-201.720614,-99.772834,-7.793228,-27.337484,-66.564126,-195.052229,-252.197315,-232.95121,-152.104399,-8.110318,-8.331662,-41.875132,-109.077116,-133.420058,-181.243035,-192.179243,-132.298297,-64.163914,94.076054,175.784813,160.912631,43.947681,-37.634174,-145.453143,-125.076332,14.632072,95.830946,64.28899,-142.531318,-253.614806,-325.093995,-290.428565,-188.061015,-144.482819,-65.785079,-27.539403,-47.146312,-122.403508,-139.616866,-108.372558,-77.571839,-9.393161,89.478072,143.297751,181.280934,127.072013,-67.300163,-106.493093,24.047634,109.023364,153.477595,89.056805,43.563771,-67.513518,-138.981054,-253.43362,-243.857429,-68.833688,145.338179,195.790746,137.720268,51.359172,-111.115856,-123.781602,21.472714,109.498332,192.914947,211.521466,201.861736,152.543749,122.928916,114.082968,144.385797,165.850847,138.889529,150.625444,146.433153,98.066282,-18.382769,-42.514597,-50.225898,-48.815628,9.716339,44.846702,-0.241489,-119.923127,-144.204984,-91.256683,-16.693456,148.082751,202.698148,169.878302,17.827827,-48.516179,-78.195931,-55.327619,48.476945,131.894745,316.609143,372.800528,324.201009,186.196744,147.120847,173.160721,230.769616,347.743648,399.83326,400.074857,289.244184,188.040027,14.013597,-27.453346,-2.772715,49.099402,148.375497,122.865982,73.078129,3.070384,-13.021898,-9.101226,25.440619,128.580495,169.214141,144.785266,52.1156,8.951781,-75.86174,-102.385612,-51.018741,6.562109,119.650168,213.523024,212.355183,74.739117,-16.875221,-87.9752,-45.085079,116.149947,209.368896,204.85883,132.589357,79.058556,-51.107346,-109.125061,-123.631098,-70.532931,98.064089,241.209233,249.596402,131.192831,64.933486,17.13805,9.881898,-8.690759,85.788897,151.556031,144.272881,73.927549,-85.842013,-133.796518,-94.181361,-24.485021,105.572315,146.579526,137.632008,82.590365,33.400238,-8.005968,39.506564,131.336611,94.702979,64.839365,9.590448,-24.1339,-123.434941,-175.737003,-179.588598,-116.492277,40.607073,127.131995,117.885845,-21.4028,-112.955372,-202.807762,-184.859523,-108.139426,-22.286415,15.080707,11.180768,-22.863187,-98.471672,-135.675378,-176.206341,-165.121259,-66.795341,64.901093,95.285103,30.286325,-55.400893,-216.201415,-224.173825,-48.214112,170.10927,196.178259,23.751621,-100.124205,-209.613983,-178.636599,-1.816313,89.772416,121.858365,20.804787,-14.730806,-78.672088,-114.113024,-118.277925,-73.895094,75.482541,231.64334,264.902145,211.248602,164.534865,101.514533,90.159596,123.12292,143.891685,116.457285,14.565772,-38.797283,-105.799724,-112.081951,-78.82724,-67.892158,-51.262748,147.19036,247.826817,143.744395,0.397587,-117.12256,-74.73448,58.85165,120.77601,252.602631,291.81292,221.179262,-65.62103,-195.526776,-200.068305,-82.904733,147.457679,178.499266,151.376933,117.840904,111.982489,60.850528,30.085242,52.782156,102.394751,201.278214,225.398914,202.212398,99.120859,29.234237,-47.042433,-17.11752,126.222446,188.603748,147.505969,40.935673,30.028078,52.594705,64.951592,128.030816,190.127392,329.09444,291.60961,174.765919,-72.417862,-130.211346,-130.983514,-118.071101,-79.900934,25.943404,55.153161,-26.209164,-95.897385,-182.056707,-196.125041,-199.219762,-198.845257,-178.462691,-163.806527,-194.538475,-293.840996,-312.983365,-269.728873,-233.322205,-88.64909,153.142076,208.596723,110.367605,25.914597,-102.365059,-134.938942,-93.172504,-18.808766,117.532459,107.738046,71.008288,-21.942794,-63.454222,-53.647609,-8.873678,53.889915,97.514266,118.399516,71.172658,8.750056,-92.242403,-104.906566,-99.657455,-91.748808,27.817245,115.44062,54.92136,-99.787472,-120.909476,-95.372759,-68.22867,58.349772,246.414124,293.699863,201.508055,98.470533,-44.496269,-48.320481,37.495021,83.178966,131.839774,170.214081,173.917341,97.07073,24.068465,-81.836028,-69.418818,53.292054,169.028602,188.569338,138.254373,78.958498,-55.324718,-82.21342,-1.726419,64.35541,146.056836,150.087949,129.183867,47.16321,-1.764591,-60.120679,-58.279899,-10.872012,97.649542,155.31659,170.283306,128.554002,41.916304,22.724049,41.613881,81.682727,219.422931,304.001033,279.466964,158.294339,102.469964,25.48761,-0.372208,-40.902362,-19.107129,9.550543,26.295727,10.76961,-18.963334,-10.483159,62.161259,110.621466:-249.657477,-236.564144,-283.403527,-403.669287,-425.033605,-412.967864,-381.330644,-246.035034,-114.823012,-112.563542,-264.666969,-345.908346,-383.381043,-349.82561,-219.767957,-157.236038,-101.761252,-84.025849,-86.964214,-129.054135,-160.295823,-210.677971,-197.925668,-79.139878,0.564687,-20.985606,-120.441217,-149.76068,-156.422058,-142.32733,-54.304717,0.632963,68.356685,119.374917,126.533473,70.559735,19.948107,-70.074035,-75.773859,-32.70654,-17.050246,-25.579868,-103.886547,-156.924361,-223.106435,-229.687246,-159.010532,-100.952038,-72.591487,-94.588911,-72.916017,-35.319481,-44.052499,-82.691723,-81.184403,5.457698,162.42668,220.008096,179.617539,94.98006,-62.788723,-87.842811,3.683037,56.672303,39.474306,-25.558749,-53.033268,-116.551656,-131.151063,-130.765546,-134.725662,-97.393052,13.168089,48.940146,-68.030594,-197.964259,-341.077666,-317.607083,-171.211498,-85.08525,25.181741,6.080298,-51.121413,-176.312356,-179.889687,-70.326141,-14.02419,4.596102,-42.435471,-47.218415,-43.60164,-57.773993,-97.448579,-96.482704,-29.92027,7.167969,7.536325,-53.144308,-69.211884,-35.710861,-12.449064,-3.683714,8.364708,74.458718,91.955329,48.435405,-69.411456,-86.814033,-65.975707,-71.218128,-65.665641,-25.118281,87.348309,170.696875,189.054737,193.76634,190.310989,164.185451,156.975996,205.646483,315.094035,344.229677,292.361054,257.483237,228.433934,206.349854,167.156355,174.675894,207.262656,204.218701,206.039311,279.291343,311.311068,253.525552,194.10642,142.200297,215.419108,268.412873,260.532336,173.076133,-40.909777,-103.650844,-84.290268,-12.218024,148.947068,221.271384,210.947289,148.196691,134.034362,137.713986,145.472767,210.004527,264.264537,264.208729,234.817231,186.877058,34.693729,-18.085355,-26.868579,-7.966689,56.476301,179.690246,228.648519,179.701747,85.926947,-71.610917,-75.165052,45.886364,148.95312,133.005958,-1.618391,-54.358807,-125.238587,-172.222781,-186.457224,-127.302901,9.523592,78.173031,88.349765,57.770986,25.141517,-12.910463,6.755593,116.142947,202.900067,198.860259,103.219516,50.326353,-8.216393,-17.846926,6.394889,29.739205,80.816837,172.38199,183.73089,87.202849,31.486005,-20.833619,-21.750349,19.516181,75.109888,79.806156,17.130106,-34.87297,-140.410214,-190.673908,-244.983021,-230.147006,-114.819912,30.427549,67.43493,28.323398,-52.819793,-284.769767,-340.645902,-172.144312,94.444135,148.298036,67.596287,-28.944864,-176.251929,-178.246849,-15.806903,86.233493,137.139645,116.179248,133.545051,125.295814,73.972463,-57.118025,-70.838569,48.187408,222.373195,269.926925,219.336592,144.985426,36.735527,29.788886,41.699304,23.140331,-54.060802,-41.003767,8.918306,52.218515,-0.341296,-166.943038,-189.429584,-34.511621,156.720287,165.732174,6.522675,-81.146393,-124.10989,-100.278292,-56.557334,-48.714285,-30.172519,14.103174,2.433045,-128.934472,-200.169236,-235.917712,-212.269374,-178.941669,-194.316715,-206.520687,-255.787541,-269.502887,-220.984521,-207.467571,-221.503636,-189.208321,-42.301093,81.573127,102.010014,67.556965,21.401024,-135.879907,-195.82228,-154.403428,19.408385,86.44076,53.016968,-23.701373,-91.113506,-35.534138,171.145362,259.202287,310.732103,236.160896,186.826044,118.999675,103.240306,40.56203,-17.613813,-90.623874,-56.549488,-54.223514,-82.947371,-65.793485,-0.466191,2.545891,-44.2934,-84.376673,-162.098614,-155.82175,-142.080566,-170.410232,-202.235156,-227.190903,-204.599771,-97.710994,50.395631,108.913884,118.616879,80.611448,1.328257,-16.384888,35.651612,75.543911,75.527498,13.559832,-7.028934,-8.378815,-13.874393,-119.827173,-186.566463,-205.487554,-104.061827,-34.650578,34.433245,8.85186,-98.960607,-147.211065,-172.119114,-133.952617,26.070221,135.232896,121.141254,54.25282,33.788089,-27.077583,-66.579065,-81.565233,45.61785,126.490052,181.557117,149.193696,61.948387,34.236748,32.995162,47.874693,63.719258,131.383045,193.992511,223.183796,158.735874,36.719653,41.876803,89.412337,51.636639,26.45248,12.662453,24.778332,49.37455,47.196434,77.95491,133.190163,270.713648,331.309421,291.494529,105.067343,16.362949,-89.962598,-110.388981,-79.175307,45.634334,119.447063,164.612566,129.48813,51.489893,31.642093,38.636114,62.364387,139.632286,197.431467,170.584658,72.936436,50.207373,15.981131,-24.28023,-93.646015,-29.769609,39.346675,142.722224,154.066461,125.272468,122.286706,202.198087,250.414594:-125.608573,-99.158418,-128.429539,-259.817854,-328.13739,-415.752284,-422.063822,-322.668692,-142.414765,-112.88346,-262.199969,-371.921717,-464.993896,-422.709729,-241.894712,-171.713108,-114.441021,-72.262783,-67.77606,-153.283954,-234.919752,-334.105054,-287.346918,-92.78673,-31.029197,-79.862964,-252.878448,-298.791056,-231.930841,-178.734681,-102.029977,-49.502167,100.992467,184.188018,149.267587,-4.812469,-75.648991,-135.954675,-116.24224,-58.891244,-37.322258,-27.918675,-66.254032,-124.255387,-238.549537,-276.259699,-296.184635,-267.016657,-143.725202,-62.114626,-87.8693,-172.70957,-176.825038,-136.992214,-102.982065,35.916504,201.290042,237.108785,174.612646,107.274233,4.726072,-6.975439,41.124701,67.3926,67.859979,8.1661,-32.859835,-126.729735,-180.548415,-245.834809,-226.518509,-90.457228,53.958633,85.659826,22.519879,-58.820071,-210.546349,-234.220312,-135.545471,-51.222719,58.541827,66.55566,48.324486,15.196404,11.00053,1.298923,-0.853877,40.691125,120.252846,129.49335,42.595784,-20.773037,-108.610957,-112.195665,-28.228998,19.157429,60.087921,40.893918,5.606072,-76.145617,-109.142559,-110.140182,-51.62396,135.531962,248.918293,223.960736,50.304884,-25.814169,-77.238548,-70.551411,27.736908,127.122085,308.30832,367.873226,360.037868,273.835128,207.775459,142.969697,193.105092,409.464768,569.963975,568.389315,385.553104,268.874821,141.321197,128.331695,156.716161,186.025872,234.774017,198.919501,155.031847,117.55713,116.338072,95.365773,105.787121,187.046953,205.560717,186.288202,144.442469,99.269772,-89.983467,-172.306984,-111.962457,15.190847,251.370629,291.712654,255.689375,164.423671,106.489056,-1.173986,6.35374,150.349046,253.710526,246.598931,155.113539,90.316144,-68.314214,-133.019237,-129.485227,-71.339751,95.327239,270.669343,301.497159,187.677667,64.373833,-170.726778,-208.341604,-93.195903,94.809592,140.131484,72.027882,-12.813524,-188.281154,-234.894867,-168.255065,-93.733372,50.964752,195.012489,213.08897,93.604965,21.981625,0.165112,41.745249,127.282387,161.486563,158.588307,80.722737,20.104262,-58.717186,-52.08135,59.064348,128.507564,219.6579,223.524381,185.321388,97.377393,64.660042,-5.466537,-28.679755,20.081099,161.794772,205.369957,149.530863,70.422316,-111.903124,-189.15593,-211.525948,-157.050943,-28.272491,78.486514,110.041866,61.219586,-30.026809,-216.445903,-217.954866,-24.229538,152.477931,167.075687,53.560347,-29.79628,-141.137173,-148.31926,-16.87257,87.663389,190.372638,161.894738,132.532621,19.373214,-50.94764,-119.380068,-108.632415,-20.346571,194.825333,299.993012,300.86007,189.704261,-59.612244,-97.888812,47.75561,138.479823,169.081109,118.323018,104.32539,70.354892,40.84813,-19.613915,-20.983389,73.27373,246.943754,291.994606,158.992126,41.313269,-36.112633,3.632028,95.764883,138.447175,243.959787,252.663596,157.645409,-149.308764,-258.807778,-241.44546,-160.71754,-45.329792,-2.52273,24.400319,26.236753,-5.691716,-29.82082,-24.359081,-28.921553,-18.282595,102.629329,254.312599,253.833849,114.735478,31.142899,-93.221769,-105.791003,11.245681,167.698494,193.029178,140.130468,94.980397,15.484398,10.99541,159.30522,278.13008,390.649479,232.393302,108.111037,-55.168452,-83.507867,-105.979531,-100.066991,-43.347973,-11.190276,-21.889074,-92.991866,-143.477546,-242.789808,-276.1115,-244.147602,-184.122637,-88.809058,-119.624441,-185.19746,-367.734345,-425.690501,-371.169521,-291.488687,-109.231467,80.970901,124.679318,59.548473,-11.302279,-179.518195,-254.086157,-233.378651,-136.003006,39.575631,23.2277,-50.50631,-188.00774,-212.047673,-211.21876,-205.89433,-172.708427,-86.87082,-31.333115,-1.938641,-73.937585,-297.576512,-344.719139,-240.116612,-158.039471,-35.172601,40.953327,34.309009,-47.743385,-100.167949,-194.61443,-187.889434,-9.858498,196.535695,241.0899,202.164237,133.197521,-59.071664,-132.697557,-112.002887,-33.036592,149.240235,246.794932,242.594749,133.068091,48.938535,-15.107219,38.396248,170.224815,217.112894,219.541815,159.893173,99.199067,-27.374939,-64.033994,-17.929668,58.028616,211.555414,289.399855,274.224129,122.745337,29.785224,-56.018623,-37.17935,46.214514,187.881206,252.974811,214.65595,133.03793,22.960709,11.742716,24.377745,49.04873,157.042179,244.694724,232.862274,136.072844,77.648545,-48.345961,-88.684957,-59.455959,17.85334,32.572837,37.21489,40.514958,14.47384,-5.56337,52.17673,123.549617:-106.875305,-50.54771,-52.981253,-74.731092,-91.61947,-147.999032,-147.412492,-52.744304,39.330103,58.527523,68.489881,66.458377,41.653469,13.212552,-47.28715,-50.09241,-13.340132,-3.93017,-12.397884,-37.600066,-57.008152,-122.479544,-125.800598,18.529318,167.908296,161.306478,8.136622,-61.456107,-45.044045,12.733904,98.8723,113.560287,128.129395,159.944932,157.559025,91.2953,48.325505,-12.033319,-22.84636,1.036646,15.459412,-4.046739,-24.471427,-25.157386,-85.487397,-126.642789,-105.283268,-52.033606,1.224935,16.440179,32.244976,19.418126,-1.644779,-17.422527,-2.45172,95.25832,283.192827,352.891896,288.913491,195.393122,100.287747,111.911342,180.915595,202.407731,149.034663,33.984833,-8.063645,-21.682762,-14.376925,-78.903919,-116.888634,-61.098895,57.349601,68.218046,-60.044072,-148.831835,-223.676817,-220.370112,-184.920689,-164.350372,-185.900119,-267.147335,-327.388212,-413.880152,-364.444502,-125.25859,-36.411767,-25.9737,-83.706303,-75.728028,-35.686764,-42.810538,-74.745019,-62.191851,37.545932,90.380995,100.957503,3.737958,-46.525037,-80.564584,-74.646993,-70.271796,-67.95831,-64.558482,-58.29012,-67.959091,-138.328771,-171.534072,-204.443551,-225.524718,-241.783526,-208.758568,-112.136068,-92.502272,-121.717477,-179.966136,-188.179385,-150.814573,-91.38186,64.245173,106.22985,94.814122,123.26107,138.144257,95.221391,72.244636,96.209928,112.617716,82.934732,6.752626,-5.274681,67.462918,108.394368,107.092692,91.234433,118.721718,204.446311,250.245836,293.962856,257.217798,40.106583,-86.604123,-193.437355,-155.622742,26.97302,169.672485,168.141013,77.055839,42.311789,50.170566,93.416902,219.728346,233.79907,177.680786,75.360286,51.583043,10.907208,-13.269675,-38.855762,-24.661607,42.30313,112.365103,140.516477,112.003644,46.475146,-66.485174,-69.947881,10.178281,65.848105,46.634344,-55.203448,-105.627321,-183.974747,-217.03537,-242.604961,-214.372139,-103.170246,-7.990715,20.208357,32.388651,34.982886,100.180709,154.471051,188.030103,132.083968,130.186315,136.234668,109.094841,37.406303,15.616136,0.40581,8.143966,67.717506,165.105908,186.305566,149.679784,123.100534,50.458962,3.28143,-64.587388,-63.116349,-22.054671,36.979767,-10.153826,-192.00746,-237.246147,-215.273742,-208.929888,-211.823001,-88.18514,8.410249,72.47527,-0.33493,-200.086779,-225.563139,-85.323812,73.041909,95.595685,45.238793,4.889477,-14.125769,18.599753,133.620752,185.453698,217.22173,229.693127,248.779938,250.516834,203.405318,60.155247,31.736851,94.404117,194.879278,257.778211,341.710865,316.997247,207.413625,183.328092,199.726764,203.387268,158.466634,135.028704,141.733636,123.078497,85.323472,-28.523572,-72.918151,-54.974878,44.118307,68.884806,23.232084,-18.28235,-40.373406,-24.841454,-22.088374,-37.753116,-9.072228,96.034832,98.430775,-4.530619,-43.223096,-21.286038,8.433721,-22.605562,-155.661611,-193.160357,-189.784613,-192.278187,-251.231039,-282.520793,-245.448604,-170.58908,-2.831791,92.171442,83.94283,8.449494,-12.316593,-21.614686,-27.421714,-72.949235,-79.705559,-33.632412,55.414405,66.492249,45.479882,37.627308,126.666373,228.746165,383.515222,362.819353,330.331974,312.028901,315.849178,256.520713,185.67549,40.04557,-45.622136,-78.035794,-127.938235,-111.048118,7.40949,48.555638,3.957143,-50.630879,-86.671206,-5.37245,25.178074,-4.211292,-52.449107,-174.667087,-196.63004,-82.92385,43.776468,72.840211,124.521057,151.199368,142.682898,105.583007,84.954869,108.691303,117.524847,107.327063,119.473123,90.175824,36.402794,-64.09327,-88.210898,-145.422818,-190.094431,-120.811062,137.678086,204.705127,112.023808,19.649257,-54.785714,-22.355878,42.704674,49.10546,64.968797,129.860788,142.606309,35.154928,-50.421957,-84.544106,28.7283,60.094186,37.08257,17.181834,-1.538308,-18.395275,-46.656503,-30.769136,53.842173,135.708478,149.111359,103.65149,59.863868,-2.419238,1.723045,10.953605,-112.400515,-164.475727,-118.859394,-65.529373,-13.99864,-10.424072,-3.57206,-0.937441,45.718621,183.64999,229.158356,148.740987,34.500044,-160.241452,-178.847943,-112.782798,-59.047712,-24.736903,29.9232,31.181782,30.306425,20.66543,-24.011065,-21.786517,35.849668,45.137773,46.042122,101.522436,116.550441,43.252726,-19.464133,-91.841875,-43.587322,-6.498798,45.023885,82.586929,184.205041,198.436605,143.158081,116.457352:-176.989837,-73.642885,-63.465076,-67.507907,-90.11513,-222.338012,-269.359599,-190.023822,-89.765314,-101.8519,-156.217574,-150.628159,-108.02704,-94.018674,-41.616905,-12.283022,10.455244,50.803023,49.105567,-44.882019,-88.63464,-87.756281,-37.026799,130.165339,195.671063,157.498367,92.246074,115.654277,186.828059,188.304566,176.323676,180.410845,178.79927,191.17419,204.462912,233.797726,224.728227,103.486975,32.255934,-21.523496,16.222404,29.93459,-24.367922,-66.809974,-100.571844,-91.850807,-12.729375,27.783942,27.743492,52.539036,92.599374,122.958204,100.334184,67.509392,74.791794,94.904877,151.988077,198.000757,213.777887,166.281832,52.604637,32.683194,125.600766,186.685025,181.773305,136.210753,125.798449,49.051754,-9.314522,-88.381242,-84.210595,29.025117,142.074166,149.165499,84.427628,31.484874,-79.313867,-130.973885,-129.353293,-41.831807,139.809792,33.137539,-121.446777,-315.975505,-248.750061,39.75667,113.63287,32.801782,-99.998547,-107.208597,-49.146948,-23.567595,-19.575277,-33.22844,-16.971585,15.162311,43.877808,-22.472014,-71.652648,-138.368259,-163.368346,-183.600595,-158.533701,-129.072807,-157.005526,-147.534369,-96.791519,-80.64565,-84.874112,-101.995128,-125.233915,-109.297044,-34.416337,39.033446,66.52081,95.397184,93.152256,93.582962,130.203713,233.113344,271.76808,291.311561,299.062741,265.462692,180.134969,149.772456,147.496107,168.818957,180.335992,118.545481,90.415673,120.267055,152.681813,107.022023,44.24548,9.096895,110.83008,145.882677,110.74826,77.558643,23.964056,-21.366276,-80.836957,-38.477626,154.630323,315.01747,327.642548,223.320126,162.115441,114.434347,115.974266,124.064967,139.340852,148.58111,127.498504,93.443083,18.656199,-14.723926,-83.307882,-111.356213,-83.687538,73.226919,137.237283,99.08931,14.699464,-97.421188,-71.723633,65.831018,130.901343,125.128444,99.251739,90.23629,-1.088664,-94.129148,-206.82144,-174.193446,-24.796014,64.13263,60.542448,-34.750352,-80.321869,-71.331478,-29.600574,30.383908,13.763506,14.152568,33.461074,13.197881,-110.596772,-176.871615,-224.841246,-214.438265,-153.826054,-15.392944,40.210746,3.962963,-63.757621,-171.003527,-202.685296,-241.10807,-173.812401,-98.146846,-30.78685,-82.350623,-267.215122,-339.335264,-367.494455,-331.709076,-169.783425,70.542029,123.34772,-7.733693,-139.092106,-366.479235,-396.32044,-205.613816,29.306546,36.967558,-65.967156,-82.536576,-25.117896,-6.461845,-10.611017,-6.71324,33.491475,106.358694,138.242064,167.7623,149.46467,18.996231,-56.210598,-78.966724,76.821774,151.065836,149.257452,87.905667,-8.045002,-22.425451,-23.42286,-15.876989,-25.510408,-29.95558,-1.984347,36.827508,-4.338383,-219.260269,-311.970629,-245.318666,-25.351285,11.158063,-47.897948,-89.413037,-169.282929,-212.723625,-247.889976,-226.812955,-155.805246,-98.106509,-87.872632,-136.103338,-194.62711,-272.197646,-245.135414,-153.944604,-199.533623,-248.315085,-293.279947,-289.399744,-284.02646,-299.758249,-288.53793,-225.337266,-42.174335,95.391086,94.600643,0.656967,-15.790471,3.445117,-19.777742,-129.991965,-142.326807,-97.033866,-69.378813,-108.378519,-121.338702,-72.487771,8.3014,27.814224,101.941718,170.352477,146.722916,75.676844,80.197672,83.738034,36.56936,-113.417842,-215.953758,-235.969166,-187.286204,-127.107486,-67.289547,-93.102372,-158.015836,-150.443119,-38.507116,73.983114,79.650896,-8.740279,-68.747311,-120.124081,-93.081441,44.111383,209.294566,259.64275,245.448004,217.592485,225.471576,247.763285,262.951207,242.135912,159.453198,156.993065,194.691209,226.704868,187.292813,73.93258,65.109431,103.561947,91.401751,131.138994,308.736393,359.713514,266.684188,139.390303,-70.586029,-65.022261,98.466896,197.047738,192.128332,168.600462,163.274575,81.066322,11.734723,-82.81036,-90.679699,-62.93125,24.955453,57.230755,47.063846,21.209161,-37.380584,-79.849298,-109.485486,25.837453,91.986992,65.171348,-9.881826,-109.776219,-105.650607,-90.32318,-153.937337,-187.053644,-156.451416,-91.464383,16.713428,24.445305,36.831957,74.308214,168.643115,215.075778,193.088071,83.928359,19.585981,-99.240826,-128.312587,-128.340163,-115.589669,-89.985999,-25.027225,5.347117,54.096617,49.956976,35.853459,60.514317,140.445973,206.703234,200.806859,85.425697,31.994381,15.487247,12.840243,-70.732495,-135.047344,-94.820605,56.307366,102.182147,86.405056,50.094219,43.515883,94.43597:-146.144188,-63.403735,-49.798419,-128.506387,-167.26481,-187.817023,-174.77886,-102.6967,-30.739228,-13.476703,-42.927713,-87.518469,-161.751941,-180.326769,-162.883297,-113.887833,-2.57913,19.345192,-17.477696,-146.507957,-200.060378,-206.902763,-157.796305,-78.158403,-104.257401,-116.09551,-131.09628,-155.789458,-212.940441,-219.29786,-130.53106,-46.076096,111.215307,185.28215,172.450152,53.90083,-18.7606,-97.094851,-90.232391,-65.042705,-79.182033,-70.683284,-55.087455,-63.894181,-106.855896,-139.028973,-153.093998,-120.156845,-57.546674,-77.698304,-110.749747,-133.964426,-117.407044,-68.868938,-18.201609,121.338167,231.297291,268.080547,257.45874,200.046726,74.499235,59.129976,140.928419,179.602167,148.669638,52.438197,-15.104097,-193.211577,-258.712173,-217.822458,-127.163129,10.661933,15.424507,-8.151315,-57.139452,-67.739346,-128.825452,-182.565224,-165.508895,-87.960966,-19.497235,-104.559572,-136.098882,-133.286975,-100.203825,-7.740568,16.009098,-6.345247,-46.028034,-49.899338,-46.138355,-48.432697,-52.000212,-43.957919,25.699108,79.362081,136.477593,92.215361,53.231463,-4.153877,-27.06095,-29.477571,23.384356,133.82983,60.856989,8.546236,8.005227,22.586034,-41.422882,-87.408636,-56.585314,9.046639,118.524201,133.698777,103.278575,53.406612,61.504913,78.478831,78.085181,123.957854,247.554579,318.703856,377.693492,353.256218,272.322275,232.483434,180.238152,171.089894,183.021361,187.663993,167.522231,149.960049,151.490305,119.631866,120.360276,220.916495,316.072037,320.390378,202.115201,95.493362,-67.207576,-86.636005,-38.048526,1.203987,84.269254,149.542821,151.540208,125.299997,117.550164,88.660934,78.968405,132.344603,224.802892,225.507381,66.802168,-34.622813,-96.876946,-85.944153,-119.122021,-139.894136,-59.956042,140.528635,201.458321,170.414334,98.634594,-65.518055,-105.886212,-51.136078,-3.268636,-32.178882,-139.473894,-177.18986,-193.48105,-193.974615,-190.497985,-180.895516,-111.156267,42.176115,93.177327,54.590363,4.027961,4.137608,62.628393,120.503779,71.283484,70.049727,74.99031,55.724809,17.26123,12.838432,28.356547,43.364543,105.148684,245.877296,291.259291,243.141876,174.829248,44.243177,19.945894,66.623349,122.426667,121.69925,45.543781,-9.36793,-93.003039,-125.477406,-148.02436,-137.589081,-96.777683,24.772622,91.722219,110.750508,40.751177,-153.678171,-186.153221,-50.477441,97.682825,102.247927,-0.062221,-58.904851,-73.975626,-25.721815,89.809081,124.794081,146.99833,119.06805,70.082175,-45.667807,-71.570795,-34.177915,15.948338,88.348788,119.34471,151.032952,141.51216,80.012342,16.689471,55.246269,153.226936,157.098606,84.43036,53.940198,76.670917,141.310039,119.416866,-55.351353,-90.412148,62.310229,187.770397,177.433837,78.658874,34.753199,15.12243,14.695172,-5.423709,-7.616296,33.055002,56.417388,10.896758,-106.571037,-113.099072,-90.702706,-115.626749,-184.362785,-172.994103,-147.868834,-143.812047,-167.234517,-207.342778,-206.458789,-133.785719,-72.520036,52.869029,116.24843,109.029125,84.512309,72.613867,6.539019,-30.175487,-35.210725,62.590548,114.185718,104.233308,49.788306,-22.352255,-9.38598,128.478731,237.491388,380.813235,344.34916,296.265484,216.780521,190.254002,127.17128,95.645303,54.424914,4.326944,-8.958581,6.801094,-1.153919,-72.868524,-93.142734,-56.013025,-38.210492,-64.520146,-76.605944,-86.959732,-192.105222,-267.599205,-384.507084,-376.381821,-191.777084,-20.10285,-6.737757,-94.65927,-129.283606,-139.491357,-150.737253,-147.574515,-120.069375,-48.11509,18.956043,18.800126,-8.518806,-19.266837,-118.81579,-180.81394,-197.336684,-147.810603,-114.116034,-51.513558,-38.694052,-56.376125,-97.785925,-181.771705,-172.681405,-28.259041,119.511437,130.667958,69.266162,32.404507,-33.828322,-61.426011,-43.941934,71.135389,116.217249,134.64735,107.006211,9.492283,-31.278245,-52.287897,-46.30853,-21.617593,49.192441,70.094883,65.190376,58.092972,30.425348,34.866662,130.478948,165.568117,120.710349,3.171032,-17.267517,32.066756,42.198605,-29.018106,-46.050763,103.04046,297.227892,285.763565,107.954261,36.603453,-21.319661,-30.121077,-8.34649,57.609953,82.74118,81.305764,74.630727,56.530945,27.575805,-39.736326,-46.715836,15.691153,65.716838,41.937013,-46.013485,-76.150963,-135.531925,-174.393685,-207.063687,-153.79421,-131.725687,-110.704364,-76.831877,30.011613,60.230345,68.661794,71.013968:backward
131.510709,144.423,139.364606,168.96923,182.699237,138.357956,78.526298,-23.324135,55.149362,128.127014,213.665237,207.684403,101.223066,27.642785,-98.059916,-135.711591,-129.611146,-72.22077,-45.208865,14.361511,35.487907,33.894143,12.154262,-50.864085,-5.659746,86.395653,266.723027,271.844857,78.585067,-51.54766,-180.345019,-168.340534,-125.116978,-135.875718,-135.319023,-117.086501,-139.749864,-235.964954,-252.119422,-185.160586,-92.267378,-66.608042,-37.410859,-26.661232,-30.360941,-21.49464,39.215199,54.854457,49.714182,51.348177,46.132125,16.97679,-6.734463,-78.388917,-126.115369,-200.881513,-203.29208,-196.848729,-193.362705,-197.498911,-269.854224,-331.245199,-385.992742,-363.931465,-296.37697,-266.045856,-263.643862,-285.261716,-301.729599,-286.939821,-259.305149,-203.729908,-110.812986,-71.353812,-78.732264,-109.723089,-177.411976,-225.613002,-345.941046,-387.640118,-397.818822,-367.003836,-332.510868,-206.748205,-167.580062,-232.06087,-298.44874,-380.010702,-338.199,-283.788605,-166.031981,-113.756465,-72.853575,-112.574079,-246.416876,-271.777447,-198.746187,-79.879754,-31.170277,-26.265722,-79.90595,-188.360981,-203.391467,-181.266777,-130.691352,-86.341362,8.654712,31.538055,17.813488,-2.609174,-33.120509,-35.765068,-14.093662,19.384732,27.901622,-0.261581,-17.246605,20.018788,45.591092,36.832929,85.105841,131.125019,124.412525,80.31211,38.266739,41.915046,17.623117,3.362291,48.318717,139.936398,161.588215,172.258151,199.215778,279.526867,278.070781,196.60995,151.698575,132.654416,67.905413,44.598858,65.275378,91.660542,78.051824,51.522549,69.344636,84.396,69.636831,115.388377,176.130104,236.012683,205.939068,65.523038,-58.882958,-72.135529,10.948745,75.422284,138.848212,123.977112,36.375958,-1.240823,7.395175,71.002807,102.813888,114.310869,74.888905,-52.797833,-128.444269,-253.134835,-234.723966,-180.860619,-7.086238,91.3839,166.054007,122.781789,-14.076064,-48.605292,6.773044,97.086496,105.442722,56.554052,17.641761,-47.498837,-63.239244,-53.565023,-1.35002,44.337732,166.233213,207.953243,184.526955,138.352432,44.915678,15.295731,23.807293,53.224366,62.360092,106.166465,107.35991,45.816533,16.213174,-39.806585,-77.377298,-50.962519,48.065815,53.173473,-50.401789,-105.803968,-198.148048,-237.127074,-221.573013,-130.455405,-96.285726,-77.038037,-86.826737,-85.25289,-74.898833,-86.082176,-118.630256,-119.899789,-70.086539,-46.32203,-43.965845,-36.873709,-0.857556,10.345467,61.405118,158.55824,188.994334,171.237055,119.864651,-55.891238,-133.252628,-146.447321,-86.07603,-73.521863,-60.94694,-61.931839,-128.574,-188.772041,-278.869298,-290.174523,-218.158669,-74.355311,-49.097852,-147.78148,-222.101348,-275.94883,-255.123037,-197.266946,-114.757571,-66.353762,-15.742217,-35.88331,-133.648316,-153.636493,-90.833279,-56.642597,-39.704065,-35.53245,-27.837115,17.001714,42.839266,16.43033,-52.83602,-172.418141,-80.965681,-0.963347,50.674993,8.295733,-103.495673,-110.778578,-19.999841,18.63129,-9.645823,-111.169412,-133.524346,-115.233607,-118.474473,-167.920835,-189.173085,-183.642383,-84.850902,-19.607182,61.732916,51.433331,-51.365569,-96.101343,-96.799448,-62.065465,7.522278,-33.763322,-80.53311,-146.623117,-190.01784,-335.724376,-403.894251,-404.836204,-244.501727,-170.518367,-75.585339,-65.920961,-175.253874,-252.263504,-275.320847,-211.187309,-65.95767,-47.614646,-55.014213,-32.770716,-35.057085,-92.98338,-124.885399,-185.802314,-216.743505,-200.434338,-102.161448,-26.506901,101.638089,126.560241,90.061179,42.862509,7.007925,128.006935,203.317044,260.213651,229.241675,122.579381,83.88184,102.488899,210.113332,232.334967,213.77632,212.436577,192.782394,147.03167,34.889948,-6.834446,-56.5803,-36.644517,-14.492428,6.661962,8.884336,-11.600446,-23.053002,19.171056,36.167072,-15.012081,-113.064319,-115.165414,-102.089018,-134.188444,-226.253643,-216.408845,-96.259758,-75.440974,-113.968301,-193.749048,-215.157379,-178.479207,-131.2626,-68.529403,-10.613143,38.139702,112.724502,102.693915,14.20298,-20.964857,-101.028018,-161.204641,-223.899372,-209.76186,-215.210375,-249.17153,-255.113357,-237.197104,-228.78363,-182.138456,-69.674113,-35.791393,-21.406535,-17.318086,8.918675,39.204517,76.406515,63.281819,58.110134,114.459285,140.69,163.325424,143.048769,44.823219,1.135812,-20.075652,10.847722,28.924918,70.242896,89.691666,101.842397,84.595926,31.170433,17.819182:148.749687,162.58554,168.901138,154.25655,142.205349,115.298737,76.867694,-29.433303,1.552382,70.402186,155.666669,127.3091,-20.635575,-91.496904,-190.615381,-213.735445,-194.485927,-140.692856,-109.413946,-35.347725,-10.271169,-28.034652,-77.968771,-142.572458,-11.900286,86.114998,196.490713,167.287567,-34.976848,-147.38919,-238.552693,-201.684673,-76.383075,-39.019183,-50.358337,-70.654668,-105.225725,-267.766007,-340.512892,-319.047249,-145.536107,-81.324534,-35.64292,-35.769702,-80.351934,-101.84663,-78.234215,-42.693839,11.596831,-1.294346,-18.768097,-70.894264,-103.859202,-160.511736,-184.369719,-198.967236,-175.5785,-163.406576,-97.821522,-67.162222,-138.06457,-226.572357,-373.121915,-391.133437,-326.543532,-224.809867,-181.462301,-171.364206,-216.010556,-308.759245,-311.87275,-226.702811,-99.767419,-53.712218,-21.40863,-51.187732,-222.083475,-321.813273,-438.039936,-441.882545,-352.494913,-256.748173,-256.081469,-280.228115,-261.098725,-211.908195,-223.317621,-268.583518,-241.287177,-205.598659,-98.01803,-49.049254,-68.488241,-132.831955,-230.657953,-221.242805,-150.10224,-101.274718,-70.946007,-45.824895,-75.191088,-137.394714,-135.93291,-82.03247,-52.060038,-51.119492,-14.376303,-8.758044,-70.394549,-91.634425,-89.957772,-82.391853,-34.330833,53.065655,84.477041,51.429785,7.477974,-1.94251,20.202516,-2.40249,-31.12672,0.131314,96.670775,107.061157,18.405991,-55.501135,-187.696952,-184.913663,4.472846,128.497961,91.655719,3.773369,28.04864,139.805512,166.585808,206.731737,226.983221,179.748893,100.117471,104.516214,122.11946,106.67112,20.68663,-14.075164,-23.275915,-10.283243,27.060408,128.927106,151.274043,160.31858,143.820414,44.562235,-14.60743,8.960488,118.082382,161.89088,120.834251,34.238934,-128.078237,-135.267227,12.167846,177.742926,208.458808,160.283469,103.41169,-45.219132,-121.429811,-186.042521,-158.422302,-151.604532,-83.89909,-11.927115,75.463458,63.71173,15.413488,20.580683,49.883076,13.8229,24.155465,106.302555,104.065565,-1.976621,-56.322629,-85.836205,16.295722,89.198725,194.99906,200.347217,127.682526,75.907578,-20.874125,-57.004665,-81.125233,-12.779365,50.270002,122.889033,103.195052,20.204107,-18.60953,-67.934483,-25.855601,32.997985,107.424029,75.157263,-66.84284,-139.538245,-271.840784,-304.524048,-239.691536,-132.14739,-107.769491,-97.617678,-105.237849,-135.345691,-142.686469,-99.826072,-18.9898,22.251234,93.622662,81.526621,-65.48319,-125.331515,-87.208585,-27.34495,57.996839,98.37233,124.833157,145.953653,99.628651,-59.848563,-113.586245,-120.020352,-49.506216,-15.457364,-6.277109,-34.619586,-126.267403,-169.250233,-207.892266,-196.952369,-105.643547,26.222605,63.159895,25.113976,-53.250791,-219.258491,-231.958909,-92.77018,56.718074,83.571953,85.84393,76.329511,14.451488,-18.813079,-34.686732,-35.676135,-57.413564,-39.211353,7.140189,60.178162,17.932731,-121.903044,-159.916159,-144.591195,-76.464092,-45.894217,-13.808757,-12.75226,-56.70663,-89.503114,-90.207183,-56.783163,-20.987581,-18.597226,2.150901,-4.670951,-56.713709,-205.407133,-268.617402,-260.68011,-69.969925,16.184823,81.078837,60.335362,-48.243764,-90.967055,-101.298657,-76.521864,-17.918562,-24.003453,-42.186652,-117.416666,-190.8915,-376.624468,-446.698376,-443.847717,-301.726289,-224.562533,-92.781819,-71.764967,-185.810021,-279.063245,-364.290515,-313.250706,-118.700207,-23.067167,-10.1366,-13.219621,-43.338805,-150.508395,-183.806045,-188.902792,-158.577363,-94.790891,60.97948,74.094962,-2.632478,-15.28284,30.528184,48.008313,74.948976,104.513761,124.426521,182.452782,200.067502,159.088127,106.544811,61.797051,123.463478,138.058243,125.312651,128.93085,143.11352,121.740407,27.341947,-13.583532,-23.731866,72.760915,129.095969,135.798319,83.12553,-12.476038,-28.410664,-49.721495,-68.920442,-52.326522,-18.296557,-45.104656,-168.354496,-216.716226,-231.45285,-207.454726,-130.668859,-50.034963,-23.481044,-36.055382,-82.953854,-198.392037,-227.517597,-202.390556,-147.144788,-111.873135,1.075028,37.501276,-18.790287,-70.439483,-97.165605,-83.968648,-99.545781,-114.141894,-75.79967,-6.050201,-25.718632,-144.756343,-194.593245,-176.77587,-64.072912,-15.786884,17.642301,-4.046274,-50.756621,-45.364436,11.688907,59.145939,165.44598,214.815289,230.318318,266.053098,256.550859,172.723095,130.154341,94.346335,141.242529,176.897648,233.190013,232.315844,144.988022,92.396418,42.310386,39.126398:182.640813,143.914277,89.445799,75.721617,85.908581,26.291164,-32.782157,-98.767585,-51.624104,-10.0324,77.688849,104.121349,36.607928,-58.384522,-240.179852,-260.438404,-143.26951,-36.892101,-27.840273,-21.776033,-30.055387,-112.602999,-146.549698,-73.097366,68.863517,115.961593,182.764109,175.877994,35.985105,-58.194524,-187.435058,-195.536682,-113.139629,-44.593313,-41.260832,-126.771564,-202.901256,-316.016944,-337.104295,-267.83236,-68.426568,-3.298184,-26.140166,-77.02058,-150.622963,-149.440448,-81.179656,-52.024093,-62.266793,-104.085249,-102.803457,-80.810129,-84.893509,-119.937052,-140.272063,-176.976189,-192.794221,-170.036988,-70.034963,-45.50335,-121.400446,-194.218007,-331.508694,-364.13183,-299.695607,-152.568754,-103.004278,-118.814162,-163.47044,-220.431581,-228.363526,-184.351705,-68.634778,-41.440656,-58.037119,-72.077077,-122.156374,-176.089189,-293.359828,-299.271268,-224.189778,-229.170726,-238.94129,-200.457118,-182.874585,-219.357694,-260.935785,-293.615965,-224.803986,-159.438491,28.929127,97.704412,39.316317,-65.697724,-228.847254,-228.507962,-133.580557,-80.733668,-73.225282,-94.86274,-123.191829,-174.099541,-187.751101,-168.873575,-88.919983,-42.739388,-3.896426,-36.455311,-124.001317,-132.752439,-159.50853,-195.29662,-132.34363,90.822596,132.363126,11.569163,-65.037687,-114.229673,-115.739192,-103.820021,-39.558933,-18.114362,-13.064841,-14.456874,-12.670628,-28.736257,-121.568059,-152.596592,-85.511971,31.725749,55.981062,45.814078,36.988236,25.008369,3.93301,-35.898398,-16.704472,9.277084,85.395069,104.343643,62.455573,32.708796,-22.808532,-54.577175,-74.350675,20.042166,88.511481,159.545034,170.522732,201.173007,188.005248,105.57198,118.476489,152.452304,177.236364,158.745952,105.291881,79.091959,33.590453,37.93506,114.224876,176.089676,192.954494,202.313121,176.406295,61.478133,-1.200029,-54.903308,-28.523332,-17.614619,-0.450441,14.987372,15.101614,-9.953938,-43.822306,-30.054891,5.36401,-24.744272,-17.957836,46.451681,44.954629,-6.637511,-16.002883,-0.824827,85.303524,176.816558,319.457583,298.568723,148.121892,83.450393,-29.001099,-75.758964,-62.628187,57.638887,110.098617,108.866543,64.393823,15.379383,-2.213792,-68.95702,-2.931249,96.720783,234.148287,191.620788,-61.502008,-181.560889,-297.970399,-296.444556,-211.20314,-97.780216,-60.740353,-66.446707,-89.882906,-103.118993,-88.728524,-43.129117,-36.856586,-29.881573,65.894861,100.580362,-5.587427,-94.208703,-148.548375,-123.21267,-51.357326,39.826279,83.747533,86.565648,23.6869,-146.867993,-198.662864,-161.451559,-37.286558,5.514837,45.083675,36.373873,-39.416771,-78.735427,-117.816479,-120.881176,-105.737425,-10.69562,63.687375,104.058247,39.479484,-132.362788,-173.966495,-123.549413,15.339312,81.060772,159.878345,161.475507,50.304487,-50.102989,-165.606123,-127.602989,45.992603,107.338791,76.337091,34.476625,41.97489,-16.735501,-80.557222,-97.378552,39.4397,78.801421,48.48966,15.853146,-23.719559,-17.495551,12.826625,9.256863,-18.866282,15.853454,54.445772,50.425954,-6.764343,-142.77904,-173.547763,-78.908419,130.849972,204.918601,225.573826,191.535054,98.057313,36.221714,-74.274303,-77.332089,-18.576587,-14.483449,-17.069096,-62.053787,-132.533119,-283.109011,-325.112403,-354.886216,-361.110654,-337.709245,-223.788472,-199.462291,-301.532424,-369.155907,-385.273499,-334.468247,-217.904263,-130.678065,-97.821748,-68.83698,-64.219477,-73.930219,-101.798377,-129.538606,-17.399992,65.571173,192.164301,186.350088,41.92651,-23.013308,-48.251909,-41.378365,-34.655767,28.634458,84.84035,161.905598,160.173419,104.566254,57.727377,-31.578357,-10.857311,24.45789,44.015851,21.340476,-45.944143,-71.325427,-89.04544,-80.484633,-27.756573,43.880462,64.508272,12.858073,-28.808744,-8.902823,26.941167,19.449492,-37.812031,-61.804126,-140.127882,-176.025369,-170.330236,-159.86402,-189.14921,-186.575154,-86.03011,14.630857,33.675873,-8.53525,-74.354277,-221.220115,-260.987109,-233.275665,-152.290817,-130.827634,-77.530184,-46.106438,-61.537466,-104.97679,-179.926136,-184.78425,-129.226414,-64.894575,-37.461274,-22.509225,-56.486769,-198.378094,-268.666525,-272.978308,-113.541969,-42.842878,-10.639704,-37.513748,-68.315459,-53.3098,10.604531,56.196459,141.139937,187.96465,239.91197,349.626237,323.597513,153.334958,99.331329,109.021021,204.585444,255.980528,288.247869,260.447886,171.095024,121.786277,18.307283,-9.953566:177.596326,145.408033,139.171502,132.812802,109.32858,85.455894,101.203327,136.050389,174.237151,188.863248,174.230866,153.896801,89.056163,16.590094,-171.977539,-204.95329,-96.914782,9.769711,27.721222,7.63551,-29.820981,-93.147468,-86.506372,-24.323532,48.67676,95.733608,181.014176,180.251417,41.101481,-55.567203,-163.842057,-169.402741,-149.918546,-116.797402,-95.95688,-118.35453,-175.483296,-307.779307,-348.037655,-308.119365,-129.241592,-68.435004,-51.661308,-49.648278,-44.995555,-50.329143,-54.575071,-60.022921,-73.902041,-61.269245,-43.035997,-45.588209,-85.144393,-189.341172,-236.121787,-284.295193,-229.570536,-180.728836,-83.418387,-60.606307,-114.567943,-168.685782,-268.778076,-290.762004,-226.158719,-134.214937,-122.900717,-182.136968,-237.70867,-289.127696,-259.218672,-128.677971,-5.163839,19.24587,-3.773595,-29.002397,-80.523845,-107.722585,-196.752629,-261.737557,-331.404467,-249.635582,-190.588578,-142.24443,-163.752141,-237.321062,-272.488861,-317.545726,-247.674785,-175.641268,-38.094691,-1.06435,-39.794949,-113.25638,-278.537245,-323.869996,-274.164569,-115.945308,-66.703735,-58.047351,-68.07861,-86.672768,-97.612165,-86.814406,-62.675151,-60.473057,-48.693901,-54.858185,-97.882432,-102.213665,-96.074227,-117.911461,-169.813567,-104.552785,-45.690748,-30.033888,-74.977603,-139.803241,-139.133808,-78.539711,35.019971,54.56521,-6.493019,-37.792612,-78.504185,-113.526076,-182.650799,-166.657675,-10.958135,93.531512,91.024225,97.867313,140.720051,215.978427,190.447086,88.70705,89.764301,95.379816,92.826722,99.263215,102.396758,97.105241,70.972826,50.094154,38.461459,70.502228,105.318725,246.121801,313.222554,302.912436,239.873188,129.472548,158.892034,207.163357,246.230365,242.746504,234.096414,200.336088,57.057288,17.151324,116.722796,257.338547,288.934506,257.675674,185.846605,11.949635,-49.051201,-110.349681,-104.979034,-78.977222,10.09767,58.470413,83.720942,55.773839,-4.837022,-9.068208,47.563064,96.16717,99.10433,82.662434,70.742355,71.165188,70.707157,43.046438,73.523077,132.702437,261.960857,278.58688,199.065647,151.714187,78.087975,42.333664,39.160498,115.760241,132.098959,93.144683,49.891799,-16.640121,-32.737039,-57.957043,-1.554448,74.83091,149.815453,86.246604,-120.644377,-192.705877,-277.405074,-308.211628,-293.64566,-128.054559,-30.827432,22.913219,-32.903587,-144.372521,-152.423539,-95.354771,4.76355,40.230937,29.192317,-15.117943,-121.219486,-143.96337,-132.96312,-125.946862,-66.985525,77.940694,139.597084,128.19685,34.671813,-208.886832,-272.286517,-192.344601,-26.454756,7.687769,-1.308811,-34.017594,-170.25662,-237.821999,-281.840456,-259.121086,-143.545269,-27.004143,-3.881256,-44.438576,-100.675796,-192.87871,-207.754855,-209.722393,-141.464469,-66.35554,69.654932,72.300247,-58.366645,-124.181504,-156.15614,-134.040122,-30.160358,84.758658,99.779686,54.964735,32.980502,28.364686,30.769195,31.392763,24.66346,9.288532,16.827555,36.830567,-4.90127,-60.460836,-140.70421,-132.213945,1.008638,138.432809,145.568523,26.042047,-70.604867,-219.639841,-231.336216,-127.328892,38.579667,118.312839,213.884841,190.661486,31.040894,-34.923232,-18.438546,49.42359,140.336682,66.461421,14.348873,-88.344848,-164.078836,-312.623213,-354.708802,-386.671959,-368.413713,-341.93926,-267.895353,-254.773242,-327.400404,-362.155224,-315.924238,-253.4982,-161.845902,-121.535934,-83.909864,-8.553434,-1.252922,-48.271277,-95.429159,-159.662562,-125.395887,-100.661529,-3.620315,65.983397,120.716896,85.200462,-52.278776,-103.641324,-79.866817,6.780269,33.27079,70.50928,79.133407,34.227707,-17.147312,-90.065718,-32.889665,12.49644,71.532577,89.055842,52.1425,-8.850173,-147.335175,-197.648491,-201.489256,-117.092123,-92.386524,-130.757842,-159.64811,-152.587879,-139.456827,-152.932952,-170.884594,-182.627792,-199.69191,-189.704988,-167.773943,-173.831885,-196.271049,-186.590935,-128.113782,-142.550642,-178.288039,-219.607518,-229.269577,-251.96971,-247.961428,-147.715781,-6.944478,8.230008,-14.610125,-0.27419,35.916155,16.823524,-110.249274,-171.896415,-174.842428,-114.272088,-98.08065,-96.795715,-131.623609,-267.870933,-323.562388,-306.868668,-123.2846,-42.225611,-30.342083,-69.713609,-114.245224,-113.806209,-107.768512,-84.675206,23.437603,73.449125,71.580173,79.949045,60.680659,-66.61387,-124.460788,-97.582235,48.819549,111.600624,171.664747,168.156899,135.480913,120.479916,64.767138,24.558627:195.585483,217.037427,209.99684,157.863666,130.432868,106.751613,90.365737,33.678834,-14.469957,-21.068952,54.998588,109.210929,69.822829,-32.932289,-232.410169,-265.634834,-183.538949,-30.13668,30.39355,63.070024,25.22038,-95.873343,-118.393173,-39.1922,46.270158,73.422428,188.392788,237.278561,152.772822,40.58602,-150.369081,-172.889961,-73.37498,66.601105,104.383263,31.37426,-62.163948,-202.951608,-240.338323,-277.088141,-147.565005,-54.917164,-2.241051,-33.524886,-104.170002,-133.722581,-177.280776,-169.19889,-94.897963,-49.014238,-44.171111,-97.676687,-150.84991,-224.479843,-244.865496,-274.13486,-213.547787,-128.616852,68.620893,94.99531,-78.896269,-199.928494,-326.179316,-329.754208,-233.701954,-52.407462,8.755608,-22.407702,-103.598702,-248.965616,-260.607244,-158.036406,-10.215324,14.702291,-29.020657,-42.92038,-46.451729,-91.188348,-259.687659,-303.465139,-236.963929,-126.937253,-92.631002,-84.131216,-125.943987,-267.562541,-322.894671,-331.923193,-211.901154,-109.452117,96.550849,127.947765,18.108618,-78.498057,-271.657062,-313.158059,-211.979795,-28.29421,23.631113,-3.833855,-48.3613,-104.491236,-107.806536,-49.362517,-7.254718,-14.357146,-18.625554,-22.084566,-87.639147,-142.358122,-232.478242,-244.857075,-206.090876,-119.118666,-66.622717,-43.047832,-98.035417,-237.202674,-256.164804,-173.287088,-41.332902,5.099692,18.117299,4.831337,-18.350427,-57.467226,-218.810789,-257.893105,-100.987767,76.704767,89.588002,75.15185,71.937797,15.122275,-36.294918,-68.268368,4.695739,39.251785,98.137739,114.780003,100.24043,83.444379,25.537251,-19.288392,-29.279273,114.525482,173.08756,202.870698,197.108192,150.768745,112.193914,91.345219,198.884971,255.702967,277.0096,258.851346,242.456279,202.71591,-2.389711,-64.880824,78.449391,308.618279,351.923608,267.77998,172.065772,-36.082775,-120.89903,-156.588564,-17.466084,62.473967,165.944843,178.343913,127.86727,86.606139,37.20716,27.997882,8.31241,40.002163,84.259118,115.204507,100.625158,118.732657,122.498803,75.387554,153.700763,243.056854,349.337181,328.211026,218.166189,169.768444,46.011666,-19.275317,-16.48509,136.485482,192.959693,152.739716,82.384749,-27.793077,-42.983746,-6.866584,47.625063,88.134363,146.926556,119.522321,-9.040957,-71.870914,-198.12813,-258.166039,-261.685737,-36.465115,91.603241,131.725393,46.846205,-78.437534,-77.944097,-55.56365,-14.933455,45.885516,163.195487,143.14908,-26.263254,-86.775948,-106.13565,-91.746594,-27.957744,68.864845,117.086952,119.970121,38.992405,-191.808262,-250.135836,-146.22329,28.320103,49.145911,10.367868,-14.684439,-86.8483,-135.299017,-198.889374,-178.403726,-71.726635,3.975101,46.125094,58.456698,-18.623853,-221.37095,-278.262566,-223.13301,-18.276368,60.530353,109.210597,90.780412,-25.593079,-113.752274,-203.768857,-152.325002,39.139313,167.22443,215.33991,259.216934,215.181436,47.16834,-15.625791,-31.893506,72.01793,120.356288,94.777197,27.761077,-69.890089,-78.912759,-77.933368,-58.884826,28.485035,84.582096,93.734156,69.821781,30.991858,-46.568652,-65.861678,-13.379477,186.479758,283.689127,290.088374,196.159806,11.444219,-25.589643,-11.113349,15.366231,50.047911,87.646682,115.483507,34.061733,-102.306758,-358.694358,-407.302032,-402.594734,-397.697991,-383.747062,-290.498532,-265.025026,-363.548947,-440.49,-465.19677,-407.954993,-308.735001,-259.987983,-190.249022,-38.551771,-21.413003,-82.616681,-125.208032,-171.172496,-120.344288,-55.835791,83.622765,98.750193,3.742352,-60.075507,-172.055057,-199.350496,-148.398468,-24.313924,45.512132,118.521502,93.189933,-58.873164,-153.758453,-243.381585,-119.778095,-23.867586,60.323689,9.036575,-187.381279,-258.359786,-304.91453,-307.574795,-243.633617,-81.718711,-25.151514,-37.468517,-86.909822,-200.469391,-247.326141,-236.490042,-81.462592,-27.064634,-57.341901,-105.026824,-121.231341,-107.736059,-153.5073,-167.067449,-68.390801,17.533425,-5.027955,-120.679517,-172.917212,-276.026123,-330.361389,-324.829757,-132.889609,-40.725059,25.449413,1.452787,-85.647669,-112.752593,-153.052883,-174.014208,-134.935628,-11.28619,21.521425,-41.158386,-117.148808,-253.994004,-292.556069,-309.953009,-220.7894,-134.824374,-11.767706,-23.990557,-107.532273,-114.687648,-59.794461,-24.345503,73.352944,164.063453,186.70518,168.892317,116.530777,-21.10777,-62.857286,-19.880039,161.498375,247.495247,315.826322,289.596439,166.482243,110.270589,63.147449,63.59441:159.907735,269.51011,279.172107,213.290165,142.015635,72.849383,96.205301,121.795029,141.198949,185.067024,243.191014,219.464645,128.033525,98.644514,52.355664,19.701366,-40.916043,-6.468834,50.585462,92.778772,37.700523,-102.777051,-119.690269,-35.518499,133.702573,226.220735,339.889964,328.619523,128.685346,-18.568434,-170.080124,-143.609707,-25.018618,50.204631,45.447056,-81.919069,-173.490642,-308.175545,-331.563817,-249.999322,-75.220237,-26.310021,-35.190898,-54.583214,-64.654807,-56.334447,-45.38634,-51.398039,-60.272053,-16.546799,29.997515,49.957133,-5.935048,-131.265036,-151.136725,-101.023819,-66.437504,-92.795876,-160.034963,-178.623609,-223.939841,-251.752562,-261.835461,-226.765807,-111.825964,-77.380086,-87.668026,-76.476816,-75.067924,-127.234571,-145.578383,-94.880934,12.436526,47.640519,31.735846,-27.123354,-162.119837,-182.362789,-137.693998,-120.495986,-101.805552,-48.841002,-36.038314,-75.751369,-123.123928,-197.380713,-201.864949,-208.925812,-230.485602,-220.216393,-124.2978,-66.43948,-78.523373,-154.430039,-299.207371,-312.481408,-212.864472,-73.700678,-9.446993,98.521754,111.839679,17.872341,-64.774205,-149.072185,-49.366129,0.348304,0.4637,-24.481939,-37.902583,-19.598186,9.308718,-8.702998,-73.379879,-45.044371,-3.375653,1.092993,-36.594244,-27.878087,32.125702,114.245357,97.52812,93.559488,103.483724,96.553359,60.359395,37.779575,-11.578532,-18.1138,48.384916,133.977226,153.749484,201.232148,231.88908,225.790829,177.862485,81.529325,111.772946,144.39209,134.814284,112.831464,99.807526,122.403805,196.942064,195.023712,86.595311,-6.861365,1.172045,122.223963,190.136762,235.71437,207.069945,102.268121,60.670429,80.469212,155.279911,182.804323,139.692518,73.400369,-26.641079,-21.077903,100.68929,256.073916,295.706195,230.841726,143.546236,-40.696319,-116.44226,-145.439097,-21.030054,37.097803,136.601895,180.003165,189.422429,160.163389,81.639313,54.998307,122.320773,246.561979,253.788973,183.105008,122.766499,36.128116,44.805211,95.058777,169.102927,229.786857,332.161081,342.089279,253.973836,186.952729,98.736609,95.607005,180.165492,236.582288,223.588054,203.913049,209.119696,190.816335,156.643521,68.251365,21.806907,37.677661,100.477412,95.890696,-36.311082,-116.669297,-188.963962,-192.27817,-147.88213,7.544522,82.252231,53.393361,-26.141041,-93.388333,-84.045239,-135.587025,-194.705864,-178.198107,-91.956141,-52.099716,-32.079031,-53.974308,-143.363182,-186.781186,-139.918087,75.579032,164.73757,166.701607,78.504301,-118.408832,-171.331852,-178.273241,-145.110801,-140.537859,-84.677174,-30.688044,-31.328428,-119.852901,-316.22046,-334.347892,-172.764193,-46.662738,-69.281289,-155.354855,-176.808007,-192.434827,-209.795337,-300.427127,-333.606616,-279.174398,-140.946205,-122.895432,-180.626825,-204.150305,-196.261165,-173.427586,-106.148326,-38.690526,33.609332,210.940223,230.253488,80.534031,-29.227937,-140.463781,-56.276286,-5.143405,-2.174835,-53.577938,-182.231933,-197.788875,-98.900078,-38.792699,47.513417,101.64556,89.099292,-20.027075,-78.972755,-114.261793,-99.216098,-34.311178,52.536198,76.591944,74.769254,53.041776,-32.304328,-69.643375,-50.32019,0.444211,110.889615,108.603749,50.037919,-97.187744,-158.923601,-256.512042,-304.184845,-381.561456,-354.903696,-301.351911,-229.580416,-244.090377,-302.503917,-304.634666,-254.174541,-212.793016,-127.095646,-91.647855,-72.718953,-56.901259,-92.277794,-201.417904,-242.834094,-283.742648,-240.788473,-202.109072,-115.211189,-59.733731,12.39013,-4.720625,-113.02643,-151.830874,-104.529878,12.550423,51.681062,95.039988,86.71687,-0.776543,-45.057588,-31.596251,65.235637,79.992219,61.446809,72.378809,66.971215,6.042193,-147.798037,-181.560375,-142.162764,-104.211925,-111.336106,-139.108296,-163.420356,-195.811427,-167.416074,-43.647928,-35.203471,-90.681838,-124.130659,-84.599552,-75.59712,-132.078782,-208.453576,-176.493324,-61.523896,-82.953365,-136.803777,-225.51911,-252.486596,-209.757721,-130.948258,51.919479,178.1511,183.907749,94.278161,52.41565,14.287646,-18.371993,-148.79128,-194.097402,-138.197632,-52.035052,-62.906701,-180.416121,-239.858569,-256.528392,-226.327837,-155.116833,-20.786523,59.443524,73.864716,-14.788136,-187.391745,-177.585485,-15.230858,54.836349,99.549114,18.062948,-43.444076,-97.05406,-91.515284,-116.156141,-147.549772,-177.481959,-141.644071,-88.166992,55.439883,89.378992,21.558753,-21.790184,1.033276,31.003037:227.134695,351.829009,388.882133,340.746002,242.22811,63.717927,51.688619,106.228922,183.689381,241.308875,330.013259,323.742505,166.671566,34.008832,-185.747696,-212.729027,-93.462975,133.684703,218.550362,178.424567,66.013422,-107.53159,-102.95098,35.863007,195.585359,273.160606,409.077262,410.25248,202.377427,58.261376,-138.654804,-175.996194,-113.225241,54.040791,96.441883,-8.008988,-118.479882,-283.754472,-321.175517,-306.784051,-126.913139,-17.173654,89.24453,75.121392,-36.098205,-106.697276,-203.468978,-209.463234,-127.34513,-11.432177,9.872949,-43.908106,-84.318772,-149.483946,-196.28798,-279.605582,-202.563418,-103.789777,79.846602,77.924926,-154.258439,-291.922682,-391.534738,-329.558164,-114.012812,-3.533581,14.628712,10.589747,-32.723263,-185.365536,-236.49116,-94.817282,249.175756,326.855502,191.754592,66.241672,-89.432616,-123.24733,-197.312583,-216.960583,-128.080279,0.404748,20.686594,-25.717015,-96.359187,-286.556315,-337.353747,-254.411037,-60.194547,9.409471,81.857826,80.403043,-59.001866,-185.160345,-375.563074,-373.095588,-190.203605,56.24493,147.033687,165.928034,96.591409,-72.229336,-132.158272,-166.030534,-65.056841,16.088559,113.1698,83.133769,-87.773463,-156.381057,-188.511649,-183.786216,-153.786491,-57.194815,-15.521622,-42.227478,-103.384259,-239.111266,-272.292872,-176.054183,3.684644,51.26448,43.187177,0.361963,-100.295737,-145.972181,-227.034184,-209.716976,-2.12194,158.778511,176.106916,136.144564,78.559794,-43.881396,-79.953762,-83.049657,55.622032,145.562547,219.336518,178.073553,13.082711,-36.413223,-32.404147,-19.916029,23.642273,117.695915,153.984655,167.173304,150.735582,86.904556,55.775074,50.272178,129.692503,187.477045,265.401448,259.191987,155.864893,77.223922,-76.733686,-103.347396,57.520038,341.226598,414.346963,296.005435,145.521134,-85.755453,-137.397089,-158.637407,-10.076869,84.454904,174.253762,170.756097,79.079861,19.479679,-28.716108,-12.871107,63.787597,152.849934,171.147208,85.45751,12.990158,-28.781547,3.544112,68.926036,142.199951,210.955098,363.481968,374.018742,194.464385,75.735573,-46.338173,-36.961044,92.595118,191.201985,172.989691,56.198143,-7.193004,-60.110403,-46.527076,-42.028519,-47.502903,16.235305,212.109628,228.071449,2.917545,-147.906426,-316.354963,-317.473751,-168.065985,76.390766,163.482224,111.298285,-17.309251,-209.249236,-202.131959,-57.2523,80.483267,126.98825,162.157797,119.531773,-55.076652,-126.200292,-179.322839,-158.362221,23.841667,255.865996,286.381904,150.543604,38.720095,-176.45499,-249.364453,-213.501521,5.292819,82.02937,73.641593,10.919008,-123.766687,-170.720422,-240.101635,-245.400659,-99.111258,120.000949,149.85003,1.869024,-121.973149,-296.200908,-320.454679,-283.001773,-178.874948,-114.930646,-30.938616,-52.710601,-217.307578,-289.547405,-256.588294,-176.886203,-35.377839,91.857954,161.602097,200.629356,131.963187,-80.609029,-150.65723,-150.763611,-18.188262,57.848849,112.242857,69.256973,-97.064114,-173.663332,-235.467748,-199.088587,-8.677559,128.465126,133.058335,68.93197,8.891628,-139.694557,-183.104521,-111.148973,67.163635,125.476336,163.837514,128.311878,-53.525187,-129.59954,-137.735449,-85.587385,27.116788,45.389429,23.510625,-118.610536,-238.170166,-418.788011,-454.410816,-464.860121,-389.914328,-333.093257,-256.049696,-279.319011,-450.029592,-512.709734,-450.442362,-368.007417,-228.897785,-123.657447,-74.930554,-38.655493,-77.529043,-241.889658,-325.409295,-360.305366,-233.196078,-178.300632,-105.596816,-69.657249,-56.728992,-116.701695,-294.108899,-325.311383,-205.400467,-41.224115,-14.268101,-51.650529,-96.342525,-222.094448,-266.497855,-203.781953,-10.42038,64.693341,84.626739,20.549992,-198.964454,-295.321972,-360.645118,-346.166124,-270.336407,-149.541191,-97.84577,-61.880314,-95.929062,-224.500997,-263.824251,-230.246075,-98.928679,-23.84366,51.270051,13.54243,-145.330585,-199.41594,-201.190741,-156.127604,-10.399479,10.932456,-54.855975,-188.740867,-231.411997,-253.465574,-196.419033,25.638611,149.826037,160.458838,168.852602,157.864469,76.19247,12.952,-131.972971,-173.134335,-107.582207,43.54424,85.898593,17.781205,-76.592129,-226.932121,-244.309468,-164.960578,24.713103,99.242915,113.08422,65.141351,-70.514647,-119.795187,-127.96473,-89.396266,34.59212,128.055105,130.989509,60.626017,12.423893,-86.239825,-130.455684,-143.328876,-0.934349,92.559218,172.437065,119.048036,-35.119564,-45.509029,37.171272,67.636563:22.692952,24.086986,22.714174,45.636779,45.617229,-12.511222,-42.560777,-30.858462,86.84897,147.669002,208.417247,205.573791,108.100672,55.721687,53.867769,67.526984,73.712514,106.023063,122.791658,112.388237,78.61078,14.344141,11.032632,49.758825,102.83408,141.86887,251.553577,274.260587,130.806775,8.124038,-100.453715,-65.502745,64.080833,152.623994,144.756592,0.210717,-96.824486,-156.091776,-107.71377,-25.631521,48.799726,113.561102,181.16583,160.353435,76.102323,50.358188,57.221956,74.161217,101.252121,74.024258,28.543902,-73.098886,-91.545186,-49.508552,-24.159327,-26.54269,-101.520873,-157.054198,-201.122449,-167.220244,-89.444884,-79.184447,-102.672172,-116.301697,-77.672798,6.582698,26.547547,46.161244,55.935584,42.328593,13.142313,-31.286902,14.985801,56.444507,117.157891,121.727205,82.361568,48.773957,-10.688808,-20.808687,26.523266,145.616268,190.825497,174.648538,104.084982,-92.273822,-154.500873,-154.315847,-134.503259,-141.853738,-129.403748,-116.898857,-131.457859,-144.47747,-121.36164,-87.322948,-3.388733,103.859572,150.201352,147.284939,95.097733,-24.384627,-61.431902,-102.620786,-100.228951,-55.38326,65.988085,103.279586,129.470972,133.131001,97.08792,50.871996,-20.145924,-10.699435,-2.625598,-5.126374,0.902533,61.033067,98.667646,105.29744,59.589413,59.656471,63.139846,38.794805,-31.794148,-39.652453,-0.332881,16.987003,42.00755,82.72769,123.288958,223.24799,234.609081,113.783031,36.992801,16.587268,87.013571,83.323662,15.368905,8.480714,44.192521,36.980426,-27.910349,-62.452655,-113.83065,-121.583645,-105.620766,-70.571097,-68.767535,-67.527075,-67.477266,-116.362641,-172.905963,-174.418748,-132.823258,-92.860832,18.080493,54.053404,10.590929,-27.866611,15.145969,157.871042,211.476737,224.022797,163.606921,-14.96535,-73.867675,-104.493772,-4.431372,95.758612,255.831447,260.959883,154.750992,97.187845,30.338658,23.552795,91.48041,156.991582,149.867742,123.492395,103.363282,40.584614,23.935925,40.678258,135.666142,202.830071,271.081979,250.438598,157.390589,130.613804,140.115787,146.352298,176.320335,289.024736,343.588004,369.80751,334.835507,229.903264,179.667237,77.499447,53.223589,115.747869,312.135833,348.069063,210.436319,122.545528,46.203833,17.699114,-57.212526,-44.775595,-4.275001,27.020445,10.340747,9.403618,15.187971,-5.584153,2.535533,17.711045,46.577721,67.638412,109.377902,93.958675,-60.597436,-155.106362,-167.340245,59.798038,147.575326,148.300939,100.925187,13.362115,-23.529966,-69.867412,-28.25753,5.680487,18.261934,0.212027,-37.972749,-61.110413,-110.058434,-98.941254,2.349088,-0.492718,-53.444036,-110.541221,-101.717393,-104.7912,-139.221042,-228.635687,-216.522723,-176.96016,-164.601397,-200.121649,-266.830142,-273.277134,-271.516626,-273.490899,-215.568035,-69.198436,7.701229,81.461245,57.260887,-25.464306,-59.84754,-129.23096,-119.105237,-79.662315,-17.564934,-21.72825,-105.527662,-145.378293,-132.71365,-96.439733,-52.611391,-59.595079,-53.046574,-3.128972,27.175414,89.265579,120.562979,168.42597,176.286794,152.317602,59.928668,16.106691,-16.333177,-1.650135,47.552307,70.435335,99.999582,65.367833,39.814668,3.012729,-33.120109,-180.515521,-266.586165,-332.33428,-249.64284,-229.906972,-299.961522,-352.965918,-400.497591,-376.264597,-262.023819,-207.69358,-149.04346,-152.512146,-157.342346,-118.925873,-105.011774,-161.308019,-191.903812,-195.767559,-146.724923,-108.345008,-29.067756,-4.667543,-48.411493,-93.445039,-116.042427,-102.957133,-65.337789,-11.925515,23.097526,117.134527,136.853349,89.050156,65.615474,88.991517,135.971714,134.794046,105.924011,91.631626,64.349342,45.944748,-70.481679,-149.221221,-150.723519,-25.893917,9.061189,57.328467,65.624105,34.38823,16.505145,42.11242,157.477556,177.549679,125.588904,103.177266,69.932053,37.752759,-23.645453,-8.12017,130.053897,154.863778,71.976877,-84.095513,-75.797881,124.889162,240.403053,312.222081,271.261682,268.814937,285.312221,268.053203,147.438897,69.539083,-64.504015,-99.751722,-61.958125,13.596306,8.772645,-68.101064,-93.120127,-97.288452,-121.707832,-179.114423,-83.582788,-27.531486,-47.697695,-106.791006,-177.742972,-138.074843,53.362019,130.030977,115.731377,-5.475312,-38.326454,-55.386402,-71.874445,-175.013852,-235.14256,-265.668401,-200.779038,-164.474044,-127.133758,-140.847079,-185.994681,-173.041254,-87.401325,-57.301688:72.770824,50.778104,51.562071,69.54426,49.578228,-32.782228,-65.933537,-67.480314,61.999397,124.836391,164.91595,165.986934,164.260586,158.410812,117.358219,70.73654,-42.900235,-52.063265,12.111537,142.365016,144.936414,69.540212,32.282022,-29.553692,-41.955636,0.934462,136.843059,169.786672,100.954267,30.617363,-56.548811,-45.214356,65.855367,156.595158,148.362807,47.49974,-18.805696,-97.442175,-101.67368,-71.036809,32.891121,87.632844,139.813994,146.522081,145.070959,132.878648,89.551805,80.838932,99.471119,107.372294,116.028892,114.103489,75.336313,-37.382955,-66.243911,-39.614886,-47.872468,-119.929817,-255.021407,-247.452319,-187.347036,-201.90434,-313.937536,-359.148618,-332.588718,-282.162078,-292.200168,-274.31631,-211.39176,-53.307417,-17.117403,-30.099057,-20.570494,-14.526475,-43.958831,-78.858042,-166.920948,-196.589705,-188.697284,-171.020981,-161.873082,-144.141926,-103.842199,-25.586681,-41.285566,-165.113645,-226.197858,-281.629754,-215.442279,-157.258742,-93.111277,-102.537937,-162.910654,-179.584479,-167.425508,-153.596801,-106.880038,-6.426251,58.677432,104.273339,63.757535,-41.633616,-78.407974,-132.848973,-149.590267,-136.515244,-55.05979,0.130247,87.76764,111.038713,68.580156,29.528957,71.643602,153.706644,129.029159,31.854651,32.018084,141.094436,182.437603,129.795883,36.818068,32.440904,66.247823,69.892396,18.901037,-21.880159,-69.221222,-68.778671,-20.075212,107.162916,188.227224,308.636459,319.964726,268.109408,227.423275,153.842229,149.989612,149.198756,108.371596,91.506334,77.123531,78.426527,104.948519,109.536443,63.683688,-28.544189,-59.802161,-18.859183,37.156119,122.214921,121.717922,-17.265267,-259.364976,-310.475905,-158.591623,-29.535153,98.784471,88.929933,38.889013,27.054613,15.898535,-3.539659,11.808675,68.930085,49.390286,-83.664687,-138.907382,-156.996274,-115.667499,-104.517036,-29.658246,50.735506,182.754921,197.304017,153.768083,120.126111,83.471985,129.153332,165.361588,196.433515,185.568226,151.45822,118.999777,34.113734,53.117954,101.975341,201.219915,229.337855,232.319575,220.484008,171.441311,136.239905,129.428799,234.869812,291.586613,340.080526,313.148402,196.923854,139.011992,27.583045,-0.232254,40.085054,110.022126,101.674183,14.041066,-45.51296,-159.733311,-192.800864,-155.823964,-101.692873,-105.659222,-93.088232,-61.157825,19.586433,36.968215,-29.476381,-103.168032,-80.934395,22.602009,43.191013,-3.96091,-29.542447,-26.430265,-18.066959,15.515166,99.816892,137.755295,185.543169,182.778531,83.707545,-8.596661,-130.903115,-55.645874,-9.670753,15.327993,-3.995207,-116.928882,-184.540513,-243.796925,-218.937927,-106.476593,-48.884677,-56.721208,-100.079085,-122.586776,-160.649726,-185.591094,-251.228963,-236.982456,-204.115605,-184.912197,-192.53723,-179.481175,-157.172321,-113.557876,-98.74008,-80.800335,-63.478948,-28.978562,68.391207,83.943776,18.623771,-33.73704,-95.616827,-28.517067,34.526038,69.572306,6.665214,-124.801638,-104.506259,26.422257,45.944387,4.517221,-27.689141,-30.050676,2.58035,16.98388,20.725826,29.941915,96.882274,175.62676,181.957764,141.472705,114.998497,70.26504,64.145984,81.897298,90.054003,76.173282,6.187313,-43.919193,-158.964894,-209.000234,-265.775555,-292.67305,-355.092606,-302.391144,-235.425684,-144.208707,-144.451429,-215.413237,-243.837635,-203.432207,-153.177605,-93.36392,-116.245431,-108.479632,-23.3122,-3.700945,-84.471149,-143.793657,-209.753864,-229.063231,-221.082734,-130.49881,-80.621937,-103.631198,-142.20572,-90.853355,-11.783528,89.835021,105.432576,133.518096,195.46981,182.317969,101.5385,76.392014,114.081724,231.615281,259.578153,216.597218,178.362215,107.427094,79.818076,30.58428,-16.7044,-149.844059,-209.420487,-193.789814,-113.820001,-59.443866,48.769813,59.537163,-17.381539,-38.12623,-22.113818,28.145655,72.645844,104.089918,57.431533,-56.186443,-69.701958,-61.728621,-127.973008,-173.450774,-234.433355,-228.377876,-85.192488,26.016915,178.653893,172.910285,134.923152,106.004586,118.248906,55.179088,-33.674671,-204.310776,-248.365328,-255.473924,-243.591598,-262.415918,-292.089573,-265.767739,-179.361265,-162.610793,-154.913007,-113.792762,-84.896151,-9.577438,18.259445,12.29164,-5.474019,-25.761046,-7.389971,63.529771,39.249086,0.273605,-40.828357,-60.189686,-141.932039,-186.321726,-221.147982,-173.20342,-149.521679,-117.551633,-89.856655,-40.790114,-44.847458,-67.004219,-57.739213:-24.223639,70.155027,114.936883,97.158471,46.87677,50.482523,108.430053,181.5228,162.321906,126.036569,61.565154,74.714121,71.889917,3.188287,-122.77696,-119.75298,-12.498685,143.354452,186.066603,109.547614,23.294304,-62.397126,-20.947293,119.73955,127.716098,107.624743,174.196206,227.853577,172.837342,74.43175,-77.909326,-90.686579,15.055422,173.794895,200.112963,61.246804,-82.611218,-322.995759,-359.363528,-280.050196,-44.378076,84.866417,162.004996,95.608396,-59.311509,-80.487488,-41.025704,-21.174374,17.442073,8.529089,-38.692767,-137.696239,-157.57695,-115.730126,-73.63686,-46.644809,-105.342554,-139.04698,-192.250337,-206.604371,-225.361188,-237.742972,-242.055221,-210.659525,-61.067415,65.045055,80.058203,50.787097,6.718094,-58.704968,-49.294083,-1.311904,67.887416,102.796981,135.652181,128.50222,60.025517,22.136958,2.420471,13.305065,64.351325,136.225737,149.165511,51.554946,-62.482919,-242.224506,-238.900542,-121.058325,-27.125822,-14.632871,-40.637874,-54.320796,-92.666037,-147.146359,-275.882463,-273.545787,-88.887074,50.287799,59.917118,55.86559,37.59907,-39.894734,-81.394522,-153.550417,-129.978386,-73.358716,33.079237,49.166424,-10.477632,-57.782828,-129.378798,-157.460301,-129.579244,-40.896028,-61.563658,-181.482335,-200.606676,-95.315936,-14.899128,76.56634,51.34507,26.44731,21.527151,16.663132,-99.826911,-178.922175,-205.062704,-128.616927,68.988703,136.647866,135.782441,97.840133,66.499764,28.68431,8.490318,-66.514754,-44.292218,43.085231,222.398911,223.589868,46.997676,-36.254055,-70.915014,-58.482082,-23.077893,39.80233,63.231881,69.730249,61.536972,86.341475,95.942856,-5.83541,-96.895638,-87.924778,-2.125351,70.328953,166.1147,133.365909,-16.640458,-56.762809,10.254617,198.853343,283.05674,278.013183,183.571936,3.438245,-33.414965,-45.121262,6.929362,55.696648,152.788692,182.986284,137.158929,71.354448,2.548152,21.494198,117.039515,188.132675,188.572814,149.609808,110.327136,4.950304,-35.103062,-37.239659,67.277634,130.202987,244.524951,269.056125,173.271056,85.064909,-9.623474,8.68495,124.662476,193.768762,181.946354,143.389546,143.170974,176.125256,176.042666,112.582828,123.965565,166.776079,188.750906,149.947389,33.324931,-4.380681,-16.158549,-24.289254,4.68173,172.510877,227.86648,169.783376,101.148616,32.881737,22.162886,-5.251971,38.482117,82.135707,112.39416,79.808118,-21.952749,-62.166667,-129.587537,-156.430852,-99.889866,104.27798,176.390464,140.785022,69.144123,-30.74896,-43.360709,-24.307542,63.871664,91.956062,54.207663,25.406246,-37.471675,-87.594042,-141.014314,-118.514077,-33.147489,21.257608,24.774084,-91.393567,-204.542396,-305.27743,-282.499363,-301.282919,-335.878346,-294.568589,-204.432724,-213.658452,-305.650513,-319.534037,-210.129778,-138.436537,-60.37677,31.905019,108.073109,195.22249,150.790235,-22.820634,-94.563465,-176.344895,-104.282043,-20.538258,91.640847,77.92791,-71.200801,-147.621146,-169.694707,-121.304952,21.834305,116.623929,109.723906,34.926353,-0.678489,-34.964874,-22.811422,56.244508,73.359635,23.4061,-49.694761,-16.79488,62.610892,41.086777,-55.316455,-53.775358,58.88781,98.092723,75.90719,23.315706,-20.993767,-133.587029,-170.113108,-204.824227,-216.34014,-224.823529,-271.045446,-317.31682,-444.12438,-484.985002,-450.811144,-390.170283,-245.820255,-141.254896,-111.628838,-113.54071,-147.15326,-179.203911,-168.693722,-189.497045,-192.995801,-160.537515,-68.841378,-35.10821,-31.573649,-56.91829,-153.392241,-194.119839,-160.460995,-86.868641,-56.91238,18.284892,19.757612,-87.161534,-127.725471,-75.296606,45.41747,77.079027,64.781736,24.856106,-98.271819,-140.505116,-168.471566,-173.083048,-169.850744,-156.377881,-120.534282,-2.545071,23.654724,-42.75106,-106.077691,-176.968026,-55.553734,34.317857,98.730558,67.24418,-39.82011,-82.270978,-122.28516,-120.481776,-36.9687,76.026662,84.045519,-37.798604,-121.553093,-77.090183,60.540457,283.310359,305.357689,290.467972,289.053714,297.514665,240.526308,168.601714,39.979344,23.204482,74.177001,89.427551,53.623748,-45.448558,-77.609814,-124.951362,-149.356599,-155.514162,-125.724277,-114.979486,-113.068044,-137.900814,-198.763942,-177.508356,-21.274428,61.043116,142.561202,100.292515,44.72406,-101.061203,-165.863423,-225.968978,-234.149124,-196.598368,-35.071887,29.962562,7.641777,-50.026246,-118.192126,-97.738447,3.837312,43.287611:backward
-102.16034,-131.352214,-102.91967,8.108737,64.171223,95.110088,59.227396,24.680609,84.927902,87.303919,48.788769,66.575869,207.531573,255.34221,191.08445,136.519544,82.439207,87.490535,133.758566,250.748993,277.109207,264.087031,241.634678,214.759254,265.023107,297.313434,296.699995,295.433555,417.405398,514.283662,616.478026,600.895845,447.3065,204.238776,126.574634,141.422838,180.80974,172.756014,121.821218,4.596059,1.277221,65.281488,197.212622,245.654378,412.436804,518.571955,585.716117,505.934989,218.183464,33.168813,38.779343,149.601079,185.455829,125.422039,58.490084,13.875713,25.275152,4.232777,-12.890427,9.404416,71.70884,73.479291,-12.654299,-61.844575,-106.944733,-43.247292,29.994745,145.894668,162.750068,109.128471,35.59451,-109.297712,-123.0841,-92.770152,-18.474983,25.867263,140.245827,187.689024,216.886916,190.953202,70.114007,76.280895,170.141762,354.155255,387.953451,380.864284,345.740637,167.841715,21.320219,50.3326,239.732363,305.12242,304.065583,269.697904,166.630626,121.099444,115.837635,159.923117,168.468181,202.436939,248.517846,288.331771,230.9123,102.375671,131.113918,133.758687,96.358292,125.440026,215.07108,193.463868,94.205772,109.237126,215.251437,174.927474,123.279149,82.482711,102.122065,179.9285,210.063754,227.222517,199.601881,177.872645,161.332048,166.141708,139.363619,99.09833,-6.191134,-58.45458,-141.914416,-129.131552,-64.370902,64.529119,96.518002,150.435692,164.803046,93.806981,-19.521546,-45.931943,-29.638409,1.739005,86.120334,142.626568,266.277951,311.259119,320.012754,303.151523,334.613056,410.205518,426.038651,414.123844,379.727119,323.99299,319.774741,282.551346,176.921186,161.735139,186.311146,174.363373,61.262894,2.669729,-36.848002,-34.138147,-20.504741,42.979538,77.293915,144.615727,179.364649,233.437702,202.941934,151.648615,59.029316,55.253538,156.525338,208.502238,197.200114,158.394421,111.380645,159.621205,204.563697,224.512579,210.556226,225.921008,244.484202,254.029253,239.614086,236.915851,255.586446,255.304886,200.872354,163.126087,126.511605,123.764832,30.145463,-134.613878,-159.097429,-147.821831,-169.862279,-231.052927,-243.827479,-247.401097,-278.301425,-302.223123,-282.747739,-246.947718,-159.895525,-91.750835,-8.71268,-44.445782,-183.653718,-259.329697,-256.169962,-187.687522,-143.577191,-116.76217,-147.33539,-184.641067,-146.244981,-161.221775,-222.215322,-181.930593,49.395727,119.979956,3.413955,-107.326496,-251.300799,-313.3519,-291.470136,-175.7721,-159.324898,-220.826161,-241.074649,-219.811082,-187.521783,-171.921892,-133.853622,-114.932098,-24.429795,32.950104,32.554339,-19.837881,-151.219176,-281.597798,-310.566165,-255.330792,-191.613735,-88.682076,-83.150634,-151.53506,-157.623193,-101.830565,9.301261,5.39523,-93.825303,-125.779165,-102.391049,-82.869828,-123.770949,-226.746098,-249.039766,-209.825373,-159.465594,-72.971497,-88.910061,-238.892825,-440.828066,-532.956608,-570.558123,-513.614328,-360.766383,-297.250366,-280.305703,-325.339962,-397.597583,-380.451303,-340.803227,-223.958473,-159.216224,-78.254742,-91.25858,-175.547447,-218.501972,-222.249609,-241.266636,-267.305095,-279.14524,-245.225557,-182.779463,-177.249653,-217.610072,-225.578225,-175.716946,-97.805467,-100.863907,-106.154931,-108.881472,-146.961928,-243.782666,-306.116848,-323.534628,-274.794216,-192.200076,-195.005172,-265.797016,-314.088014,-448.462196,-523.664581,-485.807334,-409.265414,-420.968058,-409.327121,-368.343471,-370.783476,-497.063032,-543.239577,-482.497046,-374.963315,-131.391298,-59.296422,-77.649582,-131.638341,-221.32094,-206.751885,-142.75557,13.945421,49.945709,-15.687004,-82.548564,-141.691442,-78.817001,-53.308422,-58.397479,-80.108009,-97.795036,-56.95915,89.269561,118.045891,-28.513733,-220.157875,-254.056579,-268.265949,-254.406846,-128.545219,-38.266323,81.8703,-12.099196,-120.459421,-228.457766,-186.480526,21.319988,106.319551,48.37451,-52.382349,-191.024423,-229.612496,-211.191732,-103.518788,-56.728741,-43.856765,-78.144714,-170.153511,-177.958985,-143.966204,-58.320589,-12.199051,132.623049,207.173146,191.598994,120.157936,56.86643,55.375045,25.919839,-43.914903,-58.29666,-67.944013,-78.757594,-164.250022,-327.406654,-348.471347,-165.037646,-53.073482,-50.763815,-166.098602,-396.976054,-402.86232,-257.870906,-189.993557,-177.128174,-155.887413,-167.048507,-221.845815,-248.040933,-229.470759,-96.83703,-35.277226,31.76086,62.105267,164.263587,222.959042,238.622411,169.532997:5.219112,-103.838847,-112.415732,-44.530314,-23.421025,-45.367224,-40.544984,30.317335,47.399612,32.079558,36.734395,77.149322,222.920672,265.000588,121.887132,-0.074721,-96.148049,-35.63684,22.68577,167.328424,221.749364,203.858512,127.428507,-39.926666,-90.039632,-58.780388,74.721027,137.655092,232.816014,277.903958,294.738996,236.555774,88.876146,9.701474,-21.758841,6.864059,77.861866,175.68908,154.717893,41.987627,-39.855995,-37.557553,82.899903,162.431,265.556368,296.884756,332.032231,308.788019,147.45894,-36.226432,-68.391349,19.844387,87.006644,109.37225,72.850234,30.998516,-2.606932,-58.055678,-165.747729,-166.841205,-101.364556,-79.83459,-69.896085,-83.734733,-147.077238,-60.599119,53.957077,206.839258,207.460456,117.494003,53.909585,-9.893551,25.191014,30.094081,54.946357,120.259326,308.576893,363.16949,263.948608,128.502375,-80.134332,-6.040271,101.689831,239.845754,239.707201,208.331775,196.189185,117.785755,-18.671582,-40.022039,79.486531,167.012433,235.52633,207.812231,89.867914,26.399198,-11.538845,76.252313,116.619435,167.105391,211.71225,318.331585,316.75695,139.154953,-90.972786,-138.594068,-63.586132,7.04093,86.851974,102.341907,142.263795,166.517267,164.570581,76.049348,62.434912,166.270336,224.207485,254.270105,237.548033,164.412425,135.310903,160.427303,166.293639,113.718355,-5.512661,-21.500266,6.811892,6.225353,-34.881485,-27.795772,12.169124,111.820611,150.924965,202.759711,199.623975,87.488804,-57.59494,-78.762307,-35.359295,3.966986,135.774771,209.242166,229.85421,187.964415,167.962376,261.970081,321.459035,391.699322,389.57486,312.921445,259.54323,209.911554,148.133793,109.437881,144.725891,194.506519,231.820609,214.547225,143.884554,105.598281,49.98078,57.605639,89.177518,134.147064,125.900336,101.134353,109.982486,147.935454,111.123835,59.475717,-0.013907,17.531187,92.32157,127.84579,148.092714,118.286733,61.696242,123.73281,171.972965,216.863258,228.541175,264.07934,277.951943,275.288716,194.137437,150.492521,130.042749,120.634775,44.652862,29.309674,92.347233,104.256922,-19.135523,-151.977592,-141.124765,-66.13351,-73.171883,-149.410703,-183.010299,-240.833702,-261.115979,-228.12463,-123.138185,-103.332407,-133.449061,-136.081689,-97.863385,-71.514928,5.74618,40.592235,27.696057,31.530984,59.536563,79.19964,45.662991,-16.823887,3.042025,15.972401,76.728982,140.442531,270.867267,291.097996,170.806383,62.321547,-88.453118,-111.421,-109.050174,-90.804277,-49.490671,65.077766,72.927832,-45.399522,-124.105838,-106.400958,-32.076577,7.962799,103.274742,127.883727,46.036314,-27.79495,-134.976921,-208.499605,-215.774377,-116.010327,-49.502691,-12.804407,-27.053121,-4.285181,56.712025,89.829087,179.816815,202.179333,155.086577,110.040433,39.210157,44.289325,107.585481,97.373274,58.24922,-4.813194,20.047352,109.817113,73.78472,-136.085817,-280.778816,-309.679927,-276.086294,-218.325555,-71.979614,-23.755639,-67.537123,-153.533804,-335.179191,-350.552907,-282.729696,-94.441781,-25.534295,-44.126038,-120.622369,-235.179595,-258.495636,-271.051354,-256.868712,-223.494268,-166.468959,-161.506108,-179.469666,-176.122227,-191.423599,-311.272386,-347.534916,-263.939337,-180.953143,-107.401594,-136.597587,-219.275408,-295.493035,-322.385513,-272.619646,-218.175543,-153.143012,-152.364814,-205.353567,-257.016157,-366.329969,-382.955058,-359.380032,-335.56859,-341.801101,-328.642043,-316.410757,-318.139482,-374.444891,-415.509701,-388.812077,-291.859221,-68.735016,-34.016181,-101.278709,-118.021549,-86.868386,-74.354955,-52.532813,35.441209,58.225976,-6.165068,-72.863632,-140.467498,-97.536271,-82.080638,-48.892979,-8.022651,82.648997,106.916642,93.002502,60.560806,-0.093671,-15.13412,-14.860859,-16.649075,-18.805856,6.909671,38.074874,92.841189,68.402182,21.513452,-53.886688,-42.122941,106.340525,185.307811,183.766002,116.077845,-32.882431,-90.815057,-72.797164,-5.190375,22.163752,40.053412,31.740127,-34.653503,-133.344468,-141.667735,-56.563946,2.282403,125.545126,179.176267,158.263697,93.580057,-4.01398,-56.6252,-92.980263,-172.580692,-190.874657,-160.690228,-139.861035,-175.666277,-243.751187,-241.537167,-173.60034,-130.054454,-94.95063,-134.409675,-307.609037,-374.240748,-346.382712,-211.35728,-165.109936,-181.579216,-214.657749,-192.921185,-157.902266,-195.244491,-239.24345,-175.301694,-5.819618,37.403688,102.634979,137.878128,104.043706,10.608953:-89.01962,-207.942078,-229.87655,-200.982845,-128.994306,12.886104,22.85836,-36.541883,-80.852788,-63.04747,58.215242,129.715939,228.734452,230.725522,97.110033,2.200252,-138.036434,-174.442786,-117.967784,112.545507,209.359469,197.325888,93.882334,-134.535699,-219.442697,-177.282263,7.094681,71.851392,92.331237,79.887457,21.941272,-32.190257,-113.204161,-92.665507,-69.241389,43.269519,129.297342,209.597929,172.836361,30.677404,-47.862534,-6.229045,201.979417,267.839131,249.266394,225.881753,185.805643,131.600389,-14.700186,-53.131464,-19.160843,80.021601,104.435837,50.547956,-1.545834,-40.190143,-56.693344,-91.604175,-122.643922,-109.690794,-96.402716,-104.275412,-138.566198,-157.816295,-187.955772,-162.117623,-101.231198,95.796466,167.914545,113.785745,34.624945,-44.750715,-70.016811,-59.083764,54.526236,117.372755,217.061744,268.908279,294.180895,222.412984,2.091031,-43.169523,13.190823,118.923746,126.347701,88.846907,83.974539,62.881268,-89.024295,-139.814421,-40.026169,39.397707,52.292363,15.579525,-7.779336,-11.507208,-12.494494,100.702596,157.054732,177.025153,182.202377,230.109516,233.160443,146.151124,30.469667,4.160398,8.138625,23.734283,46.955144,45.469498,56.581472,88.448951,151.325916,129.747338,126.419629,188.940857,207.314246,166.007362,147.329862,144.275055,107.352236,98.943957,131.787642,134.96124,107.702538,97.9263,73.33669,60.298268,43.709885,20.01536,21.753284,108.249909,173.822354,228.404526,210.861599,132.940895,-13.690924,-69.134452,-43.778431,5.192127,106.577622,148.572839,164.912248,151.491133,157.684534,219.667403,247.35265,255.055772,258.72369,282.002789,265.773023,191.906895,182.525433,207.404916,259.871718,273.338746,293.78626,303.450234,278.596437,235.409315,139.892341,120.381761,141.433796,178.35135,182.095979,201.114177,214.197518,161.169727,11.43268,-32.90072,20.266873,96.107951,249.52095,293.51011,245.949691,177.274959,109.814776,188.272911,240.590121,317.095585,340.333944,316.555664,272.886795,214.419782,185.058685,187.706116,239.445612,244.168577,161.811549,111.683436,39.141302,-6.34917,-113.804923,-104.199643,-62.245074,-59.202818,-81.756864,-42.078804,-14.13396,-94.822604,-231.912355,-227.305027,-88.737045,-27.702087,7.897674,13.844994,26.339954,30.048897,70.314468,155.191605,184.935207,190.588007,203.89839,270.311809,266.938259,142.280776,72.775376,111.323303,257.874977,327.959173,371.821613,319.289652,164.292277,117.753134,54.654418,12.838408,43.235466,134.572721,154.237053,170.891623,154.190131,30.180124,-22.767729,22.825774,112.588047,117.835834,163.50325,220.102589,176.992939,34.121447,-242.460637,-233.17846,-171.687578,-75.904422,-29.935225,61.840885,95.452301,124.540008,95.916026,119.613748,266.640037,315.801469,272.274151,217.703366,94.309485,36.602892,23.496331,68.625693,61.682572,65.52449,100.564645,115.391033,55.858906,-68.374993,-109.981506,-148.306912,-220.236246,-202.834496,-66.356896,-3.760587,-24.35851,-103.438757,-253.337552,-209.604024,-125.03361,-2.21535,-14.974004,-140.350196,-197.591312,-258.003002,-302.428061,-306.766296,-246.010413,-203.57544,-177.435185,-201.598661,-287.895036,-314.405333,-291.84034,-267.576329,-267.606226,-230.049262,-171.604018,-21.358666,7.680314,-89.500796,-233.148751,-258.539521,-190.679079,-140.269788,-121.510407,-133.426504,-135.31016,-163.336858,-278.618251,-274.431185,-225.153978,-171.042845,-172.836976,-151.901524,-148.992696,-238.209475,-317.144409,-316.753379,-250.417262,-175.895947,2.861015,27.98517,-102.593207,-161.088224,-121.624714,-6.59194,39.817706,99.41772,101.672199,35.226057,-10.898283,-90.267351,-190.648722,-206.465957,-107.634987,-43.51188,22.32601,19.863716,-44.477092,-63.861646,-18.74607,46.924358,85.064636,164.058852,176.170154,107.340598,44.974182,-27.784137,-30.481535,-38.000474,-39.840372,-12.133717,120.834081,193.224077,177.352324,82.315953,-83.450294,-79.163861,-51.974748,-7.677532,28.985995,57.512731,8.979204,-120.922192,-175.260787,-160.616218,-79.196393,-54.329179,-22.436226,33.016019,170.805585,182.801546,15.441622,-198.497801,-225.971066,-161.071461,-129.912349,-137.843454,-155.893655,-187.479626,-247.54243,-263.312332,-194.182654,-133.871085,-104.849516,-171.584142,-371.682998,-405.830518,-314.991422,-281.526343,-299.476186,-337.574071,-350.035389,-300.795227,-235.753371,-162.907217,-190.31244,-179.760954,-102.968346,-57.21582,28.350514,57.300706,31.676901,-37.667542:-105.679234,-136.142267,-113.432848,-75.099472,-48.357021,-21.245331,-55.156444,-133.725326,-132.897564,-113.264467,-43.008595,15.273082,166.469031,205.546619,104.254295,17.25233,-105.329491,-154.620323,-114.429997,95.088883,202.723237,241.922084,165.869532,15.436523,7.800294,33.097938,100.766137,138.912289,269.068861,353.487304,369.995226,283.442042,97.421525,37.386838,77.242872,232.805015,288.916162,276.925078,214.756274,73.519991,30.605676,67.152448,222.263756,307.713423,438.602006,464.24778,389.764792,302.883199,110.199075,0.879512,2.857164,70.242477,100.503434,92.266209,56.313153,-19.97181,-74.47227,-90.929726,-62.682497,-24.352664,-4.591191,-48.591188,-197.649346,-262.647869,-317.605537,-225.237671,-128.670241,24.684867,58.418647,69.057799,30.991399,-121.939153,-193.018915,-156.911364,-20.238683,33.959007,108.214412,153.206442,223.528404,212.864447,104.602981,33.390899,67.229722,201.586624,259.246265,325.979644,313.800441,186.359474,41.446653,14.412551,90.445765,159.020573,232.818336,230.635369,184.542843,134.229291,29.437749,93.858215,175.557624,285.771837,303.830293,296.445933,259.258516,125.851975,28.466438,33.86668,138.448901,190.570986,208.906987,189.687091,180.581286,197.008157,193.229558,145.713209,159.217219,237.709773,256.998586,245.988373,233.760206,235.99474,267.293416,273.326664,254.31042,227.744979,188.535514,189.550521,157.560711,116.952787,53.700827,69.143962,113.481938,195.654996,216.137833,262.504295,267.946844,158.40342,-15.866102,-58.588986,-20.82064,15.444367,91.369315,150.945566,240.878008,248.67889,254.964507,289.542772,296.732699,304.638906,321.437433,329.591697,309.12932,301.012497,336.587975,341.509193,381.787282,434.217867,499.226802,446.72337,209.31679,131.92829,168.331984,214.027986,204.312265,240.112533,285.855532,323.232807,296.15174,233.121007,201.838427,181.120231,151.346859,161.748787,279.69965,352.543647,368.67757,311.973683,200.257031,210.402329,247.63909,310.509638,335.912865,331.823683,300.779359,302.836425,345.222823,332.855201,291.050252,262.358183,189.838393,179.345153,173.775556,128.644079,-40.233999,-132.335676,-125.376477,-80.906285,-59.273564,-43.200249,-81.18626,-240.356869,-326.096019,-305.477058,-186.408881,-134.614093,-74.127847,-43.382254,5.737384,8.816156,-61.92656,-164.056714,-150.458034,7.465567,88.344482,135.32943,102.758819,47.671969,56.260678,60.423595,68.567073,85.99346,168.960912,199.947874,135.871693,65.213371,-90.281617,-195.705406,-157.494139,15.854368,69.30552,77.821518,37.074361,-87.855547,-87.947629,-38.084471,38.345426,55.530316,123.511119,168.185109,141.410974,56.531452,-159.903818,-270.250506,-267.740481,-208.834365,-149.315383,-13.907992,18.628742,20.30403,-3.64929,5.874357,85.092968,99.327002,54.163879,48.816622,81.459912,79.166869,-18.013796,-168.785776,-204.811702,-154.411107,-89.339588,-4.086609,-43.710481,-214.346159,-346.778963,-406.476023,-407.857562,-327.312943,-150.918867,-114.112041,-193.608795,-279.877278,-367.111964,-282.066404,-245.141353,-228.152869,-208.798685,-185.400654,-218.772564,-283.802983,-259.884083,-236.732278,-220.87166,-234.724747,-231.711908,-200.516916,-169.49114,-190.114981,-275.464344,-266.498406,-196.459008,-97.659876,-88.799512,-60.959303,-65.651267,-170.357638,-279.881696,-288.952641,-227.929621,-201.956828,-219.80857,-230.517284,-192.790051,-183.51839,-245.259937,-276.549964,-255.297434,-232.673956,-250.478835,-257.258312,-248.531121,-328.581366,-473.702589,-493.265642,-374.832287,-260.834107,-74.26049,-71.726824,-186.352736,-203.034755,-127.956663,-85.933857,-82.678301,-63.981693,-55.062949,-104.043359,-157.223164,-217.768466,-182.083901,-134.564292,-33.781411,-23.925578,-63.171521,-73.040462,-78.135958,-74.028975,-54.820801,-52.544239,-41.173715,-32.740678,-43.408299,-49.12932,-30.036554,36.245453,-6.918488,-81.302004,-163.377299,-115.155128,94.099203,160.75171,83.09715,-6.900408,-130.240264,-207.275228,-234.070986,-217.312652,-167.019308,-71.442753,-85.962487,-214.772361,-292.252412,-279.431084,-181.385984,-141.803621,-85.850346,-25.888695,80.972588,66.566817,-73.397119,-171.687965,-170.172156,-123.371835,-102.672434,-86.915028,-107.765436,-237.32127,-374.061347,-386.01815,-277.812727,-209.964074,-196.08896,-263.805476,-423.548248,-437.24586,-342.327158,-274.354475,-250.588016,-199.664072,-195.460383,-237.934359,-256.890859,-241.460103,-177.816114,-150.142993,-130.99201,-129.813595,-51.387054,31.878413,98.827634,33.269729:-262.038923,-274.609174,-237.303538,-148.546016,-85.796487,-6.449892,-35.122264,-143.72795,-172.306554,-156.004457,-58.4533,28.851168,182.978306,164.510174,-55.26388,-144.832019,-179.07291,-197.712316,-202.137949,-73.268559,35.50911,94.312291,17.658519,-120.55922,-71.756301,-23.063081,42.866667,73.848596,151.998335,177.949085,135.674917,67.151134,-80.368473,-94.869179,-26.195622,181.83446,252.059605,218.879195,152.326298,40.928148,-21.468715,3.130507,194.016072,290.380327,344.984887,312.701212,219.713627,171.969076,25.81256,-77.724019,-45.18928,104.105441,152.905919,123.514589,59.250867,-70.862389,-113.976133,-111.807787,-115.189334,-104.055316,-42.710132,-43.518805,-173.898548,-261.280528,-366.072224,-245.814754,-113.923008,64.581061,81.129674,47.997303,-1.966464,-209.385753,-382.334513,-344.845269,-99.081204,11.745632,188.872015,253.868386,202.299243,95.597398,-64.342719,-5.528774,69.48167,172.626106,178.325384,125.316032,90.774485,-11.473253,-171.512819,-197.174177,-81.060208,-7.859641,71.662008,79.100874,13.675194,-40.4015,-85.024159,39.140141,139.416069,293.008361,321.642207,286.642247,241.092083,122.565579,-1.057201,-13.575531,110.692672,207.654378,319.209423,307.103373,239.088241,222.518161,192.512586,175.661136,215.537071,367.132291,416.906477,312.860938,183.23606,33.517576,110.154566,170.306953,285.161865,326.55729,305.034616,244.224349,104.450632,46.437052,-6.08329,73.193071,141.953588,221.233811,217.556034,203.178439,199.357476,89.204313,-146.048558,-210.997185,-147.794271,-59.545436,95.649861,122.600692,120.955007,131.884677,127.510558,62.281791,66.723568,184.494751,259.17452,311.137067,288.940675,251.91314,223.695709,242.881908,375.265037,418.722178,401.74558,373.604731,267.316168,190.734209,127.084273,225.152482,265.708614,316.412563,363.191825,446.438452,449.111534,370.086923,215.636689,179.11883,251.637197,312.911739,404.609621,422.212678,367.633043,294.260224,123.080177,152.414462,249.761205,408.215408,442.764168,429.932686,375.25095,272.170239,289.32697,310.248387,330.782229,336.332688,322.365847,284.996839,128.555141,41.16796,-52.470546,-39.062103,-28.007434,-52.721392,-52.186985,-7.847049,-39.473957,-224.207126,-255.313113,-169.706651,24.200416,69.952675,116.752897,153.240636,187.583369,162.766835,82.099363,104.734274,163.643637,278.402539,321.420291,353.412496,316.881838,204.09007,169.208282,175.160756,203.639678,233.460363,332.45424,366.158387,276.810371,158.291668,-62.693877,-82.614956,-31.196445,96.203944,156.62494,223.514082,200.015939,56.472177,-11.288634,30.490177,133.355509,160.031047,222.955236,237.7039,109.621044,-15.949814,-207.650193,-143.014399,-62.732924,8.043397,18.89919,72.963247,96.190288,89.772991,82.877278,124.045953,220.56969,215.958846,140.394269,115.923017,103.705797,88.797284,-18.317679,-94.914469,-61.199394,57.555555,95.50067,79.027152,15.363388,-130.333108,-225.013758,-264.342894,-254.652852,-194.278451,-74.562872,-67.228473,-161.538293,-214.434025,-246.280381,-196.567103,-153.348581,-84.955789,-84.174798,-173.292739,-251.978715,-350.842694,-321.542343,-291.385885,-183.768759,-111.55038,-29.549452,-41.67966,-128.883098,-183.70379,-311.171038,-328.280147,-255.122235,-105.38793,-67.082121,-5.3011,5.373327,-97.931787,-266.041233,-294.597073,-220.947623,-151.721835,-38.168367,-31.118632,-119.581322,-175.046462,-198.324154,-86.326029,-36.476536,-38.622713,-53.649521,-59.310644,-101.683304,-308.222607,-461.226669,-456.612661,-272.220162,-130.747838,49.970972,37.185491,-96.707103,-132.119606,-111.158798,-66.631441,-44.342736,-0.968687,16.914708,-40.755195,-132.810743,-281.470722,-200.471081,-100.109834,34.915539,21.015012,-83.300269,-129.370141,-199.22775,-199.635071,-117.644117,-26.406346,21.35153,103.305483,112.317197,41.444176,-14.844905,-75.705814,-68.372482,-56.483778,-47.220507,-43.436607,17.342757,52.136029,29.826182,-21.992719,-125.933823,-148.475567,-139.981788,-112.386434,-76.040821,-4.258328,-21.836178,-169.716199,-264.701696,-216.928159,-20.298571,22.948503,-10.363589,-18.30401,-25.189605,-54.721682,-127.911497,-89.364915,-41.225668,-0.329086,2.600995,-5.185019,-58.736355,-268.932319,-399.198359,-386.423371,-251.533777,-183.017265,-172.855524,-242.027797,-412.46183,-432.565282,-337.415602,-242.059863,-225.243356,-257.033911,-267.066232,-219.226034,-201.319358,-239.311322,-253.710827,-218.951915,-137.1951,-121.019018,-73.27024,-19.228474,33.684711,-18.039645:-221.184529,-223.404771,-198.069237,-27.305508,87.839295,153.785416,68.390136,-80.437845,9.662019,73.90282,87.68043,58.719957,98.778881,148.01599,114.677574,65.097885,32.071391,10.845891,21.141524,120.453795,166.433594,175.359075,153.111795,136.121469,203.872749,247.001523,309.721359,336.505743,460.483077,568.940898,710.883872,658.035712,348.149665,165.19568,212.591809,369.053932,351.358535,129.576045,26.654189,3.738642,129.103438,172.492858,263.871037,352.320733,606.430955,725.045928,731.582103,602.15626,281.726823,92.863983,68.016569,134.918539,205.511189,281.098576,242.477586,118.604536,77.621776,67.119078,70.943318,103.441428,175.036782,168.101171,38.32973,-53.872919,-208.04891,-184.503761,-91.872404,86.191292,110.373475,19.971221,-66.368357,-217.580279,-258.251227,-238.711959,-130.323916,-56.188819,71.732907,98.509588,72.268801,51.213051,39.990064,81.123082,140.473123,314.39261,375.121313,343.690417,269.958254,88.922453,-104.088045,-134.018233,50.585882,189.651278,330.812334,326.588012,241.616333,180.392917,93.7711,134.103379,180.387706,252.157879,265.354156,188.1081,99.341941,-18.381324,6.585238,18.434655,99.369504,182.621957,244.020379,197.876993,130.410965,147.178051,167.401234,69.632807,31.223009,87.865171,163.153732,258.418821,240.380724,166.650617,164.417801,159.245355,127.167695,135.455491,216.170924,233.568106,125.215813,40.272668,-80.915081,-82.128526,-36.2976,53.695302,82.818214,176.868389,235.115892,225.117449,43.947426,-16.541688,-27.763849,-2.626047,130.221664,224.400071,312.370643,282.182275,204.877627,252.045095,303.400607,360.929128,366.648994,405.788542,430.615984,439.419337,413.423676,387.982062,347.348098,346.28369,323.525048,267.833735,68.231707,-27.367354,-85.21973,30.061178,98.266276,158.838306,176.743064,250.68657,282.529893,303.132353,307.401795,303.490013,308.138598,339.92329,448.114817,480.597579,447.288672,391.274335,241.519281,218.230858,274.634764,305.456687,251.979791,194.718446,223.359023,301.026304,328.229651,317.641972,279.240569,259.616877,225.200776,207.783217,164.923394,142.140105,44.630051,-88.977615,-112.135302,-65.690724,-34.108882,-54.240653,-112.186522,-201.072666,-209.690354,-213.353927,-160.690777,-112.428593,-65.888434,-54.711654,-42.897004,-61.502088,-158.123402,-235.630804,-205.858728,-64.176472,-17.827184,-50.474627,-119.737423,-211.842471,-155.786255,-144.926117,-192.614531,-193.325478,-98.768081,-53.653764,-94.248737,-162.742746,-300.278404,-359.642342,-316.364963,-173.237174,-148.452204,-180.399327,-203.004128,-257.467719,-273.874698,-256.11375,-221.958746,-202.71904,-85.594308,-18.33304,-20.418235,-74.693771,-175.858816,-248.414222,-275.082785,-224.936188,-134.641545,-7.635703,-46.974144,-255.571235,-343.413347,-283.857629,-113.250268,-90.397966,-91.112619,-45.997902,42.326711,38.64232,-76.650717,-288.112584,-353.774639,-312.036254,-233.169975,-149.132755,-205.837083,-436.068445,-633.334488,-690.416609,-633.054541,-527.173361,-352.466425,-343.059719,-408.326293,-403.960091,-348.191868,-402.003916,-418.47175,-328.605327,-246.285853,-149.807182,-170.417981,-240.787246,-242.989087,-222.663307,-181.496729,-182.937534,-180.060399,-145.565007,-57.429349,-39.077954,-101.011492,-198.478397,-179.171508,-12.825591,66.258009,71.621278,-9.845602,-181.915473,-218.476988,-220.463539,-203.064456,-161.307028,-68.168588,-57.569922,-117.018361,-160.266545,-249.040847,-288.243554,-260.996795,-215.726432,-225.799222,-256.662403,-282.998062,-384.206546,-506.98697,-557.270878,-529.98566,-441.768554,-256.271765,-220.009301,-266.152962,-292.833866,-279.806441,-258.298292,-212.676891,-41.057322,13.402598,-52.873407,-140.273104,-235.316395,-190.504102,-166.101101,-142.84327,-155.396915,-235.143516,-252.974787,-184.171613,-140.555128,-157.46391,-277.68478,-308.45938,-253.691882,-213.384358,-198.082711,-176.007407,-4.645263,46.8514,-30.671075,-167.957346,-163.40149,-27.143467,28.699008,-94.320963,-226.34286,-358.741441,-285.950394,-223.72153,-156.369734,-163.571714,-165.011961,-168.589524,-286.083273,-391.943759,-365.957257,-206.813559,-131.958003,-44.159819,-8.368996,55.098482,61.411643,27.878523,-47.031796,-76.491793,-75.823881,-62.363435,-69.613844,-95.900998,-195.94672,-374.038086,-437.44937,-349.697229,-234.584547,-143.537775,-225.314136,-437.849808,-444.435975,-278.345444,-112.239101,-37.140634,25.153485,-23.030187,-178.254075,-232.972168,-223.816195,-47.854257,16.723283,-9.305026,-28.878944,73.462183,161.018072,186.933196,104.533265:-309.559895,-252.389919,-202.294202,-52.493625,34.135298,85.867231,12.724583,-186.773173,-228.574616,-203.392,-127.33046,-56.967586,119.869596,133.98745,-77.416542,-204.160071,-313.286154,-268.612964,-185.104859,36.79517,113.259256,143.595942,120.255673,58.555923,1.045809,10.655457,149.344125,230.44786,345.815161,382.056927,355.03294,274.075607,57.159457,19.548415,126.207863,389.636164,428.051326,256.41483,109.004624,-104.357814,-91.082275,-10.045165,260.062985,412.828847,605.945027,614.471047,468.27919,335.643534,81.309191,-16.210344,7.619717,195.234197,300.019308,297.558545,192.395713,-7.088955,-69.06906,-55.211585,29.443079,76.716137,128.666751,109.877133,-52.779325,-167.145098,-345.13805,-320.934068,-208.902453,63.801808,137.930518,80.350809,-26.307036,-254.233397,-312.019316,-239.039648,19.564241,133.634738,259.502258,266.35598,140.098341,43.517971,-58.243794,22.200611,95.083557,228.610601,282.789303,300.026588,238.472653,29.153696,-185.421824,-223.705457,-50.768242,95.487657,279.307791,276.571271,104.527969,-11.974138,-127.477398,53.231399,197.897116,358.059863,345.041776,213.83235,133.709215,35.392171,43.157463,70.075469,178.110945,252.942549,339.827142,310.315123,172.25629,128.634767,126.29447,203.099467,272.291525,358.623671,353.349328,321.340648,295.208454,180.759682,81.475622,93.708765,237.738254,321.906734,413.815699,392.04798,213.896961,114.454828,47.224859,174.324913,233.773245,269.985765,288.980918,317.434503,281.959415,86.566466,-93.436089,-89.896112,66.655343,135.796669,184.472414,197.260383,216.423845,201.609512,133.268876,150.147172,219.155394,369.102931,412.886834,429.502398,395.818516,255.561247,132.974156,129.409297,268.694281,369.601394,447.967133,385.46024,142.524452,22.91046,-119.396501,-14.908378,119.345704,360.795789,424.421848,415.86508,340.754454,186.338665,193.590751,230.319945,320.84765,385.947278,544.003801,587.558239,454.686311,303.27257,87.379912,153.991221,255.351119,427.817141,458.330547,394.325966,326.725595,245.013551,280.880482,317.790545,353.168974,341.475746,318.183161,302.799852,171.646039,59.286733,-126.385655,-112.547616,-47.243724,65.635784,92.274248,66.919589,0.5824,-175.957127,-242.185777,-204.782547,-23.330823,58.53457,106.588287,92.271516,18.67445,-35.487332,-172.12362,-214.851365,-130.577038,112.848386,172.200808,101.773368,10.45621,-110.727322,-98.576963,-90.111022,-58.142377,-5.104104,137.193609,170.494712,103.722393,20.75092,-199.660303,-287.603189,-213.555945,28.382052,109.452442,110.139988,50.075547,-83.692493,-132.948847,-111.034008,-23.074744,16.770778,87.073571,111.093157,46.237498,-44.499506,-208.786981,-227.77094,-183.339962,-31.561402,52.540212,116.609467,67.465224,-74.854575,-82.175535,-20.558271,149.174266,194.587187,145.208295,96.890545,64.048299,62.911438,-42.77141,-221.148903,-232.016078,-81.865684,4.875977,23.440364,-73.667552,-361.922687,-543.870811,-551.797835,-349.4626,-206.593541,-97.282722,-137.500958,-273.307906,-319.507613,-324.844298,-300.927331,-290.573253,-204.738977,-138.399431,-126.563663,-208.119531,-378.945071,-410.944917,-377.978455,-202.417678,-87.909127,36.850572,12.300615,-154.303323,-245.037783,-363.54982,-337.794486,-273.216237,-122.402234,-51.819034,27.040475,-8.111814,-215.228305,-379.376719,-362.866788,-195.773505,-129.641509,-88.120326,-81.821778,-85.963691,-112.349442,-177.362969,-171.981864,-140.268433,-75.772721,-70.230222,-124.590028,-170.245015,-278.823324,-459.603046,-536.922286,-462.741031,-330.557843,-132.794384,-111.338236,-132.074746,-147.247259,-218.967976,-273.099719,-227.253604,-27.693335,39.382161,-64.092154,-202.499345,-366.771676,-293.752069,-226.699977,-110.926835,-91.490844,-126.760024,-155.106805,-199.339143,-206.688107,-217.645897,-242.16826,-227.974286,-158.178616,-130.975904,-119.913662,-129.411529,-106.488264,-95.181536,-144.257405,-184.017334,-98.111382,154.387996,204.368618,22.046642,-144.123178,-335.673568,-268.40787,-202.825785,-84.82935,-35.19187,-33.704575,-101.008271,-269.396686,-387.218607,-385.324297,-202.244899,-84.494413,25.756499,27.029227,18.252892,9.205501,-61.777938,-130.563004,-122.458619,-37.699631,18.022773,49.096231,-14.992474,-215.682184,-352.198901,-372.961967,-291.324528,-213.643278,-108.967165,-124.179381,-265.924113,-326.145451,-348.485576,-263.110758,-189.498643,-83.662012,-93.405505,-212.335549,-266.391487,-265.510934,-169.834327,-128.70015,-99.072384,-92.34539,-10.506391,57.793406,101.600838,34.226512:-189.046575,-182.87533,-174.689823,-47.485415,64.764044,183.306985,119.863956,-29.888776,43.335949,75.349881,38.504343,33.905538,146.944786,203.783931,179.014977,135.247415,76.752818,23.791861,18.386756,70.969766,101.405687,100.965678,79.776662,88.208646,137.105699,134.090727,77.241924,70.509448,214.476476,334.378766,430.553504,375.617755,194.605139,102.067127,137.631377,277.540343,287.553826,123.587974,35.753667,41.52766,199.632871,276.475675,431.271263,531.765512,796.905753,916.280544,914.436267,780.846245,462.059257,297.983347,301.362321,440.151646,529.875726,621.984308,602.56521,521.164246,465.06015,441.621269,452.242658,502.160221,612.837711,602.81739,417.361468,310.070617,188.414164,198.189547,220.057177,203.577635,164.106615,78.027585,37.301042,-32.356863,-74.496252,-83.555458,-25.284536,35.257749,142.139067,174.117963,175.756458,146.980587,101.100145,173.215757,238.88405,293.112315,275.75142,234.376656,189.533513,-63.297953,-373.806986,-414.266562,-226.363362,-96.72204,52.353734,79.358002,79.625551,48.859342,-0.262493,60.525973,89.170456,34.313934,-36.58307,-155.348561,-181.419065,-188.287851,-180.42582,-170.77692,-100.720983,-46.406903,20.45152,6.46979,-59.288968,-62.21882,-53.361066,-128.752456,-144.338172,-72.864184,-18.793723,63.996153,76.996368,82.882036,122.439455,127.960122,89.852639,75.377903,91.74297,98.691753,39.431233,-31.244777,-202.309941,-293.296908,-265.695567,-115.455188,-39.219026,98.677221,147.656209,123.483242,10.059153,-0.987358,90.551739,133.76561,141.201799,133.309242,157.688189,181.639893,207.897502,224.898964,246.134597,290.571478,302.643232,362.064562,419.232627,460.229408,324.736556,260.191909,234.394397,248.333735,238.998948,185.928861,-25.051307,-138.890739,-221.218525,-90.815934,-6.980835,128.82344,177.328853,224.38488,241.035897,341.657387,461.466614,477.627693,414.341145,366.18445,368.729065,416.959827,425.614844,362.854179,204.129447,123.330759,149.692698,271.439834,289.046136,163.191479,83.864929,93.806776,223.422471,237.240562,185.087734,152.937973,114.029242,110.556797,99.039396,82.123618,-4.349671,-144.820934,-182.463979,-167.738587,-145.7254,-150.101625,-190.479937,-255.357905,-224.075005,-215.374931,-209.78277,-183.825533,-84.34372,-22.529431,63.796726,58.059441,-41.529213,-74.96165,-26.519746,51.127776,34.02284,-17.224497,-11.516046,11.076676,-26.995364,-34.516087,2.996729,0.776716,-66.34191,-91.636567,-99.874742,-90.103939,-97.10494,-168.691833,-174.43479,-94.232533,-71.43628,-164.704641,-236.190997,-263.763974,-248.818958,-303.269589,-404.271396,-354.756424,-111.294906,-42.300978,-134.51309,-208.366992,-199.424215,-123.289507,-146.153793,-216.964753,-196.493008,-138.458388,-189.119848,-365.260524,-320.639643,-245.039304,-159.087466,-143.138614,-117.340333,-106.503104,-75.708616,-61.462442,-131.153182,-260.3052,-252.373965,-103.199015,-36.252946,-19.993438,-61.676066,-161.973888,-304.225404,-382.638504,-391.773504,-328.479261,-208.462022,-175.944164,-162.229338,-169.784824,-184.325708,-215.607675,-212.990805,-111.219905,-54.586623,-57.004725,-100.284777,-153.902321,-178.415512,-188.715072,-149.888291,-124.766098,-88.323087,-41.081037,83.761601,115.956331,45.551857,-103.87043,-94.289455,111.096329,214.504817,253.927637,193.124814,61.171706,13.730079,-4.273198,-34.154282,-35.598033,22.285315,90.749375,193.292169,174.85499,74.775353,23.872502,2.579849,-42.295121,-41.525798,4.491207,-2.154471,-170.003622,-338.816662,-328.14854,-186.749397,-137.222116,-131.763747,-129.17429,-87.884115,-78.762282,-145.57263,-263.631039,-272.256672,-174.352741,-118.487499,-84.131955,-100.207861,-132.629821,-135.339363,-156.01958,-224.05612,-214.646039,-78.633115,-18.493889,-57.843371,-138.5526,-288.056325,-328.949326,-313.119529,-295.328179,-303.502472,-288.921616,-249.39325,-112.779779,-35.388027,-63.27012,-104.924078,-55.831251,112.30137,143.279433,-4.405064,-109.240824,-168.774406,-47.510367,33.355483,102.286704,75.994111,23.158472,12.991345,-74.62599,-228.845273,-256.36086,-165.832252,-96.913111,-41.108726,-55.08298,-56.48819,-8.874481,94.026785,57.864782,25.620133,3.697531,6.684892,34.046221,16.154129,-155.717506,-346.782134,-385.322643,-312.507516,-228.909644,-124.764493,-138.797865,-199.84988,-189.039874,-106.483678,-79.691019,-60.170728,19.863206,47.579773,59.94335,50.146837,58.499137,174.303866,216.886979,187.878167,144.823313,85.00819,98.640596,175.213182,170.037048:-152.684398,-19.890983,57.556327,140.328214,125.117493,46.663613,27.428626,88.746531,171.504487,151.64227,26.902735,-5.385417,84.11295,152.317762,152.237535,109.046927,71.100802,35.800684,23.437991,79.352938,120.599347,143.752887,149.755892,226.385933,294.393364,302.132576,290.516733,274.384557,345.249468,460.278987,656.447489,663.84981,506.299775,257.700939,173.163287,141.250025,151.410661,113.80288,60.487034,-26.130434,37.620007,116.028058,257.87881,328.299367,583.875895,717.569504,720.190093,598.148542,358.03721,242.054099,228.650622,280.224709,328.111507,381.615526,362.52532,305.356828,306.432092,333.668586,443.486939,487.009874,438.477562,365.744416,251.704651,210.706248,125.699205,177.124112,256.322088,337.682765,323.831199,275.291209,227.970268,68.99115,2.432671,26.487154,107.383729,139.609244,189.757167,208.328139,187.935482,152.963741,86.413471,121.556978,208.344946,403.277683,443.05641,394.81713,329.216614,102.16113,-161.387869,-202.693018,-52.803026,39.420272,123.153939,147.098991,180.190385,171.515096,113.405094,106.246709,125.919025,149.291847,148.782049,88.313677,29.749218,2.282435,67.440387,60.29572,53.907631,118.210889,254.785297,236.145288,112.22636,101.957564,151.213508,79.433453,16.282564,-3.643633,65.63349,215.528533,231.364726,201.103589,216.196502,227.282944,179.531503,108.194828,-26.891517,-37.453194,-17.952505,-40.010625,-129.371523,-174.878768,-165.862817,-95.319888,-32.387004,106.402608,122.486235,42.839773,15.131682,19.409745,18.195512,27.639286,78.658741,100.52514,99.999989,114.509394,225.762803,316.930414,341.19208,359.065965,343.251425,297.167711,299.810055,390.845545,396.828819,309.685831,119.772291,77.823547,62.682439,47.349665,-44.594754,-111.567705,-226.712671,-192.019747,-97.094449,128.251101,204.253094,255.38514,250.666281,288.743652,385.164999,387.046518,257.611651,182.297227,156.028172,189.936382,214.796473,181.955766,60.688869,-26.593528,-26.615872,33.288258,70.115733,113.432636,114.52537,112.440848,92.741214,72.362654,95.927209,136.094249,173.283757,160.701225,121.370039,110.703769,35.828029,-150.66121,-209.81664,-186.241311,-158.654838,-191.786592,-227.700388,-210.615867,-168.120765,-179.242505,-184.795716,-156.450945,-42.025321,20.766545,36.679008,-3.209041,-58.636194,-102.804194,-111.768993,-50.405104,-3.484585,41.638491,37.553621,22.13904,-22.264995,-55.011204,-56.231923,-29.281529,21.42606,36.730859,6.126098,-40.54107,-147.833644,-217.378176,-224.739301,-223.13564,-239.517673,-323.18966,-359.496825,-319.090615,-219.634063,-209.27608,-225.27046,-208.235947,-94.278114,-48.230476,-133.621226,-218.676986,-270.456275,-258.000477,-286.094828,-339.414275,-304.845965,-133.483362,-98.900461,-249.065754,-378.776444,-347.96685,-257.418384,-274.928956,-329.59877,-277.064708,-68.17817,-22.145926,-185.814053,-380.893884,-379.306723,-294.463768,-254.553588,-168.488706,-148.713366,-227.662685,-414.343231,-488.839447,-489.536685,-450.429031,-385.877784,-330.540154,-208.683133,-203.276795,-280.211768,-307.132075,-281.218299,-201.85833,-155.763132,-82.661905,-82.807411,-103.072901,-115.283523,-142.516166,-185.480429,-192.806129,-188.380611,-167.209724,-91.449234,-57.092888,-81.120813,-163.516218,-158.273411,-58.249406,-3.892109,19.25163,-29.040226,-117.988495,-70.355625,-65.636133,-143.677767,-164.408825,-101.522987,-61.317473,-51.912278,-92.055117,-252.757794,-357.014121,-348.357962,-325.394209,-332.006117,-284.044951,-246.114908,-278.043046,-431.014551,-487.33129,-427.131357,-323.880436,-150.190909,-121.917698,-128.428258,-127.785059,-147.550919,-232.685778,-237.84296,-151.719243,-103.570405,-41.366502,-44.171725,-131.185355,-194.943787,-193.822288,-203.564929,-222.574157,-196.422101,-135.292934,-35.6665,-50.408005,-203.898698,-374.445817,-433.541716,-527.024979,-533.400043,-405.392792,-308.750735,-149.912707,-151.480879,-222.990986,-291.878527,-234.544829,-74.392718,-44.877939,-111.730858,-154.05898,-155.965477,-124.090963,-104.699003,-69.28678,-75.767848,-81.168803,-63.382966,-70.957859,-127.288896,-122.692177,-42.900385,10.97368,133.499241,182.144863,183.554992,164.915892,162.367706,142.711425,137.525916,129.495757,106.811196,31.081277,-21.739998,-162.369611,-329.858327,-368.905585,-251.50784,-147.366348,-96.662564,-180.876409,-339.781507,-326.6962,-197.144722,-86.107692,-39.835298,-17.431381,-50.901003,-119.173023,-136.142445,-79.960662,96.314651,133.532986,49.131282,11.367984,57.702488,108.155106,166.492867,153.625986:-146.427901,-284.252546,-296.739074,-120.811563,25.109358,181.039404,117.082663,-78.723631,-90.196577,-81.103694,-132.255334,-148.23377,-31.148431,47.438145,31.082537,-18.590288,-24.322218,-33.285177,-54.901418,-43.100889,-14.034402,30.139023,33.097184,28.870978,20.977036,28.24898,136.051849,207.751301,289.193513,311.487905,340.64081,328.106173,207.305617,96.124233,135.477083,321.661414,341.045557,172.186262,83.177249,39.362308,66.689077,83.52955,220.212428,364.607799,690.262665,778.724587,683.838863,545.078942,287.361729,157.830481,152.568906,263.962204,339.078995,380.422682,337.21824,255.358661,204.705841,162.137665,173.293713,247.041526,337.181281,287.308036,52.833802,-52.932604,-120.283623,-19.512335,39.542151,60.379327,34.70612,-26.10353,-75.025979,-211.86316,-259.026947,-202.34334,6.892052,95.296122,171.504629,155.897197,36.975381,-17.490223,12.746791,135.513544,150.100907,108.132732,104.500106,167.1325,186.422656,49.258825,-247.523112,-317.501441,-183.480721,-69.748889,56.840653,72.588884,50.059807,12.934376,-79.743903,-48.525023,23.197662,122.115671,117.851802,34.343234,-41.597742,-176.987945,-180.850368,-138.57431,-6.596173,49.733009,110.277357,115.415644,63.90912,31.409901,1.142462,-11.83286,-7.125999,40.986217,103.253744,263.881211,262.093391,40.208506,-94.745739,-79.623327,-4.162268,35.472305,91.162886,92.012672,40.960556,14.082516,-2.06303,-49.263557,-90.114343,-105.396953,-59.413656,109.612146,179.0044,186.485174,131.371401,112.170211,62.196378,60.81077,197.321485,286.902175,294.690319,226.519225,158.207084,227.883714,266.28444,324.853867,379.581595,514.329177,532.890029,424.368825,198.049292,110.62649,120.406652,187.034786,274.796953,252.288816,75.86002,-26.97648,-128.732212,-68.860794,-2.39857,133.043771,182.021464,230.504109,230.65478,250.964406,327.814527,359.088819,389.853368,412.321964,496.713793,530.432904,500.338616,446.170369,341.19788,275.678028,272.216811,319.042988,348.322763,337.015368,273.078479,147.172635,183.287597,224.629736,241.118785,218.192871,185.60343,185.205603,125.641613,50.303416,-54.007192,-3.389001,35.344482,10.983881,-39.845114,-105.315118,-125.184098,-140.488532,-121.748688,-113.799581,-47.594262,-25.543914,-75.110051,-74.084691,20.476421,28.430351,-89.804024,-175.993902,-159.683408,-75.711197,-46.376472,-73.694131,-117.735368,-114.706409,-16.878748,-9.53733,-41.420244,-58.328498,-83.018212,-65.230711,6.148633,8.071344,-103.356423,-235.584497,-233.629429,-62.012244,29.564391,-0.405875,-98.612368,-203.27148,-182.729199,-191.701439,-206.252112,-171.817108,-69.768807,-70.774241,-178.478593,-191.378563,-57.886938,16.694883,-8.6276,-34.100254,9.593299,84.920835,38.879142,-132.988541,-188.243313,-171.346766,-100.896972,-80.950609,-69.346624,-31.433806,92.533541,102.266844,-87.662266,-314.785052,-304.001069,-134.796387,-99.434088,-153.379372,-185.577688,-251.591049,-419.419523,-505.475103,-444.414602,-297.420294,-77.947397,-77.35803,-183.495347,-222.820335,-257.121058,-308.74165,-306.236592,-201.532973,-148.148178,-161.610485,-223.212594,-323.041433,-314.773263,-293.561244,-205.49686,-135.514164,-23.729997,-6.991175,-59.45094,-86.99973,-86.929022,-110.901188,-101.9132,-1.29688,61.946201,100.561431,30.142753,-148.055918,-117.757572,-77.531749,-30.176353,2.084196,37.055239,35.576941,51.66667,61.124456,49.717576,45.094216,45.11133,-27.436955,-64.58358,-25.38557,-17.41621,-166.832825,-365.951599,-406.431217,-297.393023,-182.183966,-22.504099,-10.55656,-26.548216,-37.42178,-154.819099,-313.406022,-276.096323,-6.498888,75.956594,-7.923433,-95.554048,-159.604435,-95.421836,-70.083443,-41.00792,-29.419726,-6.43438,4.163062,-53.609783,-121.903763,-223.097816,-258.715194,-270.670901,-266.187856,-244.632673,-196.759674,-179.046888,-93.228321,43.718929,51.428591,-62.422659,-98.932751,-27.629184,8.145349,-130.603335,-264.980017,-371.99347,-182.422216,-57.116018,65.989116,48.984731,-47.02642,-107.163082,-248.394467,-331.21892,-303.994814,-137.531592,-67.1765,-35.181917,-40.217174,-21.663314,-2.417019,23.666877,-5.984051,-35.028498,-79.213321,-80.912805,-35.618183,-17.273348,-61.521461,-203.365512,-273.112999,-301.863185,-265.159821,-168.531537,-136.750714,-127.734671,-113.073787,-39.486231,-19.432889,-8.01235,24.053092,23.821519,27.575305,29.638605,-14.362927,-16.4499,21.997229,76.430608,65.527445,38.410572,48.213636,41.878579,6.509237:backward
7.691666,115.741219,109.071804,4.549925,-31.568442,-21.222939,15.155482,105.041848,162.91278,152.047313,38.015731,-3.069454,43.814093,83.890733,80.365322,47.917191,-4.178252,-46.055101,-77.141025,-68.304116,-33.524064,-97.38136,-180.346091,-159.708633,113.826747,232.790321,302.87465,253.689728,46.85283,-64.581569,-186.191887,-192.08081,-176.043768,-183.28198,-185.186372,-174.828656,-194.299826,-247.32828,-205.485949,1.81625,118.217107,106.280039,10.680772,-27.727039,-26.98835,-6.837215,32.969556,66.730243,191.986032,298.837004,289.254979,166.678475,116.88165,128.923724,175.334601,291.310543,323.974296,291.18599,256.316228,280.995997,325.499609,311.840641,242.746249,213.868154,202.264157,246.222606,244.609515,143.793471,75.77298,-31.05609,-65.647405,-35.902034,153.658532,237.587582,267.783126,218.899846,57.374632,0.010262,6.135003,22.401302,13.644095,49.525976,61.371051,-38.412331,-120.521168,-169.597512,-109.578543,41.352424,116.635603,152.953355,184.991892,155.00001,67.566593,46.372711,51.018092,64.495458,117.443324,173.866621,160.37877,74.90517,36.060415,-52.328504,-83.943803,-19.942728,129.985369,180.45542,214.888228,204.042369,119.39402,60.856197,30.543282,65.927113,113.130797,87.791628,68.333777,33.417435,5.224414,-71.74271,-78.000517,-1.703052,38.697746,15.899355,-105.533396,-179.422528,-262.692096,-252.024033,-128.736763,-44.56015,48.735123,4.420316,-27.308732,-35.902919,-28.265591,-46.128571,-50.518241,22.277574,144.740482,184.819507,135.841177,62.313116,-36.447211,-43.060505,-22.613217,-18.872489,-0.474901,78.636364,95.824842,74.809999,71.736097,72.788921,70.635834,73.026922,103.441513,139.161578,230.105669,293.653285,431.343066,460.59462,456.452954,459.48269,482.405942,510.824517,477.160848,231.238868,79.029491,-86.266098,-93.82788,-76.669972,-30.117001,16.574218,40.635843,9.184545,-106.440439,-193.715926,-287.330162,-242.417628,-105.649223,-65.805241,-49.524976,14.328089,21.028187,-79.745231,-125.549987,-41.122475,147.180849,209.991972,262.229462,261.944192,217.623655,182.209471,154.192071,177.653588,257.016592,270.236925,208.062379,6.122986,-67.580178,-131.930416,-150.202873,-162.246755,-39.533144,64.095114,168.445776,153.922289,121.170884,119.161684,128.238373,136.655745,145.153358,135.624518,124.072527,82.305632,43.549958,-44.667193,-60.364029,-42.506352,-53.57283,-44.362235,18.320807,25.909449,-26.53757,-41.636832,22.813267,83.45418,164.659142,122.715817,59.066828,-46.128175,-71.263577,-157.422192,-219.000983,-275.402584,-263.116687,-264.743205,-298.932735,-332.553362,-407.782588,-423.063528,-371.613969,-342.362047,-341.193294,-256.906094,-197.573575,-222.304923,-294.490257,-378.588577,-336.093695,-151.034973,-80.364189,-105.74619,-211.937155,-257.316022,-297.509301,-321.100505,-341.064574,-310.755602,-247.338923,-247.48154,-260.466769,-289.834081,-313.00514,-341.102108,-298.7571,-96.632209,60.15811,77.161633,15.22079,-13.363808,42.205137,83.749683,95.915822,104.85925,170.445206,187.481654,173.028666,145.278196,106.834797,-65.825113,-144.419685,-179.849272,-162.344278,-156.676801,-159.669464,-165.666359,-107.368453,-54.081441,-23.333909,-36.469688,37.499963,154.664471,109.291718,-128.196709,-230.329195,-375.584647,-402.529247,-274.825322,-74.017533,-15.446546,20.535373,12.290461,-83.751408,-165.593451,-253.654508,-237.185027,-158.736113,-91.003044,-64.952684,-23.869654,-42.686272,-162.06794,-184.541892,-103.013214,-15.61071,3.475793,-24.723588,-53.836278,-95.897588,-128.702772,-159.715804,-109.087936,50.317894,79.738489,43.147366,-15.9301,-34.156718,-87.226346,-96.982942,-100.925789,-151.657876,-141.36674,-60.865882,-36.523108,-60.788653,-92.726638,-76.045426,-39.415759,-40.270992,-105.197002,-129.06434,-149.95331,-165.645814,-227.237568,-239.728175,-237.469298,-272.445528,-280.262701,-260.572395,-225.831619,-109.187783,-58.918936,-12.312922,-6.196093,18.019591,120.192402,175.690216,155.916615,94.444019,36.617089,71.019907,198.849122,248.83495,230.422173,104.104604,1.618712,-164.233533,-185.811843,-115.458733,-75.760414,-85.004323,-86.031683,-69.637839,-78.597568,-93.256396,-54.005226,4.368419,82.1877,95.174604,112.664157,98.276836,65.490902,50.325171,68.126097,107.152177,126.903698,164.456387,183.659576,176.322375,96.345485,38.223868,-49.400109,-69.864411,-42.875255,4.556588,-0.448745,-33.104485,-35.522845,-31.952389,-42.356598,-18.021288,35.206106:78.197114,133.268837,103.660162,55.727349,53.433617,22.907713,19.084705,81.939125,146.601567,149.848964,108.616681,74.247198,29.11883,34.68979,53.614145,46.722087,24.456648,-28.929634,-82.559904,-158.44646,-157.158308,-150.697099,-156.451106,-99.953703,61.26965,144.979596,200.042951,143.760327,-90.265394,-213.686006,-293.758644,-244.381473,-163.906596,-193.772249,-203.215199,-189.935671,-199.630073,-249.380496,-230.28889,-51.949523,102.61965,112.068184,59.649252,40.60272,45.706704,70.656455,116.276036,105.358037,112.79102,222.528713,228.946267,66.17988,-31.402607,-96.553978,-79.428821,-15.653692,77.731857,117.005108,138.360202,120.043053,51.577246,26.616079,54.635556,97.378563,188.131518,240.47827,229.600624,142.872438,84.067514,-55.116411,-116.53993,-94.49046,119.369941,196.609905,170.470762,118.524688,63.925346,53.508508,60.637032,91.171378,147.003184,114.029428,64.854627,-76.881043,-125.846962,-93.554591,-48.028658,40.109887,170.512954,203.420565,106.204904,26.784089,-56.973835,-63.980792,-15.897761,33.432838,124.343317,134.480466,87.979709,-59.524216,-122.426764,-177.035546,-150.977166,-22.894841,11.136357,-8.55664,37.122877,101.178407,139.255618,85.317962,-4.834987,10.007106,76.190569,69.836837,45.99381,-6.482898,-34.029335,-95.959184,-132.321516,-155.044513,-23.203629,51.168428,48.921127,-21.844175,-190.200018,-236.694028,-130.588579,-15.945307,66.241,-76.485387,-141.11345,-177.620149,-161.863197,-93.612222,-61.982108,0.731374,113.379766,132.299581,15.511209,-57.808548,-120.675029,-131.814535,-153.885172,-151.172354,-68.776392,106.88126,169.590509,150.250809,106.885774,83.907558,104.74314,145.714562,193.665387,224.783779,281.86794,306.208336,274.803465,220.191399,263.330493,379.762716,484.56341,333.614837,261.107106,151.061588,76.382861,-64.42723,-77.472097,-41.54961,-67.236771,-86.260073,-116.245261,-140.602534,-229.419268,-285.302528,-320.194327,-271.694924,-146.951275,-142.349693,-148.504087,-121.117928,-126.213504,-172.148848,-156.744827,-13.405329,77.309997,82.28546,133.446416,188.408061,222.091177,157.561345,7.714463,13.381693,147.70461,138.028763,49.023,-148.563644,-202.234655,-156.837063,-91.297853,-3.858716,65.966054,128.901173,177.695203,118.986508,1.338471,7.532341,103.768145,156.723079,242.7495,259.621183,244.984852,224.99246,192.936239,58.33621,10.482871,-2.574885,-12.098797,-16.989437,2.303942,2.578473,-70.049877,-109.987898,-65.347979,25.371173,220.253766,221.243926,123.728064,-121.302557,-216.132789,-336.578721,-358.688591,-349.762762,-317.607681,-280.896782,-221.641904,-232.428857,-303.735617,-316.950289,-249.586257,-210.112337,-206.545057,-257.39118,-299.008069,-392.988874,-408.337225,-353.970614,-306.114386,-206.434802,-127.525795,-118.906553,-204.144801,-258.485532,-284.266966,-278.355546,-271.402132,-249.854077,-181.37061,-191.690563,-232.145512,-278.027714,-265.821397,-208.364308,-156.872407,-4.146654,124.530284,151.708586,103.6621,65.909704,21.757574,-3.223824,-6.432074,49.696525,214.638936,286.552073,278.122211,241.485691,205.330641,38.279953,-54.007232,-96.855232,-43.800154,-44.251337,-111.256041,-152.078318,-147.359841,-93.218499,44.149348,87.64304,127.613687,183.508798,184.213434,78.444347,0.965366,-137.056263,-167.393473,-83.352338,65.991471,78.241119,-16.589071,-56.065332,-110.814108,-156.370459,-202.836721,-174.838609,-66.223817,25.055662,18.790051,-113.746905,-188.687206,-244.193853,-221.679858,-126.107411,1.877013,51.188938,33.817533,-13.149611,-92.032293,-113.056048,-50.725008,37.983647,206.382147,205.355688,136.047323,-4.578415,-46.598366,-111.462644,-128.912162,-122.297762,-84.882118,-53.412552,-27.882028,-29.708269,-28.920529,-42.442773,-48.352284,-29.093382,-33.721679,-69.817819,-102.036862,-254.014153,-337.997286,-378.957038,-316.81787,-148.788286,-91.580467,-112.536929,-196.707099,-219.43845,-172.376751,-124.338191,-36.957107,0.132468,70.265351,138.384616,170.496639,204.83239,183.106664,94.806316,82.784309,129.045651,153.254395,144.205709,24.919418,-80.58924,-242.217944,-255.199322,-170.358405,-111.385086,-33.501022,3.185343,19.250318,-2.3123,-51.572914,-85.355039,-28.45998,113.524982,155.657546,150.877957,133.050838,120.77012,65.235336,35.813144,54.023253,103.35075,228.651196,248.924081,189.279485,12.40133,-58.823598,-125.427818,-127.91127,-78.59836,-39.967062,-55.427991,-137.655651,-182.864634,-191.351085,-139.382643,-44.628978,-37.880403:131.824303,102.333872,75.933727,30.699176,6.767431,-27.330315,-8.804641,60.100677,74.803165,58.61826,20.377428,9.770638,-23.934945,-45.692356,-1.618637,57.481455,79.933721,-57.970024,-117.140383,-182.672018,-229.5101,-329.287093,-320.012613,-150.575103,-6.279248,13.371544,38.562832,47.161181,-59.887297,-174.581335,-311.713664,-272.290029,-113.201004,-86.096408,-108.110882,-162.872296,-218.783866,-330.558909,-307.372696,-84.71694,133.552984,174.391363,102.556497,41.127074,-18.908022,-33.098154,-79.314193,-90.507658,-12.180545,91.230401,61.658634,-160.268282,-264.325904,-291.018264,-236.270478,-117.570652,-43.349691,-19.942528,9.990389,-1.467574,-91.210276,-127.283655,-84.742846,-17.247506,109.198971,116.056359,90.134843,56.064731,20.763797,-91.584534,-99.392771,37.583752,185.627024,214.361838,177.693354,130.075912,56.676419,50.347027,57.752517,74.211553,213.215106,329.982595,299.068297,96.829814,-18.967635,-135.147859,-109.041495,33.529642,97.388637,69.971618,-21.624008,-29.215417,13.348618,16.435856,36.055561,76.052662,148.735205,92.560389,6.000694,-169.286687,-206.532726,-177.974129,-138.149853,-47.496425,35.219118,76.407786,81.319767,22.596164,-68.427502,-51.762064,14.892309,24.159574,17.709765,-3.101576,-18.583463,-17.177179,-12.302545,-37.614298,-47.186006,-10.255937,60.676551,92.238981,77.728623,20.978045,-126.907721,-158.480532,-63.627517,0.856318,35.127494,2.682116,-16.064026,-117.342551,-201.664185,-244.611568,-159.926001,75.148354,201.606952,195.468623,76.314729,-4.747669,-181.310778,-235.926402,-164.477726,-79.641844,51.552317,147.054858,188.523001,182.968453,141.231992,96.947972,102.142732,132.83776,237.537115,283.269427,269.310031,243.667067,187.747582,139.628896,112.200334,173.013436,316.763669,311.577411,250.96508,66.690779,-26.779733,-83.960749,-26.021525,89.46348,36.02201,-19.605683,-108.639837,-141.043079,-209.307472,-241.794147,-225.690055,-175.743975,-75.309933,-44.785369,-50.446931,-86.722754,-129.618042,-196.155741,-158.079477,43.076256,155.386646,153.961606,122.743929,100.655703,25.642998,-9.834492,5.70065,60.202891,164.205974,105.506538,12.30778,-124.522674,-118.1915,-37.615324,-2.333029,67.317347,143.321636,164.939318,140.035504,109.82837,79.025686,76.02253,81.445677,100.240387,177.626093,249.744535,251.307791,177.915021,119.508946,38.298574,43.72939,79.689409,78.40426,94.118334,146.641168,147.782495,47.246653,-12.609984,16.54382,92.19606,185.719053,98.329657,12.240865,-132.125622,-179.571934,-301.112912,-366.923766,-363.049776,-188.377044,-133.621462,-188.03752,-252.199147,-336.865709,-343.041905,-289.51997,-251.252813,-185.802509,-149.191755,-159.11838,-206.029226,-228.161596,-250.653083,-221.238857,-59.053549,116.208641,147.239693,61.470205,-8.594092,-105.874647,-130.12211,-137.057927,-134.098595,-148.889056,-157.953627,-149.99775,-180.408157,-221.319301,-198.558455,-103.939241,80.066128,142.472298,152.37997,83.417753,3.38471,-131.172712,-138.939603,-46.049242,31.951537,203.578428,244.545396,205.614762,142.760542,130.41293,65.084598,5.812807,-92.46142,-103.470907,-110.409111,-158.403898,-156.799545,-88.346261,-64.118331,-57.030561,-48.652124,-2.158123,89.001005,128.216756,86.745134,-0.558465,-113.130143,-60.16538,149.627275,177.903902,120.380305,21.415408,-11.283335,-122.396688,-183.296645,-180.382285,-121.042145,-12.842002,1.475276,-56.182928,-249.648213,-308.359863,-268.791956,-200.470563,-57.12946,37.313816,69.152826,107.535224,95.826407,-1.802482,-58.132891,-59.457049,8.120701,178.595958,204.747672,152.675457,73.01712,51.555759,-14.014425,-26.812482,22.866244,37.659912,7.604248,-44.771739,-24.218225,33.982171,3.489155,-92.869747,-93.723904,-93.045446,-187.965067,-217.33995,-260.526589,-318.12893,-412.379453,-375.789339,-204.926187,-98.274295,-57.525283,-45.897847,-99.876875,-209.181476,-205.02426,-85.429289,-0.310995,157.390027,171.24979,135.787853,94.428404,90.615616,111.682927,137.318069,163.842688,165.886636,170.153722,89.488812,8.109659,-82.912825,-66.910271,30.800105,78.223465,143.310541,182.473449,173.874871,103.686823,64.055041,42.7087,76.427703,176.333104,254.614695,265.446216,180.880545,108.300615,-7.169891,-22.088316,48.848316,94.175059,131.066328,85.996952,42.670885,-34.552004,-68.953867,-113.76554,-111.654981,-91.821865,-65.997718,-48.980975,-108.512684,-190.561668,-273.47247,-237.740556,-188.809831,-206.492971:75.010378,71.129601,46.818304,14.652531,11.809795,31.543529,65.653603,76.834593,8.386586,-10.239593,-68.955553,-84.258449,-2.992994,38.92018,24.0187,4.384093,-17.045386,-122.731307,-178.549284,-188.355837,-181.397816,-267.843424,-321.615461,-284.864616,-82.244701,18.0165,106.008298,95.818413,-19.352462,-123.050072,-259.312522,-248.07468,-179.901041,-176.033057,-190.482414,-201.978595,-199.237698,-197.100041,-188.449176,-123.393824,2.622865,53.533265,70.099531,50.919356,-4.163779,-28.258635,-26.659395,-6.125341,55.711873,146.693947,168.622043,112.799278,46.548952,-90.011831,-104.177976,49.193219,233.983293,270.006996,266.78779,232.594743,112.559547,76.485668,129.98596,175.233211,213.297752,227.304841,203.512964,96.326207,56.348633,6.014663,-12.870686,27.93968,174.967406,239.173692,269.996864,244.398063,157.085427,120.557626,135.345927,178.723654,253.569907,267.672029,239.400764,85.951645,-11.484031,-95.620384,-51.83095,73.948848,59.29123,27.352449,29.977606,49.250268,35.270779,16.369118,20.393244,22.482415,42.331552,137.620758,142.972011,21.121491,-46.366266,-92.430819,-67.803569,31.872874,105.608242,118.190717,107.81609,89.964718,29.316952,-14.453088,-56.437119,-25.295527,90.49283,146.230517,134.618808,57.635457,-0.704511,-117.469556,-127.059082,-6.450793,119.240263,147.768736,89.403793,10.257957,-123.0321,-151.856672,-88.024924,-10.312305,71.300773,7.856329,-35.829848,-94.684383,-99.607069,-62.080533,-21.855075,116.324895,267.072296,297.785925,220.494161,141.121095,14.312292,-7.704101,18.876377,40.429239,101.722833,241.022708,297.632471,255.154745,176.067572,79.125719,86.51947,113.942764,113.077612,131.716091,224.054949,283.374868,347.335739,331.10784,299.862198,312.431536,338.286684,339.640748,308.301909,151.600989,50.661242,-79.999205,-79.216406,-26.273099,12.367243,44.959412,83.034066,46.897264,-128.238334,-208.047496,-222.051018,-177.516785,-105.57587,-57.98315,-26.072905,40.394104,53.046579,-1.176448,-31.155523,44.32031,175.318568,180.895979,138.925662,133.833164,143.705253,144.419213,138.726915,140.947958,155.596674,135.842099,85.361105,-52.243206,-91.501812,-103.085468,-94.19651,-50.203959,29.278554,71.318378,99.908966,84.237641,47.954553,32.635968,9.28285,5.42284,30.351801,123.566737,138.806291,23.154001,-41.312456,-53.966313,-27.551664,17.529446,48.478169,64.457802,79.46491,69.734064,8.355195,-33.701039,-45.066717,-8.596418,66.288361,78.809794,45.500574,-41.421473,-72.821124,-164.753541,-225.272107,-288.273784,-250.016554,-228.968365,-255.007471,-287.869611,-332.381274,-339.46724,-301.083617,-268.130415,-224.23486,-173.334602,-153.18659,-162.640144,-181.063283,-182.802641,-141.517385,-15.68909,3.510482,-42.389551,-156.713827,-197.669638,-256.684204,-305.877274,-413.364752,-414.774274,-308.070642,-226.964068,-210.294338,-211.709108,-252.184156,-335.595073,-297.253275,-126.552062,-59.115603,-48.469704,-84.83599,-138.793678,-221.055603,-226.936192,-183.510739,-123.21023,89.140663,192.637365,138.06083,-5.519658,-38.80678,-112.896052,-178.408668,-259.519209,-176.748389,-138.420951,-209.638284,-258.116857,-197.626061,-124.824092,-70.003234,-104.88342,-181.847222,-103.33103,-69.532541,-170.731903,-273.08165,-431.456626,-422.979429,-193.339815,32.493742,64.092539,2.792321,-40.070712,-92.867489,-122.824073,-172.503009,-165.814566,-111.24788,-93.350079,-101.995556,-134.996112,-178.866171,-284.262885,-281.900177,-146.973758,42.048477,119.78463,126.267702,62.03023,-74.008816,-125.946002,-128.139114,-59.560052,96.870548,110.558264,66.284516,-15.482318,-35.713474,-56.802209,-55.348281,-47.159565,-56.666062,-64.741937,-84.625851,-67.509604,-10.011373,-31.806784,-124.827203,-128.400556,-61.125558,-69.784963,-117.588245,-185.823394,-203.892021,-266.808402,-279.120438,-216.408324,-162.417465,-161.821571,-179.798692,-179.357755,-130.18148,-84.629317,-5.857635,23.702549,125.608946,239.052099,255.200341,206.803758,170.310754,150.707914,182.225639,259.729595,283.861938,274.491815,110.253933,-35.853773,-225.171127,-223.551274,-102.988573,-41.249155,21.768636,96.954518,123.046418,73.518282,20.141206,-26.620946,4.205463,105.417482,181.554484,205.266665,167.777375,115.853705,23.795388,3.897727,59.112952,108.827294,171.888034,194.948345,171.267101,42.176011,-33.596293,-120.911085,-114.260424,-43.624335,25.952659,34.253033,-54.275564,-126.095546,-198.195175,-172.412212,-69.314364,-27.738111:155.820689,99.610662,49.398286,-78.176385,-141.453042,-155.124494,-83.035101,39.51058,-29.581935,-97.365832,-182.956624,-185.117848,-157.877461,-134.497892,-28.091718,20.65071,-33.84505,-230.518423,-296.018778,-290.330927,-280.671827,-395.778538,-461.696045,-399.70791,-141.970666,-33.51484,-2.989539,-71.69675,-257.856591,-323.926868,-321.222744,-264.115001,-119.414588,-32.061665,-40.649841,-142.036697,-212.175775,-292.316532,-268.302593,-132.169783,15.062242,56.339913,25.539856,-23.180128,-129.109599,-188.111493,-251.79553,-216.620242,-37.17741,120.378311,118.621647,-66.261368,-180.761822,-265.587259,-231.666876,-122.25015,9.20008,77.641313,114.953306,50.77569,-144.185332,-177.785702,-42.701062,50.266859,137.150257,153.330807,146.450522,39.826969,-72.105388,-269.076413,-271.312441,-127.777364,50.876941,143.968985,251.019828,230.850624,136.715475,126.800954,205.228952,275.06846,407.766122,381.578485,309.17748,155.643385,87.152569,9.871783,18.235061,38.800403,-11.247215,-42.819362,-62.170643,-55.454541,-82.156733,-105.428994,-79.321106,-30.72355,87.904095,109.419336,61.073526,-95.545964,-167.270928,-179.570034,-110.50478,48.225394,140.828647,166.119713,122.134482,43.061551,-98.681992,-103.151257,-20.752601,8.767964,27.484608,57.675905,53.18608,0.700548,-27.928986,-47.82287,-30.026205,48.62362,192.651501,262.465506,246.274037,160.453389,-37.405319,-90.030264,-8.048289,89.67975,229.563157,209.658922,153.935021,-15.496917,-104.561914,-150.551582,-84.748482,123.314545,291.180893,321.087374,245.971942,177.152633,77.071876,61.088047,93.688238,114.040476,130.94291,212.496128,264.774083,265.202288,211.711746,97.728004,78.210781,146.205388,259.304717,290.222321,272.835678,238.476751,138.214054,91.30278,109.497686,184.694491,357.800838,381.989181,320.12254,131.067767,35.940078,-40.121047,4.155855,156.421448,266.55493,275.398953,146.546878,35.288039,-149.325244,-175.796333,-96.862559,-43.744974,36.461444,130.806169,156.955059,87.356195,12.392258,-42.391153,21.750271,239.23726,357.617367,340.469895,203.966021,136.897997,93.045728,111.168079,170.694361,208.153378,280.047813,206.205296,114.335525,-30.383542,-49.204332,-12.106839,19.390505,104.320592,213.503272,245.433817,220.988962,178.396695,84.583647,69.312215,165.800265,231.46412,262.873146,271.936778,268.372869,160.426732,98.7427,100.355421,170.279358,313.027435,296.383567,262.064307,272.451393,287.193433,163.08365,51.004973,-37.671204,5.035679,134.286985,192.384245,157.874884,1.266509,-64.347771,-123.742542,-138.102149,-126.533238,-0.545517,40.533802,-19.475856,-56.543497,-70.537412,-93.121335,-162.351724,-139.118424,65.878367,215.200614,172.964296,-48.522202,-119.485513,-39.054997,77.261588,276.341094,360.520915,363.657273,274.552716,195.986138,28.168571,-37.204227,-72.461051,-46.434115,6.118087,-32.127844,-77.477827,-148.319986,-161.384019,-138.703963,-96.253443,29.374772,104.525859,84.84257,-56.609035,-127.236574,-210.823246,-235.429976,-199.823131,-123.196467,62.198118,159.715636,156.752608,38.979981,-47.225454,-164.805282,-187.135095,-174.903388,-126.082077,-141.228012,-240.899705,-249.936354,-141.45036,-80.095279,-40.005128,-56.469504,-77.410153,-7.596069,1.476002,-127.324714,-217.431401,-285.324551,-238.665047,-65.458689,38.597474,43.188138,-4.27137,-41.848651,-100.100322,-114.412368,-124.275932,-117.405789,-89.258895,-110.529632,-147.603742,-201.026085,-204.271783,-177.66555,-140.313066,-20.290307,75.825886,97.985749,46.519198,-21.191928,-134.16137,-146.601472,-56.462472,21.912018,147.68292,159.983116,126.273272,43.885685,-3.688416,-73.542991,-60.979923,-0.867126,40.706024,60.730829,59.326947,40.17033,-30.363332,-82.63202,-139.840198,-120.098035,-34.846539,-40.722051,-90.029446,-154.876561,-167.966894,-214.768715,-222.010889,-188.829946,-141.967926,-108.408006,-66.555498,-67.642038,-61.867812,-43.469647,16.36627,66.600551,206.506271,260.425839,229.078366,130.440862,86.774929,62.707469,109.60595,251.476784,291.484556,251.216562,62.202498,-35.088431,-122.297698,-122.042141,-30.36764,55.981384,169.99475,118.578703,69.490093,-35.658075,-103.720946,-169.50604,-119.734949,44.229928,182.383245,233.529998,186.393575,94.016913,-65.039312,-90.822116,-50.857144,-18.560473,66.873388,146.660821,113.921384,-75.2023,-167.014423,-230.09156,-201.388876,-144.750103,-155.23553,-150.780561,-122.930402,-125.792767,-208.821478,-254.382967,-231.182765,-168.601075:-146.391347,-102.877859,-72.41868,-32.314312,-26.878891,-97.555043,-143.644988,-118.433659,-12.868409,-17.854008,-120.060236,-134.903469,-21.741559,56.148969,103.820017,60.275411,-63.011066,-128.054077,-118.560844,-34.888129,-25.890494,-185.063478,-281.701043,-274.658349,-50.576977,52.776232,121.494949,94.079973,6.726273,-37.40736,-136.965105,-180.793857,-218.265793,-206.920836,-189.423949,-148.582823,-142.642425,-166.885922,-169.713667,-76.990533,114.617346,171.077122,90.787397,6.397275,-92.362577,-106.504641,-68.667102,-19.688426,124.761787,281.610107,286.827759,155.153411,113.030569,166.625168,214.420062,276.3778,302.834822,301.692968,281.647632,276.851723,295.516297,299.354332,235.529552,168.53975,61.056098,101.51185,135.883654,72.553714,-22.276666,-167.907358,-169.089074,-56.521922,104.890234,154.594863,136.013392,104.630845,58.944671,37.025088,53.029181,94.979678,157.191471,176.464032,148.811148,-23.684755,-116.770517,-143.735763,-75.35638,48.351783,50.973438,56.322391,93.765285,88.858223,31.666293,0.645962,-26.455012,-14.734529,52.099197,149.319727,152.370801,53.882588,15.3037,-26.940963,-48.104666,-16.56158,139.53232,210.09975,214.066529,166.99004,96.849378,88.36439,114.615367,150.481283,250.145515,284.351299,253.937168,129.514653,51.772424,-60.78178,-67.603407,-7.516504,47.674216,45.346129,-42.984023,-100.653722,-168.509859,-192.001422,-178.058069,-105.505058,56.552991,66.920794,49.001446,49.691143,46.619249,-21.937564,-47.632674,70.733811,284.67518,328.722056,262.586009,193.341034,71.241298,43.110973,68.867576,80.732083,78.37544,166.690722,194.827421,137.216407,84.563924,-8.123732,-23.073257,8.099988,38.01925,73.964863,202.730146,258.955288,283.166972,250.58621,202.974378,222.36804,273.996632,274.087691,248.560694,74.382777,-63.257847,-253.094287,-247.994024,-130.354525,-51.087659,-7.64757,82.189058,75.891135,-77.932871,-170.125032,-220.951508,-188.446703,-123.503163,-94.148773,-72.440739,1.321819,3.525246,-151.353329,-224.420584,-133.440053,45.400981,81.516589,110.083029,104.233434,53.973256,42.468174,114.112379,167.391042,165.545929,41.328607,-15.058837,-52.48425,-54.530888,-160.663802,-242.894067,-252.473947,-52.945163,25.765494,19.833874,-13.180607,-10.7772,-0.643683,-22.088271,-33.225193,-13.411673,23.152393,7.039031,-85.827924,-123.573589,-167.095009,-169.804935,-127.60936,-105.005965,-101.59652,-71.059031,-44.07343,-41.74484,-100.71665,-214.279917,-191.912106,-23.1458,88.652778,61.388476,-110.96195,-191.476373,-266.18223,-257.021971,-150.968516,-75.541672,-112.066336,-295.377331,-359.991555,-319.615994,-281.956654,-318.118372,-340.472172,-233.531375,-30.601677,-2.360076,-123.977625,-179.798759,-164.916963,-125.889444,-29.982042,4.607963,-26.603044,-148.403725,-217.609566,-329.272267,-359.842001,-368.356431,-360.781424,-323.703593,-225.865583,-168.222637,-132.889536,-187.619785,-348.499453,-357.837867,-208.700814,-140.584144,-178.046586,-260.149859,-251.220152,-164.154765,-138.816928,-121.178363,-90.460905,14.100187,22.986942,-47.443739,-229.330426,-286.465029,-330.95122,-351.038259,-397.630223,-365.2674,-316.989297,-257.957528,-254.895366,-248.99816,-252.100288,-272.152818,-258.634725,-156.229934,-75.95871,-119.244551,-326.368381,-398.865585,-396.136804,-346.129552,-257.175962,-191.080482,-115.485437,49.399256,79.012877,15.649444,-47.169273,-135.789258,-139.050304,-106.57472,-118.929656,-129.902834,-92.265311,-61.475873,-59.284089,-83.64495,-106.430492,-17.679204,46.34602,46.736772,-27.892111,-209.841244,-291.999004,-332.93088,-237.942566,62.928977,138.504816,59.418597,-121.99831,-160.84136,-105.809361,-39.77649,1.349372,-127.190495,-177.423047,-181.013747,-157.628931,-139.257313,-144.373953,-106.504637,-72.928814,-96.007943,-253.423352,-320.071021,-324.682016,-291.906303,-302.708079,-328.672027,-281.954746,-198.834989,-190.800655,-222.818453,-221.882314,-117.454567,-47.189254,23.959465,24.553987,12.395988,70.183702,121.08518,129.581674,89.859441,59.546516,96.193407,186.693143,175.632759,168.979152,107.443437,4.617792,-217.748456,-249.196936,-112.931572,-19.584651,49.997877,30.313775,16.825694,-42.121551,-66.476772,-7.974388,52.583325,111.188104,129.186085,149.499101,160.716758,145.045675,97.93113,89.209676,142.217871,154.640835,83.451746,68.627342,96.083326,117.460138,105.477098,84.803617,90.074975,123.804998,136.424188,139.509417,107.729837,61.097838,-36.35575,-56.2637,29.812893,134.551365:-44.90875,0.403119,-5.710971,-79.148715,-105.455132,-94.592473,-70.75548,-59.437224,-78.632642,-84.850944,-163.697445,-222.740498,-231.702709,-169.873299,-32.782056,-6.270339,-62.718922,-142.666068,-159.888179,-193.079344,-240.134046,-389.26473,-427.809158,-345.545829,-166.288284,-83.415265,17.214627,14.22741,-135.278113,-242.882821,-311.642032,-268.141103,-187.508736,-157.273607,-140.147396,-109.120747,-119.327272,-159.350584,-146.107939,-46.722371,54.392569,69.363023,33.953737,-0.811983,-129.751937,-208.551172,-245.243445,-172.844195,67.847001,224.067561,199.859632,2.256004,-96.479457,-153.010632,-100.505429,55.478718,152.314364,181.717655,182.270759,127.636361,-19.879697,-48.901463,-1.570261,33.173435,83.653608,128.406806,124.0968,28.026111,-53.033447,-175.475823,-160.504033,-23.83854,117.424085,177.462667,207.793188,175.521965,74.477771,40.067252,94.505344,164.142262,301.890666,366.426394,324.921923,109.617716,-15.946148,-151.56644,-122.82709,13.75855,52.497703,48.218029,46.681761,37.455124,-24.016952,-53.891507,-5.982409,58.16615,138.497074,131.478773,107.153723,14.973774,-35.096728,-59.678869,-20.136242,82.626708,131.549569,137.336905,106.911816,65.089518,-47.642031,-90.074899,-80.452005,-19.276983,184.041052,309.271644,272.423876,69.417537,-26.463044,-109.393716,-87.061801,83.8682,288.985014,317.222278,175.388736,78.86138,-48.21489,-90.177071,-71.00679,6.306117,187.109925,208.160675,148.915442,26.657271,-9.596555,-23.328436,18.223388,165.205849,280.446551,324.685349,348.715155,305.150476,162.002421,109.245992,111.045715,146.41375,216.836401,284.670838,303.330705,263.849447,199.323369,55.258048,29.988963,99.717315,202.894491,229.114884,232.363264,216.201717,118.459093,41.082603,-2.735664,83.315953,327.106047,365.665918,277.573997,-3.149646,-123.777962,-150.740034,-55.0927,127.720506,154.594939,161.371167,169.508069,140.728379,-24.603498,-131.313829,-181.240282,-110.697251,54.072985,152.31147,165.462685,73.295765,-15.953826,-114.694454,-72.796718,118.397983,243.643173,260.077167,218.399583,163.408884,43.22602,25.709669,116.284054,179.819453,247.193143,239.646697,202.482349,54.179629,-34.425674,-147.728865,-148.569188,-38.858108,153.403069,233.402072,270.864031,229.445632,85.425115,18.94358,15.530248,69.971197,161.845788,197.951531,172.348215,47.037447,15.889751,72.739579,132.046591,266.619674,345.818178,340.608807,258.81491,209.257893,107.258801,45.059666,7.039653,61.743151,216.209299,296.997369,276.852605,95.006758,-16.991285,-114.97634,-92.99276,-27.418618,40.861155,84.917068,85.902092,42.011465,-48.211458,-76.800238,-66.879142,-32.09833,62.661449,151.807183,160.815815,92.377903,57.141199,61.407775,93.395891,182.499804,265.79119,287.144659,235.44264,163.582799,2.58675,-49.657797,-75.459077,-60.357728,22.922877,70.468029,42.489141,-81.352544,-152.672404,-205.387158,-147.782817,9.711761,-2.065592,-71.863214,-215.417557,-252.215744,-286.712132,-283.689672,-155.556128,-50.397035,76.395939,46.194583,5.717586,-98.737205,-159.168506,-254.35339,-281.325539,-265.875247,-145.358105,-105.027412,-174.856162,-226.112437,-204.653594,-169.87752,-169.416611,-191.555523,-153.502407,4.264265,4.243207,-227.503635,-349.633,-401.005637,-350.610404,-257.954786,-168.469738,-72.208741,96.610523,82.925255,-87.075448,-154.391146,-135.848274,-75.315149,11.230045,-11.588991,-39.28198,-90.322111,-123.926919,-154.439864,-112.833636,23.081852,123.515193,149.436162,74.363061,-26.196996,-254.171332,-332.863411,-289.319985,-174.415212,48.127186,77.318543,21.380496,-139.370353,-202.830771,-213.162522,-161.223921,-41.383873,23.024418,40.243732,37.275792,20.741924,-35.2846,-76.820173,-109.185225,-76.829907,18.61482,19.741852,-24.132992,-115.031181,-160.600792,-254.725105,-260.922469,-167.597015,-83.842008,-67.655257,-78.82203,-86.967578,-39.93196,3.481461,98.773627,166.022536,286.640576,250.390381,189.862146,104.184556,96.443154,109.655378,134.273288,219.221879,258.830059,237.988785,36.037466,-114.597591,-288.625199,-284.545362,-173.309243,-101.841444,-14.779561,-10.31116,-28.43915,-114.050933,-168.440878,-218.524679,-194.500631,-103.979885,-16.063996,19.852689,9.796735,-54.445019,-206.862049,-219.919674,-102.449887,-31.99359,46.66922,43.88735,22.208252,-41.887793,-94.382482,-178.667733,-150.442266,-24.417827,-12.708712,-10.568427,47.057989,51.814167,-84.089035,-169.87044,-171.862409,-96.507855:-208.07699,-132.954766,-89.602248,-47.295484,-44.944666,-103.464953,-150.746928,-193.523097,-144.939155,-111.987677,-76.414016,-66.147026,-11.737883,13.147034,-9.198735,-33.550158,-33.552797,15.947952,51.744656,136.782067,152.639402,36.557758,-59.360745,-132.739589,22.472676,147.147315,294.589516,273.912141,134.046602,55.532654,-74.545989,-118.233942,-147.536438,-69.931252,-25.830244,3.781043,-6.056939,-59.974668,-78.901259,-5.487416,130.868941,139.66216,14.845603,-62.810298,-136.572423,-138.092585,-74.098467,-9.478776,106.509846,159.009743,188.636194,253.391079,268.570458,282.363484,301.204475,336.524745,249.419302,188.382255,170.740894,200.943225,194.260797,136.367956,52.269001,75.189725,131.358258,87.015329,57.365163,-16.908601,-65.597248,-92.787763,-29.938334,164.443254,181.432889,129.079518,66.406814,60.640337,50.000349,41.047377,56.337044,85.808895,133.173102,132.246677,97.470239,-15.556579,-38.021971,33.537089,85.571951,122.758094,111.091439,129.19102,174.589068,178.740209,171.957215,152.408439,53.216021,6.346922,-8.421773,17.074162,27.522979,62.748391,83.087042,77.057158,57.565446,58.381864,109.239952,137.287465,174.721079,175.095373,153.044517,150.924288,166.372286,171.893543,230.121174,323.33064,294.562547,109.629133,38.66181,-21.736374,-27.621037,20.874445,60.26114,31.356054,-78.825831,-95.026319,-12.962415,6.029221,-57.942337,-54.988717,81.0272,133.165807,92.082026,34.628062,48.171248,35.515106,-3.963469,23.647771,236.10686,326.05087,304.998953,213.21291,90.787441,121.366949,290.76095,321.434199,150.491668,-45.04858,-55.244688,60.379736,109.828866,20.913354,-77.227532,-169.845438,-126.793149,-95.899982,-11.264433,45.489116,119.436764,118.37246,70.119486,39.910935,-1.531083,-5.003256,-35.528232,-197.43624,-277.077963,-325.902,-300.71321,-222.997488,-126.419518,-45.127859,60.591811,13.916663,-187.501559,-239.420954,-168.232274,-106.328861,-54.227508,-18.444312,23.008239,46.929596,-4.133943,-141.883158,-160.604227,-83.453419,-36.71078,-35.316088,2.724806,32.930601,28.173499,-12.503994,-78.574052,-78.996453,-81.46138,-143.724193,-190.81124,-306.335318,-342.477919,-323.695792,-294.596648,-263.188474,-246.463117,-211.548941,-100.846372,-70.27197,-122.088727,-173.756271,-202.417764,-176.524001,-145.099244,-163.773191,-174.439528,-150.175094,-123.357623,-153.331157,-186.279661,-114.618138,-7.524985,-39.620017,-191.529798,-223.457031,-188.946343,-184.702058,-205.80078,-200.333494,-142.09784,-24.057321,-3.554908,-122.988843,-199.640834,-242.038492,-217.048275,-173.361773,-217.267022,-257.263191,-346.005761,-383.646098,-397.431341,-381.867942,-353.441403,-324.9646,-150.480547,24.80324,-7.772625,-216.277376,-253.066246,-118.599218,-30.542498,42.620791,-16.52511,-73.161119,-228.082613,-300.899826,-319.792036,-271.15252,-213.734334,-239.368217,-314.52638,-260.795823,-202.259119,-197.626195,-274.582666,-407.915992,-379.294897,-210.352339,-188.069628,-224.318292,-257.781574,-255.994324,-253.786668,-250.886288,-203.339324,-149.028835,-54.725746,-72.982634,-115.002943,-261.454675,-356.475259,-481.438693,-493.070689,-475.926109,-444.369252,-413.606909,-373.676262,-365.015387,-325.335849,-315.275388,-367.650483,-394.859088,-363.597276,-294.047184,-284.181734,-325.032334,-346.97184,-346.704494,-329.217937,-293.093347,-245.09067,-191.635467,-57.887715,-11.402697,13.271094,-6.101851,-63.788248,-77.191763,-65.827599,-20.932769,-0.961005,-3.237763,-24.583085,-66.361846,-71.67184,-31.309731,104.482256,164.345194,146.294847,86.510942,-39.683773,-104.882755,-178.979818,-138.703452,50.431076,179.138463,185.675137,89.589749,19.516247,4.317562,79.749781,197.214438,82.502527,4.048329,-80.452271,-110.704337,-167.031177,-171.055782,-139.351502,-140.104469,-191.789092,-250.361281,-273.889366,-273.873383,-264.317835,-343.259753,-411.842591,-409.817263,-239.635843,-178.400005,-164.064155,-153.902015,0.696935,96.198191,124.714254,77.71189,47.276408,27.555971,-13.620657,-19.00597,37.511521,102.248171,81.476132,43.21448,41.897278,28.527825,-37.975934,-82.509602,-165.16581,-181.796691,-108.377826,-37.961752,57.661202,54.595458,31.53939,14.730252,32.565803,44.630136,15.435839,-65.533787,-92.725895,-77.747328,-6.24461,41.700036,108.376349,102.721921,65.789306,53.117765,18.870907,32.758752,64.136481,113.103265,113.387326,96.319802,111.333023,174.014908,166.895267,147.609733,128.831503,120.015148,58.449617,18.254072,10.169018,48.790258:-124.308649,-107.835626,-93.096154,-44.019085,-27.507063,-125.751284,-199.708683,-177.121817,-13.477653,30.905837,17.08361,-5.124018,12.505324,44.504293,44.778492,-7.286878,-125.867003,-87.12838,-27.582514,4.900422,-26.409984,-81.13716,-84.944642,-65.566077,45.95334,151.86186,328.18031,339.844995,206.674403,98.683771,-69.219494,-86.948381,-45.694764,-24.68967,-24.045182,-49.757881,-76.826724,-110.286012,-87.212303,52.174108,146.567306,116.667444,-26.443628,-77.791968,-77.888547,-43.066628,88.909457,166.317369,196.226346,160.816629,200.058366,327.032909,369.124473,389.28573,388.781632,381.899871,308.353212,280.892447,312.193847,340.523207,350.03604,318.838176,213.9674,161.612305,97.675431,176.119077,224.213421,163.258884,73.561082,-69.71002,-81.900093,27.701719,137.937938,132.79215,64.691644,40.065165,3.29304,-21.383618,-58.944487,-55.056054,-19.063964,-28.781722,-48.613981,-72.708759,-79.700816,-71.764001,-38.318801,75.66626,203.055667,266.982174,331.199397,321.324597,254.256476,205.489436,124.666218,105.085876,88.745351,119.678091,118.115725,66.546741,63.046356,79.002879,82.249221,160.35019,303.244335,352.986504,385.020013,372.004952,292.113674,238.579213,190.220855,209.384208,279.408259,286.786532,227.404989,60.042483,16.150232,41.384539,78.719517,126.719793,116.734717,84.105967,-39.454398,-96.11982,-115.913918,-97.575922,-15.833571,62.874652,182.95186,97.335009,32.601078,42.633647,88.02778,89.31101,49.369969,32.9193,129.523898,184.038229,211.175728,184.269927,145.961506,148.596941,160.320412,138.449423,29.171695,-28.022387,-24.870761,-5.419357,2.871408,7.319996,13.400769,1.63284,-64.131981,-68.049182,49.795562,183.563182,458.492517,497.980011,425.571939,392.567771,357.134037,348.671572,332.669126,217.005368,145.857325,34.149046,-4.846819,-45.215942,15.192916,92.016015,176.75309,140.96812,15.836362,-25.102465,-55.014799,-54.584445,-36.803345,-5.154735,26.972147,122.093445,129.05519,-21.751783,-92.166543,-12.137473,176.470287,220.290532,214.994514,214.47546,254.528603,257.081673,229.994199,232.915926,222.983946,118.623415,49.180915,-62.500353,-93.085094,-152.327673,-176.087244,-165.217861,-132.608853,-110.549749,-21.503299,26.74415,38.360039,6.934548,-6.378566,26.648584,109.861783,110.890132,73.114271,16.327254,8.070628,-47.327102,-89.803228,-96.905376,-31.369425,-32.998306,-115.399557,-134.165728,-40.50831,12.862596,35.330967,48.919421,123.773261,165.722811,164.420921,139.5024,108.800392,3.290405,-47.036361,-105.402783,-162.260979,-180.823955,-142.774947,-112.519069,-123.554147,-153.686887,-166.765641,-139.686924,-6.608558,149.010181,136.444519,-60.246505,-149.339319,-182.071557,-129.553724,34.206249,136.820354,131.828717,-10.660112,-94.479813,-152.763458,-157.010906,-190.371057,-207.561253,-214.40835,-150.267911,-102.065836,-77.999178,-126.438311,-243.18013,-224.837008,-35.522408,61.131561,38.912417,-41.772672,-51.613712,20.014508,54.812996,44.617193,31.889433,84.801922,164.340347,133.103501,-80.51065,-188.353525,-299.656685,-326.246829,-349.559515,-299.689769,-278.685532,-318.107566,-324.662086,-192.780924,-123.394616,-146.836773,-187.574295,-138.516313,-25.192635,-51.703581,-269.401661,-385.716514,-500.21974,-470.931646,-280.545027,-141.88532,-140.09928,-136.888906,-80.76138,-10.564801,-77.288171,-273.703285,-295.408,-164.533044,7.067163,52.649877,61.622505,39.133919,-50.724794,-95.850832,-97.769552,43.134657,103.229128,58.548452,-19.15797,-128.838713,-141.092638,-82.589065,-19.593924,118.825946,195.833135,189.250683,88.843881,15.765012,-30.19281,23.513282,83.32462,-34.52676,-71.723987,-56.930021,-45.922753,-64.703208,-81.998527,-81.308673,-66.772473,-57.245313,-135.812779,-210.561454,-295.691619,-279.677493,-278.512465,-331.112557,-416.504594,-357.521105,-311.989485,-237.396929,-175.948649,0.049337,64.941994,64.3789,21.037661,-9.052319,78.690906,118.307765,107.315274,58.664315,-43.19687,-46.754413,23.187129,25.234801,10.527363,-17.170369,-60.917754,-189.176169,-226.153252,-164.653327,-89.715263,-16.037843,-60.14339,-64.353563,8.700093,51.173208,81.356806,71.385921,15.677776,7.458266,46.481499,76.923053,44.568447,19.301408,46.224438,95.729239,101.478256,118.340865,178.752674,197.357685,161.291383,116.029251,43.216647,35.920171,34.503442,-20.440797,-42.620261,-36.319336,-17.287415,28.18927,37.638352,69.998299,116.234187:-183.740746,-63.393473,-33.823673,-120.733652,-181.056656,-190.440906,-149.583565,-95.018517,-115.614364,-119.724904,-94.219187,-96.53255,-160.179692,-184.627976,-129.058242,-79.248162,-56.163873,-42.28232,-26.55787,-55.776693,-106.558405,-255.588372,-299.602912,-228.524088,-81.830656,-26.199425,17.38398,17.737018,-0.606672,-47.521601,-172.289852,-190.254722,-136.136422,-86.823786,-83.124889,-109.729442,-135.325758,-141.939327,-90.08152,57.012068,78.380561,44.400317,-30.242813,-59.169433,-98.090773,-104.646386,-62.252895,-5.298424,136.652835,214.52202,210.50398,153.820087,116.825366,67.062859,85.394445,167.555615,164.394568,157.933153,199.951155,225.149468,214.693996,170.093485,73.005598,62.896917,75.664565,20.775945,-11.895688,-6.804733,11.659066,-52.986484,-115.300159,-103.458684,50.983221,118.283441,168.424586,128.563285,-14.504835,-36.841959,76.338469,139.304034,180.581538,181.997108,164.045123,78.005285,32.303103,8.409746,28.746837,59.000196,3.245127,-21.32679,60.297769,134.592148,177.946656,133.520634,36.439169,19.616424,12.176189,55.697057,102.23895,118.826872,58.996835,-72.593149,-85.322123,-32.698611,15.441272,43.496163,133.412764,160.003795,103.347416,68.400556,80.715735,109.240613,194.772308,309.794154,323.871976,181.312898,63.521397,-89.031618,-90.527802,14.831197,160.659855,190.175944,92.793857,27.283362,26.426215,31.965277,-54.865432,-58.804352,92.372211,169.065459,127.798116,-1.458699,-44.698011,-87.133633,-66.791812,109.316237,301.556837,346.961853,305.281968,235.217891,89.524297,55.084194,151.949719,231.524072,237.514943,186.498898,209.253226,231.993531,205.466453,118.781227,58.301669,-42.03858,-14.064245,16.701046,20.614484,11.852565,14.451324,0.857142,-57.384007,-67.414262,-34.573238,22.575412,31.436557,-54.985614,-131.892138,-245.600638,-231.267709,-85.487385,-29.551648,-13.765777,77.465942,85.706785,-80.069776,-186.23185,-198.953184,-113.260076,-16.256426,-31.009641,0.779089,82.803082,57.435459,-119.636086,-176.085431,-112.297565,14.199417,53.502838,89.757249,77.887712,13.404329,-7.073173,10.099099,39.893453,50.167971,-85.1093,-160.409723,-204.6848,-189.147276,-167.615274,-153.302926,-91.21396,-28.030038,9.163436,129.581789,174.262143,60.467185,-69.416761,-148.790599,-70.813626,31.613898,-72.982312,-145.722204,-181.71845,-142.36661,-42.322266,5.003397,64.786774,32.235768,-10.118601,-86.538918,-87.937629,-48.667502,-64.46323,-121.893579,-104.085341,-1.274704,66.356541,51.525353,-82.814963,-160.873077,-240.874593,-235.21024,-160.665214,-88.936125,-94.355563,-197.517654,-264.245994,-355.026935,-361.416682,-309.428142,-266.98957,-133.711566,-0.352081,0.760418,-89.485985,-92.998443,72.953948,157.655007,107.265024,-49.871796,-64.873208,-61.356421,-99.222197,-150.084508,-116.153543,-60.484596,-92.233186,-181.046341,-127.157788,-60.480481,-32.319451,-110.143178,-274.713069,-253.982794,-77.276835,-111.349994,-221.316049,-404.00188,-407.339206,-280.224998,-225.451469,-183.313584,-166.512513,-118.754775,-91.874644,-111.071322,-190.276607,-235.42001,-333.238778,-369.770286,-382.588948,-325.247347,-284.674887,-212.765434,-186.325763,-169.716339,-196.103728,-296.740094,-316.530284,-208.431953,-74.458925,-91.18168,-272.002612,-347.788804,-354.81543,-315.229381,-246.204294,-179.581251,-116.066833,23.133218,54.292324,31.642764,4.975322,-19.915813,-16.056453,-15.676206,16.648225,56.267219,93.083662,67.938527,-10.041054,-23.47172,25.207894,119.610722,150.046991,92.269751,13.14365,-153.538992,-222.666291,-255.656895,-190.908643,-11.947594,61.601906,63.087188,9.111526,-47.032187,-112.637554,-68.686001,77.996095,37.742366,-25.368312,-62.89463,-43.313511,-45.799883,-93.579608,-172.542161,-148.104869,-26.273818,21.400999,-8.637655,-125.399132,-188.919437,-282.311172,-281.581489,-179.540475,-127.119938,-139.508718,-111.851596,-48.094176,125.356552,185.369611,141.70821,71.07293,21.225969,76.312898,79.665411,13.162475,-21.924324,-11.275395,41.782864,140.761443,79.051963,20.470966,-95.7696,-164.988988,-275.631268,-294.912754,-233.156641,-165.392875,-58.660961,-16.997933,-18.346347,-95.178909,-151.681502,-184.017069,-148.961655,-74.615932,-60.022613,-65.99061,-69.991022,-30.945406,123.520986,174.107074,161.897144,123.484223,56.108096,31.982035,14.451055,-10.17323,-1.355423,46.215054,79.548882,122.91934,137.159318,157.034973,178.396567,159.502747,51.482855,-12.453946,-18.158925,35.709203:backward
-48.824923,-88.122866,-109.222884,-154.301972,-174.362249,-229.843806,-283.786656,-342.442379,-278.586143,-265.783697,-291.689063,-276.286226,-114.864401,-20.189527,56.534807,72.737492,145.674822,145.957774,95.297603,-20.334603,-42.645114,-19.081147,-7.929019,-26.686482,-86.387088,-129.531778,-233.834112,-275.59632,-296.951176,-281.16576,-174.112806,-78.483771,96.147762,157.228532,145.63953,60.91029,17.56016,-26.903951,-24.099581,48.081663,128.96293,142.632151,75.277953,2.330306,-66.917343,-35.350378,52.478667,57.629163,-21.777708,-49.608793,-35.133452,5.522918,50.736761,132.341958,130.127536,51.753583,-67.727616,-119.76683,-191.914957,-201.997479,-122.077285,-41.254698,118.547661,148.858797,50.715153,-85.081528,-128.562948,-204.663201,-215.015062,-150.046968,-93.432472,-6.458779,-59.408479,-87.684907,-69.057801,-76.095066,-172.319931,-216.089465,-212.521552,-178.616605,-113.434038,-98.601388,-139.014974,-274.397834,-304.306978,-255.718496,-225.653502,-199.77941,-171.546333,-172.191945,-186.613351,-144.020886,28.26005,75.741631,72.836277,88.27256,157.095749,149.024539,109.491376,32.015994,19.410935,19.135574,21.37768,78.956797,136.675573,100.024193,-92.186223,-162.030254,-67.313339,48.345656,201.922741,231.667313,246.014999,191.70207,146.38655,104.429631,126.030091,171.920704,171.494435,183.799073,222.38574,226.1307,221.181611,241.627747,359.337316,420.30518,473.864687,465.547503,394.68328,388.801355,407.81507,356.48299,302.373022,216.944422,198.642682,249.572462,310.674959,284.788271,101.865728,-15.34441,-151.249389,-150.705641,-75.324274,-31.731169,-2.858605,-75.130273,-149.168559,-321.953601,-359.837758,-269.424915,-164.778679,29.820778,51.063852,8.957633,-116.475948,-180.423521,-223.241857,-175.102449,23.211622,103.416573,107.012348,59.480864,45.624827,14.606951,34.162176,122.019684,135.394471,103.092081,67.213282,51.500801,20.584831,24.813854,99.824768,128.924861,139.744019,159.695134,204.680841,194.459722,174.470083,79.610586,18.49776,-25.984842,-0.229784,16.023939,-51.462584,-58.777389,-16.125023,3.640349,28.290338,51.006984,145.745859,202.58519,224.960001,112.923321,48.386444,-22.712449,-5.033935,91.441423,125.447142,131.467589,97.066791,84.81826,57.951123,19.182954,-45.997578,-3.617662,221.546452,310.491732,241.177232,-9.930019,-107.155228,-198.005564,-173.424598,-44.369348,-4.8168,-23.56812,-120.962266,-168.368141,-252.319426,-281.082272,-225.973701,-146.778636,11.521356,65.29361,101.744552,-6.728468,-130.228675,-380.513165,-428.333119,-369.981329,-319.108133,-290.031724,-371.410607,-404.766806,-420.961867,-422.040067,-416.966261,-411.932278,-367.610343,-300.175684,-177.027097,-176.732606,-160.898282,-86.540492,-64.799726,-54.231886,-48.866148,-22.619437,-20.837788,-43.612247,-94.13926,-99.534903,-99.467057,-120.82252,-158.591387,-140.413057,-45.066375,78.804071,125.562999,163.161322,190.493736,276.461511,297.702004,286.22611,248.330789,214.994742,112.268032,64.869488,23.296318,19.09509,60.973254,124.442119,221.272029,158.064167,93.886513,-12.993188,-28.533226,42.209691,108.19,155.341084,68.008219,38.044516,3.096978,-18.183723,-15.868802,8.399769,56.915454,77.176419,88.870705,48.414423,10.407338,-72.065917,-80.327434,-29.3239,6.954492,96.90434,116.7245,74.63782,-36.70584,-55.553296,33.02465,95.178328,180.754221,221.483955,294.119339,280.512513,222.807283,101.592057,92.813185,96.958895,78.307523,98.082583,189.674668,230.356923,225.829035,168.898757,36.791405,-7.505789,-4.442579,49.870867,167.54668,203.99675,175.267314,29.817413,-40.574359,-91.47577,-67.788042,38.995099,61.830382,4.61696,-157.125402,-199.319581,-110.683084,-13.067515,106.666863,85.116412,-113.212331,-327.659765,-380.619051,-392.947693,-369.607643,-302.876392,-261.081986,-185.147421,-227.307468,-272.949387,-355.285265,-406.877063,-447.877634,-388.339745,-220.708137,-189.310008,-210.169494,-241.762597,-262.923297,-263.634175,-221.392581,-119.85753,-87.551063,-23.578883,30.232523,-3.123456,-211.652294,-315.776365,-346.995953,-276.990107,-137.241877,-123.256306,-162.01643,-176.037531,-181.801155,-212.802862,-214.575509,-172.433469,-145.807177,-128.669575,-176.418671,-189.080395,-141.412928,-92.912529,-7.479262,2.079604,-25.130154,-35.316079,-29.297547,-35.973056,-89.261103,-241.655496,-267.362958,-190.616246,-137.652738,-93.861553,-161.821403,-219.863222,-320.53535,-341.274728,-319.241514,-301.856724,-244.27007,-177.156556:55.201153,-3.186112,-52.713675,-112.069328,-104.151259,-89.233023,-104.002472,-164.872235,-295.10076,-360.727807,-395.052573,-351.461028,-190.082471,-105.723114,17.479872,49.838706,21.735153,-102.550742,-138.901472,-82.810153,-30.863654,-9.855584,-16.007201,-12.124137,-114.094214,-186.67236,-254.076069,-262.947518,-266.712664,-230.413402,-54.646202,40.36733,147.111082,155.381707,124.828898,53.125608,36.751605,-7.556967,-34.554838,-18.509932,69.440983,107.337484,79.642097,9.539432,-108.419091,-110.517878,-21.637708,32.333029,79.250747,24.44658,-22.652804,-50.205295,-3.495117,126.992591,155.749623,121.450643,43.573828,1.168384,-64.348117,-65.516091,5.336231,42.571735,78.987361,97.218295,76.93199,-73.578649,-164.302786,-270.971189,-243.068436,-88.181802,-27.095281,13.582417,-22.771046,-41.325309,-54.17657,-68.209854,-154.466859,-198.354333,-167.070483,-111.31243,-117.835048,-271.711339,-327.587915,-311.404339,-249.482748,-148.780107,-132.834013,-126.07604,-140.161029,-145.837311,-132.820458,-122.666451,-114.307361,-114.233028,-53.972167,15.608938,117.382747,55.939468,-11.55014,-88.293333,-79.985488,-11.554889,50.221472,168.030118,49.925835,-76.436256,-251.511966,-255.199658,-102.063637,19.546575,226.766663,257.554972,198.540013,134.988487,81.340515,-46.725768,-36.593393,145.481097,229.022756,257.140564,196.878082,202.078357,308.296698,353.356449,368.289401,380.64201,506.504534,588.058481,591.40154,416.545301,353.264137,329.271882,357.556233,405.732367,389.36639,303.271648,239.857596,201.435174,18.63317,-95.565149,-167.797787,-107.343983,3.569797,-16.72834,-114.110665,-150.958994,-201.807918,-357.522852,-373.978096,-240.792754,-158.119084,-79.773311,-55.199643,-41.428131,-81.670263,-127.833968,-161.262269,-128.54986,9.584122,71.844148,91.114387,54.035387,35.925235,21.3669,47.540131,154.153676,205.872649,229.947232,132.619865,72.647354,-32.096288,-62.140707,-5.447268,61.456694,176.889601,226.332304,252.13353,103.639803,19.254068,-72.902549,-83.818393,-60.093568,-38.626148,-66.217922,-173.889885,-177.23391,-99.612145,-59.997469,16.092063,45.978591,129.382888,194.305605,200.716338,-7.753169,-84.017836,-79.573628,-42.792872,34.373864,79.004235,132.96945,87.000871,53.054886,16.114107,16.24025,70.049904,115.14657,203.247965,231.255219,194.366503,77.293715,23.503017,-52.686893,-69.645962,-64.874101,-56.291675,-78.453411,-148.144445,-174.900394,-213.272403,-221.52033,-165.432252,-97.929809,51.758735,81.638453,2.284663,-128.545423,-207.599236,-369.003134,-397.48262,-306.322581,-232.287352,-204.880339,-351.130674,-404.057657,-429.192081,-429.571773,-407.300534,-384.408528,-325.414729,-291.995596,-233.027443,-149.044573,-101.704817,-73.278255,-90.258612,-105.180029,-94.316524,-50.582914,-38.211306,-85.160896,-189.343871,-166.738481,-32.37731,-11.024101,-65.026459,-73.819305,13.094942,124.293767,147.63127,180.489647,210.413323,230.282904,204.043135,194.720319,302.360878,323.94283,211.478788,153.588158,167.205847,184.949882,165.525164,159.083002,151.003307,49.888998,-38.173281,-120.432086,-76.439943,24.352131,38.901765,35.781826,5.176954,-20.309301,-92.126559,-113.778418,-70.683509,-42.522638,-38.421956,-34.589608,20.299141,23.191177,-31.539559,-152.308014,-170.150946,-152.134508,-134.797018,-64.653211,17.334682,31.301041,-28.588849,-61.457009,0.210142,75.106138,192.963661,226.171745,240.695987,204.59895,172.403179,87.669606,55.178709,47.775602,86.095653,192.529031,183.784139,160.212448,157.230941,159.728224,104.680481,43.411637,-66.219145,-75.426201,-6.192231,101.144234,133.420461,85.176529,31.47519,-16.479788,-6.008945,40.00314,42.284063,11.303658,-89.38602,-136.249095,-119.973642,-56.297283,54.856459,56.388118,-71.742551,-220.796242,-245.058211,-212.122375,-201.646666,-224.852326,-211.87762,-97.608139,-48.240502,-104.090431,-311.895075,-403.125051,-462.036833,-421.819154,-253.51652,-177.261608,-117.612899,-104.814643,-100.136788,-105.100591,-102.581798,-29.600957,38.866766,115.339653,21.254083,-59.809183,-212.053869,-260.204454,-238.262007,-160.442588,32.495468,82.288529,32.980006,-43.756242,-58.725837,-84.87265,-91.443354,-106.571834,-129.476866,-165.849658,-125.661728,-116.968255,-161.857696,-145.527193,-5.86816,45.464555,63.916139,41.725994,-52.702137,-96.103112,-97.731826,-115.966943,-114.136204,-62.000159,-20.497918,56.992767,12.809386,-62.667897,-210.752223,-238.903254,-193.724434,-158.263566,-95.918709,-54.601335:25.835208,-146.568056,-174.998705,-149.268649,-143.788312,-168.1526,-160.427462,-127.245906,-235.016965,-317.652305,-373.083097,-326.924207,-163.211259,-96.261971,-34.172536,-25.976848,-51.285656,-106.930655,-144.985565,-208.849326,-201.989875,-134.83118,-118.787137,-176.546623,-285.63826,-321.152292,-343.127992,-333.695961,-286.518607,-253.839315,-119.388574,-14.215306,145.08125,128.10752,71.401117,-12.755569,-7.579319,54.236385,80.129745,71.721933,-21.999417,-69.865036,-122.39725,-123.092977,-89.477217,-62.064827,23.810601,52.291703,3.309684,-47.090419,-31.755543,68.17321,150.383399,308.248829,334.806776,236.089312,74.603424,24.446219,-25.896282,-39.921989,1.60015,69.968053,186.695907,185.144499,93.374315,2.045703,-36.928734,-79.026189,-53.347057,79.965756,145.819893,196.966151,152.788915,130.85604,109.74718,103.021766,79.68509,52.723732,-14.011898,-45.279795,-139.385013,-251.521231,-290.372204,-286.161585,-246.445924,-178.91262,-155.12011,-116.705512,-183.960427,-261.222709,-334.595409,-278.529843,-131.715728,-121.204293,-144.119534,-113.497827,-7.685557,-48.364595,-123.288126,-158.015981,-89.486906,49.472086,74.819887,58.909872,-32.910865,-103.016902,-222.20276,-235.643364,-144.195799,-66.934783,78.253202,130.299345,144.120606,33.078416,-18.34825,-5.864513,56.249041,178.856922,201.304576,193.041395,194.108302,215.634459,279.458182,316.989373,419.323415,468.487242,541.241618,562.296083,529.599216,418.650474,368.50603,340.811605,354.646037,355.37712,337.274338,310.146317,287.807586,249.480369,64.761195,-37.893706,-63.01483,4.586556,55.657278,-6.117455,-151.601055,-181.263388,-200.151962,-274.385994,-280.533243,-165.946194,-73.688499,3.993347,-73.008548,-99.72983,-71.160936,-30.621597,33.638759,55.694055,114.430124,138.195669,124.942966,90.016023,102.549831,197.688817,232.479641,196.266105,175.299394,202.600777,168.280816,90.677081,-90.664187,-112.517554,48.529297,156.798633,256.844874,247.559416,153.197611,28.82031,-10.239717,-10.805924,3.669325,-16.11601,-36.823933,-43.744171,-59.983344,-81.179892,-118.298348,-114.58704,-47.627567,-5.101476,96.919312,158.922763,189.18456,34.564683,-42.906343,-73.894207,-37.074253,67.188904,122.648054,184.266916,112.024097,57.321621,28.492839,72.515061,176.535527,197.837552,233.098789,261.231879,244.343365,109.783465,39.379354,-59.204543,-71.074227,-15.731963,15.856386,0.152835,-68.877011,-80.593023,-97.965169,-114.698512,-60.914674,25.208073,211.29779,250.115568,173.291446,30.544052,-44.532659,-177.217427,-203.865145,-172.333004,-138.290174,-113.430551,-156.239433,-176.350142,-201.013487,-200.862547,-177.521234,-177.603073,-234.661408,-262.18476,-208.502945,-62.898389,-9.064304,19.578961,-9.327547,-74.366856,-67.285101,3.261145,11.895132,-35.281814,-157.691133,-176.63224,-115.884891,-81.975958,-52.665377,-46.14194,-36.821796,-14.326332,10.038796,75.88525,100.091905,123.072685,140.848405,210.412793,250.526585,229.831746,166.363405,159.51758,169.442209,158.882198,135.103838,139.798676,125.518348,2.654486,-82.568076,-160.960985,-127.731654,-61.847603,-54.35185,5.944773,40.436991,3.478712,-118.755072,-144.67801,-63.976298,-21.749518,-50.593694,-74.586785,-47.216479,-46.390649,-100.906717,-200.585888,-186.36664,-81.866695,-17.658064,99.534268,36.564287,-47.556197,-133.076647,-105.969854,19.508813,76.908649,154.947972,182.072707,210.719277,185.261389,142.436638,52.323808,33.773901,53.731257,84.762065,102.388994,19.171725,7.901837,67.967161,91.551696,81.184674,43.503706,-85.629496,-148.01978,-184.590521,-88.524879,-43.445881,-39.946974,-68.04115,-107.847131,-87.970261,6.681698,24.900284,-4.78895,-75.711093,-100.274987,-125.84443,-125.800346,-86.022492,-75.109382,-148.432201,-233.62835,-257.921829,-279.24115,-256.039079,-175.598895,-157.507273,-167.147503,-121.609129,-108.763859,-253.03076,-355.919391,-393.693872,-329.534107,-164.586623,-103.303812,-55.829615,-68.031799,-77.289677,-65.435289,-44.832328,4.789381,38.252346,78.865516,-6.761044,-69.162701,-109.095212,-79.505725,-1.041417,33.916083,137.54859,185.10944,182.197249,85.838572,19.414821,-83.965293,-90.155702,-57.728885,-64.237842,-151.713466,-210.070876,-212.408659,-210.611713,-186.833949,-69.253803,-7.958831,55.116724,53.129646,-9.177558,-85.65642,-111.523082,-147.167088,-130.459009,22.241556,111.889102,121.377232,-73.478344,-147.936514,-169.818342,-137.742864,-66.7051,-50.207357,-50.630932,-53.978415:-78.0883,-119.839399,-157.204725,-221.803617,-241.181334,-243.033124,-230.258846,-236.169471,-293.221528,-294.584453,-236.309331,-213.435632,-157.701211,-100.931569,-1.252824,20.253941,27.597707,-8.739811,-35.356256,-84.188091,-101.631738,-139.414407,-149.373974,-121.573583,-114.370571,-129.78223,-172.90368,-185.439912,-154.857989,-129.122849,-77.723141,-45.632219,17.930477,99.491268,106.93248,-3.304509,-66.296182,-92.08298,-54.072704,78.702771,106.255769,33.616497,-156.682421,-192.514301,-126.907606,-78.280657,-24.233871,-24.754583,-49.431548,-28.207739,-14.199272,7.551623,45.850191,139.931883,149.876473,85.276258,-31.400236,-85.861204,-180.489269,-211.487352,-130.795782,-19.031734,178.672186,220.478993,205.399312,62.864263,-43.30913,-145.52292,-87.387062,102.332258,150.151552,126.093281,23.688942,-18.711051,-34.237258,-16.055182,11.957396,-4.307811,-75.714804,-103.368455,-142.633274,-207.020657,-257.316273,-305.357069,-264.539761,-164.181114,-167.359447,-207.172272,-204.92074,-200.152877,-135.499077,-67.453519,42.647853,45.854443,47.925024,102.117686,230.069891,199.072285,134.5348,47.273555,44.996335,42.797533,46.860588,112.18051,95.863061,10.213369,-202.141364,-238.503938,-109.0577,-13.903265,131.55473,187.783604,210.278897,135.273921,113.179175,155.301767,202.435567,245.258139,231.699585,192.664492,177.019006,189.860852,249.590949,291.974213,412.923036,460.204265,467.518226,450.648587,426.751394,396.05515,346.899399,221.128376,199.5466,217.337325,231.113194,266.959056,227.665975,174.659774,52.674392,-14.350415,-113.493404,-119.474165,-87.269759,-89.026904,-112.064883,-77.336749,-85.781484,-212.957484,-264.568378,-215.038766,-131.222907,29.595276,67.8509,49.221347,-22.114863,-57.445655,-37.655019,20.442397,155.546382,205.859429,205.400974,138.3232,120.075662,125.137408,145.035362,169.654674,166.168649,162.875485,132.586029,108.236487,103.06459,121.06215,143.877534,152.860918,227.834469,274.490389,261.4559,126.744881,63.865786,15.551545,24.128585,-0.545822,-39.667896,-60.764533,-23.506301,-17.816609,-45.067329,-56.487335,-25.481854,6.08058,103.467172,169.307035,193.934882,27.082245,-55.494504,-94.99708,-42.36318,91.387511,129.824218,164.184164,128.799429,94.163256,59.468112,61.675082,81.062745,114.564826,288.792864,389.181259,404.905123,201.876325,101.835415,-8.829461,-10.693638,47.88461,76.405854,75.036635,0.932397,-50.99059,-154.854212,-177.766627,-103.895396,-15.94892,183.288841,252.372134,242.465796,72.468049,-29.114536,-159.217746,-168.190892,-130.211633,-118.164194,-124.678974,-133.399068,-135.186548,-142.097947,-151.0143,-193.670896,-228.969224,-304.66886,-328.666247,-302.797025,-148.227221,-69.799642,-30.181401,-60.711637,-88.527726,-51.603764,28.778923,-30.668633,-88.701873,-125.734177,-100.629545,-104.025946,-137.827265,-136.579704,-107.784216,-93.378914,-74.517069,-37.289609,92.584026,169.745295,232.057143,222.980548,253.231987,279.787056,244.578507,107.57601,40.610798,0.384317,28.916659,105.271767,118.342503,73.737777,4.562821,-41.036678,-136.50662,-143.786854,-64.43169,-15.748823,47.362768,65.969357,72.159196,54.877989,22.687119,-30.306306,-29.385036,41.196095,83.435378,94.540725,44.069139,1.362105,-91.061307,-108.419252,-117.561929,-109.432051,-6.144167,74.965463,63.894892,-10.965216,-41.017931,1.480032,65.969654,195.654403,250.939298,277.596198,171.221336,130.561953,88.703711,45.680634,-74.731858,-90.57991,-1.155834,46.345501,45.688911,24.422395,-3.853157,-36.090084,-44.826582,-108.159398,-131.377668,-91.453545,-42.039224,-63.025403,-154.151031,-172.838335,-158.178326,-152.0113,-105.287949,-45.114044,-64.674066,-178.906133,-213.462792,-178.814805,-140.487034,-57.467847,-34.573386,-129.748791,-278.151141,-309.576715,-324.339795,-321.084048,-304.653328,-286.284367,-192.064829,-96.156699,-95.958642,-212.328165,-309.455529,-428.344383,-388.368547,-192.976322,-131.42478,-128.597762,-132.374089,-127.392079,-113.689434,-89.429208,0.626048,72.255224,189.091039,98.350423,5.546191,-159.25328,-201.903444,-131.870653,-52.622681,57.56148,82.015872,47.102491,-88.895645,-144.913112,-185.58428,-185.783671,-173.590126,-143.229655,-60.69969,-87.596491,-113.484593,-104.483062,-84.868762,-50.477619,-28.117134,59.283969,101.052615,77.098133,-47.496555,-113.035892,-198.761637,-198.456351,-145.016293,-101.923548,-22.263555,-126.026802,-218.705371,-292.652092,-264.483261,-162.60384,-130.505916,-103.19129,-70.95308:-38.676821,-204.688875,-221.80903,-147.25192,-114.091346,-125.264839,-138.884377,-171.332647,-274.809861,-321.4991,-322.653706,-279.965343,-141.961767,-64.105941,33.686736,44.052494,21.115041,-34.932714,-76.988398,-167.501361,-194.907005,-212.489606,-203.715407,-175.789265,-225.633085,-259.584146,-298.17199,-308.039516,-273.584967,-221.93409,-64.533767,6.547561,35.679937,6.41452,-11.457499,-46.657587,-32.851393,55.821616,92.252204,104.179495,29.123331,-51.076522,-226.739482,-269.247317,-225.585773,-165.889121,-63.783335,-51.963265,-105.23947,-145.863282,-153.064498,-96.092237,-8.846041,145.330336,146.960797,27.387576,-145.41121,-233.027849,-335.394596,-304.813899,-93.488927,25.789453,168.197429,185.386519,162.647015,54.167351,-35.517046,-93.994197,-16.327884,159.078112,196.361634,221.401345,172.25069,119.724141,72.037925,104.121308,164.244456,144.505472,57.726864,5.883226,-125.515696,-248.073074,-313.140376,-374.540223,-319.562906,-158.658803,-136.209635,-186.188328,-238.395889,-248.572736,-208.907957,-162.199083,-88.013056,-76.212327,-20.743688,38.489571,117.24457,52.462475,-18.514461,-114.502953,-104.832105,-35.898827,0.132893,44.573771,-21.127823,-94.511141,-280.702776,-343.480808,-302.197241,-215.060685,6.306301,99.530212,153.255456,52.234401,5.408427,57.314445,129.210951,163.279712,122.609532,82.111939,117.823457,133.10727,142.465542,169.77073,322.762268,407.64013,495.40395,495.152883,432.24951,311.208852,228.750927,98.857028,110.233899,241.849852,289.616995,322.324721,283.233153,210.437533,4.794838,-68.947833,-87.040962,-52.623051,7.234156,-3.625919,-78.075047,-117.235907,-137.642165,-171.788413,-156.202714,-85.280664,-49.858994,22.422806,53.666141,54.665507,68.992584,79.972995,115.694548,143.107727,196.68984,211.585228,199.992511,213.004464,222.337224,152.495282,96.493252,90.942662,156.534416,246.611206,112.18664,29.331392,-7.686344,31.743037,114.142872,145.873295,267.134573,331.375552,292.368655,76.403204,-7.388606,-29.710158,3.555596,53.655765,66.835231,53.72396,-35.352884,-80.93347,-128.489943,-117.425805,-22.849076,32.725613,128.983105,168.988628,152.62337,-24.887766,-117.00077,-126.828185,-37.337483,150.134479,199.803285,251.457022,257.42495,225.501281,113.58058,67.699019,95.705536,175.238276,352.675441,397.271591,368.309221,248.957796,172.159617,38.521598,14.529631,77.216615,138.88427,215.32473,151.475298,80.472973,-50.396995,-68.938825,40.741893,147.200537,352.576681,398.09202,319.039608,135.032612,42.751549,-66.638276,-55.094525,29.696399,58.639209,70.760999,43.66513,13.350493,-65.977934,-82.375464,-40.464155,-12.242307,5.664018,-12.393249,-57.517181,-10.244204,11.996488,11.487732,17.50021,47.175455,62.227139,71.140537,-10.467742,-87.113724,-216.567879,-217.677739,-114.620263,-66.459276,-21.224839,-13.650713,-11.906704,-46.720566,-75.508388,-42.910806,30.197532,157.924627,209.795406,334.778748,319.25222,227.073538,12.829801,-41.229011,-27.997477,3.566471,58.050811,63.17996,29.480503,-12.844328,-50.799042,-141.583032,-159.745304,-116.353936,-54.088057,99.065113,159.785131,139.025555,10.538943,-64.077771,-109.868669,-61.62087,83.134337,112.583786,58.955057,3.856993,-13.859311,-30.239874,-25.576378,-37.100967,-32.317185,53.542763,47.274183,-34.897882,-165.105519,-137.36768,8.320845,52.114025,104.491418,136.70657,117.003156,-25.19993,-76.608706,-76.861791,-55.172508,-73.250821,-105.551564,-122.753749,-109.256192,-117.071823,-156.197515,-172.31144,-179.956159,-199.273279,-264.517402,-276.302862,-267.30755,-280.166958,-296.849342,-299.567918,-276.963605,-198.018055,-139.598824,-79.433542,-132.149929,-154.919324,-211.474267,-231.940921,-169.588218,-115.393657,-66.661296,-80.348983,-152.708826,-233.019003,-281.235787,-371.883184,-380.375622,-279.085228,-192.691357,-107.59892,-159.65654,-181.25035,-236.621812,-281.543586,-307.41247,-255.142091,-121.495273,-99.00085,-93.480681,-83.887934,-104.24244,-127.047125,-97.955631,5.192897,69.148584,172.315912,141.347446,68.013384,-111.313822,-151.494796,-99.609039,-54.333122,34.199505,65.969135,22.860387,-87.131363,-125.380131,-187.237674,-189.775908,-92.129988,-43.933489,-77.814489,-174.867161,-185.70974,-151.630712,-132.973289,-93.314202,-42.232974,120.494935,161.147746,72.441202,-90.787758,-159.025151,-195.537288,-138.397273,62.548853,138.158447,117.482931,-69.167929,-158.341538,-204.134608,-154.545277,-54.066487,-47.555302,-29.143038,15.36087:-92.737981,-154.263055,-136.475473,-89.948437,-109.396028,-182.250488,-201.820372,-223.841936,-269.952186,-264.974914,-198.547985,-183.179176,-147.138771,-76.391905,141.427434,209.736465,139.596947,25.42433,22.886548,-26.141614,-88.187852,-111.094103,-51.587499,45.146184,-33.428521,-96.307664,-182.641677,-212.015643,-236.940487,-229.084554,-158.455374,-81.791037,83.355072,98.457366,59.824821,-20.770458,-45.030866,-49.007756,-36.451937,15.637625,98.694087,133.376413,102.607457,33.138603,-59.593699,-46.654476,18.798595,32.32857,2.938462,-19.303413,-8.101056,2.727053,-15.037035,-45.64413,-45.316739,-65.264065,-151.101663,-205.841656,-304.969264,-342.163643,-305.528568,-211.86868,-21.685107,17.938932,12.614533,-40.457836,-79.85609,-105.196583,-80.9616,-86.087972,-113.24066,-93.75521,-97.06415,-132.133653,-112.363795,-44.491572,24.602076,-29.96255,-191.17789,-222.517666,-194.836693,-179.457479,-195.315587,-255.322089,-274.700289,-262.818891,-247.125394,-248.578428,-271.469966,-255.738427,-182.148267,-151.58872,-74.433586,-2.680212,179.404463,264.214955,349.636959,263.047769,186.368097,82.410245,54.223666,22.276283,43.125788,125.938241,97.383834,31.233926,-86.93328,-94.23157,-45.611229,-23.540911,57.857014,117.120306,164.155765,122.608105,101.059957,114.328219,163.582092,239.819516,209.146281,83.316642,-0.927633,-34.857034,-17.152914,67.986029,297.794885,350.833814,305.455727,285.151604,280.225341,229.527928,212.798451,253.312991,298.02727,337.700551,329.905581,327.529043,286.579059,232.586236,107.565537,50.112288,-26.9191,-37.389731,-6.414703,25.549652,66.372331,46.764504,8.932881,-130.084551,-185.197411,-161.498427,-88.026131,85.664949,137.441843,114.037154,10.318423,-36.802891,1.329536,59.407481,129.808134,169.016137,243.462967,169.956811,123.350883,106.072894,121.177073,155.681553,164.240041,155.786565,135.041937,135.16575,140.76067,151.757349,209.241537,227.170948,210.6466,195.567983,164.06903,132.768105,113.856164,33.992637,-13.939384,-78.436441,-87.467701,-79.085399,-92.921348,-97.377375,-106.086452,-119.741627,-75.016435,5.573873,153.264398,166.911383,79.044775,-64.105545,-120.484343,-161.558323,-130.830083,0.38692,38.792524,7.214991,7.826152,57.896546,144.643486,132.74388,56.792056,61.738841,227.86118,330.46876,386.817245,265.44742,167.263613,-6.551062,-32.821251,4.060695,31.983557,78.673219,67.540195,39.806764,-26.415219,-61.838385,-26.886364,87.633649,328.888253,349.882801,235.028112,123.593843,61.955285,-77.821172,-130.42849,-201.525082,-211.824682,-191.897138,-222.07026,-224.154219,-130.502822,-99.355929,-206.168221,-276.879181,-255.593102,-182.58742,-81.298489,-35.090464,12.647252,78.148296,63.427267,-11.756108,-30.497276,34.618296,91.052272,47.556821,-96.814897,-128.85921,-111.129182,-113.00059,-163.617326,-175.492917,-92.658317,76.29647,134.947969,185.458414,199.207511,218.722332,241.917313,302.973719,193.791363,108.274701,74.647438,81.888796,6.272705,-23.875176,44.845789,115.27987,178.545961,131.025675,109.152785,56.516808,26.569109,41.525299,76.947199,92.099292,67.537223,68.044283,50.976702,40.958182,86.918519,125.601586,168.140194,171.309002,123.181758,60.920398,68.585088,131.192591,155.028275,128.984271,97.722995,90.458638,133.948845,136.059283,38.776995,-20.476478,-16.369206,30.255107,147.690471,215.721408,268.743658,154.978678,90.228477,35.414445,35.733825,39.105008,41.602843,78.602597,104.408389,90.361384,62.792158,57.211043,-0.487677,-52.307988,-64.042679,-8.477766,53.064445,5.898897,-20.48421,-81.261963,-106.052283,-93.635453,-58.823014,-18.473191,-79.776786,-132.560594,-226.042184,-253.318727,-218.003436,-145.435248,-0.283455,7.918731,-150.957339,-337.773911,-370.335652,-352.116483,-315.835207,-190.68502,-128.255457,-75.11118,-84.709736,-87.535477,-130.458126,-193.544753,-305.448456,-304.343763,-237.505406,-197.913273,-115.30962,-100.391291,-111.319597,-85.41556,-48.950546,13.064835,51.679252,167.928264,155.861782,65.089468,-116.5854,-129.478449,-25.192805,23.606825,30.794395,4.897513,-77.466568,-149.77836,-164.167729,-141.255296,-88.072556,50.496631,83.300366,54.851008,-17.633622,-23.517256,59.963492,96.418711,67.00718,26.267666,-3.530823,6.667539,-25.382798,-183.358283,-288.631258,-431.074656,-429.431699,-330.808091,-275.42358,-232.433972,-334.438318,-384.128401,-341.848437,-290.616421,-282.537606,-302.925397,-258.537167,-199.903564:-134.29226,-226.030849,-258.736905,-252.84945,-204.993744,-79.855604,-32.633632,-26.315572,-139.414555,-168.997618,-127.802985,-95.187113,-14.160581,41.590205,131.760113,134.894657,32.713532,-100.490876,-156.19597,-235.968053,-228.331992,-135.152098,-88.777347,-35.414104,-49.364381,-85.368088,-210.362905,-259.039365,-201.855946,-137.258934,-74.947426,-59.486455,-18.903062,-20.941388,-56.975685,-133.925561,-133.474633,-68.096587,-21.991882,68.565128,53.671434,-0.329057,-145.570677,-204.873684,-179.69801,-109.980557,-15.728313,-10.836212,-54.215968,-118.197369,-140.993053,-95.779939,-31.749788,18.87865,-14.306337,-104.889962,-174.301895,-214.790972,-328.417765,-360.563877,-255.253334,-141.117001,39.990827,78.360414,85.336584,63.629662,45.669757,0.854193,-1.496537,84.022091,159.343882,217.878223,74.688913,13.895045,32.531065,85.821919,182.984041,185.968946,74.301906,6.014068,-73.817316,-153.380214,-215.058273,-271.185049,-225.014573,-98.133079,-80.372279,-125.41735,-219.369982,-268.748042,-285.174841,-225.493588,-17.978003,76.297865,199.912461,249.916325,274.702213,153.042633,85.742388,17.693168,17.960116,43.585062,66.029936,131.216559,124.105766,64.528766,-105.082007,-158.450548,-127.433903,-63.949071,105.207486,178.187544,172.35536,76.061077,66.743063,100.444272,122.80039,162.104234,176.249792,152.131304,46.827421,-4.300369,-41.629072,8.685543,241.003778,339.121405,406.733638,408.046975,362.041792,253.950132,188.114278,117.313856,145.756523,235.552281,248.284972,241.235592,221.990244,186.149734,46.531133,-3.616474,31.253446,66.711461,78.696309,69.289393,37.830614,-33.566838,-86.806385,-149.521422,-111.042956,21.642535,43.954572,-7.37001,-11.307507,21.975258,50.677929,53.639967,136.777259,192.822203,249.583651,261.994146,264.550115,227.434239,190.840664,102.180597,88.697286,166.663384,223.365566,241.447674,118.20947,63.663349,42.052284,51.401127,87.976351,146.317232,338.731197,399.764606,301.578449,87.183654,33.01099,11.840825,12.252491,3.78032,-1.927596,-15.646914,-61.952009,-92.837451,-145.161399,-144.123471,-61.005873,3.20013,149.059112,207.772678,189.123518,-3.573076,-90.031084,-104.403011,-56.081015,27.105261,55.789228,87.986333,55.719191,39.929073,6.213994,-8.11473,43.842801,106.255858,237.550121,276.798137,252.581166,177.135904,136.993634,33.618455,4.838177,36.645877,58.489593,65.745869,64.897825,36.71752,-83.902946,-124.519686,-75.111866,23.794869,306.266769,394.875629,340.045702,175.239443,90.639749,-60.169231,-80.333886,11.298646,70.340204,77.315061,-7.972867,-22.627733,-18.5849,-24.334627,-56.706454,-85.684739,-130.310364,-117.898127,-45.963399,33.364564,75.179572,133.525309,135.628598,117.264476,137.56275,212.276912,135.143006,41.526949,-113.016984,-139.814988,-87.967757,-32.55547,42.774926,38.042137,-19.755194,3.044453,54.890345,184.82811,246.402227,317.121497,320.004926,270.124896,202.767622,165.110251,43.471,-18.119827,-62.916557,-42.991392,59.207265,114.571798,126.718946,2.231538,-73.280681,-173.794091,-186.205857,-129.637278,-58.243616,96.589528,165.204607,170.773954,109.984537,53.447337,-19.120808,-8.566452,104.804426,160.16375,134.452474,-2.212681,-50.423769,-42.658695,0.723124,54.22669,59.054216,93.46138,63.515518,4.448712,-84.368868,-87.841486,-59.340072,-33.835482,93.931546,172.935506,222.756314,141.830406,85.501575,-8.604198,-19.199312,5.67328,4.294758,-30.177512,-63.703362,-79.314691,-133.432939,-157.793703,-158.197939,-160.814146,-187.391412,-194.152077,-203.150663,-203.60727,-210.812146,-245.922923,-244.134101,-179.832312,-149.07297,-145.284415,-173.850252,-201.115843,-282.762351,-283.81597,-146.869945,-53.291286,71.814006,72.29395,-79.599943,-305.090587,-376.611581,-392.80004,-354.723781,-231.460115,-164.068602,-100.801708,-152.091342,-190.465743,-252.519829,-263.53354,-247.473122,-235.711616,-212.323944,-197.085404,-149.953016,-108.454376,-123.972797,-188.67482,-183.329973,-32.535325,95.409856,250.906422,65.884929,-72.638498,-209.792439,-195.276645,-82.045857,-31.451963,11.308359,9.131022,-6.679504,-47.309247,-111.47897,-212.603968,-181.925933,-27.198703,23.022252,-11.949,-116.387049,-138.775429,-124.676772,-105.449765,-49.44905,-8.845958,64.132538,79.495978,68.139689,-46.267599,-146.855774,-297.149872,-306.63656,-201.657055,-111.666898,-16.179115,-137.54188,-200.310609,-212.176249,-187.798688,-165.759477,-175.187004,-140.370207,-78.538514:-69.622959,-75.080857,-68.774553,-62.492446,-57.725312,-94.709325,-137.811296,-171.450427,-141.278626,-129.925546,-75.159465,-47.56935,-49.984923,-43.35594,72.158683,158.678794,235.382836,128.647663,76.839306,16.076635,-29.193421,-102.526857,-83.703858,-10.423694,-52.321631,-113.692144,-274.789543,-335.426494,-278.706052,-177.823169,-44.221085,-28.933374,33.303211,97.291122,90.910624,46.348222,34.039966,33.989492,33.094902,64.862029,131.596824,130.994393,107.605358,131.272386,233.968336,266.316888,252.057216,244.828515,254.727771,204.010862,164.193958,111.61734,108.14329,109.492754,79.533136,-28.937377,-143.783331,-211.222798,-335.593391,-378.896895,-381.695748,-335.65997,-218.646434,-164.857225,-73.384645,11.782911,53.541372,27.770646,-46.905497,-137.22396,-104.997544,3.570324,8.64104,1.751823,95.105825,175.646456,224.119383,181.945725,114.063082,115.898592,153.240546,166.164675,133.488574,31.635457,7.007324,-44.254781,-104.593603,-210.186093,-251.30925,-259.110866,-218.211601,-172.012979,-72.868375,-39.453019,-0.178064,36.993877,131.53299,89.791597,12.163864,-123.682185,-132.17974,-22.128928,57.928263,169.322991,150.890382,95.967539,-54.035396,-110.660508,-107.028247,-55.6853,62.062408,91.846664,54.061309,12.049253,39.881434,128.61896,153.133689,144.065772,106.895233,6.948456,-18.653344,-4.939014,11.578711,29.857023,156.611926,226.489549,259.329207,251.371816,276.654522,310.781572,314.861643,286.817724,280.054204,289.792267,278.570942,282.11704,373.589766,384.695211,257.463995,177.157915,116.485299,119.431149,168.74362,231.64859,311.991987,190.253365,113.886042,7.577523,-41.571961,-100.826628,-65.416989,123.093122,193.538962,159.697364,65.490032,45.773961,133.596275,199.517875,256.561014,269.89817,315.078132,283.609325,217.245678,72.045245,41.547932,70.763524,93.59878,112.711372,93.303917,73.458594,74.533518,109.320267,218.387979,264.954849,284.805699,259.370434,179.177607,129.738244,104.445584,-16.297056,-87.926778,-180.949846,-199.970399,-167.496771,-90.14168,-64.671737,-96.529311,-138.026969,-94.560517,-5.638083,114.890763,118.077414,59.214839,-43.141748,-90.31542,-153.012857,-159.586952,-176.418189,-215.638777,-235.688386,-82.491581,1.647178,77.097488,75.795576,51.068398,29.2964,19.415205,62.755885,171.155793,136.659551,62.988115,-79.906982,-98.404297,-67.764792,-81.609139,-170.06267,-181.829483,-148.346535,-91.135067,-92.610672,-92.859365,-46.405028,124.473754,189.17294,181.968249,89.218276,31.582923,-165.219492,-284.010836,-386.46825,-344.364925,-230.054956,-184.614845,-149.158882,-53.398701,-46.971008,-179.652067,-268.36278,-329.242282,-273.116965,-56.389953,144.765862,190.247913,132.752851,58.765021,-64.708922,-81.684269,-65.823282,-69.187844,-63.048129,-27.637681,-0.886553,67.631214,70.196098,-22.045528,-63.523466,-23.744444,178.885265,267.970767,280.481263,256.422308,276.621166,296.540672,279.479393,166.342057,131.532562,162.785785,151.34133,15.959657,-30.586872,7.05397,47.190721,84.53194,99.991523,103.072875,59.271064,19.158271,-29.950665,-37.017104,-33.051525,37.37873,83.128564,85.3608,41.02666,-6.525185,20.639247,95.225317,106.735569,111.410411,159.808514,177.103118,159.898517,156.376,179.055575,187.644892,191.111393,164.064294,146.57142,68.959548,-7.25326,-117.904247,-109.607985,12.016007,96.214147,183.224119,142.675359,118.852206,49.199011,4.369834,-46.225604,-47.559735,10.793907,169.150497,243.215449,273.961012,234.565513,117.379519,75.4664,89.278744,131.299456,201.760301,200.729575,158.788644,21.419084,-7.397171,76.478302,128.761695,111.882175,-20.960465,-65.645277,-46.986802,-5.091527,37.224086,5.635939,-92.746878,-114.25252,-149.543664,-235.772476,-270.000016,-248.398427,-194.738379,-70.777201,-26.936192,-6.451745,-13.962254,9.550488,23.757236,-31.189563,-166.514991,-192.574266,-172.242436,-144.523633,-94.802994,-93.931867,-101.923386,-78.320679,-30.502618,71.317176,94.655121,86.185471,36.142455,0.682753,-94.278626,-124.231829,-84.737831,-55.568312,-60.201424,-67.395477,-31.061528,10.776995,3.229957,18.354593,70.123025,121.80679,94.319141,98.53464,131.385494,93.662397,34.202573,44.211694,54.027663,15.490242,-112.830641,-148.265748,-126.33894,-167.575426,-271.594884,-517.815179,-557.740609,-431.918396,-347.381691,-308.300119,-429.280782,-471.159092,-452.224254,-426.628197,-377.396826,-350.794298,-330.752012,-327.430814:-11.884436,46.325921,72.903831,25.694997,-45.401686,-204.944565,-276.878327,-367.575122,-316.871887,-244.78253,-133.368213,-131.521375,-132.050579,-97.664858,3.927896,58.109374,105.684094,40.086516,4.696614,-26.462315,-28.612195,-55.07113,-92.475079,-180.849908,-203.715458,-186.051843,-164.841332,-159.677049,-118.601773,-108.040596,-103.431384,-68.951344,27.237942,67.456471,86.182826,108.763241,82.83135,-13.586151,-38.264948,-15.057218,58.805149,111.097528,150.020989,115.256987,58.546353,75.960214,166.341072,202.614772,143.250585,-42.938486,-90.55799,-49.769217,-8.793367,28.543886,35.83158,24.616003,-96.830699,-158.247843,-207.002913,-218.83607,-213.205073,-169.661524,-27.994029,22.329643,11.050025,-31.764533,-37.565529,-89.669687,-135.459295,-164.36659,-128.560934,-46.137965,-60.151624,-71.860875,-25.683757,0.419654,-31.313748,-78.000052,-151.202213,-139.588812,-8.355593,112.413379,104.322029,-19.81034,-73.32924,-107.326575,-109.088097,-117.51182,-155.675271,-185.888462,-190.541032,-150.72751,-52.769691,-16.510366,96.027332,171.444542,160.05728,-17.850884,-73.544762,-104.89695,-97.204758,-59.738129,-30.012417,70.579881,153.144939,126.280611,-27.86426,-76.330521,-42.730297,15.340612,159.213884,221.553971,246.175439,140.847532,97.688819,98.878002,115.530076,113.327197,103.458335,107.612802,130.239907,145.308754,192.222942,223.49664,308.323149,343.317938,374.653895,403.065859,464.238389,426.155043,410.401179,422.63857,414.695455,323.614879,274.175051,307.167088,391.592479,344.171051,118.112267,29.171257,-13.673988,-1.659032,43.348261,88.992875,186.710333,182.275267,114.866737,-75.42537,-127.456368,-114.08715,-80.263902,44.043479,138.597876,115.081307,-15.849218,-66.093206,-64.634972,-31.350383,52.84602,112.024615,222.338437,193.011327,124.198528,-4.007503,-17.586813,22.685194,39.020914,62.405919,74.967186,54.534915,-3.10394,16.21488,164.638284,218.124876,220.396586,221.235053,240.409524,194.915713,140.879085,1.638164,-41.495911,-43.679707,-37.796869,-56.787163,-84.796465,-81.558161,-53.95131,-49.645439,-7.349867,54.34287,170.689193,195.946334,169.276676,63.162092,-0.625303,-127.177259,-151.704986,-86.318085,-37.909317,11.753188,62.859061,100.048003,108.369191,64.843549,-43.103245,-47.313293,106.917982,199.622631,203.085743,28.258551,-67.042012,-203.861589,-213.693911,-165.954844,-155.533609,-139.386656,-123.004237,-136.141693,-208.879785,-249.290982,-191.208454,-85.324599,106.075332,149.939163,146.993899,50.578089,-42.758043,-283.511535,-363.843266,-342.944631,-293.919064,-308.247427,-387.755999,-381.458861,-324.904696,-321.649952,-402.49251,-443.947523,-376.470946,-258.673014,-42.936976,18.955858,42.432555,75.811396,63.504985,9.487184,-11.188832,-8.231529,-40.833879,-93.33437,-140.637508,-119.690268,-139.865154,-188.965157,-206.702361,-174.084925,-86.606815,55.503129,115.581336,177.748454,199.743035,232.50279,239.30041,223.393316,179.436409,163.666112,106.496286,39.205317,-111.248335,-125.785417,3.850405,74.293768,98.403207,94.59984,87.10024,0.893849,-40.687646,-59.866737,-40.640307,50.028027,100.653265,87.109547,8.571738,-15.755496,70.195193,140.519447,145.919045,89.892135,18.8209,37.195546,46.232759,50.056134,67.974659,117.549571,119.160244,78.597243,57.830892,60.443174,17.259909,-22.545709,-18.499968,29.745096,118.79778,135.763803,139.29829,156.046346,156.1187,110.999244,86.410368,68.153198,73.236182,137.761646,226.19341,230.883782,201.411772,192.149032,117.356346,43.851752,-50.799355,-24.576693,142.544538,261.932944,247.040584,127.293724,71.074572,-3.278013,-12.021312,2.836982,-50.049194,-79.199894,-107.505623,-110.221379,-16.093203,59.890053,84.746785,30.621735,-76.483114,-169.786162,-232.481498,-294.213429,-253.589309,-141.697102,-130.090415,-164.441115,-174.022156,-159.746586,-155.871478,-198.172205,-307.68685,-326.470987,-285.301339,-246.202291,-203.805428,-276.912306,-314.630314,-270.945181,-198.237791,-71.754901,-21.81241,136.336247,230.652242,151.195597,-164.179356,-260.70806,-225.013086,-172.360898,-139.983617,-163.652631,-239.282902,-243.386579,-234.014924,-224.843439,-189.588022,-89.719316,-65.195563,-50.897869,-48.864632,-37.281874,21.633198,55.445056,78.787285,35.476677,-107.8935,-139.929392,-80.595254,-57.560023,-132.279035,-369.134182,-431.13963,-361.221706,-303.558851,-254.122818,-228.550345,-227.434505,-302.522432,-356.204818,-359.180699,-309.905219,-204.691154,-158.817401:-153.045617,-132.907081,-165.048682,-181.689326,-143.956338,-57.102714,-37.857077,-61.726375,-99.233886,-90.984741,-49.270085,-45.217624,-55.979463,-39.356374,92.340049,170.368337,156.722383,2.094484,-33.699351,-54.768692,-82.286687,-129.506799,-115.06173,-56.037992,-105.162876,-168.107708,-260.90483,-276.273562,-267.44089,-237.694484,-142.408038,-106.204548,-75.55841,-46.723527,-48.873169,-96.748209,-104.592319,-65.797474,-29.715493,44.218093,61.677862,93.983624,145.236499,93.563225,-33.696586,-40.112077,6.905344,45.741826,152.034708,185.102231,158.038714,120.201838,136.202199,138.506707,79.264353,-118.303508,-293.140068,-347.08134,-401.615302,-397.44891,-255.619276,-146.657828,-7.520541,16.349809,31.553307,71.816199,100.591589,118.624164,98.06917,22.198426,2.268538,16.74662,4.404135,-5.232099,36.725656,110.138587,244.082103,223.84323,68.533938,16.820059,4.364722,-51.97857,-104.85613,-112.33811,-63.175829,-25.08931,-58.849648,-151.775238,-253.074241,-277.527607,-212.700365,-153.523586,-69.888155,-43.380679,29.009643,96.449822,221.476167,157.413158,76.900395,-39.329746,-45.830766,18.191312,66.487184,168.497961,198.941487,166.247412,14.89332,-74.991554,-113.181873,-32.173946,175.392195,223.584424,162.66695,23.854885,-10.624662,34.034824,96.637801,169.488164,134.813551,-1.518005,-79.302212,-104.602295,-129.553253,-77.665143,153.78136,250.421934,328.958918,337.153435,305.123567,224.59315,171.50192,131.222695,187.318727,308.608235,291.869766,187.453972,218.659614,243.774347,127.897185,30.444317,-8.368371,48.133726,164.091539,191.853647,153.265277,80.62287,69.950103,32.21145,-5.020916,-86.929606,-105.244776,-29.355369,70.026067,89.128963,91.47829,100.420578,189.382476,224.083229,189.474739,187.662117,268.013476,251.100432,199.057636,126.805924,133.905422,165.393196,150.230451,80.944926,48.423045,60.799648,104.380307,127.018762,220.336983,288.40074,386.53066,395.526974,322.174023,171.90279,93.555242,-17.602182,-37.305499,-53.500618,-51.919199,-14.916673,-51.050934,-99.251699,-125.930596,-90.512511,-18.421171,-9.21925,46.059976,118.453028,175.831097,-1.497609,-65.415871,-22.684435,13.370975,5.456235,3.40077,60.392639,110.137519,131.861044,151.236038,129.265075,82.245016,91.059021,216.055764,321.750133,422.291172,254.807999,149.033724,51.457739,54.190263,63.72341,56.425221,22.745584,-23.78554,-20.141161,24.744241,33.383352,43.359819,97.963757,330.791974,411.790362,307.972636,93.028398,24.462276,-90.807082,-135.973692,-173.014416,-159.288985,-66.714731,-42.346464,-58.532098,-37.180725,-18.970727,-12.717501,-20.311467,-109.69844,-165.569634,-132.018492,51.672113,107.645255,57.815993,10.81208,15.698412,49.718266,98.648413,74.439291,29.971063,-69.66399,-70.151343,49.287159,83.69944,29.729793,14.286568,83.326281,149.495642,149.838042,154.679664,194.015801,263.828299,253.964062,198.07893,139.085248,111.795084,71.854732,45.87207,-37.856179,-81.291926,-63.345934,8.325124,129.92135,128.565653,93.566532,-38.658655,-97.854708,-117.586927,-99.651618,-43.979906,37.199713,67.517243,91.242537,88.416223,74.36961,71.393621,106.512435,150.04164,208.171059,173.267375,162.148171,182.856762,186.984368,141.409022,119.341687,131.254905,119.668698,73.590128,-67.192934,-117.314487,-108.810082,-59.099423,43.917212,62.707177,53.032065,54.443479,46.868221,-34.710651,-72.311444,-46.286299,-25.781666,-23.63682,45.22087,71.521898,25.0998,-12.235755,-54.081179,-64.581367,-72.713922,-73.0255,-64.761755,-40.177245,-44.806048,-88.201871,-90.146575,-57.866226,-43.298848,6.801511,1.074882,-44.511493,-126.295672,-135.863366,-62.097854,-0.245871,51.045016,15.90892,-154.552783,-296.909644,-308.162321,-293.002118,-289.815366,-239.930352,-175.447658,-13.815189,29.221638,10.160481,-20.118317,-53.423435,-154.32932,-186.208335,-173.556956,-147.405537,-124.029822,-109.996205,-107.066954,-96.583005,-64.298462,7.969842,25.000688,78.569774,53.354601,-39.601247,-225.544355,-227.060913,-31.68522,66.720196,73.280573,12.323089,-57.958571,6.453641,40.402018,21.505623,0.748509,18.12213,20.186893,-42.38692,-59.303656,-16.787396,94.858417,117.139019,62.649357,3.506728,-90.325436,-88.960655,-19.473808,-73.788,-193.220921,-416.488341,-409.030168,-205.633292,-119.344659,-124.862298,-279.725246,-326.352702,-283.400632,-235.618428,-188.506459,-184.3146,-133.544801,-84.516176:backward
7.916607,85.358464,140.375673,246.144413,280.88445,264.872314,214.024814,92.347987,7.917352,-15.929081,-22.221105,-19.56413,-63.570887,-92.538842,-74.798848,-39.373868,13.66174,83.129758,141.17347,220.745812,216.758115,183.112445,176.705614,121.496549,45.156837,40.879114,41.115384,12.880536,-77.752029,-117.869345,-169.265945,-181.70707,-155.424525,-8.425955,70.036143,137.88638,144.70656,104.203738,27.309095,-172.1531,-282.611014,-285.695382,-168.606704,-84.39837,-18.740672,-44.54172,-144.263076,-221.176248,-381.039181,-331.272607,-220.782453,-35.133528,-22.917616,-88.772444,-108.176904,-165.386135,-273.195688,-291.033133,-209.84482,-136.660869,-67.601985,-95.552398,-181.872318,-213.427181,-238.322667,-138.088586,-40.170419,155.259815,195.364456,127.858742,76.914775,4.718604,-49.575477,-45.982035,27.976986,69.38994,62.166629,14.050704,-55.801632,-75.122322,-113.371567,-81.750929,-41.898316,81.249215,138.717082,155.656846,121.687547,51.844346,85.034764,130.364317,185.232556,173.147246,46.700156,-37.518239,-130.750474,-149.710329,-218.117167,-247.457913,-203.162277,-44.843639,9.229804,44.88447,57.758937,53.87776,23.935702,35.575967,105.696706,157.899702,278.989946,307.283189,219.183128,111.096985,-94.27826,-61.218453,36.273359,167.407317,150.597804,73.201011,59.299921,2.679316,-97.524461,-115.708588,-70.452615,-38.251075,-56.365987,-94.680227,-169.1342,-212.499884,-304.753965,-388.673805,-385.421687,-184.351627,-65.011218,-16.339858,-55.337772,-116.363827,-89.950354,-43.651211,107.0751,214.927839,349.569564,323.447031,225.233951,215.853722,247.077369,338.942777,413.231877,481.051231,440.186314,370.847744,375.681535,283.516572,123.669737,116.286099,195.001814,239.169262,278.421387,254.128223,110.122826,0.019785,-181.066734,-209.371503,-192.72776,-119.368442,-59.795579,35.737324,35.13526,-69.435108,-104.78623,-47.980414,96.350584,142.781233,156.739155,117.603554,1.179057,-27.901368,15.17381,53.288097,40.386658,37.636912,58.659454,70.949113,49.131711,-32.546859,-115.285643,-128.035109,-66.642054,0.83835,119.031642,130.327301,55.595553,-2.443408,-73.856573,-26.476935,35.277383,196.063389,265.774559,311.327623,277.617528,143.942893,112.922511,151.313749,165.572155,133.624418,85.047184,74.88398,9.889719,-86.311843,-314.413975,-296.884797,-201.546839,-28.548898,7.450954,21.800872,27.449419,8.035468,-61.999723,-95.288746,-101.355687,-58.895922,11.3384,-12.907575,-136.32912,-187.927183,-214.435404,-175.224794,-155.49599,-129.986926,-120.825546,-111.434236,-121.820203,-190.31426,-216.900934,-190.516731,-122.067049,-81.31941,-11.03231,-2.435131,-25.662569,-56.806161,-149.334696,-202.34205,-185.218712,-54.319072,6.188344,-4.238495,-44.342553,-110.342647,-132.114012,-108.118038,-6.294117,41.386508,32.641397,-15.793692,-46.596939,-14.795161,24.61243,19.448132,40.611992,117.093116,113.086004,-7.81541,-66.910616,-159.02852,-261.878642,-271.123156,-158.668317,-78.592195,29.236923,62.074255,100.297447,115.841446,211.732567,287.670191,268.025105,240.057965,268.010829,325.509163,330.201528,283.408779,186.877029,150.698669,180.170298,250.709844,371.408295,365.661302,232.019532,157.294536,116.520096,199.057246,252.613868,396.12906,473.618175,532.153798,490.275545,288.933653,76.202118,25.849558,91.269624,174.910596,263.714934,243.785896,157.549837,110.882563,41.996463,107.112372,183.031596,267.382909,243.786258,162.540231,141.48909,107.235342,104.897274,122.612872,133.373928,126.028476,83.694798,29.8108,-114.773942,-167.520355,-181.508362,-129.960041,-106.836222,-31.000623,7.620657,-22.934082,-88.65544,-215.112615,-211.753377,-169.749732,-96.433153,-77.469249,-81.835683,-85.511908,-33.432022,7.932762,34.6506,-79.742616,-152.212083,-164.153561,-111.490146,-40.597646,-36.759967,-21.774515,13.855374,12.787249,26.081136,57.121017,72.923527,57.72242,31.54361,-17.143522,-177.582952,-154.4578,-67.289045,72.462093,94.008165,104.318121,119.398861,99.498746,-38.879184,-80.92091,4.634722,94.748644,178.692806,138.587584,-30.068387,-111.73124,-183.24463,-146.68472,-109.311073,18.400721,76.694879,97.055132,76.00706,-3.676711,-44.716209,-6.884866,96.602607,114.261748,58.98938,21.079881,21.00769,23.376983,-83.540281,-188.471663,-172.853619,-44.813306,2.0766,-25.098216,-67.963033,-137.72147,-202.259703,-217.800876,-176.68082,-129.934593,-52.067927,-49.954465,-107.696626,-128.858364:-124.645331,-51.287466,5.172026,120.259137,165.265217,130.571428,66.259065,-6.048299,25.138077,58.81432,155.430758,194.273899,167.305884,121.713737,97.223944,123.682984,179.833004,164.457883,133.55082,100.417242,101.538802,101.467097,101.228732,95.787475,71.204329,58.670389,63.268894,90.245488,139.452093,116.805562,-43.759427,-130.452339,-146.573985,59.547925,153.815262,151.843061,82.106487,-5.298318,-2.246889,-4.498522,-71.856584,-90.374217,-44.511395,0.878709,60.029782,55.210049,-34.489934,-111.035105,-231.025782,-170.688888,-91.342205,24.360895,33.405133,-30.390721,-87.955559,-218.867205,-257.805931,-223.12604,-171.182266,-172.808722,-186.109755,-206.479954,-280.932587,-317.744267,-361.006511,-277.429158,-171.540654,40.60883,80.600843,1.662176,-67.095144,-130.064268,-103.534504,-89.576599,-12.637454,58.625825,124.203797,88.982772,-11.12882,-44.814637,-86.728762,-71.651903,-19.193011,135.455773,172.299213,116.546763,75.251062,37.548774,102.608947,171.890812,269.230239,263.157905,148.126113,58.381676,-112.746253,-172.177494,-233.555086,-205.507898,-158.717241,-51.564077,-24.329405,-19.224527,-11.980399,-4.943608,-14.080047,3.390997,89.188755,124.137409,124.155201,107.685062,45.044821,-21.29424,-151.181489,-72.190855,20.798862,94.211268,58.7849,24.672423,46.499876,-45.864858,-257.90861,-288.510516,-206.203261,-155.555324,-176.369254,-254.841892,-388.380864,-404.660333,-418.251601,-428.453675,-379.909586,-211.320015,-160.206147,-168.005121,-191.872765,-193.371711,-46.61613,47.545799,177.004739,229.395981,309.924844,319.60584,266.700805,221.161869,234.283626,371.835538,408.416095,410.543899,400.672372,369.192391,327.846642,165.866824,88.691106,117.811777,193.945625,197.947113,117.957077,64.737619,-41.008477,-101.210937,-166.970514,-149.016195,-129.835117,-73.924774,-49.057898,-46.697959,-77.682404,-141.088962,-114.567518,-78.838349,25.03888,94.642526,194.703926,200.935588,121.717687,47.003445,-56.772573,2.840599,50.40677,69.814996,53.913804,40.0669,23.760889,-79.616723,-187.95773,-196.170863,-62.249318,43.956214,156.119704,150.150669,92.540379,63.856834,71.952669,203.790545,273.177848,340.359837,350.716542,351.855143,335.192724,257.575345,208.022114,228.396837,304.394244,322.951421,273.678559,214.471369,51.596142,-33.142792,-111.723159,-60.490035,-15.22696,73.587166,90.562418,60.958117,45.87874,39.807878,23.144071,26.761019,103.125483,151.703022,142.247188,83.450658,-36.330631,-87.0839,-200.937456,-294.156858,-286.666302,-194.485974,-164.119875,-126.229656,-111.462372,-166.698952,-185.243359,-114.955223,117.956254,223.734488,271.037379,208.869415,16.684306,-77.617142,-150.940759,-2.268949,92.549928,165.321499,137.103825,56.209124,40.735429,26.252994,20.936727,45.115742,78.784639,70.168666,65.950276,74.639444,66.469931,56.471709,64.264947,54.157363,38.989983,48.064634,41.841255,-72.758376,-145.340012,-230.435162,-253.852061,-241.519597,-107.620052,-8.332374,66.143494,35.759729,12.334149,54.730796,183.521665,210.712776,193.440522,222.845895,263.760244,294.967081,268.543954,155.975401,64.728314,73.916939,198.26041,275.683161,382.533212,394.702864,315.168535,250.807028,201.803144,276.208571,324.226679,404.876318,427.671889,407.650572,361.218972,227.227975,99.289612,57.032401,81.461606,145.549006,258.800371,255.028659,120.246863,54.995652,73.281791,167.510064,177.477224,170.010449,170.243743,143.391934,114.108791,42.900032,19.628704,42.897271,144.567111,197.371353,177.182242,98.98615,-35.911967,-54.40706,-51.573155,-53.331719,-18.516731,143.770788,202.506197,129.760752,14.258606,-193.507506,-144.361346,-70.043842,-25.389013,-51.798708,-141.844343,-186.052471,-207.508693,-196.388683,-206.693007,-223.216996,-208.474266,-191.322396,-224.329295,-268.556366,-226.373779,-133.904166,-154.596631,-163.730205,-103.674641,-64.822527,-42.559885,-23.682538,34.910216,21.02064,-94.157044,-140.908625,-92.93113,24.138047,24.598594,-45.448404,-60.978374,-61.412456,-115.841243,-123.424845,18.937443,110.78015,100.644176,12.934327,-138.444786,-175.939533,-187.3616,-111.144456,-24.054089,183.895782,227.58411,175.700851,141.912989,110.932499,110.437819,131.3665,179.103019,176.871197,144.618907,142.081245,64.169228,-49.948814,-224.409785,-131.269103,-54.896268,11.38125,7.615797,-14.493538,-28.703398,-73.617411,-106.910631,-102.948627,-74.370246,-58.310365,-38.137608,-42.633743,-38.814079,-16.913112:-132.280482,-72.465521,-1.396607,134.292524,153.012835,101.138355,75.710688,71.540788,88.334563,106.761082,195.243082,230.687471,164.27613,97.309452,79.417774,126.585181,185.001007,121.17251,101.450881,144.410253,149.823362,71.112108,26.921157,3.025283,49.841381,93.02924,195.619606,216.277155,164.624021,134.109637,97.45742,59.862227,-17.867363,86.974615,194.350845,307.170683,278.86091,153.192205,108.893742,71.197247,26.397724,33.584311,156.88293,207.618314,143.85296,65.529934,-31.159281,-54.26645,-125.872377,-139.92664,-96.388344,10.195846,42.729355,62.520084,42.126302,-92.891382,-187.698986,-161.835896,-58.93422,-35.03905,-99.82717,-164.93144,-261.588243,-284.479187,-257.939506,-172.462213,-134.379593,-52.854919,-19.529505,0.80419,-17.199924,-112.04093,-136.50276,-87.762873,13.517347,22.322219,-10.143086,-27.264169,-91.097298,-125.881423,-128.302561,-84.206796,-50.5493,72.480387,122.272312,82.291488,9.361313,-67.669418,-24.979473,-26.39,-21.896595,21.71168,65.440163,18.20066,-160.661834,-235.184327,-234.957279,-103.788023,-49.426292,3.037412,-6.162999,-57.859219,-65.577532,-55.311462,-51.738755,-44.103228,-36.016574,-37.084253,-8.120658,14.972541,-29.976505,-114.8159,-242.455376,-184.605101,-118.069536,-13.021949,-14.279882,-99.068469,-138.035654,-199.67878,-261.923967,-276.637045,-296.135468,-312.910084,-348.833506,-381.907605,-526.305555,-612.624046,-670.187836,-541.390004,-449.626713,-289.430866,-241.650884,-180.3652,-149.661698,-91.369877,-33.280894,-3.832383,89.008577,159.215031,239.190221,224.925738,148.809618,110.978001,128.675215,281.668213,363.254431,422.470052,362.991179,180.382639,123.072785,22.105819,-55.269399,-22.818242,155.371163,208.089878,85.208719,-26.302944,-147.120128,-161.914738,-160.150133,-148.998095,-128.292702,-29.42752,13.320474,-14.358674,-70.190753,-151.305792,-123.659581,-64.34575,129.098745,213.431122,247.841739,232.110899,208.274832,188.023793,154.384559,165.794838,186.246788,225.702201,225.029613,179.40373,139.470373,87.032785,115.62747,120.123084,108.729074,130.818336,197.393919,194.592802,107.785016,64.987827,56.201104,165.978058,254.797176,396.604323,425.053916,435.404143,423.023408,335.365987,248.252925,256.113042,365.152125,407.582551,354.636577,274.079449,94.169215,27.547777,-19.185654,-12.785885,7.910278,82.931845,94.91049,36.591675,2.267912,-54.619778,-80.702578,-48.120605,85.076342,121.541544,40.7454,-26.184671,-105.787762,-142.095927,-217.606782,-232.898345,-213.929562,-169.751341,-168.864086,-162.538967,-126.70721,-37.321042,10.862903,40.46493,165.80021,240.016003,301.428893,274.61863,100.275053,-17.988292,-104.557746,65.324909,133.900513,108.257002,67.254022,56.973068,68.735662,36.550079,30.884491,62.467837,95.564969,93.106629,90.125854,80.207678,28.99152,5.792492,5.1929,10.179793,-7.327956,-27.398573,-26.63203,-75.40956,-131.528168,-225.026699,-196.803454,-137.441285,23.248133,84.450213,91.242773,71.369878,81.439279,113.149294,235.29597,342.226552,353.566865,345.823451,356.70373,362.14668,315.778783,160.615203,74.292631,75.546195,156.027962,217.669792,287.997965,298.257211,289.684881,251.436861,165.818009,213.357196,285.49369,407.726909,418.441104,351.919479,283.495185,119.148629,31.388294,30.974345,162.515424,263.756863,328.727966,285.071844,184.331268,157.431355,176.988676,231.355487,249.897265,284.031153,288.135318,251.351563,201.909309,67.277398,29.858166,64.300622,172.820491,227.669078,316.105411,323.435231,196.311526,104.115996,66.727404,178.132826,222.29468,278.185983,276.824667,167.679035,75.568394,-67.862807,-54.021207,-37.08184,-55.017378,-65.270453,-54.726045,-49.573233,-107.531595,-167.233212,-224.404337,-190.81193,-190.660358,-199.893024,-180.4574,-131.143302,-138.503967,-178.833428,-87.574168,-35.59154,-0.170444,27.484278,79.087503,62.870526,-20.895023,-60.687625,-123.246106,-131.026909,-61.380534,137.851646,157.957334,39.650167,0.788434,61.25708,120.062467,112.504117,91.998337,88.918765,54.432233,14.770553,-126.082883,-204.743654,-197.914232,-34.235638,27.068618,136.154015,184.469341,229.958895,228.163706,148.567889,66.176206,80.929023,165.430346,205.555684,248.778261,236.239885,81.356656,-53.061803,-221.401231,-114.503004,-17.212441,99.842714,93.525727,51.978938,51.495493,40.817616,-6.49523,-38.956871,-85.160077,-68.508805,11.620653,22.959318,-64.284332,-126.54698:-2.844672,97.022836,175.945145,323.999744,352.465809,267.111045,181.293525,19.330656,-26.86081,6.004438,96.952522,114.441643,54.333161,20.484018,52.617978,83.657097,89.186154,138.152545,204.979268,306.852955,286.040224,168.905325,142.259209,106.793648,14.4425,8.949173,82.292699,98.45959,43.248315,15.24737,11.837992,-4.543276,-74.826587,43.405059,182.384222,366.684414,353.359636,228.875923,165.825975,31.64458,-85.63957,-94.701626,47.729173,145.554246,161.051008,82.904362,-74.3412,-146.686762,-283.803694,-232.589646,-135.956706,38.26675,87.754003,97.690301,36.797951,-170.509711,-225.473461,-176.31281,-68.45309,-38.193911,-68.819867,-135.843677,-322.794007,-409.725559,-435.301599,-243.297638,-149.598099,-27.10986,36.483535,159.374614,174.346203,77.081748,-33.465948,-43.478433,10.142921,31.768402,-7.809656,-51.612408,-117.03982,-136.113495,-163.730136,-170.49981,-129.187331,39.439404,95.506868,75.942327,34.137892,-28.223258,17.56924,53.407154,73.455353,76.135259,35.800799,-37.727212,-193.880162,-235.309084,-275.99513,-211.964732,-116.085241,69.19733,92.820079,39.837405,28.541045,75.225955,139.25121,158.50504,167.026902,171.652451,195.853646,203.24155,100.821714,-43.286185,-296.892011,-161.57044,-14.935713,106.602812,65.194664,-40.06337,-70.236333,-157.720537,-263.976364,-287.872526,-283.416676,-266.606261,-275.238696,-321.283327,-428.770172,-465.04182,-488.870749,-435.323399,-359.950313,-116.606407,-12.443417,31.882074,-1.76921,-53.260272,-0.58793,47.28918,130.603156,181.732173,257.120931,241.261137,147.974541,115.13244,143.189227,298.298205,384.671128,458.667166,421.714043,290.014027,239.980783,124.566954,32.467923,51.859557,164.289932,197.915996,153.868495,94.035612,-54.344912,-125.54765,-152.573969,-10.529408,71.238136,205.284128,244.955188,210.770321,145.761808,19.693533,-2.279086,46.155544,184.968785,213.041875,187.025678,198.837659,285.235379,286.898427,190.727507,181.107208,220.433202,295.631809,300.006454,214.858403,149.822384,67.016514,32.792154,-2.786844,-64.824342,-28.154845,138.767173,167.841231,41.962083,-46.74241,-105.265617,18.024327,108.872084,272.839155,323.873741,351.297386,325.892266,189.091491,99.738006,126.118744,222.509752,246.781264,207.99118,149.196283,-28.99616,-138.217478,-272.874668,-201.198404,-119.608525,39.725064,67.422128,7.395699,-24.159597,-20.557312,-4.003137,-25.022242,-80.534916,-59.625731,34.045436,28.528062,-110.882141,-186.688497,-227.930915,-186.695589,-183.662354,-176.613918,-149.309922,-80.447184,-66.489973,-99.765579,-107.628463,-75.235906,24.158089,78.816656,156.779237,157.018561,80.865129,19.009151,-89.26575,-42.714294,35.765005,151.618802,149.443016,87.544003,64.234411,16.917713,-64.216694,-92.625583,-52.571776,5.528694,56.717322,33.761298,-19.786976,-41.094477,-53.425506,-1.026219,25.90322,71.064922,74.961196,-22.033068,-100.561997,-190.407546,-157.893232,-112.335572,17.837364,83.728787,159.609471,168.65097,166.733865,172.198658,221.966137,310.475449,341.379175,338.193974,323.515275,314.62487,296.822584,193.359547,112.048804,103.007821,158.426118,225.186209,325.313922,315.938769,190.125353,108.697239,50.096526,188.340942,283.269652,426.478636,449.086337,397.376603,335.878027,162.315696,59.889606,66.70727,165.975238,236.03244,293.550853,260.797041,154.449838,95.884604,8.057459,63.393894,121.15407,206.06107,236.021627,274.591074,253.360277,129.186081,68.549698,84.04484,161.730442,200.652685,182.173294,120.985947,-14.882231,-60.102371,-65.448157,0.417554,28.686782,75.058141,80.523426,14.606677,-45.332687,-184.401047,-225.549054,-164.889376,-1.243448,30.435513,-17.88686,-52.407559,-74.296386,-64.214392,-38.159428,-110.130073,-174.563197,-199.257186,-149.90653,-47.714686,-23.642337,-13.227075,9.207097,14.421323,21.390536,50.239434,94.71932,79.340091,-2.080376,-50.560844,-101.057143,-42.136144,14.22076,116.328437,134.688609,129.234292,133.345073,135.75949,58.837026,28.89781,91.894363,150.337673,158.631089,103.509864,-28.107836,-92.712294,-214.81869,-224.100888,-154.837069,40.005758,93.354773,80.184398,44.080754,-59.796779,-114.301939,-86.331776,19.030068,44.905568,-2.735355,-49.381746,-124.273968,-152.627315,-179.525045,-120.089078,-73.715822,-29.355245,-49.754788,-87.888981,-67.294819,-40.370924,-129.728626,-174.848794,-181.710562,-146.103462,-55.547584,-36.820956,-89.573418,-125.971183:-69.040422,61.160185,128.947638,218.10445,214.519255,117.597762,29.808636,-137.566194,-117.151908,-54.579773,69.707744,100.108083,15.042243,-67.192573,-123.674444,-92.114469,-15.233992,42.350676,87.597092,167.560387,149.277079,39.085891,-4.568534,-42.415062,-28.974956,-3.166341,126.440614,216.279836,270.654341,207.919212,63.755903,32.832647,16.872023,89.770573,188.01986,306.58898,259.794831,115.677434,63.885648,-60.130595,-92.65201,-33.175226,124.135265,166.208085,127.142949,57.766593,-112.886838,-178.170064,-203.518726,-112.038398,-36.934433,115.477037,146.645642,99.183211,44.840013,-116.977858,-269.261737,-280.281831,-158.305866,-87.588425,-95.295207,-175.012064,-399.213948,-492.328929,-476.79257,-269.165821,-178.429125,-43.308069,-6.330676,3.6292,-3.408536,-60.69877,-135.892419,-126.431949,-10.269186,47.279457,33.910793,-42.119016,-211.612844,-243.539989,-168.381367,-70.649953,-45.597328,27.498108,67.166375,64.881739,7.176667,-129.275649,-97.128934,-53.990246,-5.180874,20.426225,36.631147,-0.047376,-139.89215,-214.779232,-243.47552,-35.042786,95.536497,255.077059,249.510294,114.868648,52.027868,39.582896,153.794856,201.71719,200.772121,192.392599,250.12581,265.863249,69.772231,-115.42385,-332.276969,-176.734273,-40.556352,94.192414,52.153861,-133.554977,-209.948152,-280.089773,-247.284197,-219.788775,-215.259201,-230.86991,-285.854416,-317.989105,-393.33459,-456.009847,-553.698632,-427.605091,-277.500893,13.825712,80.409707,95.232986,88.272907,35.359008,-21.99807,-11.220771,93.614801,158.587357,223.367505,227.426762,208.97398,178.791919,159.945193,288.531449,382.864274,493.577126,460.981194,277.704264,168.719264,-42.088859,-74.815116,7.383906,229.770959,287.059551,234.063929,170.503168,0.425538,-94.096766,-96.171142,164.967367,283.938644,394.298202,382.675994,252.481059,169.377702,53.544183,68.128886,127.16192,344.529692,444.696143,440.592262,378.632802,312.457633,302.926012,297.644242,341.849297,388.797417,467.243201,454.516634,308.945812,214.352881,124.822161,226.628646,279.122497,313.046693,330.067498,347.754964,297.080991,81.034929,-4.989468,30.11656,230.845982,335.271584,467.187861,466.55895,391.305978,343.032077,229.064348,210.772428,262.334793,397.774946,424.026948,309.82109,227.074413,114.164946,43.252234,-77.049664,10.719655,99.094409,202.910807,187.116005,94.39911,60.175663,45.712942,40.445919,6.369058,-5.615364,62.483928,153.659962,90.651799,-128.998585,-186.796912,-161.606968,-75.971307,-22.394618,82.741536,105.563093,81.040172,44.847554,-28.772171,28.395416,100.187875,218.291987,248.460484,244.550681,204.160455,18.689657,-91.574851,-165.79314,-22.72096,56.509298,106.912649,88.69907,42.45883,9.974318,-81.630353,-71.37814,-18.810158,86.096432,116.722561,101.233423,50.157368,-84.083368,-136.337239,-142.286593,-52.276044,-11.083694,25.553277,1.965655,-107.56496,-156.65695,-153.696238,-2.793845,68.055329,132.893656,171.118277,297.75287,324.614927,214.312108,142.05509,192.573384,409.387,479.245403,511.364163,489.974534,407.276684,353.855544,247.275489,173.815108,155.592646,206.314402,265.579824,312.156054,281.607423,164.890053,98.619784,72.778094,258.015525,355.329104,432.046102,415.650249,335.045453,278.726602,143.915286,106.609924,130.766037,210.581017,264.185233,337.515687,321.56976,165.628384,63.027077,-23.867321,57.176434,110.593636,197.975319,220.002854,214.253419,181.568055,43.053215,-70.177142,-71.414101,31.879408,98.340258,152.880134,134.028028,14.048359,-65.553387,-130.39438,-11.452874,81.520592,194.754106,171.710619,6.933992,-93.204696,-261.206268,-272.562806,-216.453862,-113.965115,-100.884654,-144.365461,-180.881018,-256.66201,-290.241822,-264.165737,-164.942596,-166.834113,-241.056739,-252.849239,-210.162416,-190.245088,-174.695807,-127.611677,-103.636351,-47.335521,-10.214656,-16.205702,-56.860847,-136.013416,-174.308983,-210.103481,-135.512336,-52.013711,122.395001,158.069743,119.319579,79.783137,23.74795,42.54752,76.426952,134.890714,140.345977,82.134798,31.161436,-57.131257,-91.057317,-160.393892,-143.501006,-53.633099,163.162113,204.353717,145.357131,81.703958,-45.368227,-31.441654,29.33133,147.941099,170.975242,115.493054,55.909194,-121.311311,-220.956252,-253.981959,-46.431077,48.396601,96.913659,78.310661,61.490693,49.996437,-49.963949,-126.999671,-112.070138,-53.484984,-36.039606,-19.043258,-19.356623,-90.903962,-157.053244:102.973486,167.066632,231.329323,322.172442,338.777087,267.099936,183.803957,51.873936,-34.862674,-94.509416,-165.473758,-155.087312,-187.67294,-253.675747,-294.098331,-243.304669,-136.840754,-17.792144,66.894734,210.187296,247.332831,247.478883,216.285897,107.45559,-8.52584,-30.929718,31.92633,73.284885,65.382189,37.832675,28.172138,37.08335,35.055605,84.871895,153.872938,288.501594,302.465205,182.223655,75.454923,-140.243002,-245.172034,-222.20035,-67.550926,4.569479,-8.219389,-89.547094,-261.533206,-320.37326,-380.478262,-312.474648,-225.936144,-29.549325,20.433014,-7.332468,-46.11857,-180.703638,-319.49965,-307.870918,-123.97005,-4.549719,117.297116,71.867471,-145.328052,-232.349787,-260.460102,-147.756,-56.374903,180.207556,272.21169,264.351257,198.929242,94.683881,4.521419,-44.761077,-74.035273,-50.374424,-51.028909,-76.650698,-56.968187,-33.547684,-69.785828,-77.24477,-19.729777,137.62784,184.626396,168.134888,123.38716,25.314475,-23.995469,-24.508155,8.162053,27.476951,-3.250094,-46.114113,-95.972456,-120.415504,-200.061117,-169.074091,-85.503278,110.510254,161.410438,138.101936,107.607611,95.346034,161.331426,193.985947,189.572995,178.959998,244.226165,296.17992,273.345002,169.022398,-53.274165,6.361922,103.35535,226.68638,233.636158,146.506549,57.659904,-142.309179,-192.576656,-143.520434,-18.498654,16.399806,-12.809217,-54.523802,-95.743623,-99.861155,-156.489385,-244.185682,-236.719559,-97.258039,-27.740679,3.001537,-13.150157,-54.506293,-116.905954,-143.396076,-99.538593,-16.326603,147.531019,179.120633,159.405822,139.177562,175.668787,328.977533,376.718575,323.692461,272.67641,266.982966,284.495516,177.683898,-23.783062,-30.237923,165.922184,266.738586,323.6778,292.60583,145.304891,46.297859,-82.668783,-4.596502,86.498966,233.115938,255.131551,223.958577,183.618974,38.946207,-58.249276,-11.84926,211.269308,302.121556,343.803277,305.726535,182.595615,144.253354,187.772854,270.870043,277.590326,299.666296,332.20659,336.587346,276.842148,80.360989,-6.405668,24.409952,99.229718,125.085883,186.566135,198.932772,135.754889,63.367643,-86.498194,-37.755987,71.552029,283.270056,322.747315,277.95103,227.247082,91.96152,28.7358,71.968253,187.309784,193.58581,58.223294,-40.659935,-168.343343,-202.581253,-249.648166,-201.220683,-121.313125,70.054308,123.980145,129.201961,105.119688,34.473776,-22.917487,-52.377866,-90.265727,-42.581047,146.913215,182.92962,64.097269,-35.840678,-199.794071,-175.903336,-101.638252,7.423847,26.987185,52.40247,25.330564,-167.823485,-292.951195,-266.455609,-141.784677,-93.472596,-46.535404,-29.525148,-16.886741,-33.792583,-69.890996,-14.885354,29.423607,70.673067,63.259894,36.45731,39.084523,9.134265,-96.732527,-101.763084,1.82894,27.570739,-76.915328,-147.664343,-153.924634,-102.8474,-3.409258,71.095996,94.571493,125.694749,132.192869,104.521131,85.021759,62.40498,37.033666,24.018096,51.692202,117.798303,273.023418,293.783808,252.63078,256.404843,301.704494,281.196021,276.26989,350.34962,387.714182,378.478427,349.321254,262.487828,207.417681,210.649343,254.384438,317.251905,447.520872,436.984905,247.484291,142.571315,101.605964,271.221187,375.839306,551.45215,592.301566,536.115386,451.203818,242.185381,101.143838,79.557367,163.022781,241.010053,313.360838,304.659234,224.358889,123.200925,-68.254786,-0.150544,98.012206,234.201539,215.242047,96.443161,87.400731,170.664683,184.177557,149.174828,122.868273,152.79616,158.979546,82.309691,-150.832551,-222.794635,-181.257403,-67.580715,-41.236497,8.072793,26.998122,-12.230236,-74.250728,-262.175959,-356.516664,-316.915406,-146.087515,-65.700249,-29.642718,-71.421046,-117.311994,-87.343123,-18.64492,-109.738058,-181.924522,-184.280996,-109.457175,40.123707,66.364774,17.721816,-75.385011,-96.396698,-37.311514,17.968696,63.560827,48.605712,-27.768983,-99.388209,-265.110808,-273.905528,-186.833387,74.72094,182.869091,229.110773,189.211778,134.67834,125.510124,110.922227,74.716671,78.452734,134.164297,153.36592,127.678303,79.431423,-63.66223,-96.2845,-40.922425,89.471646,112.995614,42.720958,-25.098005,-159.441115,-169.578812,-101.731402,47.107112,71.53629,17.690635,-17.781192,-56.096892,-75.334919,-77.368971,10.064591,39.907327,29.776209,1.523362,-53.851003,-61.001344,-128.879697,-258.512569,-255.365226,-185.478553,-184.220869,-208.571429,-191.647888,-114.121578,-99.389626:-34.91204,136.354461,227.038375,366.794276,382.760967,239.156554,112.772225,-128.297763,-208.874459,-151.522314,40.202459,87.469396,-20.275466,-136.502836,-297.128308,-302.402129,-225.232299,-75.202952,41.932729,274.108281,326.666815,251.529978,149.605815,-59.333572,-102.733904,-59.877859,95.304438,192.87782,299.535257,269.556431,96.400785,-6.731324,-102.978898,44.460894,167.759967,351.308305,362.686781,218.870608,103.057385,-112.520923,-190.822078,-145.648374,86.233508,204.44018,224.524437,119.796135,-152.802105,-268.631157,-382.683104,-249.019366,-103.566777,143.149942,183.256567,142.691704,83.94039,-135.748233,-282.220517,-241.687466,-46.100323,41.043231,79.154145,12.340706,-236.957706,-365.449147,-456.49017,-263.299851,-96.71653,187.526605,226.081196,122.492508,57.790803,-22.814144,-85.095743,-77.936465,47.482883,108.006287,61.315679,-35.710185,-240.205415,-310.226743,-314.621191,-150.900441,-40.400934,148.3778,183.241979,96.531148,-2.753987,-181.52697,-171.565054,-114.291154,-12.105124,23.052609,43.196363,15.36375,-96.108009,-160.71543,-230.929038,-129.058048,-5.741108,287.609013,370.27427,300.318676,206.441743,93.812668,144.890326,180.241627,232.013873,296.072659,415.759151,380.763975,107.570095,-57.1062,-244.027367,-113.139133,37.866581,233.446331,209.596295,20.516721,-104.854603,-352.56141,-372.828411,-288.665507,-132.227074,-107.855647,-132.536111,-158.810084,-266.235101,-349.090436,-437.965652,-263.362694,-105.322917,170.075501,236.525899,223.132198,163.035196,-13.685274,-91.971897,-54.084999,106.635533,190.769003,251.276149,209.944752,67.113633,2.967793,-10.902644,213.726512,352.613797,469.87146,439.732901,332.254389,269.522801,50.329025,-109.922271,-67.192471,198.97574,330.778997,421.269092,364.907995,110.510098,-23.592827,-109.669047,135.95244,314.417287,535.879138,528.197415,362.849384,267.367915,129.856841,109.151405,156.118016,327.990879,398.617482,421.245073,399.12061,340.753627,302.815485,285.593566,408.422406,485.261573,564.956667,533.748783,357.851748,256.557661,72.599216,18.621303,56.640838,162.119488,206.657136,247.924194,226.13746,68.673579,-44.669685,-158.668231,-8.645135,133.463475,393.893055,439.643603,346.534927,259.913052,100.364599,72.363097,126.61254,269.101038,313.309502,281.418725,201.339097,-43.977922,-165.670944,-224.608797,-64.246709,25.596238,197.212841,246.337009,186.284186,105.813779,-15.581447,-76.127293,-105.797654,-40.160161,79.449601,262.317808,224.249547,-57.257964,-200.09847,-301.625889,-151.047168,-39.953712,112.535239,121.442286,72.582611,35.078716,-114.593125,-221.378064,-202.476325,-60.07536,38.571291,173.839506,162.287511,-0.112542,-88.131745,-147.314053,-48.946647,42.620616,183.965269,168.336907,7.38564,-66.456367,-156.296068,-228.342141,-217.160773,-19.596511,101.506299,126.903531,19.649635,-197.878892,-238.237834,-219.610066,-121.987732,-32.687286,118.511269,109.915683,-33.592066,-97.913719,-152.30596,-94.498853,-18.493077,170.387026,260.769352,363.505727,352.716212,243.898067,184.518681,125.377878,177.098879,241.719428,398.927833,446.593128,425.193639,360.638598,149.492897,31.422349,59.787609,207.940787,286.353138,336.734804,287.551685,117.623477,43.666875,39.108219,246.134889,370.049059,533.789975,553.442107,463.778569,347.457898,45.879294,-46.104796,18.732023,244.540177,356.728613,387.514676,281.821301,-3.004585,-111.270291,-165.760951,-26.922726,71.631901,229.993473,250.645935,163.506648,79.194983,-109.505202,-184.297992,-135.415867,81.143665,176.998443,194.293632,110.19639,-135.909029,-228.023967,-257.708239,-181.895206,-117.839845,47.190643,87.0392,-21.592783,-158.984093,-440.418369,-452.679068,-346.736167,-70.913409,28.003458,19.012763,-46.869718,-140.994883,-176.109771,-209.695801,-163.03617,-138.901449,-101.632088,-75.979932,-42.306341,-60.937923,-171.422094,-245.730643,-225.96824,-38.969899,96.239645,210.861551,149.240684,-62.535024,-144.093095,-175.21392,-21.059823,98.775715,310.90306,362.151871,320.604252,245.307676,98.304466,75.548992,102.96962,166.35693,189.616278,203.183125,191.044177,83.006472,-15.382438,-126.224378,-25.497446,48.389119,170.788206,199.03775,142.785336,57.688299,-174.620924,-254.957325,-159.613361,177.530787,290.320479,227.719032,101.117051,-158.068901,-250.232412,-269.834941,-77.253531,36.132276,181.842183,192.606111,119.487195,53.881572,-116.145762,-216.584275,-211.499703,-104.53619,-15.395407,132.656498,142.129071,-19.77244,-149.209192:199.42031,188.513185,220.2846,274.195374,261.639391,139.42717,72.666191,12.862981,-0.572132,-44.145473,-240.803282,-341.993592,-435.701275,-433.189876,-388.622895,-373.098936,-371.123099,-267.692595,-164.423868,36.275949,95.238107,118.825586,116.647229,114.166199,59.063352,34.464209,48.653838,63.861765,27.942904,-9.104973,-23.129008,6.178519,117.438189,233.433582,267.049174,329.565908,351.44372,269.518062,165.124462,-66.113765,-237.60608,-288.11194,-276.733719,-224.015404,-173.166076,-197.705972,-278.937272,-327.409104,-386.431449,-278.900946,-187.824269,-51.180738,-33.037659,-66.887243,-93.146318,-159.355699,-191.919682,-152.528729,-0.037276,69.276837,171.177703,199.38228,141.599081,57.067444,-32.490527,89.374571,135.563473,118.348742,92.336247,50.274903,40.816838,4.597225,-114.610756,-176.181622,-172.425121,-90.247299,21.922973,-22.212202,-126.169564,-110.762971,-31.151327,33.362946,68.788965,145.936343,184.523295,256.742332,273.582132,186.508653,50.279074,42.515515,97.768105,107.991018,89.420172,97.488762,141.990759,128.900723,45.208068,65.866618,123.682119,279.700336,341.661097,304.250401,208.771065,26.998434,13.57695,61.352677,154.104112,192.835161,312.909885,359.476925,301.488732,206.527128,29.951476,40.593412,114.18005,274.39252,286.923071,121.43519,2.61315,-161.963481,-157.308805,-104.210659,-3.800562,28.619356,99.470664,141.184801,184.469097,149.259541,-36.564497,-126.294827,-79.808889,45.297393,71.129402,107.31375,139.495591,144.714725,63.041493,49.386594,114.59964,163.771131,247.196959,271.431049,235.157274,183.115345,142.138784,283.230242,369.145461,406.865794,365.181823,291.852137,265.70372,130.110014,-36.919309,-35.432954,154.756062,285.000855,474.069594,498.809162,414.243692,325.302438,125.350278,25.522982,44.636545,163.117149,210.034172,221.446316,186.787973,65.772067,-2.084556,27.609871,190.454267,258.757913,211.463238,125.698477,76.25505,117.109644,126.330608,127.54781,180.679823,244.280552,223.129024,188.465883,175.454242,48.972584,-31.787579,10.019717,115.808527,139.822066,145.97831,144.90017,145.958455,108.020434,-66.830359,-180.101747,-168.766245,-36.961947,28.919381,39.481361,-2.368818,-103.651864,-132.710932,-100.877098,-19.831206,-7.703431,-86.363534,-151.087291,-265.961622,-315.968142,-336.567968,-220.440908,-156.781658,-51.278396,-3.145263,42.74645,13.019849,-113.527015,-202.036186,-234.696652,-225.317061,-143.26791,40.708607,60.695299,-25.581432,-91.406268,-188.510369,-155.449597,-116.822776,-70.114915,-44.952624,-6.49626,-42.50867,-235.768607,-353.92936,-333.840846,-225.192296,-176.973331,-138.667857,-133.256467,-104.671169,-78.407866,-28.562841,-45.990833,-52.6502,-7.53022,15.970349,37.157209,45.372177,-10.96038,-124.898788,-140.274263,-115.270943,-116.629809,-179.915883,-198.401218,-141.931283,-112.999722,-95.233232,-26.517391,24.826461,150.647247,216.573754,313.383629,329.465386,235.968966,89.840212,73.939565,153.455411,213.988431,260.008676,225.523635,177.626986,199.2989,257.490287,217.089895,172.164387,180.469143,242.950378,393.021236,444.862888,414.34425,272.964853,242.493892,302.342872,361.190271,438.68545,424.943696,280.222241,183.441639,73.660084,141.180765,200.037706,289.745848,320.790529,329.561463,288.103536,142.560263,31.844883,13.292948,85.579361,171.699772,290.577272,278.978363,185.638573,131.7399,48.22768,57.017387,99.323017,187.990994,197.253251,194.055408,215.326872,254.157699,246.053642,223.810061,121.906405,75.581731,39.155312,-0.010767,-173.896027,-255.244353,-306.466604,-287.668305,-245.940916,-60.473246,11.628762,-49.994665,-159.999682,-384.311549,-462.914014,-434.779071,-285.184113,-192.832384,-87.328571,-85.56198,-80.495583,-59.436273,-31.619439,-105.771842,-163.859563,-167.647218,-124.618263,-79.297024,-69.279429,-65.890676,-117.310865,-120.532676,-49.47603,-2.584252,47.641946,27.319218,-110.340034,-189.537751,-265.117728,-168.470133,-74.853498,82.022454,111.998866,86.24818,76.14962,118.491019,118.933538,80.930929,7.249219,22.930816,152.406459,207.804975,215.158807,157.276593,-42.663578,-96.228581,-24.747755,124.265347,137.859145,57.993788,-9.484973,-143.821176,-191.04362,-141.765841,87.378191,181.558588,153.434226,67.431506,-73.69457,-100.870723,-72.753296,-2.596036,27.653718,81.528923,77.297678,-37.9464,-114.180493,-234.786705,-260.030018,-235.78751,-192.638317,-195.822417,-234.429427,-242.637044,-203.533295,-190.533594:239.301862,331.86401,369.177881,363.108783,347.424552,320.744628,303.66254,217.489071,33.160225,-47.271309,-96.933549,-113.720693,-272.29129,-364.443611,-344.130126,-254.287988,-169.878346,-182.552362,-127.687024,82.728346,149.99335,109.47961,54.699833,7.834166,12.743883,15.85793,-0.941838,-41.288044,-167.890039,-206.617742,-192.432265,-175.628573,-108.069753,45.866601,96.26931,139.464144,152.597763,94.224136,7.55228,-201.798071,-315.378638,-338.357264,-333.926999,-300.975187,-257.424271,-259.11699,-274.14206,-305.456456,-398.806098,-351.603544,-263.51013,-88.910139,-60.992796,-123.569797,-155.576478,-162.305116,-191.684829,-232.346997,-207.862436,-88.661929,160.866308,183.476136,64.076404,-9.340968,-39.111602,127.293927,204.05521,233.33162,193.341072,76.115737,34.11182,-39.022475,-149.856396,-177.189371,-122.113074,-73.158908,-42.728226,-57.083932,-89.439081,-121.919801,-216.864265,-192.025604,-106.877172,105.321025,171.528577,208.207303,195.191689,106.58012,83.304112,102.764676,96.084067,83.16272,43.29995,6.677998,-17.467283,-11.749844,-75.665389,-149.515833,-121.536609,50.638345,121.868089,103.046966,48.361548,-22.803311,12.416124,64.755684,194.808703,264.351134,376.825079,394.32428,331.681711,259.373927,100.963859,65.018062,113.725401,275.907591,324.3006,250.83304,162.167447,0.836178,-62.778771,-56.503254,-20.320761,3.361238,53.448451,74.557759,72.923502,26.913634,-118.453397,-230.827896,-250.820865,-131.070253,-28.635682,35.620509,15.593724,33.792772,63.811742,36.475536,-14.940545,46.616684,281.936851,331.166842,223.195107,148.609231,133.009222,263.376836,302.669194,283.371082,265.709497,280.579625,284.324115,188.879079,54.912248,16.723131,34.468203,118.412481,385.616121,468.235495,381.508179,262.984187,75.735183,34.856062,50.775499,125.241509,171.325893,218.170131,191.40174,45.823736,2.649666,52.679326,159.963251,190.587102,206.052379,188.136811,124.873115,95.833996,69.954683,50.008201,45.55504,97.882245,123.853622,92.105137,54.982065,-15.092467,-38.722677,-11.788225,92.267693,150.522838,203.467807,190.97275,171.001448,162.135879,98.361166,25.413099,13.178163,93.16167,159.971384,199.163228,152.040336,-10.138134,-75.116032,-49.357229,-35.515109,-78.845524,-172.050938,-183.056094,-200.775055,-247.302075,-346.260129,-297.622386,-223.427927,-86.522796,-69.314645,-110.81726,-119.000014,-131.77217,-244.253358,-307.470558,-290.905829,-189.902926,22.313956,55.923087,-27.345121,-115.258397,-260.545699,-210.465338,-137.819545,-9.531155,33.911899,65.258822,26.718765,-175.698315,-308.056396,-298.384481,-254.965417,-247.855708,-227.217473,-208.531333,-176.089341,-165.742921,-158.780687,-166.814529,-165.247331,-166.821993,-181.965145,-166.309617,-113.935839,-30.371131,-93.926139,-147.460077,-174.479719,-143.646738,-104.055986,-122.517683,-197.4707,-231.235511,-205.033007,-71.017466,-8.008308,125.971758,187.819681,220.026517,189.362205,47.209651,-144.145669,-173.147289,-33.652834,61.793517,114.00873,98.780404,169.354038,239.501039,315.092196,272.384835,252.391539,305.686048,351.036512,420.857803,444.493429,444.959343,406.804589,376.921419,322.129704,331.318709,370.497751,348.724177,231.110983,163.417368,70.855462,64.061969,108.792714,324.251379,436.108977,498.987147,452.839603,273.098618,42.263112,-46.063235,-48.975913,33.518839,174.404859,171.478276,71.438477,19.913571,-7.930609,62.668194,91.313734,99.348064,88.600527,92.18523,127.273787,203.123331,213.039918,197.158627,125.395166,84.680714,-0.362153,-62.514072,-220.972545,-292.091724,-310.781272,-219.759565,-194.205987,-134.505988,-96.184501,-79.9751,-115.266804,-273.823603,-382.446238,-359.467251,-215.40974,-145.393165,-145.328197,-190.470329,-152.968219,-70.6831,25.330907,-92.651972,-170.008599,-182.584997,-157.028704,-164.26161,-161.221151,-92.812618,-43.182703,-38.040647,-33.545804,-34.032577,-7.463567,33.880172,54.955325,-16.515813,-211.829304,-211.535494,-136.264282,8.093528,42.722652,69.165702,79.12946,54.563832,-4.22963,4.549531,66.738328,84.588058,84.629177,94.900134,138.970701,111.1788,-51.732121,-72.118491,-7.580889,113.865806,124.734201,53.963089,0.098833,-98.100176,-75.999779,2.702935,174.996482,210.439182,150.581863,82.730995,-26.175272,-53.076388,-82.795499,-39.835811,13.36747,72.837927,45.300939,-74.072671,-121.783818,-168.594652,-218.148041,-248.759741,-300.580299,-315.559618,-322.031047,-307.95197,-244.150706,-224.931609:121.811465,93.475765,99.011098,146.356002,162.249646,90.813816,22.611491,-91.55387,-191.994726,-192.832093,-73.357643,-39.607057,-148.205446,-233.069863,-282.763224,-264.983094,-259.998981,-205.736028,-110.107701,141.272689,199.002062,129.052071,80.300863,38.569023,-13.76139,-46.904385,2.878733,98.384041,221.3075,193.518223,77.866427,60.452847,104.96746,114.69405,149.81667,324.65176,356.524272,155.313105,6.935615,-151.540994,-150.556194,-128.591904,-29.649232,23.717876,5.988505,-52.556589,-145.995746,-183.191897,-290.618435,-286.198271,-194.321569,7.408877,35.380996,-45.150184,-107.406165,-220.117456,-238.990692,-202.907683,-62.314924,36.09083,150.02154,108.898246,-101.596208,-195.56849,-218.726666,-71.61272,3.85963,84.773705,81.420815,42.500197,39.238237,20.886435,-71.790483,-106.546075,-92.031742,-63.901681,-97.259164,-152.983139,-232.608893,-273.949316,-290.855877,-119.023844,-25.99631,107.060775,127.756791,62.868454,18.368274,-28.899328,-47.186329,-42.490841,23.799796,90.529628,168.623556,139.371778,45.583324,16.957799,9.341613,68.023489,120.108218,233.617921,243.843329,139.080643,84.12432,38.786383,51.619551,67.307906,113.46996,169.273035,281.67224,272.894594,127.85834,52.684223,-9.570128,34.431248,82.183416,166.263027,169.950012,59.569468,-34.864338,-186.790541,-244.883554,-230.334852,-80.830464,10.638145,88.441371,88.548671,77.074171,35.344128,-114.945766,-100.783192,-10.951789,181.459131,231.365478,190.467838,128.29978,56.071298,17.792697,-9.771166,42.311383,120.379975,158.764595,101.074487,14.081257,3.194227,23.174309,162.971806,244.640468,314.252051,290.89225,203.177478,175.374814,91.119278,-24.249759,-18.484537,137.858403,238.422956,328.966303,292.222663,111.917746,5.397716,-103.573314,58.604187,179.228245,294.362635,291.757683,259.662675,235.470795,152.203041,70.138708,74.912662,191.701707,258.453438,316.150924,305.092298,236.754101,203.034648,220.467946,304.591597,329.686699,352.744773,348.497771,318.19732,286.846531,97.906881,-75.761986,-62.373034,27.564574,44.749481,58.176238,61.829439,10.073874,-54.639021,-169.319039,-139.363891,-77.972744,68.042441,105.490789,94.378056,82.822109,15.781241,-82.960747,-76.144215,29.814553,73.720111,49.231807,-18.441687,-185.204122,-255.881058,-299.435433,-143.517974,-19.900695,224.428306,296.993986,272.174888,211.655068,90.145607,-61.246349,-123.344293,-77.515293,18.909722,157.643472,138.292374,-33.431651,-114.684408,-158.829883,-84.235141,-32.921011,57.682412,77.809817,52.877834,6.784969,-185.524196,-336.277194,-314.103609,-180.857009,-117.90854,-9.344321,23.868136,22.552988,6.243533,-30.538755,-49.640965,-18.026716,56.100939,44.035677,-27.469083,-38.157991,-74.817531,-189.943654,-206.353044,-113.235869,-66.998425,-98.235207,-150.883377,-207.905559,-195.448271,-113.742676,-47.231724,-33.734565,11.239941,40.388189,81.528007,83.868007,-4.470331,-54.995451,4.783064,180.396111,253.878082,343.084474,331.016166,235.139578,198.195682,161.423566,181.787132,218.775696,347.735893,410.258185,422.490243,371.519877,226.169603,123.775472,134.229455,293.011123,390.854785,458.962983,407.205737,235.064932,161.618269,112.154705,229.896366,320.793818,489.600728,517.716665,394.496337,290.457873,117.996239,52.043611,69.201846,237.678626,372.026781,470.911601,370.721007,79.485425,-11.577459,-37.018418,65.34888,133.088311,207.873289,187.695638,145.228057,160.865586,141.37238,37.324747,32.533938,171.388305,258.963531,243.551399,129.394248,-105.500189,-179.472779,-238.854279,-156.055592,-64.969025,117.880267,146.017086,5.949019,-109.91619,-251.517779,-246.981119,-220.154209,-153.739396,-129.750125,-128.700472,-117.544122,-32.102592,-13.090902,-74.228323,-103.652248,-107.363354,-116.493814,-80.165058,48.458901,62.796518,-90.280034,-207.376499,-153.077435,96.478012,193.962277,162.803439,73.964301,-86.627426,-148.110282,-182.791159,-46.268522,35.280035,159.833463,207.337162,210.57415,165.907195,91.630127,58.854451,54.223239,75.109357,102.379282,175.508353,200.126815,129.808058,17.948734,-153.353604,-26.811315,88.306126,209.044079,186.902481,64.063811,-2.185364,-175.264521,-235.391933,-138.961822,101.691557,135.159874,2.022867,-80.59226,-116.114034,-114.145426,-142.296702,-94.759388,-35.887892,93.342815,108.563359,-22.973318,-112.271755,-225.187529,-211.617349,-149.226459,-45.148948,-38.86083,-42.311923,-35.070785,-61.193332,-108.392308:backward
29.931902,118.224928,137.141545,131.325851,106.491335,62.823562,76.178786,95.950142,18.557849,-17.531937,-81.113105,-120.721436,-159.106363,-147.391018,-78.964246,-21.518343,114.771596,179.229519,156.926636,69.715367,40.561842,28.427008,31.635922,8.679278,25.07041,80.537479,153.557403,115.749593,-16.455175,-36.410409,12.110983,22.786141,-28.34438,-87.610228,-111.50372,-121.26955,-95.962008,-59.994804,-62.845904,-9.330918,139.789945,176.777751,150.289359,127.333936,37.872618,-28.922239,-73.556942,-35.902758,84.44446,194.554336,210.739454,135.201814,66.479314,-23.206852,-14.499018,27.677817,10.311617,-6.660419,-58.306352,-95.762708,-156.934877,-164.047617,-139.173364,-131.280322,-171.007369,-208.883886,-192.864662,-154.989152,-161.559338,-134.091153,-61.709987,110.211835,202.290494,206.3293,94.867232,9.711112,-98.260148,-94.420587,1.35096,28.467797,-21.691946,-77.525141,-85.139561,-8.019095,73.363383,216.117984,256.226237,269.386008,241.440262,233.346012,207.21261,175.71245,121.403443,133.290021,184.103675,162.750945,53.892081,26.621842,26.139836,-38.834145,-90.297409,-137.533151,-103.4344,44.352709,130.180055,120.511927,58.001571,35.953799,-23.256655,-67.217542,-90.302559,-58.130115,18.056341,0.711421,-44.404222,-86.564567,-75.410342,-52.857259,-25.291202,89.739021,207.414997,235.655431,149.870803,66.558119,-6.021962,8.622801,-14.202228,-84.84129,-230.12866,-225.923823,-184.64394,-147.83902,-176.52475,-222.938221,-177.604491,-35.511335,-42.792291,-91.04024,-196.684613,-237.943377,-268.036185,-253.935488,-197.683516,-170.27626,-78.2155,49.640837,48.38459,-77.354435,-123.008294,-104.295461,-70.834487,-38.666947,-1.991987,25.070878,16.158075,-24.126341,-122.432714,-130.188836,0.130037,68.479315,87.837498,57.118059,26.884647,-2.176352,31.875337,90.706004,73.05357,2.944394,-17.942909,-35.976197,-55.131866,4.436883,162.457115,169.055263,74.425837,40.111308,31.794066,40.212147,55.107143,166.224899,236.061339,302.150133,307.58296,340.833567,415.785937,410.487094,265.941759,189.919729,100.943479,71.686865,52.257697,42.507643,-29.787346,-117.628146,-156.694687,-178.588987,-158.203628,-160.975833,-179.664364,-94.212581,97.777103,140.411519,110.483435,90.356496,38.193101,-12.677008,-34.511133,37.521303,225.883101,174.88993,47.500718,-164.338231,-191.465649,-137.177597,-94.551183,-47.793724,-61.911285,-66.799587,-74.094265,-91.142987,-154.286697,-179.24497,-122.538684,-48.990394,55.385026,81.944683,84.3349,37.139967,-24.389569,-168.191059,-201.165185,-158.306665,-108.152565,-102.266208,-58.05312,-16.925089,32.71369,30.314393,10.082748,21.110086,92.956783,123.042705,110.827321,123.13804,158.119171,195.425396,195.015266,231.332106,269.649524,260.436669,204.671406,184.506442,181.479506,186.247212,202.123464,205.860756,213.786953,278.287505,299.894768,243.053596,175.914533,103.692488,141.907905,274.494553,297.509958,260.408454,145.015681,78.676991,-89.395613,-175.33623,-258.560838,-262.017706,-227.19193,-151.516867,-164.007428,-301.987174,-349.572372,-271.306565,-182.818165,-82.925842,-74.008404,-73.565768,-128.227372,-176.818792,-239.54811,-243.176631,-199.43999,-175.326238,-160.845361,-142.369151,-148.576896,-219.242899,-262.449107,-301.15039,-285.085443,-241.201476,-205.549762,-180.460409,-142.085932,-119.669182,-69.070796,-72.231541,-114.655548,-116.026525,-93.75652,-79.493534,-69.791649,-40.225452,-13.203966,57.762569,65.261127,-18.595732,-57.180464,-21.333665,42.36576,39.295253,-36.534749,-85.637019,-83.810777,-27.150223,105.538719,150.277241,110.223706,11.697324,-20.271182,-71.552316,-67.143242,-7.978008,-17.522957,-50.698607,-124.415434,-141.508769,-146.294234,-158.616325,-157.177167,-128.724821,-99.212421,-175.480298,-234.183571,-287.36518,-281.04924,-270.470113,-261.77188,-220.751548,-151.011114,-120.1634,-129.051401,-166.643788,-267.563195,-309.963484,-294.236137,-244.263795,-178.27293,-169.491836,-171.093875,-198.397318,-219.989994,-192.604698,-124.959513,41.927806,169.286853,197.709339,158.162369,124.06523,62.825361,19.758419,-29.810818,5.269265,187.520096,301.361864,263.700029,115.293693,63.163865,1.226382,4.754838,89.755853,89.695959,36.552079,-81.568545,-105.632201,-33.181987,37.230382,157.431764,193.82072,213.105556,181.633923,179.389908,251.534159,300.79486,347.626619,342.178755,297.171596,245.543882,231.027045,198.006201,158.721103,46.990481,5.662056,-11.699217,1.801668:94.749292,123.785778,135.319344,162.85294,158.044487,103.184649,66.302608,30.970506,78.000605,77.71517,-43.235226,-105.940114,-118.65097,-101.577821,-90.529402,-65.530034,13.352911,-9.35023,-48.491662,-125.219617,-165.178513,-161.872973,-97.912601,46.365491,141.485398,154.38651,111.66348,87.931406,54.523182,44.700644,64.769281,81.626521,93.008709,37.332231,-26.939957,-150.888552,-178.483346,-139.41664,-78.27162,75.543606,213.647074,235.789859,165.749362,110.293518,-6.411593,-64.446477,-127.144585,-112.84409,-40.913504,-36.355747,-54.425973,-87.34336,-104.80652,-125.23016,-114.681418,-53.727899,-1.321635,-3.938408,-55.8678,-100.373756,-230.297443,-274.040574,-221.211292,-159.902081,-117.501803,-197.810939,-236.384718,-248.233568,-230.130703,-147.203776,-71.649901,115.17471,198.829527,161.857808,11.181678,-38.963106,-71.926518,-88.001072,-116.376671,-111.366655,-54.532496,4.583286,1.052533,-68.165805,-95.098587,-27.006058,66.906719,245.942477,288.958493,263.58886,173.344359,124.162688,73.592679,104.286011,206.974853,208.737578,156.073185,123.368516,71.865646,-56.010097,-87.909567,-91.859415,-55.91831,112.862476,238.248504,221.781373,102.192582,53.040332,-24.742252,-59.795724,-80.585818,-73.698785,-28.782773,61.07532,76.089415,2.915729,-45.064793,-38.775535,8.194826,53.907551,66.81492,91.565625,73.063942,3.407639,-178.715975,-239.105783,-249.983591,-219.796153,-165.853374,-198.197154,-228.955011,-239.552867,-230.104383,-185.937047,-139.018546,-73.904747,-99.152811,-128.971025,-189.135336,-205.414343,-223.370342,-221.048664,-206.672586,-206.809751,-143.453325,4.5495,34.302581,-42.793955,-106.463215,-189.108844,-174.442106,-22.932258,145.576779,167.020451,45.725536,-42.130038,-156.26919,-170.291831,-68.199456,16.712203,94.622012,35.54641,-0.554032,0.953715,18.377166,4.721658,-3.404152,29.466632,18.373576,-10.065962,-13.449657,11.599629,28.017236,24.081108,48.206832,58.642271,39.239818,46.784853,71.494212,94.070748,76.643072,98.317117,162.383549,251.62961,242.521344,211.327513,89.815685,46.211288,59.290123,79.808104,93.196542,93.0058,70.335892,-40.290814,-108.392193,-153.074237,-145.631791,-167.347339,-187.80745,-151.777577,19.543308,89.728776,81.257188,39.727354,-1.984115,-4.260289,24.299001,65.677214,153.43245,135.545028,74.957311,-94.978733,-172.227162,-229.689304,-207.19767,-119.558167,-24.349549,-11.17446,-106.768721,-179.326648,-252.297797,-239.245588,-137.130659,-63.123518,57.977136,75.656305,56.864032,-9.593067,-62.823069,-168.486975,-175.901682,-80.988262,32.400894,57.216914,57.806459,60.571636,65.787258,57.032643,87.230245,159.287721,330.204763,293.8888,217.915391,204.48888,265.968907,355.423064,381.822961,422.244855,431.483479,433.016976,386.21006,321.2191,171.635051,141.164592,193.110848,223.353746,217.788995,222.258533,263.056565,309.069235,265.912546,185.322185,214.39258,320.716821,319.227253,269.991507,134.514274,65.824221,-67.07722,-111.823367,-129.845108,-124.638144,-95.250889,-57.900818,-94.571289,-267.866895,-326.499541,-287.121978,-212.017699,-61.452348,-27.640289,-70.315955,-196.15719,-238.717873,-271.3242,-251.514111,-149.873905,-113.646662,-120.963934,-158.558851,-172.201756,-176.808116,-166.031632,-116.424754,-96.434145,-166.797683,-206.737974,-147.168208,-46.929181,-58.531702,-123.256818,-136.757555,-84.388367,-34.832169,9.260116,-8.744148,-18.675645,-46.415481,-54.777208,-14.944729,24.638576,55.753596,17.348231,-10.938938,-78.146042,-109.709938,-143.232383,-111.657286,61.68284,145.012604,238.72142,213.943584,148.757816,11.509204,-32.150611,-76.129038,-69.183869,-11.110386,-16.522019,-60.434111,-121.54736,-104.948374,-74.742744,-97.99571,-146.561051,-144.056592,-106.706483,-117.470396,-165.151773,-285.732611,-332.631261,-386.183331,-385.06698,-327.471286,-226.592282,-177.914717,-140.882448,-170.390056,-263.51296,-268.708661,-177.321836,-155.372107,-232.223099,-247.818562,-222.623326,-236.84499,-273.712165,-270.665478,-216.729455,-97.159333,12.171768,48.651982,37.525901,1.592269,-70.056965,-80.492122,-13.061088,56.173516,201.245149,189.031377,103.847922,-60.241877,-104.301436,-138.36978,-110.951418,9.208203,30.738424,-17.821723,-115.130204,-115.896833,-64.835117,-38.355434,61.213546,130.056515,240.310697,276.262847,257.613706,167.078488,114.684578,95.526691,146.201374,206.783721,101.404135,68.131014,112.727089,119.378696,-0.506807,-72.29526,-70.775647,6.262072:143.885911,134.84164,59.055527,-29.669281,5.847266,137.175064,157.264275,68.129585,9.950249,18.25334,-18.235921,-76.922892,-127.718755,-87.258458,-3.263318,20.982229,108.876899,135.472527,70.793591,-70.870622,-98.42276,-111.065692,-89.892983,26.594881,119.416433,139.516752,189.217168,204.588277,125.677063,60.377185,12.514255,46.505047,166.568359,176.663316,114.524612,-32.678428,-71.159766,-44.222628,13.637492,145.004756,258.654334,284.505362,211.72114,133.229105,-27.04083,-81.206732,-100.264003,-74.514977,-30.123505,-51.119191,-69.880152,-120.364824,-171.765855,-257.974474,-236.684755,-91.683041,31.344752,46.977185,13.142717,-19.122649,-109.611092,-136.715466,-108.592985,-99.435351,-184.047345,-296.732918,-307.015104,-273.202453,-271.171528,-251.772012,-197.454335,-44.169404,19.333878,-9.338721,-132.23767,-206.212923,-295.362607,-260.10557,-101.908831,-67.377327,-84.978392,-82.926743,-102.580778,-173.002631,-181.280142,-97.506829,-20.625869,111.231885,175.925941,185.155982,154.891392,123.312327,62.70736,48.558122,54.163963,54.680154,15.789187,-46.817502,-80.306431,-143.928883,-162.385893,-132.780265,-78.490195,59.508828,152.380181,150.990431,57.974024,-10.252972,-157.003576,-200.699487,-170.402314,-129.452567,-100.571535,-113.4786,-108.021796,-131.485592,-174.855694,-221.130459,-195.365465,-83.144406,61.628246,103.854403,27.330314,-71.761956,-253.983626,-302.360838,-327.24131,-313.24491,-228.998571,-163.623434,-182.608709,-261.810904,-265.670733,-179.61699,-125.471574,-49.631188,-43.129069,-86.60399,-190.929834,-200.435004,-156.935262,-128.597727,-86.524392,-88.316664,-88.57703,-8.822857,23.740032,-35.99631,-118.208908,-214.939025,-160.115822,64.393142,134.667231,107.64084,53.244731,16.830572,-133.263338,-204.591683,-198.084681,-129.755027,14.805443,28.963901,-5.918783,-43.947073,-50.398838,-89.206665,-85.060011,-2.574434,-26.202266,-72.557117,-69.489249,-21.285739,14.520886,-15.726284,-55.955747,-31.415142,85.431778,145.872617,123.229356,56.126803,47.123515,100.136893,147.320999,216.728485,244.842775,237.763175,133.072232,52.39396,-53.135323,-46.325904,96.346999,180.550381,192.695677,20.871771,-49.390288,-84.704484,-100.264037,-207.847945,-245.703227,-159.143793,3.911061,35.587635,19.644202,-2.664969,-65.503013,-78.80902,-5.907286,66.78276,176.063686,93.858022,-16.30544,-200.379532,-220.436655,-146.33204,-92.820718,-8.892045,-1.605772,-52.867747,-158.402128,-167.413415,-126.763974,-91.301711,3.668965,58.937876,142.37153,97.755121,41.574045,-84.830876,-146.211912,-189.97351,-154.88564,-34.169018,37.453112,44.167965,54.745653,81.734214,171.595474,205.018272,237.784281,276.181237,384.441239,374.625565,339.372726,304.659425,302.193406,300.506085,313.715346,382.831851,432.600271,433.118888,394.474415,346.14128,210.366454,166.313826,188.949137,224.137407,236.317566,207.569483,209.169335,186.86252,150.69753,141.036825,179.284376,255.397631,310.060141,296.668641,166.30801,79.240044,-76.327101,-104.886576,-47.512847,-6.401771,37.160337,27.645497,0.61064,-83.698495,-111.910359,-70.935539,-30.625222,-8.62063,-19.089104,-39.215323,-134.52165,-181.764944,-183.490444,-112.361812,74.135919,104.055238,42.940971,-25.505009,-69.124694,-143.103749,-138.186491,-46.169245,-0.557949,1.077554,-45.683672,-41.001321,14.743379,32.801127,-18.305827,-55.50792,-22.025752,38.057683,128.802059,79.695696,18.674227,-16.331214,24.38106,92.923696,98.08508,96.341719,95.415469,71.532613,-42.084027,-94.05368,-135.095857,-144.640525,-103.003065,-18.478779,174.070393,183.805935,128.870508,-1.066817,-56.450425,-101.739694,-80.189301,1.795752,22.784899,-6.058921,-89.703273,-124.36275,-192.506569,-213.33936,-191.803183,-165.329841,-124.073685,-152.042024,-201.212704,-308.847662,-343.052785,-354.206284,-329.415116,-247.178423,-146.454998,-107.1565,-131.973977,-170.46993,-208.868241,-224.576741,-251.752828,-238.036648,-172.450879,-172.323554,-201.545652,-240.368984,-226.98431,-126.175966,-62.192218,22.837802,33.995306,7.108437,-71.060605,-90.378663,-99.871593,-88.193221,18.496125,95.618513,221.037147,207.148874,125.84379,-73.447132,-129.842003,-101.871879,-41.972966,56.447934,44.631939,-2.818537,-136.150865,-197.037883,-211.155535,-140.127484,58.364336,129.186633,186.754547,179.194744,164.938137,113.997832,62.763506,-22.789675,-17.377779,40.163327,80.082161,83.789444,49.86024,16.880791,-65.99498,-106.198536,-115.886974,-61.868776:182.419387,221.431075,198.752706,138.002773,125.933655,132.272492,148.668301,187.280361,196.175117,185.983364,114.933631,57.807929,-39.590629,-55.150028,21.016794,99.216628,221.079035,223.767264,178.621436,81.357258,57.197781,53.962999,83.515422,186.865222,246.25688,243.790804,196.631298,164.807889,104.168781,83.489253,97.319179,126.937269,150.072129,74.202826,37.344096,41.57535,40.995428,-36.328344,-52.788813,40.16266,120.451026,106.428989,18.744249,-19.122483,-97.3306,-159.010633,-233.020343,-199.837896,-62.442055,19.897861,26.738309,-34.551745,-102.20036,-236.670858,-251.550024,-151.612557,-33.436643,-22.681067,-111.622217,-185.478718,-305.720355,-315.052927,-231.2593,-199.445125,-234.182531,-316.379284,-350.462828,-359.477493,-326.422435,-199.272985,-116.955819,45.620632,148.959049,136.925916,-38.353503,-137.740802,-207.642572,-183.392875,-109.701132,-88.014255,-107.157802,-162.011047,-167.35773,-146.062389,-134.357661,-78.807329,-28.835562,57.736306,100.697487,106.441065,66.632903,38.228572,25.489915,44.784566,59.489036,24.213565,-45.030934,-3.845515,-2.381117,-122.469581,-203.113771,-254.836578,-188.852057,52.610232,206.799325,196.70624,25.808143,-68.458757,-156.60629,-164.73696,-153.350955,-133.726564,-110.693253,-158.36576,-191.251482,-229.719399,-228.188452,-169.010113,-101.073235,65.137496,132.981196,117.796791,40.834634,0.062134,-73.12295,-112.750592,-162.362012,-156.155606,-112.354407,-41.489983,1.010205,38.146642,24.143451,24.773512,60.940688,103.014558,73.909212,56.473318,-4.893056,-56.139165,-159.291853,-171.995469,-124.747526,-99.599881,-50.495507,-2.339952,10.180431,4.079261,-32.020499,-150.815564,-176.933121,-119.850824,-35.78582,-3.075868,-10.499323,-63.114118,-164.104118,-157.020028,-11.526865,60.875677,58.494463,-44.061367,-70.183408,-22.014373,13.427137,-11.315752,-37.89658,-1.712187,70.48621,75.86099,25.322254,-5.768986,-12.825214,10.627097,76.764667,107.021426,128.110205,110.831907,111.63524,157.117972,179.500378,197.317773,208.659652,272.112921,362.810887,356.712006,217.293672,152.666386,102.783287,91.907432,128.385619,173.723746,166.895809,-14.63234,-100.506793,-150.264434,-144.731941,-164.0307,-158.766415,-69.156045,-21.913816,-33.032331,-24.865972,-1.194021,1.288401,-15.598839,-3.541791,31.601007,96.853045,33.965061,-44.257544,-144.6098,-138.10089,-68.978806,-36.577453,-30.9147,-33.886971,-7.260016,29.706004,5.590555,-110.350698,-149.834465,-78.408702,6.025178,132.475655,101.329347,23.330597,-179.361853,-257.574766,-291.968148,-253.340125,-141.658549,-62.130839,-53.475757,-71.482264,-48.455637,44.299759,56.847361,31.349691,38.453553,103.396896,116.097678,97.406698,106.5213,129.148391,159.607381,178.023305,226.902871,242.905558,243.968745,227.368434,186.235083,75.205094,59.478861,131.22412,161.376429,133.730473,148.340237,187.321655,175.018602,97.709794,-39.58711,-32.496775,83.477831,179.514549,194.491925,136.980992,64.612942,-95.814123,-127.033204,-63.192538,-43.060989,-113.461191,-157.657222,-158.507099,-177.196563,-189.406471,-198.582982,-192.856962,-147.57024,-73.673523,-61.31374,-125.729719,-168.434443,-216.305081,-218.132614,-148.291174,-97.407364,-70.503,-139.682498,-176.180523,-229.594856,-238.798136,-186.313702,-144.405048,-114.136601,-85.941656,-38.633055,42.491523,39.15106,-38.682147,-64.466558,-29.635983,-0.194918,27.24731,-6.108435,-48.394376,-66.088892,-12.469357,104.479331,126.863276,135.342615,142.914142,120.38552,12.50505,-34.217682,-87.206713,-100.393492,-31.237858,59.085122,266.182299,361.897618,309.599473,85.125422,1.685279,-22.600542,13.236289,68.551764,34.578083,-10.743148,-116.477024,-155.138552,-225.737937,-250.369382,-196.091534,-136.092042,-89.123827,-151.333276,-195.423181,-256.645808,-249.320912,-177.677958,-151.869953,-169.958429,-184.575077,-150.078118,-63.038614,-58.783161,-152.152713,-204.98382,-193.772417,-145.104644,-116.300247,-209.828569,-265.766648,-342.756382,-355.848003,-294.889992,-206.839225,18.147732,135.308522,121.957112,16.344521,-21.906244,-19.651644,-2.908165,35.872832,58.382457,95.256283,87.106612,50.436256,-10.595676,-6.702376,41.655988,74.222041,103.254938,10.166863,-73.58584,-225.613023,-251.224431,-193.451138,-134.603062,20.829096,99.00683,171.628151,128.724918,111.937801,155.150067,184.816417,177.265055,143.054468,72.097721,79.604374,91.663772,45.302709,1.81811,-41.697459,-39.741729,-40.454111,-45.786668:173.79657,182.564573,156.817573,87.043825,51.243563,60.343169,106.618769,133.619949,63.699128,41.340439,40.332949,21.724716,-82.568601,-92.947711,67.241833,162.366506,243.249173,231.593369,173.280908,-1.814728,-49.799182,-25.721447,27.401112,167.641108,261.907244,265.856478,209.962307,165.025752,25.350257,-37.727117,-11.584408,65.872263,198.723495,149.992309,71.326621,-33.497394,-51.135642,-82.95621,-87.318476,-58.081835,-17.753212,-9.281912,-63.835278,-123.765567,-243.957624,-274.413899,-230.239791,-164.302107,-60.448992,-69.010618,-84.286964,-181.191244,-270.236906,-347.80822,-305.410734,-156.111642,-1.94549,18.386367,-92.501336,-160.199575,-240.043642,-258.468348,-241.115289,-216.966108,-178.880026,-180.190221,-220.572352,-363.742905,-415.871979,-337.306263,-216.736246,-16.989355,13.997247,-22.857558,-191.579925,-290.696308,-371.424227,-337.248293,-242.999436,-212.659556,-127.786364,-68.741499,-77.795989,-104.205006,-121.576707,-158.771462,-137.05754,-11.056316,70.866662,70.797193,29.144041,-1.663869,-72.092123,-86.860264,-63.455985,-55.783874,-24.065362,62.295334,59.861568,-90.882557,-169.863556,-136.107728,-35.362471,132.183587,123.405865,74.663399,-23.878928,-63.389313,-151.201098,-179.223461,-124.647556,-80.076589,-88.072985,-175.976281,-201.613831,-231.880914,-249.158795,-196.46314,-116.162453,42.288766,138.713348,146.836662,35.294195,-52.468735,-204.136039,-251.008329,-235.97587,-189.09966,-75.502774,47.056915,81.29889,73.562791,46.185154,21.211936,60.378735,188.756069,176.871781,96.558968,-63.640808,-100.148206,-148.500407,-173.083793,-140.227702,-71.616882,94.801615,145.594848,111.126698,-19.013972,-104.189733,-211.273802,-185.257513,-61.278321,13.685588,40.894229,66.244283,18.979504,-176.359515,-224.973888,-97.588503,12.359874,139.26183,123.428935,82.245387,-4.022246,-26.715212,-17.57046,6.940387,53.415276,60.379701,38.091949,-34.396292,-52.937277,-40.841924,-17.307749,51.295501,81.521239,134.117943,108.018316,51.237967,-8.940035,21.568729,153.889849,212.033629,244.076064,248.414112,247.15209,152.253558,67.032165,-51.999025,-38.386601,134.698606,215.596065,160.003421,-19.824542,-43.789302,-40.685439,-88.761179,-200.866974,-180.352378,-32.789234,7.49248,-27.87024,-73.647325,-58.413632,-51.540449,-66.126602,-1.26138,74.626983,132.698304,-18.538328,-109.88699,-160.751337,-118.93557,-6.098474,36.312546,81.810575,116.142275,121.824468,87.645825,73.207295,51.317083,28.748636,6.883977,33.61973,145.624838,161.762067,95.155786,-100.47137,-184.495862,-266.598845,-266.178284,-184.800185,-12.592898,50.147609,91.928953,123.102422,187.824916,179.536412,158.331168,183.090665,251.466715,259.273308,243.033508,176.17096,126.236057,63.041406,84.388257,219.231312,324.026138,325.565097,244.903895,169.983173,-14.780631,-59.991317,47.572772,142.550485,224.435182,171.679674,145.032977,89.274417,34.678806,-44.552743,-15.937615,123.72637,195.042362,170.332701,52.773509,14.045138,32.902724,66.617926,107.126246,95.552949,39.565799,15.78702,4.456384,-19.301097,-11.695048,19.542922,29.194401,75.922653,98.152372,59.928809,-20.073102,-37.719295,-111.296193,-149.008614,-92.130016,-22.207615,74.338542,97.17316,69.247085,-64.5483,-118.701531,-77.282862,-8.310284,62.393351,50.602928,51.609541,17.430624,-25.169075,-75.094664,-70.648957,-20.268145,29.709671,97.398093,-17.799072,-94.25283,-111.872725,-75.530048,-50.872469,-58.811973,-27.140949,78.296453,88.843883,-20.101515,-72.790921,-130.198476,-133.622605,7.334143,126.542158,306.00781,319.52082,246.870838,29.998111,-39.421476,-38.188194,-13.05746,9.514207,20.440893,15.617584,-50.329286,-100.17291,-176.388867,-192.224615,-181.144601,-166.817364,-133.913624,-97.691923,-91.490756,-128.203509,-165.413156,-213.256274,-195.695387,-110.401403,-91.402619,-102.629541,-107.463042,-107.262324,-158.17534,-199.199882,-207.157008,-179.787479,-155.947425,-188.155213,-226.695511,-317.766467,-337.10079,-257.087364,-160.569385,25.049156,61.492227,31.060276,-6.407888,3.695101,-8.801305,-34.047231,-19.595433,28.808089,149.536198,185.740671,149.992266,54.59096,19.536522,7.240763,41.50445,87.410239,13.718607,-31.72416,-96.276824,-120.854949,-150.22015,-127.138746,35.549148,138.393332,246.627924,171.698623,113.43379,71.962327,64.549134,-7.560365,-38.605911,11.37862,122.619969,134.040728,55.127843,0.952365,-79.445008,-89.370997,-19.739704,29.765678:194.525494,266.313856,242.24603,118.917657,97.925936,181.093352,219.505243,197.349312,115.47752,62.958332,-30.827449,-39.559241,-6.869362,11.847838,93.30947,163.293917,303.212627,338.69923,291.31802,191.123522,191.102469,225.33672,216.57265,166.912469,152.912656,148.075027,118.880541,103.354024,76.479973,65.497776,96.220955,123.214168,57.240687,-75.911868,-86.555383,-25.684669,-11.09638,-94.45544,-162.480348,-206.908222,-76.710116,-11.011006,2.774606,-32.94286,-104.132326,-123.552466,-123.073487,-103.351788,-16.933629,94.017794,118.391192,62.190644,-1.945138,-133.647294,-176.605527,-177.082049,-120.978475,-105.716581,-150.833402,-222.695364,-367.019358,-364.006692,-206.244153,-137.034237,-153.056618,-201.008448,-169.885516,-111.589378,-130.841586,-152.506393,-107.50322,31.381173,190.516285,241.639631,101.996736,-43.066729,-168.634204,-129.498478,-34.519676,-26.503065,-45.696889,-38.604553,-7.490829,95.820917,111.738675,19.193517,-21.612807,1.185128,46.803604,60.422437,92.416195,116.422151,129.443312,97.452955,-17.824109,-87.018534,-182.944102,-157.619023,-140.840127,-181.360569,-234.604389,-330.284954,-314.827875,-169.005755,-93.369882,-94.484168,-103.680289,-114.808278,-183.192147,-226.201256,-233.352083,-191.214316,-124.496707,-166.157358,-219.4765,-307.097691,-274.745619,-23.568608,103.60146,169.878662,111.716077,118.27378,192.159461,211.165751,153.911211,97.591959,25.538798,12.768924,-42.655248,-43.228466,28.808591,185.093272,204.662868,157.746097,139.663494,165.714212,207.419794,182.522117,18.828818,-62.032405,-127.243496,-123.136864,-69.647813,-27.469392,79.96424,155.439385,135.540969,21.331503,-26.947983,-45.610517,-15.814979,67.601798,121.854524,121.861956,23.068818,-38.685418,-68.618642,-47.012879,45.47634,101.533814,141.006337,63.678695,-20.974519,-158.559154,-150.990929,-64.540622,-33.809281,32.719344,110.318728,104.29983,-13.086274,-53.665006,-22.509468,-5.124926,-4.859315,2.077967,52.186926,127.007333,133.152,110.687209,125.104901,211.946228,263.445339,335.505367,386.280288,390.016597,252.11517,153.721872,67.553803,71.368776,102.100539,106.741641,43.256,-47.843031,-65.522746,-107.351363,-145.559129,-129.656328,-68.356527,6.432829,20.447453,46.153073,95.07246,109.622775,126.003156,95.358049,-4.637372,7.258031,150.722533,111.14073,9.494243,-76.694151,-22.188208,137.040333,175.623907,123.990294,43.698962,37.870446,33.441276,11.608595,-81.757902,-130.033599,-131.609457,-94.756174,-58.114782,-61.654666,-84.134297,-199.949549,-254.965443,-266.199415,-233.080927,-198.818172,-223.715858,-203.667814,-65.697564,5.391346,5.272668,-69.255799,-176.019854,-146.793955,-18.681797,-3.798024,-28.540721,-55.535898,-48.76548,10.074106,42.473976,58.429919,82.6039,125.407174,146.142968,85.182298,-35.068049,-16.474532,133.620164,172.899757,114.888077,120.489951,153.646521,67.643661,-46.362795,-160.929342,-106.64376,78.292091,140.688237,129.845176,77.431283,45.742942,-34.762705,-87.993778,-164.964756,-176.821567,-192.080882,-196.298615,-187.086522,-199.649435,-218.690283,-213.919062,-190.696534,-128.413955,-58.408801,-47.762438,-111.591149,-155.459279,-158.821547,-114.407244,-37.782049,-40.472045,-109.210841,-178.378545,-201.32087,-195.887552,-175.24828,-154.767453,-144.818324,-118.660998,-142.789026,-136.025918,-38.095081,13.643324,35.904618,9.860099,-28.017699,-27.509446,-20.694748,-3.415518,-6.805227,-30.876763,-15.847434,79.671906,120.067031,149.696675,167.247665,158.237559,65.576923,19.850286,20.301003,51.848381,108.078843,124.813195,156.752936,171.305384,145.392875,37.093892,-3.330007,11.786657,53.194602,69.96529,-22.786058,-41.548646,1.790503,6.866384,-103.820425,-186.4831,-236.450231,-186.816756,-82.051047,-114.025014,-170.491446,-244.175757,-231.64841,-178.000503,-177.603142,-202.033914,-86.452546,0.971478,20.739667,-42.97311,-170.647709,-212.14448,-245.611437,-236.330316,-207.434627,-172.051118,-145.339248,-157.192737,-213.984169,-255.666863,-161.306958,133.939913,195.941754,126.667081,30.231472,64.37624,179.494193,183.508257,132.639554,145.85077,219.162818,176.947799,137.385873,139.239186,161.129297,158.313477,147.400042,121.948136,57.563056,31.591708,7.558001,-3.2413,12.681319,49.812599,125.864885,151.830476,155.413369,88.678916,71.095511,148.433231,218.609406,294.271824,287.527725,241.42706,198.386332,165.497785,63.33876,7.346567,-74.165007,-87.906314,-47.217424,1.939646:239.900761,238.056061,186.579056,115.963315,116.422358,158.425772,188.858376,229.816074,183.081918,127.406709,67.359725,87.096891,99.592,77.051969,118.994021,193.748136,332.401402,330.754381,252.788326,92.431702,80.38931,173.041791,233.98778,298.751618,275.108848,245.357891,167.854993,124.01676,23.209156,-10.789691,12.309511,50.393882,112.342729,11.014964,-98.403784,-208.848585,-187.304658,-140.437235,-145.2095,-153.440503,-108.167674,-99.557152,-171.582934,-207.946563,-199.236289,-187.775771,-190.019431,-183.269937,-158.680799,-107.581654,-87.68045,-126.647813,-176.351228,-259.113347,-263.199766,-208.844554,-146.857864,-148.381023,-251.225036,-313.872296,-354.464815,-335.673478,-294.487657,-282.270273,-253.52417,-203.056478,-183.768717,-217.79035,-260.679126,-230.404343,-135.620984,39.400737,85.374516,60.211711,-119.883123,-233.18159,-332.931845,-309.021042,-190.374217,-127.791886,-61.363139,-70.439115,-69.722802,-47.092361,-58.163653,-107.336445,-88.289972,20.062749,26.092536,-14.911659,-97.573169,-122.95053,-136.777029,-120.366206,-66.962784,-47.31992,-1.532705,-8.415926,-69.495741,-224.529172,-279.283932,-292.667723,-240.953163,-83.157093,22.878244,18.612084,-93.16288,-151.824929,-231.790098,-258.314664,-208.782321,-141.103122,-99.450706,-235.077529,-300.605314,-325.054704,-299.883023,-156.485093,-21.907136,211.467148,202.935368,141.69027,44.122017,22.085304,-19.402063,-46.656453,-66.824415,-51.64641,9.090148,66.854212,75.22417,69.759984,79.811332,157.146127,204.736424,240.144648,181.11063,112.190462,-70.349607,-140.139556,-190.967722,-180.516562,-89.307005,-16.668309,96.29982,83.356555,50.400484,0.081694,-31.550479,-107.980405,-113.215089,-58.175807,-41.460622,-59.769361,-107.433684,-128.095811,-121.080332,-75.606034,80.930946,152.248798,167.115027,-0.414412,-104.537771,-181.331878,-146.560679,-59.331119,-25.175628,36.479315,17.155621,-24.252971,-67.043808,-47.536777,-15.459566,-20.782715,33.551487,94.375135,162.061382,78.040854,-3.531433,-61.673776,-15.241153,103.384627,146.654053,195.083939,231.031969,237.518486,147.449931,69.639145,-5.342961,37.146347,189.285396,210.190906,101.168986,-38.498784,-96.533621,-189.57328,-200.862583,-123.579717,-59.891665,21.321411,20.026682,6.424876,-20.946667,-28.275539,-53.17407,-68.678435,-7.874504,77.874839,203.69558,116.645777,29.546469,-81.44887,-73.921949,45.645965,116.232476,192.892221,209.597832,197.232328,108.105044,64.826075,35.012955,37.984936,55.328265,58.743288,75.597433,94.259858,49.317396,-169.520063,-275.089142,-304.66022,-244.531123,-155.072736,-172.748924,-188.813105,-127.424689,-48.585499,40.210224,21.257796,-5.515376,20.977993,80.275553,76.121404,59.846373,61.072003,75.179405,103.885754,133.487924,188.49471,156.712492,136.703419,114.627419,80.098535,-8.543042,2.308838,158.318176,233.372316,263.693925,223.055518,202.395574,95.470903,-0.281422,-114.74263,-68.29527,129.428331,208.310428,185.271393,74.630606,14.301119,-47.714479,-31.225159,61.040926,93.68444,80.294136,-18.933579,-82.571394,-175.061751,-184.838806,-135.777339,-98.736418,-15.049307,71.383171,78.891114,-5.820639,-77.775213,-181.22175,-176.097818,-86.398475,-48.717565,-33.805423,-69.993493,-101.368853,-166.015069,-187.013785,-164.539466,-112.546081,-18.952765,1.470859,9.793055,17.302662,8.648344,-0.105338,19.659732,112.202384,148.352105,98.409179,-62.424005,-125.100911,-148.448216,-120.839756,-22.35496,33.209581,107.859433,121.659948,92.01579,-23.567315,-73.334908,-112.050471,-101.339273,-3.339431,82.58829,258.991949,278.279422,213.952654,61.177075,16.677288,34.674516,76.848069,115.491384,78.299845,52.828651,5.726212,-27.178882,-141.716924,-194.273114,-179.496558,-125.246031,-55.256491,-63.256789,-72.302128,-121.219462,-168.981453,-225.124912,-191.592469,-85.860237,-76.42094,-81.983942,-54.658777,-42.476898,-63.725439,-75.618754,-83.621878,-96.261901,-115.392629,-137.519378,-187.434327,-306.686318,-322.732324,-214.174878,-101.321439,119.953338,176.888236,123.07568,-20.423478,-33.890364,56.441245,117.85836,198.612629,194.693028,156.355519,155.451221,132.20456,62.95276,65.826208,142.364349,159.58809,82.708563,34.525914,39.404483,-8.311478,-57.749124,-99.312734,-57.57573,104.499642,175.156773,219.963612,149.44324,119.602373,165.548945,201.172253,158.629811,116.411509,125.417256,168.888192,143.182082,20.022083,-16.195889,-9.87277,-1.075934,49.011975,105.556522:239.91949,148.687549,114.194121,181.109588,246.532046,287.695373,276.162365,264.053079,220.318078,189.896276,138.302902,120.555066,117.073261,127.777037,175.753108,198.383563,219.33706,326.909823,403.237661,491.561557,485.715342,371.977457,304.652404,273.828302,349.63019,362.352701,262.797074,199.163125,186.254016,208.225727,127.544815,38.798409,-57.335746,-24.435899,-17.68451,-104.423473,-187.011102,-318.971208,-319.90266,-209.306483,-117.616839,-113.433987,-140.983769,-138.774728,-98.993169,-86.063335,-84.971068,-81.25436,-8.76796,168.600131,241.060119,220.783994,138.889623,-32.202721,-74.024693,-63.765711,-51.078773,-81.66259,-181.350055,-221.654739,-268.674784,-275.253494,-201.745357,-124.544713,-40.260938,-126.322259,-166.16446,-136.849498,-115.866671,-149.627409,-152.529378,-60.082981,-13.386754,-46.452985,-161.870248,-189.415696,-142.85749,-117.255939,-104.657602,-98.291527,-65.087452,-17.930101,16.950146,150.732592,204.6178,130.584369,46.716168,-15.765002,42.42721,96.072416,208.882167,224.604576,138.827168,90.890112,74.722766,58.528483,-59.298822,-127.313223,-145.921949,-283.277294,-382.057758,-458.507027,-401.052718,-220.004016,-136.715716,-134.255588,-195.017294,-228.359573,-227.25772,-204.207826,-94.454056,-9.647186,65.154203,-44.121952,-108.782749,-126.367837,-72.719577,65.674566,115.502346,183.559331,262.267981,309.031712,425.14121,478.433989,448.020583,357.098096,212.615601,180.350863,69.120164,11.038757,55.496424,146.266074,130.444533,23.045332,11.686392,103.51591,146.821935,147.288421,139.828308,119.409637,74.987131,76.003261,160.152595,233.217652,333.595023,282.066876,212.83295,137.97256,165.729367,251.411164,270.602382,270.859777,268.591043,263.361496,223.827184,212.274891,225.837157,221.435168,188.746243,175.621139,135.702605,51.172988,-7.301618,-121.512655,-162.357456,-172.018404,-137.651362,-75.854682,-97.093951,-121.008619,-137.526136,-114.672696,-85.692043,-123.180215,-217.906399,-212.69954,-118.677118,-88.669046,-99.540487,-56.503034,1.430921,117.893289,152.540655,120.144398,79.347177,112.060527,147.791137,98.111167,-61.709858,-111.131158,-74.114865,-33.778764,-69.954492,-179.227986,-194.710962,-117.767871,-60.453297,-8.438139,-2.106906,42.133832,97.274374,128.34916,227.422329,280.783472,285.710532,231.091412,145.437938,142.265977,161.399738,129.203917,80.711951,26.788921,59.371652,182.016736,217.133464,150.27194,51.497325,52.369513,86.571029,91.087223,90.525317,89.529309,59.683192,34.795751,42.135079,69.42763,20.832601,-116.499306,-128.369735,-108.410125,-138.276238,-204.870039,-145.4824,-77.036732,58.643452,88.094174,23.713016,-47.259267,-155.469049,-156.090343,-77.788815,-50.540691,-61.079962,-52.081489,-50.10847,-115.79164,-146.799849,-84.525706,19.820555,32.907315,-7.113462,-39.808053,-65.981234,-46.064403,37.646767,75.476581,127.145828,155.886021,137.981381,26.641344,-58.869787,-185.931758,-161.432375,2.560092,57.090257,42.902213,15.83403,0.626548,-56.461282,-93.708836,-147.417142,-157.801901,-189.728342,-244.98058,-255.725731,-214.336564,-169.366289,-75.517988,-38.155012,-41.524922,-63.721074,-28.575263,1.740477,-33.972873,-66.158508,-44.358445,-1.599085,0.77783,-24.318361,-88.615931,-149.363573,-245.780905,-234.146221,-152.390974,-123.655637,-98.217197,-117.827964,-129.082323,-84.777952,-40.207185,-29.686482,-62.464933,-80.082723,-69.607403,-91.640267,-87.466875,-51.572532,22.498151,51.150398,114.477133,144.868801,157.184466,128.060634,111.610778,51.226443,29.726628,43.544477,48.438388,54.438291,92.816112,182.397827,134.195446,84.526177,52.352215,48.537874,-19.473018,-53.418156,-41.924983,-76.140683,-124.909611,-146.669891,-130.300116,-184.730507,-246.273063,-291.089769,-262.001097,-214.807576,-225.936075,-227.693583,-240.947368,-260.919067,-282.691015,-250.7046,-125.687278,-59.514743,-63.134857,-98.787821,-102.84749,-96.942464,-119.366534,-184.820427,-202.872939,-228.540218,-194.656326,-148.409264,-122.464742,-151.52438,-139.68615,-47.636046,218.740158,288.762153,225.890847,127.877726,149.416083,224.957815,229.394363,221.241489,248.318771,319.121004,273.905066,231.499763,218.564973,230.361501,224.917902,230.938939,249.262204,172.430115,108.511013,30.033774,54.37158,145.015527,154.594911,168.144073,188.718764,181.047002,112.8089,91.833584,175.014796,275.038687,405.226838,393.211801,294.167981,182.560327,109.023577,-34.414955,-60.168136,-31.075665,-9.742297,39.815795,64.378349:73.086849,147.608154,163.831282,164.839476,162.327646,165.0109,169.958922,143.85453,74.477052,51.513759,45.137503,62.778452,106.087042,110.649954,117.066839,134.608749,203.63823,290.019921,280.743718,159.111349,125.914481,158.250705,156.382342,51.513053,21.707936,65.505861,113.194506,92.961164,11.547933,-30.859439,-53.185914,-43.392578,-106.890469,-153.344325,-105.356401,-40.815843,-94.788261,-249.027679,-257.370818,-99.736899,69.550296,82.249956,37.654929,23.485331,5.052806,6.533178,61.30929,106.03221,214.226247,317.944733,335.382449,268.654428,197.301334,56.79064,17.554761,6.806373,21.073073,13.812842,-53.63513,-112.138413,-201.186097,-200.34564,-170.462116,-169.548749,-151.043731,-139.992998,-164.337459,-202.699931,-195.433959,-142.162913,-86.702038,72.642071,164.43852,148.441246,20.064903,-30.058169,-24.021118,-15.51921,-63.529384,-82.468064,-20.507032,50.220103,52.453347,96.684787,136.547483,154.643987,152.224921,168.14817,172.787224,176.737104,182.338057,181.76918,175.290649,161.681725,101.903317,55.919449,-35.122762,-83.710318,-118.408918,-236.324744,-300.961105,-385.531787,-362.551847,-186.813163,-78.838121,-80.435748,-118.345185,-136.980023,-199.117285,-239.4992,-216.776283,-140.15923,-10.556764,-45.752133,-101.321679,-182.039167,-177.759971,-91.135321,-38.964117,58.281665,175.830499,218.787657,266.536983,301.201103,314.784153,236.265774,-7.325417,-101.823786,-181.805483,-121.233998,-64.272514,-8.594857,-40.83769,-132.322574,-114.048697,29.340982,119.598172,116.809244,42.235721,11.421118,24.332662,51.859761,98.997745,119.605715,177.315159,179.890353,125.177083,29.526505,32.624998,98.482509,150.934784,245.826239,290.550493,300.5021,234.051057,168.079821,103.791729,129.868068,223.679116,227.780221,130.541659,64.992277,60.128111,82.351358,92.633476,44.396958,-5.536997,-89.996642,-102.733562,-101.596441,-89.653766,-41.39367,65.306057,54.207976,-32.722269,-44.107673,10.51877,54.36752,66.055221,172.014239,252.307387,336.579048,340.672522,323.411179,280.792013,251.625648,143.030351,74.876355,3.864835,-3.428428,-28.179288,-56.400587,-133.144484,-144.421009,-111.7458,-64.901286,-74.404059,-88.584529,-66.33907,19.878081,115.324151,153.441508,194.970192,206.321068,170.115825,101.510935,-1.546167,33.579981,188.381274,182.440654,100.802725,-68.178338,-111.42304,-124.984377,-115.420746,-90.119857,-32.439371,5.042231,62.522674,81.765489,47.750041,-6.378248,-43.490246,-5.246281,96.499077,115.440772,80.200822,7.947238,-14.920697,-88.20482,-117.460401,-85.753749,-35.79685,-23.7178,64.985061,133.863803,125.508394,26.266384,-124.559666,-100.414361,45.201273,100.902034,84.425156,51.764479,55.885065,61.206365,37.372558,-26.902933,7.526939,54.38012,66.031693,13.442021,-101.11654,-115.35342,-14.911582,58.286285,89.227699,46.064381,56.674372,35.040855,-38.662555,-146.568023,-109.033277,32.786821,45.560671,22.860658,10.386578,9.828208,-57.403356,-119.247446,-209.02236,-221.073527,-193.796416,-152.94039,-155.395861,-194.034815,-203.201544,-141.794406,-79.818951,16.893526,80.766977,107.760843,100.639019,67.154942,-12.342489,-46.453847,-62.900924,-46.022807,-27.994345,-49.571313,-79.854522,-163.341774,-195.319997,-192.431352,-144.762799,-30.180586,-46.47502,-90.9589,-132.912109,-101.063196,-1.00117,10.613099,-48.971068,-85.299571,-123.467564,-71.599053,-25.380509,64.087889,104.24255,145.541273,142.719505,82.273716,30.548891,49.444611,88.675752,64.541682,-34.27922,-52.307829,29.33684,82.484752,143.510412,142.72516,96.270638,-14.154974,-57.732096,-157.480876,-171.93719,-63.369587,-9.98207,-45.660139,-130.154946,-162.655857,-252.308071,-300.584744,-282.390963,-217.458315,-138.857961,-177.589241,-213.752768,-272.836348,-285.806687,-255.364317,-196.750976,-68.238521,-34.092043,-26.66131,-21.68988,-54.609478,-246.955403,-356.673896,-388.750401,-322.191939,-231.00171,-223.940112,-198.584932,-136.083549,-144.343387,-154.430441,-85.833202,116.348,170.410836,163.219656,204.136513,250.15424,273.046724,212.108207,69.195144,85.419933,289.743656,345.193714,269.997065,130.870133,114.802779,106.382408,79.903495,20.864888,54.86783,84.224204,26.056164,-29.167768,-14.394423,42.462558,128.218283,140.680888,123.125022,105.333759,135.872281,276.7225,345.632201,425.62467,442.722504,427.480416,314.147013,241.138764,140.191492,101.718216,-13.712958,-79.906479,-130.272724,-96.004235:157.861835,177.599186,165.713075,134.002404,146.199907,194.432763,192.258515,143.802728,134.013557,143.101057,133.076384,124.786042,157.821271,188.111684,224.645888,229.363781,287.745162,385.125354,372.265135,272.505481,261.10097,302.846274,302.820411,241.882414,212.645539,207.128873,105.17815,39.358761,15.100032,30.311735,19.55867,-7.901788,-58.982733,-26.204043,-13.536391,-70.102119,-126.551895,-243.399648,-257.356032,-182.024196,-125.913072,-137.078385,-229.670641,-253.669946,-177.787798,-143.192536,-161.503356,-170.582866,-110.619156,9.79097,33.697442,-30.922719,-86.302485,-180.360531,-207.725954,-226.401128,-191.573073,-165.466123,-181.910227,-233.887864,-361.377482,-378.070431,-235.274833,-151.124716,-106.518659,-74.470481,-68.698347,-132.438144,-168.450945,-140.202297,-77.903458,-10.87445,-30.313243,-35.537762,-99.914515,-156.36034,-211.606892,-199.608112,-132.454874,-96.861775,-53.327179,0.146159,30.689535,84.033504,99.982307,31.174846,-50.388026,-157.55514,-101.045752,-43.663236,56.465983,78.199648,31.125344,-16.312209,-74.339993,-74.182795,-23.491407,25.535363,-21.161773,-256.787934,-342.902393,-313.727289,-261.305633,-211.1893,-151.482341,-124.725026,-162.955196,-208.970919,-267.412647,-270.803827,-209.072824,-153.686911,-65.777438,-116.053061,-193.537127,-219.308604,-120.650887,88.451127,141.441538,186.215021,163.617621,147.792542,184.830781,241.094117,280.33489,214.790613,80.181789,65.611189,37.730778,70.713,132.377592,186.391947,166.1576,147.333681,163.077691,152.503471,63.715269,37.11141,26.187026,9.316469,-47.814874,-58.695171,-13.482102,22.717264,81.622019,86.101782,63.941106,100.787918,154.7479,168.546123,146.097341,160.468076,106.980188,44.862378,14.915394,59.075712,149.691802,157.458403,126.813991,117.99719,105.879743,69.923749,45.365055,27.21751,31.464794,4.034243,-16.047369,-30.783301,-13.522072,10.986355,-7.343465,-50.38263,-73.162735,-48.912618,14.077086,36.473107,-14.93576,-120.577492,-113.011335,-18.7188,1.663962,-1.577594,26.164205,113.938204,165.697217,188.003943,190.660271,170.226335,128.88149,105.38068,51.050294,29.494866,-20.402862,-107.116931,-155.54022,-208.815638,-194.68162,-135.077635,-109.392342,-62.011831,-40.859537,-33.388679,8.039984,56.139599,165.094921,174.928062,133.379998,133.586466,132.447519,51.39331,8.772374,-13.852678,30.57772,196.752302,257.107054,219.832826,127.381987,133.708768,135.241276,96.434875,38.663389,55.163467,120.316787,106.695828,-3.157187,-45.649675,-74.077298,-213.479972,-269.369667,-265.797885,-240.71956,-242.79601,-211.726415,-130.294474,47.970675,70.494835,-30.442187,-106.445543,-193.641719,-177.171891,-59.428523,-10.469308,-40.14465,-111.732549,-123.77127,-108.416116,-95.290588,-77.098353,-40.992237,-7.097311,32.899747,17.397172,-32.766927,-18.615972,109.979646,164.697252,176.258336,202.836498,226.029407,138.853223,23.831526,-146.824232,-111.385506,107.487147,106.355246,21.325861,-62.703466,-32.500015,18.403173,3.292303,-11.936377,-9.791288,-109.011666,-224.940937,-215.441,-116.74983,-85.442712,-106.138315,-121.498621,-85.526543,-8.586473,11.085085,-18.61318,-61.697724,-116.885039,-105.751832,-45.780969,-9.35716,2.468301,-114.171934,-167.259959,-173.765072,-148.969476,-71.598239,-9.532311,40.231649,-88.85092,-118.837587,1.814347,85.204847,96.959578,35.632824,-7.674121,31.011786,72.583485,72.227784,92.941384,115.795905,99.697661,77.852001,91.299434,76.007186,21.309637,19.12518,42.493493,58.134412,86.848471,79.123073,43.472187,77.793061,228.674732,237.704493,171.087876,44.699415,10.650548,-40.98142,-32.304802,58.623287,15.035984,-44.140034,-51.025681,-6.302692,11.808456,-61.434583,-242.227928,-245.784425,-101.903999,-59.846143,-110.771772,-217.013542,-207.297601,-90.59281,-54.548862,-87.301806,-69.440245,-32.064089,-70.855166,-122.727982,-150.928765,-140.976559,-102.974737,-84.642977,-133.63887,-230.39912,-237.756365,-199.023279,-188.878076,-152.463134,-95.702014,16.752131,39.388305,43.979354,57.360944,63.76009,104.721143,133.952114,169.957234,179.961883,209.031104,221.678101,190.257136,128.032819,131.715986,135.310786,132.032476,160.071268,126.847178,63.53965,-84.505442,-104.562279,25.194746,106.082646,156.72681,142.445635,99.736316,66.492237,68.580607,144.143002,191.945462,223.551813,216.292541,185.215659,127.958146,87.535909,-0.240522,-22.886067,-4.97764,3.200367,-24.024982,-13.855573:backward
283.619474,150.108415,35.247669,-85.249059,-74.556048,33.440547,100.881711,189.859146,227.421326,225.964364,197.728251,195.05961,221.877192,246.513719,277.394647,257.96548,174.046392,117.772018,107.36749,48.227183,-5.810926,1.771588,76.836494,142.806151,-19.311508,-120.971886,-228.505826,-231.354728,-179.025915,-105.787565,94.232701,140.055133,68.611898,-81.699073,-141.793869,-203.532828,-206.626945,-131.034349,-94.664161,-147.199878,-156.085139,-117.679623,-55.018228,-18.512419,59.427451,67.76592,3.076917,-27.997668,-19.564871,-59.183765,-112.814371,-173.561386,-167.688691,-134.344325,-139.37454,-216.440742,-210.537046,-158.59046,-114.839374,-161.75251,-281.159131,-278.294688,-180.840218,-140.388233,-58.996723,-2.841412,-14.977446,-52.44543,-58.067963,-81.994931,-106.427631,-145.324326,-180.314194,-221.605464,-346.766007,-397.980823,-395.112357,-338.657339,-208.698213,-156.978772,-31.414343,73.00272,87.965986,42.660294,-15.921383,-106.037423,-88.351935,43.976312,161.089878,170.125191,62.465162,-34.448,-172.162768,-155.62735,-56.017703,-61.216552,-119.728127,-77.425353,-53.585144,-62.376993,-82.595807,-78.836339,-42.460344,55.36442,160.150846,185.219065,141.792953,95.2162,-31.591302,-97.160359,-161.337995,-157.967605,-134.713788,-152.554949,-160.371156,-150.123401,-161.624988,-219.183033,-243.163022,-255.625084,-207.03077,-181.631855,-144.492253,-121.622183,-98.245731,-96.443901,-57.562811,-15.408671,65.960737,42.819911,32.431936,152.382001,242.699631,282.19125,213.872776,108.040985,217.299915,267.268891,235.586457,201.366224,96.113435,15.97854,-27.878378,19.81952,83.108377,116.861166,174.714007,246.359673,199.385601,77.394649,82.63273,176.678947,192.622673,169.916085,107.36208,42.884947,-150.675537,-206.761542,-153.369227,-87.762909,10.304043,-68.661126,-152.63719,-268.230766,-283.86682,-222.279022,-165.458036,-119.84736,-141.661383,-141.695479,-172.744836,-202.66934,-208.783724,-172.197542,-30.511819,61.962145,213.798734,252.962956,230.809839,176.767552,175.83896,231.600549,270.410557,319.600781,310.04837,265.024359,166.202708,170.917034,225.023333,220.127311,186.632834,187.221458,159.426776,55.249323,32.047886,97.102155,149.072003,196.647952,179.608267,133.669595,144.23363,143.728366,138.969144,139.514933,58.925644,4.236151,34.148293,108.183085,240.260936,272.37716,266.193787,280.288337,308.726828,367.619694,389.580425,432.081244,387.834861,328.911983,244.476666,209.013849,78.64721,26.645941,58.554308,107.339707,128.613427,23.570694,-32.439434,-117.510546,-147.299315,-116.877868,-69.255736,-58.921107,-135.159164,-134.839331,-51.881337,-35.2976,-144.720468,-200.13016,-160.516221,-101.437755,-8.084802,61.052068,82.798025,26.85552,-33.40365,-49.686828,-5.192016,36.708438,12.156539,21.477518,103.182585,139.243785,78.923744,15.984503,42.176995,128.02341,207.162424,19.112775,-78.972674,-111.526934,-100.435183,-158.998037,-208.185037,-259.942799,-226.935199,-189.770119,-117.496927,-109.732965,-144.320487,-138.867108,-48.204143,12.428293,112.834063,132.395197,116.308001,26.776219,-50.359424,-110.753752,-55.693,67.339179,100.811012,102.462942,94.942683,84.939128,21.842259,-18.769875,-41.375045,-13.037799,82.555462,116.665288,77.58265,-91.070727,-180.155599,-222.603224,-179.851017,-97.861964,-12.97808,20.139706,-64.873857,-181.589012,-357.854461,-329.030481,-75.072709,36.892975,62.322675,10.388929,39.635401,155.832294,193.818357,223.451796,223.219528,235.058757,332.692509,358.031987,250.084019,167.362108,109.831984,143.765713,222.930617,217.317335,136.924383,108.566602,111.746313,47.34619,-16.510019,-59.471607,-9.163347,160.689478,245.989849,213.710663,91.286981,47.270438,9.069184,14.607252,59.677322,91.556497,136.530555,66.264973,4.880951,-93.229269,-143.909932,-272.938157,-326.898223,-385.79244,-411.013814,-410.999323,-375.966054,-347.363152,-299.809436,-278.166192,-189.501656,-128.325059,-65.709018,-144.69409,-198.554643,-250.456907,-248.307563,-157.743701,-79.585568,0.265498,-18.093887,-17.956059,7.187715,12.428936,-16.726436,-35.892041,-2.790009,62.844717,211.721808,202.940969,151.230638,99.12176,107.740835,176.506695,241.633587,420.055673,505.819697,443.78717,221.765116,153.447374,138.806924,155.966662,170.576038,168.019355,177.940919,152.273909,94.373236,-61.530487,-123.327957,-174.238595,-167.338833,-144.614826,-144.297699,-141.208993,-134.306627,-149.752722,-213.593062,-235.594389,-260.378833,-268.26977:238.658348,150.397613,68.24258,-6.953266,12.364498,62.643612,81.641985,170.870547,283.626916,291.210261,199.472572,143.170568,126.979581,170.725889,260.180957,277.712376,273.772517,229.671063,182.998477,51.970703,3.404496,46.012578,124.495664,224.384036,101.300276,-3.200923,-109.851686,-102.006385,-64.814996,-21.027592,150.097883,206.543915,156.777231,-0.26222,-87.274795,-228.776596,-249.562872,-183.022013,-141.839619,-107.635669,-67.476649,-60.431849,-110.756984,-139.54146,-144.269289,-112.324621,-16.684463,20.45596,48.409925,-10.681607,-65.118706,-145.574255,-151.808593,-145.052888,-178.162896,-234.700445,-66.878586,30.796125,12.392258,-108.344645,-361.120825,-399.616445,-267.377749,-157.885589,-22.084929,-67.914337,-117.074611,-189.233431,-225.369458,-282.918352,-271.75848,-158.219192,-93.824489,-125.469442,-207.579408,-222.894211,-233.954001,-231.529866,-187.225449,-145.299735,-40.7104,-12.275388,-38.737116,-98.560956,-106.003396,-44.868481,25.207841,148.939397,155.407836,143.153575,75.514727,-10.879854,-142.776134,-123.632219,-46.82795,-44.287453,-68.600339,-61.410215,-52.470822,-105.080848,-160.425603,-157.039285,-80.296323,53.7986,37.770229,6.674028,-80.062817,-157.419258,-269.615925,-246.178876,-135.553207,-104.853071,-117.192328,-163.998572,-176.975772,-250.714892,-312.902791,-369.042258,-349.528171,-289.807794,-228.752615,-170.487924,-9.251057,44.079806,25.259036,-5.697866,2.550179,30.139083,91.884308,107.557363,86.889308,54.833537,57.69217,94.10535,108.049319,80.305313,85.691728,124.571547,151.226945,111.913408,-23.124316,-78.235766,-113.481205,-113.345992,-108.500124,-41.393666,39.032932,139.068927,93.259425,-31.869227,-9.683643,155.711922,208.032282,186.682072,121.133919,51.604278,-121.099861,-150.214681,-105.190371,-72.960795,12.415459,-7.629549,-85.96808,-254.532421,-295.274025,-219.411374,-133.98201,-60.329683,-110.645741,-126.383165,-133.571153,-136.79402,-141.66266,-120.711124,1.069299,78.876129,207.067545,240.410205,196.234661,48.404731,16.93249,112.053837,181.047269,234.037551,206.623977,155.598198,-16.533772,-70.239048,28.460657,135.399761,270.044021,288.356849,265.044123,147.771728,97.841945,109.900147,135.676836,139.422506,136.780232,194.272817,229.766541,198.911645,148.793246,136.817881,60.564314,28.59262,66.945359,114.653824,239.549536,331.400034,306.111888,184.357669,172.851959,281.073341,333.20981,344.049915,262.600449,197.493615,91.921817,77.181793,84.131583,72.407882,34.709315,30.428357,20.959178,-32.276847,-63.999361,-142.028576,-194.948333,-242.54146,-205.369077,-72.088951,-24.048063,-52.169201,-108.332153,-121.625704,-175.732594,-210.799254,-219.11077,-172.071263,-35.227724,32.434129,33.178962,-57.822831,-128.587354,-152.977549,-90.115032,49.475733,85.000853,69.298374,20.515968,-3.022315,-31.964997,-14.975974,90.662815,139.460915,142.984987,-4.205328,-92.874385,-195.169378,-224.437295,-267.931028,-273.068069,-256.478727,-187.133848,-130.947453,-73.758229,-109.734292,-252.173284,-291.916914,-247.08269,-186.312034,-57.372732,-15.158096,-39.110944,-152.31881,-210.943877,-203.341633,-129.266783,38.614843,105.397673,99.041676,73.406324,50.752767,-18.883651,-24.823417,35.537786,60.664996,85.6077,92.12935,51.927448,-129.605963,-214.024824,-199.786948,-102.649237,76.369142,72.597833,45.468701,27.130299,3.337535,-94.281368,-97.773392,75.395235,188.032445,278.634219,176.880466,129.607635,134.05766,152.46008,161.274462,171.041893,253.603976,327.991023,281.225021,57.304598,-13.684684,24.737805,88.193577,144.019143,109.725424,36.539762,105.576801,138.124683,50.697349,-20.529864,1.812322,81.116436,205.137627,289.150397,305.14828,219.611316,139.410209,35.519887,47.729176,159.501419,208.655561,196.748905,52.818298,-37.60192,-170.207613,-189.085595,-136.882638,-115.249495,-214.086976,-359.147348,-365.320231,-293.031675,-267.591606,-236.229524,-193.214113,-43.553571,22.410801,23.565747,-74.782057,-84.812861,-76.914255,-100.553811,-143.726814,-126.020508,-25.278709,66.1082,110.342774,172.126607,144.213953,39.52248,31.998703,118.745933,191.372616,325.337215,293.20116,239.607835,186.300255,197.684772,314.829978,406.344073,547.708663,540.737346,485.179937,335.428282,274.234436,276.582142,323.636149,350.023788,336.180087,322.490321,187.117567,88.401845,-21.039364,-56.555617,-154.509189,-181.666828,-147.040477,-66.947924,-42.212907,-76.782561,-137.217655,-263.534891,-306.63463,-341.790523,-315.415614:91.918285,-84.743608,-165.633134,-126.176605,-58.090694,42.80671,91.263336,215.339406,252.551245,203.080009,92.178601,77.9834,106.885335,129.402443,165.84208,178.997299,210.68448,220.84711,192.451655,62.397927,5.228078,67.442506,172.023768,292.739721,175.255699,91.251636,-2.734062,-35.036142,-80.910033,-37.607921,179.077568,267.135344,259.041226,76.016556,-25.112152,-160.037578,-160.687049,-38.599512,6.620072,-32.109459,-74.372506,-70.424516,-60.389767,-72.895397,-136.883357,-156.77391,-111.46209,-51.275815,68.421501,2.053649,-93.146685,-199.049564,-183.669749,-132.347456,-127.282292,-82.787135,64.533261,113.408334,5.649837,-122.785076,-278.878721,-259.639886,-151.661725,-115.129825,-130.248007,-252.399565,-320.498437,-424.165122,-435.526687,-326.584397,-243.370544,-135.363324,-75.585031,-44.737684,-72.86989,-144.212436,-209.955838,-149.137116,-12.585825,-14.305679,-44.540816,30.125192,48.104336,-9.413971,-49.288022,-53.029084,-18.761882,40.130475,55.29024,54.685976,27.776336,-19.853705,-131.82088,-161.675631,-217.677214,-245.067218,-215.734112,-168.702406,-172.147735,-171.353146,-160.369887,-132.362625,-99.74667,-7.158023,-15.127631,-70.337366,-190.300608,-240.681736,-321.176404,-320.99221,-216.019184,-160.617772,-138.647373,-186.182771,-204.382952,-251.660047,-299.708946,-383.851718,-376.913013,-273.727627,-195.567222,-172.526336,-109.926228,-91.500589,-89.86336,-67.2241,29.939644,75.42452,147.422172,96.147389,-2.590738,-160.978186,-154.632905,-62.523029,-49.188329,-104.823331,-104.99904,-50.275571,59.983773,51.347846,-94.982277,-164.388744,-170.604735,-128.012333,-78.305989,-64.388383,-15.81121,102.790718,103.284591,22.735455,20.251227,126.896621,174.345083,129.391084,-9.807296,-59.329648,-108.837044,-116.791664,-119.600734,-116.599162,-89.344115,-131.050588,-191.197673,-264.90518,-253.947845,-189.733313,-152.119434,-90.115476,-107.371997,-132.426683,-118.759251,-80.35352,-31.776463,-39.680134,-52.378832,-12.566873,144.692342,220.43449,192.847217,82.156894,66.30562,190.995958,262.597238,272.821972,217.315811,159.644648,-23.636872,-72.049138,23.729473,121.77255,261.133071,278.684816,242.749757,182.015987,171.436803,193.415638,214.634007,257.115046,261.529327,282.046109,316.836168,277.883665,146.478788,88.622751,-40.071465,-83.620528,-25.588383,58.118392,230.523571,347.134096,358.224491,273.301005,228.689401,258.594213,310.839029,325.740959,143.462862,39.016542,-72.954579,-77.348348,-11.880199,38.568602,91.795027,70.933108,-16.767591,-73.256837,-94.839584,-159.536678,-206.11568,-278.917314,-271.551826,-167.351395,-85.150693,-80.101922,-114.853705,-140.502648,-169.350789,-166.424076,-135.770318,-106.983896,-41.999618,13.322929,30.028722,-27.655616,-82.06923,-85.36261,-14.226132,125.941456,135.840621,115.911161,14.371593,-69.163857,-157.764815,-119.774415,-9.640423,6.975261,5.898388,-42.29028,-109.416602,-268.072845,-309.191623,-272.329151,-237.132937,-213.367023,-198.323788,-183.589218,-152.275984,-147.98943,-206.209487,-251.75044,-254.882521,-198.875889,-80.348084,-57.174685,-85.107707,-219.794809,-281.634613,-261.862898,-202.471913,-82.632377,-26.484457,-32.909447,-66.81137,-93.472703,-161.47675,-165.481859,-57.884123,11.513379,71.868678,28.539434,-27.877424,-190.719301,-253.630494,-187.517625,-65.45057,163.72574,231.480768,220.310248,178.633462,155.102008,121.504634,128.252538,248.550899,366.582639,537.979283,379.676086,252.227271,150.37328,166.840793,234.031207,259.827905,289.442465,342.091795,340.968862,222.491709,145.42305,50.055773,45.194762,94.616854,113.910576,124.865215,138.750399,113.567255,-7.537815,-42.804176,30.26806,99.81989,188.034183,222.123229,235.636021,240.558012,197.145038,61.326993,48.134348,169.479424,227.785047,199.870701,82.6322,36.13981,-69.741101,-137.109904,-212.964523,-191.20965,-122.012997,-175.230537,-215.13742,-207.572138,-179.650916,-127.498004,-84.499562,21.116938,55.664948,59.288257,0.243751,-27.287469,-56.983591,-58.113558,-13.579534,40.641258,187.232964,266.955547,285.041806,320.926947,309.808862,232.571418,213.325373,266.505234,324.003917,382.809189,268.200301,211.664507,246.048903,314.397163,426.958769,444.542243,462.745008,517.668762,510.160327,367.390663,274.06681,194.128403,228.756531,348.150303,391.842729,383.511216,193.502062,85.959849,-85.321552,-156.800508,-215.494672,-210.784581,-176.29034,-56.500946,8.253983,52.537882,29.69163,-33.443422,-54.968444,-135.833248,-179.970398:103.276451,-25.485036,-123.156777,-263.524583,-268.149455,-120.239679,-14.510882,130.446405,218.5485,245.355128,222.041628,183.580501,158.769351,190.312229,229.797864,209.289913,164.416613,111.248931,79.384809,85.578176,104.580272,98.825306,92.001773,110.761484,63.136271,-4.618124,-115.627513,-139.08008,-158.431857,-126.229449,47.072516,114.682705,64.675364,-140.086011,-223.717578,-241.043707,-189.223501,-82.685721,-63.856057,-80.09816,-37.204605,-0.717418,47.711176,60.887268,46.384472,25.621683,7.446815,13.955285,27.502711,-13.554445,-55.704707,-152.901728,-182.507501,-177.82421,-179.077536,-166.096277,-22.279824,32.454063,-57.759066,-183.850808,-383.911862,-384.946388,-240.682607,-172.146329,-139.220812,-196.749062,-212.956884,-238.812603,-275.731234,-323.222212,-287.980057,-153.549308,-121.688404,-164.799849,-291.376805,-334.626839,-327.849533,-278.364864,-168.282652,-130.814188,-31.232129,47.045174,39.699505,-24.318881,-60.576561,-96.956218,-78.733766,3.55566,43.572612,31.545211,-58.790991,-140.52925,-269.719226,-269.404648,-228.537643,-224.174857,-177.316094,-116.981778,-109.556183,-117.880987,-121.326752,-68.102684,-15.259045,108.619168,202.329197,177.207345,24.345352,-41.002663,-125.47287,-150.994483,-169.630702,-165.899905,-148.294889,-215.45046,-265.740304,-288.696501,-286.436296,-311.525016,-304.667374,-215.571877,-180.926516,-212.253514,-257.169951,-244.543901,-185.448705,-147.46455,-56.619972,-9.406244,72.069375,90.079044,77.564919,70.630325,97.278438,189.735181,219.098113,219.354463,226.493293,243.429397,266.228857,249.922178,135.375222,70.668184,38.004655,52.008784,80.785367,171.039793,228.169545,270.956673,237.331688,119.911287,89.704899,144.949894,199.732659,164.600589,62.545812,26.696934,-55.316796,-82.478365,-80.415674,-60.300774,35.989965,33.809138,-33.697887,-175.165464,-210.860173,-161.432517,-93.022458,31.035342,74.463629,55.212595,-46.949706,-112.900946,-211.956099,-197.21045,-23.293429,76.908795,201.878359,236.076022,223.810887,164.959566,156.99565,245.743852,296.330063,307.291514,282.913885,243.546821,132.94706,134.996843,261.86566,319.472858,342.458218,322.14796,241.509167,171.48018,192.669115,308.403042,337.714455,289.0491,255.203157,283.789986,371.520823,366.063571,255.501106,173.665329,18.393697,0.356141,92.07163,134.696185,186.133413,287.909566,330.625845,318.249955,270.585656,202.680156,217.747766,316.465026,354.9406,309.675584,148.683866,67.965732,-43.599248,-43.239762,32.658463,36.488947,-16.649716,-6.283416,-5.445528,-130.88217,-226.32799,-267.471547,-196.30708,-36.020884,-6.892282,-26.562738,-46.202547,-47.039134,-98.639696,-148.946194,-223.696232,-207.144116,-39.634359,99.734964,94.611221,24.848729,13.307571,14.668804,4.605179,11.636545,49.120931,53.455626,47.491245,27.885686,-59.451943,-71.959929,42.505625,109.422951,133.967491,40.193454,-13.007482,-91.971902,-132.811781,-204.808442,-208.527291,-173.438324,-159.049114,-143.858545,-86.618544,-91.875457,-186.813434,-219.502878,-206.516642,-173.265114,-51.260725,34.71995,16.10833,-125.097428,-194.726183,-181.471178,-112.790058,-1.340713,31.776329,26.278911,-10.347134,-37.943569,-106.503427,-124.314229,-106.105262,-86.536822,-38.855964,-66.692234,-135.524876,-294.726255,-342.443879,-293.162537,-216.460049,-109.694592,-88.876743,-97.645943,-149.079719,-165.463626,-129.252712,-74.352115,86.288921,171.997516,297.362333,277.978899,236.084847,200.077974,215.497657,243.629154,235.106905,237.133039,332.414185,355.392651,217.288528,97.307133,-28.564231,1.814114,116.785649,125.782745,68.484907,67.467427,68.674077,-38.476097,-114.552133,-88.841949,13.124314,177.928392,193.233928,158.276364,74.62317,35.462364,-66.644926,-98.553656,-34.627017,39.950353,132.300406,54.04337,-23.457898,-144.044103,-187.057948,-272.637672,-299.379563,-297.284591,-285.590326,-303.549528,-354.920979,-362.311045,-311.658539,-262.482447,-161.81484,-117.296177,-82.937125,-183.338258,-252.238968,-298.727905,-254.914628,-77.78879,13.943312,116.734922,151.680428,178.757609,222.04105,205.235249,122.617147,104.332102,139.26872,173.541903,242.937127,265.38026,265.059908,225.792733,209.223237,315.677323,407.844557,487.838817,436.354978,391.646923,292.446779,248.323688,192.916298,197.216497,240.380906,258.589379,285.410493,194.969336,103.010591,-47.639125,-89.613534,-108.810919,-93.014707,-48.805059,29.76141,72.718032,94.510167,51.158004,-94.266514,-144.169622,-185.058265,-199.908122:61.471108,-124.946271,-252.895741,-374.068294,-345.516429,-175.813266,-77.863988,102.199246,228.637988,246.228966,205.878033,160.383693,87.793436,102.873406,212.733522,256.418689,239.193884,102.876229,39.509915,-28.080433,-36.986966,20.724055,79.613162,160.499946,81.533116,0.888528,-100.025744,-118.527723,-127.80886,-105.042746,12.648014,100.818351,189.474343,-18.130779,-159.24621,-273.42926,-221.999695,6.766083,104.351754,145.67437,102.954545,79.72924,57.700908,48.657733,-42.857805,-82.375498,-34.982927,22.543812,115.730417,92.551987,26.885776,-125.530984,-169.872157,-153.097988,-109.435113,37.350622,181.807788,179.559278,10.333485,-116.208068,-284.918496,-277.462066,-159.912504,-113.129474,-91.871926,-178.023091,-232.020529,-294.737672,-317.332435,-318.199118,-264.07231,-86.951861,-44.473423,-102.206027,-253.137611,-309.464826,-292.997736,-200.244353,-1.460295,32.87467,12.296648,-14.435328,-24.47777,-7.074317,16.694679,26.137973,13.550388,29.643454,58.609688,29.334159,-116.935116,-219.494311,-371.228816,-361.715454,-213.005143,-139.058847,-79.038113,-65.846978,-52.638285,-69.136849,-92.407031,-55.41155,18.308643,205.588977,255.759764,178.011806,-48.552192,-127.496523,-174.269946,-143.859604,-46.780468,-19.013824,-14.059982,-102.796328,-188.156626,-360.747534,-396.319479,-327.377533,-274.552672,-230.656763,-228.759002,-230.224954,-251.032897,-268.497175,-240.395418,-176.47675,-15.756936,52.831325,123.814673,49.017837,-32.435636,-164.551322,-170.824133,-69.847172,-9.450955,76.631586,152.340172,175.058622,157.706257,110.21203,-9.80743,-39.885189,-31.916887,-21.046017,-4.082607,66.639694,117.616227,125.684077,79.564322,41.082404,77.737581,196.61764,250.452768,229.171455,106.7288,29.829334,-72.148515,-76.402322,-65.637077,-71.310024,-25.899969,-3.92812,-52.434434,-158.826893,-157.981914,-56.349572,3.555991,100.803177,108.476717,58.39759,-51.090887,-84.047762,-87.930648,-54.480754,17.417405,44.451358,92.856874,108.556212,119.726391,171.794798,204.952354,256.581289,251.543777,211.485526,196.569673,146.241651,2.527384,-1.589555,158.708123,244.478062,312.217454,320.231531,286.539084,200.491376,198.305642,248.302791,260.209475,273.152665,300.249687,410.474078,440.846533,377.90377,210.840673,149.289128,70.321717,65.996273,116.767874,144.578835,225.739574,309.544025,297.361101,188.893677,165.031518,221.041975,258.444672,350.945018,419.144182,371.788569,138.894549,24.733972,-34.437595,29.664991,160.397231,152.510375,53.084554,16.086538,-3.844455,-76.751843,-96.545408,-102.267068,-93.3739,-26.062464,30.257816,30.44903,-4.675829,-41.070578,-137.573262,-164.181136,-122.602508,-78.429984,-29.487671,-19.233229,0.962057,11.442662,-11.621846,-16.262469,6.467852,25.34354,10.886398,-4.432442,-54.858202,-98.634453,-188.019674,-180.492587,-31.23397,55.656719,99.722397,-5.655748,-68.297432,-215.232737,-281.410395,-270.20184,-196.642895,-90.843163,-160.238262,-185.512718,-113.143637,-88.412581,-142.11306,-144.061943,-26.201346,37.771636,77.675106,32.836031,-2.378496,-124.960084,-185.315252,-166.577553,-110.236767,-34.001694,-17.957372,-54.349046,-190.95241,-242.963517,-256.475897,-224.661654,-119.683543,-48.026721,81.183415,49.94039,-27.372202,-226.51429,-294.580388,-246.179715,-167.06974,-55.506532,-14.837502,-23.784959,-83.921916,-87.63403,12.353803,87.383731,261.105433,366.559118,508.612977,459.979158,403.502517,271.677393,214.396133,223.248092,284.252677,408.516238,462.72494,438.651477,274.536593,165.109548,58.636023,95.073379,198.183554,207.238038,178.611977,156.779539,122.114567,-24.921752,-61.951265,86.252245,193.889039,273.108554,266.513593,268.666194,265.814628,234.819208,123.693655,89.069942,136.386491,212.882448,303.461825,160.097991,49.768959,-167.153527,-246.560213,-271.032385,-230.450445,-129.115781,-104.221534,-124.544907,-165.754902,-193.02254,-263.586073,-262.68989,-144.007022,-69.796923,-34.954053,-148.026136,-204.073024,-266.027019,-250.478319,-70.816592,51.010805,210.840572,252.337092,251.448583,236.129465,227.339483,225.577594,237.831362,262.533705,284.163885,371.455545,366.868363,291.483696,116.277971,107.184405,289.563722,380.021974,416.389398,359.161549,306.214732,202.922158,178.874113,165.616988,168.290846,181.544138,195.609604,257.906356,178.998207,57.869605,-154.915079,-178.400518,-93.913063,-53.050045,5.845459,130.362282,187.415553,208.888264,170.173998,44.776669,-7.751849,-59.012212,-45.931329:144.150704,155.618593,54.6484,-172.091128,-220.253888,-114.650589,20.30868,235.934191,184.464548,126.483591,104.695359,113.062156,121.510575,158.052119,237.727075,223.560016,151.875317,98.762961,61.58867,13.137998,9.086878,24.882895,36.39809,23.36641,-16.074333,-46.35226,-140.620154,-176.50525,-146.302047,-86.493222,19.479446,20.715987,-89.190989,-233.469288,-277.076305,-276.892624,-232.768267,-71.309603,10.350353,67.491538,7.97954,-17.732943,12.594034,54.320609,71.114483,35.246199,-13.743826,8.586637,63.984649,-63.481118,-132.392226,-120.230234,-104.268268,-131.812336,-147.880895,-162.391645,-67.425557,6.368398,-8.326781,-127.001807,-333.391518,-300.880516,-76.478669,-21.666335,-53.718033,-12.92516,25.412563,-17.516514,-95.014046,-195.954572,-173.058304,-79.335206,-82.636642,-135.62611,-298.036201,-359.504505,-393.243269,-363.838623,-210.210274,-126.370629,-49.43517,-30.404994,9.447876,71.186619,44.671162,-28.666883,-26.603739,7.186359,25.198356,18.469867,-72.028039,-137.463974,-231.576341,-248.907476,-237.836497,-211.117229,-120.568953,-80.355063,-75.265113,-11.860144,32.462822,71.582073,76.344659,118.84834,172.715047,179.087944,153.059964,106.375517,-79.513305,-160.839773,-176.233207,-142.592306,-123.921945,-241.365791,-294.376873,-230.348937,-166.738429,-168.039875,-218.684402,-277.554426,-214.240606,-168.861657,-147.45619,-160.931043,-121.577291,-64.072611,17.095698,27.821296,55.837397,74.861676,82.304876,143.408336,180.942914,227.467494,241.715114,266.131325,292.772953,289.829675,254.477207,217.130995,56.656445,-4.813386,31.66362,72.092821,106.234651,170.086614,219.926532,276.751317,261.037268,197.05426,184.623554,157.527038,110.735612,113.251843,142.794759,109.126225,-77.297667,-153.584145,-170.292621,-134.866689,-48.723337,-66.033175,-116.830755,-190.676784,-188.35426,-121.81031,-91.906527,-95.335425,-103.632632,-80.488662,-40.3358,-75.433407,-205.710141,-211.254767,-68.516925,18.108339,155.299896,222.032908,204.134789,134.642264,143.318032,257.758295,307.136748,325.365312,271.884257,213.316675,128.19172,157.306001,263.154344,259.200569,171.342281,149.235526,122.020234,52.973542,45.632496,77.215849,79.100729,76.310086,94.234059,179.434507,239.213578,200.333723,76.186201,52.836935,30.814713,11.479589,16.441988,39.906497,76.848799,116.914678,162.319956,258.139844,282.315923,332.973489,358.148869,358.643465,390.674554,422.174721,367.382924,262.861426,38.832739,-21.257323,1.087724,55.749409,127.796414,70.788289,27.111816,-17.668532,-39.431257,-89.868467,-76.514942,16.89911,66.51698,62.925999,23.632741,-11.243828,-106.557911,-142.96742,-137.972685,-93.522886,53.61609,181.838571,207.399615,190.586744,149.715585,47.671246,28.471347,72.348052,110.2767,111.439161,159.303507,185.024044,121.651465,89.674022,188.434865,265.522023,263.73058,73.383942,-9.147689,-63.76455,-62.112796,-34.097248,-8.527789,11.586084,-37.754488,-67.466472,-57.16939,-20.49853,1.31543,-17.294768,-5.062654,54.413283,238.420528,272.110395,207.133443,70.640809,30.217101,-0.378759,-13.118635,-46.706696,5.82578,43.63791,82.239163,82.326646,17.261777,-25.324004,-32.597078,-8.049486,14.830208,14.681734,9.915197,-54.476594,-99.423228,-113.33865,-89.931182,-107.142385,-165.133237,-163.96192,-181.688536,-213.32427,-225.359304,-178.813205,-8.232204,74.114559,157.832898,173.906809,187.809757,218.825751,221.525237,252.009197,289.354175,373.298031,489.477607,527.234886,413.408885,289.34414,147.351438,172.438394,283.102478,288.508517,190.629199,105.989012,80.829405,40.962832,7.9585,-70.24641,-64.689903,79.952492,169.149654,116.789052,-17.778404,-40.952854,-88.140506,-126.669216,-127.655979,-74.419488,12.068967,-3.157539,-10.785948,-46.368611,-107.224788,-280.319324,-343.417138,-347.56226,-254.076905,-223.161731,-234.303238,-267.973162,-348.682633,-362.799645,-287.756317,-220.235212,-135.063656,-160.005818,-179.71463,-195.367896,-181.992197,-48.314209,48.578254,137.472727,114.915106,124.999512,159.003197,146.179182,93.640025,88.415315,117.53421,148.760214,222.7619,188.827507,130.225299,29.959559,29.801749,184.580499,293.195699,402.012431,357.084353,283.616359,123.096954,108.164699,184.814823,198.586987,142.710606,123.962881,127.229382,52.350567,-22.193709,-172.366006,-213.70157,-177.538749,-129.435348,-90.928368,-103.706569,-72.701992,107.23269,177.935733,106.158125,16.397924,-83.418911,-99.154301:54.749454,-22.820616,-129.837506,-327.536596,-358.123187,-204.132759,-66.797774,133.233439,214.16513,223.724264,148.528576,68.718108,-14.224573,41.155154,218.656104,262.145815,238.933396,142.525359,91.396506,24.331224,23.961883,71.258745,80.75355,46.754094,-1.158578,-16.597471,14.267215,22.763621,-68.400705,-109.185522,-34.9568,46.787685,94.546963,-75.900497,-165.645189,-241.005761,-214.395796,-36.998347,59.472975,153.065817,173.82714,171.192392,130.421805,92.348528,-5.045839,-35.694197,14.82553,78.770105,153.981383,61.182078,-13.942178,-138.026313,-179.987389,-166.259936,-113.406331,1.634363,85.392296,98.458733,4.405919,-109.360104,-305.015488,-294.75764,-113.117611,-31.263007,38.414179,-12.64946,-56.578729,-138.272409,-194.266647,-258.929699,-202.136123,1.46627,24.456642,-53.769158,-245.293007,-301.210929,-289.370183,-226.814707,-60.868334,-5.743888,23.200893,32.738891,56.346945,86.207933,52.924516,-31.423917,-27.956726,48.166352,101.932869,83.810891,-52.706236,-154.632336,-315.196752,-321.507675,-229.787863,-172.583985,-38.567523,13.837709,-3.471835,-50.962882,-67.442242,-8.719069,69.744745,228.273198,269.14493,215.662406,24.645059,-51.282833,-99.653325,-87.602028,-44.352594,-35.672113,-98.738148,-261.544349,-323.042271,-329.816343,-308.742326,-271.360286,-242.181998,-149.295947,-102.498818,-135.437533,-257.800835,-305.62245,-280.341963,-197.637407,-2.040342,70.478099,156.471081,171.434629,149.836652,35.567783,-23.814354,30.275091,140.022712,338.1595,343.548505,282.892997,170.487592,125.427682,14.215909,-10.133879,78.343441,141.63369,160.730478,126.260166,161.507513,257.554094,243.350934,109.128534,67.737037,133.624815,222.333267,204.796852,84.136454,10.634206,-89.491998,-84.130131,-14.149777,18.082936,64.85492,-15.697197,-84.599073,-150.512849,-132.439272,-0.548789,79.62409,179.286515,185.731696,148.994112,-10.635509,-109.91535,-226.653498,-197.617675,-13.48776,61.690804,72.464825,28.798316,44.556282,92.151411,108.535875,179.130613,215.56991,250.772811,293.922843,274.304249,134.554196,88.656056,125.013894,185.098187,291.215399,299.093683,232.10058,170.513924,167.989825,173.351104,161.203715,143.127651,157.103813,255.009356,368.889591,336.327251,104.396077,-1.684938,-62.414959,-15.952357,116.049154,139.055839,110.128942,167.686291,238.974248,286.414482,242.78448,214.288211,275.605173,458.138701,514.385378,453.676006,256.606136,153.774379,-16.731848,-29.521931,104.32808,168.85952,159.971002,54.591537,15.710561,-49.825966,-95.358531,-97.928895,-18.161879,126.229379,71.566615,29.795408,-17.428113,-56.244811,-138.096132,-157.704739,-168.958057,-135.225703,20.302726,114.556369,125.258898,125.730548,122.72889,114.03495,93.46019,45.105168,71.660575,85.737292,60.035269,12.639128,-84.840502,-63.182573,112.954591,181.888558,190.053673,77.564822,-1.490871,-159.457286,-223.520634,-236.586223,-169.242294,-10.761389,5.206147,-22.834367,-27.144886,-25.666742,-93.630476,-106.695332,7.926585,93.367168,198.732295,135.937476,56.415238,-72.520042,-93.384348,-58.988363,-36.627492,-13.8102,8.302548,-0.195351,-49.784552,-90.571263,-185.312484,-189.84032,-52.707669,40.758444,102.153311,1.728543,-52.597776,-156.560952,-208.330533,-218.059903,-156.763148,-0.522264,33.50336,-8.502057,-117.444394,-137.541608,-81.393687,-19.626525,139.034759,223.411379,343.90896,331.387343,298.911436,260.257343,259.849947,284.667171,305.90659,381.944065,496.652674,500.666663,291.956087,140.819994,9.96775,70.679344,247.14001,267.773727,164.849759,53.729416,30.50442,-29.842252,-66.252963,-27.406124,43.039851,133.560544,135.853376,131.13517,90.49653,40.631793,-106.284729,-153.19166,-76.462155,18.01221,136.180435,61.564321,-15.858003,-170.58063,-222.66921,-219.266424,-175.929013,-106.919043,-146.099166,-190.837386,-254.984487,-288.613249,-385.421544,-398.825103,-296.619752,-223.900499,-165.253246,-234.227847,-267.296267,-326.713779,-338.640009,-166.897259,-9.533587,148.384054,87.317848,78.241271,124.495413,125.202572,37.496176,-2.875334,46.022468,137.967659,288.066171,197.089996,111.320982,19.969931,39.114583,196.710222,280.039147,332.991654,322.59008,311.570624,219.890064,148.02105,51.827694,43.60321,83.195534,134.408784,235.750728,156.145648,45.416738,-177.269599,-229.322101,-182.248185,-129.163223,-24.164154,111.890748,156.418211,134.966021,78.103647,-37.912966,-53.150833,-7.872631,19.093622:70.281768,110.286924,75.012613,-67.013821,-129.389067,-134.006541,-56.576456,162.040116,166.80998,83.474723,-11.69377,-3.926315,14.533434,32.679688,85.157601,72.301322,2.444652,20.622982,52.904441,122.10955,151.100852,178.036067,163.567609,63.245922,-20.092917,-29.263811,-14.324534,-12.664986,-46.69145,-73.990331,-130.764157,-133.858929,-67.290823,-94.70765,-142.719992,-160.890923,-126.88247,-35.885668,-8.85359,-17.382069,-30.525915,-17.574717,32.985202,50.60613,13.654145,-33.32738,-68.542398,-30.819592,48.794943,-2.760173,-15.374276,52.077832,72.032583,46.928051,16.767173,-42.227992,-11.711644,14.040883,16.405855,0.347831,8.988084,73.884759,248.766683,279.586155,232.118906,230.617823,261.520529,291.749128,254.351802,116.844776,74.035225,43.621463,9.834658,-19.058821,-117.172656,-183.802133,-332.973228,-378.809819,-314.88179,-239.413412,-154.936186,-171.688555,-172.031941,-122.615921,-104.254758,-70.046251,-42.887862,-7.813433,18.33373,34.799515,54.414944,29.312398,-109.819722,-168.137881,-170.566524,-131.358395,-21.87434,29.829878,23.593215,23.392134,44.251927,110.301942,135.730052,138.454635,107.613611,104.025613,147.915817,155.844328,25.130356,-65.836501,-119.338838,-107.223781,-156.929927,-255.649909,-239.870216,-39.835147,43.721231,-18.447279,-113.004189,-189.569171,-60.736071,0.863513,-4.937631,-50.037267,-142.723847,-160.023939,-64.846498,11.285413,64.757173,50.647898,76.028194,162.310053,185.274069,178.705577,163.547782,123.697568,121.804829,126.945469,77.882831,19.985079,-88.115679,-85.905984,18.842708,54.635604,39.34364,24.067188,36.525662,38.439246,7.61398,-59.686088,-67.991729,-44.243876,-4.815901,-0.012976,-24.973306,-52.769987,-139.419967,-190.301829,-261.920427,-242.445997,-90.05244,-29.798637,-76.588755,-179.709864,-193.414979,-161.86686,-141.649724,-110.206342,-94.265591,-108.635296,-119.788285,-96.989843,-82.845651,-114.798096,-179.546686,-158.667703,21.593894,163.641431,184.550582,238.990625,267.199819,283.988438,282.740214,267.654316,253.025033,244.506346,227.217391,237.87761,264.565711,238.499659,121.949926,79.028059,42.86178,5.206121,16.530306,51.937602,3.611503,-168.734275,-198.123521,-117.661077,-63.556378,-82.859566,-138.868352,-146.325509,-144.004757,-147.751147,-169.279825,-184.575617,-203.094435,-182.593228,-143.952913,-32.428928,8.864283,24.990638,24.177565,104.341148,211.553215,219.399575,182.319085,142.610109,9.243114,-38.226076,-24.006384,-0.384999,16.919615,-21.925272,-75.120995,-156.519595,-153.900929,-119.81654,-99.025208,-32.339178,45.434562,63.84546,37.835128,-10.374702,-130.678633,-144.344635,-35.216321,35.407273,147.279802,250.998196,289.396768,280.337199,213.849667,34.866098,-20.564511,-37.086159,-21.825431,-14.782609,43.843505,88.007911,116.411338,116.469886,167.076797,180.983703,95.725776,-21.234219,-35.227721,-0.108929,0.158917,-61.362727,-84.355246,-77.844356,-67.517688,-78.243834,-105.112288,-107.365509,-110.03464,-103.964871,-17.829386,42.458763,98.353799,72.523616,46.436587,-9.044951,-31.100822,-61.335101,-79.508466,-125.632581,-73.725446,-3.322798,107.673709,105.978768,-18.213446,-90.586971,-121.521584,-96.245679,-109.308669,-94.856628,-12.960616,103.289631,60.104958,-96.747605,-136.508354,-162.112071,-186.529651,-194.575806,-208.769101,-217.345863,-239.61122,-240.899072,-216.857191,-198.87066,-94.254438,57.621647,91.081488,87.36678,94.770361,171.685071,215.347855,265.492241,344.002555,377.396128,325.079979,264.617391,200.498856,201.58887,158.649025,92.981402,-18.684901,-51.629012,-59.073211,-72.931186,-84.35357,-55.653597,-10.491585,37.5368,7.347559,-34.454688,-130.795067,-138.852557,-109.15119,-122.53336,-203.461184,-218.219212,-110.459658,-0.487604,-6.738657,-63.416453,-87.778533,-139.439475,-166.367625,-178.204314,-126.5106,-108.213892,-131.402429,-165.536692,-224.403533,-222.643517,-155.693629,-125.625281,-105.978959,-79.142922,-37.631266,86.040395,136.068761,182.351139,169.946013,90.068761,100.64106,137.055028,173.414028,171.584573,120.001852,71.027201,26.645639,60.126904,172.907981,196.725069,166.212744,66.893768,13.777979,-3.201656,64.175189,255.596158,303.914842,256.051548,142.546114,115.549483,80.709184,57.414305,51.440418,70.182517,74.731963,-28.193223,-113.717039,-258.695427,-288.142744,-265.375419,-233.053897,-159.240875,-111.503102,-91.506838,23.647174,79.072955,48.424607,6.941306,-30.424981,-55.11422:309.968137,211.900611,93.606209,-101.626515,-143.194058,-103.43773,-24.02595,167.387184,184.125394,120.642169,21.566444,10.694222,53.78244,114.208142,238.271437,228.961643,57.286842,-20.324991,12.401365,48.401352,30.710012,58.414492,102.508584,77.182124,-67.535555,-132.269022,-226.99303,-238.917882,-186.014548,-137.771947,-57.234487,-44.06681,-56.270989,-56.322733,-46.572143,-55.057738,-53.50077,20.749205,43.86783,-18.584989,-70.020952,-70.177512,-55.852658,-36.544702,21.462671,51.327452,83.590736,82.402343,67.333306,26.937639,8.213996,0.739056,3.079988,4.631627,-27.967601,-145.481122,-102.546625,-36.251155,-1.779516,-27.797653,5.981315,90.013625,236.641891,246.921103,203.142449,185.684639,196.210923,225.34111,217.461819,131.033769,70.008437,-44.552997,-129.671593,-164.938281,-199.475638,-201.736451,-221.111368,-230.25527,-205.740585,-173.974118,-105.741462,-96.921058,-102.950918,-88.042457,-84.049826,-51.910012,0.870663,98.824147,74.799647,37.781971,4.567608,1.933893,-45.017375,-84.287884,-121.921347,-101.617611,20.277127,126.95693,132.801615,127.579409,140.663678,152.778063,151.816921,196.641567,240.908069,239.580046,247.598444,239.564623,84.164955,-32.168925,-152.8402,-146.824739,-116.470658,-133.616722,-119.717705,-5.175995,44.713349,31.198606,-14.470033,-67.817528,-42.362671,-41.474735,-48.793715,-48.943395,-80.287438,-91.965459,-45.783716,4.947958,107.919095,130.936019,124.577038,153.992481,169.876197,143.897296,121.770314,118.727839,152.80596,143.004323,68.288942,35.882432,-7.996734,-28.235487,-39.322223,-16.143271,37.093917,8.707521,-4.213674,16.506054,9.340912,-32.252655,-42.130064,-51.178707,-7.822402,11.531592,-11.646496,-34.345848,-122.973393,-199.530323,-286.05399,-243.528949,-94.167343,-148.45988,-231.55226,-295.177653,-284.948452,-240.104398,-207.258671,-193.048143,-213.491982,-194.237101,-109.428677,-83.188046,-105.248206,-117.003468,-84.144828,-44.513026,99.239833,247.889567,264.357421,205.171006,181.008996,225.19385,257.273079,214.715063,154.008576,172.584455,249.129049,264.098126,198.421704,144.30962,103.285614,122.028941,142.622027,61.732043,11.830088,-16.304962,-4.986281,-32.670582,-76.886016,-103.666824,-0.517665,41.176207,68.505772,69.480121,9.569085,-22.568552,35.91323,82.493766,37.987083,-27.449867,21.847009,195.557013,254.647207,284.48701,270.045633,236.642018,238.582298,243.92162,266.828346,257.166184,77.192692,-46.231336,-86.660192,-19.098853,15.87408,-109.247257,-157.94445,-168.883896,-156.605145,-130.563939,-114.787795,-109.989983,-106.956827,-86.25503,-20.359102,-10.5766,-89.466724,-125.605369,-93.331651,-48.716153,57.499993,134.863589,109.244174,-31.519811,-86.074561,-82.785358,-35.023292,28.878838,-37.800015,-86.601295,-79.465651,-20.857679,43.856657,28.38779,32.447018,67.313448,82.854361,-36.357759,-83.295154,-54.22375,-30.107132,-72.468222,-118.801674,-182.491819,-188.640789,-188.895852,-145.905135,-87.752751,-11.366675,-17.199146,16.791527,91.381468,228.79056,182.546974,125.863312,66.298387,60.072478,66.558428,65.821915,28.118556,45.892941,85.73193,154.024856,170.978723,145.979967,113.051308,66.060448,60.365756,77.230948,117.48013,143.661777,143.699364,84.584296,-78.247213,-115.826296,-68.03173,18.122538,11.498441,-173.466846,-297.919079,-406.379033,-363.390787,-212.887031,-172.912811,-113.602952,46.867488,123.437705,183.673002,189.38956,206.958279,201.829148,212.486424,356.454345,378.036026,213.987051,134.403835,130.267134,173.128967,258.313974,265.825359,174.101369,69.605337,73.176351,114.325534,75.792884,-58.766965,-71.764883,44.345438,133.709757,100.667581,-8.002713,-22.307619,-0.851322,0.908624,-12.381207,-10.219096,29.290087,23.113786,-20.851983,-80.336958,-73.32314,-88.09748,-143.204191,-285.984222,-314.55299,-277.374545,-232.697605,-255.370005,-319.449592,-310.261896,-202.006041,-153.193158,-148.980165,-189.435622,-184.526721,-160.76222,-169.221274,-154.766464,-117.381883,-105.063296,-123.467178,-73.416687,51.964538,40.166292,-99.015079,-131.14478,-66.811523,-18.033853,76.093466,134.699909,132.603916,75.7296,35.807974,25.993887,78.122723,247.753948,370.72135,356.101225,195.235503,118.317823,59.412257,58.277001,54.078601,56.451026,84.620977,-19.048024,-113.694161,-179.185952,-160.752709,-169.907019,-186.332942,-172.604846,-165.591775,-175.237749,-126.163805,-62.081823,-29.084037,-96.202056,-246.335782,-259.981702:62.716285,-22.339177,-121.611915,-293.360239,-324.240892,-220.970514,-113.418624,57.683667,87.186608,72.661473,65.453344,57.469574,-6.833076,-7.717598,121.949402,187.582882,217.251187,154.732909,102.823742,40.917969,51.873646,123.826417,144.748161,80.143994,-53.027571,-77.543956,10.937159,48.717968,-67.174702,-150.645569,-137.109651,-72.525417,-33.328509,-166.446825,-226.444588,-224.225754,-161.440214,26.882896,90.361245,60.551382,21.975425,46.644655,104.276132,120.023586,85.621296,46.819933,-19.202701,-50.72923,-48.143993,21.219955,20.189023,-51.539762,-79.740932,-53.908239,-16.589803,53.456495,92.409187,83.328132,6.894975,-38.51154,-81.800567,-49.855096,83.185578,115.413929,87.002372,85.682342,90.353349,54.51595,12.6911,-66.212253,-65.870245,-16.010047,-63.945562,-127.704106,-237.02976,-259.430423,-276.601406,-280.143322,-245.220732,-198.948016,-83.56045,-49.921891,-70.076178,-133.286418,-151.046037,-81.967454,-24.476153,12.44554,22.700087,33.220323,-36.001057,-134.414647,-305.237244,-291.185697,-154.178274,-135.747878,-168.006908,-103.347426,-42.127134,75.282021,109.016937,112.407555,103.52589,86.205559,41.799211,15.199342,-4.5809,-3.45644,-53.964739,-100.394532,-160.547761,-171.658687,-187.079006,-210.606324,-217.44999,-211.698108,-204.511853,-194.577065,-208.551978,-284.869857,-309.871234,-287.090851,-235.460801,-230.386889,-248.509086,-227.243169,-92.074643,-23.464353,51.710807,64.636034,54.199644,57.343727,85.834837,157.921056,174.889498,154.906927,104.747354,70.661441,20.062138,6.65497,-39.892286,-47.73746,-0.373454,22.843136,83.123843,157.341562,165.786312,132.845596,103.830445,76.424938,74.822886,14.630384,-4.897288,29.280765,16.62783,-47.032249,-140.840635,-146.74918,-144.872374,-128.486873,-1.038848,-9.736997,-107.956173,-208.812263,-162.91263,-30.805466,-3.566231,-3.270716,43.584219,36.924215,-82.653121,-130.429362,-173.902324,-196.280969,-191.010897,-137.557587,29.302217,173.962356,212.796588,202.843093,186.105702,194.58469,194.791863,179.13535,193.381186,170.612787,90.754419,96.263437,185.389015,198.605742,103.605437,53.62573,60.076428,61.692655,43.189004,31.060171,15.538616,-32.290118,-27.635799,51.310795,99.059405,79.148813,23.760002,16.785409,-5.285081,-26.991824,-58.699981,-71.369707,-84.172615,-43.937583,1.521436,47.757714,24.573872,-0.572794,28.212094,145.706125,277.633792,293.7215,213.51227,156.23929,38.708988,1.739206,40.464628,90.015664,129.573631,64.072417,37.784755,36.407054,21.133585,-14.969702,16.77985,121.020491,116.037042,70.333483,-8.781861,-22.120469,-73.37486,-116.5613,-138.352556,-87.227418,65.830685,147.294342,170.788932,186.587674,155.130029,40.390437,-14.171468,-98.637986,-164.384358,-152.715344,13.830729,104.03649,165.858032,170.274805,189.617943,188.079968,163.468246,147.245241,134.23226,54.552266,-10.620909,-96.44414,-75.088286,50.858284,82.893575,41.856806,-41.557339,-49.477739,-36.313428,-28.802701,26.635038,80.813735,168.579877,151.422674,145.934502,164.27097,128.26681,-4.250094,-43.238363,-70.542216,-33.593048,-8.631841,-26.089109,-58.677675,-117.191719,-124.983052,-88.310907,-65.488772,-57.635318,-46.72278,-24.710115,-14.551984,-38.352668,-72.174274,-62.520916,-42.785989,-85.755311,-120.252222,-165.310287,-168.279256,-160.94375,-153.225288,-93.945239,-42.254515,114.311828,267.670083,280.209884,251.305519,273.433253,351.582869,345.037611,287.988542,381.004216,434.88171,357.840442,263.087958,150.721003,144.871206,131.810943,96.709329,35.857112,39.222735,34.356952,-42.136454,-90.011882,-61.239602,9.616721,106.921795,93.407438,53.019713,-11.897557,-3.309847,5.579972,-46.711829,-164.85256,-147.774636,8.681671,37.30178,-17.739475,-114.82488,-129.012598,-105.416274,-76.446141,-31.454484,-51.857775,-76.634938,-103.493836,-114.970294,-156.359001,-175.759083,-182.957196,-148.289311,-28.50169,-22.744549,-68.578064,-122.71249,-93.747994,47.460176,118.171116,233.001683,322.379484,314.005004,170.21399,103.503872,102.315533,140.220052,193.08472,217.272528,269.885006,201.267131,140.717612,124.610337,152.573918,171.489298,164.351644,159.21699,167.343798,156.283591,109.050242,93.222105,72.404772,57.137585,39.358644,54.084336,92.216068,-16.846199,-116.834993,-249.352037,-271.675941,-262.173851,-225.399213,-93.92251,0.115061,7.37186,48.103623,95.275607,129.922731,92.747408,-14.58045,-28.439158:backward
-257.622751,-329.052954,-299.247154,-212.482659,-159.521575,-72.757211,-69.406132,-85.354273,20.516539,116.272539,219.382348,206.373282,199.071663,214.535028,176.562236,107.430704,-108.11319,-211.861813,-182.359502,-152.121286,-183.07424,-230.630533,-215.873995,-166.181302,-170.639597,-176.487362,-158.158933,-138.403719,-116.494348,-118.472197,-128.716453,-139.268212,-165.624862,-149.76204,-126.797536,-54.123274,2.23598,61.33232,34.901714,-52.945363,-129.162452,-155.087102,-142.133857,-109.572995,-46.740168,-46.888854,-180.602286,-299.052573,-490.540034,-496.986337,-463.572513,-440.102584,-440.366361,-382.794082,-320.30931,-197.225014,-129.724554,-66.436091,176.746322,308.185703,439.748246,412.870985,234.691852,132.021191,-52.557111,-131.78756,-101.394966,56.895371,130.99398,172.975358,170.511843,181.94691,161.433987,167.286187,217.391924,222.804862,218.321285,238.215377,299.809947,292.394111,173.509915,109.191375,115.159675,118.789472,111.779566,104.425822,104.433271,68.993901,-19.724704,-30.539197,11.837524,9.550279,-44.768792,-74.859296,-148.824035,-174.247451,-136.909165,28.705945,129.266466,269.023118,301.773404,333.453197,336.746026,310.423874,227.393828,170.851052,81.212921,75.4183,125.743114,146.095886,193.013779,235.545557,267.308832,254.857326,259.284679,230.364888,223.120219,267.817175,285.969798,256.293335,140.452496,80.622235,19.937097,26.216458,71.811626,84.583512,80.895528,77.182469,80.311877,113.919282,130.487495,146.872046,166.991439,203.741184,172.02695,10.898981,-88.948702,-74.444485,3.984336,36.037337,112.09764,147.904975,146.363116,114.858934,29.125627,-24.466786,-5.946567,103.795129,161.243365,201.17317,168.072592,5.649354,-133.702467,-129.004368,-16.161535,54.607515,183.111966,222.725883,225.833838,201.816084,128.462541,100.411978,120.643379,139.664091,117.137458,33.060824,-12.778201,-94.581808,-151.84413,-153.120714,-81.414081,1.30037,218.97911,291.815576,297.307683,250.563864,140.601893,107.369335,110.283276,88.416328,57.977336,-27.437304,-56.102342,-66.518793,-80.293046,-67.156778,-21.283596,-32.272382,-108.114482,-135.376009,-111.198396,-95.078339,-157.875495,-182.77055,-176.318203,-244.841639,-275.978024,-234.095881,-192.486396,-150.216873,-157.790434,-154.44148,-126.861601,-106.062384,-31.000163,-2.631284,-7.184457,-27.501355,-72.179278,-47.822883,-13.392135,14.38701,-10.282467,-99.743431,-128.105054,-161.952241,-241.036095,-260.591427,-223.170941,-184.895068,-100.042854,-67.03586,-42.568865,-55.040657,-91.04379,-55.880777,-41.169753,-76.511714,-88.708877,-53.499485,-48.388861,-125.632105,-174.721106,-143.817845,-60.160314,-33.497794,-14.174248,-40.478047,-165.900157,-255.018087,-443.50562,-425.83421,-306.248708,-41.314945,36.470558,38.889707,-14.389509,-96.959786,-64.498102,-31.455673,2.556468,0.148966,-3.10082,2.164195,-1.522091,-8.613711,2.398876,27.486147,37.567549,34.088915,-4.756704,-157.995322,-210.337485,-153.161036,-26.537867,35.793546,193.889495,240.915863,188.953983,141.365242,125.035762,132.44993,47.081557,-93.71069,-98.272225,18.990315,78.560648,33.279513,-59.587945,-162.794834,-92.294138,-36.880397,48.532873,66.430724,79.159106,90.006162,100.634953,79.091694,-7.398612,-33.682618,-14.530748,39.971313,92.732256,227.480412,259.169965,217.866046,183.987145,218.963644,326.503214,361.514585,381.544162,377.915606,385.80946,374.11753,245.254106,162.533292,214.62759,391.939051,430.673439,358.698526,300.924296,201.890164,77.441217,39.091112,59.389879,97.692826,171.61237,181.584238,132.120645,104.136032,86.034092,88.034078,86.869741,127.270688,181.338627,238.51932,205.468829,92.498274,73.458141,130.567747,252.592908,261.636072,215.686142,192.612075,192.839516,220.850476,292.78489,317.663807,289.302813,196.564722,184.259642,228.625785,222.824745,98.980832,17.756616,41.942853,119.319332,135.848408,133.531456,109.305326,7.704999,-28.092468,-11.248968,-3.546637,-35.709487,-124.22214,-173.257624,-320.525205,-373.234529,-313.655651,-206.807276,-183.217017,-169.481691,-172.129782,-197.4425,-229.681916,-335.456375,-380.830642,-333.703983,-173.407097,-148.967964,-150.395295,-104.34461,6.367762,15.128438,-44.235925,-160.759332,-209.838091,-240.322412,-220.831076,-119.768627,-69.01179,-65.171071,-105.81512,-170.821485,-165.901352,-157.730753,-91.414313,-13.789028,106.461493,105.543412,35.121878,-18.555075,-0.615994,67.17619,64.796046,-6.533167,-48.40431,-88.993918,-88.869842:6.428733,-69.960153,-52.578442,71.302832,140.963964,162.726342,122.69626,55.259817,108.560654,183.406027,296.676469,300.496794,272.095768,259.125037,195.516072,140.686977,17.857293,-50.263199,-66.68759,-90.683566,-75.416865,-16.264796,-13.333606,-84.460093,-164.842879,-159.239156,-88.58397,-65.94,-53.519991,-72.004562,-158.690864,-176.401824,-97.609281,17.261575,39.655573,64.5466,108.362909,198.530497,203.277466,129.343076,60.243761,67.451148,75.208077,40.862933,-35.225914,-68.10262,-213.314706,-312.882944,-382.204493,-265.124967,-239.014914,-277.616688,-272.849522,-257.019937,-273.655311,-240.784738,-108.174737,-31.850937,200.219193,349.692607,505.043271,447.399696,200.946496,103.489396,-9.268552,-8.226911,42.212649,139.384941,145.048156,99.935832,91.785163,91.069407,62.678526,89.286001,240.222821,325.567816,421.176078,408.032866,334.135644,316.188843,296.255909,238.312705,190.751065,87.306612,58.215711,58.223646,53.645905,-13.421102,-51.290707,-36.417268,-3.689496,-5.19266,-18.238728,-30.336383,-101.99753,-148.34591,-134.088133,99.740358,232.136426,374.160972,375.135895,356.12779,390.905394,433.165407,286.634539,223.492529,225.594797,261.203223,286.219084,261.486439,245.22113,282.14985,373.799941,419.214332,418.789558,325.389696,244.451547,151.225922,167.512827,182.854337,35.743517,-36.643449,-94.942925,-96.887041,-93.936196,-100.278808,-84.952937,-56.955051,-35.626504,-35.788575,-26.964791,-10.445301,14.08902,96.664568,109.012924,33.768554,-31.08444,-21.781723,40.631571,68.996317,100.680251,102.274637,82.58617,72.973208,91.320368,133.103455,137.344958,164.069592,195.571966,205.145863,160.162035,24.033843,-86.703925,-114.739758,-103.155267,-72.418115,-30.492368,-36.561795,-54.229834,-54.22511,-51.69808,-37.67421,-26.493201,-8.900868,1.180891,16.693882,-8.682383,-127.142335,-156.910145,-119.84327,-31.453543,12.482694,130.778155,185.321624,180.591961,101.447279,-110.531122,-112.702162,-26.617946,87.854869,59.308064,-79.96932,-119.406965,-151.286208,-214.272229,-208.977131,-108.46858,-57.076662,15.017694,33.997759,-4.368414,-54.416059,-116.269515,-71.326034,-56.137495,-110.25483,-144.057009,-176.416577,-182.931656,-158.758773,-64.834036,-5.772349,75.51594,86.18697,63.68201,48.995503,38.236859,17.935299,-63.31836,-45.111429,-7.181294,0.951524,-16.775507,-42.734132,-62.794378,-103.167013,-102.488637,-106.819633,-178.339213,-217.239119,-180.981504,-112.348164,-17.259374,-22.437833,-63.182366,-92.865016,-117.44889,-111.64904,-75.202282,-55.727313,-69.318899,-71.774231,-39.430118,-6.999774,15.720102,-17.585482,-93.050543,-106.465573,-168.11903,-254.656491,-393.939844,-275.779948,-174.159849,-8.192494,55.290063,103.764069,65.189535,-61.272398,-34.879045,26.857102,97.18583,106.200067,111.978646,100.350545,62.98626,44.039486,37.457088,75.018201,88.705347,93.498596,67.815168,-45.765116,-92.000975,-78.316502,23.989385,72.233433,156.461011,181.458991,159.772117,147.102399,199.462824,210.650401,66.462801,-118.208405,-136.148181,-45.787481,5.937695,25.146198,-14.9313,-144.292726,-198.271607,-167.671639,-46.935445,22.466929,124.940205,131.509791,71.478976,28.735767,-13.701334,29.033155,43.076543,76.428292,130.620611,281.701176,344.053976,358.413407,298.249273,323.457164,438.340428,447.317924,365.242607,354.709635,443.044511,460.363679,374.547784,376.273329,423.176885,495.913463,507.047162,447.798371,387.331175,271.203853,187.81454,147.475653,53.56312,36.626914,115.575791,151.475572,115.606484,77.544876,44.919585,40.164839,18.130344,7.813378,47.588566,33.180527,-65.286083,-199.734877,-32.804143,72.603151,102.487319,62.346015,15.462739,-12.764743,-94.646454,-92.216041,44.297643,168.175259,173.439364,134.618199,128.933164,121.74077,93.172946,-13.092694,-79.148268,-63.82596,-11.219558,-4.397845,-16.753604,-24.725089,-18.998254,-26.481835,-110.98862,-154.331135,-147.480801,-139.794787,-143.265657,-188.259685,-226.398644,-255.498941,-230.664998,-228.551363,-213.450312,-172.119679,-93.98559,-114.572049,-260.826786,-313.536825,-228.147529,-30.178737,3.492698,-29.088932,-47.726115,-93.370045,-113.415733,-149.24417,-237.163379,-273.592273,-240.269591,-178.360939,-81.369629,-74.572454,-99.383129,-110.117281,-105.976833,-85.727174,-86.697885,-25.554441,37.957963,60.651372,9.74482,-87.472736,-140.392482,-142.046521,-99.472765,-86.414747,-140.561635,-201.370216,-302.482577,-326.760305:156.523312,210.350128,265.65573,379.006467,403.781343,288.015832,172.193944,-6.460773,34.575925,106.931041,194.822368,220.221543,268.454393,246.147827,89.51927,3.228868,-93.756962,-39.652964,3.219336,-0.083591,-8.165757,62.935327,96.531831,52.163412,-31.724283,-41.003986,-42.281564,-47.226916,-56.718939,-72.367394,-103.318711,-99.427995,-61.935894,26.745988,100.222621,250.997896,302.701861,287.923032,222.232961,103.743786,72.837621,59.82014,44.272011,61.820257,63.279671,17.597281,-140.528988,-258.84932,-439.714575,-304.726324,-193.092647,-112.080115,-137.770342,-207.693815,-209.168916,-126.943002,-34.361266,20.748473,231.727368,362.632652,473.802179,408.06268,196.955265,133.093548,46.839535,-50.057402,-59.99,6.349123,37.048155,15.960908,-19.182396,-75.824632,-24.32943,50.91046,211.498298,273.507224,317.721349,296.716003,245.069267,230.586057,178.853012,54.803747,-2.808969,-27.211012,-0.836524,56.345996,46.999982,-96.54085,-201.86506,-170.403442,-54.026622,-36.009951,-106.792079,-151.004127,-164.673027,-155.437609,-132.638922,10.981331,129.418058,321.643784,334.81103,232.139075,186.624215,141.728497,104.191346,89.486073,92.412471,114.16357,140.608554,133.944426,154.90408,176.889072,169.122608,192.333869,235.02536,252.228155,191.170156,32.749364,10.642298,50.399256,11.338659,-46.08924,-168.835822,-189.413603,-157.915297,-161.886073,-219.548023,-243.414751,-258.369119,-204.296515,-181.232837,-186.646795,-177.487554,-87.533566,-38.119256,-14.608917,-44.682399,-33.838635,22.872239,45.279275,49.840342,34.218071,6.542527,12.178404,55.025585,105.9758,137.066894,190.558954,187.646645,83.962929,5.553969,-124.405654,-200.966794,-228.528782,-211.267218,-142.141731,-36.435374,-69.329908,-163.249053,-153.183146,-89.582935,-104.868916,-136.970508,-138.457629,-102.918472,-92.520258,-135.113817,-212.149774,-145.469495,-76.884195,29.973246,82.812179,160.563698,135.228473,25.342974,3.550734,-41.482887,-129.114919,-116.217218,-8.475436,5.888673,-86.997699,-131.620078,-143.284222,-136.604543,-121.970398,-16.163506,68.686111,214.319868,231.524781,133.296034,55.962849,5.961965,123.551191,150.939315,95.035286,70.671994,56.589829,44.521601,22.860191,58.742816,87.544953,128.691439,152.803647,192.675497,169.681586,64.329446,42.658107,88.212198,59.952352,2.889589,-35.489077,2.78433,65.953434,53.642981,-58.53287,-165.149532,-155.176665,-22.905738,47.658464,72.653485,42.761592,26.642116,27.095062,0.730195,-5.316974,-18.001704,-33.205714,-19.36082,-4.259463,-12.204038,-63.763231,-62.055131,-4.104602,119.755423,138.304517,66.087953,-15.221032,-212.999493,-291.280946,-302.938766,-125.717473,-31.242536,85.86874,109.844998,90.270753,55.966782,-0.191587,22.72671,56.280473,73.238435,62.816627,92.532081,118.637772,93.511907,43.842789,-13.317601,48.0463,84.749846,105.655325,73.754099,-54.01894,-87.03428,-24.357845,33.915553,42.747576,147.823102,241.265515,330.857235,290.233212,149.516719,89.484052,2.222537,-13.406636,5.731861,104.071079,152.410134,106.11617,31.646901,-42.796259,-18.51682,5.51605,102.768828,163.675497,236.874456,251.288807,264.375187,231.401446,94.676424,90.609815,157.661492,331.467632,392.742938,418.749905,411.236928,395.620796,418.040899,470.830501,604.339784,634.772931,569.59923,512.889304,480.056184,483.190576,421.312629,417.735296,463.645274,527.029322,515.105264,407.575007,347.530236,287.778566,285.789566,276.403823,194.263688,155.81096,147.279851,142.413857,63.990101,13.970201,-11.269103,-0.576261,-14.538527,10.02933,50.763976,32.889686,-27.251894,-65.04129,20.875774,45.87185,34.967976,35.30305,77.693411,75.727258,6.913836,-12.763057,11.496449,64.001481,91.158891,122.608197,108.836732,20.530361,-17.581957,-23.078623,-4.351789,-5.584948,-1.514935,20.694524,45.026338,8.674943,-108.901305,-135.508258,-110.700282,-118.710235,-139.300867,-143.366177,-123.833864,-98.413866,-117.775904,-246.485073,-349.118597,-323.791872,-174.270717,-99.10855,-32.057406,-48.535287,-133.602368,-183.538615,-223.328386,-102.375706,-39.691784,41.06498,81.955579,119.813818,100.143379,-8.83379,-113.735356,-129.611916,-97.979944,-64.699191,-19.842072,-25.777539,-63.364546,-86.358341,-142.322536,-120.014368,-77.47016,-17.925416,-19.085054,-77.277001,-110.841173,-129.082422,-102.239278,-91.403341,-114.59005,-127.631235,-97.827559,-102.022541,-254.677469,-359.913779:-26.597868,-55.453459,-3.663121,68.091589,64.658132,12.52099,-5.286112,-3.688614,13.662248,42.517628,125.320998,166.248439,222.897366,214.028558,96.653473,11.02242,-135.707446,-186.100769,-183.64043,-154.698189,-119.178425,-57.655261,-67.679182,-132.86965,-142.052807,-113.231139,-57.241545,-60.154283,-71.430673,-61.654026,-90.736537,-129.585528,-164.447392,-119.854955,-66.107546,78.558334,122.824363,96.208906,68.5925,77.968769,114.390205,106.034132,13.378427,-36.606593,-84.736698,-109.873582,-253.035842,-371.991682,-549.825064,-472.816337,-386.057217,-268.661727,-234.35592,-168.477836,-136.357539,-62.165781,72.336889,174.545869,416.464992,525.51481,583.497536,506.715986,275.671879,170.694079,-12.285297,-99.576063,-77.817123,55.682426,112.788243,116.797055,101.194014,63.960305,-15.665861,-9.423009,93.945428,133.464773,130.365003,109.77887,92.628271,83.847673,25.849085,-25.230586,-46.029445,-76.724779,-69.861932,-29.617931,-10.292229,-10.060485,-76.634651,-96.744353,-60.317688,-23.613699,11.528544,-10.399107,-114.275059,-159.937152,-151.885331,-21.188836,40.867482,132.080521,185.089745,273.17426,275.567128,187.142541,89.810887,84.879468,108.212686,112.444184,136.383867,159.368641,242.991822,286.841924,281.111104,229.571797,223.913238,220.204997,206.451199,138.813239,117.812821,149.949748,131.041349,82.506336,-33.753194,-62.73511,11.408311,50.698675,-46.369202,-134.763153,-186.388913,-60.929106,-1.001012,26.69179,19.800149,30.341588,39.594187,13.266496,-47.681249,-66.628428,-52.799325,-9.994807,96.849906,100.537715,-25.025745,-84.185461,-72.756588,75.321308,154.367686,220.309712,211.961933,146.759856,101.922568,23.353367,-72.957436,-125.642951,-134.742239,-57.023328,187.268751,268.932063,212.560292,115.789933,30.732523,113.244972,126.529168,67.389705,48.062819,44.435457,16.736275,-128.822814,-230.75874,-210.906138,-79.807862,23.069176,272.819964,350.190402,321.570946,264.20146,165.128713,114.346019,118.971553,138.155693,111.852573,-33.56776,-95.906709,-102.797686,-54.948967,-25.086686,53.116861,85.125914,110.031869,99.427848,56.414976,19.313199,-86.37399,-66.354266,-18.483561,29.206474,39.204176,19.840782,-20.218068,-68.153281,19.735019,95.104643,180.803262,168.013089,106.004466,72.932624,-11.278475,-21.3526,79.456276,140.838362,114.344402,44.383721,37.60354,43.348153,21.065303,-73.969459,-163.461187,-195.395277,-217.387546,-183.219149,-62.283775,-47.980677,-132.036426,-159.812132,-115.085924,-31.830495,-6.707142,16.296805,27.709382,36.509328,14.863204,-84.380845,-134.997627,-110.564117,-13.409892,33.55469,66.359068,28.271632,-118.832198,-192.77613,-282.868478,-208.420048,-120.006711,12.962499,17.676746,-58.720748,-105.437316,-151.345736,-119.141695,-100.522724,-74.353878,-42.283946,68.389079,107.091851,85.316195,50.533568,28.272717,66.450095,80.362096,65.169502,24.597952,-112.52921,-163.4646,-162.268686,-93.995168,-41.188485,141.747675,242.123672,305.609077,250.427517,87.856241,30.714345,-11.473093,49.491209,98.488623,155.739219,162.572114,124.668231,86.423645,48.419894,61.714559,78.720946,132.069653,158.687575,202.202091,216.259167,207.462356,168.091367,62.963254,69.024024,106.869314,192.817898,241.191854,314.192752,325.545161,323.443901,353.276108,399.463028,486.23341,490.784599,475.88362,487.301144,481.902095,440.196527,339.868938,325.954121,351.79413,376.4588,350.291322,236.643403,178.341173,86.963244,-3.175461,-15.614137,51.825559,95.722798,107.637226,61.751329,-22.331162,-23.358453,-31.258784,-67.499213,-61.88655,26.334017,103.580198,200.667362,177.12667,52.695118,21.707262,65.411533,154.462156,179.799664,203.25888,179.443977,110.970063,108.363143,129.545025,88.931738,52.798707,41.339829,65.65765,65.973206,38.901852,11.75777,28.469025,53.517317,97.405882,101.595699,87.949296,46.650194,-103.931414,-154.630373,-156.240885,-193.286532,-238.003707,-255.826816,-226.499355,-205.15912,-216.74025,-225.267273,-268.659606,-285.654245,-238.956692,-213.448324,-245.196958,-278.646316,-294.807417,-284.934699,-269.142397,-194.36907,-134.48549,-6.610021,42.535275,84.937746,95.87738,77.004715,-71.701246,-138.66478,-125.392892,-63.236462,59.852097,85.999665,27.694676,-48.123349,-175.222222,-140.833065,-94.579485,-26.343081,4.218859,43.650538,47.722299,29.65658,-3.258799,14.958228,52.237417,31.110685,-38.468439,-70.954552,-171.666419,-245.116031:-15.726956,77.292217,147.5512,280.895579,303.607364,147.110784,11.236951,-147.877759,-74.619735,4.547056,138.656058,192.081115,243.026037,204.913274,14.929926,-104.631757,-269.951769,-246.067336,-203.190084,-148.239721,-139.817241,-128.885728,-134.333621,-200.014071,-238.97825,-213.352661,-157.098285,-160.014595,-175.965353,-178.725393,-218.235377,-237.420132,-205.545543,-115.58426,-54.73389,88.111685,138.784361,123.498443,76.417945,6.738423,-22.152047,-25.792125,10.04199,26.329413,-5.618659,-51.455885,-211.98747,-332.553697,-537.256177,-481.61335,-374.191854,-211.506723,-202.39464,-246.181963,-234.019729,-138.406779,-43.522814,35.794494,302.14193,440.083322,535.328819,453.723848,161.693832,41.601279,-88.71521,-128.250744,-114.717244,-29.05248,6.151936,-19.8896,-51.253342,-96.337048,-126.476706,-109.164874,32.29597,132.372193,220.384096,167.685943,-22.354769,-97.556076,-164.475016,-105.53445,-48.193495,16.69973,13.226545,5.6019,10.485744,-66.730855,-196.313881,-193.503609,-87.540021,-49.69149,-99.58247,-169.7943,-257.730957,-249.543139,-156.319311,-5.458365,67.869667,184.549828,221.956825,232.680649,206.155319,92.047906,-35.858535,-54.768121,8.432643,71.428818,154.366808,125.793151,-9.183467,-47.341849,-21.396953,64.400433,111.361095,140.553001,91.711556,-59.311785,-76.12866,17.699466,2.666219,-42.472915,-55.577009,-22.50388,2.524549,-50.279321,-245.741676,-321.024569,-318.603295,-205.351556,-168.800977,-124.89161,-85.334998,-14.55759,-22.345658,-113.267445,-130.065237,-84.127772,11.767584,43.495,33.882557,-27.435009,-163.755907,-181.962611,-121.88127,-20.667309,51.004893,209.877034,235.356159,120.228181,38.61775,-67.046889,-119.437888,-114.914274,-40.033423,-0.967584,23.567907,17.336556,15.102311,22.705409,34.31037,-13.894322,-55.710489,-53.268044,-16.750959,-46.821026,-125.619534,-288.229591,-291.632311,-225.148786,-81.897949,-18.367126,109.019587,132.176548,51.460491,-18.087066,-113.846715,-67.388124,2.533673,124.779424,125.417645,-3.930967,-73.244039,-127.419993,-107.774744,-58.720699,85.796252,132.765519,128.982849,99.733889,47.851235,18.317222,-18.542851,70.675647,132.963364,214.712077,220.256965,131.501954,64.426485,17.745823,159.108859,245.616422,273.709327,244.935093,260.940507,271.49718,170.622531,96.01408,56.119495,148.03124,195.129334,258.226817,266.04012,176.137414,84.205903,-84.798361,-110.010246,-81.004548,3.98568,62.463911,149.170691,147.18326,70.062441,20.508675,-44.675306,-31.108751,15.301722,135.46086,139.091689,20.556552,-39.927655,-117.604272,-90.008356,-15.318079,167.071421,225.004445,202.069916,123.6777,-81.886675,-176.265899,-237.858594,-55.191028,56.41287,137.687462,111.036487,52.549781,36.879647,-39.376429,-106.693507,-73.10716,60.792635,96.643436,89.525787,71.305493,16.066617,-17.534503,-43.729157,56.39761,129.315375,181.373905,145.806007,13.536228,-52.967876,-131.759433,-50.41021,43.008753,221.120526,276.006632,278.383081,233.631667,99.596766,22.864427,-57.176261,38.562837,122.337855,257.283895,270.959136,177.538941,109.104268,18.099107,30.916822,85.224281,214.469161,246.991511,245.940055,241.067014,215.249255,154.719737,17.122255,71.597985,149.634161,293.531939,336.084024,359.722727,362.79205,367.154102,372.35186,393.05628,499.66223,560.017951,555.559889,501.702967,421.064676,394.210529,315.090419,283.221119,314.765402,397.078358,399.789795,293.266151,225.169566,141.619398,89.565628,74.859179,110.685125,168.116932,232.972149,189.945677,56.550241,17.796835,-1.59122,-1.779314,-1.776459,65.67725,128.597022,176.397325,152.237431,104.17012,124.648545,175.641387,292.051212,314.514741,263.757761,194.324748,38.986986,0.474313,40.397451,126.288796,140.6833,111.549889,75.65445,11.593794,6.334878,10.224271,24.991008,58.825447,89.416027,70.707185,52.560444,52.283032,-14.065593,-74.840619,-149.794146,-144.587175,-138.412681,-105.796584,-79.505722,-82.656288,-118.670503,-214.638725,-272.876497,-251.387349,-110.319492,-37.265444,-19.623121,-75.617121,-188.822867,-213.289192,-193.830551,-74.769815,4.934256,138.417771,174.620493,167.695587,136.569789,47.260239,-16.051483,-14.271929,39.654416,89.002973,142.583596,95.528584,-88.427658,-161.392773,-155.691497,3.157498,57.139222,74.406286,71.065448,57.999077,48.910877,26.367986,-19.746004,-44.525206,-81.062849,-67.651316,-7.11728,-28.667179,-205.452388,-290.959106:-305.46114,-310.437547,-266.062363,-195.385378,-181.877674,-184.25002,-189.339734,-171.992706,-89.989202,-34.210724,44.934873,72.313447,148.231384,175.690824,112.955975,12.347191,-206.794387,-252.55052,-233.599416,-197.521685,-163.866942,-104.660112,-137.504493,-319.922619,-346.047493,-240.984294,-34.003394,-16.865685,-91.815098,-121.097751,-127.979039,-133.52259,-172.908515,-206.738525,-207.761434,-151.876351,-97.372409,3.500451,24.768736,-2.091123,-44.108307,-41.408056,-31.879034,-47.323732,-77.319069,-73.197009,-112.841284,-195.882691,-403.214415,-441.461641,-397.898774,-290.048498,-223.862701,-96.394294,-56.889923,25.653242,140.192693,208.951181,372.625863,428.257581,396.822613,326.795626,198.721453,146.055241,-8.428939,-82.54332,-35.852261,98.966776,134.532079,138.550454,135.761048,150.00506,146.396164,130.568781,105.076788,101.800481,89.680479,81.764751,91.136058,78.280827,-35.958688,-52.871026,-3.517986,57.957221,65.193727,75.83331,73.543657,51.255556,29.454218,23.213151,17.984381,28.833823,40.453844,-7.344129,-132.1483,-122.935971,2.667389,100.315435,134.13346,217.189941,279.928725,366.988074,338.599683,176.367606,62.84407,34.802862,-5.60109,-3.609405,38.469485,60.608007,141.558095,188.483337,178.217905,135.736529,139.425291,147.394891,176.169438,249.344439,254.5732,233.202327,186.076194,155.213245,119.571105,108.506599,83.869235,82.738825,69.792047,33.733084,-49.045806,-8.849555,26.57899,14.595751,16.091277,104.544127,112.093719,-48.926845,-184.614126,-165.613938,-51.975144,-13.554756,0.44173,-29.955252,-136.116287,-157.4255,-77.500066,82.407804,156.001641,248.880784,272.407256,241.212877,173.925675,26.100409,-43.616461,-48.507389,2.859766,54.466721,213.241305,289.035221,330.524678,300.919918,223.59959,223.180991,230.752209,178.441864,133.987916,57.261297,30.96591,-12.479894,-80.188774,-108.316913,-73.939962,24.940034,245.103206,250.918399,116.595154,93.737758,149.477381,168.281156,164.847619,110.915067,50.167578,-46.519283,-42.158173,-23.341804,-107.336593,-112.024044,-2.090511,39.704766,-0.596624,-59.125432,-157.427796,-185.23083,-219.92709,-179.504843,-138.151948,-130.974417,-162.001727,-172.285895,-140.883253,-73.797709,-66.997053,-76.858269,-80.839754,-73.178907,-45.958017,-22.805521,37.135525,51.021936,12.837795,12.59624,62.201151,203.688709,237.239595,126.063215,27.603423,-117.219769,-165.236413,-141.30541,-66.138516,-48.90397,-56.761104,-60.580456,-21.648737,2.384851,-8.473766,-14.88033,11.364858,43.969745,27.700034,-58.731085,-97.989958,-113.660937,-101.829969,-82.26732,-10.605833,31.26816,78.57249,37.319905,-142.519132,-218.300338,-295.300689,-291.219093,-263.88906,-170.884989,-128.983416,-136.455889,-184.546658,-265.400997,-243.432866,-206.42133,-93.949501,-30.831617,13.290348,-16.788081,-39.62092,11.939679,126.543512,88.549769,49.014311,16.684058,4.685318,-42.430512,-53.099252,-13.573687,44.432368,85.846819,227.469289,286.075816,268.130966,210.993797,127.195734,106.208924,45.020773,-20.475203,-28.171364,13.189256,35.355118,27.441101,5.770312,-37.137862,-40.778397,-17.060926,25.222291,42.791018,126.184122,174.924373,189.808287,138.78711,-8.719629,-61.812949,-49.887912,32.081557,106.630968,182.334981,133.295958,-1.826897,32.774016,106.350904,208.932419,227.964204,276.355482,297.601692,312.744287,313.631937,258.599463,166.192331,160.905974,232.435872,263.093352,225.767716,176.064302,66.124894,-64.892596,-92.31882,8.981771,95.928526,161.745117,121.823523,42.226992,35.228776,25.539023,58.781065,113.594936,266.928971,338.169253,376.146765,333.910953,206.330337,143.796942,178.052862,283.227982,281.152416,213.122162,190.90955,185.239893,213.967115,304.889057,275.343877,194.791817,56.065572,54.035008,130.818763,154.133578,109.798382,45.641947,53.525518,141.515157,198.855899,252.558189,204.863272,14.992708,-53.701974,-114.097062,-174.072318,-203.297601,-232.512581,-236.668326,-265.495056,-286.306274,-274.157917,-145.373097,-78.455241,-92.593896,-156.983626,-221.382631,-216.00053,-251.918905,-288.065464,-274.302641,-126.878517,-53.153365,36.017378,83.397612,200.521147,229.072337,156.305361,-88.664716,-199.369843,-203.439833,-120.3037,31.626676,65.916984,39.194494,-20.300396,-140.674792,-145.338023,-117.119203,-22.433216,38.490452,109.282984,101.765578,32.180701,-21.921803,-0.914504,97.366256,112.363729,32.861888,-24.321412,-98.780978,-121.731973:-305.491326,-205.715439,-115.024462,-5.676419,-5.230594,-81.726081,-137.931024,-225.344341,-167.962442,-80.400712,70.085308,118.709169,208.405177,208.054759,31.163035,-94.626003,-257.593694,-282.41997,-263.097716,-147.404136,-73.915981,-80.526464,-178.983658,-386.600681,-402.07025,-332.283883,-180.115241,-143.889166,-130.479355,-140.768865,-211.073091,-260.933171,-333.313511,-340.281109,-303.831128,-134.258213,-47.686526,-5.18348,-44.891251,-137.309748,-117.494962,-90.428354,-106.928388,-124.427663,-109.853355,-110.291055,-233.329562,-355.024229,-568.123565,-523.213389,-438.792914,-260.330885,-156.666932,5.193836,16.552379,-47.917395,-10.642146,78.387339,315.782781,414.002289,458.28113,395.04756,175.595244,54.590481,-122.273824,-58.629083,37.902791,168.903181,172.905802,73.054512,14.254803,-37.121092,-74.628157,-81.152781,15.309768,79.491911,79.441912,36.006783,-32.066629,-74.379893,-165.01893,-135.266587,-91.297193,-28.959414,-9.451021,26.793416,42.34111,38.052774,-5.101623,-5.1354,58.149634,97.804246,128.023338,104.556713,10.060366,-35.469465,-33.091288,135.547658,202.908481,218.603055,216.768855,226.300599,200.664697,74.890546,1.737023,18.592748,85.269814,111.913133,147.89428,159.46175,165.312129,137.122816,40.006708,81.887503,151.554963,232.998456,228.868419,171.143962,134.102319,84.316245,68.150345,69.271394,90.437612,106.932112,110.428586,80.330565,-51.535039,-134.010203,-234.560863,-150.658186,-65.821053,49.478898,66.418469,34.548367,-4.433468,-95.275876,-121.467794,-71.158187,47.486015,52.673837,-48.640762,-121.796802,-247.593777,-280.534789,-234.645627,-33.267508,73.185048,175.601639,175.413092,89.960665,13.219873,-77.319125,-15.479944,26.427775,78.737535,110.854356,216.755918,251.897997,227.099859,186.764815,96.187493,64.710645,76.082286,114.154137,138.138329,117.57039,42.088151,-136.769703,-156.391194,-104.824669,0.555398,45.539778,161.857351,202.388258,159.812192,102.545969,53.364712,96.546727,100.335028,83.871118,89.679818,67.083925,21.178747,-79.875903,-95.622129,-38.057665,159.469012,226.712811,191.875554,129.551618,65.144276,51.551082,-19.669249,-26.210185,31.748921,175.482229,199.449552,67.856567,-41.31461,-139.83267,-27.450836,61.553143,194.711653,216.957143,188.411269,145.385207,24.502302,-23.626055,-16.827347,132.199435,214.35305,312.795475,317.805208,218.745752,133.185624,-47.089962,-177.235293,-188.576528,-126.708668,-86.092089,-26.107882,-23.30177,-78.147997,-112.051175,-130.832786,-53.216839,10.609986,134.113932,153.5769,78.432835,15.489125,-105.791701,-130.194797,-74.163014,120.237063,222.648711,311.371175,249.221809,-1.259762,-111.187884,-207.869867,-155.367288,-104.897934,-33.458754,-22.317223,-22.387121,-40.627001,-150.81282,-215.623076,-176.48445,-34.139577,27.195266,60.933215,23.980422,-19.030019,12.069921,53.828267,34.649544,57.308621,158.235039,171.277095,38.090714,-52.796567,-138.594527,-93.827683,-35.17723,131.116638,203.818347,213.581174,156.814984,50.400663,20.819999,-32.630205,-29.708604,11.026309,110.285003,140.675795,121.958223,80.458197,8.372227,-11.380696,1.646473,99.531707,169.00038,240.792153,212.856401,46.890098,-39.14918,-80.067619,14.378854,46.013365,117.242582,187.785846,250.254473,196.85235,58.398057,43.098986,83.242623,228.18751,312.287258,431.481662,436.547846,336.36527,265.831226,166.705016,138.542492,127.490191,117.144608,124.771652,107.573626,71.729559,-21.708134,-84.654796,-55.443277,120.713409,196.943607,199.403936,143.30597,43.978609,17.601346,-32.843083,-22.133481,28.622226,155.960683,213.500206,245.239939,205.15501,104.664063,102.684166,149.700885,261.402395,292.995493,255.844995,187.987796,79.857838,67.961693,87.672559,158.516866,181.595461,143.608623,98.033445,4.566871,-36.145104,-72.641335,1.283339,63.36127,147.861098,161.165601,135.846633,84.510306,-79.683447,-151.283516,-226.975054,-237.15777,-207.647262,-92.227237,-55.605863,-114.29127,-173.478285,-214.89982,-155.998031,-119.489154,-99.920822,-108.343327,-97.867099,-103.948443,-203.089104,-253.804994,-219.558931,-55.085144,13.507129,144.079985,222.536409,293.279889,257.588227,75.006911,-133.322928,-157.472717,0.247119,114.767935,231.584681,204.174021,45.900644,-31.191217,-121.288608,-81.657494,-21.373092,92.311582,137.119882,202.975967,200.287427,75.848476,-48.266747,-37.584447,50.160325,76.936457,59.378287,1.801455,-167.904186,-238.777882:-186.546651,-275.868325,-296.240545,-259.314367,-220.522517,-175.205655,-175.442041,-197.555808,-229.945035,-218.508811,-110.886296,-37.844656,85.41894,120.522072,127.060568,92.305098,3.858759,30.207134,60.290617,60.043783,46.768815,26.210103,-1.300838,-106.867262,-205.604907,-211.240393,-136.561048,-107.012869,-110.233185,-109.90389,-90.329367,-101.7179,-173.108792,-207.99757,-223.534116,-291.926574,-295.38755,-161.079562,-78.194308,-18.831258,34.248872,84.126673,68.178325,23.708174,78.214289,151.411699,174.119818,108.510831,-54.414542,-96.365778,-65.362067,40.685019,104.62058,234.424584,275.449047,276.990609,221.792216,215.611121,260.821726,262.584062,169.082459,125.591756,132.932762,138.696379,39.012904,-41.733617,-9.238048,128.441314,197.148983,288.419386,296.954477,249.277046,162.149846,117.524881,82.359839,97.32327,112.298293,69.416522,-72.795633,-115.629171,-105.597344,4.135961,53.025658,37.336641,28.71708,102.88965,115.53945,43.240484,64.083635,122.525676,196.446089,193.471471,180.543095,184.915667,203.999323,218.984912,251.508748,291.421317,314.301003,344.904783,370.785118,445.734976,456.686633,348.803915,143.392425,74.0333,19.371896,17.832307,103.488486,164.655335,182.451146,157.198623,152.362192,208.508623,231.119515,261.999837,295.964727,362.502052,371.161635,362.907739,317.029978,298.212788,310.94463,329.667804,335.113655,294.684292,122.68695,51.860197,83.737551,191.671896,187.104862,121.644155,122.243382,160.399615,138.312656,-2.978798,-134.894003,-135.047781,-36.234154,-10.329267,-68.608636,-130.11594,-199.49818,-165.667526,-6.913567,143.245406,179.614131,173.490525,176.427502,229.00427,219.301878,95.541076,25.668705,32.992016,68.974323,82.595455,132.93751,172.926048,206.420031,164.620417,0.053254,19.904703,123.412045,222.174387,170.169387,59.810637,64.186095,115.346242,35.768085,-14.909362,-14.580319,17.360378,47.743487,32.263771,11.280302,28.189619,60.089348,26.535901,-15.000778,-115.138082,-148.893931,-184.61688,-193.287752,-170.412223,-153.449052,-146.569364,-113.36982,-103.833532,-129.013085,-170.815125,-251.679409,-266.251476,-302.501606,-310.835133,-277.109162,-229.413694,-219.207681,-169.258028,-146.985916,-153.025042,-172.588285,-168.466225,-190.359966,-217.237294,-184.456184,-122.047626,-22.540915,-24.713588,-130.52913,-142.802607,-66.721119,144.296304,206.238536,129.432264,39.561568,-93.769708,-170.845154,-173.255414,-84.165334,-23.243942,53.407278,56.975309,-4.866044,-38.413576,-29.903891,4.221517,-11.071715,-90.624331,-116.189979,-123.183622,-137.489553,-203.710154,-209.551387,-151.499521,-28.117051,-41.420856,-212.276877,-296.908442,-355.374167,-353.237111,-378.596361,-385.524354,-367.818971,-380.304382,-396.606138,-327.759924,-263.793461,-259.501977,-378.124062,-390.412939,-272.60676,-189.887292,-80.640058,-63.658132,-32.10562,14.969852,79.484906,62.545345,91.827094,182.576459,177.624798,65.939283,21.14543,61.532864,164.480523,193.987564,211.027178,190.731282,83.946939,20.479063,-66.860742,-90.913205,-145.035975,-180.502127,-172.707926,-140.52389,-130.104792,-150.435124,-169.043286,-144.591873,-94.576054,-90.474766,-97.789863,-99.14416,-89.865685,-85.881911,-87.916335,-94.161626,-160.589132,-271.794786,-286.724483,-193.824094,-131.575317,-110.309112,-146.454471,-224.062124,-234.369089,-209.789306,-145.563613,-89.125873,76.663833,133.983386,112.177438,54.379851,-56.41188,-107.34567,-117.22981,-88.550536,-41.910535,32.434113,42.626526,32.686108,-13.939642,-23.989831,19.507457,81.011284,263.67692,331.732847,310.894626,243.76189,162.637277,232.791578,277.248728,346.439745,397.474817,479.447123,456.423374,292.117857,146.911036,139.440736,198.168613,194.946853,127.139797,115.573869,153.289252,190.057452,279.23489,263.752969,179.504757,-9.996397,-33.963191,66.83955,109.919911,57.592569,1.488589,25.564491,81.710629,94.604077,109.559168,101.948982,73.193508,77.663356,85.217572,21.990178,-7.612705,-26.06087,-43.141112,-138.35898,-171.159052,-119.432793,-60.227137,-45.527135,1.73307,22.917139,33.405086,2.589482,-149.62841,-196.526432,-74.85811,109.223009,145.083758,207.254428,280.109418,440.347807,454.706771,287.633765,44.961252,-12.091113,4.151308,31.733981,81.708635,87.266612,15.876047,-40.819059,-122.364378,-151.250501,-164.063376,-157.527519,-125.224712,-77.804137,-85.599205,-120.694802,-154.435079,-153.511324,-91.517942,-61.608044,-42.902953,-51.824135,-104.194065,-134.062691:-197.831474,-244.288276,-215.54422,-175.11768,-171.108855,-113.118871,-65.496975,-39.196195,-85.795883,-82.255198,13.89461,83.68544,200.392883,205.815724,72.138315,-27.278489,-206.469029,-234.438512,-181.047948,-123.734784,-155.157011,-263.228048,-309.836572,-327.391887,-234.41619,-166.569811,-75.107179,-93.534139,-175.263112,-170.643841,-85.480244,-56.876877,-79.139008,-134.134803,-163.613403,-199.565549,-172.585982,-83.437062,-76.487848,-109.287771,-75.478204,-35.482026,21.197773,41.8837,132.72496,175.204096,140.639698,58.70713,-170.81693,-254.746639,-193.412843,-62.180295,-63.094075,-122.047972,-113.36395,-26.147932,-6.967399,-25.61744,19.467989,105.587309,261.803764,270.641147,177.124973,117.382116,12.050463,-34.153318,-14.723595,137.867321,239.018141,339.314471,341.954547,338.717565,273.814255,200.695871,57.067446,28.264179,46.891413,59.022401,84.780952,92.796769,34.357505,5.971009,34.722556,52.887347,42.342723,64.176547,74.007808,25.510673,-19.620476,2.272647,31.659596,-1.426109,-73.99456,-85.459879,-76.001696,-48.74103,43.912338,149.38625,200.953476,283.599921,315.574471,335.682499,313.576169,231.245132,141.303736,91.133477,-60.891534,-121.948516,-65.453113,7.078067,77.767561,84.555654,97.910424,129.174958,139.723309,168.519862,217.876967,336.493839,364.814614,367.231158,326.623818,305.110495,262.885275,242.601852,241.149549,261.176056,287.92324,252.910065,98.489923,45.711738,60.976232,106.993123,149.67328,173.945441,105.665758,-65.739815,-140.932654,-150.049999,-104.179514,-63.770288,16.461861,49.324315,85.228211,95.583239,72.277742,-1.079682,-16.361961,33.478971,85.699819,152.055926,131.902831,-26.146568,-207.725578,-219.783679,-54.722537,45.205303,142.468345,163.763029,191.627585,172.328014,66.510804,47.361546,94.35024,178.841424,170.65744,84.960373,55.647768,27.619092,-45.018748,-78.713384,-98.04451,-73.050211,49.277403,107.492749,132.450804,96.975358,-6.774052,-55.197387,-46.767293,32.224902,67.425184,7.044768,-78.550335,-188.925558,-124.616603,-83.869065,-107.112131,-159.143768,-231.153161,-236.58731,-228.678377,-239.77378,-317.769497,-362.415562,-359.318424,-388.414922,-415.978186,-423.640449,-384.326715,-250.392416,-212.725724,-251.317963,-350.095797,-355.742213,-233.520028,-166.633911,-124.931049,-126.115605,-118.646832,-42.739446,18.20798,115.513831,128.284883,29.837371,-52.827933,-163.778958,-191.744494,-171.212994,-103.311613,-77.382009,-43.421854,-51.39209,-118.85236,-135.01145,-60.144193,18.784289,-2.420233,-124.959904,-167.74101,-158.732365,-143.061054,-185.200193,-235.973624,-210.497601,-162.110273,-174.613402,-173.145244,-145.54324,-179.724584,-280.711957,-478.347248,-429.776345,-361.838265,-250.718051,-196.944414,-141.4181,-159.238428,-218.226627,-234.845102,-212.117281,-134.338857,-114.9664,-114.864172,-109.656464,-78.0295,-51.483331,26.203921,116.990812,148.935689,159.618041,126.372137,-33.025358,-101.727035,-55.632955,97.559648,137.476741,113.901091,79.834204,79.899445,109.092259,137.498001,124.675957,29.205035,-120.781015,-146.104725,-51.216583,-3.815262,-35.494346,-64.294531,-38.754522,-36.255937,-48.259555,-20.502508,-4.776208,-31.807236,-57.51301,-48.939109,-24.496496,-64.326722,-173.333596,-175.463457,-65.801645,-0.434086,59.181787,59.702506,68.539996,32.99324,-13.779345,-55.137874,-14.42442,144.008987,202.315876,195.495224,140.8967,11.029044,63.080309,173.967094,323.593111,297.774087,144.749566,82.076392,24.464265,-11.065876,-17.066152,34.310232,103.763759,278.727654,309.673495,209.699716,151.172008,136.912177,168.048434,186.006836,309.049168,380.885799,352.888127,278.129387,183.459298,141.703973,133.532025,164.874359,193.255252,243.846769,263.579843,327.457105,367.51446,381.63766,308.382467,256.91369,188.599576,197.983683,254.120624,261.031833,184.078112,47.161936,27.267824,134.461766,206.26984,244.049357,202.827881,128.293785,138.124256,157.022993,70.696457,23.861946,-27.142896,-49.494991,-113.214055,-124.92785,-90.683491,-92.342222,-97.735601,-91.211252,-93.087888,-108.79077,-130.243327,-195.577119,-211.400494,-151.693279,-12.5111,20.055483,-0.99955,4.755646,103.510246,178.880502,241.913873,11.475878,-113.64332,-122.756786,-60.14025,17.110772,30.968081,8.924926,-22.273979,-55.569391,-77.489023,-102.918434,-55.324345,43.225373,211.544365,218.213567,101.619768,-50.247538,-75.758997,-17.905888,15.978583,2.934083,-36.486596,-84.223846,-89.777072:-348.648289,-404.047789,-367.155899,-227.056466,-168.84793,-159.418,-191.294297,-210.452227,-218.142032,-212.05516,-81.313016,21.753102,173.504856,191.577284,133.01147,94.416395,70.101359,54.238486,11.748365,-59.908446,-52.354397,-27.670006,-50.372368,-198.279859,-340.126175,-318.821332,-159.119332,-107.092624,-103.904197,-113.411565,-130.229073,-164.380586,-259.222266,-259.954678,-232.300758,-188.177842,-164.070002,-117.498173,-100.750859,-37.462559,29.320431,34.815317,8.029353,0.09563,12.117298,9.453256,-59.496048,-121.716752,-207.37087,-169.933462,-139.988714,-59.966189,10.611422,171.422455,232.366846,278.935985,289.144085,318.47974,374.828598,367.124197,279.086413,229.81085,209.838337,217.513138,120.536402,14.124611,29.362914,104.363317,115.586691,58.962978,16.30547,-5.720361,54.971977,59.676239,-3.063392,-15.372947,40.628762,68.455487,67.902911,36.774576,-80.349287,-107.088856,-48.624804,57.95038,62.808184,88.904924,142.110452,218.911732,153.270539,96.586568,56.099539,101.543329,250.588303,274.015239,210.839304,200.741266,226.942972,224.353853,230.444218,281.938861,345.435454,469.261724,444.872697,188.000691,-11.405117,-5.971521,55.507301,65.643828,124.507394,180.071433,243.323461,236.287418,164.508055,131.397216,160.979051,236.302547,258.683863,219.857416,169.528375,124.832781,149.600533,170.311753,194.668868,191.331305,202.344734,203.552412,107.534563,30.519058,-57.22198,1.216527,46.816698,85.226167,91.812424,101.632771,79.651159,-38.981361,-179.93151,-210.628477,-140.785164,-68.689495,6.419678,-33.322341,-162.043609,-161.660098,-43.497903,69.898131,147.149775,317.957921,349.180165,253.636497,173.49321,88.310246,97.261399,106.925722,118.375187,151.456893,321.562,383.942491,305.580683,222.43824,136.511336,134.549998,136.524444,118.29085,111.408371,126.095642,138.808622,130.153145,67.241086,30.794615,-7.569382,37.116481,176.652682,167.282951,56.991506,70.659559,191.513669,214.161801,193.599131,84.264296,2.057759,-91.763409,-76.327404,-28.796928,-55.097219,-54.836752,6.612695,29.026682,0.168568,-37.817022,-85.226733,-79.619351,-84.633414,-152.33414,-177.497861,-146.692278,-99.082601,-93.279259,-153.234549,-242.757145,-199.952446,-141.880633,-15.723426,12.73281,-48.577009,-107.328058,-136.377644,-94.964339,2.859927,101.822416,162.347575,242.109517,233.64955,73.703526,-47.631518,-188.851857,-199.874355,-196.280808,-144.74383,-100.72063,-48.1597,-61.92157,-113.671344,-115.054872,-100.470077,-74.163118,-30.908988,42.294945,32.537724,-72.342161,-143.831438,-280.679091,-267.678301,-177.874593,-18.630092,-8.892168,-44.61506,-56.710939,-120.529663,-183.423814,-266.621271,-175.415854,-108.258322,-80.844014,-117.14887,-179.574985,-173.480562,-124.8697,-153.926338,-190.99294,-239.766541,-227.185295,-147.177536,-113.39418,-35.857681,19.063252,48.978255,-24.416815,-22.107432,74.679281,99.746625,12.399307,-44.251286,-40.58534,15.112271,53.366719,184.364682,210.037667,120.960765,68.186939,-5.715148,-36.991496,-48.083725,-17.452997,-37.568044,-107.518696,-87.144804,3.735535,-1.321233,-70.000089,-84.649739,-66.541221,2.456778,27.608092,24.43082,14.875518,3.949856,-22.651754,-113.581437,-131.506467,-119.203913,-72.778416,-22.975197,45.238731,24.459323,-66.283183,-106.269192,-85.35326,1.695952,50.793207,135.200927,144.462408,134.263028,131.264915,47.067557,-32.720005,-23.672414,-4.880351,-14.809399,-32.495586,-32.299079,-36.694864,-17.840502,17.689766,86.53641,93.401273,103.678497,130.663825,174.833123,159.364268,72.748019,85.423575,149.832632,279.291702,312.05825,291.476002,247.226711,164.187247,136.10298,154.643728,222.734432,241.454004,228.8553,200.738183,126.031416,95.277175,85.430965,159.05063,173.058781,83.244791,41.78271,93.065906,147.441601,159.646731,72.931203,57.223895,111.006084,129.63607,77.969606,42.126812,6.310721,-10.491791,-62.419131,-73.443196,-56.957293,-22.484641,-23.048979,-123.426802,-196.698674,-214.142217,-63.394024,-0.527687,-8.475661,-42.943179,-36.05222,-19.92325,-66.142092,-95.511055,-52.757308,21.937059,26.872017,93.182636,195.589649,376.318764,359.633574,135.848436,-59.899542,-74.666966,36.082704,103.565068,149.827617,119.817584,21.820861,-17.662445,-124.276601,-212.583119,-189.30831,-60.72183,-22.913377,-54.564732,-81.609091,-94.388325,-133.126835,-132.907467,-36.040994,14.242595,34.607221,-8.802708,-155.028263,-212.342349:backward
92.925278,117.917477,166.907815,273.498619,260.260424,58.761064,-63.769275,-211.188396,-220.499919,-180.407427,-75.269374,-33.689628,22.616484,39.994123,45.704049,16.805414,-72.524364,-72.428744,-38.710372,3.917792,-38.576287,-237.049322,-310.335882,-321.660956,-298.513648,-307.748361,-313.568975,-296.51529,-273.907991,-266.326476,-235.915268,-241.183125,-264.331177,-163.813162,-96.601843,-70.911745,-89.946984,-21.603939,46.817285,54.8213,-9.297198,4.815502,66.920157,81.93493,62.416781,32.105186,-35.777526,-42.224364,52.390416,132.927706,87.885326,-113.585908,-205.806825,-264.311928,-225.265765,-122.337061,-84.73051,-85.11732,-76.964588,-60.339529,-61.357988,-84.337963,-138.384383,-174.201968,-250.066015,-256.563088,-215.118719,-62.555352,-11.354384,-65.401431,-126.227377,-175.455514,-109.932582,-46.350494,104.092739,165.366228,249.565334,271.561983,220.136214,166.041205,161.828483,190.640896,146.591859,40.09316,7.493201,-39.58501,-66.835767,-134.258185,-138.949935,-103.473432,10.274296,58.344191,70.39424,62.009931,39.649654,-23.660044,-169.409455,-70.259399,29.812617,97.31236,49.958589,-51.315196,-63.078897,-65.696782,-42.964604,3.633779,136.339162,183.154599,155.419199,108.851557,47.894335,12.869785,-49.401632,21.296325,76.862017,154.346256,169.592869,135.547734,88.863599,-19.192758,-23.939162,42.181009,214.177128,258.671017,190.489644,116.316941,49.036435,67.400017,134.457036,125.250319,73.293792,18.804521,64.613967,172.405915,168.830912,59.793337,20.462376,43.619153,54.398156,66.636495,202.965555,279.189407,262.361919,178.398411,87.644116,174.533706,234.79915,337.261652,347.644005,214.174556,86.378949,-147.836607,-181.825722,-123.42251,34.848819,101.909371,170.567278,179.911458,203.283063,215.707326,232.191675,233.410693,221.728255,215.290989,234.464491,254.863679,219.042391,52.949963,-20.75261,35.157556,194.424653,220.213702,141.712127,119.898097,200.03898,221.423671,161.184556,164.065773,210.382473,325.169639,361.986998,380.454462,375.446181,329.600396,249.634967,239.604697,352.750604,437.145782,448.446516,369.725368,217.711949,170.406166,100.03137,75.393163,85.019501,136.496415,173.882899,238.333082,233.143432,120.101454,-0.026124,-32.23546,0.864624,68.020072,151.340901,130.507206,79.56556,76.63701,66.259962,45.637216,50.650657,77.405957,55.882946,-78.272789,-147.014381,-254.0595,-317.041432,-299.219851,-203.29711,-168.430227,-160.582468,-170.536611,-161.812768,-151.974976,-117.501089,3.687934,69.909392,93.570387,28.734605,-145.637675,-202.061386,-248.398017,-168.980692,-91.852216,-1.691625,-4.243436,-53.790191,-79.007319,-114.192332,-134.389864,-138.695777,-36.018686,17.306689,47.76876,27.620267,-13.225932,-8.263371,-13.327725,-116.476646,-161.507223,-146.739664,-90.24769,29.435242,45.291287,-15.652887,-56.743372,-107.532718,-88.403422,-41.837066,37.139817,22.387246,-51.747518,-72.338242,-174.348466,-305.907801,-278.205978,-98.746053,-46.91316,-57.109119,-55.085925,4.808477,34.02182,70.815908,50.019569,19.3768,0.320073,25.343896,96.120914,111.317478,77.063117,-3.653944,-31.592312,13.596916,71.542771,120.125154,105.898842,97.488117,108.424466,148.412828,224.799818,257.982547,313.171816,341.143505,355.619393,315.044551,137.665253,12.660125,-4.442612,-6.323524,22.272286,73.690063,17.220118,-255.994297,-369.600925,-362.83109,-243.084166,-236.373226,-267.26173,-278.851399,-307.830728,-311.306342,-244.446411,-93.557887,-11.762808,57.772178,33.554283,-44.102826,-44.447262,52.50269,88.2989,73.526068,80.246362,122.560369,208.079813,213.380089,177.15373,164.937116,169.258674,171.14288,161.883226,156.266729,171.281724,230.411527,262.233029,267.319818,215.704172,50.223757,2.723823,71.514182,279.225558,342.130923,332.798207,299.102715,251.913398,195.888872,156.274143,122.457538,167.950112,311.309927,331.516035,239.352327,166.53457,55.656313,55.653012,84.983966,192.580188,260.263586,313.420231,271.595079,69.104446,-119.49077,-120.594602,37.025164,110.16243,91.963416,29.553363,-77.531641,-123.834493,-155.465644,-59.111343,-17.927841,6.927685,-0.215426,-25.793314,-22.745094,-53.169811,-200.231774,-231.431749,-131.355177,-67.174226,-83.719579,-153.079,-247.603146,-260.073045,-267.676925,-217.211088,-173.767665,-95.634901,-84.304973,-142.300932,-178.702791,-176.721314,-60.719807,-10.287852,-52.077348,-111.769888,-139.365477,-102.655064,-41.240325,-42.125793:-24.849637,80.269057,138.032605,178.871136,129.84149,-43.552599,-137.844747,-275.244583,-248.271068,-179.360877,-14.407401,39.854433,35.075759,-9.231031,-114.551652,-156.06948,-190.845455,-152.134456,-92.013852,31.049947,8.411337,-193.425427,-282.641625,-347.502993,-304.606271,-270.555572,-224.63615,-213.43505,-214.981289,-220.149897,-237.328052,-260.039675,-236.056458,-89.886321,-60.638711,-129.664611,-160.767737,-121.473913,-89.978622,-103.542287,-131.624836,-107.812571,5.913325,54.002022,34.326958,-39.528348,-201.418613,-205.890988,-71.137899,-41.096514,-77.725545,-114.579723,-120.999274,-183.356794,-206.594671,-143.145427,-37.270262,-16.385656,-19.096019,-19.135087,-15.860589,-33.513601,-134.60908,-184.644132,-145.982092,-9.503804,12.519055,-8.379708,-9.68061,-32.693306,-70.809125,-124.131591,-103.451114,-66.812762,121.23655,243.3161,343.047135,304.824066,118.602658,27.88228,35.462297,120.658094,104.929718,9.322616,-43.121982,-81.058996,-60.976513,-61.471766,-146.475106,-153.019267,25.902565,148.900295,188.939764,119.571722,-2.717431,-42.576967,-47.648387,59.094385,89.755061,3.817187,-88.649406,-186.127598,-169.714615,-141.788382,-154.503634,-125.691462,22.846663,91.685171,87.440694,32.782278,-40.335075,-59.811667,-93.225005,-2.630176,85.517776,180.953128,158.078537,47.257324,-17.735245,-120.614404,-77.631281,-15.663176,66.840429,78.728147,87.844761,88.861648,59.98059,43.280903,92.251318,133.247298,68.565653,-125.585855,-164.227277,-145.024615,-160.936514,-288.801893,-299.502683,-219.688531,-55.789588,-2.610383,67.428008,66.489534,-41.55617,-106.82144,-97.205014,111.699571,216.545398,279.657086,245.922281,142.180645,92.284059,49.331225,102.501947,119.897122,135.536053,191.800259,358.215133,395.39871,371.133382,338.673631,242.03211,193.982725,206.876078,218.242408,213.010347,205.49043,161.506846,-39.684618,-113.553624,-53.915044,96.943575,128.388694,87.24797,44.03824,2.860881,38.663549,189.684506,231.997457,223.853676,287.686728,348.398285,416.706903,388.774547,267.732695,210.142611,217.598831,311.015126,388.808611,492.157677,454.485472,245.359927,179.307271,218.957613,237.196576,197.928556,181.223396,230.558155,326.018841,307.361225,151.798633,65.296251,78.736968,181.058764,235.991019,236.571455,193.880803,122.988747,89.702627,18.052202,16.697586,51.185649,90.226412,42.962071,-130.8612,-188.560725,-204.486874,-155.660623,-121.460617,-75.442498,-72.781493,-91.041249,-100.819642,-118.864404,-125.172544,-84.711059,4.400534,27.307855,-18.018606,-82.13662,-192.111075,-206.393275,-193.901376,-136.732493,-91.105718,-57.022515,-74.460844,-97.915002,-104.340727,-155.464274,-179.727217,-190.906391,-158.695766,-97.344454,28.643732,30.14775,-29.462937,-38.129513,-20.996862,31.555997,56.475428,46.212178,38.709978,46.464404,35.020761,-26.753242,-57.740912,-84.66138,-44.956741,3.692421,103.782232,115.896664,52.606285,6.771244,-76.443186,-51.257561,15.656643,109.177158,108.24051,59.456317,29.216574,-20.966957,-20.840328,31.803256,28.832129,10.029644,38.97697,95.809623,218.791824,227.731156,120.987017,80.614813,101.056102,132.201983,146.036846,160.304697,160.357746,201.026044,236.098763,248.764169,215.891295,237.415875,351.606943,394.699483,384.807424,331.888842,169.233168,94.117646,104.217254,123.988372,132.022631,144.983654,103.480225,-78.654591,-141.083217,-89.913726,-31.959342,-52.291658,-18.454741,36.009567,40.623884,-15.981388,-74.091569,57.924742,146.319369,258.078528,262.146378,148.440579,83.192717,60.59926,74.570474,105.482209,160.5529,181.093723,228.849169,246.896593,172.086901,98.695191,44.955975,65.618965,71.898734,158.105383,231.983097,293.735777,261.442667,184.854688,170.061202,129.163816,112.593395,177.111028,353.321737,389.358537,356.802542,307.975477,147.365055,59.319561,86.678437,180.433446,217.788216,252.704395,238.096941,175.712406,157.280776,179.106276,214.423904,226.828043,276.699615,291.772813,230.720576,159.957528,46.103131,42.386921,62.333084,122.875403,147.912959,105.402268,57.341263,6.178575,-19.684855,-97.595142,-75.447738,-14.443683,99.454452,95.767645,-29.458671,-89.47419,-159.895202,-217.839823,-222.807822,-153.936847,-120.031447,-145.529201,-179.713753,-223.735852,-250.939114,-307.881775,-277.388829,-243.538246,-227.221475,-245.198193,-258.393504,-256.849053,-306.578039,-258.71923,-167.156658,-86.288453,-124.485804,-134.73,-69.910331,2.636991,-44.743399:-71.412007,18.607126,65.850247,115.533667,95.238116,-39.931358,-136.86957,-306.000496,-369.353833,-344.884888,-179.119149,-87.406533,-20.756087,-46.627604,-162.880182,-222.66213,-255.658075,-177.139734,-98.382026,44.025354,24.761154,-153.07709,-221.538285,-270.593811,-276.870792,-282.472325,-303.643145,-299.325635,-221.01767,-165.875959,-157.63124,-217.648562,-300.32293,-227.285939,-182.83727,-195.362506,-215.501486,-132.644088,-68.654049,-80.127036,-201.585703,-198.916484,-18.763524,62.434753,35.353393,-30.564567,-142.647976,-161.428454,-87.786544,-26.842485,-34.04533,-41.957456,-44.09596,-91.358611,-118.356292,-97.956309,4.027234,47.05885,106.767824,116.143741,36.772945,-20.144288,-65.013958,-61.525552,-11.902082,83.882542,115.292638,91.590246,44.296494,-72.943006,-134.52924,-187.296338,-65.139489,8.757549,84.641841,104.391571,132.404069,115.162536,-24.13473,-89.002865,-54.794339,26.070558,29.268032,85.385749,132.99893,134.308921,88.590466,-13.086075,-46.083374,-17.101814,77.805174,85.633415,36.980212,43.893118,48.32208,-12.030396,-155.546779,-162.094314,-107.77889,-51.091668,-114.066044,-281.801032,-300.642678,-257.455432,-236.401337,-226.855289,-183.690189,-157.17667,-141.815364,-149.127136,-154.655173,-156.299975,-130.011186,-103.069853,-122.372808,-140.265132,-109.745193,-48.542939,-72.133869,-193.666205,-171.87117,-88.44037,48.656603,60.900567,24.083818,-13.987164,-110.701065,-130.394368,-50.493252,-12.992251,-83.538142,-281.467729,-336.471377,-371.858919,-400.266274,-410.967319,-232.109805,-152.332811,-124.89703,-128.91172,-104.931419,-89.00346,-97.867604,-119.147396,-66.697971,145.262638,236.321558,253.11225,192.171992,73.194474,49.319972,68.583119,138.378065,167.817562,191.41905,208.595484,289.16714,322.164055,268.113709,193.047972,124.517117,192.554346,179.854669,30.743966,-10.167864,59.546395,93.477991,49.260134,-56.846164,-87.062526,-43.910187,2.701355,10.752961,-30.214056,-63.957203,-18.163707,147.201234,264.085728,290.270417,324.915382,341.799759,356.835629,329.667324,228.887267,218.719926,241.567997,252.375253,247.124764,253.503468,258.175025,246.297643,220.130085,157.228107,172.325405,201.859534,256.922691,300.095783,394.204345,370.050019,180.761844,176.785157,264.407344,360.844681,327.92401,215.881683,194.912911,192.263227,156.299283,24.716522,-15.059182,22.533101,114.504914,119.456217,42.465954,-25.376992,-159.154391,-122.240115,-38.010551,83.532981,68.270123,-18.627299,-32.624842,-63.860368,-90.337198,-32.777271,105.958343,126.716521,64.863935,18.844298,-73.604241,-127.839401,-185.422776,-81.748733,-21.815292,18.980886,18.472575,-11.87025,-52.72134,-167.168365,-206.868861,-205.712365,-144.035375,-101.341711,-26.875086,0.825041,61.440176,73.719885,9.145171,-15.502992,3.742832,0.76608,6.851887,91.401967,123.468161,86.324868,33.965085,-56.169642,-16.155196,59.655668,174.411048,175.640114,139.716896,109.897179,9.517361,18.487963,81.506921,147.042593,132.422786,121.267584,122.750889,52.758501,9.170212,49.812822,158.284677,156.759337,68.260459,55.322442,133.945882,157.649285,111.297971,68.231384,72.882568,108.036833,106.192749,51.956499,46.337336,123.572466,163.419902,145.658321,133.528159,191.540212,308.692031,310.320346,263.260788,241.553815,160.347349,53.177767,40.230365,106.440366,141.157455,89.093953,-8.721829,-192.336163,-211.286232,-103.867835,31.889706,66.729079,97.910841,107.598598,111.077522,110.143516,136.677373,161.871198,162.283702,181.713517,187.220508,158.158263,153.708195,114.920904,44.988921,-28.307148,108.649089,179.421585,205.058713,165.281261,59.045116,23.002106,43.355588,175.200984,242.390139,332.967624,349.46563,296.691432,236.556177,149.683454,149.910487,191.491182,220.264487,251.380481,366.512027,408.903236,401.109053,343.128168,166.632787,126.797651,164.851742,234.632666,256.820675,275.009125,259.633963,198.272255,167.692218,142.991153,202.439013,250.785495,299.256279,266.537148,124.287021,61.365882,7.310062,38.25655,62.622842,131.410631,181.733399,232.057273,211.461873,108.390836,46.070197,-40.145779,-34.078001,23.619248,135.549925,99.961373,-53.926504,-66.243096,-29.524689,-40.313214,-35.009159,-48.422582,-87.377912,-162.005547,-178.451197,-227.097194,-265.924644,-282.318614,-197.915952,-144.179577,-75.283472,-78.605519,-125.328387,-152.954702,-216.788192,-176.989516,-105.025136,-40.213345,-61.851653,-53.096277,2.326686,77.097275,46.701475:-51.360118,50.825932,64.860503,119.730905,139.770769,21.159003,-106.305277,-334.331482,-345.663886,-284.687229,-141.832941,-86.722568,-50.475139,-64.438632,-130.690782,-176.948758,-228.739148,-189.478887,-149.142497,-61.78526,-66.470615,-219.626417,-310.213494,-405.40392,-419.542649,-416.124872,-389.173741,-374.520053,-370.140263,-356.639895,-299.169081,-302.203963,-363.103863,-327.211488,-277.866848,-200.763332,-162.335829,-44.889626,-4.291774,-34.1905,-8.808515,46.832383,97.606579,93.425913,97.108497,102.566108,81.793164,49.601009,-4.791044,-26.964904,-46.418714,-40.435772,-13.814368,-21.669751,-63.195804,-136.057719,-107.820785,-64.764987,9.72196,18.70268,-70.411206,-148.298906,-241.095896,-248.82909,-193.717627,-69.986881,-34.584053,-44.926705,-78.149036,-150.788774,-164.622987,-141.790977,-82.161037,-37.910393,114.967745,202.638695,242.176232,197.75114,116.047095,91.658317,78.150261,98.511813,101.089336,106.131,103.682893,81.267112,70.268364,9.882554,-61.069744,-48.788784,57.498229,110.771138,129.28407,90.679028,-34.29459,-96.98858,-141.750175,-64.843341,-22.274692,-7.092164,-43.819946,-138.842354,-170.668201,-213.851254,-203.129892,-176.482868,-113.784261,-87.802413,-82.085582,-95.90277,-138.559796,-172.673843,-183.354658,-56.327442,6.016517,68.657072,70.98856,31.240692,1.063934,-46.072463,3.364795,67.318358,193.958954,237.816861,255.5143,221.673242,117.294759,74.271672,57.569063,27.204128,-16.409501,-23.444382,22.365215,62.755775,13.04371,-140.151384,-137.691474,-77.754972,48.155498,114.085809,222.8001,233.176491,152.773913,102.897677,127.997775,233.699308,249.52905,279.84029,286.416125,144.656099,36.324823,-20.319616,98.778593,128.245648,152.314338,205.2867,334.708996,350.332724,286.910639,240.214529,179.645669,182.305535,180.368566,149.325672,147.705544,172.645817,158.926191,60.064847,15.463629,40.802097,143.259837,185.674875,170.736341,147.766861,186.03245,227.820242,273.951266,280.069819,308.445215,421.371445,465.46414,489.190214,457.498443,300.580311,213.1235,231.643112,322.47481,364.659702,335.810411,265.140255,160.928735,146.468187,128.587145,114.35436,140.695029,286.253908,365.290826,414.79791,371.726772,245.942006,228.645406,257.058872,321.63933,353.785642,380.679634,367.845833,301.432905,240.91989,101.732,54.808255,83.535994,156.661198,141.979727,23.416115,-33.024738,-145.472834,-209.173184,-167.992353,-14.033717,22.722203,-24.128659,-45.269367,-18.265464,-22.647432,-53.935355,85.862607,184.19707,227.501462,165.47703,30.455557,-4.483541,-52.300567,-68.877012,-52.816922,15.528458,48.850158,-1.352878,-84.197707,-213.445659,-225.446352,-188.8383,-146.022251,-107.567198,25.481299,73.358245,28.754659,-30.238183,-115.175343,-119.720591,-89.849046,-53.521708,-56.329675,-39.993695,-22.602635,-22.480618,-45.631199,-111.321931,-97.710926,-28.031979,131.195739,160.42787,119.176914,61.564673,-136.736941,-237.192386,-180.359103,-19.811376,13.166278,3.671776,-10.29044,-16.408422,7.540022,98.187175,102.692404,65.338035,22.127105,34.493154,107.253233,141.17326,110.130899,-9.768825,-58.851413,-75.208178,-46.647275,-21.77596,-38.752648,-52.75888,-34.490725,46.639885,160.198676,220.486761,301.161887,294.96326,200.334533,124.948973,-55.82926,-116.312359,-69.749409,28.363332,34.078023,-47.856319,-137.03525,-348.735929,-408.112582,-340.949919,-201.099924,-175.3899,-134.717053,-102.96647,-84.197561,-95.40442,-94.306696,-25.263995,13.917916,37.344792,26.248447,10.061622,24.83429,36.942877,-9.955614,-86.472117,27.969746,114.600101,261.206138,291.876981,245.633191,214.867856,235.699648,259.121314,220.541407,139.931244,154.190525,244.543901,268.162702,242.014895,210.137546,146.230192,148.509183,218.234968,437.785367,490.203757,435.985169,399.547475,333.451572,207.939542,155.69428,150.519204,185.830327,215.451651,198.795533,178.850452,158.717251,58.211236,38.885309,78.31601,161.44795,177.903113,166.16743,145.689212,34.220383,-91.227873,-79.448737,82.236245,158.970198,167.346701,127.088399,43.724107,-19.991781,-142.943124,-113.122574,-46.737534,77.561286,90.836999,62.088821,56.431717,-13.708669,-149.906473,-149.386906,-29.68643,7.565818,-47.871723,-106.552216,-182.249211,-204.65514,-262.829497,-256.386586,-196.103805,-59.351299,-47.793144,-107.874322,-128.417143,-149.809823,-100.371498,-37.921112,25.42673,19.187542,46.558943,72.350097,16.385568,-65.918299:-120.386971,-12.413315,55.025173,154.163634,134.994594,-59.915142,-183.963998,-333.419568,-315.114001,-260.172297,-104.069411,-45.421039,-63.881055,-127.813967,-261.15607,-295.526356,-289.274326,-229.683151,-166.653692,-57.687628,-74.729906,-202.087586,-254.90832,-288.770234,-286.000852,-316.661323,-381.071483,-373.699045,-328.257335,-308.56942,-306.839056,-339.316558,-386.499494,-319.920399,-245.577244,-90.638827,-56.53536,-61.91806,-68.46838,-48.274318,36.108424,95.50317,195.114474,205.393189,169.339927,151.485209,67.048199,4.364129,-24.289687,42.200475,65.675842,50.787271,-4.377565,-138.270705,-165.046545,-125.427939,-43.847206,-8.118082,74.718863,117.87739,97.394636,31.413762,-73.185269,-82.187351,-45.233823,7.163817,43.229881,125.079727,122.971711,-25.827435,-126.072172,-202.605963,-38.115069,85.872959,298.023767,345.467264,244.827259,127.614135,-50.201388,-65.766169,18.268958,107.595146,137.770625,193.080074,201.658349,186.023746,168.685039,85.132867,11.77339,20.776881,132.444511,181.364416,126.769264,48.943242,-79.949351,-127.476016,-200.228997,-167.889379,-108.532855,-27.512695,-50.454425,-200.864059,-267.234208,-247.142236,-136.316644,-123.006415,-139.565391,-139.07272,-150.183943,-166.162715,-211.337897,-238.03295,-233.468818,-122.836303,-80.74541,-85.823309,-100.043852,-121.41205,-150.541191,-175.296327,-47.601353,29.086256,127.172125,139.55481,88.916242,51.091943,-33.140662,-85.472854,-87.087999,5.594713,6.290186,-47.613513,-74.856429,-121.004827,-150.698312,-219.285565,-203.043286,-166.992949,-58.284918,20.592735,154.905856,160.885543,30.020866,-33.123397,27.647089,196.824254,254.26856,297.199296,283.912308,185.010291,111.424344,48.123139,148.49021,189.867816,219.040077,237.479058,268.631179,259.838816,173.098005,119.275386,106.051617,146.932169,122.581362,10.459074,-12.828628,55.157476,78.103262,31.747426,10.098609,36.710806,129.40473,147.459737,64.823133,8.501514,-33.08824,-8.303955,127.158382,281.111972,345.729157,449.11735,474.972748,439.387801,372.638122,254.688357,282.545795,304.029603,299.036489,303.436971,329.397066,328.966582,315.85293,307.407605,287.05191,303.713401,328.874955,376.380525,392.470345,393.759545,344.895144,210.008992,279.838832,353.925207,434.714712,445.751802,373.898433,316.186559,259.639801,227.46737,116.845671,76.334606,103.780039,166.95841,160.269526,101.869911,69.419977,-19.193616,-38.920671,12.128464,158.821555,180.316474,18.350335,-80.278605,-111.525217,-91.460184,-59.413788,74.965164,164.390884,230.76541,184.864629,17.939475,-74.552812,-175.326723,-42.569465,36.386588,79.592871,77.699862,26.625379,-56.048852,-245.675342,-278.078434,-198.92259,-152.537966,-147.815162,-61.694604,-9.298913,9.505858,-32.269299,-173.892956,-180.00694,-106.134696,13.093583,17.160971,-9.901305,-23.180128,-97.241748,-125.93729,-53.147038,82.71344,140.471891,202.723607,205.810145,189.661565,135.779184,-72.875522,-103.292161,-12.477217,147.843023,170.702799,170.284536,154.888143,111.041975,115.544081,188.454503,227.1222,212.458307,166.706897,160.215719,155.831396,137.825708,96.942765,51.969867,20.522223,9.693836,27.243405,7.847009,-20.221379,-32.639643,-21.923481,55.543248,242.205942,320.814439,325.278965,267.542119,146.679142,97.025432,10.91833,-24.357862,-24.933227,-19.148962,-17.476481,-53.339057,-113.800552,-276.10767,-318.410812,-260.519236,-162.516023,-133.290254,-58.69157,-16.110617,26.697501,18.565657,-21.02842,15.564628,64.946665,139.284637,137.927824,59.260619,9.471016,-96.499053,-160.837676,-205.798795,-46.239715,61.622828,204.491127,217.653427,137.108503,77.256677,51.448069,165.354733,221.188538,259.112683,257.654828,278.091039,279.360304,189.383304,132.361796,109.453999,200.429139,269.727006,388.944644,409.81033,395.133779,362.308422,247.222176,228.779321,256.510206,286.525,281.09849,235.922811,212.330057,181.551105,157.018904,109.396449,144.584141,176.101731,209.521451,207.589024,174.696098,141.159305,21.446045,-78.179931,-66.075713,90.932116,177.162072,200.293069,159.712401,79.8396,44.62424,27.918352,76.159356,103.828163,112.782017,61.760461,-98.69603,-139.844227,-119.029428,-54.34547,-19.36648,7.217841,-23.55219,-156.760107,-213.45845,-246.117064,-238.488544,-209.807676,-207.061222,-189.877838,-82.933835,-46.98231,-76.466494,-116.401252,-203.530148,-194.573256,-141.025329,-35.409777,-3.100637,34.497433,42.962463,6.784203,-43.912962:71.277848,136.299196,166.457836,217.509277,198.913199,23.256926,-74.182349,-176.871173,-209.384735,-203.146601,-125.998626,-81.324155,-45.986202,-30.800582,18.333137,12.934446,-89.333869,-196.207936,-199.946532,-143.37849,-140.096554,-207.189141,-253.937189,-357.977353,-424.756375,-417.092653,-320.010659,-253.009883,-199.995737,-224.727389,-304.797028,-342.101526,-343.773587,-191.58266,-108.947843,-51.709973,-48.118398,62.77651,159.362574,224.778316,131.630017,112.429621,120.806842,118.426566,119.11898,131.97282,129.052669,110.492918,164.417011,255.658751,206.637395,-2.906791,-77.620064,-126.73972,-129.017081,-120.932783,-62.703963,-38.401599,-73.141365,-106.130955,-147.039025,-171.590199,-244.045646,-273.490225,-260.028626,-184.047247,-168.725047,-186.047404,-185.720063,-127.374346,-99.431054,-109.744727,-78.657168,-6.796541,165.849494,226.199407,258.134863,243.030261,205.818579,177.470078,108.521814,60.660913,27.90794,-37.856565,-74.201103,-161.016784,-175.263159,-168.945252,-234.498783,-239.772117,-94.41295,1.352197,76.013936,63.906659,7.783645,-42.630522,-138.79555,-139.606002,-104.787285,-39.02607,-55.63936,-130.882296,-125.626195,-101.151505,-194.020055,-246.002539,-207.432159,-114.907882,-7.200292,-57.919419,-247.948736,-296.465284,-223.080807,-70.184978,-24.434984,39.017895,76.292259,99.900865,68.475316,3.887894,93.872285,184.171644,301.164729,302.33427,263.625975,248.916525,187.533737,134.374878,111.186654,204.189211,213.281081,211.952924,252.588492,343.908952,346.182342,208.837173,51.777509,40.83319,95.392169,169.06195,440.09819,538.388336,440.985677,307.561703,188.506659,268.213068,278.826405,246.904514,231.09935,105.787996,-22.649024,-269.22064,-209.265009,-75.157476,98.363377,91.249113,-5.031526,-39.707216,33.646666,125.957268,274.976252,286.536182,243.901665,174.412602,186.144453,203.918442,168.305165,96.632277,147.266556,193.968471,248.793858,267.435722,326.260043,361.37391,384.773685,339.268093,203.324077,240.306153,306.559645,403.240255,431.036951,437.85542,393.342778,249.583666,206.914155,234.771198,309.889733,337.419558,310.130957,252.441859,143.989056,105.780856,58.369475,88.607462,125.65964,202.651066,224.98761,218.325699,191.741496,121.209009,111.859347,116.144436,122.063548,154.771044,218.692605,203.68636,136.8229,112.214216,53.490351,-2.046139,-11.0252,3.199388,-0.988264,-82.194332,-141.501271,-247.272235,-285.762318,-259.349432,-144.491622,-100.088737,-124.431042,-157.005119,-145.97418,-111.810895,13.466425,245.283272,320.112519,235.146633,123.888847,-46.644409,-91.355656,-144.144576,-128.597187,-90.696762,-32.722028,-29.259165,-41.11434,-53.585194,-104.952264,-133.636135,-164.124503,-141.689298,-111.637882,-60.076621,-71.674477,-151.356783,-181.764281,-237.344087,-291.990791,-285.597506,-212.844186,-163.545069,-77.593783,-57.269699,-77.380627,-109.492869,-169.667023,-182.701535,-164.213941,-31.510931,58.159839,94.89811,14.12483,-222.464614,-353.34115,-356.846341,-312.616588,-280.288192,-204.429927,-162.097652,-61.154617,-24.988078,-3.054731,37.620144,64.850057,89.599883,84.970972,72.995805,73.817632,47.965873,-64.952797,-132.922165,-181.899926,-140.824197,-42.680527,-43.324889,-107.028265,-112.268713,42.553532,240.573823,246.975761,167.192939,163.633051,189.355726,155.416489,11.10276,-131.208623,-184.081109,-165.496573,-99.713912,-66.873157,-154.583,-409.64644,-499.223911,-516.509001,-426.871174,-394.264986,-318.959066,-286.25612,-288.955617,-301.216041,-294.573861,-218.661885,-139.963618,11.26206,32.921174,-20.812058,-31.226542,20.446462,9.628674,-91.683045,-57.324935,22.797977,165.066058,181.445585,167.256974,189.152685,270.810107,280.417762,260.152399,237.013621,245.269222,241.084865,209.164038,116.465962,79.579357,49.862443,65.795221,125.941999,328.989997,401.146964,420.164653,392.541976,318.206768,308.448719,311.650388,239.4622,205.12268,230.326916,244.407867,171.490722,87.774391,-76.805697,-86.494505,-44.132143,22.294233,40.658896,123.1259,170.619673,108.169994,-92.75914,-120.939683,20.060918,104.269503,94.03323,9.221012,-160.119061,-216.588932,-246.931299,-154.29686,-81.851638,79.09048,122.289053,68.572191,11.823181,-84.021656,-63.982594,-7.889748,44.922885,26.519785,-54.800473,-109.965234,-204.41733,-231.515331,-239.31674,-170.426833,-105.896292,24.679578,42.549005,-18.050357,-38.476503,-5.028674,85.120065,125.928956,135.520306,122.932406,128.51517,137.026748,125.776803,94.37158:-130.96194,17.825221,99.41771,176.592481,141.368359,-44.044313,-147.980119,-293.763799,-265.156419,-206.407504,-115.560705,-94.651117,-96.601343,-117.187285,-175.429712,-197.40349,-193.158928,-112.8837,-58.154397,-31.926414,-82.778658,-185.175317,-207.195183,-266.251852,-354.932594,-386.294352,-381.301013,-341.179935,-290.221776,-301.238897,-346.077364,-351.400619,-265.666316,-137.841617,-102.687173,-43.010775,-3.927568,42.696464,40.705313,62.517702,164.567305,215.723216,255.475377,252.93927,253.545416,247.699236,153.762578,88.993409,80.532809,128.827968,103.95781,29.172698,-4.373214,-101.172166,-142.814708,-139.625956,-84.859709,-66.853193,-5.152258,41.538022,41.094628,-25.935131,-165.959712,-191.467244,-148.117422,-65.609118,-45.436604,-66.881817,-97.238676,-147.306655,-151.927023,-98.828397,44.828497,137.766677,326.256003,392.356491,365.091159,284.419638,150.907885,130.0231,152.190857,155.257167,144.155187,168.633265,187.781619,159.271963,98.951972,-86.212741,-180.488929,-134.7126,88.660884,175.772355,131.419142,44.296698,-94.075397,-138.111843,-165.500967,-89.580414,-12.782577,104.266859,85.743566,-57.544914,-136.575181,-224.605543,-171.191979,-133.27654,-81.760761,-65.564496,-84.78113,-109.75192,-152.927882,-181.284478,-179.839836,-64.630558,-23.458331,44.715095,99.35291,143.094864,86.641853,-34.713577,95.481283,206.603364,344.458417,368.124593,333.291512,275.27731,105.658626,27.725285,1.072072,55.858628,53.027165,86.173709,138.696131,177.01008,129.925727,4.201572,35.799152,84.309668,177.214919,252.383091,390.900159,390.643084,261.93726,193.768862,177.402072,269.603495,315.65253,370.152445,334.025479,107.305976,-15.00833,-127.461292,-31.526871,66.158393,227.12286,254.384044,208.756175,148.91084,19.712156,-4.709825,77.482376,187.943309,199.260998,164.846173,144.558481,114.473516,83.812775,-11.229685,43.98701,147.879443,319.663034,344.236905,320.197513,296.842818,236.592413,198.51032,192.198766,325.354522,408.409023,523.091102,522.889423,407.276483,325.353131,207.740175,244.990936,302.816362,355.149435,344.694784,286.246712,233.210093,106.641244,49.591063,6.463212,105.976183,189.034819,322.785385,342.237501,282.886137,222.225751,131.533268,209.356593,294.254357,436.940228,463.607826,386.263318,300.125548,144.559491,94.170218,54.524675,72.23367,86.188677,123.637495,130.658104,75.491999,-2.989264,-215.52587,-243.483101,-169.04111,-0.481433,45.152327,12.016256,-29.243799,-80.168738,-106.041784,-88.524689,122.247636,212.235096,215.346212,157.568196,14.436833,-67.902825,-223.065389,-184.601245,-73.624744,155.053811,198.322943,91.528128,-18.634725,-207.678057,-243.065501,-209.598655,-190.237168,-186.5971,-148.413419,-138.803971,-160.928698,-175.245823,-184.129667,-141.440207,-115.598963,-90.325772,-67.009563,-13.079534,-21.363363,-84.269796,-98.287934,-64.495788,32.483038,109.640084,242.085186,254.747907,149.470623,29.529257,-258.71758,-293.1954,-184.322931,26.908875,61.026471,1.319644,-62.761252,-128.872684,-93.272316,41.048494,76.17865,71.63954,112.404197,126.417637,109.594413,99.805787,41.356844,-107.803041,-162.694969,-125.274789,-61.607739,11.674412,-7.664502,-102.949113,-113.842976,44.957035,281.384164,342.121183,335.37286,302.162584,210.553037,137.707392,-28.851479,-107.491236,-85.245497,41.012445,87.688786,15.377656,-110.572382,-418.758123,-534.518077,-568.030303,-389.013813,-292.894587,-193.651183,-194.59846,-198.056867,-193.312388,-246.971556,-247.336927,-164.90173,38.709979,80.012777,20.822602,-26.971196,-122.157634,-178.463283,-184.856214,14.929922,128.197238,273.503324,280.646338,190.823306,133.63681,91.182814,179.560294,227.828209,240.237921,229.299366,256.747531,265.937273,189.668082,132.578403,75.049734,98.707095,162.154126,362.813863,430.069556,427.733657,387.642846,310.305217,309.81061,323.516161,313.953843,291.316669,221.95841,179.416068,95.896674,46.773744,-34.82721,45.701842,118.856379,139.357261,93.77693,58.541022,70.891297,1.732592,-157.360547,-167.385906,18.682543,136.005754,174.596046,103.080037,-33.128382,-76.45396,-125.685684,-67.304512,4.527083,135.574212,145.100475,69.168881,25.167413,-40.469747,8.247021,74.121978,128.673703,89.687311,-34.498436,-77.743469,-122.477143,-145.048637,-209.031567,-228.625298,-174.290081,-26.679336,-16.05583,-125.30524,-174.082053,-160.161079,-26.087841,50.826275,146.685131,160.585327,104.871988,43.174776,-66.802323,-106.149363:147.419549,182.265525,210.966542,239.412659,215.492416,77.111538,-0.978442,-99.249235,-113.068376,-78.969907,25.567924,64.821488,133.582096,192.505227,327.176453,341.321989,225.935924,107.40831,108.229584,186.67539,195.254744,106.996953,50.246713,-42.175422,-101.689874,-113.458905,-79.656713,-42.852498,25.649955,55.354869,57.744849,-1.03048,-148.53069,-131.050701,-66.43665,99.078436,186.367424,313.958739,327.672393,252.318896,150.75065,138.51954,194.501324,214.992851,142.828202,76.721544,8.753645,18.80883,91.779879,86.112269,20.842201,-120.576045,-158.315108,-176.021084,-159.659657,-82.802152,-25.344711,-27.04023,-84.450761,-108.056949,-83.267307,-54.066504,-53.273562,-87.042129,-127.547213,-76.970745,-68.263783,-113.058517,-112.682882,-22.618485,19.232043,29.200256,61.686472,111.730356,176.893658,181.032557,202.29706,210.276398,148.893333,95.216361,21.446044,-63.152108,-130.782562,-223.758813,-247.920983,-282.560893,-266.566252,-222.219637,-270.040122,-290.607745,-188.835532,-61.313933,147.974113,155.787924,41.641444,-13.779941,-51.607617,-34.762048,-44.590873,-135.363573,-163.608694,-108.1571,-85.351269,-151.589392,-237.032573,-257.251912,-245.051781,-208.144356,-144.200553,-142.638483,-160.151267,-161.143113,-142.905708,-117.135014,-112.305631,-98.361884,-73.962439,10.033321,43.183179,26.369519,-24.553055,-32.655778,5.407196,62.043579,128.949448,82.054367,-94.247027,-136.095959,-8.119802,182.519129,223.149647,279.80229,323.610811,379.360313,365.530463,278.738614,178.670856,125.154292,100.540821,191.681404,454.720395,503.134369,413.141797,360.844241,338.3067,295.20221,248.2246,176.786541,145.134813,31.864949,-61.235088,-269.711681,-305.270732,-240.805737,-123.496456,-107.447421,-134.766822,-150.518309,-78.798773,-5.34471,95.565427,165.36549,195.9987,198.006205,167.78852,105.896636,99.527051,101.019508,119.541879,156.681982,242.880569,282.850767,358.642872,354.298046,201.950525,118.699299,84.498189,126.535538,146.237609,158.883257,124.444819,87.746402,125.1115,127.670449,-21.969791,-64.070793,-7.256761,49.375005,85.964879,56.056023,-29.005558,-67.085526,-109.744353,-72.026561,-15.203043,115.024674,113.617319,-50.827326,-136.231734,-184.968578,-153.947901,-154.416536,-112.404169,-36.650339,70.9249,37.018501,-99.017907,-132.851432,-156.621834,-216.820179,-238.962906,-226.455424,-211.600678,-214.51381,-229.581801,-292.997576,-393.99144,-404.159172,-251.694392,-143.306093,-96.407499,-156.11019,-254.546871,-264.348283,-204.53711,-28.120741,24.296801,-64.072636,-152.516921,-248.076285,-245.760206,-233.800444,-229.434574,-205.889166,-162.101062,-161.567971,-168.825096,-159.321241,-134.591479,-151.779287,-259.063777,-314.189414,-281.58445,-171.360369,-154.989518,-227.515098,-275.155529,-300.329884,-204.178111,-145.018408,-71.167459,-43.472071,-28.462652,-62.540717,-144.370837,-142.01551,-69.709803,-42.614747,-28.977447,16.314957,13.13601,-38.627683,-62.165363,-109.591964,-127.726796,-108.885711,-75.812761,-89.115952,-155.033479,-169.527465,-126.021596,-100.280621,-72.288431,-31.944746,-38.214838,-102.100105,-104.154836,-23.220461,11.618129,-7.960994,-150.610342,-234.733489,-299.728264,-268.626526,-198.382389,-199.837038,-238.290493,-235.010828,-105.433823,96.969259,153.389197,191.282523,206.582477,206.058311,179.957005,144.993947,131.104919,100.790324,52.906337,47.830749,-8.976293,-73.807149,-187.960441,-224.726353,-286.85082,-274.571632,-252.555329,-193.450982,-143.995641,-94.082097,-117.483999,-151.537597,-76.689817,-25.308977,31.945239,15.256008,-79.690856,-82.499294,39.180877,61.13053,-69.034394,-153.798519,-120.202765,4.179187,56.166271,107.084821,124.612554,164.227902,135.897279,114.432595,141.266249,179.858709,216.716644,197.91922,125.498897,88.496972,14.429596,-25.169911,-4.81016,98.861306,142.897176,194.817322,218.068397,260.040629,288.913091,267.692189,120.663467,50.741775,9.89263,11.193884,13.293103,8.237619,-36.255537,-113.838564,-130.780002,-29.689772,54.589751,140.870754,142.341615,88.475699,-29.162441,-64.933498,-12.732962,42.127691,34.190301,-28.134268,-97.102317,-100.551914,-120.757855,-98.880271,-71.01517,5.466612,52.850208,119.719986,143.145788,159.07102,94.689912,55.084217,-14.316087,-44.674573,-93.031216,-103.948422,-115.001966,-141.412704,-194.109149,-113.285383,-37.287968,80.899757,82.525287,-46.237228,-127.172359,-157.90243,35.14882,123.993277,135.241266,91.152625,24.346864,25.113316,83.609487,91.340451:148.517751,106.967039,137.09702,227.028877,225.98404,102.926995,39.837421,14.686001,60.930859,65.080012,35.521226,60.416052,219.973694,301.457608,360.959241,328.547508,222.100061,164.97171,127.928221,34.074999,11.928238,-18.831979,-49.897699,-72.892203,-31.00681,-41.902972,-100.204067,-76.982067,46.370058,68.335763,-15.994104,-93.668608,-210.524269,-155.155544,-82.733465,48.151549,105.467686,234.525114,287.474273,264.324503,155.795078,144.525812,160.501363,150.154121,85.56192,55.535126,37.015023,44.369884,115.444546,140.640635,78.435715,-70.141369,-119.090077,-172.602051,-150.212018,-38.962296,-52.782003,-124.404697,-227.592016,-191.367991,-16.55436,28.446425,-77.158257,-190.728697,-337.415128,-300.39552,-263.003169,-199.045328,-174.527894,-157.737203,-160.816794,-168.702173,-146.202136,-97.080887,50.603449,105.547027,148.84062,161.413002,151.88675,108.215993,29.738831,-4.288054,-65.284439,-233.628517,-289.800791,-298.583848,-263.859883,-234.574738,-274.708411,-294.166358,-241.433117,-138.827345,69.000891,99.100466,2.11452,-93.427736,-188.939182,-56.745338,3.682458,1.816966,-31.158154,-64.180385,-43.56947,9.366814,-20.968521,-26.834433,49.288364,82.025253,16.550351,-51.978398,-127.344437,-130.437456,-117.354705,-56.902408,2.781983,145.436496,192.319531,183.519499,144.639103,75.239248,87.610433,120.509981,191.048296,218.607753,187.599143,121.943796,15.800924,27.308,166.363626,219.042169,189.598464,252.796163,355.028499,448.500877,406.960398,250.591222,92.244194,50.724604,97.209266,178.814183,356.534923,413.235332,394.388055,315.172092,184.24001,259.802317,322.308057,372.965465,345.104229,162.01045,28.68956,-210.471022,-287.356947,-257.097323,-134.889574,-78.156753,-30.920897,-30.993801,11.220601,65.625859,197.311627,269.398272,288.248204,344.960039,360.093542,323.005838,278.910361,150.572444,77.5436,100.662048,185.494793,201.92299,194.342493,199.517296,202.161027,170.123429,122.658833,199.403202,234.851529,252.025211,226.643882,142.879512,140.479782,198.619014,182.820455,159.44231,194.617991,255.959559,288.883208,215.410766,45.472448,19.489768,63.71151,85.730088,66.871219,35.957129,37.594629,29.376894,4.308236,-66.111158,-128.376151,-157.832015,-144.314612,-85.864479,27.767641,24.130389,-118.262237,-192.422758,-212.352769,-168.163896,-164.538787,-169.942184,-197.305738,-311.58592,-353.487036,-389.663084,-432.017383,-432.789241,-379.869046,-353.801135,-323.286227,-290.451649,-195.695491,-187.550601,-207.197674,-77.116687,-9.268768,-74.126536,-173.421666,-236.747703,-183.516082,-91.613183,-101.973681,-112.953859,-100.689596,-81.701755,-43.363127,-33.069042,-71.566331,-131.172561,-260.722492,-263.39473,-209.822776,-119.664369,-118.971024,-159.862396,-200.731655,-344.45338,-388.91451,-344.187913,-218.252765,-142.671598,3.757488,39.506874,4.697978,-55.685593,-152.699124,-97.790332,-48.682251,-13.200745,-30.525878,-68.050719,-86.243171,-186.23013,-246.584679,-201.022192,-46.766238,-7.380875,-46.044022,-76.850397,-65.893083,-42.417371,-35.160692,-34.026289,-25.965378,-32.272883,-39.437001,-28.737015,-21.003105,-51.605115,-133.09045,-160.927575,-123.243085,-73.109583,-74.824901,-128.305228,-141.785213,-85.658817,-2.693577,28.739864,84.816417,264.88147,331.551873,330.374435,285.653699,180.116462,65.335146,21.924678,-26.318803,-26.276897,15.926346,8.891209,-143.710703,-256.33777,-389.533716,-353.547177,-324.400434,-292.503142,-289.201935,-288.061484,-265.199594,-189.726534,-104.52231,-24.701063,160.992221,187.347214,40.044275,-34.643869,17.739586,66.401316,30.694802,-9.831851,-6.346652,-18.17349,-31.21238,-9.495546,42.432372,184.051222,231.187984,192.492471,80.202083,73.828849,190.633275,248.490923,205.581286,106.571027,-101.016307,-177.120534,-142.649099,25.699131,110.081493,217.01449,232.487864,193.928293,173.513908,172.271177,110.483696,85.089953,152.776247,195.314427,128.325279,43.132424,-56.640644,-55.550921,-64.019391,-66.540647,-22.510228,130.527311,187.955698,162.391864,32.292916,-1.380569,-9.029953,-11.365187,-38.530818,-60.59919,-96.812565,-116.931764,-131.819243,-50.323142,-4.809323,44.697316,57.386305,121.494464,160.904522,87.085872,-104.242387,-126.623747,-21.892008,29.788705,1.201609,-55.316804,-136.520531,-168.675948,-233.278841,-189.392152,-112.045043,72.293813,103.809386,-37.482402,-131.966736,-175.869801,-25.867332,56.911306,61.507175,-5.859014,-80.402416,-37.928152,110.174157,117.684922:119.882467,61.504639,72.699495,174.052568,171.314277,-43.432044,-183.747626,-334.615913,-248.625279,-168.684062,-76.047906,-54.103137,5.65728,52.204422,133.117506,125.80987,35.551882,-6.707865,-4.176689,-18.805558,-52.860276,-129.840526,-171.015061,-318.53962,-423.809232,-387.804399,-167.789763,-58.965794,-5.456294,-38.967158,-110.929061,-153.502792,-216.621817,-95.821209,0.853596,70.052098,53.407543,91.03737,160.795565,256.672247,230.625349,224.285587,215.082744,181.527047,103.023723,108.511596,196.962732,221.107679,202.049902,138.96808,90.96873,-23.69489,-89.084986,-178.454174,-180.982386,-179.56527,-175.573368,-124.642112,-9.14706,-6.433165,-100.83546,-136.347868,-80.163202,-28.089197,-12.694297,-114.817073,-173.063454,-183.393467,-139.226299,-78.57008,-67.999971,-10.400341,131.760217,217.112022,302.226793,285.220071,232.07602,220.600693,182.867213,146.807355,71.049656,-30.859411,-97.713654,-185.013878,-185.477298,-161.708122,-169.219742,-201.8219,-216.088257,-219.034473,-116.790205,-4.184707,108.3317,53.157155,-99.749343,-134.684439,-118.914144,-40.455299,-11.232391,-2.545832,-15.791871,-51.020231,-68.567475,-165.443306,-300.595811,-327.508017,-314.5941,-282.018401,-187.711798,-160.554127,-186.927844,-232.019349,-283.98697,-188.106748,-128.462938,-39.065225,-13.243585,-29.961366,-52.898939,-62.809575,-24.044162,12.433326,137.655273,213.997267,265.523586,207.542043,17.708671,-53.85538,-94.287081,-64.056381,-42.803491,53.502094,119.755815,205.984076,203.138845,95.379231,20.640556,29.927575,79.453709,145.453523,377.687971,467.178264,450.21263,375.267348,274.983138,261.482525,249.026645,216.002633,164.658998,-15.316297,-73.227589,-120.779455,-171.307708,-157.232738,-48.812449,-5.798882,9.283154,12.450649,30.338454,16.955025,-18.733866,51.384611,95.805119,132.408034,125.049215,66.003564,38.379215,15.283195,4.758306,28.573966,167.512359,262.946912,406.097251,397.681519,229.404845,149.203218,147.932822,275.653043,311.262251,273.498545,237.992525,275.094307,321.889454,240.861512,85.564552,100.705795,218.809187,244.990572,174.340287,110.915126,29.544414,-6.966571,-57.046873,58.606647,148.858119,254.886965,222.496418,53.198877,4.891776,33.702501,105.144447,140.566013,170.498783,155.423305,101.280262,76.338874,39.931504,24.498301,-27.937803,-92.045537,-94.175036,-34.184757,-11.073745,-42.12149,-89.384482,-190.792503,-242.568541,-236.812009,-182.531728,-156.15919,-112.529086,-77.327735,-42.378101,-95.142121,-183.310733,-3.228811,89.888126,66.772312,-21.587674,-193.861827,-235.856755,-221.084628,-149.898065,-111.516411,-57.084044,-51.002402,-110.929695,-166.165999,-220.802266,-220.055072,-247.279435,-300.747039,-295.687043,-152.17801,-72.692825,-112.898335,-217.344515,-367.281895,-223.844696,-108.992703,-39.834522,-46.667765,-3.176167,6.666186,-12.22132,9.418607,54.485325,-5.928863,-1.248485,146.57107,190.84319,49.554262,-79.494021,-269.304639,-287.432229,-238.559193,-157.611592,-168.206775,-252.904092,-272.333688,-171.543126,-84.482615,5.150296,1.109848,7.763549,14.687031,-4.217157,-21.941109,3.234263,26.098247,-68.832592,-140.281453,-235.58343,-219.003808,-131.403475,-124.271462,-175.161361,-170.812441,-3.324816,219.775645,266.194877,222.467737,171.079987,98.637605,90.414718,85.252602,57.889842,53.473835,96.87196,118.122297,27.663408,-98.520451,-361.84285,-430.658158,-414.437122,-312.720735,-276.604721,-270.168527,-287.999021,-312.908681,-305.665743,-241.062231,-163.99609,-127.560466,-28.791052,27.39053,70.656183,38.374985,-87.164025,-148.630794,-149.681592,-18.350694,23.710426,47.942672,55.919408,100.136029,121.228276,99.843592,145.649247,203.872084,246.226562,239.80866,247.139117,244.050314,162.440282,92.612518,-26.644523,4.548768,70.270631,179.965577,208.558012,266.160396,306.007941,385.388267,403.273127,352.081629,186.808418,154.091997,209.855251,213.064152,69.666999,-41.330952,-194.365553,-161.444529,-108.839306,-2.016104,33.862305,56.711131,57.499331,5.628246,-129.398311,-166.451333,-47.167834,71.033538,140.312608,73.838122,-45.31056,-68.941017,-91.118339,-41.920537,-0.21447,71.44723,106.908385,162.872332,181.04488,218.060171,217.891564,191.647084,166.329544,180.725131,158.748696,108.25389,21.587795,-14.706058,-84.00262,-68.891491,-40.836934,11.511078,32.346827,32.732242,8.334909,-5.801942,115.207856,177.679539,158.951065,103.442073,99.1826,164.641721,231.417807,180.679435:backward
20.19626,67.247442,52.400676,-61.938011,-120.895108,-98.057617,-11.195098,157.058916,220.472865,244.213426,283.022482,283.433854,263.577929,261.911582,224.060859,164.862917,93.39779,107.412833,82.188146,21.611402,-4.993342,-121.953428,-173.452469,-166.021503,-48.175881,29.784565,119.57206,101.937782,-41.520198,-118.908762,-118.47639,-53.269161,39.91238,63.822111,63.012241,-16.960575,-103.857225,-273.35934,-301.925333,-213.580372,-14.068292,50.29411,-14.260674,-93.155787,-189.683727,-206.115072,-171.283513,-107.123591,47.381141,66.103588,1.424706,-186.19007,-252.961557,-224.095046,-146.60124,-47.631926,-71.895751,-90.090659,-115.187388,-124.355856,-161.35492,-195.877363,-250.457403,-252.952653,-194.617535,-160.95668,-209.351872,-315.044279,-312.544959,-254.132128,-222.116864,-109.863631,41.056936,71.683529,30.381649,15.170251,29.166355,26.700207,34.992619,70.461168,132.906168,88.96602,42.086047,-13.761028,-27.041943,-65.01476,-58.377866,58.597015,136.00301,107.014719,67.618536,99.496095,135.586593,116.016101,123.293363,172.62325,306.568566,326.5028,267.079705,143.91627,105.779774,54.832984,59.610036,105.593722,131.496388,151.737324,166.131867,127.85197,9.372909,-21.594263,0.885418,34.769353,170.989058,310.753153,277.795972,64.256988,-10.398927,-35.590614,-41.569958,-91.230691,-109.312267,-98.836891,-34.809866,1.083454,-19.962852,-49.495142,-20.354845,-1.78609,-47.560795,-91.696743,-96.501995,-46.702412,-10.300822,-45.193674,-86.374758,-44.750151,123.302351,193.409573,207.994585,147.471243,-18.174933,-61.12864,7.173954,82.343487,248.349598,440.744947,490.173823,456.938888,418.019376,321.883965,266.206674,210.487166,207.598275,178.192219,64.182383,10.681159,-90.685444,-139.845066,-139.993861,-75.753615,84.685963,161.2017,153.776265,98.339682,61.683306,-17.688588,-45.937486,-58.902143,-11.21815,-4.922426,-89.063643,-143.80454,-217.313902,-249.572125,-284.328229,-252.547125,-103.732392,-42.28318,-85.558891,-193.181135,-215.743435,-223.856326,-210.651555,-126.925754,5.285324,69.196331,133.336425,123.373473,16.96049,-51.648069,-100.889526,-77.521771,29.479954,167.668336,206.05266,219.41716,189.787116,101.070292,111.76825,238.91434,307.211697,303.398309,244.425987,195.788864,79.51733,24.720496,-38.592487,-53.646095,-56.650189,-8.868046,-10.842719,-64.807476,-75.537694,-47.931211,-24.873014,11.955479,49.860848,75.161501,94.420172,83.670462,22.984443,-20.582116,-51.614615,-26.289608,9.547431,-89.723894,-161.334564,-222.140087,-226.723978,-281.994499,-301.851169,-255.247303,-227.704724,-246.666414,-214.860154,-138.375068,-59.886751,-127.116893,-306.02817,-310.794556,-121.138619,118.429041,186.053916,179.407947,103.310297,-78.997153,-102.340341,-7.109146,49.464727,27.511824,-84.569427,-158.383664,-295.006937,-338.337449,-331.043442,-283.184583,-156.693419,-67.106146,-48.019271,-10.729475,11.835932,-7.975907,-60.064703,-162.577369,-159.202494,-122.868937,-51.95727,-55.089952,-171.734579,-243.977363,-252.556067,-174.534904,1.453818,-2.248742,-55.243803,-99.670262,-92.058057,-61.37512,-18.687998,87.453117,123.341515,110.298894,58.220242,38.175184,-12.424584,-58.672874,-145.737534,-152.980907,-51.344704,103.451493,139.243753,102.561432,65.931018,55.08833,83.790601,182.767058,305.423992,367.436107,482.994768,509.129594,476.84505,445.083131,371.339476,337.743956,351.118656,366.986866,300.286872,139.288287,121.250098,156.414261,161.594955,165.985695,207.584059,203.435945,122.48154,104.51903,187.404141,240.708119,264.997344,260.953558,321.929906,360.331349,321.514915,186.637925,122.025982,67.341612,92.887843,162.780973,155.152759,131.763546,88.501699,78.602289,87.976757,108.589047,165.886697,192.877137,301.096975,517.418777,599.170115,598.539239,531.904364,392.156926,343.700417,247.354916,248.159924,298.972674,298.001532,219.165946,10.225453,-70.742929,-87.360865,-36.719321,82.390382,161.922154,165.087661,131.078401,117.878137,117.000316,125.867646,152.021502,223.788932,292.314343,412.062687,406.722401,245.646664,157.589741,138.44102,180.792527,197.058839,135.603152,124.990356,203.155353,265.210731,307.522116,286.767136,229.383351,194.011432,187.232972,150.249708,108.366274,16.342339,-1.993705,75.265904,141.590928,217.300304,226.140541,206.354147,117.113317,75.0958,74.253221,116.681305,205.538856,318.721963,382.196693,368.381471,302.224175,230.874856,244.76605,289.366593,286.343791:255.330621,249.323807,126.36665,-78.992695,-80.19215,22.834593,94.026904,262.712335,309.295935,261.191264,165.445966,141.959368,80.247622,46.087918,38.182918,73.078978,176.149854,136.897466,60.106368,-40.234721,-62.968048,-122.609929,-136.811106,-62.605554,65.440782,97.420952,91.227675,67.472174,-50.403776,-133.696128,-183.749466,-129.509778,-17.934655,-17.618709,-50.066267,-170.706167,-242.345281,-309.351216,-296.417796,-208.488773,-39.532768,18.258215,-36.686242,-132.320093,-314.757927,-328.882588,-192.559663,-113.894076,-45.536617,-96.358448,-167.618647,-324.888254,-356.246632,-257.659035,-156.437253,-32.694793,-79.462613,-108.038914,-141.417727,-176.426811,-272.45492,-300.897201,-308.817333,-314.816479,-298.956421,-177.67074,-159.064622,-295.204405,-366.415618,-332.913187,-241.927179,-66.862727,-48.041229,-86.702579,-165.426287,-174.966276,-159.151529,-145.491865,-65.290975,-16.503477,-11.285697,-113.406545,-161.189134,-187.434815,-177.745607,-158.550554,-125.728465,39.969463,174.99945,159.398681,106.107274,115.954141,77.814023,32.461721,55.598739,104.365012,172.699257,198.431832,159.028298,7.325215,-57.799887,-122.669946,-128.510898,-98.931578,-28.328869,-10.668725,-45.618605,-73.584844,-123.567508,-136.55779,-66.133081,-12.086278,20.31616,7.375144,-17.385168,-92.181231,-108.367938,-116.737388,-146.186971,-221.635566,-167.915179,-127.033608,-139.728725,-180.756309,-270.231805,-298.965549,-325.720847,-336.871475,-301.403882,-243.925527,-245.553348,-229.04984,-208.2498,-218.447431,-239.107444,-217.847127,-130.765003,-106.135551,-104.691452,-114.156572,-177.755555,-209.542966,-184.071187,-143.568566,-25.838184,133.264832,194.527132,226.251469,176.539851,-6.263099,-77.090086,-109.719409,-119.11461,-163.017303,-282.237185,-314.512976,-308.916133,-292.40113,-245.192898,-199.433051,-68.159158,-0.673874,-11.609323,-72.282275,-101.845056,-131.848068,-124.810993,-94.252834,-59.333203,-34.032182,-22.083694,-53.828469,-155.767433,-188.108688,-161.180823,-122.669704,-62.427338,-56.061727,-94.516957,-225.633551,-271.954961,-275.315598,-241.830346,-170.757925,-136.933366,-126.261358,-139.063714,-147.131556,-123.577018,-108.044639,-63.200979,-17.134641,82.870922,110.62481,96.93229,49.98174,14.475906,-27.028727,-12.540155,37.376675,129.760834,176.313566,145.459941,71.117075,-114.132716,-182.338458,-189.424414,-161.974787,-128.714674,-118.940516,-130.2569,-163.505838,-181.690057,-177.959269,-126.507534,6.807297,77.643916,93.764714,68.237186,29.128418,-69.248893,-113.47424,-114.804395,-57.001864,56.721676,-35.047374,-134.917775,-268.455694,-283.818709,-243.158528,-207.608147,-165.266041,-160.174312,-175.236392,-217.301087,-214.103687,-183.992749,-200.348153,-264.577022,-246.56277,-59.960375,80.472944,52.840428,-64.82337,-84.550629,-50.321929,-25.54966,6.188058,2.970657,-12.018573,-59.609703,-101.505427,-239.758126,-285.65854,-239.306499,-206.165682,-198.04468,-123.484019,-58.736896,-3.775848,-35.051683,-110.951817,-109.649754,-45.377448,-40.939027,-73.633182,-138.328669,-173.363017,-275.37694,-296.807818,-207.96845,-137.685962,-43.838133,-53.666681,-56.551782,17.053882,40.135059,6.296451,1.266826,51.360911,73.623896,62.58088,67.092899,86.776081,72.280561,29.861143,-35.548005,-26.736641,97.675448,264.563245,297.121767,239.018027,195.788654,219.194324,280.310117,371.326187,391.714313,396.134792,436.873903,474.003818,510.703395,505.786909,488.428955,475.446747,455.381723,397.844215,329.169037,170.677258,115.435473,102.729877,146.085857,265.836077,373.657942,388.580173,280.737377,217.778894,256.780222,346.520529,468.435698,471.539084,482.185116,509.155102,486.441892,385.441858,331.371187,306.378476,338.461041,393.974167,405.25619,374.125168,216.433467,138.998498,111.340667,170.148583,310.638516,334.26028,371.186897,548.585353,622.685534,611.159333,561.004634,491.280765,497.451273,565.560912,585.168133,554.511687,417.388357,323.796878,181.342069,171.061507,231.426617,267.567845,360.87132,419.074746,395.416101,307.670467,300.06474,373.056764,415.418185,483.272209,559.719056,582.745203,549.723613,490.070232,311.728118,240.842718,225.668221,251.495068,281.269979,272.387493,265.492725,262.205575,258.504425,236.050367,214.035513,142.549914,99.578066,97.803928,71.909933,49.220122,8.076493,-4.25207,51.329005,126.560471,281.066536,302.158117,249.561023,100.210917,58.859564,120.619848,182.17538,249.451458,334.554077,383.517147,358.239324,300.171507,207.081609,197.589059,261.41316,294.46179:104.385233,134.897298,94.386252,0.908919,-9.845104,57.758979,121.50911,230.846651,247.042442,216.547212,145.434967,148.486132,169.49171,134.989482,31.628703,31.320277,120.209027,73.502363,-0.154934,-89.373216,-94.321454,-127.377507,-168.42936,-146.786289,26.87687,50.562876,-59.746339,-111.739767,-179.312715,-203.645884,-178.598732,-144.953332,-112.235205,-166.28303,-209.21876,-273.298564,-295.195078,-305.664569,-277.166183,-147.06114,4.257779,43.53787,-12.739516,-83.612935,-208.625968,-229.046182,-148.215209,-81.995245,-45.731268,-159.569753,-218.979308,-305.081101,-353.487576,-413.429755,-378.053599,-210.156097,-137.923029,-182.339233,-320.507893,-355.471024,-353.183259,-346.698329,-384.128795,-412.035511,-351.341329,-211.661357,-215.802595,-355.386154,-395.256307,-322.735725,-267.207884,-211.690931,-172.602536,-159.413051,-150.581642,-154.862375,-205.813446,-221.994868,-147.586992,-92.771682,-55.961547,-120.52731,-169.386011,-220.962478,-222.385942,-208.366231,-179.146336,-39.033853,16.385281,-39.440004,-122.028375,-110.714423,-70.982308,-47.335742,27.214093,57.84696,86.409684,104.860166,105.057014,30.156714,-52.950346,-158.772411,-129.688656,-42.580101,-61.154392,-90.369094,-174.746342,-214.678946,-216.340481,-178.208174,-92.473825,-60.853367,-20.25062,-22.716986,-50.164866,-162.856246,-205.759989,-176.94377,-155.851747,-192.597688,-158.072941,-106.799062,-90.292869,-148.654169,-297.217166,-320.543091,-264.436723,-224.367442,-127.127169,-122.140405,-180.261306,-270.788057,-260.228485,-159.946547,-124.299988,-126.785458,-104.38205,-99.0782,-181.744786,-258.055758,-383.686877,-387.63309,-276.595843,-201.726925,-60.886564,22.774843,21.65412,-29.916468,-60.542638,-119.340586,-135.558751,-117.719428,-134.731322,-186.901774,-281.608232,-297.506196,-297.959192,-277.862181,-189.754431,-138.563508,-34.64058,16.051298,16.757715,13.01091,-5.565911,-56.526342,-54.479975,11.80731,85.671024,83.680587,21.366306,13.673655,44.963415,42.28808,38.274494,65.92598,100.694675,32.067673,-29.836634,-164.195797,-199.469702,-154.893939,-102.293154,-33.60089,7.243484,20.227227,-20.462999,-55.191806,-58.603267,-26.627377,48.784709,73.027486,71.916033,53.908151,45.902595,-10.572074,-53.404024,-57.204696,-6.936822,94.669961,155.471086,161.485053,88.201915,35.743951,-63.257476,-105.341643,-130.555474,-119.689798,-85.68813,-92.094599,-122.2798,-187.502403,-198.349729,-102.541921,-9.769679,134.598212,162.494318,142.249291,65.682736,16.209668,-75.016306,-95.930854,-43.292394,31.889442,158.106683,61.847678,-44.899656,-168.356223,-159.935058,-84.781186,-55.039475,-52.765544,-47.68433,-45.095375,-87.932794,-109.766969,-114.175951,-104.206295,-56.283974,1.508984,145.839414,140.830732,70.463137,-76.712756,-116.41128,-100.668649,-48.245489,54.739746,-10.166627,-107.796227,-246.126982,-240.427608,-217.186683,-247.755531,-312.006411,-311.17978,-245.529601,-199.716047,-195.024606,-159.049607,-150.606328,-172.640967,-171.493165,-139.949939,-64.346532,-16.509893,-9.34747,-86.936318,-315.468358,-358.251772,-233.172101,-152.093743,-71.932531,8.540442,58.346197,47.592203,-16.728483,-50.363391,20.855169,165.718435,120.219234,63.123566,26.515025,44.343105,46.212602,7.206749,-94.359724,-111.347467,-21.162497,174.681942,253.060669,267.732307,227.52235,234.290187,283.293095,324.157243,346.132227,373.763469,353.999725,296.27598,216.779429,247.893436,351.578845,359.957901,310.226765,261.193026,233.536423,144.817065,100.425958,90.316194,119.228881,179.473734,236.610425,235.683846,158.895392,131.411646,161.445033,208.313484,285.561663,297.461686,355.896844,473.332746,489.874295,361.32287,253.227456,145.430997,167.583289,253.882185,313.604689,314.810344,254.173226,211.73576,141.263596,146.371568,265.368565,327.012638,358.507784,367.106308,407.616224,522.283451,558.150055,564.883258,543.117815,480.451173,460.386572,456.150992,371.816198,296.953595,168.674193,135.000343,155.367604,210.824976,365.314085,443.985367,421.464389,341.201745,332.568723,409.011542,478.993812,572.308432,537.698261,508.987234,407.135203,312.925636,139.834439,115.367158,167.013807,191.257226,190.342146,164.266751,148.302119,122.811074,105.560457,60.789968,51.05075,69.714113,103.047279,90.166602,-1.599201,-45.146323,-86.685367,-89.490403,-53.879075,0.692354,160.780689,155.923988,69.211183,-57.369829,-51.633122,52.238393,118.152339,216.759195,315.83666,357.075944,342.272234,298.79682,209.416104,186.542536,218.167397,254.528553:-69.173451,-41.257823,-34.147864,-115.049121,-184.304109,-172.167627,-52.909976,214.009923,290.981822,280.278152,296.094258,337.373869,396.81261,390.022741,325.773672,287.51256,245.129095,153.394947,60.230459,-107.244206,-156.041411,-219.510578,-234.297959,-200.080186,-80.915362,-28.241398,-25.568655,-64.775749,-160.292562,-197.556048,-210.007536,-181.118445,-93.633641,-54.973085,-73.739671,-161.180108,-221.197551,-325.021017,-327.243055,-189.083589,24.410612,87.393196,70.222576,18.764563,-117.359003,-158.683264,-57.571701,36.55597,101.717602,21.341539,-44.100296,-212.224379,-288.782747,-325.059609,-273.374579,-121.88225,-50.984801,-80.357006,-223.084834,-267.418615,-263.653613,-273.486816,-384.70265,-445.683593,-435.685954,-335.529285,-356.080282,-500.53195,-531.080694,-428.003768,-336.448532,-182.716806,-52.796354,-11.079411,-20.000832,-35.798597,-55.233012,-65.637568,-74.054555,-76.525879,-43.3857,-14.252573,-53.131251,-153.02823,-186.039972,-255.512013,-265.192784,-149.268049,-23.620231,-20.862798,-37.455677,-20.068879,-3.033189,-11.753933,27.425995,68.558303,131.663702,184.925818,173.077674,66.175149,14.817121,-21.642814,8.499349,126.198497,175.082972,182.517276,168.126229,109.284731,-63.10997,-102.052999,-30.738936,22.290089,94.885823,155.54765,134.633851,-13.182778,-76.080489,-82.678178,-44.237906,30.950741,70.119431,68.984093,36.010026,26.478678,14.032623,-18.310956,-69.567546,-27.807702,139.398444,152.946708,97.370637,27.70734,20.120729,-27.628314,-59.43218,-29.62743,113.407427,150.57559,53.426041,-35.293588,-161.067231,-168.326052,-40.682419,60.058662,234.899812,334.100412,344.002518,309.977115,285.189473,220.041851,187.893957,149.113663,93.199024,54.665168,-4.92079,-25.6684,-67.769002,-86.478168,-93.477123,-69.47745,56.844775,205.57373,232.668042,202.769957,161.625663,57.494538,32.184274,52.394381,72.6162,61.395335,15.644851,7.134006,-7.590538,-38.400613,-75.906544,-56.366891,34.86601,62.246596,-9.809549,-204.370796,-248.066568,-222.758271,-176.731996,-38.343439,99.615588,148.380435,172.272341,132.721467,-0.268602,-37.270765,31.177606,102.435079,218.029705,260.712565,234.300677,133.033476,85.115415,23.819678,26.659998,135.484687,305.424948,347.157903,310.938074,269.519876,149.885307,64.11386,-35.331227,-24.916872,9.69196,-41.701449,-84.773462,-94.439858,-50.442748,48.167113,77.932366,136.644768,232.474512,243.846468,149.253599,100.822,50.722737,26.859057,21.926256,53.070573,117.894608,76.49042,13.146035,-76.864099,-86.773183,-86.445651,-73.701446,-20.807834,38.44908,59.409453,65.322117,50.516963,-29.551563,-83.415849,-105.369748,-52.733125,120.628547,246.23202,259.075524,214.482539,151.356348,3.997134,-19.525325,3.075661,-15.786707,-29.153149,-68.825776,-119.620749,-270.476126,-327.029026,-348.462856,-331.627495,-244.398679,-110.185406,-81.37012,-129.951646,-162.000347,-157.773563,-137.794479,-116.133795,-62.069569,-21.579566,1.565352,-45.383786,-254.93416,-341.356147,-281.510587,-167.264403,11.524891,39.259733,23.324253,-31.050184,-65.995005,-58.236851,-5.041403,46.2319,0.352997,-3.736531,35.332169,43.841681,-45.593944,-128.60458,-225.364385,-204.190587,-28.242912,196.477898,238.903866,126.550105,41.674087,29.081433,93.932994,194.521359,230.627113,253.325275,295.150425,307.115996,301.932211,278.234034,248.150918,259.542314,258.008306,200.487513,173.802046,107.210151,66.465745,29.603722,45.753054,107.320735,173.895711,179.794934,67.28832,8.449295,31.72552,89.119348,173.727237,181.309518,172.403856,199.100691,205.131114,112.801228,22.325987,-94.016494,-78.02691,55.304986,189.846975,205.055947,113.223246,46.314715,-72.817909,-107.599099,-57.13113,18.19151,210.989157,388.433536,419.477601,398.508609,382.580204,350.005664,348.854569,384.037657,397.261872,386.08202,308.982741,242.789983,93.139281,33.626567,-17.993019,-8.648635,102.23254,281.760699,325.214327,291.052399,270.306799,300.530321,331.013471,365.2953,395.47395,407.435078,365.970724,305.010147,154.645996,101.768093,89.527697,111.01226,121.535029,65.065144,64.303625,190.302776,246.199579,187.947283,120.865982,55.71207,78.748353,97.177473,82.421295,36.118479,-96.637889,-124.635267,-28.283266,42.155733,111.417051,96.8156,56.69528,-50.12243,-80.638731,-44.519698,19.841046,151.48776,224.081309,255.854001,269.840513,229.071364,124.505974,113.234814,191.336007,238.872115:-315.850689,-225.814378,-214.852504,-263.585902,-312.168081,-359.263977,-296.054312,-58.474988,84.415417,96.4162,84.902695,89.406638,91.555032,78.012929,34.727271,11.522748,-44.056195,-187.458724,-269.683878,-362.641001,-386.484292,-437.37586,-461.572886,-445.356783,-308.175137,-251.770536,-253.293669,-300.963405,-422.496411,-438.033966,-329.826593,-261.146991,-207.43214,-284.0117,-354.304946,-474.18263,-496.280304,-474.202945,-439.144338,-294.095898,-51.132803,19.517151,-103.21754,-223.951957,-316.056316,-282.057205,-190.13757,-146.343679,-62.137817,-127.437832,-223.090444,-420.870278,-497.189155,-538.803978,-490.822558,-331.289437,-265.904724,-310.816353,-449.095837,-477.153748,-463.488919,-475.389065,-585.216263,-626.797165,-528.645545,-394.319735,-427.696244,-593.579172,-620.821224,-512.151905,-440.920205,-307.870636,-145.97134,-119.868653,-204.904362,-258.785362,-300.565171,-269.39462,-145.515702,-105.066303,-96.018175,-165.048409,-225.641499,-344.440644,-386.950646,-402.643034,-370.227751,-250.130142,-128.482402,-100.98497,-126.514473,-177.026773,-284.175406,-282.79679,-168.766257,-103.936197,-13.895772,-42.985778,-99.14429,-165.468479,-169.078817,-186.786545,-183.2777,-85.044354,-1.485202,-21.170576,-129.339292,-183.9851,-258.158702,-262.206296,-213.654987,-190.491138,-159.563936,-153.046147,-185.312003,-312.423115,-362.021303,-310.135481,-217.365885,-56.258016,-4.93145,-21.069823,-132.810498,-195.73889,-254.97752,-245.672436,-142.431075,-53.84833,98.020978,57.81692,-27.172286,-150.234767,-142.096466,-64.795564,-41.888629,-4.072519,57.398481,48.559574,-72.910259,-148.66945,-262.118341,-269.657006,-149.192082,-51.064759,121.446137,139.497177,71.034622,-105.00284,-143.998251,-84.286755,-42.984265,-48.237394,-87.667709,-99.558428,-145.34982,-182.469939,-226.937305,-214.725794,-149.514734,-96.287433,54.882071,88.445313,46.364787,5.195114,23.763127,45.033819,25.993063,-22.247172,-31.407532,-33.440955,-30.572945,-23.9557,-45.372803,-66.520653,-36.880287,18.022958,101.463375,12.650868,-74.096892,-182.388526,-195.969466,-178.30639,-128.170272,26.131377,81.917233,68.939564,63.326889,81.255191,89.01317,65.694025,30.477859,55.176622,171.009501,150.271008,73.300863,-51.787858,-81.328402,-65.441853,-10.489522,135.230155,231.282116,245.156526,212.113506,164.874215,-2.551322,-73.807779,-60.118844,-4.944464,49.002586,4.029723,-35.936758,-120.450878,-142.399891,-63.53624,34.761328,205.761471,273.68521,285.272514,263.337805,229.927134,113.192802,57.346005,75.607031,146.512125,260.185644,167.277414,78.716795,31.746339,65.952156,87.843091,85.27629,146.947604,197.747989,178.636031,114.684901,94.083031,52.527933,31.243133,39.251157,94.571091,268.13459,285.762704,224.190036,119.145647,80.258994,28.650122,50.850681,132.018087,107.905046,62.769537,-16.706667,-39.972057,-105.403897,-150.082229,-209.744212,-199.124585,-23.034459,144.087679,118.780605,-24.974681,-72.21723,-73.517824,-41.497675,15.539678,116.803483,180.432606,174.9426,87.800528,-127.077055,-175.4636,-99.971032,-29.155303,90.50436,168.004837,175.29211,116.486009,66.830942,16.512468,38.425104,129.183652,185.638682,160.539192,25.900233,-25.543123,-63.752218,-65.185923,-24.209435,13.967599,121.954824,234.927199,252.837328,193.058794,147.988703,142.462817,183.554035,247.835313,280.929498,291.66479,242.45565,185.793499,89.942914,72.895109,61.191369,58.861159,136.878879,244.804631,239.006253,99.263168,7.331024,-56.524075,-4.832187,103.204125,92.216257,76.080196,29.918954,-18.437658,-74.347291,-22.673127,122.040841,127.335411,119.212021,224.424714,234.016726,77.621299,-30.026062,-101.869191,-63.009151,45.741696,201.20589,242.399267,138.04843,55.485716,-22.488131,-3.985033,134.603497,210.297854,309.489268,401.355272,416.715596,348.347133,307.965684,307.16057,343.307415,404.220553,377.149002,349.507204,294.229756,246.891339,95.243395,34.344209,34.398415,77.441003,173.708229,266.601923,303.182138,322.290339,311.41424,321.426783,365.531095,479.138888,497.694776,463.547111,334.828737,253.828055,123.799998,97.924921,116.795622,138.74196,140.760662,63.748849,34.96093,53.935262,79.357333,122.631901,135.646847,102.981764,84.298167,110.092424,90.978645,17.414321,-108.171432,-115.149376,-43.922231,22.532254,179.601668,244.62249,197.323059,-9.835521,-93.462036,-75.112673,-0.623881,170.626689,358.837177,396.076745,259.470071,150.541598,51.714142,76.362974,181.469926,235.588068:-227.600497,-249.8361,-276.249025,-300.107522,-292.185703,-260.153369,-222.106262,-56.865932,160.447156,228.92135,242.758547,225.181823,225.508657,245.673964,243.075516,179.366987,4.791968,-91.263142,-130.046025,-176.683196,-168.959614,-169.192334,-201.316309,-277.185292,-233.26135,-162.664462,-73.684144,-104.704788,-267.989956,-315.847411,-252.683553,-197.559743,-137.695042,-153.587919,-188.770931,-253.537862,-287.482424,-392.907231,-432.129094,-352.279195,-117.429616,-71.978721,-212.908217,-293.677849,-290.395455,-248.13535,-182.557303,-146.623803,-54.646996,-22.885117,-71.589565,-272.283741,-356.135336,-324.463336,-225.886916,-99.743741,-173.898805,-228.443916,-290.879775,-285.662173,-255.308336,-281.691624,-420.93989,-472.967409,-462.012106,-452.578082,-466.226001,-491.394821,-530.000847,-565.114632,-492.801973,-286.967831,-179.07329,-152.938225,-117.646571,-95.515394,-99.842697,-128.710993,-139.782858,-112.969101,-31.766227,-65.44412,-167.24906,-324.755902,-311.454476,-219.836016,-183.882755,-118.083325,-75.330982,-77.347005,-124.949515,-142.858052,-142.114743,-130.711083,-39.604315,25.603925,59.962058,-17.873175,-58.157426,-72.288504,-42.86879,2.257018,17.08306,97.016108,172.721958,183.796914,162.930043,123.161548,-6.323846,-49.630417,-32.936527,-8.84182,53.781976,108.184829,89.240453,-6.287982,-46.333655,-45.420624,-19.096581,-18.755034,-71.113527,-85.189625,-81.77181,-70.780058,-77.098843,-100.884738,-109.193455,-70.82974,38.204225,60.463202,0.30065,-137.985106,-142.915943,-80.832594,-68.812685,-64.513552,49.640358,115.763221,92.026111,-3.766094,-197.857858,-212.878743,-14.992322,127.135732,313.103937,371.625778,360.069797,309.096808,292.761919,251.849666,229.364866,225.091019,201.106415,148.81975,18.100096,-33.817139,-120.389514,-146.30893,-111.647574,-78.796698,-23.136217,100.627487,158.656839,149.778025,78.388896,-117.573131,-195.866253,-227.173,-90.107256,-17.021323,-4.374894,-66.495278,-248.304533,-314.962489,-283.880929,-205.341218,-86.361332,-111.348364,-156.000023,-252.78148,-286.503261,-281.733605,-247.86071,-136.434941,64.784761,153.520438,173.561642,129.26592,30.493136,-9.821239,-29.964159,-7.996481,98.896694,204.241969,201.182892,151.006623,129.734021,99.874597,124.380391,270.58342,408.121401,429.434244,372.467414,319.107274,182.343737,103.209499,-19.371213,-61.325548,-93.107566,-45.614855,-30.779132,-41.85138,-56.214465,-75.239007,-77.586308,-89.729478,-37.527831,27.326131,101.010284,86.195894,33.966949,28.500946,86.997177,124.399228,149.629114,119.466439,88.881401,45.777856,38.130273,-8.717757,-40.409574,-34.986205,75.580538,119.979981,103.223317,88.218251,113.398927,103.499714,34.818185,40.972523,191.809258,356.820518,393.598305,423.086068,398.322714,209.627901,116.227831,97.669649,200.165945,233.460069,194.448306,142.13832,26.563612,-37.144186,-104.066107,-71.470095,107.099556,227.228305,214.680181,162.906245,166.982773,200.652667,205.24308,181.908641,178.698549,190.633801,180.560614,141.424097,30.691479,-10.821876,-34.428797,-5.775558,139.067091,219.698566,193.746393,102.38833,61.747211,52.77644,100.801247,199.746711,247.936189,257.266277,195.120305,135.20765,51.693656,38.269966,19.44277,2.93714,19.640267,181.684807,262.50192,261.982523,186.496974,63.341418,81.612989,254.051343,418.477861,444.607057,372.842695,323.940598,305.383802,303.994595,238.108405,203.586662,243.455811,339.404169,324.649899,246.424602,229.286509,191.055288,165.964173,146.013875,193.182706,203.059764,102.803166,54.48246,94.444123,134.045292,123.731923,96.848244,107.38967,163.496692,163.220183,61.825008,-25.094735,-129.752453,-98.50133,50.409215,139.688853,155.636186,82.000509,-11.627103,-159.960773,-161.875563,-19.903633,82.272522,255.137365,374.607442,391.907247,340.762098,287.839936,178.04447,150.679452,130.735292,132.598402,144.489398,97.923914,12.351896,-197.823004,-254.998249,-216.42857,-170.729992,-131.328484,-61.1099,3.801863,99.727373,105.492445,75.640303,80.424554,144.310504,176.768893,187.370684,241.037131,244.159694,96.533647,-0.983344,3.542456,80.733939,117.248511,14.236425,14.447544,192.208263,294.959431,346.341587,313.35539,255.558619,248.419007,247.445495,198.163926,144.438891,40.408622,18.534511,58.438408,112.241618,228.944996,267.934066,238.12438,113.415778,60.983502,76.225621,129.878345,207.139172,251.115873,276.915116,279.419359,243.637876,144.305576,125.955858,235.750962,313.072002:-364.14863,-414.579196,-477.857237,-540.738624,-536.438036,-481.260547,-427.399629,-297.897766,-136.431844,-42.096039,96.389475,117.804687,86.305876,64.931156,28.6929,-15.900863,-131.78931,-221.962835,-291.760688,-461.247822,-511.926233,-501.26282,-476.349818,-464.944544,-377.108107,-303.884055,-278.429118,-344.689909,-491.667097,-500.052411,-380.611204,-318.244566,-276.234651,-292.576159,-320.085979,-466.139783,-550.747555,-548.880185,-460.888061,-263.61692,-110.408883,-76.245904,-156.253064,-218.860759,-291.100244,-313.193898,-290.520844,-233.200332,-64.312006,35.979917,-8.710025,-226.027495,-311.622967,-325.035433,-262.333207,-117.752654,-120.004228,-174.55524,-287.458095,-331.389265,-475.591242,-567.341169,-639.745962,-610.708533,-486.863306,-414.252282,-448.810081,-585.417301,-622.672958,-557.86747,-468.311478,-241.905712,-57.99613,-41.806793,-149.620033,-203.344477,-229.1527,-211.15635,-124.977063,-80.519151,-47.344075,-68.511231,-100.486881,-209.730501,-283.242673,-424.217484,-432.510836,-264.309022,-132.643583,-156.120726,-256.291502,-272.523046,-252.401618,-250.306227,-215.160138,-148.353892,-4.424287,-22.802636,-76.684644,-155.144481,-162.995294,-94.010196,-14.069957,138.990632,179.411842,170.63322,119.572331,61.656655,-100.710918,-153.44324,-137.443356,-101.133209,-33.649736,-9.331054,-49.989199,-201.351448,-253.708131,-204.231952,-114.29446,38.845394,14.284162,-43.640057,-138.329743,-165.26052,-223.630351,-238.842201,-114.864753,13.131332,202.644226,149.506256,44.724099,-140.399873,-164.551245,-122.379344,-80.969812,28.967925,83.195855,51.36266,-90.350855,-156.772969,-224.381387,-191.339044,25.991709,131.605962,200.512716,145.362846,104.664197,56.627874,53.379424,83.294858,107.469166,99.251906,20.967934,-1.359305,4.478309,-21.897696,-197.029983,-259.670377,-155.559366,-48.423911,82.547572,90.529768,83.696282,86.785232,61.42547,-68.089864,-122.177662,-138.893009,-50.333754,5.677614,22.935918,-31.8229,-195.077791,-245.10432,-212.117517,-154.591862,-27.655347,-25.631008,-101.792822,-293.425905,-362.878316,-353.067072,-249.801556,7.832302,96.415677,90.414227,82.76681,79.818474,18.633865,-17.521618,6.790096,55.354718,135.599416,132.962282,109.113619,39.908433,-11.218429,-53.002873,2.402514,205.693571,338.261142,345.339202,295.557237,256.927291,153.069333,108.578404,93.275106,91.098262,27.382708,-18.80949,-31.536359,-115.36282,-170.323011,-165.740751,-93.749107,82.289853,192.484281,189.826,85.149276,31.160299,-23.879487,-14.551438,76.742333,113.891729,139.296667,150.04357,125.382801,64.555214,60.482056,58.311955,62.94337,144.236378,245.689487,252.555109,168.589867,119.220502,86.076498,93.757119,102.205929,111.111873,206.041218,333.33467,359.736351,308.446333,233.68395,98.531226,101.56639,228.628651,295.953305,274.752718,192.836504,148.134391,59.552718,21.457522,-33.368716,-30.210313,97.005741,248.609987,257.888463,142.162213,68.294593,49.329543,106.40958,175.950277,206.137296,261.828636,306.14322,233.850557,25.251173,-21.331457,43.033224,112.805121,231.088309,247.895765,222.94013,137.691624,85.790117,47.218957,95.66944,249.353293,303.284341,284.684295,179.184485,98.946987,-59.728741,-90.982779,-10.992029,62.36374,204.956911,293.932767,290.139155,164.690757,82.756973,38.213114,80.499379,202.2628,312.735496,332.711921,268.083257,206.082268,102.536429,86.962805,109.35888,121.356644,161.127482,214.482066,207.572046,143.694777,127.384108,134.749475,137.092685,147.868478,209.347538,197.290245,5.07997,-81.521793,-55.280293,8.122827,58.157149,39.638024,28.554262,110.374986,129.987423,-4.726811,-119.270107,-167.237721,-69.465283,161.360998,249.458902,220.363446,56.516775,-24.913167,-106.816907,-101.268958,12.224145,95.71608,240.432321,348.149069,368.84797,320.016628,273.732329,223.63416,229.01684,256.609025,312.620062,330.955918,256.0889,166.091558,-32.840397,-103.147466,-142.404991,-112.046458,35.35552,182.815472,207.183831,197.171487,192.782546,234.087462,279.226402,348.669766,372.505633,360.683657,265.136833,202.648686,103.657179,74.888474,58.392545,61.3827,76.759458,71.09258,64.703076,135.290467,204.131382,298.415617,316.559674,337.155979,310.695581,256.833728,103.308329,32.286465,-75.87077,-92.388158,14.741751,117.149371,282.814214,231.92199,139.182296,-17.81687,-65.867234,-96.749292,-57.264079,87.582092,234.07601,292.424276,276.682887,191.863003,32.162139,36.667943,215.3676,306.696211:34.30104,-53.075314,-113.257001,-148.46511,-124.500554,-107.321723,-90.383185,65.11621,199.315208,200.516555,186.684454,206.340695,246.083189,242.190276,165.751167,97.102716,-20.095656,-21.570902,-9.182098,-20.710019,-25.027332,-5.770121,8.029782,32.705524,49.098744,54.039162,59.516991,57.534505,48.62492,57.234443,109.002556,112.694248,38.857968,8.275701,22.307374,6.163709,-51.641288,-213.321709,-259.098804,-237.837568,-164.935812,-142.007764,-188.8293,-228.145524,-218.912064,-207.59251,-239.12,-237.587866,-135.899458,-8.558612,-13.502668,-168.026452,-213.25605,-48.784742,91.38976,185.561964,51.384914,-9.764864,-62.428967,-56.139847,-51.957094,-107.673494,-263.322911,-277.318597,-180.458067,-183.38604,-236.528975,-314.571311,-346.68778,-449.979835,-467.666246,-337.59699,-181.884053,-151.847648,-126.065374,-95.5805,-35.929945,-48.096944,-85.605798,-54.582522,83.652428,159.724934,150.215423,110.196964,83.084428,-2.605839,-17.769096,17.472816,-4.402649,-28.464529,-94.664271,-134.20985,-108.835915,-47.561293,23.994642,26.723722,56.447726,59.571078,18.103052,-29.46517,-25.10148,-59.02959,-89.030071,-89.746083,-0.509079,58.383477,118.641923,96.600274,-12.970975,-45.996382,47.125877,124.85983,154.08406,121.803013,113.313474,38.850707,0.350157,-27.306009,-51.759718,-77.533792,35.456502,76.03832,61.341444,46.027329,8.269904,-10.034454,65.327635,151.243638,251.000024,140.024776,53.858401,-17.368326,-14.050827,-19.253588,-20.082471,-9.374363,48.304372,114.351403,234.264054,245.26776,166.705641,131.972936,209.490568,304.685339,449.696308,412.756466,349.034097,276.449679,275.598293,257.315107,245.346863,261.428947,215.838137,119.951612,-103.875048,-150.249108,-129.975221,-111.753257,-54.667849,-20.608507,28.455175,95.032912,130.008671,163.120626,154.323715,81.101277,29.307044,-27.808629,-19.499587,-23.55624,-66.312099,-101.365928,-174.826896,-179.18885,-109.264495,-70.287439,-2.285354,28.786673,15.296084,17.406912,37.507784,15.161066,-24.342533,-58.606144,17.22241,57.598633,65.226224,48.892074,-3.463425,-24.343429,-7.369524,13.312404,70.155182,179.300977,238.536147,305.617206,298.691908,239.067589,225.264159,254.797483,284.139066,265.991873,164.13943,121.519892,56.104109,7.993346,-50.746153,-50.738902,-102.924051,-174.211235,-158.338885,-118.823445,-140.762822,-206.704978,-218.621632,-218.108591,-165.015102,-99.939255,33.63985,81.959638,122.13129,109.030544,80.691651,84.624094,170.457936,328.412233,344.06139,231.053577,173.217122,117.555303,105.867095,90.071536,92.907618,113.574557,173.116919,200.666615,224.100513,201.86804,126.872434,113.868155,173.655486,240.975932,251.017428,281.651816,260.697382,58.442854,-39.597583,-75.097369,39.036864,96.851812,75.955122,15.042978,-54.100249,-69.1989,-105.486753,-69.835225,141.278142,269.234977,251.683634,170.692565,147.204229,120.407533,117.873238,165.862264,257.996676,301.536636,321.959675,287.817025,168.719921,105.157175,88.320098,167.233602,380.322129,400.095742,330.113845,220.154319,188.287552,102.047435,86.236505,165.599571,256.618708,266.014468,154.095124,53.993833,-66.690393,-69.440744,-57.60561,-70.192347,-89.251521,-39.420728,-29.118998,-75.482325,-113.220117,-171.950289,-157.60753,-45.922218,62.325808,132.219705,225.394251,199.190401,96.472309,69.449284,54.043269,48.769614,59.312394,134.694489,163.784854,162.769164,134.764611,5.634511,-71.611154,-174.501513,-187.684546,-179.017491,-179.204521,-175.115662,-156.437981,-152.828492,-126.282232,-92.807645,-8.869743,24.382173,-10.997632,-174.51181,-255.305856,-297.726915,-256.695039,-151.914895,-77.430866,-38.318392,4.974669,2.274879,-22.731974,-50.86493,-110.391919,-119.066179,-71.240976,58.181914,103.530106,67.750163,2.450422,-115.165699,-133.702564,-108.496616,-94.286321,-113.005747,-214.358941,-294.949153,-497.518888,-593.567007,-654.361341,-616.88283,-528.724862,-480.655885,-456.299484,-364.331291,-304.943426,-242.462042,-242.591252,-218.734146,-148.518081,-140.10613,-222.597871,-283.933238,-358.941608,-365.210847,-319.645453,-267.137618,-179.779425,-190.243188,-180.507813,-59.451397,16.877755,122.424257,147.849557,132.941915,78.949559,69.633896,39.004589,17.813013,37.624577,77.483448,142.397133,147.009952,168.829668,228.430421,219.411122,159.334942,152.522237,193.930547,221.18812,230.879637,188.269619,181.705389,212.389781,226.596802,220.219691,233.734717,336.872276,360.042953:-14.424359,97.02284,118.721098,33.175915,-43.361098,-110.105353,-57.889617,117.415073,216.846155,257.987746,344.369642,360.889737,318.269807,271.915494,169.464778,125.739803,70.939517,69.23478,78.28476,94.32381,96.147256,82.537252,69.065285,47.104404,142.630405,237.386742,348.692191,319.667254,141.236234,58.949303,47.334852,94.411883,167.46214,166.645333,154.292605,131.534309,91.453434,-89.969471,-166.790067,-122.102231,90.775952,153.008498,103.235883,49.798323,-5.747229,-11.255081,43.380142,99.608362,187.106774,180.957181,137.983534,31.612332,6.009457,58.401305,129.556436,216.747711,138.70148,97.822222,94.621258,108.278556,72.757635,36.776887,63.934846,119.301809,187.245797,214.437119,207.670237,86.902457,-9.739501,-89.623691,-33.1795,127.461152,150.593786,119.780743,109.881121,150.648098,231.017975,249.378578,280.613003,285.183005,254.448783,283.762506,326.223018,398.323613,403.701553,328.695259,284.670797,265.504374,295.204542,305.996656,286.66726,269.051024,277.230503,288.340349,304.742853,332.759257,425.031927,428.092647,370.817991,224.221132,176.911457,167.328829,171.195989,144.208429,243.951104,341.173021,394.815226,341.972597,232.436022,191.333651,143.521721,166.853659,345.33793,514.221519,497.685532,335.43495,256.896369,132.549423,89.71617,66.31448,128.485001,183.891871,283.859281,296.497005,219.98011,176.657437,194.820934,232.144106,271.925529,239.414754,193.301007,145.566173,163.45965,173.878235,171.599838,261.112169,433.875881,502.785252,525.896293,464.305978,242.715945,173.985353,307.003793,434.504822,562.735003,657.127731,723.197921,742.171033,679.129282,536.4484,508.33905,532.722986,505.434888,436.377067,286.488933,249.980063,206.154508,175.060376,177.15548,235.76773,403.187143,460.596817,429.402733,379.800845,358.411664,246.144798,188.988982,149.155919,161.814449,151.545693,39.280237,-32.641292,-87.619182,-67.085466,0.229669,28.312057,92.843645,149.729231,144.085547,103.819214,87.182985,52.930476,43.769148,56.037776,152.776239,219.819665,269.402004,253.550148,185.112869,124.7906,18.784044,22.756726,173.621348,401.744815,476.288427,452.085832,344.57327,111.156207,99.668861,278.666878,401.134368,395.652756,316.92625,260.617086,122.342156,54.724006,-31.720182,-59.833626,-75.287792,-12.894174,-2.568019,-57.256853,-100.353758,-147.898862,-138.001194,-149.41613,-124.355359,-41.471424,93.009626,108.288058,95.866615,59.206217,-44.692579,-52.589741,67.499645,161.948432,143.860405,62.997065,13.722189,-122.576567,-177.236702,-210.02783,-182.145895,-156.486732,-102.011724,-62.533625,0.29833,-37.313646,-222.458289,-263.138463,-117.526238,56.259396,80.969967,62.700929,15.933311,-147.084595,-196.943175,-123.587578,20.20938,32.946245,-107.934407,-220.744191,-387.770345,-407.189155,-310.560677,-235.163043,-121.260536,-14.530887,26.870268,34.233538,4.612764,-98.325324,-149.333487,-180.453034,-127.88519,-109.963244,-90.892363,-83.642219,-155.44561,-215.710664,-207.462842,-128.975139,51.826869,67.872203,0.238908,-122.035113,-139.361643,-100.550511,-61.221303,1.112045,66.958247,81.820413,-18.030457,-100.097886,-190.31624,-200.65765,-220.29409,-245.930017,-299.870988,-228.854786,-167.849463,-160.985615,-222.857597,-297.542198,-259.223946,-105.485977,60.831421,150.904016,288.973398,298.583332,188.767081,115.619353,43.595343,39.520508,57.910894,103.320765,101.636322,30.925373,-26.048491,-156.136347,-208.724512,-267.684559,-234.662506,-193.156818,-141.806781,-134.509475,-144.170805,-153.683728,-142.509888,-121.514602,-41.477987,76.504986,94.945075,-34.909799,-153.000926,-287.483439,-240.15323,-55.001668,-49.565693,-90.628056,-113.375077,-86.768881,-12.381854,5.498533,14.194806,30.277709,94.319566,166.916504,202.17432,218.43316,159.910679,-45.300813,-98.714797,-39.841104,15.087644,-0.334079,-103.972502,-200.702888,-467.477193,-568.234365,-557.145209,-488.311323,-386.680975,-327.780437,-295.720745,-232.056215,-230.036274,-294.286633,-322.225527,-320.497387,-287.515576,-262.421438,-190.680344,-168.40991,-232.71881,-287.257136,-269.820963,-211.102985,-144.615922,-154.170864,-144.419609,-44.360378,14.738751,23.372686,-31.976183,-138.208504,-111.994697,-55.009335,23.070329,21.132127,-7.292078,-15.429768,-5.590382,3.483561,34.9226,96.710534,98.256354,15.66066,-25.189786,-40.79872,-34.124465,-31.524701,21.253405,75.353345,132.827397,114.330817,30.965061,6.047291,61.215971,114.493924:-195.326569,-231.418797,-245.247795,-239.814242,-220.246864,-170.532681,-121.847638,-13.640812,90.846099,178.015918,293.004427,274.254638,216.184769,237.541755,276.619991,215.528101,18.979461,-47.689081,-52.595726,-62.960794,-68.869552,-102.049351,-126.890107,-144.062589,-21.483406,48.090707,22.720736,-52.499616,-153.852156,-144.726119,-56.710908,-28.688041,-41.453194,-30.036911,-28.278286,-168.241352,-289.90709,-388.721486,-313.7861,-93.697464,30.678226,59.231898,43.205782,19.983463,-10.506224,-28.864221,-75.97535,-102.050466,-114.562635,-21.432709,20.032871,5.378017,-47.675444,-91.13603,-33.794212,74.187169,25.143751,-7.139248,-67.169983,-108.946601,-153.622092,-143.327476,-159.387965,-197.420635,-182.052498,-81.685584,-107.784711,-286.283934,-356.94721,-361.378737,-308.022525,-193.91847,-125.805019,-89.901974,8.091941,66.057051,120.08264,86.227584,-38.802198,-66.580483,30.501548,147.903111,118.960977,-72.494356,-168.750505,-241.794556,-215.335946,-113.819684,-2.526647,30.828186,-2.417458,-18.225283,50.517294,80.039519,48.638437,32.141667,82.335264,144.203088,111.081009,-8.785116,-38.858154,-52.622971,-22.782972,134.263497,260.691915,267.975346,143.527037,57.084553,36.137789,82.872284,101.409506,71.634266,64.626351,101.467185,91.856717,65.43541,57.391032,34.507014,44.886138,106.680702,81.657893,31.237563,-38.812197,-28.482727,26.229138,38.105935,66.690251,112.598317,240.271643,249.913507,185.839376,54.238268,26.598833,12.434922,19.067639,69.710517,109.452691,100.223265,45.528462,44.114799,122.161966,164.93877,246.222403,297.60414,355.770493,320.609239,315.124634,347.554441,347.210608,300.132888,275.897062,202.550866,124.727548,109.204848,59.882202,31.409905,11.978366,15.468089,63.570554,88.055892,79.290006,154.44081,228.598783,301.723617,305.722408,294.289698,265.492663,190.821353,184.599426,198.655957,165.874382,117.840414,25.77595,-17.509565,-70.003951,-58.609405,0.062876,51.964101,47.567535,-47.132741,-106.119071,-158.768214,-131.496782,-26.193317,88.065718,163.705473,307.164694,352.490158,284.979125,166.035986,-24.995586,-34.626772,83.49614,237.785243,252.935084,156.651476,103.79843,105.82501,187.56211,411.890611,456.393967,410.198934,323.096647,300.53621,234.543103,186.341136,114.416454,94.667652,54.584164,1.902178,-26.284359,-107.670841,-160.635916,-236.389465,-224.945964,-123.966843,-68.477599,-59.781395,-18.752685,16.034676,75.001292,104.321778,172.399162,172.250869,167.690532,257.578318,261.096987,199.325172,182.937183,180.504051,182.472597,192.115423,231.786022,235.344934,154.366345,112.295207,100.30752,104.397529,93.802956,101.946243,183.391421,258.076891,276.978167,310.377858,298.882211,179.463728,123.312704,110.914524,154.032431,171.131201,150.3503,86.918573,-102.548889,-160.523041,-132.555445,-80.702321,27.032134,65.308702,47.582897,14.028335,21.518328,25.014611,14.79643,55.894231,143.053778,158.733146,160.318802,163.178944,114.035143,64.219916,43.279034,87.684109,163.54126,152.290892,126.094206,54.64559,32.769974,29.45173,36.218433,63.583466,92.615934,87.044906,20.54166,-11.367233,-32.834134,-49.921359,-113.782201,-120.668313,-51.038458,24.913133,37.435463,-25.616275,-90.516169,-148.860832,-107.462556,38.263491,163.633565,202.75598,184.182369,123.450813,-29.009748,-68.248464,-41.954943,-13.178173,51.142782,148.752001,157.454188,62.735926,31.045086,70.518574,89.276506,38.254607,-15.260067,-17.05054,-46.12199,-71.262025,-116.287692,-125.613349,-108.007226,-112.55682,-146.37136,-128.278446,-124.056883,-174.889975,-218.262786,-282.437492,-279.607174,-205.89336,-80.902709,-21.2496,7.250969,-34.093932,-151.183888,-195.239903,-214.538239,-187.62308,-79.503789,42.181702,60.761562,-7.739781,-59.6232,-87.035725,-66.040703,-46.51789,-17.462391,3.607401,-66.848011,-174.161118,-391.302996,-432.067862,-376.427404,-339.715154,-311.879518,-249.414007,-196.69831,-95.762656,-57.071925,-7.43327,10.33606,49.733386,50.321089,23.405092,-41.502956,-49.17683,-48.002943,-87.219809,-162.932442,-146.59799,-105.570597,-120.428451,-94.973956,70.79354,156.558096,210.799774,190.423241,116.998531,100.028089,103.993987,23.277022,-27.286412,-27.709285,-20.477836,-78.571479,-102.644071,-46.017723,24.067145,4.15065,-29.617323,-12.211158,8.847472,9.410709,24.723673,86.083929,128.858789,158.331856,135.088532,40.491531,20.640591,140.076138,216.896999:backward
54.768011,5.862221,13.792143,86.311172,114.662756,37.777643,-71.842331,-257.408392,-259.883144,-212.802385,-117.347454,-108.986471,-140.287795,-138.613936,-133.931385,-168.035498,-296.953125,-350.760993,-324.30088,-267.52558,-259.45384,-255.402126,-249.41371,-238.671136,-273.10448,-304.067119,-291.736085,-237.505831,-185.508432,-237.494739,-432.334681,-508.301774,-540.240971,-527.710283,-548.567924,-594.498541,-578.958199,-511.35174,-491.898318,-432.998885,-318.673956,-263.654901,-177.234588,-151.096604,-102.36025,-66.197921,4.335243,14.966864,-37.025281,-15.748638,74.669202,288.263388,350.315973,336.654676,264.91525,41.200031,-186.250835,-245.410426,-192.493108,-120.660259,-27.186204,-34.312746,-118.407062,-148.693024,-170.531472,-185.908,-168.24043,-55.947874,24.016196,121.479936,106.678499,-20.314636,-214.358971,-276.985984,-209.278001,-92.609013,120.931209,127.17456,-47.6288,-137.721214,-235.887917,-276.721331,-262.839409,-165.675891,-127.115117,-126.194285,-126.143622,-67.498929,-48.364715,-47.824066,41.685795,96.688211,88.574244,30.152781,-34.357062,-0.414627,51.614016,-32.253129,-67.184112,-64.27625,-33.101246,84.695589,145.335655,148.461177,-53.109078,-161.549993,-212.108621,-139.989598,75.293957,145.664746,137.478517,89.779521,-6.372547,-43.828613,-29.974927,-0.421565,4.456546,-3.12381,-23.20308,-49.122998,-19.304764,16.723211,144.856255,215.975101,285.073228,260.990217,114.615267,52.472136,20.543906,3.6056,20.788629,109.732873,109.382376,-75.447856,-183.381322,-205.178761,-108.844023,-87.030656,-33.185202,6.328558,15.487158,-29.831482,-131.306034,-156.632857,-197.345257,-215.063399,-182.33942,-102.87206,-89.796678,-120.868116,-135.597354,-114.926475,-131.165204,-171.388358,-257.660519,-291.002065,-272.237099,-214.19316,-143.748016,-157.355898,-199.797003,-171.013851,-138.306742,-109.149027,-107.18389,-89.958656,-96.772065,-167.811276,-249.12108,-278.681381,-203.989775,-86.08528,114.576174,124.462269,17.741069,-40.550511,-100.995849,-26.277365,37.249241,49.139525,5.205924,-49.726659,-67.525207,-146.471423,-237.698719,-270.039754,-293.26793,-270.723414,-168.454833,-129.360708,-148.425465,-181.627987,-188.320556,-106.403337,-78.122104,-118.086551,-157.119165,-158.768466,-119.671245,-81.857959,-185.742761,-223.715049,-157.023075,-84.936352,56.89576,115.360477,204.933282,236.073715,227.568141,108.44003,33.946758,-42.749795,-1.89162,146.675468,145.082744,-61.039098,-217.147832,-182.76626,1.793669,64.963029,99.681761,98.180595,122.050044,165.811665,210.347753,153.727556,146.190498,152.349944,145.873179,151.213125,160.732608,148.529712,73.894383,35.71483,49.663219,94.303468,130.855231,86.396909,-17.000745,-14.614026,-2.57019,-57.969811,-15.540489,226.549961,328.249856,361.449211,317.177408,204.777529,125.420929,103.662362,34.311853,-47.435943,-178.723333,-140.446781,66.532572,129.328367,76.769755,-87.838272,-147.145941,-154.397904,-122.274965,-49.849581,1.088494,97.087766,43.993496,6.432022,11.084036,10.493467,-13.636792,2.514042,81.372429,108.181817,109.989932,113.836493,137.152528,223.261068,286.964965,336.74144,267.794898,66.284657,-121.627196,-214.425907,-217.467738,-94.841952,180.182924,228.623842,159.260371,106.243556,41.411158,69.346131,117.666687,270.82838,365.203655,475.858833,467.739786,409.957066,348.521494,306.537256,278.851706,321.259619,423.723886,420.516704,295.770236,241.652401,266.673549,325.69723,314.516601,271.940408,264.182495,254.09233,243.742648,224.196758,212.849511,228.011908,292.431526,309.588152,311.976756,327.412557,383.872326,383.291246,253.245771,166.914331,233.903912,434.888438,487.201855,491.557747,443.867287,231.982617,34.439278,-0.74592,30.151756,56.442856,106.964327,143.430521,145.039926,71.967127,-78.0143,-48.719304,-21.534261,-39.914122,-58.873877,-81.152049,-88.469174,-103.223363,-115.216878,-99.737768,-64.948655,-67.608107,-76.939525,-78.614904,-113.507803,-147.188902,-143.409096,-8.123998,14.452205,-76.244358,-109.154463,-74.273065,-59.145214,-85.833763,-99.91119,-94.551674,-32.0135,31.354873,139.895437,147.155573,67.022499,1.975461,-98.430175,-33.331743,61.18017,235.214959,283.235196,345.186921,365.864644,326.467536,234.7643,226.133192,260.584266,279.099738,347.536242,384.100881,355.473914,301.813523,204.752622,135.068248,100.188704,11.610996,-14.430269,4.086791,19.600223,-7.346709,-94.905191,-115.025849,-91.330254,-69.367468,-7.4352,21.01487,34.971296,41.296674:-29.338265,-76.598545,-31.328153,73.411156,94.781719,70.677318,13.518057,-152.473286,-197.383115,-151.604053,-40.958323,-15.075831,-14.264339,-38.69543,-107.435941,-135.018708,-237.019723,-333.07827,-319.441163,-241.53948,-214.617108,-180.353845,-179.763852,-240.091034,-326.195037,-364.79434,-358.032962,-301.291288,-247.972423,-288.070217,-428.735483,-512.693311,-648.093675,-660.436413,-641.04963,-595.17701,-572.121769,-549.993108,-529.845791,-419.008997,-292.754706,-239.838985,-128.754087,-79.825216,-77.319736,-115.771372,-114.467725,-72.487222,-72.792519,-71.779072,0.004795,123.338094,133.60828,115.578321,65.137341,-174.65533,-339.672062,-341.809885,-288.610191,-238.421825,-110.836299,-82.745492,-148.629401,-200.680032,-263.637268,-241.616452,-174.739253,58.59175,168.101128,156.615783,25.974571,-231.120757,-316.232091,-319.845975,-221.607373,-112.278818,61.946979,55.674032,-82.021865,-145.792024,-203.602448,-155.999971,-121.850464,-120.897955,-121.280097,-69.271018,-59.891136,-86.142641,-114.279243,-126.264168,-109.273114,-82.962227,-55.815,-78.3578,-123.77841,-88.926399,13.5688,-4.577907,-17.028074,19.758803,56.077827,172.644417,228.188715,119.340917,-169.423764,-209.280862,-108.976835,-71.064072,-50.994963,-40.017587,-35.067324,-54.057261,-115.980521,-167.454631,-177.553578,-161.046396,-131.870027,-109.100953,-152.825257,-247.114874,-228.491938,-195.841082,-53.751408,41.762447,78.17664,7.876439,-89.483078,-80.022627,-72.045887,-102.084743,-99.946733,-121.870339,-146.178316,-180.606272,-207.20313,-277.256519,-286.700369,-235.717101,-63.838732,-7.318198,-28.120665,-83.057918,-175.319028,-202.537309,-246.47983,-205.504775,-161.545539,-132.132846,-129.867329,-78.208193,-43.318803,-46.423871,-107.453062,-112.97909,-95.915359,-102.330405,-172.578003,-219.090887,-266.259773,-250.89404,-174.720395,-117.845021,-107.460208,-75.932471,-55.894379,-100.941998,-166.108789,-275.259241,-316.411872,-296.839844,-139.839765,-54.041598,-13.128159,-33.375978,-19.704583,-2.952914,-58.531782,-97.980163,-46.95156,95.215824,110.709001,13.852877,-54.312642,-220.69604,-386.854293,-412.97492,-348.315929,-277.312665,-124.322726,-91.930916,-131.093685,-150.633968,-147.001719,-153.285712,-155.211417,-118.598391,-88.381821,-47.32182,-51.887036,-145.087963,-242.321398,-228.40529,-102.634473,-33.887684,29.791325,19.393425,15.572309,57.467053,139.841543,108.208823,55.180528,-64.595575,-76.625625,-1.951761,12.773515,-71.477865,-172.385712,-163.001218,-16.413214,77.101736,218.031704,243.847075,179.767622,107.662228,58.719951,261.818932,352.153126,308.481833,220.941105,107.15304,107.550348,165.068069,120.296507,45.777484,-4.827279,58.054477,161.796223,122.244308,-63.48196,-137.47066,-184.615395,-89.705414,7.926886,203.679224,251.798187,247.484443,228.630019,192.456119,96.429233,42.41024,12.951017,1.692187,-61.362191,-47.608955,102.926969,149.463113,68.143531,-57.726369,-76.861563,-37.349303,4.463497,84.819126,111.003919,133.398688,90.327687,63.975911,92.394397,112.04833,42.728219,7.555674,55.531069,85.156862,60.112876,66.138644,116.918596,257.592069,305.547363,261.617249,170.60789,-21.242975,-102.331012,-121.046975,-99.27477,-18.178862,214.650654,271.289856,186.521354,98.546275,6.099396,125.010202,225.050838,387.60518,431.327635,471.802133,488.71701,505.084814,400.480864,307.069434,230.767915,277.378153,388.672335,399.313658,331.644688,293.898381,315.129151,366.129971,356.909811,359.140019,400.362506,484.894916,478.374277,363.15647,295.600359,316.510305,373.9153,403.964607,512.164299,560.943898,568.740767,531.140915,383.568402,236.712159,240.367452,358.28758,382.5117,326.802962,286.51884,171.491755,-27.311611,-100.535476,-79.200174,-16.812358,80.045465,96.755951,45.534986,-19.341552,-135.271486,-130.860185,-100.893592,-58.956746,-62.384067,-130.283202,-146.83876,-69.338552,-30.541491,-66.851553,-147.067598,-141.978811,-48.699917,-20.571659,-98.533087,-172.722332,-223.452008,-131.176232,-90.037397,-42.441901,-26.248065,-32.163911,-67.701118,-150.302679,-165.899619,-166.596241,-158.759431,-131.75574,-49.761073,-28.737954,-89.687767,-151.331544,-218.420026,-89.969991,25.087494,181.080005,200.650976,195.946551,190.815171,163.517212,140.299407,143.883837,160.061658,192.199961,287.884953,296.14823,222.528605,194.605855,169.465471,30.725109,-57.422387,-72.824926,4.248006,142.848364,160.74984,113.085932,-1.294005,-48.196472,-80.747738,-66.419588,-21.731046,-30.633777,-70.659312,-57.322346:13.920993,-15.797299,4.616645,17.872255,28.200198,54.782936,19.34839,-181.779452,-296.672483,-245.291595,-78.814027,-30.449551,-8.01722,-20.946311,-40.436787,-31.52282,-50.381603,-159.564358,-192.721772,-135.763718,-88.664899,-99.048186,-153.670213,-261.960761,-290.252698,-290.611846,-328.004408,-353.628418,-412.608828,-447.528987,-509.26409,-556.721233,-650.168043,-631.352824,-604.115712,-538.794255,-489.80561,-420.261641,-410.498635,-414.8972,-425.639175,-383.773879,-215.151502,-153.209247,-139.598597,-150.586687,-145.238207,-157.281019,-225.335487,-136.982222,-13.928643,215.46847,263.98603,150.753835,-4.069925,-299.901444,-334.452084,-287.215168,-223.499237,-203.454146,-137.973681,-130.892831,-211.070305,-251.475321,-250.239533,-164.464147,-101.145533,44.511739,97.962269,89.94822,32.413843,-119.048282,-211.40852,-189.608111,-38.342976,39.276739,100.921489,71.286337,-36.802432,-78.146961,-103.261601,2.49268,58.891403,20.24816,-35.983748,-75.726507,-72.523497,-80.194933,-96.759767,-103.090459,-125.398711,-133.100707,-112.249381,-95.110627,-72.232765,-69.814513,-107.366059,-134.00948,-110.611043,-23.428893,13.267179,94.392476,127.66323,32.312852,-234.552763,-344.760655,-356.483421,-247.445628,-24.609354,-4.228524,-96.338794,-137.438745,-177.0115,-239.14176,-253.507965,-160.531158,-107.314237,-190.804591,-291.030988,-369.152714,-253.726898,-174.078909,-29.624418,23.105743,38.972306,-0.594832,-85.220217,-104.404357,-151.216722,-199.531441,-210.909696,-209.949551,-171.591751,-62.294187,-47.65085,-132.580716,-231.504066,-218.682121,-70.641475,-10.775912,-64.999303,-154.981315,-296.098055,-318.643141,-333.952342,-296.29132,-231.412311,-82.915094,-29.857938,13.84861,15.221638,-4.869559,-44.759008,-65.52046,-83.081738,-58.475886,13.4612,11.539177,-90.170093,-148.140929,-181.719422,-130.238184,-128.958133,-181.655354,-191.809668,-206.238459,-244.481766,-310.463572,-276.933701,-254.167764,-179.144776,-103.650272,13.542736,6.203887,-60.480272,-80.32481,-131.76204,-160.959918,-119.119989,-5.217125,-11.516117,-104.904055,-113.719443,-152.61478,-322.294157,-356.514329,-247.697901,-141.876877,36.459752,46.425927,-72.350633,-124.484797,-136.916553,-93.199127,-78.594626,-64.743372,-48.381277,-2.222767,18.089171,22.913783,-42.843466,-64.360848,-9.48658,58.499135,203.516824,241.534629,238.96232,230.639021,223.750088,194.052381,162.637086,73.520692,33.004416,5.443455,12.591713,-2.988485,-82.050797,-80.231542,59.677491,134.783532,189.605535,183.526664,157.211619,142.655917,160.929531,286.910754,328.492871,290.066439,251.960398,222.891337,223.198063,168.215546,26.667905,-20.493799,14.982355,66.914113,103.911421,72.673496,-25.981699,-86.986763,-216.797162,-176.967199,-78.462337,111.404714,158.547794,197.427686,202.349006,123.497922,-6.743505,-31.186577,-46.106544,-77.809784,-123.265899,-90.382042,29.926295,48.147785,-50.055497,-173.330032,-184.479069,-63.510051,29.472235,132.571235,145.989664,163.463694,98.924637,51.764062,48.85037,82.175892,95.80257,68.64381,22.302241,2.653151,-56.577952,-18.87656,44.727433,148.277227,170.885,147.161414,94.015284,-19.642143,-37.765019,-36.81188,-28.058973,23.585897,166.691403,183.059867,109.029515,72.643468,54.342438,128.44847,199.248236,328.115437,361.888755,390.168288,395.966276,378.224876,324.124332,299.984297,269.062667,253.368184,210.038981,196.493541,206.038647,211.758136,202.684686,194.391129,200.045765,249.714671,275.273379,254.437697,230.701953,213.678117,166.627862,142.660396,176.256046,248.546688,408.918765,431.807173,373.549723,339.514531,255.134892,164.589108,174.635587,246.103465,257.668953,249.151064,230.785053,67.661035,-150.327429,-179.228246,-111.513857,-63.388025,28.139718,50.315631,15.571971,-28.763181,-135.047232,-154.345212,-134.389529,-120.679871,-121.957107,-130.229208,-130.712436,-116.411265,-136.928003,-144.842261,-102.787289,-64.588481,14.01849,34.404023,-10.54453,-58.531091,-135.209285,-152.638789,-129.360518,-4.592603,58.933969,70.134192,19.796385,-109.691675,-176.032579,-170.805066,-96.546014,-46.064299,-5.015093,-32.807801,-116.576302,-137.092779,-127.99247,-71.274451,-23.774175,88.930409,141.77193,184.663543,152.16616,50.224692,36.894367,68.701532,127.675799,136.995184,183.082201,216.949303,210.919139,181.176206,131.343305,44.867498,-6.49759,-9.576709,43.557369,145.939531,175.054066,172.88336,35.578206,-50.155537,-104.543954,-48.575271,87.724218,96.271243,29.56301,-3.494837:70.572658,-11.494174,-13.628394,44.561843,65.804936,-36.67178,-136.596886,-240.839382,-211.341043,-177.602086,-129.260927,-125.441507,-116.438496,-111.146998,-118.941643,-149.65256,-266.938507,-265.137038,-222.409291,-180.346852,-161.157899,-117.917779,-133.295063,-214.180842,-279.134654,-302.280616,-344.676549,-365.035712,-434.164566,-503.356447,-646.371294,-677.307793,-689.004582,-685.916331,-653.230824,-519.812325,-458.20136,-451.477566,-473.225706,-425.104426,-365.810583,-358.714103,-295.294565,-228.952837,-117.025365,-115.168809,-177.262308,-193.295959,-210.888271,-164.434611,-57.305485,215.283767,297.479763,287.492308,197.611533,-86.392628,-297.237701,-316.063355,-238.162658,-190.997252,-139.286677,-150.825497,-232.049876,-256.597046,-219.384639,-153.044382,-126.004078,-45.53227,0.769332,1.576347,-60.754551,-216.609006,-304.128539,-302.938858,-208.223508,-136.315711,-19.951587,-20.797035,-153.919318,-216.175538,-242.327605,-206.900732,-181.391036,-168.379676,-186.652674,-217.004458,-212.147632,-180.075039,-187.139669,-188.453504,-150.547518,-142.171637,-142.744154,-130.997015,-107.627086,-88.478642,-37.926581,-54.260014,-79.385918,-70.31436,-19.469404,104.42779,132.63095,36.395715,-185.3884,-248.224345,-204.437725,-124.081546,72.538403,140.489741,156.078988,108.728442,-88.432821,-186.144116,-127.79016,44.319271,81.551888,36.210582,1.567554,-2.015557,36.599774,57.356908,152.053684,231.397277,329.822653,304.031537,200.409954,183.277991,163.56544,70.806498,41.479874,52.232653,68.349006,61.308886,20.102324,-103.433903,-148.733622,-98.422341,90.469461,144.140957,72.912183,-18.429629,-172.815991,-208.779338,-270.783628,-293.677937,-245.840886,-84.241472,-3.62109,84.861191,68.973833,-42.085588,-125.429618,-141.884084,-163.534676,-170.087388,-123.677192,-80.020224,-50.089854,-64.820631,-104.859189,-118.276118,-129.069859,-159.784721,-138.787607,-81.905729,-110.444613,-233.582986,-261.305914,-238.07758,-156.620658,-85.147614,76.702633,111.067052,80.844327,59.998801,41.229146,84.996954,120.814996,144.556189,147.560963,162.160315,131.184385,-31.916459,-128.129532,-110.590078,-9.825254,50.709014,133.264915,122.259738,3.651037,-65.214695,-158.378086,-121.475585,-62.501764,27.840192,50.918431,84.224829,86.073547,30.914934,-63.009223,-89.000507,-59.612423,0.450652,180.602685,246.262638,251.877789,233.392321,217.395274,146.357002,96.601973,57.907338,84.309273,138.530259,112.543733,-53.92777,-205.737737,-195.00815,15.842353,147.11808,275.944136,263.277314,182.317452,145.179445,98.437908,104.888122,121.092397,135.776433,136.881742,131.46975,129.928706,104.964913,-21.205362,-77.974568,-68.421271,-21.136118,25.77264,-4.153089,-115.358541,-155.743892,-204.874712,-209.513132,-142.154511,84.815005,159.703433,192.557231,190.424154,126.226557,-49.917397,-115.722637,-151.300226,-161.468572,-163.62861,-135.631327,-66.629169,-53.359106,-97.439395,-180.744879,-189.499553,-74.157697,13.986515,89.200173,89.577996,106.815902,16.33096,-61.359408,-116.208708,-106.188352,-119.56643,-117.280172,-21.795751,19.187641,-14.227729,5.557993,82.579868,219.124396,239.152767,203.777024,156.161648,28.487806,-58.432721,-61.946215,-21.557202,10.692934,127.60771,182.475226,161.412956,104.988751,-5.446123,-50.610961,-16.083567,128.763958,190.592044,266.105835,287.764924,251.106476,167.051814,147.61751,133.501211,144.411835,198.981195,189.37202,83.585118,58.944575,71.67741,41.14669,46.147869,121.531175,147.822656,123.513336,82.223944,10.662842,26.853631,58.001089,96.116171,103.303104,163.421129,209.1768,242.238375,220.439405,124.62846,89.046896,126.344899,220.56441,257.416109,303.230231,279.636662,98.681905,-71.434676,-84.351714,-59.440981,-71.366238,-39.700091,25.953088,67.399336,10.494493,-124.686451,-155.670547,-121.330549,-31.786465,-15.514912,-36.131967,-48.525101,-84.636534,-154.262458,-155.490032,-104.622848,-96.925009,-74.933685,-45.706133,-41.329422,-69.431416,-110.757244,-86.628149,-46.56873,51.014541,94.888435,125.462158,84.365252,-48.903336,-75.397946,-43.678947,22.923432,38.316422,56.008599,50.925198,-44.786241,-117.062939,-188.958626,-116.833422,-45.908178,112.797007,181.719032,240.25224,216.426504,120.566365,74.099969,86.865111,168.474801,218.779182,301.073096,309.28848,250.285073,227.380609,235.482735,231.961829,211.576492,143.538801,120.476833,135.074653,147.440453,66.119158,-127.161702,-174.805328,-153.018868,-129.184391,-62.654564,-31.779539,-40.925351,-67.515352:-35.599724,-129.980435,-121.652888,-5.617056,41.009815,-23.732629,-103.490943,-232.222338,-284.875902,-259.804778,-120.37294,-48.236538,10.239633,7.455354,1.857809,-25.750766,-150.758405,-151.772289,-100.67228,-54.819371,-58.288697,-55.512779,-59.428673,-131.436326,-233.216515,-255.119911,-299.290342,-328.656307,-341.324231,-337.151243,-400.830307,-473.528113,-587.358648,-561.599172,-542.032909,-490.722079,-425.129653,-305.797339,-294.726038,-357.137354,-423.388161,-406.251124,-270.365575,-181.282995,-49.979575,-37.209507,-123.940002,-200.618065,-284.996107,-127.955684,-0.050748,183.546786,225.610947,243.254626,189.004839,-111.396273,-339.378554,-310.924497,-169.375078,-158.739493,-209.337942,-227.308197,-280.63061,-330.240438,-389.178493,-225.983058,-102.290836,42.562414,56.264419,22.128993,-26.232879,-189.261959,-320.322456,-303.586747,-113.04716,-17.083866,56.823741,36.142908,-89.639987,-154.421409,-180.004775,-48.083487,40.602941,89.898825,29.387136,-82.95258,-77.881799,-40.322863,-108.917957,-157.478357,-189.716069,-163.720045,-97.57432,-95.22157,-111.689905,-98.335685,-94.304585,-144.034536,-137.156065,-12.865378,66.375707,141.79044,128.595134,19.016094,-156.459847,-203.727166,-122.599962,-25.171752,109.952156,110.645785,41.023977,-6.062714,-116.216327,-91.53202,-18.57247,74.540569,65.574151,-26.688402,-79.404269,-133.145624,-59.680593,26.685475,199.422833,256.229004,290.096854,258.375343,161.603512,130.727407,56.816032,-35.43349,-58.642557,-51.775105,-21.032665,46.522701,58.436306,-9.902077,-151.669945,-162.622221,-2.488259,83.291172,54.757563,-49.189426,-254.050798,-305.208558,-327.530686,-268.11113,-185.328728,32.301572,102.117147,88.165436,40.446418,-35.507552,-45.811258,-37.560969,-11.295264,29.535197,146.437868,157.320134,28.813104,-47.924443,-94.694955,-68.612343,-75.550917,-117.897517,-123.970615,-146.123794,-183.390259,-264.35732,-305.61792,-278.353971,-100.423111,5.394646,121.920556,123.199378,101.82619,98.821175,69.245902,75.50675,111.446205,187.911029,200.912836,157.706132,124.094648,56.465102,11.365748,24.251531,109.273738,167.905421,255.007701,235.15018,98.236947,46.986878,14.313854,6.692068,3.514192,38.570783,87.403462,160.301114,148.627475,78.337142,35.320239,27.463737,85.843923,168.224566,349.220435,393.078828,370.711059,339.14912,300.062875,294.485858,278.67101,208.424071,180.691365,135.302025,105.08073,30.521992,-48.299799,-41.405767,91.2198,183.985611,329.586168,339.704346,231.797428,159.917701,106.506833,206.311871,261.356871,267.611083,211.801673,86.709491,55.172947,-0.982627,-79.182703,-88.738709,-25.538123,6.879534,-7.101666,-36.791026,-82.400334,-104.30694,-178.060406,-178.404929,-100.933082,127.877547,222.682897,256.583001,182.83008,-23.24457,-143.530905,-156.991722,-144.437502,-130.737173,-67.874213,-38.914083,-50.210864,-82.785775,-144.843386,-99.535517,-27.614931,147.68595,223.172369,264.898294,223.847749,84.005638,-52.629714,-80.293364,-61.696413,-40.306831,-14.389367,-26.953124,-69.647885,-91.771973,-143.174678,-63.032352,23.21508,167.356071,205.329105,166.177934,102.63561,-34.134904,-148.103377,-151.95309,-46.123201,5.337675,78.385588,114.081587,110.812538,42.291891,-127.884905,-114.216211,-49.503294,62.334328,107.675686,199.399874,219.379945,143.172004,8.317708,-23.083592,-6.677733,14.839011,26.381383,9.368117,-41.261385,-53.437765,-53.503492,-32.493411,13.862813,151.051146,188.998512,132.508578,80.194199,7.799897,-64.416917,-65.449778,37.897075,110.301779,230.654727,260.902433,247.908243,211.039265,120.966473,140.157325,193.223537,271.319407,282.042507,214.199791,131.23919,-91.040777,-263.337638,-268.414388,-173.624911,-121.216779,-27.094333,2.744966,-33.447483,-102.533404,-276.13829,-347.58696,-317.068144,-185.988899,-130.419031,-122.017213,-161.077227,-210.118267,-174.622038,-136.637544,-63.868944,-35.440996,9.625814,0.732534,-68.776517,-92.938189,-110.424553,-76.694224,-28.736772,100.425879,153.320473,174.561165,142.451858,0.664706,-156.402314,-172.819276,-55.017599,24.547947,88.745307,63.020451,-31.711339,-69.923334,-127.295351,-117.861687,-57.538059,129.440984,207.960428,233.399786,197.37678,102.80119,21.521151,28.252945,107.085898,149.275842,257.549567,297.726749,239.41175,172.709938,143.445405,191.413549,162.118989,73.248927,82.416542,185.015572,219.413473,143.731081,-41.88167,-99.863711,-77.776167,-25.738575,34.381003,36.97974,41.159929,29.534716:129.843541,20.435921,28.420605,63.362703,52.922258,-55.193086,-138.040102,-221.217346,-156.898412,-132.921996,-171.908427,-194.165261,-165.957185,-151.31361,-186.204614,-211.143138,-232.879355,-211.459088,-182.41983,-119.970986,-88.4771,-7.3357,18.716971,-41.546898,-188.145146,-238.606458,-272.577875,-271.941801,-265.30878,-279.44862,-367.883079,-419.146716,-470.636598,-442.632878,-399.032111,-314.055385,-306.433239,-382.33972,-436.840157,-434.561121,-301.548594,-241.921294,-183.695709,-184.281731,-152.287026,-91.449893,12.976239,5.691167,-70.637901,2.32289,118.688349,380.360832,471.648763,489.173921,414.309236,192.841375,17.435508,-23.340638,-24.167586,-20.870954,-58.491813,-80.792143,-79.721941,-69.004343,-86.262935,-100.313,-71.602192,37.359879,100.512919,140.624352,69.35101,-189.867456,-334.988951,-287.044831,-65.217651,-4.640503,-47.319672,-87.248201,-90.529232,-75.262798,-158.542711,-240.299289,-189.359129,-73.756798,-87.125734,-197.497546,-218.031374,-126.182844,-54.406519,-59.952723,-77.752915,-75.550632,-41.801204,-21.554423,-8.850859,-5.763249,28.113014,77.903226,79.275776,-14.113951,-57.335007,-6.260354,39.951257,14.169357,-113.401173,-141.672989,-77.358624,-6.485496,157.247041,218.785209,260.743021,255.938621,177.65367,17.740837,-18.464901,59.966379,127.377881,199.050359,193.742074,145.401577,137.579486,173.76228,309.084968,383.212103,444.549409,406.60954,307.873852,305.464977,301.60445,212.706685,192.319749,195.901725,176.248649,87.238359,48.749852,20.5896,56.195686,96.817876,178.298234,188.456984,92.213972,13.175908,-49.264832,-55.832809,-210.679664,-351.638641,-315.35326,-141.857964,-65.929313,-1.051162,-7.223496,-91.776419,-268.450469,-326.240213,-303.019791,-259.1513,-165.552478,-129.598619,-168.868034,-244.009336,-364.576573,-322.107654,-258.851484,-166.369158,-152.007385,-168.606763,-210.445697,-300.833672,-344.618651,-372.720553,-313.8297,-188.060376,80.208646,132.984851,60.867028,20.481436,71.239494,115.811143,92.597993,26.406019,3.597818,-7.233435,-13.661391,-87.980033,-155.486495,-122.549507,-9.270667,2.485498,-32.951234,-44.930746,-85.436745,-128.455576,-199.249246,-147.621617,-116.930426,-151.665273,-167.433518,-83.320959,-25.944514,10.830178,-19.893765,-37.281523,-32.91176,9.561712,195.381138,288.270518,343.956159,335.661711,316.416759,230.874998,184.659979,188.7097,246.684993,343.961461,315.617681,132.205625,-30.045717,-50.308779,52.426525,139.83473,254.497359,233.820232,74.319654,19.055191,27.767764,68.857029,70.552994,53.226569,63.083327,123.565517,139.391145,92.798628,-12.645573,-56.248348,-23.913791,53.020726,170.92407,173.864073,147.62299,124.790732,-25.172881,-185.413167,-160.598127,137.425458,304.619533,365.797657,273.851865,125.163001,88.569123,59.392084,-32.601757,-88.088224,-157.594271,-131.886158,-7.897412,15.084789,-63.326848,-88.233987,-57.631689,-20.290195,-8.880219,33.650998,53.024522,54.770788,-26.608727,-70.881047,-105.424471,-112.038505,-105.101596,-69.127999,21.687126,28.48627,-26.641853,-23.090187,23.35184,161.090892,232.223119,302.019277,265.220195,90.903739,-78.531559,-127.10109,-92.490306,-16.913504,116.863243,139.694517,129.749714,106.710495,44.889084,45.906855,72.14005,184.596361,291.358513,445.680262,403.151112,192.904949,95.679764,77.495751,45.76059,62.864723,151.460856,156.005888,42.792917,-17.958448,-51.307354,24.780851,85.617277,115.256785,61.170817,-47.79842,-56.122313,-9.730188,-17.256859,-35.402028,-12.845775,5.616909,-13.764409,-12.898856,83.162818,129.620706,88.458763,26.751119,83.44375,261.21308,313.24345,341.900619,328.45386,222.707954,45.501637,-12.419889,4.812135,46.292827,148.677054,200.859969,213.622218,173.760998,64.263618,-12.57361,-5.866816,44.204722,45.528435,-2.570844,-10.883814,-9.665603,-114.688533,-146.56493,-84.465605,-51.754427,-43.821442,-34.946924,29.520915,61.076839,79.910835,71.48133,68.408493,84.147769,105.39329,145.166235,133.03401,29.989188,-59.056629,-64.298813,14.491144,69.075054,99.119451,70.109437,35.49794,29.920129,-92.970308,-167.638283,-86.677005,144.547403,209.377282,215.355149,189.41781,171.385839,168.062253,157.364325,166.822345,200.006953,318.148944,361.047139,315.525595,248.016681,152.215487,160.838023,170.031766,122.504026,57.396096,-79.256468,-91.164568,-7.262144,-30.863805,-98.923645,-183.474234,-162.778211,-28.480959,37.227934,85.400914,74.528306:-55.072835,-119.961991,-106.301632,-12.369698,31.382611,7.463601,-50.317548,-155.890009,-242.786104,-262.641336,-186.378636,-117.583002,-30.324627,-26.60998,-76.205567,-130.26568,-274.506747,-256.620437,-170.729767,2.69752,53.627239,74.340081,45.793642,-80.087538,-193.321039,-224.296898,-302.861198,-337.451096,-328.902622,-323.666779,-436.838161,-537.904021,-685.701184,-661.366633,-592.765463,-427.341841,-358.157118,-306.477298,-326.413015,-388.384438,-433.178199,-438.008236,-361.437032,-269.259169,-64.121118,-14.036909,-85.005877,-176.416442,-300.318161,-178.20232,-57.822762,146.140195,222.646666,318.938695,298.204584,74.314601,-174.222486,-211.972503,-136.826444,-83.405707,-54.576729,-86.486679,-201.108207,-247.059562,-249.111595,-193.181625,-147.197415,2.114171,53.928505,14.924284,-50.176778,-232.43605,-380.696263,-346.373435,-121.655594,-33.096228,30.447513,26.562774,-56.680139,-121.130648,-178.830282,-82.432654,-30.466451,-25.23384,-46.814647,-87.993814,-124.477538,-215.869391,-235.570852,-202.767756,-116.298813,-108.803971,-146.618575,-146.451883,-103.294268,-92.915514,-133.490086,-113.063446,-49.937013,48.412144,59.604188,61.541007,49.080326,-47.601732,-164.729731,-160.304719,-20.858031,50.439434,151.101384,186.745097,153.491325,85.790369,-33.173927,-37.325406,-10.909449,45.241739,71.024063,95.031739,92.434174,77.214951,66.131808,86.937844,200.742398,279.176648,381.1202,364.747734,233.831615,163.487076,35.006055,-5.355223,59.515752,257.796942,305.166011,223.309831,149.023747,63.887857,-17.631646,-37.727762,83.15784,163.69427,131.578139,29.782024,-133.790891,-164.263842,-225.342074,-274.006254,-219.728099,-10.804118,55.443153,54.068706,19.063509,-97.523717,-194.713177,-188.920289,-118.939724,-83.351545,7.980851,41.297465,-11.840654,-75.654966,-178.582522,-190.607588,-184.465173,-162.262061,-121.1673,-78.570261,-122.254029,-234.876711,-253.890276,-234.169352,-133.66762,-42.312557,156.554823,187.734689,94.917723,54.881011,67.915092,100.85166,96.500195,106.052847,141.813693,174.540468,126.566761,-46.354144,-109.851972,-50.681716,118.059703,155.795698,147.718218,138.527357,75.767362,-6.444036,-199.27027,-234.340127,-182.661782,-41.915782,30.451629,135.523005,136.202535,50.50825,-44.851253,-54.570427,55.218304,164.7943,397.6317,467.57021,442.180966,376.719058,265.862692,223.716297,222.734252,265.393626,311.272571,347.919658,291.357488,87.025336,-70.864904,-80.074353,78.388657,204.382219,373.181954,360.610161,189.251751,105.096172,23.455576,49.617821,108.548214,275.815494,331.934388,300.809286,238.414243,77.351268,-94.043707,-122.764036,-3.21976,90.406759,171.555464,140.472709,24.75957,-31.767382,-158.031109,-185.656684,-99.843065,222.306963,371.366291,408.657782,312.346281,122.667069,13.068305,-30.520767,-106.934912,-124.565042,-62.024287,-1.045251,78.737608,66.0604,-38.96088,-47.522871,3.801571,123.344186,181.324062,254.197761,241.45677,108.292428,-64.533939,-97.0987,-57.726864,-45.389411,-48.9369,-19.814298,45.204093,15.79071,-135.393394,-115.589729,-22.141993,178.805219,259.74732,267.463831,165.926395,-43.858358,-85.929345,-92.472652,-82.052377,-18.957133,167.288191,202.925416,113.02375,47.089657,-43.938952,-72.245841,-53.817239,43.707851,121.946681,228.559531,191.725755,-4.699841,-130.166567,-123.440549,-30.850363,18.621405,108.917624,134.767847,79.187733,4.589649,-122.910759,-84.78977,-14.191124,88.166718,83.50588,2.873679,-22.629351,-42.977246,-114.582726,-125.214226,-62.855156,-16.717596,96.263294,149.729101,199.164944,195.149458,106.111283,20.122821,51.973099,211.006175,287.045565,317.797492,247.184239,16.858582,-140.750828,-146.532688,-77.445659,-39.835375,78.041792,147.529712,163.963143,88.51164,-121.436411,-215.656354,-194.056103,-70.558761,-8.804346,32.660915,12.661993,-58.343197,-139.383595,-162.864038,-137.646669,-98.879582,-7.357022,27.245422,34.182814,-3.066512,-115.401285,-71.454073,17.064391,170.672053,218.228635,226.753764,155.760229,-65.158302,-168.679503,-150.473,-58.728384,-11.000925,52.604268,44.348312,-47.245324,-100.901126,-172.48907,-173.54533,-143.759144,-16.37741,69.348261,186.564023,187.242724,83.023696,-34.989461,-29.787966,100.623333,176.762956,274.421234,286.473333,247.491976,204.232384,105.145648,83.132085,102.204735,136.29308,146.195845,153.692282,136.681831,29.751017,-113.227002,-149.940126,-144.266753,-130.545228,-68.086693,-12.084403,60.28063,43.665688:117.082341,82.230194,28.109073,-37.034858,-29.295814,-35.697429,-75.361502,-134.296019,-105.276485,-104.221535,-173.672377,-221.169966,-256.48939,-242.649423,-220.892223,-217.326214,-231.346144,-234.77487,-189.549799,-57.206159,-23.771912,-10.657555,13.562407,83.9933,78.086637,35.873335,-94.661433,-140.263164,-113.134331,-70.126005,-7.916012,1.818224,-64.373651,-92.736593,-29.697416,39.130808,-8.441826,-121.111619,-142.406599,-128.546264,-130.3297,-134.65342,-111.836427,-99.265307,-52.170113,3.269507,133.458733,149.031632,32.957716,20.261392,125.922363,388.809775,492.434514,608.774095,598.931925,487.561438,335.776482,261.194872,213.952314,238.340257,281.625315,265.273612,150.888047,88.965003,14.741988,-3.449447,8.084716,61.975538,97.427435,118.102234,58.360139,-178.137214,-351.12084,-364.097437,-274.029014,-220.07142,-168.165078,-162.661051,-142.433211,-114.192743,-83.30509,-115.714169,-106.181368,-19.28976,17.922422,18.457393,5.255668,69.580712,208.979967,239.845859,176.383791,108.616071,8.390304,-8.527767,18.915106,60.652662,84.099581,36.437417,71.959268,162.635609,142.071078,17.103654,-44.47237,-116.052886,-83.073179,-39.403934,38.289302,71.317559,162.09824,208.465349,235.318994,221.120403,183.866289,141.372171,138.216549,168.083079,178.700624,189.681978,212.423412,288.437234,341.352632,349.065197,343.382213,370.114495,506.490413,536.111371,431.005855,375.349039,325.020001,194.120088,126.111306,82.844116,97.149778,164.761454,195.127716,214.670843,225.847245,237.630466,268.705942,272.276576,226.173003,195.154802,166.161693,151.881146,62.891587,4.392424,38.685922,93.13929,67.29861,26.443824,61.851015,165.633837,49.563864,-74.147507,-209.550357,-190.992755,-57.2228,-10.572293,-83.047483,-167.504085,-314.850496,-346.673545,-304.398282,-206.336892,-178.679098,-113.636721,-75.985389,-45.344844,-88.960897,-123.386296,-105.188021,-40.222675,75.374774,73.391603,1.213408,-8.973159,29.347221,46.317327,43.683909,3.767635,-41.081178,-114.254111,-111.802298,-91.052464,-183.785371,-209.870319,-120.403621,-75.411966,-110.148902,-178.387056,-329.517714,-360.707831,-295.424114,-190.813788,-176.039134,-219.903803,-221.075929,-127.702263,-82.024027,-69.909613,-76.965279,-50.890786,5.636752,19.537582,122.915808,229.168849,374.238675,343.748583,175.063291,118.801836,146.850512,225.893246,260.750671,284.19009,257.9099,169.077581,91.311624,66.664119,56.60194,71.349106,126.382979,139.465262,99.140301,64.802759,-0.011118,-43.489398,-36.23642,16.14353,39.647761,92.882794,124.853011,134.605549,16.948375,-54.944263,-113.052007,-90.990023,-11.694098,16.761643,51.930697,55.820266,0.453138,-63.580067,-57.673474,83.811174,181.663867,206.193034,124.005859,-11.847955,-34.970984,-46.76343,-100.730431,-146.398752,-224.193671,-228.611249,-179.216103,-154.074788,-163.367213,-227.05375,-263.703606,-290.2263,-247.099286,-106.459333,-75.961691,-123.765016,-201.204384,-235.115323,-286.157865,-304.66863,-305.85081,-260.884831,-127.618792,-113.432325,-241.939231,-279.026635,-188.411169,69.284189,158.287728,145.054343,65.010514,-66.925032,-146.080074,-186.101957,-154.168062,-64.094399,124.353458,160.212508,127.811114,104.397836,111.215521,153.359031,158.31597,182.198394,233.635734,344.446802,342.053847,233.26832,112.289172,51.397932,-40.659803,-47.965757,7.679004,48.377321,95.984823,87.027163,4.747507,-83.288013,-92.805894,-85.790193,-98.598334,-131.983119,-141.586217,-158.577096,-146.252732,-133.398539,-137.788419,-152.076721,-197.049029,-231.865683,-257.042494,-222.826169,-156.356511,-151.413301,-119.106979,25.809396,102.816945,180.812252,165.410849,78.520741,39.299304,38.27226,-4.851257,-43.257961,3.882504,103.264394,198.81072,143.371732,43.386764,98.866386,117.945581,66.207629,52.606573,118.665563,153.334266,166.340894,101.85167,43.133842,-72.437592,-97.85522,-31.820093,35.723813,118.808333,130.755463,149.307506,127.777209,100.906976,46.028517,33.604804,79.658353,97.480578,13.455137,-132.892936,-177.434183,-182.329987,-156.936158,-116.077886,-124.265425,-176.159896,-195.005962,-240.025922,-264.55709,-228.056081,-118.957022,-81.25298,-33.773819,-30.397135,-105.730481,-199.689135,-191.014409,-63.499489,0.245785,81.432438,114.829856,126.686749,90.743284,-17.949833,-64.687216,-69.597346,-151.988278,-208.679784,-230.561104,-197.144404,-100.332743,-52.247474,-76.330083,-164.641,-167.467428,-52.299859,-10.0099,-74.086947,-115.078627:-19.485262,-14.394314,-10.767347,-42.330206,-62.323727,-86.8009,-112.256499,-176.570938,-206.077522,-222.770106,-284.505389,-308.818282,-293.489505,-274.66747,-274.554185,-276.970455,-279.588091,-296.367814,-287.081745,-278.077386,-297.960507,-313.304758,-280.266751,-164.05003,-86.243355,-82.630531,-89.141793,-74.726145,-52.68898,-67.756342,-139.546998,-177.86097,-208.041993,-185.111204,-179.250956,-201.060997,-221.730921,-252.923474,-246.180591,-183.627183,-136.81229,-121.109647,-52.807934,-10.000423,61.84083,86.322632,113.478513,118.382473,112.464481,182.310142,253.087777,381.491929,440.5135,524.684193,516.614664,394.97309,175.009211,87.568577,87.773321,132.688866,157.50953,127.118128,48.531817,31.223227,-11.314383,-101.543672,-94.140336,41.366037,106.391721,133.568654,104.697874,-13.343797,-196.798784,-245.438618,-203.161901,-162.312737,-93.267025,-67.643652,-60.340446,-77.430512,-150.431739,-192.139892,-156.831264,-57.622919,-47.49252,-81.429354,-71.34684,9.218097,-3.052586,-12.95962,82.878587,133.140213,104.876289,52.469559,9.337393,34.871244,79.923016,119.679083,155.682983,117.627832,40.394364,-28.203864,1.408329,38.651225,-19.187409,-58.158741,-139.570461,-139.788858,43.613324,163.096922,245.758696,213.696613,140.055821,134.116227,149.471179,195.497758,233.057368,325.364885,342.507888,321.537656,341.870012,362.527968,408.389572,435.957966,449.982428,415.187285,327.353338,311.089605,260.292585,152.152591,133.606885,173.112147,187.612403,124.226591,72.118089,83.304621,176.999446,184.41651,172.137944,169.528545,139.337104,124.31176,117.06235,115.331776,89.736819,42.269069,34.680346,34.906582,37.918312,77.356766,101.881178,77.232732,-76.720727,-160.471591,-245.550353,-246.164895,-192.10795,-159.085703,-139.683108,-137.670334,-139.346342,-167.2471,-157.353265,-116.14374,-128.333425,-186.533783,-180.105746,-98.470236,-136.380023,-214.279017,-255.028758,-184.669846,-66.973487,-90.912352,-214.399586,-228.398911,-152.187609,-117.764599,-120.168944,-110.410206,-104.409521,-167.38227,-232.61532,-300.156322,-241.601764,-206.144995,-176.156937,-174.052408,-195.557593,-228.186648,-319.468984,-350.036161,-311.625666,-175.688031,-119.259739,-115.814515,-143.739297,-148.054109,-119.011437,-14.39473,-5.438987,-70.605627,-164.778614,-144.718374,10.051688,114.963419,280.347696,309.964852,251.023102,140.528347,110.744124,127.929232,168.475408,195.367335,129.81348,-75.912663,-156.128581,-116.151007,5.728599,10.398376,-44.685235,-32.721114,49.690261,69.577633,37.579791,27.112194,64.057487,134.213564,140.953672,115.400694,92.78219,74.435886,53.806691,0.863614,-76.377905,-45.526738,46.917697,48.733637,6.217044,-4.647996,-25.979784,-67.198597,-67.161288,72.526156,185.796667,256.04581,184.310464,29.798672,27.736574,49.527749,-7.636587,-106.330476,-243.425606,-185.071002,52.044374,88.463723,-76.714299,-239.387618,-241.421814,-167.888143,-139.449016,-106.763097,-81.694564,-64.644996,-185.861873,-224.298874,-170.185486,-150.582292,-182.246471,-172.340274,-69.450568,-32.621778,-74.787929,-134.159919,-96.967669,70.864828,155.997454,206.399445,141.814393,-65.976205,-233.465263,-277.063221,-211.868563,-93.552853,174.41826,243.982681,252.106654,246.034967,263.90799,314.91381,339.882229,365.543364,395.433435,496.512363,521.928234,506.633018,445.329165,393.167052,308.835514,300.64076,346.795437,369.390367,339.871134,300.317984,218.017562,174.961034,184.595545,225.407197,225.414367,198.311296,210.101208,257.877005,216.760921,196.705244,184.367246,145.919696,69.626185,82.819533,149.582538,163.661935,111.263728,25.388437,44.670831,175.447874,246.668799,349.148325,335.922478,178.886105,43.485586,42.194993,108.306047,106.300316,70.268886,91.935962,135.399133,110.817009,58.749577,78.163949,70.599824,47.990332,49.790414,7.24171,-22.816199,0.739173,18.648603,-5.730385,-19.205852,-0.029084,50.570911,68.95409,56.184748,33.38046,38.229606,90.371267,67.570128,-51.104333,-66.308672,4.356685,29.29895,50.112837,33.978827,-1.390317,-30.916383,-18.312407,1.427606,-2.373808,-43.093179,-76.852091,-163.160583,-199.66607,-171.197021,-24.406038,90.547484,264.102683,245.651115,71.463119,-63.729074,-85.373391,-8.338994,56.334628,125.855642,121.202399,77.774433,61.357787,18.095257,-48.661003,-79.862263,-149.598146,-171.32896,-141.25553,-106.201676,-64.768969,-102.793939,-137.453541,-150.534018,-122.912152,-45.466892,-7.807884,39.568624,42.003301:137.754608,27.785153,13.808773,32.377318,26.808032,-35.959644,-75.385701,-162.122926,-217.853563,-210.64876,-197.217854,-200.105418,-144.978488,-101.262569,-100.76851,-141.605591,-206.283985,-157.414626,-84.104764,65.550606,104.716759,142.212689,160.340811,163.05396,39.596886,-61.136285,-200.18443,-207.016879,-187.58809,-203.377327,-252.93326,-258.405778,-279.623419,-358.029615,-349.456677,-247.208656,-215.72373,-201.431339,-200.053518,-205.317603,-211.074597,-231.018947,-295.446041,-278.591054,-83.966269,16.80933,46.048973,-6.197084,-107.025582,-64.964958,25.265701,267.415273,378.676496,459.590636,409.742661,225.61419,46.944498,-11.806208,-23.353987,9.502054,94.948473,111.286976,6.685498,-67.583853,-106.909359,-87.672992,-88.139675,-67.847389,-27.994724,68.630836,61.829138,-110.362021,-308.375048,-348.012564,-250.236124,-154.81096,-30.493799,-13.149229,-7.696896,-5.163212,-21.944734,-82.230084,-90.568497,-21.12193,16.048946,-3.127871,-43.342193,-91.897318,-140.079846,-180.757674,-217.289599,-199.718306,-93.427974,-22.373218,36.392741,19.800592,0.043325,15.117507,8.447378,-20.609871,-17.434605,-4.084938,-8.979095,-24.954853,-106.056479,-151.101881,-90.427346,7.237857,170.793816,200.877435,189.013515,167.640566,93.048486,44.83831,48.240694,81.443385,107.753656,127.52201,109.753081,94.600213,156.850913,205.243475,326.311173,385.73365,407.724726,349.973555,229.584496,216.192482,193.494526,126.791866,136.094869,232.743804,265.103674,247.858696,221.62001,206.337244,238.37929,250.42599,244.579357,231.17696,209.146557,192.806403,87.89413,5.820208,-156.146526,-230.684133,-175.577024,8.953258,28.350556,-75.74363,-97.823423,-25.459168,-69.071431,-150.866126,-217.259299,-162.33602,-1.560398,32.957639,-5.167447,-34.847098,-125.400532,-293.985058,-344.744999,-268.047874,-168.738437,-33.096034,-33.661009,-93.677275,-160.084013,-173.822175,-108.086597,-42.438118,91.048655,126.830778,82.610776,42.177924,43.685044,103.71881,113.498686,45.585365,-22.595356,-96.819795,-71.085134,-11.011914,-64.576742,-84.255103,-20.474018,22.765175,35.529036,7.505957,-115.452476,-194.468797,-275.382671,-197.201372,-146.0495,-67.395931,-6.518663,106.30711,99.6368,-26.20952,-156.419144,-166.275692,-28.496273,85.273437,290.280349,350.835001,375.457919,354.932706,233.556516,69.524923,53.830477,185.016171,260.373063,286.157628,245.180121,109.390718,-48.472509,-91.262087,-54.761284,6.934676,157.857374,206.547767,174.487011,124.102935,69.741007,74.946706,88.273532,121.149822,126.649126,101.304191,77.486014,6.74471,-36.550532,-21.219268,47.823768,59.45579,15.608992,-10.919062,-38.702909,-41.884029,-80.290229,-143.882257,-122.452763,44.683206,132.826866,182.088433,135.737302,3.895712,-60.283829,-60.239772,-68.247243,-109.400068,-195.185953,-175.877893,-6.248773,51.989729,-76.384493,-239.327922,-210.387116,-39.180746,38.12716,147.506373,160.617135,17.678231,-210.946196,-239.411474,-135.481324,-99.729989,-89.607991,-59.802309,-17.743855,-53.395839,-153.488169,-129.228612,-45.032098,180.791366,270.949998,310.653338,237.340797,5.243837,-164.84384,-209.144917,-160.668673,-56.184566,163.034268,191.169131,45.290776,-49.687439,-55.178709,92.3281,135.290204,199.961008,241.94293,221.636155,155.008243,86.024442,30.869188,-28.836749,-36.780548,22.036551,110.496489,108.480929,26.419986,-7.54569,-9.428427,-70.804208,-122.500136,-174.285421,-180.988046,-180.043367,-145.687064,-52.573785,-139.691175,-214.574573,-199.308016,-123.27109,-21.935337,-25.289828,-82.070237,-102.235813,-137.505667,-132.600152,-59.406656,156.931831,231.380874,260.121249,221.674459,89.941605,21.813741,40.200814,94.777688,81.001456,43.244079,88.474529,237.60217,249.351139,93.068994,-100.334759,-124.929032,-40.754031,15.987966,80.793864,86.129829,65.57483,-26.841746,-73.647884,-50.912312,-0.34513,56.784493,55.303063,64.37586,82.978626,51.35804,-3.644243,42.891036,207.241519,240.69769,164.666054,107.433263,47.981054,-8.196062,-45.913933,-85.048246,-70.866942,1.566725,13.727586,-53.244652,-97.878092,-173.771755,-181.060424,-126.71473,27.177666,86.665895,99.582278,46.462096,-53.458008,-56.695719,-35.434176,25.091255,48.388364,119.97386,177.422015,223.402927,175.084573,6.306541,-36.350041,-1.761466,6.237104,-24.756456,-36.216036,-10.495062,41.163408,-13.200416,-68.620856,-133.370506,-125.181879,-3.871125,59.849122,59.968714,19.503794:backward
326.110124,451.635715,487.603548,508.043296,461.991366,297.627942,235.174677,249.649365,383.557196,437.84279,526.85615,543.68988,413.575974,315.699806,254.663261,271.932224,235.907115,156.148569,161.816625,156.90271,102.424543,-21.528464,-74.180829,-177.350649,-206.769943,-193.348998,-159.570807,-147.80796,-148.838081,-170.887675,-217.898018,-204.151098,-131.88451,-122.923789,-121.009508,-81.793139,-65.3351,-68.015309,-85.200211,-135.292068,-165.538738,-162.88217,-86.877117,-28.671821,36.612124,45.742013,70.963096,88.407623,144.869719,249.649627,293.225545,310.207759,287.019271,196.401076,140.546211,99.261537,150.36967,151.976275,97.452527,65.898862,24.101913,37.351437,148.88235,216.989286,314.478227,327.096336,317.6092,286.625706,245.57568,114.916159,50.174669,-19.930568,18.084374,57.99605,113.444819,97.80198,20.670123,4.430075,-34.595168,-78.933248,-103.892008,-26.777701,-12.622359,-46.461478,-66.346481,-78.473748,-66.830766,7.660068,128.645726,176.389921,234.739304,243.442485,181.307541,131.784036,74.015498,75.135454,143.578034,194.137106,188.44346,176.485578,164.601346,83.576042,23.243604,-49.092339,58.308247,123.490552,117.911097,94.670855,102.264454,88.794164,-13.225567,-52.479029,-21.367805,36.703057,31.354553,-51.588154,-113.963972,-173.984647,-167.487198,-224.883297,-375.815461,-411.203787,-362.01478,-315.761198,-236.557212,-205.525278,-154.735748,-125.732498,-97.813064,-150.177804,-163.143653,-112.481091,-62.291923,33.01175,50.473059,29.160159,-10.372567,-23.333822,-3.519535,21.43672,24.152088,-0.275109,-25.426932,-23.934616,-54.414748,-103.959452,-99.914889,-36.437943,-10.980401,-61.595289,-139.414999,-252.374313,-169.198112,-85.938916,77.411189,123.319023,70.057601,1.229161,-94.73843,-123.674714,-174.309649,-112.479677,-31.332784,39.013608,-21.975874,-183.495722,-221.530404,-247.091813,-230.501432,-191.594734,-47.478275,12.770445,-27.406872,-107.302991,-239.478282,-272.135766,-320.646217,-341.640763,-315.636032,-261.19682,-253.674109,-235.376091,-235.281095,-285.625586,-329.18664,-310.213204,-185.850025,-132.891666,-163.245812,-227.45174,-342.301674,-372.92026,-360.95828,-266.966085,-216.972192,-201.279537,-247.205399,-302.373747,-265.88076,-122.606564,25.774799,81.571748,149.685813,160.517387,104.595331,70.961734,70.424454,71.394015,60.67826,124.383701,162.793258,186.842386,173.721649,89.137086,10.443868,-113.09176,-43.053305,24.644004,110.314783,109.102425,29.204991,-24.726122,-119.041031,-155.444586,-235.048429,-285.180769,-272.710116,-245.101799,-258.354403,-327.423691,-370.440062,-386.73449,-249.867471,-175.636314,-123.439329,-145.913786,-224.24695,-239.695577,-220.027443,-209.422437,-161.014075,-54.597903,10.329625,120.264872,138.348775,83.250237,34.992205,-12.63148,25.413067,49.956787,70.826587,68.373845,42.151464,-4.997864,-222.18705,-338.283714,-397.455537,-240.961131,-141.470448,-17.401181,-14.276048,-63.25428,-76.688684,-50.022875,-21.708664,-39.775982,-88.955581,-97.474381,-98.150472,-98.049087,-153.112085,-220.009796,-299.691123,-203.274798,-136.970674,-70.62614,-83.831634,-158.180317,-171.906317,-101.329551,14.259267,45.229004,65.099575,84.001914,139.408442,133.226136,5.561713,-47.099464,10.341929,116.209003,130.017265,77.067923,22.31119,-79.599787,-100.970283,-79.972349,-27.243103,13.208082,142.64115,182.974654,89.809018,-7.639168,-154.889455,-184.964056,-136.664249,12.611962,94.49924,206.417217,209.885592,138.61182,94.961139,38.903754,9.240902,6.617466,56.958158,74.722257,-11.258993,-105.184497,-296.058121,-346.313728,-336.347134,-323.218032,-306.147617,-199.843496,-152.992042,-152.927297,-206.382389,-325.708578,-238.103029,-128.688107,50.342822,84.065188,56.351463,34.604175,59.159908,100.555248,179.624977,209.271332,191.747483,127.118004,110.496449,114.155376,108.902379,83.608519,163.010148,228.342604,286.176894,275.313892,236.051772,225.341763,164.751721,91.582962,-17.874554,75.461632,148.73656,200.941409,182.722582,119.810034,72.445124,-21.652091,27.660716,103.862847,280.477348,353.080753,403.557029,379.606988,299.74807,274.524405,261.569978,280.979479,303.5311,368.019614,387.55785,321.454781,237.160779,77.943365,135.67726,228.804275,320.419467,285.466911,169.432006,147.608146,161.798349,142.326694,37.45773,48.398689,127.631581,220.392885,182.759986,96.172833,86.81014,56.589582,-56.764733,-113.779151,-100.690295,-36.606005,28.456914,-12.159781,-145.800483,-169.150483:268.123063,288.884592,301.951574,364.442253,370.037816,296.756302,226.22624,152.385939,308.125964,418.446395,540.300124,502.887545,223.208322,68.749247,-35.518361,4.156485,82.236542,107.337605,125.402819,60.195177,-50.774277,-236.26186,-236.480301,-160.010783,-174.749189,-161.687631,-17.547773,26.925571,-53.736542,-114.910131,-148.929821,-115.527204,-19.270564,-5.295786,0.359368,32.11177,14.540671,-83.924262,-111.886949,-75.346999,-64.998717,-80.583762,-27.389981,23.712967,40.056108,9.856723,-37.366979,-30.744717,78.305659,176.356262,162.708978,118.041403,152.234729,268.294065,256.520695,82.621172,19.175656,53.603415,119.621509,124.140522,81.266672,66.099715,113.823484,162.43291,239.715479,284.215839,304.729846,273.618421,219.869017,110.504772,72.114913,68.95104,118.527577,135.133473,192.890061,220.915384,202.299093,147.247234,-37.889434,-121.695368,-154.189477,-23.418876,48.855785,43.194946,-36.580471,-163.745923,-152.302425,10.025098,200.150216,253.270885,300.176658,297.955696,192.815849,115.620156,34.694477,41.698656,88.527285,121.279991,165.475281,276.570938,257.137464,83.446654,13.49281,-38.255983,48.81182,145.691688,302.845197,310.686652,208.564221,128.992001,-60.169372,-124.93538,-68.422897,20.889946,-9.760243,-137.276612,-191.547691,-216.355878,-189.38155,-170.632695,-239.417796,-270.107891,-257.42763,-224.339725,-167.218384,-134.860334,-25.861888,16.94381,-25.008197,-120.52718,-107.525084,61.016492,157.740198,176.591201,99.73514,22.013131,83.33202,73.282731,-13.91029,-38.932108,-43.096151,-36.166382,-3.535872,20.581429,27.378857,-115.739843,-185.878041,-168.183046,-125.552698,-133.12876,-181.733479,-237.094776,-113.562974,-28.984395,45.113713,23.517375,-118.713891,-202.756136,-259.900506,-239.428994,-221.281768,-184.300729,-135.52318,-130.268783,-182.64102,-244.273349,-258.120513,-270.642928,-169.860117,-86.233733,90.526267,118.210206,-25.927347,-129.884491,-242.811894,-240.306904,-153.94559,-45.434905,7.65681,116.826107,135.626648,25.968508,-69.966155,-148.686038,-90.421504,-78.083806,-42.669656,-18.884213,-63.036674,-115.107147,-171.726947,-167.785245,-124.174355,-46.018417,-5.63389,-12.623831,-55.63712,-87.33687,-82.411793,-91.555353,-8.419801,78.633157,196.753633,168.957743,45.906519,32.240194,51.410867,26.967356,11.022557,170.58204,252.42014,239.009991,146.841322,-27.244562,-46.088159,18.009304,33.625087,11.148775,15.294547,38.12144,10.973328,-28.041003,-87.842726,-123.420246,-211.96558,-215.03867,-185.846822,-168.641215,-194.092162,-263.620782,-290.067274,-262.345438,-111.386291,-55.670674,-50.572853,-73.398989,-121.386774,-152.748663,-235.607322,-254.237478,-207.678778,-128.522707,-78.742839,20.772366,45.172762,8.771276,-39.152381,-68.289392,48.831694,110.202063,163.805019,150.437591,49.163436,-24.608536,-181.655055,-225.122943,-156.854544,0.914958,60.820224,122.205969,125.84339,94.13433,79.481661,94.364995,116.671903,110.321898,135.779155,174.111508,144.744689,41.541728,-169.850392,-187.840381,-92.453627,22.508093,76.450247,58.541681,-23.555113,-161.621314,-172.925395,-106.147102,40.069991,93.655664,95.401296,85.748408,112.029766,112.430969,8.7164,-51.077292,-48.121541,-15.546833,-22.913314,-44.403071,-67.490635,-143.848813,-174.511901,-170.452896,-109.294092,-79.702283,9.860727,53.488148,-25.412827,-154.724073,-352.566285,-359.213886,-262.67671,-126.547245,-53.712121,58.847569,81.752643,71.277307,32.818002,-49.877206,23.90553,86.576828,141.109004,127.709851,6.572383,-80.490163,-155.623407,-138.867919,-104.840232,-51.874822,-15.420879,-6.600659,-28.203098,-47.465559,-57.759528,-118.653351,-107.521247,-38.385774,125.950975,155.372247,104.881353,98.438409,167.611268,192.876986,197.345742,220.924267,241.849771,223.814236,188.909704,164.254822,176.637573,192.812506,165.420028,165.291329,244.605025,298.696707,351.101831,339.350298,253.363788,197.223496,103.17094,64.848885,60.367749,71.407893,77.484302,5.253558,-62.705634,-122.617268,-46.712248,19.633922,197.146804,281.776534,327.708677,281.809276,178.223017,154.164755,110.530848,60.669566,70.665481,160.905559,191.363642,111.768282,30.427127,-38.846836,29.854097,51.929609,77.154985,87.776136,46.223807,20.290306,12.599849,-3.436367,-71.453596,-40.408417,25.786241,65.796664,14.817092,-72.059243,-81.868028,-112.70617,-186.663025,-184.999887,-42.361511,19.2993,-29.349019,-101.935567,-242.128998,-288.460581:14.52228,122.399489,166.51041,199.980366,162.079478,40.676993,3.050778,38.238901,187.383428,249.476685,267.354329,222.243664,63.380027,-28.02468,-150.922169,-134.855186,32.953571,151.121788,133.278099,-52.335895,-167.889795,-266.232575,-228.18525,-155.201365,-206.370513,-184.636837,-28.675722,-8.461887,-104.654736,-125.116687,-73.530753,-49.764172,-31.315875,1.718713,5.207441,-93.785228,-172.475966,-242.650776,-215.143405,-103.208342,-69.90141,-85.351184,-66.073052,-41.499435,-20.67147,-17.975602,-31.024438,-28.659452,65.328779,227.033611,281.116335,254.674539,204.868774,144.774807,120.631615,43.560725,-2.942814,6.972243,78.291198,100.775439,83.037334,65.338824,51.59593,69.229187,149.30061,209.868186,229.398821,246.570503,239.954591,178.164326,123.282222,44.705294,101.914292,178.755314,326.800384,333.973346,207.733403,130.975324,48.681557,35.670013,-29.131068,-2.581176,99.020839,208.069061,137.23563,-58.315461,-78.381526,35.902606,150.788701,168.406657,149.595073,127.902648,78.57137,51.088526,-1.911937,-8.043864,58.964845,198.770087,257.719048,262.478732,194.473245,67.78988,66.865096,82.119034,85.022296,136.266497,267.442023,273.28361,139.543174,43.648394,-152.28914,-218.992939,-174.754908,-73.955474,-99.555415,-244.744427,-313.886138,-389.525176,-380.49704,-297.355543,-281.16496,-295.532993,-272.421098,-237.200415,-183.731332,-176.480282,-154.518625,-122.107035,-49.571638,0.787849,29.180666,104.33212,141.811077,133.072501,72.759811,0.217489,62.332556,66.872987,0.729427,-26.450216,-51.693051,-70.216396,-92.522767,-63.876934,30.944408,3.945655,-40.671285,-109.686387,-133.335939,-165.935699,-196.004294,-259.482131,-205.857318,-147.48514,-74.529437,-97.16495,-243.257438,-310.24109,-337.230003,-308.925748,-222.74698,-68.936351,4.199356,5.304214,-50.582912,-119.133411,-116.428573,-82.073562,27.147287,123.529808,274.202775,254.23346,70.508623,-7.422378,-64.591545,-59.934072,2.85301,126.504102,196.450822,280.277544,265.312008,106.358804,0.24825,-86.575131,11.111722,49.424968,69.096442,76.946005,57.726816,14.287596,-51.737038,-30.911995,93.692823,228.664504,274.358655,233.291756,155.697178,32.781795,7.530366,25.676328,130.801402,189.86063,249.751299,232.772214,163.755038,139.551919,74.725796,27.873242,10.920754,184.983519,287.526584,284.007088,172.462799,-7.960185,-15.043903,36.881281,75.022715,107.517302,149.863209,115.77947,17.130572,19.182442,44.139847,4.199841,-96.728101,-67.844358,-34.324543,-22.004686,-26.407326,-42.187818,-80.765238,-132.931953,-33.457605,7.051402,16.138889,14.00968,-10.451178,-41.738778,-142.693405,-194.979002,-217.221274,-112.040964,-52.385923,26.416255,62.566512,78.448523,17.525167,-102.9233,40.601665,174.746034,301.256145,253.302516,79.858048,22.454497,-37.843916,-62.528339,-45.891809,89.79518,147.841789,157.195349,135.2884,125.468624,126.999917,124.217098,197.039702,257.494149,328.036879,309.289932,195.607947,135.628586,23.473546,-18.33691,-19.994924,54.107464,91.709995,73.487991,21.733984,-62.66179,-75.585744,-25.346283,39.718435,37.651485,49.499462,89.426696,156.50944,140.64367,2.57018,-56.456247,-43.384562,17.899546,36.451343,23.619786,-31.946656,-207.623985,-257.075972,-155.742129,39.657259,79.001441,53.069358,27.499628,-38.893131,-106.101188,-281.603338,-341.189913,-320.205865,-116.411875,4.376913,140.600519,140.744016,20.38552,-76.991063,-130.516761,89.080887,164.121764,95.527125,31.224621,-18.069024,-26.248992,-67.087515,-91.283882,-92.079934,-47.364044,-25.316398,16.043507,31.336274,45.180817,28.686309,-39.019153,-1.1559,64.143073,147.261536,139.308278,108.454249,119.326418,152.623431,153.269316,166.229099,212.691965,194.197503,99.644023,85.112257,109.319221,126.490603,173.198142,173.163466,174.702176,236.149612,261.246368,255.052082,245.558188,194.143815,131.383227,38.064572,118.84369,150.374346,90.447877,48.406573,2.648542,-34.430242,-139.81696,-125.234745,-54.532878,101.865858,130.596758,53.077611,-7.941785,-30.864028,19.369887,106.835004,56.364922,37.18869,82.822318,98.954905,39.282795,-7.332944,-26.892858,33.573726,56.780161,46.804695,1.495934,-123.046612,-158.539014,-153.980918,-126.962067,-25.308278,54.938508,48.242267,-44.452469,-90.403054,-108.783252,-107.214272,-164.254386,-222.91469,-187.357762,-11.683345,32.922334,-37.615673,-95.66756,-210.026621,-259.61196:-16.045746,239.187498,329.619508,374.867392,317.003992,135.727975,79.969231,126.979837,286.12517,340.230674,355.78397,318.596949,198.478682,145.211938,66.304064,52.313334,88.452287,90.629818,74.285901,21.913484,-39.30597,-190.588877,-247.70315,-346.839975,-380.021274,-324.316941,-128.322796,-84.501646,-180.061544,-245.320161,-292.323543,-282.54349,-227.544879,-173.94649,-150.417159,-115.835538,-113.815459,-153.523125,-199.842143,-267.665346,-231.274901,-215.241562,-200.369969,-166.901288,-45.840093,0.394787,-7.807585,-19.125567,93.417957,301.00331,366.157649,368.613663,310.972303,152.739334,84.27226,-27.101913,-70.535657,-34.609867,98.097716,120.516696,48.745875,21.707885,39.030376,48.223995,24.511372,50.167955,120.038411,244.042038,237.732625,111.400483,24.038231,-75.013904,15.16278,78.770256,178.534269,214.511686,227.070554,197.102037,94.585531,53.652627,8.388612,-18.950549,8.491678,110.656899,129.375987,82.100791,53.684222,75.648449,196.946136,250.872041,268.924248,235.991905,165.289275,152.506908,133.437072,115.330171,97.856422,146.064932,205.37617,322.34756,309.717769,143.678239,68.53465,31.002185,143.689937,215.649177,240.778281,186.714073,74.178849,30.670751,-149.012055,-252.570501,-210.634284,40.018746,71.047739,-83.227486,-177.283301,-271.386193,-294.100335,-369.531106,-431.317884,-421.054602,-303.508026,-238.704146,-216.489935,-241.523206,-236.632137,-209.376122,-212.404482,-226.69077,-189.918939,-97.28183,-67.755159,-21.911891,-22.872371,-82.113012,-65.383126,-28.94409,9.00752,16.617777,28.117354,23.519593,9.612074,11.493101,46.109689,83.334577,68.485876,-8.625724,-37.848242,-104.873658,-176.046314,-282.655108,-128.437872,-14.465474,82.916543,59.180428,-42.50159,-74.949235,-83.116311,-80.465496,-51.742912,84.592692,184.247085,277.485666,239.203555,123.779959,89.303845,74.428459,116.87043,159.592779,260.690582,284.649367,229.742466,163.935428,13.876059,-54.485865,-162.058878,-167.716253,-105.55251,35.845625,52.368459,-23.02279,-76.50969,-114.950031,-54.347651,-30.261728,-20.817199,-27.78376,-45.911641,-46.522694,-62.378855,-90.529153,-120.407277,-57.333426,-9.025493,33.225294,10.277735,-9.971599,11.998002,63.522008,178.189222,248.031841,309.349572,295.40412,232.139772,206.051691,165.917193,135.340475,90.952641,195.262522,290.8766,349.157317,264.152135,19.302568,-54.470664,-28.68278,104.52938,153.474018,206.222978,208.839096,148.004946,109.640658,36.320215,-12.524441,-80.04887,-29.779704,13.602379,7.271462,-56.453361,-181.306807,-201.946746,-147.685148,-39.871222,-13.604233,38.994198,70.175597,56.668199,21.551159,-65.104844,-92.833402,-82.627489,-84.952714,-63.83188,101.972586,184.538558,154.608343,49.713717,-105.876414,1.841695,103.777573,224.945343,217.002494,90.423016,7.8983,-144.45054,-204.668779,-215.501045,-62.604002,24.25203,92.74731,66.069752,-15.838206,-36.625809,-41.796452,-57.132651,-71.891966,-57.769112,-12.09011,94.96403,96.805572,-67.815196,-169.504179,-221.645956,-82.841969,-10.662067,-15.856966,-80.390798,-170.668471,-178.27856,-149.840241,-63.30244,-23.544037,1.657809,1.364419,33.550641,50.956293,1.032787,-36.157691,2.951882,90.124333,95.215063,38.865985,-7.231702,-108.965634,-161.337086,-196.720428,-74.221736,-6.551059,106.460127,165.792184,188.853074,123.607345,-81.16817,-152.320881,-96.623124,88.473106,132.049474,89.708076,50.459821,-1.008801,-32.247682,-112.249273,-71.367876,0.194841,72.014117,23.371718,-172.913871,-261.001676,-367.119939,-379.112084,-320.170614,-296.045697,-304.332599,-276.072214,-247.858273,-216.94714,-232.353459,-292.926074,-261.394595,-224.031582,-152.265184,-107.180776,-7.068106,30.627676,69.003588,83.473042,112.382077,110.915483,107.396508,130.444388,145.460156,144.606728,135.283997,124.329756,132.160468,142.436537,181.549056,218.79543,305.66821,322.342664,215.213925,115.636013,31.526774,160.464801,219.641159,208.045532,161.810199,66.256095,15.990364,-50.876024,0.475643,62.170556,200.358862,236.806299,201.093419,166.157844,167.081974,197.178298,198.337516,156.776827,186.180985,308.357649,339.698199,258.932563,172.351596,47.101987,58.475895,106.261052,231.529669,254.946357,128.661449,20.662014,-120.344723,-127.648654,-52.155518,63.855722,124.224473,159.18915,106.890147,-58.951625,-114.306756,-132.78287,-166.782786,-184.504602,-100.764964,-36.350688,-36.090179,-99.920166,-226.512475,-238.749429:-113.188416,23.73095,75.85558,127.922075,101.601284,-11.155788,-52.196412,13.040856,180.194559,211.300853,200.10903,182.403394,69.299915,-22.351846,-112.093032,-60.72642,94.150257,124.003474,97.598909,-28.176152,-111.236429,-254.772045,-315.168593,-364.80937,-262.692379,-178.643326,-79.666435,-126.3978,-331.666492,-375.77628,-295.729204,-265.445498,-291.115249,-206.967902,-125.107473,-99.755766,-180.346273,-350.936357,-366.134507,-253.518107,-151.331572,-152.413429,-173.619408,-149.411351,-42.928922,6.032784,51.63401,67.561521,124.804246,207.507381,258.148655,306.007154,278.372675,133.347418,30.992363,-135.724697,-204.139278,-197.829061,-104.922357,-82.145919,-142.575947,-171.513618,-174.248898,-166.145471,-150.150219,-48.419463,56.119568,192.379161,164.162169,25.953889,-17.92704,-19.402723,2.114612,30.03898,176.858712,241.172656,222.425252,158.319316,25.785879,-9.465668,-15.651273,35.916733,87.015308,135.937719,100.234856,-4.398243,-14.494128,77.050097,187.136279,223.309246,237.269709,191.300861,63.591817,33.634089,6.953161,-11.973653,-24.645744,102.244502,224.560359,362.574189,300.93785,39.865081,-44.229239,-14.47688,96.407553,136.964998,190.753269,177.104082,74.112693,12.195136,-146.510051,-203.84038,-129.118385,-10.712614,-13.069365,-82.679244,-136.110297,-287.853442,-349.835132,-345.93903,-264.503949,-239.922284,-214.269692,-192.54054,-123.488518,-111.398156,-178.53531,-212.36424,-213.416197,-142.745627,-81.244167,-27.113879,-54.539047,-103.711854,-97.348913,-12.383904,110.180098,118.462324,34.025197,-3.418097,-33.947751,-39.626193,-52.535292,-55.391586,-13.832063,47.706876,53.997282,31.447811,14.110344,-108.61005,-221.625288,-341.275253,-201.757142,-117.619316,-24.713084,-21.028564,-138.329535,-229.323328,-281.723444,-210.410366,-3.220213,138.244574,189.065076,247.539279,258.950505,259.986554,236.383743,177.59515,213.040046,278.719808,418.469775,435.31332,319.041692,221.100858,66.242923,37.260166,41.158739,57.529357,89.564967,168.706071,149.15278,-43.462398,-138.085014,-137.437937,-14.738426,5.143986,-4.855648,-8.875724,-15.149645,-10.389733,-5.75386,-22.931861,-13.000556,148.673858,241.947854,294.761905,244.874878,125.356023,94.359659,121.638645,225.984682,270.10066,312.989206,293.802543,196.962678,152.985697,64.555179,28.0434,80.816777,289.718853,363.599387,267.27465,131.590788,-49.263119,-58.224124,0.529599,109.295511,154.159815,158.636938,128.318901,57.172972,40.728428,29.315816,2.714296,-48.60305,51.193011,119.84359,72.14716,-25.173118,-121.71528,-102.371319,-44.573556,-19.127669,-10.071333,34.014884,44.232309,-33.897131,-86.938525,-107.495881,-81.962624,-28.125184,56.512645,106.211329,169.317138,182.582905,118.399498,28.695441,-70.932115,106.838989,229.470199,336.082711,301.433982,159.159542,81.755873,-81.466605,-141.456807,-102.603576,64.297849,108.682216,97.344213,85.160965,55.768704,7.477923,-75.778506,1.171338,53.265934,104.250407,112.65148,134.362491,148.325816,109.930962,64.282841,36.658118,118.570537,156.81605,92.656721,-8.529112,-175.65897,-196.825111,-111.842503,22.577887,53.144146,88.956925,114.891531,149.599408,124.427788,5.531295,1.368872,161.390243,216.03561,153.205518,15.737676,-21.018724,-118.330354,-183.548091,-206.892962,-94.880713,-34.324184,96.898843,146.865014,88.165223,-27.533827,-254.381544,-289.227692,-211.881996,-83.125519,-16.484855,67.570388,51.99195,-86.01844,-165.664666,-212.253908,-77.859122,-7.325614,-1.51804,-66.837462,-196.335297,-222.866198,-260.170664,-284.68152,-282.775616,-215.250216,-189.343359,-207.860133,-226.266238,-203.994252,-196.169671,-225.96858,-161.132148,-83.722764,45.239452,74.554341,68.140435,38.037191,-7.333197,12.258756,130.500535,222.40932,226.397699,178.815938,153.128741,102.027696,66.721044,52.664987,144.220423,191.463843,254.381073,262.96672,223.988412,186.66975,51.021869,-28.398715,-32.662844,129.067346,176.001423,160.324414,131.80384,39.235942,-35.389518,-137.363445,-53.511394,43.228266,192.699227,174.823675,17.599966,-41.248636,-49.464291,1.364471,146.030075,174.236404,153.483203,163.764712,182.473993,83.830051,-29.922144,-151.984511,-65.200084,-0.665969,94.590341,86.408763,-80.841185,-179.261087,-242.997336,-210.142118,-96.414936,51.230727,116.488432,104.312708,30.971407,-111.513753,-160.690917,-221.926073,-206.69827,-141.151481,53.457056,96.384047,20.938079,-39.035282,-111.65119,-116.595914:74.505399,270.191353,310.600002,276.09624,226.280044,97.735052,30.228128,0.851187,174.561556,270.677065,395.097973,425.225806,371.93327,301.079743,198.775884,188.645502,229.152003,236.05962,214.03391,88.646835,-25.295194,-161.910742,-158.386286,-196.554444,-301.38017,-336.027656,-343.426668,-317.439518,-254.144286,-234.142807,-239.622167,-245.060249,-188.905674,-108.368725,-77.868586,-71.705291,-105.526259,-164.701317,-187.250583,-238.606138,-233.123478,-230.651909,-202.988136,-146.623094,-10.680049,44.176837,147.023496,196.110545,289.711379,393.061657,425.525715,406.653166,364.228489,243.692749,167.380605,40.658857,50.282834,71.712478,52.192828,30.06369,2.810979,-3.945082,29.403156,78.611513,164.882634,170.970879,185.63078,210.134107,158.460008,-1.354015,-50.972811,-124.803258,-130.77914,-64.233703,100.366151,120.869516,52.612752,29.884778,18.124433,2.793214,2.950819,97.478453,164.956272,238.818179,226.008349,168.575607,142.07269,115.574298,194.753107,256.924135,323.915154,304.538119,213.726604,182.137854,128.101319,100.739152,134.293238,273.872638,322.589943,286.602665,213.519434,38.771875,-29.195196,-32.097229,95.01915,122.812463,64.033157,55.513362,106.563867,74.61242,-127.302962,-197.033996,-82.084663,174.368408,216.396343,94.814226,7.332644,-103.548479,-149.232594,-266.29405,-380.683113,-405.094355,-313.514303,-241.59988,-244.781661,-297.875653,-296.042096,-246.122721,-212.76076,-257.845013,-241.830058,-148.789774,-126.190986,-108.075238,-86.929422,-77.877815,-60.385307,-11.755191,70.742297,71.865526,32.529029,13.107813,-9.582637,-10.939188,-11.761023,23.457062,67.10519,160.452375,180.836229,112.289387,28.9087,-127.69154,-54.582112,84.276961,336.884111,347.575237,172.055943,98.065667,104.135028,128.891443,141.685916,220.957843,285.425781,304.283894,230.903525,99.32982,87.575889,59.963314,46.4716,97.536909,247.068761,282.864044,202.0581,97.789766,-119.379155,-170.74371,-172.217053,-263.508535,-323.459381,-283.879544,-215.805964,-176.130183,-219.938376,-301.460371,-215.426312,-138.807905,-53.256737,-71.049625,-154.91457,-169.962136,-197.989221,-252.626237,-360.219835,-347.049898,-296.699093,-150.621028,-97.183635,-101.357825,-142.081434,-173.090094,-28.727675,82.624988,231.661143,215.378643,58.780475,12.413724,48.67117,78.36384,132.003947,242.40268,312.215599,334.485569,242.655277,-16.925965,-105.603122,-117.669207,15.976865,78.540888,104.781636,69.941107,-17.768597,-44.363662,-59.653809,-61.961929,-71.447677,-95.580949,-100.166992,-66.451193,-63.372607,-147.962693,-195.45704,-205.962746,-154.211463,-126.710973,-35.95225,14.324238,15.071254,-32.685392,-135.318739,-153.490743,-88.616917,1.682656,53.222341,163.55336,163.458988,52.143443,12.709021,4.554184,3.883578,11.117776,63.837638,94.233406,91.078428,29.505089,-153.854625,-216.717524,-220.214521,-74.894045,23.450689,135.902789,119.890615,0.285787,-73.397313,-187.414342,-228.583621,-249.279125,-290.556364,-279.675858,-178.342048,-126.859245,-160.566794,-242.935262,-328.183102,-170.442145,-56.953739,58.373392,11.232737,-196.617481,-253.514587,-181.474475,-28.890416,-2.02477,-17.755804,-9.821432,23.696909,4.167251,-72.002589,-55.016422,112.503762,215.213884,200.989251,119.296089,71.832139,-32.12148,-86.667095,-130.353337,-57.649784,-0.709737,188.163432,293.839822,350.503747,292.374344,124.180601,58.533059,54.568077,220.950183,296.204207,275.39697,197.911481,61.752376,19.473929,-17.741679,52.833219,98.573692,83.285884,11.059893,-163.321433,-233.936699,-366.719817,-409.178516,-368.803457,-357.412581,-405.096895,-449.866896,-423.313965,-351.538451,-340.636614,-389.54599,-361.456181,-295.245117,-181.923882,-153.465738,-120.620916,-92.162685,-16.73593,-0.521238,-0.243083,15.01419,36.041729,93.40785,109.806991,93.926175,51.159737,-27.922469,106.824375,213.872338,302.617887,280.35201,226.396542,224.712921,157.695903,65.390011,-42.712709,106.784291,217.997189,329.052875,314.171367,239.51543,207.836023,180.512799,194.483371,216.768088,263.158898,263.691135,258.099962,271.462856,279.35959,266.336824,268.077336,357.9238,417.971893,485.242366,471.448372,376.886528,312.725412,185.790624,241.2035,348.777247,485.556442,448.711885,275.027163,214.180623,160.873779,133.309489,83.144939,117.814173,175.689968,283.227462,277.939513,157.573475,97.476277,27.848372,-45.588685,-50.949033,96.00242,184.606733,163.086072,48.521148,-150.174156,-138.300478:-125.773321,101.603535,189.925317,215.938489,159.725857,25.584647,-21.975486,-23.15976,98.588573,165.835511,280.342658,297.361867,201.132045,125.634784,12.584172,-6.315233,59.412764,161.138421,179.566728,90.479563,-14.309849,-230.098237,-312.151877,-402.509762,-369.328836,-317.118592,-199.528672,-199.493147,-349.820047,-417.836234,-421.264662,-383.1476,-277.327273,-151.733213,-122.730554,-167.051371,-206.285783,-285.770983,-335.270303,-334.887016,-169.384257,-102.709949,-21.964081,11.995692,60.823841,65.397942,8.247629,-22.905578,61.421379,277.337706,328.949927,262.051661,193.868308,65.741903,4.385509,-97.732727,-90.178889,-37.560681,64.949726,67.076724,-9.663216,-57.093264,-153.631283,-171.586521,-81.363518,120.910777,238.086095,305.128628,212.389323,-21.954874,-86.536211,-107.406512,-10.311381,73.248326,250.671386,300.216885,244.446691,165.962458,8.689202,-39.44505,-57.624878,14.562619,103.945101,275.776018,281.279836,149.596214,91.54501,104.844579,238.854494,303.591632,356.976343,318.337515,124.668072,35.37187,-13.796284,11.993108,100.70544,245.214811,334.994387,382.987918,295.059622,57.746138,-11.109309,0.599674,126.061957,165.000556,141.352408,107.517665,65.082951,40.090527,-92.316599,-156.925867,-77.185608,194.355999,269.98805,171.332259,40.575554,-208.695045,-287.567213,-349.698039,-353.032722,-327.676277,-196.904645,-132.404686,-131.559868,-192.333585,-305.539913,-316.450575,-265.320402,-145.555396,-80.409867,-66.091833,-118.822858,-215.012078,-214.764629,-92.641142,47.82933,76.848622,90.583459,81.086333,8.402825,-40.018251,-95.754642,-72.776139,41.46549,92.932181,105.430139,121.337326,83.590617,-78.686803,-165.389008,-269.05764,-150.210828,-12.432186,223.387034,231.73873,42.219951,-34.42762,-31.285412,-16.893796,64.368261,359.690148,497.783061,500.32398,394.63235,213.989636,174.555926,161.789543,221.062733,274.211241,362.119289,359.814639,239.26211,153.886387,21.989739,-14.357779,-73.961626,-109.541381,-82.448443,12.767925,23.265315,-76.779189,-147.45531,-194.038847,-133.473045,-112.113465,-96.617072,-93.68294,-86.479045,-91.853033,-150.512966,-184.416344,-184.163574,-43.065815,65.199586,188.298618,162.761308,67.7796,38.232101,32.516839,168.587222,256.752706,324.238183,279.798199,105.457789,30.610253,-35.118169,-43.364181,-5.738055,218.144105,359.050083,426.125058,330.673473,28.625747,-117.900376,-184.616215,105.301593,243.338252,292.831368,216.300835,-4.727872,-91.783134,-152.844547,-125.325663,-8.601349,62.341006,71.760217,38.928362,-5.664699,-87.855917,-108.34157,-104.649716,-56.986773,-28.27565,22.176811,18.712313,-63.683817,-110.221143,-163.048009,-159.220484,-93.213628,-7.152498,40.195292,111.26816,99.228493,-37.25438,-119.710025,-143.070778,43.129374,137.713038,217.523405,206.278728,118.609133,34.04112,-176.326751,-230.514233,-159.022799,-15.504437,22.16969,-12.776406,-68.145821,-187.757168,-238.46277,-255.917816,-164.460553,-140.588514,-174.773917,-179.052645,-87.25953,-41.117192,-93.086126,-158.797608,-175.355921,-37.863694,28.70889,22.696907,-62.544122,-261.940535,-307.34068,-257.658613,-154.73233,-117.860119,-52.694359,-10.907077,58.485636,37.671116,-89.656673,-102.432617,39.845243,170.173292,175.493277,61.878896,-32.452414,-190.024523,-240.130207,-241.142654,-88.337598,-4.074483,149.099885,200.765944,164.365509,103.876065,-17.015912,-56.695908,9.165527,167.896143,209.410076,178.899013,110.346495,-86.096642,-173.836797,-200.764826,-63.102537,8.458137,89.05999,56.896771,-185.567878,-337.473291,-531.219971,-536.389452,-394.141175,-258.22468,-244.675821,-324.815174,-382.678407,-429.69972,-437.281067,-452.223104,-366.66318,-300.254169,-177.296515,-141.188209,-165.286662,-183.112413,-104.425445,-25.025592,102.69758,127.148146,123.201327,113.929056,103.525079,65.896093,38.097244,29.328906,139.402174,202.301827,270.292524,258.929112,157.411456,97.694977,-11.190137,-33.286056,58.653843,205.954347,239.833827,202.263997,160.175643,78.272449,25.675009,-56.981967,-13.682767,59.878038,252.083241,304.562269,227.013517,138.569562,44.440257,78.793116,215.543516,317.289472,368.684693,426.27922,389.701998,170.683476,29.364987,-125.437602,24.121154,152.811925,330.156455,341.47118,195.21444,64.718473,-159.857069,-187.979047,-56.645665,117.675307,176.487419,212.215518,169.598625,-8.295987,-94.25113,-166.398784,-171.782113,-158.407627,-11.71122,74.218919,75.099396,3.167736,-122.381271,-118.544448:-192.577493,-43.572733,-27.417493,-90.268628,-124.836579,-160.647176,-197.347837,-302.840922,-245.135761,-160.991857,-1.400518,65.401221,137.879308,139.745671,140.977841,155.613736,183.586435,148.235428,126.59394,104.835609,80.732854,16.264464,-20.648567,-147.128879,-237.843483,-215.089262,-89.909781,-43.723151,-39.582073,-57.362124,-82.904588,-83.187221,1.007179,139.124827,170.67413,113.693193,51.110594,-6.190221,-7.479978,-55.775679,-69.038466,-44.614765,10.854107,41.295484,125.587633,170.250719,209.117223,199.383051,183.36816,257.916811,321.253709,369.215005,312.161645,122.853237,56.31054,-31.178095,-111.157462,-133.992066,-115.699573,-87.321919,-97.633094,-125.87306,-118.425065,-98.885034,-111.195916,-110.295001,-77.801915,-21.645871,-29.84854,-129.55375,-199.259879,-264.83134,-192.949801,-159.43011,-119.430118,-94.046229,-53.8963,-42.683888,-34.136621,-26.082673,59.104267,197.43175,241.544252,250.796616,230.881615,191.341049,174.437409,142.87758,124.346332,104.441951,63.423651,46.057423,-57.567516,-135.08763,-235.091194,-240.728815,-138.54519,100.101432,191.365364,161.580739,81.930905,-25.657614,-43.742687,-21.172569,26.960752,2.487868,-104.85864,-122.854981,-37.961099,21.407897,4.657037,-48.731523,9.841212,234.929483,297.899136,256.502496,183.717466,67.367431,17.785792,-153.540331,-317.563187,-337.018071,-182.382139,-63.821843,22.787648,-10.207374,-69.797808,-53.567605,51.18375,52.409119,-1.104988,-29.593747,12.15691,84.230244,93.129256,92.052863,100.575605,90.380086,43.715658,53.766525,151.18842,182.235073,159.711887,145.365624,173.150764,220.973282,249.644769,299.653333,266.972336,40.162413,-94.879936,-214.84854,-14.555301,146.99164,314.936667,266.138599,71.596597,61.986956,292.175225,405.476159,405.181796,349.266082,384.422271,437.128335,396.737219,275.789524,224.10822,122.512613,146.423607,211.782197,299.465881,280.378134,152.389787,104.724057,104.596499,110.282358,54.010525,-51.804935,-78.504437,-66.61877,-63.238126,-83.25264,-92.013627,-52.625079,30.210118,42.345375,42.482485,60.601646,78.199608,39.799731,-138.013145,-241.156677,-382.783265,-381.581532,-318.307174,-167.496159,-160.754267,-306.360912,-384.371874,-401.937081,-215.839942,-100.948503,9.744929,-22.83667,-161.89198,-197.971328,-189.791752,-186.442421,-154.549823,-33.284597,18.367762,50.655351,36.042373,-68.628885,-159.762919,-302.653011,-214.409226,-112.259194,25.003524,21.582878,-54.756308,-75.203807,-92.997575,-94.496877,-8.923547,104.90862,131.403988,95.573899,19.848217,-106.584627,-102.640801,-65.442954,-123.577732,-142.203215,-43.633141,26.398613,14.808786,-49.050474,-95.370461,-54.509877,63.182732,98.141037,86.304798,91.759345,113.270054,126.029964,100.086551,-6.787895,-112.147776,-135.405883,-90.773592,-28.909202,44.655646,15.061493,-99.047147,-137.975324,-161.176502,-111.239036,-40.350627,137.662379,189.273435,190.953137,165.271867,91.426905,-41.999471,-131.492148,-216.088533,-175.346961,-18.036097,26.65452,-66.725674,-150.977094,-166.567771,3.672188,85.928782,114.764704,44.165786,-122.083897,-152.590665,-128.698791,-74.216868,-75.346233,-155.068035,-186.639647,-184.172443,-168.569497,-124.605032,-83.844252,38.473889,110.977714,110.954625,82.072268,68.530431,24.266229,-24.331424,-102.201921,-28.481193,39.070673,173.632739,243.80761,326.136401,317.307,271.164271,262.95921,272.451381,320.33875,365.80247,426.484055,389.203815,206.747736,155.469321,228.521932,306.706177,302.532808,292.386105,288.081042,190.4717,102.484569,-35.777515,-47.1484,52.808349,91.705405,25.390654,-126.049828,-148.983499,-120.89815,-117.028132,-153.852839,-137.385759,-110.423476,-62.533216,-48.959853,-72.93345,-85.220638,-69.777281,-63.229324,-49.060898,-56.730422,-69.957574,-34.853329,1.890914,37.402174,43.210484,63.244546,83.934328,110.333388,179.260962,169.377133,75.130035,58.61129,68.325116,47.334836,8.990935,117.689991,203.853111,274.434796,248.857524,214.169557,241.001378,324.8152,322.591377,293.742233,274.115091,268.765738,204.364249,170.962506,126.255368,123.611305,229.22894,362.621608,375.612852,352.227642,342.542398,267.338004,198.732093,139.126772,261.359228,339.809437,437.41024,445.182492,389.920669,355.27152,292.405003,250.447221,196.171039,212.043357,219.625823,181.663594,124.850072,40.602651,41.99349,-11.776275,-149.670747,-168.747322,-84.028023,-17.858179,58.470672,47.456285,31.722217,87.95803:68.279289,118.316527,153.408702,215.634639,201.742069,104.439864,55.772362,9.650018,69.185523,142.897578,366.175629,452.83689,429.952856,367.287917,293.766489,263.067695,168.585733,130.122139,147.588269,168.337262,139.739571,46.066742,-14.683541,-187.161689,-303.301045,-292.655683,-172.303568,-117.236049,-117.970325,-161.611133,-259.647887,-272.90951,-167.319563,-43.350062,-4.744844,47.680717,41.07264,-20.311566,-55.431407,-126.943588,-131.68963,-95.683856,-16.137504,11.090759,37.694981,46.011524,72.956064,76.513909,97.961467,229.657659,311.283644,397.141414,379.047006,261.188485,181.274882,33.517898,0.672718,-13.558817,-76.665645,-89.705585,-73.868718,-35.871166,104.837246,166.316015,221.22928,237.174723,250.483181,244.210566,197.036915,54.909481,-8.582622,-90.039897,-106.627964,-100.435534,-49.964622,-27.940993,-59.723972,-85.599222,-94.187958,-69.796601,50.655589,141.53425,137.959659,89.293955,65.170256,17.411387,3.000487,32.412328,90.131512,95.510289,83.688905,83.139425,66.691606,55.176314,39.660176,22.884227,17.129911,103.504225,155.52433,220.737426,226.090908,175.025602,120.647205,61.49675,193.098656,249.550608,199.85941,158.78007,171.717692,176.367726,69.288484,13.391078,93.560066,276.834318,283.651775,130.012383,55.548383,23.085812,-0.246158,-187.168407,-340.51534,-345.675245,-274.260014,-234.465982,-180.090085,-159.823905,-122.096402,-87.367234,-3.085635,-42.955212,-93.877319,-141.00144,-139.277001,-98.729356,-64.109651,-22.583556,-23.851345,-11.980484,54.98351,85.416879,61.97204,23.884696,-7.7062,13.903114,81.236713,125.338348,167.965243,290.237215,313.479947,206.97391,108.086139,-54.473593,-60.662252,-7.527745,121.4919,141.638363,62.905346,36.113527,108.444574,145.71288,95.932656,39.793694,53.970776,61.044864,24.138511,-48.199815,-58.894002,-107.065723,-208.301553,-237.829126,-215.709924,-192.28532,-216.920155,-245.631228,-248.8626,-248.742939,-355.425963,-533.324647,-553.794539,-422.237317,-348.786697,-323.873081,-343.743124,-324.457943,-245.476583,-209.937578,-128.759977,-105.334256,-156.30509,-219.046531,-384.003272,-459.661873,-487.363667,-366.845113,-313.751965,-286.340867,-305.202318,-360.077514,-379.658962,-368.642567,-197.035916,-73.612174,74.632332,65.985897,-55.613369,-112.193571,-154.322725,-144.141111,-56.044872,27.245028,46.596237,107.708208,132.67136,45.323832,-69.741387,-282.916383,-249.923263,-147.050515,33.092485,51.686446,-15.251227,-50.781068,-97.721465,-122.274002,-162.623632,-196.200222,-200.175771,-168.101284,-180.40198,-294.395673,-329.852915,-277.00045,-206.628447,-189.582787,-119.555249,-85.840201,-112.658814,-143.648277,-170.979427,-170.566056,-127.864355,-47.462454,-0.140906,110.424115,139.351884,77.710066,24.43366,-18.519491,-41.957106,-65.429054,-51.946009,-17.632883,6.476226,-18.738625,-114.269964,-170.587724,-295.34013,-285.102355,-176.10889,75.244025,135.974067,124.652064,89.689934,55.698294,63.571079,26.368468,-69.988533,-60.544005,43.262917,63.045407,-52.219794,-149.724569,-246.495313,-118.590682,-17.401961,63.128404,8.431899,-114.435521,-122.275735,-71.850449,45.050806,69.067454,-10.595365,-37.362744,17.874901,46.054577,33.481922,39.413258,125.527424,130.572097,93.137899,68.696595,93.906292,108.387378,65.849953,-35.381691,-24.583183,21.240236,186.351249,263.459204,224.099968,138.381638,92.831923,149.109198,251.178846,255.030161,263.002042,312.701991,323.28139,316.244211,303.99635,250.375283,192.775743,182.664739,219.890011,236.979714,168.388592,103.255984,-14.20188,-60.369112,-80.336957,-54.161307,-54.7038,-63.652585,-62.207742,-52.267217,-62.768812,-126.871676,-109.744904,-57.571999,27.356568,32.447522,-7.270504,-19.711048,4.377747,28.539022,81.836224,167.236882,210.923203,208.399058,145.173784,16.043301,3.282918,26.893503,74.184854,118.389351,156.866991,119.14434,51.252558,84.883853,172.928671,142.406637,3.228992,18.40241,90.876727,198.655864,183.712674,133.706665,159.827202,258.145523,271.257206,256.831078,283.702568,297.276333,236.682224,219.607538,298.088443,335.639217,322.199546,314.385288,327.760044,317.976737,296.938961,242.173492,188.144793,92.903431,210.377095,302.096554,371.984044,346.567338,259.715364,239.969774,226.209455,186.16302,44.411965,4.652705,52.851352,120.282896,98.048276,57.865316,76.364598,112.89664,48.655218,-17.978997,-85.478622,-57.197062,-5.985125,-15.328106,-41.733524,-40.852018:-129.578268,-12.046566,19.227942,-2.613728,-44.700805,-90.352361,-82.621819,-62.077504,-16.785126,25.61999,131.538523,176.497036,179.213706,140.135134,80.677963,106.424702,216.174311,149.33951,67.388907,-47.617642,-83.096053,-139.219906,-180.931664,-285.976929,-288.354543,-245.538255,-118.3956,-78.740734,-120.528628,-158.190117,-217.140338,-258.264365,-253.266407,-79.608394,-4.3832,20.001967,-11.471267,-66.648512,-105.264925,-231.911766,-232.799994,-169.769374,-78.834988,-90.710065,-111.961481,-67.887032,48.712711,84.596043,165.458986,269.703334,293.469969,278.529663,243.188231,123.492456,61.552059,19.780827,56.030294,24.679414,-95.049751,-119.862715,-82.387456,-51.229502,-44.338226,-56.266472,-31.855715,35.438687,80.012713,123.17194,92.171882,25.862106,22.417282,-1.515268,-90.768804,-102.57428,-3.356774,65.604956,153.424778,154.029565,47.248273,-29.758498,-52.557651,114.545575,179.768497,189.75897,173.24233,188.335246,196.431867,181.553446,235.955283,283.899873,286.377535,196.127225,-47.449138,-103.582949,-100.612628,-91.852164,-9.687636,168.975788,245.591809,306.889381,276.324797,134.783684,69.761731,15.282738,77.408957,117.460593,120.345601,89.008196,12.790884,-15.853695,-60.62836,-69.503981,31.890498,223.275696,276.155144,258.059064,183.506071,-36.177272,-119.68807,-187.284345,-268.899566,-317.186924,-226.160639,-95.444907,28.447446,-16.65753,-129.692149,-152.760365,-134.310615,-70.295918,-62.630153,-129.542248,-156.724063,-114.886955,-88.520642,-74.424121,-16.314998,-3.006379,-50.381306,-63.602041,-45.479595,-39.945424,-30.695059,-24.030654,-20.091999,60.255577,145.455853,235.348002,171.939219,-61.954583,-137.681836,-164.320014,-71.781764,27.049148,227.840999,262.524595,175.164926,129.683155,177.56307,237.71479,357.535187,439.536202,447.555909,410.379821,353.469906,224.170709,194.344432,165.14933,151.535029,167.689574,227.948217,248.163088,210.508619,163.358928,76.369858,52.172898,13.460755,-60.157862,-75.661753,-29.29356,-22.513174,-160.714756,-257.431712,-249.514129,-43.167592,-3.221294,-58.685254,-86.647628,-78.540265,-58.187263,-82.253971,-148.964182,-283.297108,-211.901172,-114.152678,-8.383562,-48.217066,-192.332355,-228.124385,-206.6165,-60.913441,44.19808,131.44807,80.20952,-37.686915,-58.604278,-85.193578,-87.431157,-5.344043,138.922252,189.209828,178.046304,111.964044,-76.513461,-159.470719,-239.202777,-140.912718,-48.609089,57.659393,25.973124,-114.301651,-128.640714,-58.381917,-57.210659,-82.853081,6.73337,54.03218,33.924418,-18.512481,-69.224459,-56.395635,-13.545467,-40.941674,-85.396943,-82.819845,-40.606597,-31.515688,-56.731961,-99.144057,-112.949053,-76.745842,26.570003,76.296912,134.675428,117.566497,-13.021662,-86.232096,-135.052915,-63.431667,-37.015035,-18.007743,20.198018,102.544217,77.393,-100.319952,-170.247418,-132.108024,-17.777943,3.557096,-11.092361,-30.999939,-94.632547,-143.405263,-222.013122,-188.146043,-140.631018,-92.117609,-102.196783,-115.076073,-116.422794,-124.380892,-104.753028,-10.245962,59.277127,79.61226,104.650172,73.712758,-100.77603,-186.848947,-226.119062,-116.142684,-71.929285,-77.660284,-88.958716,-78.325331,-91.444385,-122.524706,-57.286052,220.620006,276.366858,181.649522,6.073346,-19.564381,-41.842532,-79.115272,-125.187857,-28.976763,30.674231,155.967037,236.784641,342.098889,334.594727,224.452017,155.274026,114.168503,207.547447,244.289378,242.222617,217.143581,155.379024,98.594035,-42.490611,-9.605693,58.897362,167.075362,176.234577,12.433696,-144.500422,-365.1208,-351.066252,-200.583875,-171.949814,-191.289957,-243.885392,-283.391369,-329.596051,-323.184186,-300.812058,-272.582791,-245.946749,-140.308843,-82.211327,-77.539152,-122.945252,-183.223921,-168.862261,-87.164582,-34.706418,-14.489037,72.620179,118.477643,113.869035,63.848496,2.510655,81.184324,117.425334,165.596672,191.125868,159.034767,102.82781,19.324015,3.902959,-22.165115,-0.779695,64.576961,175.357396,164.282033,117.11033,111.568647,104.349422,116.886925,144.849857,257.236941,295.294832,260.056492,220.464569,160.863751,160.95998,234.450556,303.203363,320.749587,347.824591,362.748439,348.067394,289.188393,140.851611,163.088912,225.446338,328.750103,334.612949,225.661943,166.818484,140.430436,145.368064,144.105389,151.896045,168.698602,190.054647,163.376417,53.18052,10.132177,-43.68036,-95.884299,-107.453603,-47.77036,10.986131,93.900074,91.125364,38.301245,44.243376:backward
-135.707543,-195.291047,-204.094411,-250.204898,-290.241155,-288.529696,-228.76628,-107.990223,-72.715256,-87.505878,-166.555674,-187.147565,-132.026981,-76.752971,50.290368,110.504311,184.187771,115.244165,28.195898,-74.852194,-53.140571,4.844264,-6.669887,-88.162887,-173.802626,-205.931715,-231.713463,-212.154655,-139.033151,-114.669657,-61.056651,-22.068003,-8.015127,-109.448055,-165.701847,-168.306269,-106.059195,-13.277741,-8.190682,13.760929,9.442353,-41.496458,-146.759095,-130.349314,69.486911,183.411525,265.233026,238.499061,161.353732,108.258696,68.316385,-37.473073,-73.47388,-68.15335,-44.931261,-59.208499,-141.40441,-184.294852,-253.306724,-240.826449,-98.313057,-20.283845,85.594249,124.648902,166.901275,167.479747,133.860484,15.792059,-6.802399,77.128853,143.044091,221.055094,166.836675,94.097475,-31.004063,-30.845696,83.389758,142.056088,191.926448,190.370148,160.521649,137.241119,137.340478,155.217335,167.718831,216.039442,250.382853,260.746169,128.176275,34.012924,-147.752614,-212.162686,-220.982183,-176.798374,-62.552996,-9.84543,36.114468,-6.025988,-40.366489,-77.708658,-79.410106,-86.979241,-85.648364,-91.73311,-183.400894,-235.813622,-293.959232,-310.507253,-320.987582,-286.087357,-122.366499,-55.998939,-107.604133,-269.127773,-298.713522,-211.773874,-129.123699,26.190611,90.617625,185.316223,197.496886,156.745833,-8.024654,-65.669607,6.36094,90.338149,178.553534,179.073532,161.186437,108.605512,45.455171,-45.301229,-20.410244,59.585545,40.671892,-105.181142,-267.515396,-341.148721,-440.363965,-425.221747,-270.20711,-200.322917,-158.156621,-161.819294,-158.734979,-156.405845,-181.471855,-227.18261,-216.513898,-153.834653,-134.325559,-172.17715,-319.311893,-425.764698,-576.265325,-558.489395,-357.069199,-237.573988,-121.298844,-145.746937,-213.935948,-212.070854,-250.91207,-329.412334,-293.646479,-137.121021,-67.261769,9.8644,-17.428722,-68.383267,-201.27333,-227.696228,-151.947108,-104.157952,-68.927162,-71.910107,-133.747606,-257.975222,-295.909399,-270.651836,-219.569514,-112.028434,-70.685952,12.393885,97.041371,103.994049,48.208245,36.463474,93.44858,142.504643,236.377705,254.569862,197.390324,66.987405,-0.845304,-51.474324,-16.893917,106.659021,153.943545,154.330546,59.89567,19.520033,-15.140403,-10.420672,71.31616,146.539999,288.353644,302.189512,208.816326,76.562414,9.663718,-42.352578,-19.68924,-6.314268,-19.857999,-8.138195,23.785284,13.330567,-88.06561,-128.173305,-86.262113,-41.769129,-16.356426,-29.087212,-45.948336,-72.749052,-96.682667,-73.738791,-28.958195,38.600699,82.060627,218.484996,230.774224,171.953922,66.914288,65.320685,138.715848,177.791699,216.346135,199.027356,66.750035,-87.803724,-147.814073,-210.552326,-190.435169,-69.617347,0.899945,110.331021,105.274498,49.060868,-81.314168,-97.700364,-38.415094,-18.774542,-16.627546,-10.232075,-17.477349,-137.043401,-222.133051,-283.0603,-248.230108,-163.375047,-121.766178,-55.269952,-114.236534,-156.388015,-162.76763,-144.975789,-112.586026,-80.241371,34.312511,83.660699,67.139273,-56.626933,-99.502481,-60.73761,2.11254,77.431046,82.110641,99.599793,74.17095,10.553819,-97.216208,-72.813465,67.486413,105.868647,112.354535,103.006547,43.200559,25.429363,50.994555,113.680039,132.805612,156.820037,190.802032,248.818421,118.063081,35.040405,30.752949,91.602011,228.207606,305.182481,456.000665,483.681586,366.075798,138.962649,52.453113,-29.031743,-16.023581,147.112773,255.303516,298.872939,138.341468,83.231346,48.274039,47.712377,112.778344,163.598029,189.989569,156.875205,29.447437,-174.102181,-271.603545,-282.521998,-181.986608,26.804448,71.701221,70.135234,-4.370514,-54.456277,-140.431516,-146.718349,-14.582069,83.085175,180.35511,163.173369,72.286829,9.047107,-33.837023,-126.832208,-136.892147,-70.400834,-0.547142,143.221523,105.118526,12.415582,-159.855216,-175.084423,-50.157987,36.44993,126.674272,100.921005,-54.54836,-143.652533,-134.50384,-51.699782,6.228642,114.73666,169.843635,219.185316,75.671144,-31.160235,-196.698446,-217.566016,-139.464049,-104.510931,-121.430848,-146.952596,-205.966755,-308.724534,-377.549043,-452.877917,-430.324919,-314.381072,-234.796884,-77.663752,-50.665488,-80.340459,-130.118844,-124.042947,-35.04259,32.217061,151.947009,166.753345,88.350235,-3.572086,-39.70366,-36.551826,36.955963,219.765372,267.018583,284.05049,316.959136,347.47146,371.900114,376.094951,426.516235,453.109419,463.246937,439.114881:-68.396622,-182.375412,-206.299841,-185.15724,-158.733859,-99.603256,-57.04279,4.958708,-41.010181,-90.177115,-206.73694,-227.211569,-106.260047,-18.60196,90.893714,119.612525,127.751706,49.460071,-13.945807,-98.773028,-67.647392,105.631422,141.900348,-25.96994,-220.620721,-245.392248,-237.275015,-230.177174,-207.226411,-176.376563,-63.618093,-16.138247,1.75837,-115.821772,-203.63546,-251.367998,-208.257652,-124.263051,-64.522703,105.326785,36.151112,-81.92543,-216.718095,-205.67775,-116.233564,-40.673479,160.199216,224.392767,177.470804,27.117242,-8.525709,25.500679,43.153667,-3.742875,-46.022084,-146.5521,-247.488592,-264.663051,-268.008215,-258.590629,-169.009109,-96.095662,37.429214,76.353089,98.339507,97.434872,66.1561,-38.085301,-47.87287,85.933996,190.286031,290.052197,197.318133,131.718022,13.60547,-15.372768,70.825956,152.883303,222.180976,194.625001,107.128434,40.372419,11.387578,-14.688329,-8.660436,60.806982,122.065003,140.546099,-91.031231,-226.771104,-365.559829,-366.765387,-326.772002,-298.617096,-203.223207,-158.067207,-151.820463,-193.769293,-206.632252,-189.284643,-153.804444,-85.072952,-78.325206,-163.02495,-307.014082,-340.392602,-335.686944,-326.574962,-272.267475,-208.322154,-95.465267,-109.186194,-262.116455,-333.09967,-308.856071,-207.134072,-138.476724,-8.823765,24.902755,50.141578,26.834249,-25.073404,-146.751808,-161.357049,-66.487186,2.905983,94.598626,106.191944,63.206528,-50.912568,-112.038327,-127.470896,-81.692134,-13.727203,-36.773526,-238.729675,-449.157173,-485.747709,-446.320817,-388.94951,-247.710173,-178.999169,-58.643128,-31.689023,-74.238904,-141.229693,-153.42152,-155.186509,-156.132283,-133.712948,-110.014007,-148.690365,-327.164599,-406.780173,-487.176551,-479.205833,-359.394145,-285.552542,-171.801018,-132.767855,-138.095997,-261.649645,-322.312765,-293.595601,-206.655948,-51.842245,-17.435213,-19.976786,-106.236796,-179.927155,-290.72004,-278.719335,-160.764002,-101.611981,-22.64513,-19.478174,-121.123708,-210.728778,-190.503847,-115.037493,-102.780492,-71.620538,-30.543095,43.052576,43.04156,15.823226,-36.529736,-20.646791,85.68099,128.682231,168.747798,168.668356,97.56983,-24.68839,-69.319545,-75.063939,-35.206128,59.476866,78.092761,82.002527,86.027109,58.635996,-21.915834,-16.628201,105.126815,158.533665,145.004117,115.766104,89.652867,-21.228331,-111.875908,-188.678514,-146.624698,-56.996585,-64.90779,-102.789335,-63.993938,-59.524906,-142.807677,-188.532378,-176.133355,-129.513685,-45.573321,-22.56218,-5.359722,-58.745681,-101.082417,-71.89229,-5.117505,96.733271,131.093809,208.297383,217.681673,170.39415,75.792971,83.428413,166.322161,204.612653,275.55731,291.161635,217.674273,84.661484,35.842646,-8.584707,-9.212837,47.954635,110.791899,223.679382,198.250176,133.474841,-5.302481,-16.35489,109.726834,180.269998,205.630962,165.064184,44.976854,-88.766916,-147.106447,-110.974864,-14.243323,129.16581,145.406407,147.657461,79.535197,13.251315,-67.864867,-47.94352,76.167873,144.175744,263.416289,291.192316,208.442263,65.520322,38.620735,106.487542,174.792206,283.743545,306.148275,272.946963,151.191673,85.493727,37.458569,67.690908,153.46374,174.050158,179.457648,167.271051,108.764286,81.810152,92.786699,145.706246,191.645553,294.060129,307.365175,204.678846,80.821163,55.225512,71.348859,117.281484,245.898604,314.888196,455.09767,491.221642,459.685601,363.616062,291.139074,133.296562,88.57169,159.26059,247.923862,312.422444,215.471689,147.723962,-22.041172,-63.585162,38.502519,115.148332,167.120308,133.158818,-21.265164,-191.186555,-252.219196,-208.568231,-108.711518,24.545746,21.892829,-36.79024,-117.267104,-167.002093,-188.464896,-124.669097,65.80035,140.847701,212.611452,192.21317,66.712088,-12.509804,-34.578318,-61.931023,-58.349668,2.700617,69.478355,142.774524,2.285684,-80.632846,-123.105097,-83.433681,54.861274,125.319096,178.066888,145.243041,35.321799,-24.502762,-32.488802,-6.834953,35.061566,147.951961,191.036476,173.42661,-8.090042,-127.949823,-279.561643,-262.867474,-126.458214,-85.228293,-108.630647,-152.636508,-266.615561,-370.869464,-409.610208,-432.833438,-425.431793,-387.800641,-325.369416,-170.911127,-173.896781,-201.582962,-206.901287,-181.649831,-85.167536,-31.243151,68.58352,107.622422,89.055276,-67.546752,-141.652082,-164.669603,-118.590812,12.098481,79.762503,167.828924,202.98187,207.334318,178.960919,177.073531,243.544821,290.141717,360.300641,364.988085:-104.559488,-193.757466,-220.427916,-210.822055,-164.710379,-36.011811,10.008093,-2.485764,-69.200165,-83.26272,-84.354809,-70.386046,13.956029,67.275654,113.116989,110.33837,109.330079,94.247362,76.186747,75.556701,95.942167,136.577905,132.041408,29.377262,-102.129325,-155.952514,-259.221322,-281.646011,-199.814987,-101.677735,89.980592,104.842558,-46.148364,-197.210718,-222.416054,-201.889453,-182.774042,-128.821892,-73.519938,21.303739,-45.254425,-121.222689,-212.190971,-194.714284,-61.432174,36.491729,220.375459,272.131159,269.373852,167.985352,102.283308,30.035025,43.839069,59.06557,28.880867,-60.948797,-151.130887,-198.690608,-271.071747,-251.693636,-91.158596,-9.667626,82.642865,110.852376,122.276124,31.638943,-12.258036,-12.283456,19.729663,100.420224,121.625019,53.209733,-51.142804,-67.15737,-39.373781,-3.411352,84.213118,120.817376,163.17679,151.506175,63.178913,-4.129201,-23.650971,-71.915809,-80.967204,-3.497724,51.057828,50.378114,-84.834749,-171.425158,-303.860754,-324.320642,-295.582134,-257.784725,-176.766474,-161.683574,-180.863261,-195.69048,-191.891496,-191.084111,-196.416154,-191.531813,-186.430513,-206.62382,-286.131638,-329.239316,-349.171543,-323.304242,-251.266124,-207.405736,-98.568552,-77.674539,-153.400476,-251.416775,-262.029305,-141.255128,-32.84373,86.588132,56.025168,-52.879842,-82.445958,-106.137543,-190.463782,-208.142388,-147.499025,-89.769566,-0.884761,2.369659,-96.996929,-261.918518,-304.597533,-254.148077,-204.758786,-143.121122,-127.44571,-151.375612,-273.282675,-342.516211,-402.806957,-374.081436,-242.774515,-176.495796,-73.980022,-34.521918,-4.694984,-75.657819,-128.481496,-186.899853,-186.485525,-118.324222,-84.198736,-180.666155,-369.935565,-410.070265,-425.547426,-433.951162,-416.660816,-353.363448,-168.200959,-127.858438,-212.668227,-338.817516,-366.110208,-334.099863,-269.008791,-56.901713,41.773046,79.649225,-44.764597,-101.651005,-143.593682,-131.016668,-63.006158,-18.673298,52.509584,70.73786,56.229503,-2.517944,-12.67952,5.124486,18.552489,66.144105,92.943801,105.065282,45.544703,-12.291485,-92.35734,-66.668617,72.31255,127.354116,137.692798,102.526936,10.161538,-99.325161,-142.008577,-103.548511,-32.078957,109.359958,161.907742,201.256233,59.715743,-56.321073,-150.971946,-82.657779,119.145527,175.044568,168.541834,122.676259,13.071076,-106.285254,-177.565817,-237.826181,-198.268159,-100.921734,-101.158145,-165.408744,-194.374669,-215.9042,-267.728994,-250.42471,-124.309929,-50.841415,55.119342,65.691263,-12.238452,-79.23883,-59.112471,35.357542,66.188137,99.863676,141.040756,254.112785,277.534491,250.273136,197.712713,200.668548,228.722701,232.303356,249.240701,265.106104,222.994464,89.867967,53.15914,75.816398,99.125554,165.047842,228.420326,310.403616,232.585695,168.600961,75.524644,78.080507,170.64772,215.529088,238.623513,215.519708,111.461379,-33.453957,-98.036011,-136.83224,-100.871775,57.199418,153.821354,260.134402,161.136021,83.648233,17.247709,25.747784,77.440643,142.461739,333.235333,367.924354,242.173231,141.561042,152.365874,257.694066,324.865739,381.44064,374.8478,372.033753,296.502453,210.067965,83.821582,94.222994,201.833392,254.687903,320.160784,315.260436,218.971081,117.493239,96.011313,113.173782,141.172893,198.023532,219.569126,210.832583,114.743064,56.683163,28.095065,84.050617,249.132592,316.090522,376.33633,368.960728,317.544132,247.070095,203.748283,117.331228,96.878466,127.88598,170.548312,229.639798,126.021533,34.756592,-83.655253,-85.445305,-4.912926,59.493169,151.617796,138.783135,17.321727,-145.530038,-196.436494,-148.939913,-76.486106,49.360976,63.174168,-66.770257,-217.699456,-213.993924,-103.944443,-53.022569,28.245305,75.731044,143.264069,128.68393,11.126482,-93.999968,-108.912625,-69.030829,-46.035943,-19.323534,8.921666,43.654751,-51.250647,-117.003865,-168.428638,-140.866261,-49.952467,-8.468376,73.257172,88.528022,7.002525,-129.015437,-169.647766,-125.243823,-57.207366,46.2955,54.252418,-42.927716,-211.519677,-262.349194,-245.751225,-207.938153,-173.632414,-169.121012,-125.164581,-114.042342,-207.111598,-357.896013,-390.594817,-354.488843,-322.976529,-279.29924,-235.825257,-109.516481,-99.4781,-146.857782,-237.345828,-232.786912,-121.450236,-43.544163,106.551426,146.623334,81.238291,-103.121807,-166.269873,-173.770321,-136.878057,23.641217,130.185971,212.335228,132.391924,93.566719,37.158915,38.840121,144.552818,223.864882,339.844922,353.397812:-159.065741,-184.679163,-169.561854,-155.948806,-159.684572,-146.635124,-125.838327,-92.677543,-78.880104,-89.168006,-134.865787,-120.003793,15.311029,85.864661,157.134766,153.463858,99.940351,66.401382,48.872246,2.684522,1.649247,61.024468,84.179446,36.553174,-92.925014,-163.170587,-270.178673,-266.367745,-117.696143,-26.898429,67.086652,68.518831,12.840195,-85.682042,-139.325075,-196.056511,-178.038083,-69.08546,0.758453,66.862477,-32.731067,-99.610061,-185.199142,-176.798953,-7.325544,113.659133,262.253271,273.395182,236.084584,161.671464,100.365617,26.862116,49.825671,128.333881,135.347249,63.174828,-50.389044,-91.062498,-122.480092,-114.126104,-49.577796,4.390886,142.608359,195.955329,175.301656,71.517291,34.309794,-9.15825,-9.199744,35.573108,67.298877,113.377664,106.701501,80.25331,-2.058157,-17.54134,83.090616,153.808244,202.734628,198.018058,195.067775,164.075425,142.089346,133.334238,142.788477,181.792028,209.455149,184.274731,41.159467,-3.421858,-47.268516,-95.728874,-208.126884,-209.956611,-51.300801,54.702745,116.528225,1.518838,-38.753267,-49.128191,-39.331746,-4.341881,7.919982,-57.959697,-185.316605,-218.638022,-267.005761,-289.586621,-251.518279,-178.456778,-17.524852,16.014142,-33.356644,-107.207854,-129.484754,-93.604963,-16.663991,134.9466,146.762288,80.668001,45.40028,33.589671,-47.016253,-86.273188,-38.012762,36.232789,150.861507,147.011227,16.759586,-94.429168,-106.440693,-118.91331,-129.706223,-92.956045,-67.626654,-168.943703,-380.089039,-434.526523,-420.780266,-362.422691,-196.007331,-129.697227,-31.378759,10.357568,32.520023,-32.619461,-78.271048,-129.257738,-123.872038,-93.15022,-84.572851,-130.607727,-297.409427,-385.761437,-477.922557,-471.586236,-331.754315,-216.371826,-56.219226,-65.097895,-212.826174,-349.530642,-377.863485,-318.23846,-251.770578,-142.98363,-91.186054,7.034173,-35.212418,-122.213483,-267.319533,-239.920216,-24.920521,56.416785,75.311012,49.942774,-43.34348,-149.192684,-157.05091,-85.563356,-44.23649,19.238894,39.853505,30.812264,-11.992792,-47.269871,-113.391127,-95.942957,23.549153,72.988509,89.829334,68.344866,43.554822,6.931344,-45.506136,-106.244338,-84.943642,0.608682,48.613079,123.584021,81.851921,16.722363,-89.350527,-91.673348,20.633045,116.542377,260.548781,248.668551,113.273888,42.161747,17.850478,-70.197288,-125.8408,-204.102287,-193.993913,-72.811358,37.779894,21.529291,-151.843361,-223.204163,-163.459641,-67.90894,51.37987,45.015955,-14.225834,-52.37443,-52.984728,37.215758,105.118204,186.090312,209.432326,277.835418,351.390379,340.412349,201.017713,139.026011,145.345062,204.426493,354.769575,372.460239,189.25065,-27.099615,-54.947318,6.384552,50.412039,115.89615,134.174304,108.340619,23.38008,1.851343,12.98324,42.116178,116.348308,124.37445,87.586353,71.713102,51.339807,-20.835297,-79.926126,-114.53437,-68.557538,19.178813,41.561535,83.886541,20.141755,-48.493669,-119.590013,-101.286392,-15.101384,31.746125,143.019487,184.05437,139.65706,35.952266,23.005794,69.46885,107.874346,176.233593,207.644008,232.204249,163.307863,119.22055,92.157083,120.624456,218.02748,255.508855,246.11166,197.338516,84.957357,59.106307,62.675711,59.829909,75.844876,159.067443,197.135323,194.541906,91.774339,32.758909,-23.417333,-3.354767,115.645395,192.980974,318.339496,343.000245,298.264682,151.424897,60.70692,-91.34223,-116.161349,24.311619,151.764812,262.415753,133.084418,65.792547,12.297475,22.725954,62.248089,80.891503,154.495381,188.989836,134.801388,-95.611178,-213.211456,-257.019072,-186.416233,-40.392042,-0.866912,-0.755952,-85.765284,-129.599485,-190.976167,-181.876112,-56.8306,14.156242,54.059265,10.2019,-118.960574,-173.250703,-185.794466,-178.165386,-136.909875,-27.974639,13.215289,32.662262,-94.228313,-180.565353,-237.962189,-213.867269,-187.80071,-187.181945,-125.7582,-93.390575,-130.742822,-161.607499,-136.269035,-52.807006,-14.757753,41.938263,47.526916,-35.083485,-177.657916,-249.271739,-347.739434,-325.460701,-144.063914,-68.43963,-104.67593,-192.483949,-352.701372,-438.044045,-467.720997,-447.75034,-385.40981,-237.421208,-171.142475,-82.338113,-137.79681,-205.86519,-296.686491,-292.705219,-202.877222,-133.650854,-1.494988,35.718397,-2.922552,-185.02317,-262.692552,-253.988552,-179.06989,6.783927,63.093961,47.049083,67.453861,130.381114,237.013643,257.430355,277.831885,291.75303,325.956955,324.451058:-129.834757,-235.803945,-228.364315,-135.151798,-99.509804,-68.900927,-47.109477,-21.646811,-73.852889,-114.277611,-151.554359,-127.504618,-37.263175,1.04248,59.723292,76.654686,41.799515,-41.066312,-59.423183,-31.938008,1.315177,74.623549,86.990545,20.026973,-108.013675,-182.165225,-290.466123,-276.446555,-96.463713,17.285668,170.971662,181.127901,51.754168,-178.95983,-270.552188,-287.204308,-235.118844,-113.097551,-42.007486,51.797844,-50.915755,-141.400565,-247.521133,-220.335475,-13.193297,109.728705,244.514135,238.560463,146.88691,74.602432,69.467684,101.515113,117.137226,128.882493,120.184879,50.403923,-46.063323,-87.218525,-102.429239,-53.446754,75.332006,117.741075,207.421026,247.997803,211.510286,72.83293,15.49445,-59.070633,-69.377672,-23.083046,19.469119,77.954047,38.708746,-27.214606,-119.918247,-75.794887,91.415024,137.355841,163.950404,168.787339,145.995272,60.088554,13.272692,-23.2385,-6.300741,88.221085,143.556755,158.038282,63.031178,12.36284,-111.731346,-172.775069,-218.731602,-180.662897,2.200455,86.91998,116.936495,-4.062422,-51.30134,-65.283793,-59.849916,-62.023566,-61.668814,-36.599414,-33.450236,-75.234419,-208.218281,-235.098181,-126.740365,-30.13312,104.278155,112.479447,19.245884,-111.788423,-136.549619,-54.651782,28.065191,169.336829,187.811972,84.526894,-57.446507,-107.119291,-174.751192,-168.046038,-53.366132,15.270712,55.215985,26.05107,-45.60854,-170.175536,-243.573368,-266.764835,-217.067211,-105.956449,-75.243148,-126.075212,-269.927489,-319.969634,-366.988334,-365.942021,-262.883577,-157.849864,75.305476,138.934509,78.393493,-70.233662,-108.175516,-94.629427,-80.884037,-80.260662,-75.597396,-128.053661,-311.566692,-379.311009,-396.779394,-378.036356,-278.732479,-188.861442,-65.441036,-94.445697,-288.696102,-414.627661,-409.413739,-332.053126,-297.191239,-206.207289,-119.204823,26.463547,-46.364178,-129.903478,-187.732291,-128.300125,76.958706,163.083777,204.518831,164.745573,67.926688,0.555733,-16.000447,17.29359,41.329494,79.518828,110.366287,139.988734,52.959423,-19.861899,-131.875885,-133.969375,-6.323719,95.955581,239.46906,228.988889,88.166458,-38.893762,-71.774471,-70.513727,-33.915622,119.101767,206.505049,237.107912,74.142837,-2.463586,-77.713237,-72.657123,69.754604,191.51203,345.686084,311.855701,112.741623,1.26964,-19.448627,-64.851074,-75.274008,-56.036964,-57.185841,-99.411784,-70.667568,-51.906839,-125.959119,-190.858178,-209.321026,-122.815424,87.754431,103.649133,3.760853,-16.871791,20.064611,160.196622,224.184753,279.574203,297.357834,359.745605,376.707196,334.021092,217.32926,195.377393,245.589839,312.600693,452.908918,446.393184,275.317497,136.282591,109.883239,135.464758,172.882073,239.832741,270.873905,299.306042,207.840154,128.535761,18.787503,45.761516,208.21705,262.155941,232.141798,172.408618,59.4202,-54.931143,-112.692293,-73.216401,15.947116,145.407001,184.966347,229.926223,101.225032,18.38224,14.713614,88.242987,237.856215,287.603926,339.50188,324.792059,220.60913,113.971698,81.331994,106.45342,170.878969,369.689274,454.988122,407.553735,153.307098,69.633592,93.81173,177.914833,371.743263,434.946689,408.385211,324.67849,146.045637,65.860733,61.436255,81.018426,86.565609,126.79935,174.479648,210.728158,79.396394,-11.430389,-91.42485,-49.92246,96.61658,163.162845,258.352035,266.952641,214.730896,110.281964,24.351607,-147.317411,-175.944874,-47.485564,59.584812,110.439413,-29.297525,-80.157154,-130.991875,-142.624233,-108.385216,-52.947791,67.582607,75.171954,-47.210697,-235.028453,-306.235865,-303.861712,-244.984439,-118.571885,-53.820372,-5.764535,-165.550562,-257.636814,-310.745884,-257.753928,-76.177687,-0.787254,17.858914,-41.36651,-172.026078,-231.075823,-249.885153,-233.518965,-174.407146,3.868523,59.639643,4.316847,-159.34882,-227.363383,-282.043399,-261.752555,-168.517277,-116.26357,-37.528683,-39.928663,-151.769534,-245.747368,-235.78388,-107.35436,-13.53452,124.414871,135.275976,29.20341,-163.441729,-248.938526,-310.046577,-271.596704,-166.97707,-138.614495,-143.99071,-176.567349,-244.747933,-346.691054,-402.725522,-374.72495,-298.260039,-126.027637,-46.54177,-1.446882,-122.871591,-187.120978,-264.214489,-267.748908,-170.649018,-70.341464,132.346823,167.546564,78.418677,-117.549628,-196.78768,-174.825521,-87.406128,105.049648,156.668777,124.400526,80.037338,81.811189,83.020794,92.927115,177.718044,240.470679,313.133406,291.877904:-87.449629,-123.414728,-134.475544,-144.512527,-135.147593,-70.294401,-23.369521,59.543788,70.308521,37.58514,-41.519652,-40.582115,47.358148,98.260928,170.679197,192.096244,171.302156,12.293056,-90.368364,-168.78145,-104.833042,79.999917,119.399038,74.422087,-69.70558,-157.849983,-221.165286,-159.695803,25.122823,74.510875,69.635373,41.924047,1.11114,17.195033,5.573041,-88.527,-132.735084,-129.75548,-79.031958,10.526289,-41.111555,-88.543647,-108.723576,-49.560339,191.352997,289.440671,322.989887,310.427348,267.580849,120.985468,42.915811,12.466918,62.593617,171.807782,190.688081,123.121655,-42.912771,-115.652906,-173.40516,-133.330598,57.372084,144.342123,241.465972,256.937675,208.94225,120.480565,72.703184,-37.636826,-76.917815,-57.016397,-1.768344,101.777162,49.957477,-38.5187,-182.173765,-155.811846,96.219311,224.208644,309.703128,291.572791,264.916731,291.016264,293.792249,290.636764,313.7128,426.145743,475.831229,406.503885,187.814515,120.301703,97.5622,105.151482,101.476171,94.737243,148.164445,202.124232,233.24717,202.599552,191.846607,93.334094,6.702369,-89.978252,-72.91709,-31.036089,-80.785114,-134.609135,-293.781625,-367.315631,-346.614833,-248.531645,-24.419032,56.673572,95.825264,-20.429975,-80.709426,-77.977287,-26.053823,72.579443,107.070192,141.39764,126.25595,109.500784,74.629143,78.512393,158.092306,203.510535,240.399046,228.890597,162.42468,103.325158,66.6626,4.929296,26.349208,122.700825,118.699406,-41.843467,-242.743177,-307.74407,-308.595971,-241.177117,-101.543322,-87.214392,-96.57315,-45.869841,124.163352,117.393847,40.140596,-65.282108,-66.486514,-56.651703,-62.191177,-88.5344,-166.207563,-229.640986,-346.095678,-363.131956,-270.721398,-168.334906,20.875741,39.972257,-72.443627,-224.913311,-276.63314,-305.739601,-286.577802,-183.181267,-107.819424,-30.826516,-111.833874,-151.384441,-169.610421,-142.710743,-8.601438,56.384792,73.659125,24.428378,-106.986439,-171.973138,-170.174447,-158.181041,-151.448191,-82.140993,-38.888907,-33.323172,-76.88422,-98.350999,-156.479716,-161.384015,-72.340981,10.959736,185.770579,221.87003,152.514266,49.740549,6.420777,-39.114661,-36.099656,4.646635,70.689123,218.303411,159.574826,80.832631,-60.376803,-76.807374,99.047772,246.880892,423.292974,415.354524,310.777462,195.310356,134.186542,71.08172,79.594838,71.832602,49.24237,75.232147,142.421013,102.135467,-109.132437,-175.886034,-119.0664,-56.845277,18.256349,38.532198,61.859743,31.388655,17.298361,67.613654,110.018182,114.143094,92.492378,153.748652,281.247731,280.109509,138.111751,80.889317,154.869745,253.784869,394.244088,376.962625,192.532592,53.687152,23.956345,-17.957063,-22.868315,32.436383,98.63454,227.166885,129.192039,15.128579,-107.938577,-84.883813,-5.696858,-7.875371,-50.447926,-45.866924,0.283634,-58.140751,-124.828796,-173.436732,-152.028692,-120.650121,-110.986114,-88.287496,-126.570965,-164.659122,-205.550141,-202.588478,-179.582582,-152.059847,-27.751407,53.02188,101.090737,-62.194349,-144.142201,-172.532339,-123.65015,36.9963,110.35918,147.158911,62.989576,12.537512,-42.471949,-15.664005,114.000273,156.074134,144.920389,100.208136,-41.557723,-67.266099,-19.572417,8.202025,-15.682434,18.369595,79.666789,138.8383,40.249094,-23.317735,-75.486132,-44.955474,93.353874,173.769726,299.110025,317.94982,221.612129,23.013612,-66.9008,-159.647404,-140.581832,17.211888,122.345033,197.492772,27.451749,-50.39761,-102.798297,-100.81808,-66.248967,-45.072491,-15.826107,3.08648,3.460529,-157.40895,-265.738602,-338.692561,-267.409586,-36.689407,53.176196,98.762958,-78.582066,-212.249396,-375.259261,-359.011597,-158.596508,-47.54392,12.301456,-30.831342,-136.089585,-225.796778,-275.076187,-323.9682,-289.722656,-149.414831,-97.068933,-89.836923,-145.677416,-168.918267,-222.528194,-248.481358,-228.343938,-183.117709,-108.995999,-115.012903,-208.141317,-235.85502,-190.258365,-54.215536,-4.499846,94.326704,164.165052,183.694496,-67.656646,-199.056004,-292.880208,-261.926753,-166.770472,-147.597861,-177.483935,-226.508139,-369.395903,-439.618466,-439.865295,-397.119676,-356.111448,-251.189067,-171.085933,15.126017,-5.513982,-93.761687,-189.810706,-149.779296,2.237626,51.227985,76.509748,84.264852,102.735997,50.84771,-6.961349,-50.682578,10.74859,192.844916,250.312291,260.309674,222.31728,226.780184,316.516479,393.828248,496.570127,486.417168,407.48397,342.362269:-16.849771,-118.241838,-168.330744,-180.106915,-128.648503,3.342507,49.050104,63.135163,-20.645392,-81.268776,-146.586008,-123.269911,-20.04371,26.737395,96.590985,114.306404,74.374475,-72.381423,-154.90048,-214.372522,-166.144868,-1.026515,51.045005,45.392547,-47.218028,-118.425538,-211.908196,-183.328537,-8.988315,86.847497,190.071459,171.708464,47.935888,-85.180539,-155.594413,-261.210664,-257.762945,-99.634524,10.570905,78.412175,-86.62021,-161.439895,-206.211972,-183.740392,-43.582666,67.932492,305.655714,379.187995,300.31474,52.440776,-24.178864,7.361502,98.440288,282.002277,308.246252,200.15614,15.949748,-52.345334,-67.380604,-1.139674,184.222275,258.656095,334.415396,328.707291,257.371151,97.40151,-13.777844,-96.920586,-30.497008,126.048538,161.924515,154.644383,46.211491,-23.834926,-131.460526,-122.378842,69.783882,180.496364,283.062556,286.236881,231.005219,130.407724,83.434375,39.731357,59.511128,198.16017,292.218721,351.972484,174.110103,72.500887,-47.264093,-59.665468,-23.882812,12.274268,144.627367,212.362255,204.270382,38.548725,-24.592191,-30.662777,3.109858,97.573771,151.58056,169.292907,19.419324,-76.70132,-244.089749,-279.593817,-192.761934,-93.39512,107.83044,164.070019,134.402264,9.316596,-38.537088,-12.890488,61.248403,204.672973,231.470692,185.504281,55.937092,2.080193,-31.895915,-14.490488,64.003631,116.144212,207.329636,217.86886,155.44299,-9.032631,-105.248517,-146.578184,-83.075722,37.874748,46.387841,-71.238144,-290.503629,-360.06035,-352.705931,-301.646113,-181.941886,-122.864399,8.66393,65.984397,90.230241,9.404543,-32.091264,-44.859894,-29.377922,-6.576013,2.129734,-33.546269,-171.107644,-249.707768,-370.297372,-381.376642,-240.443461,-114.227442,72.899018,78.565708,-57.642328,-226.312515,-288.950996,-340.88683,-315.260546,-144.862699,-34.018993,59.746935,-43.781927,-102.71711,-155.487282,-132.006339,53.010395,164.228606,223.482581,155.523576,-42.773852,-152.57439,-174.127067,-164.71662,-119.767178,28.733301,101.33522,135.412965,6.123448,-65.421532,-146.869535,-140.442058,-42.204694,26.997616,181.139514,231.063014,141.092036,-107.115756,-177.759622,-101.957022,-2.883139,191.673744,256.878283,259.702385,155.598185,88.208364,-10.406443,10.932918,185.647512,280.856715,387.45271,380.42813,263.24111,120.916958,72.517663,32.215903,17.494094,-0.393715,12.728566,33.069116,28.181568,-0.464017,-157.576595,-216.119791,-117.937559,-13.936038,84.352138,74.993859,50.189284,31.404335,22.700368,109.12428,198.998497,316.090083,328.296118,328.400778,293.773794,233.168806,60.699186,23.71962,166.154395,299.124626,478.854349,465.099523,257.672124,93.386136,85.022325,119.168395,129.015591,184.216501,244.05234,303.728601,178.021691,78.662836,-34.91659,5.058507,165.403764,203.091278,204.223881,196.174963,108.706166,-59.454946,-92.529507,11.264827,82.741634,138.858298,144.883978,112.291398,-40.825765,-102.534017,-63.07573,16.943628,158.291726,199.209419,260.636169,261.57738,140.002988,-20.714219,-61.127845,-28.658318,40.432819,236.995142,309.132413,282.536675,134.059382,67.451622,27.622666,73.527918,198.493128,233.205747,249.152985,219.44846,92.178748,-3.030617,-35.121735,-82.537368,-94.174618,-41.850119,36.775341,149.568075,16.497483,-85.372328,-145.750995,-88.534678,76.781466,147.759106,245.303851,235.468639,47.963776,-173.261742,-236.52895,-244.532687,-205.961532,-99.8733,-34.476083,50.462519,-40.895174,-126.010235,-260.711389,-287.263274,-261.141592,-200.122085,8.246934,78.402476,-24.656685,-322.974611,-446.395603,-468.459037,-355.439143,-59.166108,42.356508,38.812725,-176.05049,-275.271491,-337.837231,-295.192197,-136.26752,-78.636299,-77.614378,-114.427675,-193.532686,-285.048214,-340.583068,-344.252227,-265.52163,-71.324643,-8.778739,1.956861,-134.867569,-230.315432,-340.29741,-312.890376,-160.804617,-97.202589,-70.846626,-111.119872,-226.592727,-286.870675,-287.059405,-180.780612,-82.254209,102.750761,150.87911,79.687878,-142.523749,-237.580166,-307.909487,-279.489951,-165.54892,-116.425453,-101.029258,-148.829821,-318.313235,-446.637447,-459.300412,-357.878481,-256.187108,-48.448348,31.219607,90.222897,-64.956405,-177.652047,-252.674673,-185.293113,-6.665834,37.252983,76.731131,91.389776,26.072165,-161.036226,-225.470861,-150.574524,-36.04757,153.969271,183.640267,128.23607,67.120135,60.61622,86.017772,133.973213,282.502752,354.987941,443.229013,420.945582:81.539935,11.820711,-2.33009,-36.517766,-27.648575,103.762925,173.276081,167.763064,65.71031,43.327397,43.150217,70.925484,170.033897,204.930575,258.783262,275.468783,176.934529,-32.223586,-108.786844,-115.809222,-38.336464,132.883356,147.536535,41.279177,-70.532771,-112.047199,-169.765807,-153.766261,-15.617422,52.6444,90.616549,85.211793,110.000545,158.620218,155.429212,106.302735,86.003668,77.132661,87.007258,92.632428,64.68931,65.264272,122.764651,184.497456,372.998953,439.233442,398.273477,337.845622,249.445847,158.561897,83.387094,-40.362359,-32.752218,54.249116,63.181992,26.799618,2.59272,-12.704797,-42.383549,-28.203951,80.363661,132.224515,155.711333,149.749074,146.597079,72.085151,-6.973112,-132.145774,-144.554322,-109.857649,-77.37384,-9.851504,-16.713758,-74.094262,-205.690557,-194.463034,-7.808344,84.816352,183.749553,204.337161,178.876355,171.804475,221.307586,347.160178,376.300462,342.962361,312.828905,267.543831,205.561797,176.250425,162.568055,171.196036,162.338663,155.988602,207.011656,242.324747,245.079601,184.025464,159.634926,131.957772,112.417782,78.013768,80.781254,67.388193,-7.271955,-37.170433,-85.904142,-101.682232,-55.670493,3.791999,104.855463,116.553722,84.11675,-11.282066,-67.314531,-108.615285,-94.539191,-21.633386,34.987903,115.809126,101.884079,73.611793,29.743296,49.830574,146.387335,167.529981,148.122818,142.752693,141.342277,86.77789,42.198713,7.780442,25.954002,70.178641,79.587414,41.159254,-61.035318,-103.42298,-127.444024,-104.595374,-43.247456,-40.154712,-48.577042,-4.663931,143.636306,130.34275,46.627387,-79.602092,-61.768774,14.42167,3.978322,-54.814487,-33.133333,-32.590247,-171.283645,-263.011132,-251.516652,-142.65231,42.979253,49.110947,-53.214007,-136.129777,-161.144125,-155.180281,-115.744622,-64.218751,-79.085991,-130.204289,-142.196155,-142.418976,-158.30439,-159.363703,-109.937518,-81.13826,-55.115963,-49.47789,-86.794099,-197.65735,-258.579224,-337.491333,-320.848701,-175.082358,-91.630006,-5.985058,-25.945656,-53.305057,-131.73853,-162.66779,-113.588241,-29.506113,178.13257,256.700376,282.041045,188.610965,144.798998,114.129075,128.39449,188.494452,203.796104,180.101223,224.104615,254.842772,155.791797,83.886731,204.784748,364.283811,553.211205,544.406571,453.466134,410.811352,397.599363,286.292673,189.562748,92.146416,142.41928,313.58785,311.038427,222.961993,28.941642,12.841913,163.562624,231.236639,212.890451,180.74627,207.644783,278.680438,269.248038,214.2153,221.698255,278.369671,288.770973,291.655787,317.652684,296.974473,162.514627,111.755144,186.835919,289.632748,444.510717,439.458209,283.28975,102.5885,31.904469,-59.77052,-76.504152,-12.814488,74.243722,185.78642,32.64288,-63.422667,-131.886544,-116.815882,-77.420514,-72.625389,-42.150428,-8.586172,5.439937,-73.445129,-113.356491,-150.375514,-159.613661,-147.439991,-90.475992,81.463329,95.195437,26.265047,-110.568555,-145.729644,-175.58645,-169.206523,-96.653751,-50.101469,-27.618798,-157.7666,-255.330227,-348.267959,-309.006303,-161.395193,-102.041588,-86.893232,-185.214381,-227.42706,-273.693555,-272.394975,-202.486652,-154.675752,-96.802417,-102.713364,-189.070873,-282.007208,-309.850655,-357.92396,-368.291649,-272.611659,-162.325675,38.117734,35.916222,-19.278628,-88.389975,-74.826232,7.011033,58.69437,154.359928,165.335305,26.800469,-175.611932,-196.62471,-83.726974,-24.551721,49.426159,104.238343,190.135706,94.574517,8.290712,-141.366969,-168.814104,-141.643926,-149.20459,-200.786785,-187.178838,-129.103968,-190.275209,-260.148089,-331.948884,-294.5141,-147.209448,-96.42716,-119.375488,-265.555229,-348.667894,-452.669752,-436.852799,-258.558104,-168.095406,-133.916069,-164.80176,-220.892388,-223.722846,-216.784007,-239.023272,-263.374093,-271.092828,-234.70043,-150.342039,-178.852624,-231.71445,-335.296159,-351.401705,-292.557845,-245.886405,-179.132119,-168.348705,-180.875199,-196.823575,-198.921249,-142.407112,-76.993248,68.84896,131.547056,177.062377,97.171421,53.526773,-9.28995,-25.427319,-10.987701,-15.582672,-83.163183,-117.068911,-150.235872,-182.3651,-207.277951,-174.359176,-89.461723,103.807841,157.339488,188.341477,161.817014,128.97107,82.085806,95.006198,183.236834,223.833555,268.598718,282.50589,242.944136,119.670388,74.63763,102.514676,177.444654,355.443507,419.827928,437.210263,333.735343,300.91783,333.607688,368.0974,419.487899,442.644157,442.501376,376.969936:12.93152,-81.11996,-102.162907,-158.975828,-182.582357,-140.121877,-84.056298,15.556579,28.325666,-2.139204,-73.96147,-69.081705,47.426757,111.75006,167.229326,167.329709,131.482683,40.233201,-14.556344,-47.55773,-10.880932,54.53265,60.797503,59.959774,-4.688672,-65.879355,-148.345907,-130.615661,-37.490078,-14.376767,18.63434,54.385794,90.478278,27.786437,-5.345723,-6.383121,6.810125,-8.264182,-15.283367,0.270928,8.406145,10.754205,21.339685,56.316127,185.715686,228.335347,263.101022,279.284999,242.945162,123.188286,74.93712,4.376738,-31.132138,-75.103131,-40.584855,89.593779,54.972644,-14.32814,-96.413341,-79.119681,-15.662686,-12.255592,36.41153,109.140959,182.890283,87.675125,32.910971,-6.293611,26.94809,122.459133,146.784791,175.103763,157.555642,105.63498,-34.913548,-60.713796,57.144809,143.134281,253.198278,286.757775,288.969066,256.502886,283.467984,405.143913,443.539828,395.793782,341.757105,274.536894,190.859721,110.41447,-29.678791,-38.665542,46.437143,87.465801,129.529584,156.006068,175.853139,126.305512,112.287369,65.679648,19.585076,-12.09244,11.598685,-34.809253,-192.648161,-224.3584,-195.10229,-183.909706,-196.680489,-175.117405,4.407545,92.134293,25.493276,-227.624999,-314.85402,-329.179597,-257.755727,-56.616275,23.780576,126.176352,198.845624,193.243433,86.652735,61.02019,121.02578,139.852818,132.080215,153.076449,206.122084,114.972826,36.601676,-51.939916,-51.040134,-23.584595,-15.304664,-17.27785,-122.243952,-207.601322,-301.235918,-281.292934,-183.327856,-134.358555,-5.353182,72.273644,142.215163,31.618375,-50.06715,-127.061953,-104.641034,-33.159553,-25.623215,-64.652191,-144.935923,-199.577598,-332.136702,-376.769955,-301.630264,-211.66774,-108.420768,-116.199031,-156.939171,-163.618556,-184.886791,-239.002641,-222.010296,-109.770988,-65.173814,-29.61073,-0.568048,-5.171413,-84.882302,-94.090252,23.269684,67.051023,18.534306,-20.980887,-66.929245,-149.786297,-215.99499,-314.458318,-298.071295,-130.257159,-34.037453,68.130999,71.246201,50.889613,8.476756,19.563211,109.702483,161.480026,260.445173,304.012428,323.29493,194.918612,112.517906,47.206384,71.285893,152.841315,179.25992,195.589172,209.922392,200.081225,127.544757,119.972763,234.841267,315.682454,438.018388,457.395701,355.029273,197.956899,171.201924,175.140385,152.118902,58.111217,45.286297,127.858289,187.758697,164.756597,46.842264,1.036227,11.392328,54.224039,129.506636,123.480593,55.04916,9.313228,-31.256042,-68.119726,-7.930695,179.204348,239.031321,260.607881,188.523441,114.024285,-40.144319,-56.131947,88.827668,193.141785,291.808748,270.588715,136.853047,-56.658547,-150.688516,-247.873041,-240.412766,-150.059645,-74.114296,94.037564,169.870425,154.056703,50.051939,2.568352,-25.859091,-39.98414,-90.402433,-84.741061,-39.267469,-92.856666,-140.17514,-208.422683,-235.445903,-238.628705,-172.556651,-8.156121,-32.067267,-85.628883,-154.194957,-173.836439,-239.869324,-246.773079,-93.724571,2.669125,-1.739756,-136.063617,-160.582761,-179.511692,-192.610908,-147.828223,-91.488266,-30.284773,-103.187855,-164.620822,-258.061247,-271.787424,-217.037442,-148.451409,-17.629881,-16.998484,-135.049179,-233.640419,-249.923777,-206.991194,-151.829638,-58.565596,-50.782058,-109.694929,-176.213931,-183.259475,-142.95593,-100.131438,11.811413,74.609204,191.539422,212.172681,94.386083,-96.555289,-148.851786,-169.218526,-134.808431,50.516064,162.390005,240.931328,116.164247,44.599515,-20.483449,-10.728289,18.248283,18.10157,-2.084365,-34.171478,-135.475673,-218.570905,-266.062956,-297.428189,-242.496739,-116.601118,-95.764343,-107.316029,-191.075016,-259.819262,-338.144096,-309.66523,-115.434221,3.956096,113.478869,71.929641,-106.95008,-194.886772,-180.263831,-109.097534,-87.165576,-84.65434,-70.253698,12.847059,45.184774,11.130969,-137.521365,-212.237218,-262.569522,-240.040544,-172.077366,-165.705024,-189.334805,-174.813855,-177.155075,-175.993207,-141.794521,-4.574372,81.745451,201.721036,155.496398,90.437279,-29.922778,-62.192238,-67.084837,-76.793888,-153.849411,-181.415368,-158.804837,-180.553664,-238.795631,-307.383788,-276.828938,-174.948689,-138.657073,-66.885582,28.191072,55.529453,24.490352,16.226366,128.388446,213.712642,325.165753,338.26963,288.353501,196.481693,162.12842,161.558269,182.706818,230.234095,275.894826,400.210266,436.335397,429.387492,468.316175,513.023154,550.758839,514.04638,373.90108,306.008156:49.386045,29.834782,-2.701265,-26.974645,-14.104922,31.165993,71.537565,156.976464,107.37832,30.712433,-80.269866,-71.17708,31.921546,78.050953,114.1995,119.001862,98.101346,-23.913653,-108.053649,-182.845068,-127.044883,78.286136,145.560348,108.9222,-38.04874,-73.083309,-49.877494,-15.590871,98.165559,157.448879,210.037634,206.660158,141.286747,5.134902,-68.84044,-191.919153,-217.561913,-112.843566,-7.801162,84.602203,-29.983773,-84.782519,-69.954818,6.769901,228.374977,295.974868,238.273754,163.064705,68.865073,69.381351,75.694509,53.384204,36.747457,51.24604,81.177329,97.704928,40.946681,16.404407,5.165787,30.256082,145.633386,206.319082,270.886386,262.503409,176.256991,82.179579,35.429575,-2.070901,19.408721,16.077375,-18.283285,-51.797195,-84.072772,-117.610525,-154.022547,-122.956889,23.998074,86.954514,126.682636,119.341794,128.824801,188.643364,206.937083,250.553695,298.204307,370.536593,356.328927,257.467462,190.004989,183.251372,130.212153,95.88401,111.228803,129.482878,145.495808,176.064277,215.005365,106.96502,65.140074,107.072334,145.625281,177.003197,208.216988,299.747353,179.19221,48.541051,-142.492875,-158.831276,-65.510776,-8.367398,60.940394,88.924284,165.513136,159.757697,99.771189,-17.795735,-35.316687,2.146852,40.633086,91.944742,31.484406,-13.01337,-31.846051,7.725627,130.825416,169.743097,184.478346,172.125873,67.41707,-92.393299,-146.388463,-130.808784,-70.249925,18.228909,29.384697,10.274191,-84.6962,-137.156932,-213.423294,-234.256236,-214.449812,-177.058065,-67.662956,-3.289614,101.998387,94.973402,39.624401,-51.575931,-47.454317,-18.916265,-25.600432,-35.315802,-24.277953,-48.189977,-166.035822,-205.824739,-154.281922,-86.24945,33.683238,50.92698,-35.848142,-173.449502,-219.29019,-258.251159,-247.250667,-166.856621,-119.12466,-73.820991,-88.158881,-100.867971,-126.775795,-112.347076,19.785841,85.22908,86.371482,47.104096,-18.370256,-126.392663,-206.916199,-286.815553,-245.493076,-90.493101,-39.094193,-29.507695,-48.829086,-55.382669,-90.882502,-100.243541,-50.793464,-7.04617,92.281851,147.223956,197.209422,75.668998,-23.112695,-60.286545,34.637651,236.525787,267.118882,221.905479,156.378147,102.608317,-13.647968,-21.746461,106.29126,218.170526,422.902103,445.289511,290.921104,115.933322,88.753804,133.282146,152.134424,130.820403,123.954258,102.821792,46.699723,23.292156,-55.193128,-85.600227,-50.649306,-2.968925,97.050343,114.932521,66.976726,52.23045,76.117029,154.042424,179.280565,181.523376,196.353138,244.468551,212.397743,177.23697,103.429224,77.780082,119.732613,190.568484,287.591745,248.068935,70.816786,-19.414488,-27.460314,-26.185878,-31.375163,-12.692354,41.048814,161.646558,140.647045,86.232681,-47.582628,-99.116678,-101.366982,-70.684745,-19.485861,-0.592488,48.689691,67.325997,27.150243,-88.218451,-98.913478,-10.985855,36.309935,54.580541,7.56465,-23.285524,-76.119839,-71.162159,-50.243638,-58.52991,1.922281,69.168588,73.694643,-91.831272,-156.660451,-166.167206,-109.017201,65.861827,136.076629,146.430226,1.982532,-65.951651,-92.964948,-56.558814,36.591611,78.808837,132.52026,101.670708,-27.897021,-90.049446,-130.172365,-217.073301,-212.902844,-75.088833,14.851291,63.442431,-16.155251,-19.214718,8.916374,-8.291752,-39.797968,2.365924,148.322814,175.509105,57.672687,-142.551177,-212.751407,-239.841222,-189.85858,-50.893849,5.474496,51.976162,-38.728341,-87.745872,-119.557011,-131.81732,-200.220787,-237.217793,-206.803693,-131.274291,-28.779769,-132.342196,-222.515598,-306.484252,-273.89511,-149.652937,-98.528422,-62.525524,-137.332993,-212.964118,-340.548353,-339.006103,-213.569109,-153.202656,-118.876848,-128.756133,-182.180035,-265.21198,-304.275738,-358.34889,-352.919175,-254.154103,-182.18724,-116.15667,-160.41941,-182.305431,-246.55831,-270.948294,-225.533808,-173.246116,-76.482945,-63.672751,-146.88555,-206.865399,-185.809461,-101.526264,-57.266722,32.556266,80.607991,94.176802,-71.760805,-152.808515,-186.780473,-142.242669,-38.766015,-30.935518,-97.752251,-142.203407,-214.122422,-271.16457,-293.29509,-236.667355,-150.159951,26.29298,83.103366,109.010013,32.85038,-20.981517,-87.689871,-56.650938,94.809328,135.857106,107.811402,94.902804,92.465018,3.465993,-56.038152,-21.272049,81.053501,241.852461,252.95643,222.102657,220.287394,225.631873,230.806232,239.221046,297.657383,331.546228,338.069296,303.947712:backward
26.440887,218.896041,266.642499,265.6941,240.689062,132.708204,91.261829,142.247307,251.607983,276.002884,298.399114,313.579661,266.758253,178.563522,8.559777,-20.133389,-4.433323,61.241912,98.19656,83.686147,18.539117,-104.289044,-110.808638,-77.159837,-125.622283,-171.092366,-231.95766,-242.899019,-235.05904,-226.221517,-204.586124,-182.221166,-143.846976,-100.482889,-53.121889,42.110398,55.852961,68.02786,129.247524,316.045847,354.669037,339.76048,317.279619,268.543643,46.182597,-60.76701,-103.193729,-59.486875,29.969457,53.381517,37.379517,12.485551,19.587016,18.031696,-5.949135,-47.01181,45.886874,129.322152,168.376107,115.618762,-17.438452,-88.863423,-163.686269,-155.245389,-195.051969,-272.67784,-270.448335,-213.113203,-166.233561,-56.514946,-9.755693,22.964641,-73.684339,-134.02506,-158.557326,-127.606043,-103.473384,-143.760214,-239.162146,-221.218734,-30.160285,197.68677,273.937389,309.433552,274.682373,150.860869,100.855299,59.03846,13.663114,0.680845,-39.860075,-76.975725,-78.530882,-52.201203,-40.677352,-38.147115,19.358726,146.306501,203.122242,278.84583,319.269976,337.676244,293.033711,211.571841,247.720583,290.43408,302.409714,234.014819,17.863834,-45.145529,9.874593,37.954172,-39.860577,-10.28257,65.43141,120.294819,61.353864,-83.131423,-95.602036,-28.765871,64.632104,125.956923,199.608867,198.577554,182.775427,159.899998,76.667179,46.761091,75.900153,189.9249,231.248395,241.336235,224.673995,192.081819,168.352526,67.615077,-46.242717,-74.647653,-87.764961,-100.095311,-137.948637,-160.973052,-228.364258,-251.998969,-209.256704,-52.415204,2.207601,-15.697902,-53.889223,-138.637284,-164.037219,-103.556712,84.159811,184.770151,292.279576,291.446015,233.849594,192.552227,135.097271,122.156627,94.592221,79.289577,58.477023,-18.059772,-35.772066,0.957709,23.254054,24.984221,56.597092,109.292212,203.610277,215.739879,142.805337,75.82514,68.682976,135.074853,174.670313,32.028991,-43.148908,-127.988576,-132.636171,-106.070288,-79.697728,24.793277,171.148925,230.736585,241.919863,200.023549,70.24721,-13.189894,-139.702034,-157.48444,-170.071663,-236.598302,-262.284516,-179.793141,-92.695412,-29.486672,-52.789782,-43.539019,81.432788,131.936255,150.70392,173.566908,305.871904,334.735997,200.795583,107.721134,74.587968,186.355785,209.097362,159.290534,130.080356,147.423296,185.952955,235.298583,235.210861,230.594492,210.569335,203.957883,163.670367,103.320398,6.189335,16.79802,106.269184,179.280214,189.661093,180.055138,153.491873,25.011863,-28.76171,-55.125507,-101.535628,-105.445544,-7.953201,45.779398,28.043297,-31.367061,-112.869126,-122.898086,-80.465225,84.481399,145.732822,161.218455,156.720853,154.543936,152.671333,190.572061,263.453374,276.039654,236.930355,204.620011,192.259103,207.251797,181.663429,133.355359,82.632266,137.151818,139.206222,89.440514,73.459408,49.332791,63.567346,192.346772,252.219381,208.905015,83.026869,50.591163,26.028344,2.489666,-6.81117,25.945725,98.120609,145.717128,138.155021,65.92777,54.357976,113.099137,139.005979,119.027477,76.824412,83.620949,81.418753,32.65487,-111.713615,-171.009706,-190.472547,-148.195346,-94.062511,-159.125407,-187.995847,-175.879409,-155.63911,-121.282736,-97.485823,-32.710871,-3.320253,-17.574705,-80.506162,-126.420701,-266.714373,-327.110009,-311.238155,-266.108612,-245.324245,-223.289376,-156.24587,-43.616282,-75.425528,-203.547104,-185.704599,-7.895608,44.668352,9.763278,-70.182131,-95.667383,-127.165708,-158.706647,-240.367439,-255.183562,-217.160785,-64.734579,38.185245,182.904599,226.224567,331.770829,398.72028,488.927672,452.592076,389.278669,203.704952,133.565374,130.682482,151.677095,114.023327,79.917503,80.629298,83.82443,25.225318,-149.026608,-196.648321,-208.487042,-206.519887,-185.577669,-80.307732,-8.403221,42.146288,0.307414,-128.92423,-179.053519,-206.399167,-191.478607,-157.4838,-131.657022,-138.966504,-215.6863,-253.843006,-273.508779,-250.521663,-164.515465,-137.282469,-138.411935,-133.507483,-148.747271,-202.434067,-205.290151,-138.00779,-101.314674,-66.966135,-36.698147,-48.97375,-147.832657,-195.154092,-237.91292,-251.683801,-292.860092,-276.855777,-229.06425,-123.843481,-109.750518,-203.984375,-283.029851,-376.779542,-373.393805,-273.227193,-144.27802,-127.435963,-174.203874,-209.312599,-302.633246,-347.722525,-366.420968,-306.186455,-282.531778,-285.916592,-303.610495,-347.486718,-363.96232,-338.486353,-291.699852:5.416986,162.296463,168.289266,54.405718,2.139219,18.164242,76.299114,216.220569,305.895233,317.662993,262.031359,195.405258,35.390167,-22.477686,-34.021328,10.097757,128.606261,175.450665,164.883573,94.990263,34.92955,-52.8766,-36.066746,23.599891,-60.342076,-105.22208,-91.52251,-76.363354,-126.388117,-159.018573,-129.028485,-71.494672,57.098147,148.854522,179.930599,207.781271,191.871344,174.516946,236.048714,433.213744,444.739093,364.942747,152.682866,71.355516,-15.899032,-42.863385,-41.971098,-5.775247,88.466104,66.188037,10.982617,-14.488592,14.945423,-20.408579,-83.263193,-113.911434,64.596059,165.693849,194.266634,146.327532,69.579236,36.864352,-2.95556,2.842626,4.140523,-24.20409,-29.972896,-29.372275,-36.8483,-76.686604,-70.653101,34.200755,66.898825,24.219994,-72.233002,-93.206042,-138.74905,-182.634413,-206.819701,-152.016769,28.745782,190.858564,253.90155,330.897219,314.878074,164.785655,93.185358,32.242177,2.922942,1.956772,-14.449249,-25.925365,27.0451,66.036487,106.084348,117.779903,143.607547,251.114094,309.764117,312.288343,272.441003,183.868932,142.270914,95.026798,126.027736,142.930919,81.568418,16.295741,-57.22755,-55.250528,-29.486299,-26.600595,-41.551125,-2.647309,43.342327,119.165626,111.228604,25.519106,5.245994,58.198796,156.361974,213.554791,310.443843,323.895999,269.456606,214.930611,125.976317,125.344093,214.629434,265.523601,254.915868,261.29615,257.183738,137.094514,65.437182,38.136391,25.290945,-9.072764,-30.889337,-29.689951,-102.010347,-163.628238,-231.679306,-227.231404,-161.157495,-54.157944,-40.633659,-118.037274,-169.837172,-231.203162,-209.114743,-36.853047,163.674193,230.360933,237.853229,197.389479,157.645946,154.978438,93.471841,35.351537,-36.946784,-26.20535,-25.497883,-23.520484,-11.914248,-19.336913,-39.572967,-36.043503,92.664923,157.505077,162.951645,127.637864,32.377019,-33.144759,-99.06299,-64.902702,16.050062,-47.399784,-85.566279,-73.528322,-64.601099,-128.187165,-166.83802,-125.081998,89.283869,178.959629,150.622482,68.222924,-37.070029,-55.28451,-97.438954,-113.91085,-132.682699,-168.54821,-188.490964,-170.630663,-134.01871,-130.448908,-153.541584,-79.956687,76.580815,97.069034,37.867103,34.494327,144.888169,197.352942,208.150439,175.567309,77.10859,59.933728,86.741842,127.888706,139.045017,175.531253,191.707434,212.260417,306.966523,352.597267,291.55053,203.525072,48.581849,13.230298,74.3011,142.910886,211.56827,183.841863,177.71455,248.004247,278.322351,159.491689,62.147931,2.933086,45.513578,66.983126,128.710006,154.383088,101.449146,19.459709,-78.319713,-39.77579,75.119639,102.429327,124.510293,205.211741,208.76331,137.655441,131.289501,183.493979,223.573196,244.42737,223.684133,182.650653,149.554958,152.448159,118.879883,78.913685,22.040104,57.836699,54.692637,-4.027257,-0.29312,100.523419,171.721157,308.293004,378.951689,368.569906,225.07011,116.751711,-35.729431,-48.92004,5.57982,29.512365,62.971614,128.099053,113.302869,-1.331003,-10.801376,61.097556,46.633681,-103.438979,-89.147394,0.512634,66.736326,-11.57386,-222.830253,-275.056495,-247.073803,-209.633777,-191.998028,-228.732764,-224.954776,-177.272904,-166.750948,-147.476114,-112.871776,-62.962133,-77.049003,-71.559092,-70.601038,-113.827254,-257.294104,-298.857424,-238.547876,-187.279405,-154.121753,-75.888041,-14.676314,-7.522554,-89.979452,-236.458966,-198.034607,6.392046,72.305602,58.541105,21.609628,-4.465128,-82.963541,-110.452763,-73.057998,-34.435177,-4.55922,33.531305,62.806049,104.810367,133.757711,227.617652,276.826813,304.625316,221.250184,157.672633,51.801137,47.725415,75.688961,49.648157,-25.283258,-21.128097,40.807239,70.112301,35.107245,-135.433838,-235.326928,-379.459863,-375.398694,-210.420002,-91.775574,-79.549326,-46.040573,-48.981894,-168.564367,-238.078121,-264.808884,-230.796794,-151.672324,-105.022725,-96.63732,-100.823231,-119.847514,-225.420006,-273.187563,-245.687603,-142.88942,-96.911921,-85.625448,-134.876927,-215.276719,-198.168495,-114.690286,-84.901837,-9.005365,72.037424,60.3363,-42.740875,-101.353975,-190.138569,-206.034314,-226.153309,-242.17929,-206.518966,-107.443526,-109.657196,-268.910663,-357.625994,-369.102357,-331.983334,-282.402438,-158.291052,-103.633141,-146.957076,-207.872581,-274.826024,-294.188475,-315.030258,-226.489966,-192.733766,-281.075368,-358.102534,-393.949273,-352.50921,-251.217184,-210.253669:-21.513303,79.362038,104.082797,81.837779,54.944191,25.43771,34.795335,99.000711,205.52744,225.887038,139.355242,72.77551,-38.088364,-71.778887,-47.624864,7.885159,151.281359,269.914672,281.936552,192.004083,111.548507,-1.731614,3.516621,44.513366,22.066036,11.104427,-24.794675,-58.652643,-96.862103,-81.561364,11.169586,64.858503,122.966874,135.868572,167.663103,274.085152,273.467416,197.4516,248.559645,475.944769,452.080443,361.150005,208.250017,166.985656,113.013201,80.377814,23.893216,12.633983,39.827512,72.577384,52.492753,-23.873507,-61.500793,-154.950105,-196.481567,-163.110216,33.606706,117.285818,127.366373,95.000994,53.904731,22.023837,-60.52409,-65.241328,7.464001,3.739342,-54.366805,-190.739921,-229.889206,-220.810913,-185.682674,-106.637368,-78.180899,-89.136496,-149.178549,-176.255525,-177.444053,-158.745771,-116.508297,-100.980643,-49.45914,47.192616,89.567585,153.031829,159.682636,89.701456,49.469202,6.083861,-10.097638,-6.388415,4.548543,24.667159,105.244606,122.986292,97.028411,103.163021,187.385417,261.801533,255.887316,175.508355,134.893472,72.335356,31.362414,-74.246949,-94.724926,-48.293619,36.796782,4.807052,-162.441068,-209.35329,-193.796431,-189.675509,-176.627266,-65.588211,-25.681679,-73.12048,-147.739795,-235.706728,-202.303972,-47.389979,121.428789,193.375005,269.237301,268.576024,190.150043,134.060421,88.56613,92.193755,114.591388,153.568174,145.40344,103.259564,92.160235,69.570273,46.646972,-18.07745,-66.0505,-71.629442,-53.623047,-59.796781,-155.01561,-203.027252,-186.991067,-168.928888,-199.153474,-161.889359,-131.143656,-165.814245,-212.678843,-247.602155,-214.427122,-111.474928,-23.266296,20.351109,38.510912,-0.479154,-100.405378,-129.327018,-113.2428,-72.711447,14.464223,-24.236845,-70.379121,-88.928434,-83.72737,-114.197461,-125.127087,-96.297695,22.582684,96.333945,114.275067,63.57145,-20.172214,-38.610589,-67.950427,-78.332755,-77.818281,-96.993195,-94.441341,-68.166187,-94.166153,-160.249875,-129.43567,24.08531,144.355792,166.698043,103.759722,31.475106,-92.202397,-117.768828,-105.99179,-82.648807,-57.192012,-100.2101,-125.999983,-160.08609,-177.05637,-200.234545,-189.459157,-103.336592,42.493354,69.624569,-19.575918,-60.706194,-33.477674,8.734776,69.064375,60.887848,15.861716,83.085959,124.602848,120.035657,108.440792,117.009003,103.290555,88.927129,225.867308,277.824292,217.979568,157.124952,67.833897,26.603328,5.969751,54.679905,195.697715,257.435373,252.003858,213.688088,180.225553,92.848295,64.424255,71.343905,65.263654,40.755458,79.723697,130.786613,88.48718,-0.608692,-94.466803,-54.949185,68.460142,107.820295,132.998983,216.193649,219.635393,131.133994,107.5703,188.892285,281.723408,268.444027,144.980288,87.720136,60.70482,84.370822,172.953563,200.556096,166.848311,121.910729,92.951101,11.770387,19.757147,190.727585,274.198113,319.445512,337.559688,333.827336,205.626655,110.9342,-12.106543,-11.919383,79.9667,98.674211,29.308509,-4.390788,2.553243,-49.354875,-106.732574,-151.034905,-124.75273,-55.661708,-49.22134,-75.183255,-141.245172,-158.811866,-171.483476,-166.700715,-62.263471,-7.347628,-101.401964,-243.1715,-215.325455,-107.068473,-92.667276,-75.847214,-54.667371,-66.435025,-93.596716,-68.857258,-21.359556,-52.974585,-197.645573,-232.107254,-111.05998,-12.711071,54.773162,41.620352,77.953111,74.35816,-42.697229,-239.677436,-170.582574,109.607939,93.068597,10.668669,-17.047536,32.237495,58.862259,26.712149,13.158016,50.668516,164.466101,268.816132,276.620015,195.226717,141.713031,123.812524,186.082922,364.527446,393.872501,319.111491,95.526623,31.511911,54.153451,65.109457,6.860694,6.722343,135.097497,195.229383,142.633423,-32.630619,-119.862355,-232.564357,-215.078523,-72.2005,-11.056017,-12.692177,-1.968952,-1.35889,-64.9271,-116.397302,-152.77814,-116.590317,11.004722,34.945529,-4.45503,-28.686641,-8.858359,-31.418349,-77.35799,-122.35186,-15.78678,51.620863,59.091286,5.559429,-55.733447,-34.099919,25.176859,29.025221,36.530461,93.395257,102.628579,47.461414,-6.561501,-117.202111,-162.928392,-219.11606,-119.238256,-36.118522,-15.850892,-86.665742,-216.920389,-235.450261,-219.070595,-219.680007,-231.162384,-167.759754,-150.803638,-202.612419,-232.044729,-227.763938,-214.747135,-193.165433,-88.14191,-52.000653,-178.643696,-282.030292,-328.552856,-266.786713,-115.60189,-71.78334:-89.168139,-33.859335,9.851511,44.226175,16.869572,-76.229008,-92.508915,19.406819,217.818862,277.87183,307.082431,292.890735,164.410316,59.653004,-36.11336,6.487227,146.941671,196.406567,168.798382,106.910477,79.956684,-3.226547,-20.592735,13.032244,8.069942,-6.618033,-60.132868,-109.302846,-191.684156,-205.271246,-181.941855,-146.332114,-43.807896,74.366104,127.540887,171.410898,150.769663,151.281292,243.481374,496.672958,522.047513,473.910044,374.035403,306.995403,114.076526,20.821398,-65.355834,-68.391477,-38.117458,61.135584,100.094446,92.432252,55.289752,-38.865663,-65.56157,-37.063547,77.89592,135.444395,122.053788,49.936148,-124.370047,-200.791099,-257.241495,-235.980128,-216.154572,-282.618751,-297.276487,-245.759522,-233.403453,-260.143763,-220.008994,4.00331,60.094186,-21.434387,-143.615794,-132.233711,-107.779633,-139.305843,-214.487771,-206.798451,-79.477285,85.770454,150.088836,191.464537,149.488569,11.481009,-24.024773,-8.012168,-6.069011,-27.279712,-118.152495,-170.335163,-189.255322,-171.037723,-177.388892,-192.823695,-150.77969,24.398984,107.423835,209.094935,233.152272,199.309476,176.898733,235.731693,309.963416,304.934483,231.876614,183.372885,79.713324,4.091025,-152.572762,-193.801555,-227.592261,-215.932139,-170.22454,-54.62408,-53.07673,-183.328804,-221.577744,-121.293264,11.827837,53.752897,110.6513,113.604458,36.713982,-34.429708,-119.524769,-105.194422,18.771439,208.035719,254.854702,191.42671,120.677561,19.148532,13.66489,42.409483,2.442049,-23.672337,-40.642982,-52.234579,-123.835418,-179.696739,-255.203794,-259.983737,-247.787348,-198.659023,-164.522135,-144.999133,-183.725222,-314.000857,-320.98682,-146.657862,45.966209,108.642024,149.013589,120.680428,64.972929,74.675482,114.787841,109.518853,78.504555,91.551789,82.739107,34.256082,28.562161,21.584994,9.390153,8.666997,51.972188,95.06812,178.368906,189.87454,106.71885,24.990932,-51.968549,-12.901454,62.348269,22.979711,13.384828,33.431119,13.399687,-79.324615,-92.46276,-27.038454,95.215449,155.825194,173.637001,139.648329,80.0852,35.28973,-108.191596,-157.256017,-133.688594,-37.723883,-23.507792,-69.76484,-97.044459,-142.111808,-155.875534,-120.625466,8.096999,57.603058,45.337994,28.409395,78.931097,116.065649,118.695395,93.51397,73.12937,151.934609,174.414222,117.148297,96.645098,156.260124,198.483976,206.391621,182.862008,186.695158,147.702266,103.80122,24.942031,-0.531808,38.209822,89.624524,148.406308,163.170527,160.425273,137.110039,117.572002,45.439482,11.175057,-16.064186,-20.694466,6.740484,126.157924,165.77961,96.391428,6.692667,-128.909717,-134.315991,-65.800136,26.10772,83.997856,155.730425,127.448441,1.810778,-32.173912,14.529179,138.443085,183.733417,162.655769,116.769739,109.076091,150.770969,168.504081,111.121383,33.145256,146.981917,170.852178,66.38968,27.832787,118.481152,203.093107,311.351748,355.600819,362.061356,274.875318,186.555046,33.932982,7.864567,77.61627,128.601624,117.285056,25.274573,3.27057,-15.177826,-20.06619,-34.175982,-54.692109,-77.96631,10.03943,58.086501,13.722497,-55.481403,-165.948914,-198.906674,-176.639217,-129.55843,-117.414461,-210.135876,-201.451586,-85.506547,-69.004033,-129.671359,-134.490836,-80.521157,-62.325257,-56.312568,-99.866873,-197.370624,-421.428146,-444.136745,-280.716749,-186.091236,-128.093398,-121.023077,-107.221302,-135.713331,-187.933838,-241.308267,-179.086251,22.412643,65.220544,35.796126,-1.962715,3.957329,-14.056324,-56.328282,-112.264678,-93.792827,31.495657,191.635383,215.118904,161.214086,161.267292,264.097744,328.830741,434.413756,446.736728,396.970691,240.164087,175.847505,80.925845,25.917232,-5.778632,53.121061,200.06007,218.316836,169.888233,46.087969,-13.267111,-144.751132,-177.543705,-136.611181,-76.476239,-32.558725,73.125346,85.231844,-4.860321,-65.788501,-93.880981,-45.173529,59.121615,25.063871,-28.159513,-76.427573,-59.758973,-50.617762,-66.173132,-65.743965,11.037948,77.996781,138.561181,95.399788,-13.203225,-32.721033,-17.510312,8.536396,83.667869,119.411982,89.591562,-9.848377,-42.94037,-101.893153,-140.368801,-194.092186,-158.335622,-113.501507,-57.669999,-66.596837,-170.380231,-250.453829,-328.844336,-309.15186,-255.348839,-186.865385,-149.62866,-147.848173,-173.69711,-206.157484,-204.748449,-181.930028,-130.071091,-121.317346,-189.249112,-217.314139,-167.200404,-121.724775,-65.576207,-49.894937:-26.522647,-70.029809,-112.074134,-156.536123,-161.786923,-162.61418,-141.558507,-19.728404,164.767925,225.454971,263.608729,257.379651,135.366779,32.308487,-73.621355,-40.557458,146.249736,309.692539,301.566496,138.010414,53.510777,14.62633,51.067615,101.480468,96.191956,97.204325,34.44497,-41.920013,-210.501277,-246.954422,-151.787989,-75.638065,29.246414,93.484122,115.553945,169.165703,171.887389,108.40385,127.648617,363.119345,547.303446,555.043411,462.547392,376.20376,179.492947,119.633978,128.391806,152.346897,169.738983,146.212316,104.982817,18.382673,-13.076529,-41.667178,-5.732915,127.810773,201.799594,199.807468,48.618692,-73.853983,-214.252032,-211.430176,-160.106111,-132.316868,-61.799631,-85.389602,-170.179356,-362.556498,-408.222679,-377.319753,-313.546723,-134.001853,-33.186348,-45.12564,-114.800691,-134.743918,-146.548477,-145.153316,-127.0297,-110.457867,-39.364887,38.312239,48.264898,46.295299,38.583553,-4.730479,-18.312168,-39.056235,-122.242534,-157.823991,-182.717406,-184.089728,-155.794478,-129.74321,-108.554098,-105.84913,-16.821976,134.723596,158.960914,102.072526,60.426441,-2.859876,0.254916,117.381083,217.002425,213.109596,127.728748,64.626226,-84.791481,-168.914919,-272.439834,-276.707182,-276.510176,-251.382551,-219.352286,-234.109077,-287.746712,-351.676049,-322.558801,-156.507708,-16.311155,-9.583891,-48.763686,-46.685104,-78.286544,-137.825941,-195.550678,-160.02998,-24.672273,58.448371,45.802035,5.349089,4.722152,13.490233,19.171777,29.293467,60.645826,73.458987,27.179677,-15.308168,-84.492379,-96.393478,-64.18737,-59.567123,-107.254429,-122.908399,-129.403488,-184.358542,-224.591286,-265.422559,-226.626949,-70.583253,-0.090159,-9.374717,-44.124499,-56.360391,-86.493973,-97.377183,-89.873961,-72.874519,-8.640404,1.59808,-37.410405,-101.869782,-104.865796,-96.764968,-78.716757,5.273059,84.226113,105.663103,87.029966,61.16826,20.827468,-3.684439,-29.730811,-12.012969,40.486636,29.37757,-3.96249,-72.210945,-107.229797,-132.430512,-90.08251,37.173273,132.829329,153.92222,79.999133,14.402921,-39.028316,-47.454698,-123.093101,-163.197919,-163.499738,-105.493156,-97.035599,-127.468822,-132.605145,-86.15759,-46.779842,14.840744,18.573146,-11.424343,-110.56448,-133.8611,-107.996106,-83.442296,-14.292171,16.411959,83.618312,187.770337,199.480738,132.654582,109.401169,136.719288,156.430551,155.351019,179.44799,206.676227,184.287274,109.650356,-78.965501,-122.389306,-49.682188,14.976422,120.636022,205.646114,196.517941,66.011939,-0.641829,-31.386544,-0.818933,43.70153,10.644556,-0.055127,40.27464,77.640333,83.519652,40.153066,-18.581793,7.427865,94.036538,96.234671,99.555002,187.094634,197.846065,39.375618,-32.033687,29.325741,178.701692,221.267575,189.727544,109.522098,-34.046512,-24.533688,118.332705,160.075692,114.891112,71.839901,56.40589,-15.002341,-34.821408,75.445366,181.364976,339.77058,385.391025,366.358987,234.562528,155.187568,53.904589,43.163604,95.538051,124.003617,108.68172,36.722347,9.946995,-44.464006,-79.157845,-90.789803,-59.544892,32.810763,112.939751,124.635458,65.251865,2.857059,-105.346377,-109.80794,15.175621,89.661491,109.414229,16.435465,-12.988729,-11.630887,-15.078998,-36.908948,-19.313516,57.838804,73.413262,44.14843,-71.246441,-142.360929,-265.595698,-292.942497,-233.527983,-153.997918,7.816694,98.180521,98.969331,-58.010991,-180.613076,-248.557495,-142.843095,135.262061,223.087216,204.156113,104.434853,43.275854,-37.253669,-39.859275,29.218382,89.160134,235.948568,332.009017,322.653549,255.416902,237.166458,289.157387,362.585417,512.90727,548.912254,511.051215,323.10245,206.272068,14.950919,-41.871387,-9.292036,80.538245,276.181994,283.826196,212.10578,48.701973,-41.366058,-195.773562,-182.946166,-17.129668,64.069232,68.428928,60.397481,36.093484,-43.302382,-61.938749,-7.192254,55.751879,165.071383,117.937056,44.978245,-71.63532,-92.578294,-55.294277,4.182641,130.26162,200.475577,231.973352,257.926927,227.179734,105.451482,57.404953,79.146832,138.942011,267.296509,284.113063,232.927968,74.188913,-18.854245,-161.809095,-173.037571,-101.860812,-2.35787,23.462959,-73.618263,-165.422183,-267.30478,-265.882236,-215.541208,-194.720171,-190.461856,-191.333984,-196.960828,-248.826948,-278.882245,-301.806221,-282.945724,-168.202833,-54.744666,-59.300385,-142.82809,-154.926799,-147.118158,-155.846492,-95.479304,-20.421616:-71.735251,29.136333,49.659727,64.827891,66.637233,12.860767,-21.989152,16.207668,149.732506,205.915391,279.216614,310.139771,330.151034,272.432235,86.12282,37.411439,36.802644,60.301804,83.097279,118.614266,99.166366,20.083785,1.924112,-22.727337,-88.420025,-109.360346,-111.728065,-112.376085,-166.875531,-221.309301,-274.348248,-247.377643,-178.481723,-94.945548,-29.32144,52.371309,50.660995,76.695379,161.074537,389.918541,439.302121,409.657148,312.819914,241.683073,78.73489,-5.009754,-126.979495,-137.006908,-39.397784,121.093101,156.219771,129.533289,105.814233,65.210644,50.741204,88.756415,236.072144,271.535704,89.352491,-52.958073,-182.18949,-201.969596,-283.308714,-324.851369,-361.225086,-360.154068,-359.560046,-344.278465,-321.352294,-268.768566,-231.214569,-134.679088,-122.038932,-142.486304,-168.800391,-180.46414,-200.891507,-209.147278,-248.689619,-240.393774,-70.783736,120.814255,165.206155,189.240607,163.077023,17.309102,-35.509243,37.971667,126.248609,82.275161,-167.196205,-285.807262,-295.566782,-227.037968,-173.783692,-201.404998,-225.728368,-92.135897,-9.685951,122.033764,180.597323,227.042665,217.427875,248.388424,330.905396,324.912851,207.27879,162.096604,123.077594,75.202903,-50.247203,-77.129554,-56.263791,-53.663776,-68.817154,-48.689434,-28.801097,-96.123495,-158.32167,-161.40602,-33.486178,7.845083,12.471119,0.806657,-59.77187,-122.346892,-211.09989,-193.339694,-30.838799,154.157382,173.529114,71.745135,16.437557,1.106195,17.135093,0.402682,-52.094272,-68.092125,-102.868882,-115.922479,-109.285694,-115.639951,-167.049135,-182.15466,-199.1406,-237.309775,-217.446276,-90.68464,-45.413389,-59.862731,-77.801295,-31.00819,65.489245,92.529492,108.725651,113.191739,124.845297,126.36882,107.453881,84.517332,40.06492,83.348883,105.01001,44.158827,5.613291,2.587842,13.924322,36.754561,93.107645,134.456587,208.58485,238.983707,254.305686,227.304595,215.538373,257.526515,271.327289,57.837917,-46.090224,-72.825013,-22.556709,38.504565,26.442441,2.73172,118.092998,216.367557,285.703066,226.143754,65.844743,-0.923453,-111.724022,-136.631028,-78.588592,28.315211,36.822323,5.522987,-6.727146,-80.202131,-129.560291,-123.527805,45.44462,110.099192,42.324458,-23.786136,31.956841,133.713885,210.05933,150.999532,73.764751,154.889067,145.015099,10.987542,-12.190511,100.992747,168.022633,172.928808,116.516378,136.088217,191.966051,172.782597,53.225485,-15.056925,-61.048468,-28.913072,29.273318,37.404084,34.258371,28.418189,15.553029,-81.035675,-136.371603,-177.106207,-182.959589,-161.51783,-32.785253,32.225574,8.10921,-74.238177,-176.956871,-174.573738,-160.827408,-72.575152,-2.495814,99.354103,109.385671,15.582833,-40.600104,-8.581852,131.758275,160.237107,111.135194,85.048246,89.711318,96.060051,75.317707,54.026748,48.67818,88.948448,74.825448,-0.131897,-9.910388,73.015362,152.235712,284.799867,293.950886,274.710287,217.58016,177.060988,105.30225,91.777852,158.379112,219.272824,264.794908,191.955341,129.23051,19.288995,15.455878,144.627701,239.663755,290.81642,138.331639,100.513298,112.562609,88.046836,-55.056737,-134.637757,-181.590823,-140.175241,-55.00784,-51.866636,-66.705387,-100.861553,-118.677774,-121.355341,-89.532718,3.850117,4.18914,-37.658332,-155.435482,-247.242416,-433.656965,-444.265964,-303.923281,-261.014162,-340.910823,-375.915536,-292.368162,-62.415786,-45.4042,-203.738034,-209.583961,9.687302,86.689011,59.853287,13.727088,-13.223433,-111.0281,-176.831359,-256.888039,-237.43648,-85.369673,119.917307,183.205394,213.076947,233.406691,351.245702,427.678896,531.753025,463.182785,376.666489,270.158666,295.578013,371.422202,339.585393,191.652787,141.840762,114.75069,159.939734,179.365281,127.050285,69.819403,-18.638657,-30.106,-13.60969,24.677484,60.460635,101.25638,81.634238,13.366308,-12.825937,-43.845722,-46.227454,-49.788107,-84.226803,-115.980881,-168.181339,-165.24315,-147.404129,-138.872045,-69.999331,5.34525,19.190839,-15.574726,-56.794465,-124.128964,-132.177042,-88.738184,-43.428595,36.461291,52.887325,36.146959,-54.039016,-112.92311,-218.588649,-247.190656,-210.957905,-106.63274,-69.938381,-52.336916,-66.693932,-150.458933,-195.652828,-168.431616,-124.539965,-105.546931,-83.028806,-77.926603,-129.572417,-144.304052,-159.847712,-194.87128,-243.685535,-160.738608,-118.813218,-135.727214,-155.672425,-162.049029,-177.375567,-231.178319,-231.853333:-95.241639,-158.359446,-145.345034,-74.426964,-86.839076,-216.715083,-237.95321,-42.121531,201.89029,239.684037,209.138792,180.83673,77.015296,6.587961,-44.984042,-15.01448,76.393753,155.612411,169.948717,110.351521,34.063099,-99.471976,-92.224768,-3.283814,-3.319223,-17.266148,-64.219069,-117.523614,-248.397309,-299.543399,-322.729348,-277.211591,-108.831715,55.702363,110.168151,111.125967,66.823467,74.914424,188.198602,505.814421,627.853019,601.40339,498.96395,431.980213,218.790193,101.849324,7.036651,35.626915,152.522862,235.757414,230.303117,132.609618,55.837813,-52.779797,-28.82564,146.658161,275.946829,252.459341,23.494857,-106.719113,-279.191252,-328.141531,-336.797672,-292.329513,-176.151042,-199.55227,-288.275923,-415.689002,-392.802195,-281.547551,-235.790842,-152.409776,-109.734902,-117.937004,-149.605487,-151.184411,-127.011217,-116.395692,-125.266792,-127.546856,-15.01206,175.813107,195.746874,72.687962,-11.723162,-112.063876,-105.667122,-40.367994,-26.7211,-43.791792,-149.861039,-227.703363,-316.192302,-308.348784,-270.746177,-270.199881,-213.861663,-9.823677,43.973732,3.970828,5.054554,105.520853,163.444137,265.277613,322.722107,309.856867,239.474055,208.664776,120.34229,56.759803,-42.239956,-82.934126,-159.634179,-122.49747,-73.055825,-60.336458,-120.373746,-245.31472,-251.043361,-157.389931,-65.507164,-49.53823,-44.594505,-40.900929,-85.025651,-139.333366,-189.256013,-168.790407,-67.890932,70.104335,103.480905,59.671093,11.631357,-22.501943,8.785358,80.126557,84.926781,75.039691,51.633451,39.003096,-1.111127,-34.938576,-125.022691,-176.338237,-236.190168,-180.456084,-136.707563,-78.459423,-85.369666,-162.001541,-165.52118,-37.992836,60.668472,72.329259,109.447133,131.91008,135.203678,119.730814,58.077627,20.915229,18.036294,69.5271,51.528131,-24.230888,-23.697559,12.686452,9.760647,29.171103,161.895214,231.529547,235.155467,190.82359,143.475097,132.887171,131.380357,152.350827,169.607025,95.043276,52.842721,25.298199,12.819785,-42.061484,-34.86062,55.814362,127.759177,147.458759,127.425891,93.928162,4.864295,-55.460374,-138.654733,-123.052535,14.330857,100.348082,55.61571,-98.167134,-136.441921,-131.835469,-107.814109,-17.23559,79.954829,79.40952,-27.88626,-61.58894,19.441063,80.423425,122.431918,122.966399,142.086396,132.513116,84.977435,-12.646163,3.698912,159.347265,229.053003,208.302417,106.568537,113.282481,148.21794,116.971877,-16.867615,-61.026188,8.589311,91.348579,181.210364,157.280633,119.246845,15.066259,-12.69072,-5.998258,0.079664,-8.311264,-2.451316,36.865844,120.814961,120.15712,27.96742,-33.41731,-65.037611,-21.115142,71.108642,76.755113,63.97215,40.068678,12.274112,-100.952413,-149.539353,-112.148252,68.854029,143.544727,161.344889,124.809294,54.778919,29.527918,0.898405,-6.291094,8.545521,80.485681,85.994717,-17.325192,-76.206545,-30.068945,81.286369,289.543645,353.974264,362.091574,287.665542,194.019001,45.125602,35.354227,99.393031,130.406058,119.718854,58.525442,46.137383,47.565968,35.148187,-24.340321,-31.863384,74.376085,215.388526,229.223282,121.571557,36.234124,-111.150131,-151.008929,-96.290734,-10.350974,111.162345,59.905542,18.195154,-4.534568,-2.341258,-30.431478,-58.958541,-105.130653,-48.394033,-0.083695,-78.306797,-224.377081,-438.207922,-411.66842,-220.958963,-152.193859,-117.528741,-73.206309,-30.326635,-5.088346,-67.486907,-235.733524,-219.310315,16.946029,137.832928,129.902153,101.595406,75.183376,-65.153267,-146.737041,-163.675137,-96.056221,103.407698,326.185467,368.157359,258.424322,193.579723,228.829374,321.037587,519.554494,552.610395,485.002362,311.68086,258.697106,167.639827,103.192749,48.938687,92.504169,214.06254,246.528335,225.633751,126.840153,47.429233,-92.665196,-97.86526,-13.611648,43.149443,41.319432,19.240772,27.068514,24.00725,-16.107503,-83.603483,-80.736446,-12.731819,62.415897,42.462979,-73.746342,-100.517807,-88.971081,-77.223957,-0.280045,159.147473,234.608389,243.490862,173.00556,12.961064,-35.566321,-8.079881,59.740739,181.571012,176.192656,119.193578,-30.870759,-99.948504,-202.419851,-199.973149,-82.719567,-4.403173,-11.998869,-90.767533,-144.790217,-253.493688,-294.317528,-277.086164,-222.415203,-116.994998,-85.095542,-117.533334,-253.327773,-305.828618,-307.153647,-266.178845,-157.598767,-58.733466,-34.810972,-58.403465,-84.882687,-155.408068,-188.867199,-127.967381,-43.015809:-242.836384,-77.881827,-25.542848,26.228589,40.742294,14.307109,-36.26276,-129.998471,-88.561017,-23.132642,97.591529,141.988035,170.501662,131.763866,51.690527,58.625492,71.228152,10.959503,-1.822758,24.378324,17.713933,-93.573225,-150.413834,-163.130977,-133.442979,-122.733926,-92.008679,-83.304969,-96.310876,-112.551828,-105.673016,-79.187797,-52.875879,-19.986776,3.641718,-3.238113,-22.43428,-18.374299,36.480798,227.966835,362.740691,380.990575,297.4387,215.372544,51.305625,-21.387147,-104.842813,-98.594644,18.298227,173.208157,193.599625,172.863578,197.354556,284.132063,295.83617,241.309687,173.685397,147.97467,63.607053,11.55249,-81.493777,-145.65635,-282.10721,-311.844808,-332.517529,-364.992265,-355.907808,-284.777752,-254.54688,-193.239532,-127.581143,6.459381,-15.309754,-55.097156,-60.272643,-25.004346,18.782327,-0.224809,-68.788399,-66.660004,71.614709,257.628506,297.262637,273.343385,243.134471,141.275827,79.435042,42.269142,76.869817,65.460698,-14.565485,-57.198119,-104.086611,-111.844998,-107.125015,-91.708473,-55.727023,-37.89058,-23.802357,88.982112,171.404795,230.006126,209.022188,199.133721,260.558878,273.264145,175.14908,102.438198,60.481159,78.929303,99.131783,108.777791,134.385918,122.401935,125.47384,151.34528,142.738809,80.463166,72.731263,174.135728,273.394376,245.864858,73.336612,14.516281,48.967529,75.08243,34.428946,9.162131,13.58841,36.413288,31.441263,-25.017466,-55.71105,-33.027422,24.621596,132.290861,134.283328,104.094898,64.260683,78.015398,116.174243,108.014942,66.627059,54.995086,42.582987,102.895863,159.448765,229.465139,223.712739,156.517089,126.171543,88.356013,52.962896,51.697702,54.233972,57.38057,107.831912,125.352502,118.623358,114.447803,99.311766,107.147707,116.109665,70.198913,33.896221,55.803987,115.589378,200.453107,171.075253,154.179763,212.842537,292.789085,417.789363,411.12095,315.933825,289.499259,303.842521,255.397175,189.590869,90.592494,67.992894,-43.232156,-113.853028,-103.332193,108.479131,208.962881,270.450892,247.750575,172.109055,119.620001,-0.80221,-39.942592,-17.096149,76.080589,74.215155,-43.627574,-106.767211,-177.591182,-179.54608,-162.573773,-221.450034,-243.130118,-186.891217,-122.49412,7.21219,22.507885,-70.326285,-105.395642,-50.903238,35.350408,25.877722,-89.381808,-135.677642,-111.23462,-70.601083,-59.566343,-70.091125,-40.752505,-14.55571,-39.992467,-86.20442,-111.444965,-210.717892,-241.809576,-173.518103,-81.377972,-97.463906,-179.756375,-206.439279,-261.34348,-304.825113,-395.118261,-390.401616,-315.582025,-106.317297,-46.738587,-104.279268,-190.723521,-287.269551,-262.021984,-191.515319,-191.495568,-185.358123,-130.669092,-119.598189,-169.184921,-185.879816,-152.993929,-101.401425,-72.630744,-30.638438,-23.547489,-18.781675,-31.170761,-80.287595,-74.680841,21.750844,5.58059,-71.871453,-131.074483,-64.870044,99.795286,139.576023,163.823499,176.508074,170.681166,110.839189,76.166152,75.653689,96.069419,120.661948,137.683949,183.040344,204.42939,185.664782,92.917789,75.384022,135.876424,165.9419,158.293051,119.473081,114.56749,43.567424,-42.436065,-187.517318,-212.252275,-189.920979,-155.96287,-96.01291,-107.58207,-137.088295,-152.74743,-122.046761,-79.981478,-100.515149,-140.425655,-69.014704,-39.500838,-126.73481,-233.744053,-384.189095,-374.283151,-276.280573,-266.22863,-355.064519,-327.590693,-221.711544,-38.416622,-41.842339,-115.029786,-78.005425,102.503967,132.700217,97.640245,5.639323,-53.635344,-129.478937,-122.770434,-92.911873,-98.288575,-57.648126,156.65942,254.809437,297.75613,278.377002,256.776634,264.019482,328.873903,337.185398,288.873644,187.849242,177.347551,197.847112,170.213897,49.583741,21.820895,49.439087,103.683758,117.616377,26.390659,-40.315407,1.514759,107.963015,230.346015,120.555298,98.675005,210.412671,265.286572,258.561404,212.965222,94.317384,30.601648,-87.427822,-163.596285,-199.416233,-251.563901,-251.129351,-233.39243,-234.983036,-243.128217,-126.704883,-30.346341,33.63259,-2.888314,-66.988758,-90.043975,-122.232112,-108.524978,-40.758929,40.391134,60.954797,11.464044,-22.083024,-58.343568,-94.121358,-180.305384,-143.228568,-99.389171,-92.716512,-118.172428,-136.717655,-125.706271,-75.534654,-44.230494,-27.248364,-40.685099,-26.649242,-10.799868,-28.728179,-98.102234,-137.02034,-197.926894,-228.795551,-216.973954,-141.448926,-108.923914,-118.717199,-166.25066,-235.003629,-201.572782:87.385682,215.267464,249.729641,278.677671,260.694355,91.917934,-16.433026,-112.878785,-42.996001,28.86943,173.79542,222.915948,268.205645,253.734322,154.31129,98.703406,44.875079,105.412417,161.17161,194.218451,129.515675,-76.791158,-140.402139,-166.393739,-147.109919,-129.04782,-79.763302,-56.61526,-87.404224,-151.020082,-227.15601,-186.705203,-36.244671,48.05092,47.593942,31.890377,54.828406,156.581746,219.622597,335.822505,337.778553,300.554251,209.219046,154.888642,35.713341,-8.371547,-1.030283,35.800713,85.685865,107.139904,127.486029,139.611622,125.127842,120.224886,131.042886,139.494078,165.370372,188.835254,166.804808,114.205507,13.088056,-40.445784,-201.57557,-276.721745,-340.14198,-309.485852,-301.005422,-304.997235,-276.7934,-144.834047,-66.694409,2.176129,-61.362223,-90.948324,-88.478767,-61.273205,-35.232647,-60.887809,-124.193054,-126.456297,-48.753545,152.627488,245.713039,257.169192,192.576871,64.812937,34.182234,28.132984,19.984409,14.334389,-11.143751,-22.477544,-12.842865,-13.106983,-13.103724,11.645644,88.965983,178.66365,231.746353,346.883932,391.638363,360.312604,289.949615,214.851996,266.444039,269.357226,198.035198,165.661574,125.61522,88.5502,-3.120529,-36.972665,-69.145025,-10.623558,53.188797,155.759404,159.551202,70.892615,27.253998,48.761808,81.032404,61.022686,50.400152,94.825056,182.659584,173.872694,143.438263,168.766555,237.460193,205.785469,138.930403,31.38037,51.657855,186.00587,233.45535,229.908341,145.739913,110.812556,97.026003,102.724843,68.79174,26.638983,19.559927,60.671274,60.519219,56.149051,129.220222,292.163537,299.537178,143.157315,55.490259,14.783322,113.510718,190.695222,358.403246,409.279858,324.406256,202.120634,64.196066,97.3769,169.39269,116.272511,77.687567,37.550065,35.246936,23.033857,31.852994,113.939825,128.85673,82.333919,32.174888,84.375907,208.148206,200.733548,152.06226,171.403204,200.065448,53.51324,-45.553237,-116.314458,-97.518271,-88.17733,-92.893174,-5.937499,163.416432,218.1265,206.786654,163.405836,86.409218,42.734832,-94.242478,-157.006392,-212.616386,-230.059418,-237.591994,-213.213065,-183.372495,-154.0019,-142.258917,-86.786285,-82.290675,-86.225173,21.116438,121.48394,271.832613,271.34516,109.55752,21.71091,-5.893532,44.460421,13.818896,-104.668084,-127.926726,-98.032034,-74.089462,-46.174073,-62.281393,-55.000923,11.589495,40.46417,30.743137,-20.02202,-171.368905,-229.644458,-237.649301,-130.32986,-94.60471,-134.695231,-178.633451,-232.237452,-236.004779,-236.108013,-265.363584,-236.919083,-61.017852,6.074989,-35.830826,-98.02034,-154.75393,-147.776334,-107.865193,-45.605427,-29.47268,-15.813068,-2.592649,20.57882,41.710986,120.143093,149.488132,147.838751,149.968872,146.032705,151.654559,144.717547,39.110556,-29.743257,-68.739004,-36.153693,-46.460503,-56.742083,-28.951814,8.207943,7.423688,42.374896,94.475673,98.722924,85.147845,91.868125,143.143304,150.417195,95.502059,74.257697,96.766345,125.12564,103.539685,20.54871,19.701396,154.433212,232.322003,239.146964,109.407546,81.22784,84.531418,63.250799,-29.008227,-74.572608,-93.341542,-50.571407,10.196929,-140.926392,-240.563204,-247.958321,-155.354509,-1.357946,-9.891341,-124.137527,-140.417744,-103.409253,-34.393509,-38.943385,-196.021273,-310.347879,-383.896777,-350.29764,-325.181879,-243.194548,-136.702604,46.460133,53.578137,-57.922205,-80.168882,4.775329,41.06869,24.268853,-47.249685,-93.761452,-149.193718,-173.707102,-254.458551,-265.522925,-161.527511,32.861699,132.479998,266.723537,300.039235,369.901535,412.120664,442.365455,376.266261,328.922912,237.018985,226.736698,289.21309,294.315897,185.700203,127.398887,75.128851,47.463292,27.267786,-63.343371,-114.292366,-79.534615,-0.104085,86.843321,77.463652,97.907413,141.32813,135.574827,62.239203,-9.873378,-183.335383,-250.782722,-318.613726,-336.764324,-343.50634,-358.532974,-355.835827,-347.403931,-347.339478,-292.902192,-183.294796,-155.3619,-189.421195,-236.000561,-307.04303,-301.645442,-234.828276,-207.460396,-172.095546,-89.832864,-81.770925,-220.641036,-287.436366,-303.110361,-303.22469,-348.085884,-327.35336,-282.03241,-225.975155,-221.158407,-247.847196,-291.199028,-352.379497,-325.847674,-203.26578,-126.543467,-124.066616,-149.281777,-152.485846,-170.346517,-211.515355,-326.422405,-398.764607,-402.694751,-375.283456,-364.219281,-348.495957,-351.275847,-379.452488,-373.68258:-138.009871,-43.079985,-41.036617,-109.943512,-129.390379,-104.331714,-61.194398,36.240794,23.672974,26.434265,127.879718,164.917354,102.098612,30.366293,-19.169045,33.562703,144.42785,139.965077,124.925524,97.497254,55.840907,-74.849121,-110.338315,-113.26719,-160.281906,-174.063277,-109.266572,-80.141801,-132.441915,-181.277964,-205.291728,-176.917995,-82.979495,40.446755,94.840712,109.046851,77.608882,55.259023,98.564098,278.595735,443.064127,453.198265,314.122412,248.972662,235.063378,215.547365,70.261494,10.702018,57.247706,226.980004,269.564087,186.443931,105.291043,54.968845,113.261762,265.054104,278.651222,240.938051,105.061355,16.053823,-153.771736,-226.915995,-296.556725,-280.997212,-221.968406,-187.168355,-208.059932,-340.432125,-398.685835,-360.711383,-258.837783,-94.846489,-113.478649,-108.515063,-53.885706,-60.096552,-87.32414,-68.474329,-29.845987,-7.597028,136.100172,246.852423,215.075935,117.19424,93.380919,-14.844687,-94.159345,-139.89933,-60.271136,-40.457917,-122.741002,-208.329208,-323.584032,-343.053397,-352.186103,-328.694769,-226.791976,-136.265773,-102.571031,-11.39467,37.655087,68.413249,62.964242,112.159467,164.672645,150.536245,76.387836,46.766851,45.526178,56.810962,67.563466,59.266893,-8.620563,-30.142038,7.807115,30.934672,-24.708616,-135.203556,-116.901938,20.629823,38.952652,-4.710282,-77.402139,-88.937847,-75.746645,-67.313687,-38.529383,-17.226095,-14.021071,-69.773085,-102.371397,-152.195736,-168.370002,-177.899541,-149.183896,-49.421719,0.924691,23.510446,60.019491,63.232508,77.982503,72.63001,-5.499425,-38.894162,-56.52686,-79.892719,-92.991149,-67.921905,-29.566201,37.354459,66.668238,91.502594,32.218781,-0.842486,-27.033977,-21.541063,34.281644,73.232749,109.00774,93.605124,54.579759,117.548495,154.368898,150.899283,136.265013,124.981211,128.328128,196.463913,270.778935,258.185081,207.058624,219.678383,266.094933,246.269519,191.529738,219.179157,322.969902,279.395366,179.66906,-40.207349,-79.394091,-9.463831,33.413387,55.454186,81.27852,114.583704,143.966781,138.110677,122.511662,88.649652,6.110921,13.180346,109.300766,166.36574,128.933925,-44.738968,-114.934699,-149.802695,-124.86721,-57.79912,-57.986871,-65.595305,-62.071694,-46.294046,36.744432,71.169646,50.520038,24.267138,63.572972,152.675441,128.763274,33.038302,51.816144,143.331095,133.77664,45.893874,8.678936,17.293266,33.564036,31.855899,14.268038,-19.430049,-73.463941,-52.684044,13.463221,12.031573,-22.622053,-106.088646,-128.175717,-166.112797,-183.895235,-171.279494,-157.040566,-130.153994,-9.531235,33.166689,-9.636702,-85.436676,-260.003788,-315.618286,-299.615996,-223.251405,-208.097933,-179.595044,-153.785992,-149.624894,-190.037595,-270.908666,-200.505384,-128.138412,2.221642,54.283603,72.927223,19.519455,-107.944239,-120.953203,-11.982863,76.050373,54.417106,-5.115599,1.273581,75.135008,138.851602,235.871,172.722436,142.5779,159.573392,155.216446,123.189449,135.423558,201.685532,237.788011,247.754904,156.765188,110.969635,48.611281,49.479802,107.742732,135.569528,192.746063,267.057443,278.269992,142.70646,23.412983,-127.298014,-146.304967,-118.971977,-74.211163,32.055305,98.549336,115.340938,86.249588,34.006889,-94.274925,-141.285011,-167.021945,-96.469207,-58.115737,-93.74104,-174.526493,-331.218728,-339.805089,-215.197328,-158.77722,-182.249287,-179.585021,-105.717915,-26.196778,-86.595376,-221.078921,-199.256034,-40.470067,68.289884,102.425755,77.716105,10.749768,-143.385957,-214.733087,-288.006229,-251.50543,-54.480738,158.41744,217.009624,224.149812,199.64683,162.411027,183.774103,314.140179,336.505336,264.612475,127.271184,113.853646,100.023357,55.022088,-37.424621,-46.001503,-4.986384,83.714442,107.547184,21.138145,-46.019034,-50.144558,17.004917,105.594846,7.025044,-21.247324,57.900367,102.035106,103.786578,85.501273,87.070868,85.61955,-11.36104,-136.050454,-169.822331,-199.510031,-196.441208,-141.494723,-98.00465,-18.519586,80.029287,147.123637,188.925389,136.532717,33.395652,18.129854,16.081815,38.581169,126.45107,146.903452,99.675227,-76.136635,-141.22904,-144.245661,-116.431035,-71.741741,-1.100708,42.898202,45.794307,-2.037169,-84.85358,-91.821983,8.67483,102.098092,161.357208,43.347686,7.063923,-5.912169,-14.491769,-41.302103,-62.819486,-109.936999,-51.937934,1.448893,26.733278,4.857507,-24.004889,-38.358103,-108.836333,-126.039419:backward
-116.457756,-82.606143,-46.36765,5.376558,15.126163,10.803294,0.081905,-16.859522,40.534319,102.115167,173.004414,159.944068,78.124361,28.673185,-18.338492,-6.398616,36.321896,56.298091,72.093626,152.970743,193.558247,213.620884,201.657085,135.501952,101.694862,145.2766,225.533178,205.448304,92.927105,54.092895,23.11658,-21.576206,-185.006951,-235.984554,-190.810415,-23.750273,51.855955,30.842351,-56.122146,-184.092362,-144.45695,-90.750099,30.471762,84.291033,105.177913,69.883701,47.898431,88.071221,176.206541,199.3898,191.080082,168.684351,163.076564,178.988979,208.472564,260.242141,301.751884,343.004992,386.476041,371.342488,324.134765,295.501013,202.629527,145.536246,110.322134,267.325871,374.771072,537.776934,551.578373,387.156182,264.670964,119.255653,139.987418,199.050221,355.758504,405.491183,332.643623,231.57348,77.015301,47.142472,40.934283,75.586848,93.306596,144.532632,163.547683,120.996913,82.318115,17.743188,-54.010095,-71.16207,-26.768897,18.654036,36.749726,-6.359178,-29.939556,18.068056,122.048684,216.505,241.366557,200.491658,160.535198,79.287459,51.028322,43.174135,30.115935,13.756579,20.35316,52.916777,122.423392,122.277415,43.29896,-3.941757,-48.709387,5.143636,49.007922,104.130089,115.980433,133.783844,134.5565,99.90589,48.926585,32.238202,2.371793,-18.721969,-92.379317,-140.890736,-207.972016,-233.383733,-270.364242,-175.236055,-91.574802,27.238828,35.817643,-56.964299,-126.505288,-227.079667,-280.202309,-290.084048,-235.527025,-171.546491,-60.910702,-51.473735,-160.860901,-252.923449,-321.098455,-217.675268,-197.522139,-221.9249,-218.678176,-197.522097,-197.838802,-257.574931,-381.669745,-409.829565,-362.853267,-324.726391,-263.167863,-223.857418,-143.253195,-121.460024,-86.536448,-40.072361,-21.338325,30.896247,45.965689,-22.393199,-81.789177,-180.004422,-198.455575,-145.435053,43.968265,124.83864,143.131707,97.766769,48.872382,39.394556,-45.524431,-98.362223,-56.960371,128.805796,188.898667,83.038803,-19.037296,-110.847293,-106.826299,-107.032972,-71.816509,-28.936,7.15343,-18.505998,-64.020514,-57.865558,-16.399837,-8.308334,-15.688847,-29.444233,-56.779801,-173.570688,-235.751872,-307.443996,-299.957491,-274.947911,-281.681604,-323.554619,-385.541381,-398.20732,-434.014603,-474.789436,-529.182133,-388.450985,-313.392715,-278.018447,-266.709486,-187.757396,-157.866096,-226.079125,-396.261876,-445.451224,-411.684859,-352.091197,-264.806583,-267.204994,-332.02172,-353.941228,-301.930963,-174.316741,-136.573244,-119.58836,-123.887028,-137.323162,-133.360439,-142.399869,-196.578507,-217.86267,-173.536626,-95.235086,16.458531,-8.575831,-143.440343,-193.36351,-203.978859,-105.644644,-27.82052,115.543123,113.934561,-65.053495,-150.815508,-192.830722,-156.79275,-141.964485,-120.85868,-87.5304,36.724717,87.66707,86.965398,35.775924,-76.531175,-52.523728,26.48069,172.408375,171.070415,111.313711,141.850406,216.939121,43.26417,-60.41754,-69.330425,27.108803,225.609245,243.94393,144.281441,89.130522,69.871489,135.237259,146.337703,134.683788,117.517426,32.463329,-3.697405,-41.509461,-97.97361,-102.685036,0.059171,89.270055,200.761398,190.854636,131.834097,114.481848,81.246036,34.352151,11.730989,0.51712,10.041931,-14.632359,-50.528434,-109.59318,-96.017737,-61.232928,6.493038,48.513471,172.654809,205.695216,111.414717,13.405163,-128.223045,-121.002512,-88.910844,-35.320567,-34.671718,-102.480309,-137.283204,-171.811896,-175.176494,-129.445168,36.990101,115.621836,174.75033,142.573011,53.985186,30.17122,-24.065716,-105.515567,-117.65899,-40.199929,27.151384,111.443813,109.64087,83.363676,111.895437,113.72721,86.170662,113.323407,219.567628,227.563542,173.870252,173.280589,228.286115,239.158701,239.015803,278.386724,273.419158,147.144227,65.299819,-48.869698,-44.875597,-11.699856,62.358353,101.023556,98.86005,40.173423,-28.2645,6.304141,100.025588,84.993502,51.133202,17.773254,15.038182,-11.414535,-33.573509,-107.332484,-172.125179,-137.940036,40.331597,105.679432,81.475008,45.024716,59.03188,61.423816,4.519141,69.076052,105.926959,37.496182,-26.063869,-53.512454,-6.997942,81.459636,64.931745,39.728652,2.677185,-11.601962,-61.454856,-95.992945,-131.560688,-132.767123,-167.989851,-181.081466,-135.062855,9.71579,74.886554,154.700534,155.829852,82.09219,6.261543,-12.938592,5.320148,49.523512,119.474558,124.883307,136.481505,137.354329:-96.015398,-24.069347,-9.223726,-42.93771,-83.751476,-163.275071,-166.173706,-90.969659,-18.401679,-7.307524,-13.486436,-9.049471,6.281293,-2.491488,-55.59611,-82.822146,-83.152288,0.490975,48.505112,101.736397,105.343263,91.169955,79.121045,57.261379,101.314059,143.499774,161.669766,137.06448,117.775739,102.717458,-43.511594,-144.800127,-243.962525,-171.07148,-122.553139,-69.803591,-54.096596,-51.304015,-83.228191,-207.886896,-247.288519,-180.665397,22.144888,92.470709,117.045436,95.704708,95.027448,129.029941,192.980618,190.348791,179.17587,186.002505,205.49781,216.330451,184.500133,92.358269,139.811095,219.475911,319.292947,301.657967,182.034245,125.604394,73.879162,70.141579,112.477922,281.010907,387.483014,472.37943,419.720332,193.152564,69.052927,-69.58447,43.887842,165.558913,331.273659,329.654994,214.385657,155.803015,106.517606,99.459076,96.702964,134.670077,176.095803,270.428058,281.98712,179.05163,86.856509,-80.132317,-123.51315,-105.65075,-64.642018,-35.932088,23.724866,19.227808,-26.846346,-29.524504,47.90453,164.012057,171.058473,95.844674,62.309476,40.520726,46.206259,38.69739,-39.161771,-78.151154,-50.303126,29.971324,115.896976,57.589419,-81.884448,-86.952122,-22.484648,30.428854,49.582258,80.876194,100.73984,166.848724,200.790389,183.31931,104.883539,94.830457,84.445629,49.335503,-57.566445,-85.537908,-79.230262,-100.543504,-183.386443,-129.807808,-69.402104,27.051325,58.886761,23.589151,-71.31879,-283.528622,-306.406063,-274.633964,-196.702851,-150.714011,-121.311508,-155.525394,-232.948175,-250.631311,-295.573194,-327.333204,-294.492562,-184.820166,-175.937512,-212.848566,-195.746408,-173.833265,-215.681541,-200.672883,-104.58889,-50.734258,35.254586,60.932116,63.455541,59.734807,109.316038,127.211456,104.682187,128.979762,160.848913,97.932451,12.181519,-131.709242,-103.870681,-30.746905,91.688778,120.940356,92.902683,27.014814,-135.099506,-181.759935,-132.992724,-19.738259,2.10191,17.095242,-2.468804,-148.313976,-213.412361,-201.194863,-108.811013,-77.620492,-66.373938,-70.130361,-71.185766,-73.878811,-92.563383,-103.583904,-92.779412,-62.860367,-61.120496,-75.358206,-95.84339,-170.493633,-206.156651,-255.274548,-234.218818,-195.662161,-157.521834,-170.26365,-240.689317,-289.461752,-366.086667,-389.906004,-417.410901,-367.753277,-304.605799,-140.574724,-73.968075,-18.329883,-48.941362,-272.47719,-424.793982,-397.038144,-301.674687,-266.728328,-254.230126,-312.235336,-459.947589,-466.347169,-327.456224,-128.710338,-47.003244,23.88113,0.53512,-139.961269,-221.73167,-309.158454,-243.762619,-184.735174,-75.148604,-34.421053,-50.558022,-115.228826,-251.003057,-277.402323,-219.660081,-104.843998,-73.911347,-49.009296,-30.944536,-36.776499,-80.666189,-156.847745,-131.141357,-115.677032,-119.120514,-106.132515,-32.515794,4.016006,10.548893,-33.771513,-105.894111,-18.229628,53.214043,136.375944,124.77883,68.66973,68.806858,88.282434,57.713762,41.972718,90.233388,161.111356,291.636294,317.652597,288.736497,244.194505,173.292539,206.223316,232.391698,215.413828,164.709784,50.173128,31.156346,53.078407,48.595346,42.189649,88.66239,137.580466,202.736604,215.747081,220.120299,183.893182,59.911385,31.710605,47.681636,41.52574,11.850499,-46.714009,-62.688164,-107.491743,-114.729437,-83.795073,12.227789,93.432404,283.913179,319.583177,167.070905,36.286579,-83.087039,-1.757572,40.681094,47.232711,16.576481,-46.411437,-62.70469,-82.343565,-83.118388,-55.654927,86.380736,161.188388,155.724292,87.000718,-9.198072,-14.695578,-14.503986,-33.164923,-21.110615,48.618429,64.105904,5.56363,-47.477086,-118.030509,-30.664762,54.722634,175.030387,198.169397,180.002501,154.079153,173.248725,221.293998,299.439102,307.776663,309.776056,313.159708,276.319914,103.535479,20.8656,-58.967394,-70.340896,-45.887679,66.527538,122.142539,125.672855,78.679334,17.421565,26.999048,111.628619,191.668929,181.768979,119.193071,85.125017,-25.792822,-78.388398,-87.856792,-13.196574,20.446125,71.236046,99.107494,137.412191,118.358256,1.766908,-59.162632,-105.753942,-32.7268,22.667748,81.561227,65.328781,3.354053,0.81734,53.334528,75.284778,49.850692,0.676468,9.911291,14.162748,-19.950059,-106.940672,-129.824293,-96.846952,4.814495,55.019068,155.591127,225.976725,359.238315,370.765692,233.383437,60.919117,42.384975,129.705277,186.331217,223.05583,208.542569,165.52353,144.086792:-167.935737,-122.081273,-151.424209,-242.448412,-244.111551,-167.455933,-145.690109,-154.859212,-80.759748,-28.971635,-4.833504,-18.828373,-62.477924,-87.961674,-104.87282,-100.87834,-87.776635,-52.18639,-35.414321,-25.026566,-40.630508,-94.238937,-89.678357,7.443384,90.271673,109.912566,97.425182,47.946952,-85.509361,-114.176813,-92.151732,-97.94477,-174.474717,-212.175298,-175.103931,-45.465091,-15.13694,-80.551779,-145.761474,-196.1168,-110.48334,-87.896009,-96.661946,-71.059772,32.139524,76.841031,135.474508,146.007872,150.090208,157.432674,153.894447,130.335215,120.100561,130.861297,135.510262,72.21211,26.041074,43.221409,57.694798,41.431713,8.639496,-12.308978,-83.745989,-113.285362,-74.008741,66.726725,139.587969,215.034615,199.269616,120.223426,77.615225,2.57366,47.22275,116.03347,213.555988,227.367461,197.891026,145.449092,3.9969,-43.972497,-32.133602,73.771876,126.741331,190.451641,188.9534,96.212365,18.340413,-118.767724,-135.247781,-113.355653,-96.038742,-102.355383,-96.985514,-71.497851,-14.884246,-13.830356,-3.08179,113.697725,162.757217,139.332206,79.589424,-4.483708,-6.776244,-12.206576,-19.92488,7.37596,106.753929,144.493791,104.220082,40.827978,-51.723975,-71.278498,-41.839723,50.711934,57.312569,20.406712,35.341485,141.162685,177.787787,142.810339,98.420801,98.48348,64.263133,32.175611,-34.668122,-77.874046,-159.650907,-182.874722,-183.334871,-131.761168,-103.985633,-86.802081,-105.769365,-197.576906,-263.040059,-360.981492,-349.790811,-321.677505,-284.686661,-290.877905,-338.881138,-358.542134,-365.224996,-371.7545,-417.862704,-362.713336,-288.172962,-221.569666,-252.850266,-279.090555,-235.726849,-155.909599,-122.443511,-75.110938,45.951704,81.40298,86.511315,72.198462,67.171013,93.925971,193.176259,253.288335,254.022782,249.010182,241.820414,182.269249,132.571124,23.837257,1.41704,41.835507,107.119207,92.758416,19.300666,-6.302884,-56.318698,-95.039497,-104.814448,2.825086,59.516063,112.10434,67.246412,-128.574403,-196.610435,-192.136521,-128.596417,-108.658896,-57.645074,-15.624134,51.089258,63.390976,49.793353,21.279783,-42.059928,-27.512079,21.417838,115.813981,100.945971,-30.365248,-91.865071,-173.385546,-165.487624,-128.721363,-55.38372,-25.496478,-26.60136,-67.095775,-162.612595,-200.308771,-226.519455,-158.122057,-97.809811,-9.576066,-20.53132,-98.951343,-125.596712,-187.45078,-267.154678,-269.585663,-183.019354,-147.276898,-214.819891,-286.7484,-337.856275,-290.262823,-111.710423,16.850918,45.83827,98.686692,99.941078,-37.505902,-139.981167,-252.561647,-204.347388,-158.379286,-53.636927,0.539185,10.233791,-51.490358,-178.414334,-192.293197,-135.090984,-83.34926,-85.554275,-116.279677,-124.267704,-117.479317,-109.184049,-86.902937,-63.834111,-59.181507,-12.266604,39.162495,57.571278,0.997941,-92.603665,-92.809341,-44.553046,44.191477,103.580639,201.750391,204.678795,130.716826,98.243937,91.566475,137.490948,169.301954,254.145162,291.839105,306.424839,300.146876,276.035491,239.041567,160.771851,176.115476,211.941203,242.893813,211.559586,146.394814,139.770456,85.689691,15.483028,34.55356,170.49396,243.258492,309.874991,313.293319,276.109926,212.216793,60.333641,82.447475,144.120787,197.232185,141.687159,-60.386478,-118.012794,-91.978333,-16.847646,-1.32045,16.20493,71.703162,260.107292,306.165625,178.180435,68.963633,5.528884,62.784611,51.501237,5.220114,6.595282,10.863925,-25.351287,-129.581042,-70.638398,-3.387332,53.210867,54.609665,38.086666,18.45609,3.191456,4.549703,-41.240844,-55.141767,10.031984,159.676505,148.265449,-3.576788,-55.421934,-43.674933,51.850227,94.750637,122.079444,132.82414,196.217108,222.683545,233.019648,238.289674,290.656416,343.099793,362.486704,373.566628,327.822775,138.050744,53.747587,0.11177,44.800009,73.198483,124.925859,150.574893,155.373413,113.897212,1.872979,-6.25047,131.307365,253.507871,232.453436,112.048934,79.598452,66.513298,45.778057,-8.055119,45.564842,91.68509,127.684371,134.178215,158.065226,153.168373,57.957741,-18.609931,-103.197076,-33.211653,10.986886,59.123887,69.420007,87.749612,83.883313,40.918071,61.530837,82.220346,85.628155,80.062182,47.190906,18.701082,-56.635306,-94.15308,-59.48075,91.477673,134.586144,192.451779,236.61638,265.271102,225.971081,144.926245,151.53151,174.50688,257.235139,292.590494,255.819072,206.522106,165.836857,180.190591:-205.851352,-155.423241,-140.323846,-128.588077,-126.104282,-117.764964,-97.358446,-53.878573,-2.322823,38.071364,62.075226,44.45864,1.26041,-33.002286,-99.773774,-101.237137,-48.982655,6.554338,20.792025,33.180998,41.410467,87.550274,129.672723,185.456954,153.955587,130.996853,111.028934,117.847306,105.262555,53.874803,-72.506306,-112.683644,-158.360839,-190.541436,-183.790782,-67.289494,-5.100591,-16.716562,-71.362836,-172.877477,-192.084992,-168.457242,-98.594449,-47.708369,73.330464,109.992981,112.889275,101.863046,122.494838,163.064682,141.810834,66.385848,68.374338,139.070306,154.290092,110.080934,119.122499,164.846828,240.973879,241.209498,157.22029,98.394881,21.452489,-4.239607,-25.459897,133.848893,278.030643,508.101702,524.785185,365.436611,248.50438,55.019864,22.799004,89.914532,290.536012,349.478885,274.026822,177.065822,33.296722,3.164815,22.193918,83.937154,103.159899,178.154347,203.196248,102.724013,25.297472,-59.510711,-56.85761,-37.359726,-12.478194,-1.405487,1.537454,-30.240707,-109.815753,-118.778953,-12.494743,182.311262,218.237837,133.521315,80.948794,51.122951,54.007476,18.900254,-45.505413,-51.037759,26.450794,86.062461,111.019951,61.113459,-59.387753,-99.123555,-102.685398,1.485112,52.228454,150.167882,209.11355,257.227439,234.308375,152.412937,64.463289,48.871872,88.541742,96.654068,-21.994553,-118.240398,-212.855238,-211.601252,-193.348846,-163.001539,-163.184306,-157.411154,-123.977246,-116.729972,-187.547522,-347.553477,-326.444438,-270.605461,-192.628472,-187.552012,-224.853652,-251.232517,-296.626657,-313.939626,-340.136794,-335.077405,-316.06971,-251.818745,-218.293349,-165.860047,-146.233219,-159.051963,-224.81065,-231.109891,-134.751559,-53.727849,35.613984,11.173793,-60.132866,-42.893145,90.122414,163.460936,152.794378,160.176768,179.640976,132.251542,58.971948,-116.747134,-146.654535,-72.279721,114.899811,180.196233,193.407078,135.43722,17.753896,9.629882,29.830874,5.694718,12.098565,97.874381,108.6108,-45.356017,-132.162446,-151.048248,-76.935796,-62.549676,-54.324984,-18.116634,90.365021,110.415595,51.18737,-3.297868,-60.101335,-20.440834,-5.857263,3.684047,4.622943,-31.749478,-69.943728,-174.792521,-255.29044,-253.178751,-170.090749,-106.081471,-40.134606,-78.02564,-233.567031,-308.370617,-388.650359,-340.196295,-290.26553,-175.277265,-124.57438,-116.822532,-180.472134,-392.823552,-483.425992,-439.322956,-336.252631,-321.08894,-306.071305,-305.927342,-344.991455,-349.612092,-281.478679,-182.217974,-127.575183,-15.596054,2.179814,-74.744647,-122.192488,-182.035055,-268.183763,-302.298847,-254.97429,-200.227991,-166.653644,-187.615665,-242.598845,-275.15908,-300.158991,-196.466625,-125.173042,-33.017863,-22.15667,-21.913321,-24.199992,-65.752633,-94.897759,-89.064839,-46.784808,-7.373735,42.019364,24.139071,-49.560157,-74.439555,-95.077896,-63.39907,-7.41529,123.651587,146.44966,104.160758,92.371296,119.263081,111.884496,92.240604,90.68121,117.995363,182.724509,204.590225,211.957391,193.532315,138.267425,134.6309,158.806592,192.471385,155.698094,15.1372,-4.706602,67.698715,44.816599,6.845201,25.043866,84.925117,186.351789,188.269035,124.4948,91.324101,77.36269,106.95318,115.643487,123.86086,112.540078,55.124807,22.798469,-47.845827,-37.703069,-1.67181,24.766256,41.56947,170.160043,223.037319,136.352416,27.094522,-87.423511,7.642004,62.883286,115.200674,110.099379,12.575758,-46.402935,-88.395087,-78.439705,-55.273863,45.758779,110.477809,183.543083,174.047813,118.752411,81.547826,-2.089303,-43.41719,-44.922215,20.398104,86.35447,151.862798,118.132645,17.715478,9.407948,27.366823,74.782916,124.564339,229.797154,227.768746,140.459996,120.895587,190.342165,256.65178,252.555884,250.167663,240.437643,104.765156,-3.962171,-143.386605,-37.772094,54.583024,133.280327,122.430369,94.218177,77.410504,0.332457,-29.351887,38.594561,146.87503,142.943467,104.679442,106.759014,83.235733,39.535053,-52.317228,-65.656137,-29.452244,90.251403,141.339648,153.199103,118.066558,62.151556,50.53901,11.930267,9.302418,29.208355,50.201615,47.727147,41.996251,43.054351,47.164065,79.31509,93.058845,83.430463,75.953472,39.703942,6.812445,-34.768656,-43.97093,-56.532432,-14.960255,25.684742,161.862288,236.003299,239.432712,186.42808,124.354756,107.38333,104.558663,140.144995,184.797055,260.824103,251.895226,169.615523,143.924981:-133.77489,-137.577568,-158.740083,-156.601691,-120.684146,-67.167707,-77.9527,-111.692178,-37.216243,14.979717,92.953298,124.045481,83.501226,-6.985734,-175.298405,-179.605156,-44.326752,61.059773,76.973928,54.262779,21.027031,15.020526,44.882702,56.444081,39.570008,45.663573,47.719391,37.814227,0.069491,-12.670744,-26.914176,-64.537508,-168.728138,-155.944568,-109.889674,1.862399,25.732343,-95.281542,-186.0917,-240.943008,-169.669311,-131.343284,-39.061988,20.476202,107.670773,124.023774,93.933559,49.60261,33.161007,163.288868,214.048042,211.364397,177.126731,91.558145,39.144135,-20.499044,51.487957,89.418044,104.934252,100.793701,59.252318,14.242392,-74.616974,-103.331678,-84.719246,117.214564,257.775426,407.126474,367.476697,163.749666,71.610073,-24.402744,31.921787,105.612237,254.75017,309.906706,288.376042,204.565073,20.224475,-59.742283,-137.87649,40.939785,169.69956,320.635489,331.575345,204.389072,71.842951,-176.824938,-180.403325,-112.681861,-9.7016,23.012086,48.574347,18.676644,-77.250478,-106.109711,-77.326241,33.894568,83.804467,115.230363,79.115353,-13.367145,-17.01559,25.169558,25.719441,19.263089,86.916436,161.371254,203.585163,128.166563,-82.038609,-149.61456,-111.009295,57.997351,100.444771,139.87727,188.737565,279.096687,267.059837,148.587964,72.059976,72.021962,107.6088,118.603047,39.236993,-50.332355,-211.661298,-254.961517,-258.52219,-204.808424,-178.037359,-102.793508,-65.450169,-62.775488,-105.445541,-214.795856,-240.552615,-222.262165,-189.56953,-189.514626,-221.499581,-246.269015,-304.54646,-334.114269,-330.042997,-246.788042,-209.556144,-134.443092,-101.643993,-68.633296,-58.78542,-47.295048,-33.67637,-7.853853,98.337876,140.680098,113.525798,85.321361,115.010948,133.438979,113.713939,156.874097,212.694808,295.548807,305.409459,244.857405,156.727605,-43.603044,-59.225687,-9.026521,100.191485,154.63263,205.956367,171.263539,20.260691,-50.854169,-74.463613,48.118175,112.287327,160.498683,121.150144,-22.837248,-59.112883,-60.872475,-74.255781,-69.728902,13.821087,93.899567,176.199795,134.584298,38.203945,33.251442,59.106487,67.378905,86.950874,186.958526,201.140605,86.411223,23.723418,-13.170174,3.522748,6.532928,51.707847,102.215208,137.780639,94.477087,-39.508385,-98.023856,-145.396757,-84.191181,-41.336707,25.364958,49.571833,55.832426,-1.18951,-232.397159,-354.177644,-319.397378,-154.104042,-81.417391,-64.581249,-117.650596,-233.449828,-253.025148,-185.633798,-48.760944,19.670263,144.184246,166.084788,62.870107,-19.909785,-147.834741,-192.241014,-169.392012,-77.461269,-43.843579,-67.746917,-106.577363,-171.407259,-196.096447,-173.110277,-41.113093,17.800735,95.887342,105.977349,23.366563,-35.986078,-78.581726,1.834029,58.226853,139.165711,156.321012,85.605779,17.88377,-45.771744,-60.948022,-111.711312,-46.966085,48.44046,242.425749,271.253664,163.928739,89.05493,39.111264,123.920739,175.436116,260.532066,300.687978,339.042759,321.056951,199.161433,108.353716,27.622596,140.041248,204.874844,223.244683,152.229675,-6.034551,-23.141865,-8.643897,-50.52642,-54.211874,18.873303,63.839225,121.08704,134.648024,91.322294,26.540209,-56.856131,27.708944,79.874448,94.413601,60.538328,-31.593752,-73.836126,-118.723288,-83.59626,-51.841838,31.997186,90.31166,193.226979,206.06092,88.576384,-19.454251,-129.287786,-30.531576,41.628703,116.531901,90.656424,-50.906894,-130.570661,-227.254646,-147.927315,-65.783251,91.654073,142.346272,114.637703,51.437192,-52.291928,-71.022646,-65.053933,-90.003859,-102.134428,-24.288861,36.913864,37.601427,-40.642335,-201.491181,-142.536536,-76.313314,-20.5851,-6.14361,36.348694,44.65746,28.299378,24.674844,108.35183,228.673769,238.521862,202.483092,174.21442,47.758736,-40.077066,-146.385802,-87.114148,-18.401848,97.732172,119.722273,65.281663,8.121125,-75.494569,-79.735885,-2.896094,118.501093,173.898067,230.407431,212.476163,133.933499,93.132467,-5.833504,-57.349064,-39.929553,72.340026,135.120245,145.210209,98.233394,6.307845,-38.13144,-104.553639,-42.853765,26.034381,175.205117,226.736437,204.433096,129.811012,-43.436019,-46.975273,24.156216,186.601036,217.565587,84.65819,-13.681771,-62.452314,-37.945372,2.749836,108.655916,179.469408,274.656859,282.505513,204.997516,132.317322,45.112285,128.51666,183.406699,255.673145,285.331481,278.635446,235.217059,165.871287,159.787469:-132.989015,-122.112517,-94.265855,-97.70063,-131.200412,-130.453097,-58.42636,96.82222,86.996288,51.224399,24.129291,29.609368,13.706719,-4.321352,21.323068,55.497582,63.284505,74.902911,103.746511,127.689553,120.306119,106.531405,99.735227,60.389968,30.72284,29.998838,27.164766,41.440659,127.684842,161.689021,94.804145,-0.110384,-192.338124,-246.208177,-210.006653,-59.690763,7.926971,1.565724,-56.105215,-131.215851,-122.686326,-119.494482,-74.848872,-5.951695,103.942081,71.324433,-65.578241,-53.247267,141.067409,191.428751,139.119308,99.809025,118.331429,112.111183,101.398917,138.398309,172.681822,173.10062,218.005126,256.011695,219.783776,138.878909,11.79289,10.808912,127.002911,273.722241,331.139254,468.546785,508.726795,410.429631,316.790052,201.298327,196.487856,216.617887,284.053373,311.276879,279.707598,229.38116,122.979653,74.73739,33.860938,24.779426,-3.806578,-22.36587,2.029865,10.177186,-3.180729,-3.71072,-9.730226,-5.407409,24.955411,33.224172,27.863709,27.014007,25.847415,17.075924,28.488826,121.728,161.410476,147.488082,105.596714,42.525217,38.932907,40.359709,23.121337,19.46764,32.762107,60.053791,125.718157,120.302227,5.133913,-74.953022,-129.407342,37.281502,114.604539,167.609459,186.265954,220.054856,207.593346,143.728188,130.526732,147.631809,131.853418,74.772834,-56.79653,-87.272995,-95.161408,-109.998039,-178.687941,-192.601308,-164.347967,-70.93271,-35.586613,-63.843181,-108.439124,-172.562544,-195.600949,-188.010205,-142.744191,-116.176618,-51.743681,-25.465567,-67.933316,-132.966257,-196.851593,-144.249212,-140.483977,-153.299363,-140.654104,-107.823054,-96.10969,-140.488533,-308.425649,-373.944953,-353.389403,-281.596511,-145.88828,-107.945012,-79.480277,-89.534851,-94.87877,27.002632,94.133845,127.076891,112.639137,123.162771,148.360344,120.633731,23.477513,32.777831,156.318464,216.993922,252.789111,227.869118,180.283059,174.892746,120.060143,7.91559,-1.912533,114.241848,185.803336,181.616244,115.981834,46.615632,84.753458,101.595402,108.566206,110.402522,121.878993,126.135877,122.037864,113.621025,116.874169,89.910682,49.241328,38.680416,74.466632,76.363898,20.802467,-122.70767,-181.498937,-138.728738,-5.641339,19.180061,-33.315909,-92.478819,-242.863217,-308.578938,-356.757508,-298.773265,-266.256731,-172.874539,-94.296676,-8.391917,-65.66782,-289.349571,-361.043966,-323.228788,-213.33409,-164.551172,-126.402517,-140.47142,-172.722053,-170.121687,-130.919717,-118.853072,-125.010319,-103.927818,-90.615259,-68.915968,-43.200432,-41.861211,-196.050632,-259.675685,-185.887911,-76.83275,46.049881,22.67695,-80.018026,-111.160419,-50.346315,123.628489,180.530948,185.630124,132.620292,-40.072275,-85.980482,-39.045785,21.637646,33.755589,48.321344,64.85544,117.581013,115.498485,15.079929,-36.434429,-49.089748,40.085926,113.975522,261.859113,303.165333,311.018614,294.763046,211.002514,81.782951,50.105124,114.054697,193.877973,316.813876,314.142968,190.512599,104.904203,11.213964,69.296878,116.581753,201.878278,217.941359,167.469377,135.029064,94.035821,43.287509,26.57043,40.348392,75.559407,128.654541,83.361057,-71.969526,-84.641798,-20.090191,-7.755945,7.993211,58.882586,47.890782,-41.040261,-79.05463,-143.297634,-141.538169,-91.600379,2.673666,19.633092,41.769813,53.175586,3.58094,-54.656027,-129.695491,-125.900314,-117.612125,-88.807251,-67.247571,-67.73897,-107.487402,-204.880283,-203.418789,-134.592718,82.325014,151.269474,97.485693,22.674683,-59.17927,-67.401911,-101.483142,-145.185837,-137.781486,-6.675682,88.542874,145.982556,87.296414,-23.350255,26.560611,43.818275,-8.062434,5.134987,158.743987,211.684484,176.413121,128.060153,84.281671,116.112959,113.002546,83.013675,81.021984,32.989496,-29.443094,-128.83929,-90.857743,-39.963295,28.838099,51.144784,70.109487,11.604394,-189.834222,-217.265617,-35.776709,109.89814,77.633589,-42.227259,-70.207001,-78.633885,-84.591147,-118.167731,-91.094865,-34.137945,54.287608,58.051964,-1.511468,-49.533409,-82.070984,-71.453295,-82.865924,-19.062075,49.829033,95.134628,57.508025,1.614989,9.374707,39.685165,40.774731,21.130948,-35.913209,-51.220739,-96.823905,-148.336226,-209.484499,-184.323947,-118.706236,-120.718701,-123.75883,-104.236536,-105.564867,-148.71257,-154.024603,-124.195841,-140.434524,-158.086072,-122.507814,-62.456042,-1.57754,-37.149557,-121.706788,-128.103172:-177.72321,-168.769683,-134.078398,-27.503625,20.840007,43.910533,23.320121,-15.79027,58.122417,122.457325,171.87207,146.265551,46.400052,-4.139611,-67.373409,-70.890863,-0.212903,111.043125,126.83757,96.480505,88.183201,65.538914,36.896144,-15.700631,11.671769,51.558079,83.450629,70.699025,66.718553,73.472251,15.575592,-61.93649,-197.026464,-136.840943,-69.674162,-4.18007,-7.958851,-60.487985,-108.876175,-207.762611,-177.0874,-99.757197,52.749168,89.050658,103.002988,108.172413,117.019798,104.503237,87.533611,172.365966,222.968262,227.152719,191.223015,143.407355,138.513683,125.76402,119.064527,139.829443,237.906446,279.830218,258.155878,209.712699,101.732562,44.78842,11.489986,221.472134,368.945949,533.053649,515.913445,346.376992,236.567483,45.154187,-1.523203,46.922139,216.204062,280.568372,274.601671,223.572122,96.35822,34.449279,-25.769187,9.133352,50.735837,175.676278,209.489831,123.208366,45.705869,-59.168739,-50.153755,-14.846467,60.351411,111.299315,166.371051,115.69242,-37.547271,-81.310215,-105.468095,-56.48531,-20.736726,29.711568,29.58249,-4.341986,-9.650287,-17.625837,-45.253784,-33.297535,42.028761,82.907198,109.155973,73.29949,-80.035681,-155.278909,-154.815832,19.928973,105.452113,238.721196,277.39627,255.712509,201.668284,84.769254,68.909645,90.845514,97.298214,72.654719,-2.374659,-39.107529,-115.292609,-167.07798,-246.665579,-220.551879,-187.531842,-115.383127,-92.173407,-118.147764,-145.846184,-197.428599,-214.410011,-177.420586,-59.162366,-32.175979,-64.016479,-81.133877,-119.708088,-173.001795,-248.307533,-164.676488,-111.1494,-56.668261,-39.513108,13.836094,30.466036,-11.44273,-88.476172,-108.852326,-73.725182,-19.141205,65.178346,73.281628,57.975909,44.27213,57.403641,136.361401,166.283359,211.85149,237.90566,249.650186,215.993376,103.124779,53.581522,73.859097,178.575844,238.316471,262.096895,209.476483,65.272705,7.637112,-39.85835,7.86915,52.244108,149.871103,169.567902,75.978882,-16.434446,-166.139532,-115.597077,-31.005031,116.069956,166.043764,209.083208,199.673462,138.888993,94.285811,63.053398,117.43542,133.484821,139.999145,120.921878,33.022469,0.379693,-25.927708,-4.36126,36.795413,106.347644,108.723413,55.310315,13.010179,-50.761095,-72.317316,-134.170777,-156.706468,-118.90336,27.688003,83.839509,27.19544,-78.945167,-312.178466,-430.399774,-408.333305,-208.92848,-88.808391,-5.682565,-62.768042,-218.636189,-254.472123,-209.477364,-124.528679,-90.903287,25.989764,83.900696,90.533305,47.963123,-83.08601,-225.797379,-275.521221,-253.385311,-174.135576,-56.879423,-76.584902,-170.97234,-190.98553,-134.676653,18.689041,81.874199,132.044861,123.747484,31.476707,-33.358323,-87.448159,6.343308,72.474986,172.595987,201.386857,192.334234,153.828815,34.590697,-42.06313,-130.154971,3.141664,105.327012,227.459334,237.157597,175.627918,127.318985,74.071208,48.400916,31.06918,92.63768,189.515628,325.690728,289.131402,115.075008,68.261395,64.142978,99.121804,137.914272,184.63683,151.809402,55.857605,53.787244,98.927379,63.47326,45.63758,89.961842,119.009072,99.927783,69.261997,31.676103,9.163653,-29.203191,40.976635,80.675141,108.534039,89.514214,-23.155859,-78.880555,-142.320432,-147.410026,-117.764622,-15.493817,36.688147,111.263228,110.497168,-11.076832,-99.583834,-181.186412,-101.655105,-46.185872,52.645309,70.526718,-40.116084,-138.859746,-261.475159,-205.360094,-135.54308,29.536995,97.265806,64.833797,-21.088334,-109.693994,-93.287802,-75.883958,-134.945147,-142.340563,-39.887814,14.359077,-12.713537,-64.238121,-122.344878,-108.157997,-91.542548,-69.071123,-56.188419,-28.728865,-32.609279,-83.332538,-99.112774,-27.039978,70.944282,62.893584,23.588907,29.792767,-25.327644,-122.905818,-264.736529,-103.752508,4.120044,81.951465,90.692346,90.107759,39.030926,-114.396186,-146.040893,-52.820132,133.821012,190.656376,188.937975,154.233032,60.383601,-0.115905,-91.353981,-80.279382,-53.456157,35.367713,89.41739,106.501828,54.025101,-64.054952,-105.714143,-140.493358,-32.807896,61.979248,212.507178,217.054713,102.234489,44.486352,-8.759696,7.870025,33.988378,118.195462,168.703327,157.257173,77.043105,-59.160577,-60.154374,13.814968,39.745024,30.420896,80.067595,120.046098,81.902358,17.00437,-71.497204,-39.051471,15.766679,142.334211,181.981074,143.332423,85.812801,36.441125,50.771041:-181.101965,-179.770024,-145.835541,-92.81694,-87.624055,-104.332294,-99.75151,-24.626788,50.851359,56.388529,18.441997,-14.365333,-31.116712,11.552365,122.805795,147.255097,128.211448,111.437532,122.170448,146.418972,140.27072,106.640816,104.283339,88.189336,13.111551,1.661385,70.690878,130.701445,235.197067,257.54883,238.335318,183.089216,-17.458413,-122.320765,-79.477434,122.640706,202.918907,168.684666,80.486852,-70.067135,-118.690857,-111.874239,-74.482382,-74.405875,-96.736896,-91.343644,-67.453832,-70.826588,-106.750092,-115.121881,-113.988586,-106.246189,-93.736866,-79.919405,-55.995717,56.758193,117.947498,110.707692,60.685295,50.440627,42.287856,6.891051,-62.371022,-47.509021,51.451265,112.556498,115.784951,164.265685,212.339062,214.274859,168.819814,91.346836,44.098976,41.09138,99.887659,155.365866,272.369868,299.798663,259.377341,198.728028,32.694709,-50.974422,-37.840064,2.933063,-5.189787,-36.313728,-12.301752,71.95152,68.994347,66.221095,128.698122,176.305082,238.3943,250.437062,234.286415,199.251479,150.656684,182.933664,172.629066,105.820656,101.853602,112.873388,88.275293,18.643511,24.509427,64.772034,115.315288,98.460294,32.084935,-0.898853,-69.915031,-111.185453,-141.620891,-16.202255,26.142632,-35.616033,-66.747446,9.128651,67.73361,46.740414,-19.237367,-0.023725,11.919963,-22.709835,-62.165453,-48.588459,-46.855394,-92.212501,-221.322506,-239.741663,-190.150991,-38.814097,19.677442,18.927461,-40.371213,-155.471508,-145.09701,-121.160041,-70.520968,-30.503814,48.803971,55.587345,22.340237,16.517666,28.155136,-36.195912,-80.50734,-59.918262,-8.172316,82.692585,115.462878,92.972818,-109.819163,-207.493366,-231.54274,-181.362896,-166.788996,-214.186645,-215.453842,-143.505595,-9.647132,-0.908921,-31.929,-107.145888,-110.355899,10.944454,90.549649,86.582368,-99.479016,-129.363757,17.953065,118.653562,190.155278,159.283799,94.56905,71.279985,-4.863124,-57.946641,-41.459911,96.933904,191.040532,288.855304,269.574936,181.676495,108.286094,77.15318,55.388319,79.1814,165.753044,187.750176,168.367157,161.303298,153.084356,119.622889,127.336036,173.624391,165.265692,73.357059,27.646888,-12.402371,24.121073,36.455842,-13.707929,-46.426793,-91.802764,-124.089992,-177.745519,-189.965596,-224.173576,-206.188531,-183.242139,-152.07235,-118.345106,-36.662755,-24.803834,-82.567779,-201.902118,-226.060301,-88.012372,45.666055,208.620094,191.901383,93.382298,39.586444,-80.147081,-78.94493,-29.937431,57.81615,72.109133,64.820135,78.507736,124.558154,86.635914,50.061116,17.812428,31.141262,83.28721,122.182623,218.03308,236.99712,206.690943,204.721266,225.18672,304.2226,340.302638,264.113687,165.259772,35.126022,17.651837,29.220897,66.806207,77.170288,60.586522,31.180177,-40.355115,-68.956475,-55.492112,105.020953,191.824568,275.094832,293.872902,350.900686,370.55638,314.947116,113.272025,6.489375,-69.520316,-29.967053,67.277401,65.877847,-0.644248,-24.480875,-50.14523,-29.387189,9.798097,140.978306,205.801956,241.866477,213.889449,120.764969,81.695824,102.98659,131.771307,132.672515,142.629253,119.953584,9.296839,-26.970185,-21.585119,39.035483,78.675407,118.749109,98.032701,11.277805,-5.625805,27.443563,26.751209,4.713412,-34.502561,-32.472789,19.203532,40.14537,17.028393,-18.737006,-82.75506,-110.475385,-133.607398,-168.716531,-154.094126,-87.039011,-58.478391,-65.165968,-110.478051,-98.275249,-6.62916,43.144994,69.544053,36.797489,-6.352354,3.243675,-23.501515,-135.809006,-163.722941,-23.082341,109.609677,233.550087,209.941639,156.413116,126.383642,94.660262,58.569591,91.507961,156.58343,131.658495,44.601212,23.254917,-2.172662,-54.448165,-97.161988,-121.823,-82.469768,-50.964785,-89.632125,-193.92034,-276.416158,-270.854711,-159.763331,-122.694333,-194.347087,-259.509418,-291.212662,-254.425701,-174.213898,-143.589323,-138.658626,-87.650494,-40.826456,1.655093,-21.768615,-81.998858,-37.198947,4.990015,10.094924,-23.636923,-89.41666,-103.511761,-95.446459,-102.103051,-142.03338,-113.376458,-91.621506,-79.158991,-86.646563,-116.730904,-115.303671,-88.316367,-104.458667,-116.689953,-120.477277,-114.050152,-130.931268,-157.902528,-159.674795,-130.33992,-106.423916,-160.559886,-182.055409,-166.275067,-162.980337,-248.506016,-297.017434,-294.956144,-284.051958,-323.127325,-393.939972,-368.395412,-241.287247,-201.107807,-191.044741,-202.875529:-43.224656,-18.45897,36.931254,106.184858,81.410087,-33.961068,-76.410823,-68.793906,33.53868,72.993627,49.560787,5.87586,-47.658699,-29.017364,100.495429,149.625036,110.32155,38.044621,42.084548,132.328794,191.054132,235.428788,202.754093,81.661429,60.709606,106.197845,161.764038,146.120751,116.778548,124.093833,118.534533,63.678117,-115.126667,-128.728087,-60.538062,84.583203,134.805714,140.756976,89.654725,-42.279842,-88.630183,-89.407481,-104.568412,-107.173341,-70.952131,-44.197489,-20.700071,-29.214668,-71.805614,-92.509394,-75.698745,-13.217932,8.367933,33.433662,63.931219,138.85082,149.409432,164.735717,224.326365,231.519974,176.529304,143.013103,133.048348,148.881353,174.544391,240.828749,301.594376,373.677189,337.435586,173.742993,115.102423,86.910099,114.950551,147.635258,247.736136,291.012554,277.09885,228.963562,145.352723,112.9095,49.066795,-6.822218,-41.975834,-79.473957,-77.11431,-62.104542,-42.378597,-39.973072,-135.910993,-153.295638,-56.330745,12.652083,64.841055,54.321467,61.147052,85.237487,164.795997,277.551653,303.004699,261.389184,209.139275,73.246505,31.733135,74.647165,109.458315,75.851087,11.74779,11.48208,31.978919,27.107404,-21.716871,-59.66556,-114.479405,-43.350217,1.37443,12.072055,19.604592,81.183884,87.331615,11.147239,-16.926763,9.648013,13.596629,-21.12573,-99.638705,-144.653376,-216.445808,-223.477157,-241.02978,-268.317928,-227.31867,-38.674983,42.888643,38.599319,-23.970826,-123.289123,-156.871483,-152.449233,-92.265205,-50.373239,6.164653,13.772801,5.976203,-11.950146,-71.39868,-95.069314,-87.205936,-45.269184,-23.533321,2.620256,-6.632904,-144.164649,-315.527258,-354.578618,-386.674087,-382.896417,-356.542266,-365.274771,-373.596167,-338.408286,-255.465569,-218.318609,-197.109028,-126.145392,-95.710815,-61.688309,-36.063662,-35.849673,-137.578471,-145.253332,-28.164353,46.457959,114.820474,90.430118,-20.763268,-67.067102,-106.187592,-47.436383,-0.885005,62.273084,82.119461,104.030965,115.205127,143.414636,96.785369,54.167514,25.895965,45.918326,74.741335,56.113645,14.169508,19.358143,18.31258,-29.04866,-12.819223,91.101051,97.721711,-49.368778,-136.386966,-233.204668,-260.137772,-253.273289,-264.728253,-289.861581,-313.437681,-316.070131,-360.024158,-401.007491,-406.778167,-283.355621,-269.990229,-290.502266,-227.564912,-29.157897,3.095877,-147.328773,-340.975377,-354.970279,-234.924745,-147.478204,-39.889413,-49.159816,-122.092715,-138.354271,-102.139997,-37.52398,-13.959218,32.807652,42.124097,10.7091,1.198219,35.18949,66.877758,42.402862,-34.098495,-21.907037,64.462143,78.799492,81.159233,88.159591,69.973364,107.683559,167.753405,233.496151,203.490757,70.164406,13.213261,-35.398528,-86.253056,-130.762434,-158.686101,-113.243209,-17.976033,-19.318669,-51.430183,-46.786688,6.344456,104.925916,147.692342,197.688661,215.453617,221.755099,228.030401,243.253021,113.690395,19.343758,-75.551938,-64.663695,-26.391075,-23.326311,-14.269601,-18.585707,-40.582488,6.937213,36.17985,62.269618,70.275504,101.249208,107.859505,35.617636,-52.903385,-41.793418,37.615662,68.656119,99.414127,88.382121,54.100043,57.831566,51.507612,21.080618,30.912064,57.341744,42.942384,-32.265446,-70.989354,-128.897472,-146.977898,-116.035251,26.876648,86.591861,76.254805,28.193255,-29.479333,-11.969374,64.489032,10.721151,-78.588288,-198.41381,-185.726319,-124.47774,-118.294667,-121.19265,-82.304453,-44.832587,58.781544,110.832004,160.50568,146.596668,100.807386,99.103231,100.443478,29.096314,-1.746859,74.953787,160.517121,228.638025,199.319512,132.846318,132.325222,162.596291,248.526358,265.624956,201.254923,158.371081,132.417968,135.980227,163.942738,173.099181,154.678502,143.850658,147.160927,96.562948,46.677478,-32.436945,-19.843814,16.596914,64.293509,48.848978,-47.07055,-104.701317,-137.355692,-98.432177,-30.372924,-66.163898,-88.519034,-67.544952,-40.721458,-27.451683,-30.058352,-26.080366,-52.300863,-60.595379,-27.597735,-7.232567,-24.237835,-50.581269,-48.349735,-29.123963,-30.208367,7.66984,34.300032,-26.178556,-89.80424,-100.595138,-47.33686,1.561917,-5.166555,9.66947,-0.382742,-43.27099,-169.688244,-231.531716,-271.233961,-246.061247,-198.641129,-205.745371,-219.54402,-208.602967,-169.646807,-71.920701,-43.593328,-72.89507,-169.074359,-198.916567,-191.968987,-155.008492,-71.964759,-64.726764,-92.262101,-90.231807:-162.068087,-73.820581,-9.755622,-5.760774,-53.431976,-106.029157,-69.504833,44.347913,100.174242,123.354609,128.657492,109.014678,94.617263,94.896061,48.301479,19.393864,1.026262,-10.781487,-11.915256,33.192371,67.926914,104.806678,104.469052,52.40715,-3.383568,21.761632,83.578147,84.896385,147.943281,208.49952,239.291173,187.012684,-5.398658,-134.51205,-136.915043,-42.234044,21.625973,45.54273,-5.509857,-151.97962,-235.2192,-209.571119,-67.302355,3.350083,41.616847,2.512655,-68.75229,-63.453368,-2.477012,52.431411,45.589572,-13.03498,-15.472526,57.85334,95.443153,112.993109,112.451154,126.669911,176.249705,187.44718,91.00941,4.68044,-60.225491,-33.740717,26.562777,114.662602,176.76491,288.628031,308.340872,234.949452,172.466352,74.136108,18.608489,43.501636,189.089011,244.965283,267.756073,258.341815,192.797918,132.22666,53.062063,82.199397,83.994971,57.311644,52.511483,3.649946,-41.492517,-83.807015,-51.356208,-26.542854,33.697093,79.745943,163.008715,165.283807,71.029037,2.660335,-44.695579,71.934413,116.726074,99.597398,72.260117,31.511711,19.936818,-11.816505,-14.511406,16.384149,58.096895,52.902445,20.704009,-15.495944,-150.781077,-224.939381,-257.059694,-65.727816,39.699678,140.134166,150.860842,138.00591,102.994549,-20.773925,-58.007429,-25.922864,-4.095431,-31.429237,-73.338811,-70.234548,-27.431783,-23.895564,-114.33651,-240.214023,-276.640961,-228.232695,-160.295609,-79.705519,-70.98759,-66.617115,-121.128041,-142.010539,-88.277469,-37.115099,20.542474,8.269884,-86.245783,-135.304703,-157.448103,-143.607876,-154.251013,-129.783115,-64.821822,70.224742,73.857056,-56.256861,-181.15603,-183.673815,-82.685079,-27.107154,-20.901499,-58.799552,-57.784123,-8.843501,43.137182,49.525783,81.229971,161.894398,173.941206,150.227342,143.974458,133.207682,121.801719,133.497572,154.979481,148.344943,132.040077,132.789065,100.789024,60.529149,26.716005,46.888787,26.763334,0.956922,34.872293,68.996095,23.37333,-62.419771,-64.349162,-66.824282,-36.324814,18.045643,110.453039,114.665302,111.765215,124.016195,142.308102,92.951147,52.21928,53.36509,81.390946,60.223529,31.153719,47.069658,87.081852,76.904759,56.816254,85.347675,149.817974,118.585394,-22.072292,-70.691183,-127.263276,-184.233853,-202.299321,-149.029383,-93.976111,-37.954749,-55.15721,-176.267531,-295.359092,-293.652908,-169.887529,-85.404487,-6.684254,-53.073055,-183.044673,-189.352237,-121.647978,-101.34397,-109.502846,-72.760599,-12.546965,97.58005,101.58404,-5.525953,-161.083021,-214.78201,-245.608051,-209.7442,-68.816685,-11.335807,-26.149749,-96.822885,-184.901113,-28.470436,69.44478,129.355952,99.084076,-30.261954,-83.751498,-39.401609,23.99754,-3.223773,-43.506257,-23.376628,20.918741,28.670805,49.066433,44.089898,-29.96172,-13.237473,56.531021,189.020571,225.42689,254.45016,237.894745,130.036487,56.979032,35.010124,-13.295699,16.252902,131.867115,136.335066,48.607022,-2.090531,-75.747725,-60.657663,-20.826014,86.214655,126.03149,109.469239,66.849393,20.696975,47.701999,46.720879,31.745868,51.561472,104.857249,97.836276,7.873825,-61.829297,-188.437297,-135.782274,-44.048688,87.692707,70.441885,-91.80264,-172.325223,-252.316552,-208.105562,-145.601592,-61.810745,-65.467831,-87.462606,-85.482895,-66.818398,-60.840556,-81.270176,-150.969326,-182.72146,-160.785115,-111.606797,-35.68682,-31.740745,-73.031336,-113.305355,-110.923733,-45.035781,12.041372,95.658255,84.196061,-4.06942,-37.510302,-88.681685,-145.457788,-153.923322,-69.371631,19.288545,141.576891,140.649234,90.518305,26.224875,-34.352246,-140.206642,-101.4511,121.834962,179.340745,84.560193,14.716549,-11.203995,16.363378,2.238299,-27.635443,-13.705269,-13.132133,-69.36301,-200.465395,-156.954765,-68.043948,52.753867,48.864783,5.913499,-24.586665,-112.610331,-134.523911,-82.820408,0.276193,11.511658,51.188388,110.078092,133.533148,58.6262,-68.575352,-22.261215,33.612283,130.596116,129.859639,7.258987,-58.643805,-89.984607,-88.947124,-109.130209,-39.319345,16.345954,65.485743,35.230001,-82.935133,-99.896775,-31.241826,-20.566791,-45.378479,-49.979323,-13.645173,59.919094,48.401108,-30.944169,-33.688076,41.43904,81.521821,73.099946,48.086706,50.156787,29.08195,-9.067947,-98.21952,-170.799071,-170.782447,-61.079166,15.258793,31.794903,-49.454701,-196.462137,-209.078861:backward
0.256863,95.28027,65.783412,-54.536096,-92.520449,-44.645358,49.101801,229.42032,239.590718,233.092851,253.402847,259.687581,199.085148,132.472442,87.132494,149.401806,350.340509,436.955618,396.109575,264.527699,208.085736,87.69343,53.090546,58.370569,32.223217,38.337003,144.796849,200.74404,194.132671,146.290146,150.788792,217.419622,332.660861,314.488631,246.814368,102.503377,63.19848,9.227353,-13.046973,11.582597,152.967101,220.983815,235.021979,188.441467,67.436466,16.02226,-50.931626,-93.158335,-171.202416,-87.455162,-29.726085,-17.478236,-53.421927,-127.786422,-129.511378,-44.5205,80.192428,113.845859,37.268107,-56.102254,-229.482707,-273.418256,-256.837158,-219.106705,-148.878414,-52.471949,18.042212,99.656517,59.792526,-136.307015,-205.76066,-167.215504,5.634187,71.586042,71.089159,14.806629,-114.84714,-152.320697,-138.521424,-94.45307,-8.038319,5.905912,-10.645221,-53.634232,-66.032174,-74.758078,-73.996595,-36.660774,39.721614,37.104174,-101.230779,-169.311578,-183.021173,-162.748973,-157.744013,-186.610545,-241.392703,-169.829593,-146.474467,-200.19028,-219.04794,-135.789022,-57.745042,58.716016,157.078152,210.007713,162.831544,45.615201,-172.652572,-204.652693,-155.100626,-121.992577,-65.267908,0.133668,26.189433,37.43712,6.709673,-82.821345,-92.630597,-49.878842,-33.109593,-18.35195,44.538622,59.62544,4.649007,-42.706253,-65.208221,-50.037843,-14.694739,87.621919,109.118297,7.168657,-50.610585,-34.848653,21.426628,88.781582,137.478871,182.313211,198.580345,156.679473,16.642758,-57.655245,-124.112645,-99.689923,-2.20471,56.293453,74.900635,127.984594,126.046421,-9.103428,-79.386481,-53.141593,97.193709,141.878089,111.829757,44.810752,-123.86515,-179.093119,-167.617888,-110.756923,45.440925,168.477526,197.826432,212.408942,217.007796,255.946785,299.691313,396.558018,420.801615,411.058079,358.326279,311.446671,164.749809,72.666345,-4.739975,48.343534,187.510525,164.74428,80.274735,-146.971786,-234.132919,-281.21162,-224.860251,-27.080984,106.72786,150.421353,225.210471,249.992189,231.266211,180.34493,85.391072,88.423921,139.35418,123.534512,105.699333,106.431443,107.816521,41.429758,-3.759923,-5.564319,83.221845,115.651207,84.882096,33.603543,-49.598021,-67.247843,-74.835672,-82.547997,-105.282293,-52.309771,-49.653697,-235.274067,-357.553933,-417.470256,-355.463076,-273.717051,-314.853257,-305.117169,-235.486321,-218.208458,-206.381821,-190.685545,-157.786821,-152.68669,-133.264875,-56.622027,-22.321595,-80.225591,-177.837692,-328.422275,-311.162059,-141.329024,25.984152,60.798459,-33.516584,-140.196061,-282.454121,-261.322936,-109.243426,-60.483717,-33.447445,80.927736,137.738243,110.541655,43.859778,-24.128409,25.962375,206.295849,284.120408,273.318812,232.429293,219.287612,150.111022,92.091879,39.375002,40.905321,13.562549,22.325095,47.966524,81.694399,90.407607,121.690266,154.432081,217.865464,280.791475,318.077002,311.344319,273.371405,176.334877,114.693214,53.067274,74.926587,150.126828,153.292978,109.887356,-9.748413,-69.788678,-150.110613,-118.289154,73.869333,156.137348,122.037825,25.341404,17.69362,55.914925,45.841694,-39.398786,-69.115169,22.271565,183.601155,177.59575,27.868963,-37.146502,-48.93795,-25.473372,-69.689017,-108.170734,-35.258705,194.827856,282.372156,313.606035,261.124938,154.132875,149.135321,213.026828,285.27029,282.745881,192.725944,157.961489,125.684665,83.120944,-38.039871,-28.842235,24.627015,77.100329,37.118364,-132.373162,-198.921025,-191.648399,-145.808117,-52.638704,-6.170917,-40.705386,-152.840713,-169.091646,-136.670258,-128.591275,-159.434861,-176.262993,-150.85436,-83.867722,-57.575102,-18.343148,-24.764746,-78.303099,-101.641298,-81.46626,46.522989,91.151477,121.045924,131.155104,113.095418,97.325502,139.813638,220.056448,225.458344,169.018424,139.720888,109.046695,94.233334,91.259755,128.916081,289.128788,410.16829,381.354488,248.945263,203.54549,102.014549,51.841402,72.418882,164.522995,184.767632,199.541705,202.190603,158.771695,122.726,99.726875,101.472657,85.225364,130.303319,165.531764,117.324406,18.869917,-165.103303,-182.848745,-130.383421,-101.084649,-89.9734,-65.301347,-66.540219,-137.99684,-193.484087,-224.151443,-194.303647,-124.135109,-46.215386,-6.745115,28.263587,-7.650681,-116.154985,-122.864788,-93.939953,-158.611149,-187.641463,-120.455348,-53.880632,-11.050309,-35.844142,-50.01014,-31.970989:-103.45596,-17.503272,-3.89712,-19.543537,-11.751848,75.933957,132.676746,182.897402,173.885586,173.640143,147.839906,124.025682,97.816764,100.503011,165.387376,224.728114,322.103314,351.94233,333.23525,209.09751,136.739718,119.382406,172.244232,243.608503,218.264684,202.711432,224.57593,260.179772,321.886455,337.78962,345.101221,325.14296,297.934874,332.667275,315.739901,224.846212,186.694453,138.089918,125.965398,116.357374,185.207903,263.260428,342.99532,291.248277,112.650354,63.350671,57.414869,29.747284,-124.682189,-149.423275,-101.973069,-105.688758,-172.883544,-249.259012,-210.754491,-107.612966,-54.005252,-29.189362,-74.032871,-150.592498,-293.890778,-326.808387,-320.885067,-291.235606,-185.657005,-110.1526,-104.586845,-106.572664,-111.600319,-160.403166,-190.437312,-183.250931,-80.855002,-43.028357,-63.052225,-100.335723,-210.306057,-277.708793,-299.92399,-232.294405,-84.362006,-83.842517,-123.462942,-173.797042,-189.317115,-244.424501,-243.842521,-88.331025,93.102311,85.523719,-98.133521,-177.087381,-189.441475,-147.847805,-90.01911,-102.210485,-123.400272,-54.528712,-25.846561,-63.567485,-105.481857,-109.965843,-62.961669,76.000586,206.825284,227.290049,121.649281,28.64733,-117.818804,-147.180121,-132.354075,-116.51693,-57.504221,22.686543,15.376038,-75.614594,-110.976827,-94.276487,-52.681354,9.8995,-12.570211,-28.418607,-49.984225,-77.551311,-183.990388,-219.424745,-164.491169,-113.81709,-58.088989,-51.599154,-73.055519,-149.06507,-174.729589,-126.693626,-65.097689,1.514865,41.798686,82.561841,116.281192,94.655366,-31.013142,-119.171463,-197.251813,-161.485464,-78.628757,-56.14459,-24.760021,16.563137,-23.264485,-122.347066,-102.754789,25.366532,99.643111,135.357115,226.788822,231.86262,85.026372,-9.305505,-57.280515,-15.721766,97.164536,204.533842,249.393337,273.838589,245.505331,226.260186,270.29023,360.437941,360.017831,350.413008,275.464084,171.547825,-102.07147,-192.726065,-199.291048,-138.026053,49.859729,119.457094,27.276266,-269.812609,-375.423927,-406.862767,-341.873708,-150.961754,38.455388,126.140793,239.568083,237.37236,126.653568,65.889567,23.706412,37.032733,85.414597,126.250306,116.468391,34.698822,-21.037521,-125.57077,-155.867273,-158.224534,-42.374031,45.167667,96.790025,28.333988,-173.890958,-250.961573,-240.734375,-146.832206,39.730411,25.533202,-51.377937,-240.685651,-312.35971,-336.992153,-300.049005,-229.825354,-195.76557,-193.289284,-226.596226,-241.990551,-249.089718,-243.64556,-212.465456,-189.360856,-100.548396,-5.106758,-6.096027,-80.724423,-105.965344,-88.715368,-57.88916,-0.348928,34.144511,46.563235,26.002219,-18.358384,-102.762983,-93.60376,26.358184,72.488183,64.841832,72.203325,91.699839,86.422991,56.196793,-5.456594,-2.059161,127.908209,320.10094,364.457233,333.761616,291.818104,145.67761,53.978447,5.086184,65.071451,194.018035,175.256632,101.044577,-70.729232,-101.82203,-24.391599,45.026518,152.666419,169.769759,174.253268,185.338732,165.434271,45.888195,-4.961334,101.11517,226.95327,346.590166,190.109605,76.445095,-34.935862,-33.048591,-43.583572,-58.816015,-17.130129,67.084571,66.923284,17.430965,10.209956,27.159745,40.742808,75.313434,87.291682,151.439038,248.28764,228.321521,68.8781,16.054941,30.88072,26.513503,-98.029335,-107.72702,-29.638901,122.08466,159.465752,159.801231,135.621227,110.369186,118.625851,175.566219,251.515153,252.580488,210.070268,195.827928,145.024991,102.630935,61.063597,149.666568,199.945758,159.701789,76.809707,-66.336725,-77.699017,5.759286,44.424939,24.548576,-39.569577,-45.934098,-38.18462,-56.708732,-113.671977,-110.764165,-53.801488,-10.936793,5.555555,35.531005,52.160875,77.913122,88.57532,89.324366,61.785627,23.966099,93.039602,119.646018,111.227608,112.080645,156.770621,175.919527,188.735186,232.434236,255.455762,226.448381,183.358759,152.355516,186.79368,278.910446,304.20607,342.611046,381.355582,361.291014,256.363998,217.494967,184.447829,172.357003,181.041172,268.723672,306.814244,269.167982,230.74713,230.931958,236.396711,159.648819,107.422226,104.770413,161.033522,140.872311,14.255402,-35.650821,-37.695118,-22.733144,-35.825074,-54.527516,-42.868736,-25.084182,-43.527481,-133.274955,-162.749674,-114.823475,-85.357381,-87.028434,-68.695568,-58.970088,-90.24215,-133.73671,-212.876627,-222.772326,-191.890471,-84.831952,-19.398357,57.143625,56.785846,16.322733,5.721442,41.594663,77.071568:-98.032856,81.767793,120.061244,46.523382,-0.641822,-1.572514,43.775593,156.823013,225.430175,235.114899,191.182649,148.141397,65.484549,46.059715,108.352067,174.550127,270.991669,268.070228,220.762749,63.288163,-8.10464,-79.287497,-76.994357,1.46527,152.012881,223.48904,281.424771,271.861648,221.562014,193.555689,158.982386,163.041173,241.015669,329.521256,317.346904,177.182905,102.089297,52.397149,61.56521,75.815332,173.315173,241.403451,239.171698,173.836021,56.738834,33.447047,30.904396,22.921897,-24.417174,-56.271198,-68.74426,-111.631468,-135.702584,-208.101558,-256.949809,-294.813115,-171.443058,-106.295085,-126.769366,-205.598723,-376.023508,-420.192315,-400.519408,-350.156453,-203.740696,-115.935595,-125.525277,-223.552917,-281.921066,-323.997663,-294.760753,-219.666339,-192.62252,-178.549386,-155.458098,-172.944162,-284.511338,-327.639678,-277.009511,-219.547596,-163.775721,-181.14934,-208.478525,-293.17929,-336.261589,-364.026461,-325.876856,-153.751183,15.542452,16.020485,-156.753757,-224.219071,-176.002452,-99.698652,-5.131374,-10.525387,-4.797065,47.851757,43.575813,0.10821,-3.803841,49.27164,86.260306,148.814339,241.434427,265.506162,167.696516,74.702436,-74.080179,-108.646368,-108.489824,-80.970011,-25.661376,-20.452365,-1.198421,42.276994,26.142293,-8.910424,7.886501,41.570509,-14.115621,-48.346579,-77.715279,-93.690076,-148.88989,-159.260397,-129.014874,-134.784049,-167.714311,-101.6741,-79.662393,-103.115404,-116.095079,-85.391436,-39.484158,53.113581,99.297708,94.312359,48.019962,28.786737,-34.973708,-89.94043,-178.689711,-186.605623,-108.083022,-23.359361,-48.166843,-164.120738,-202.25246,-217.092914,-178.440642,25.825162,226.916969,258.570414,218.155522,172.91475,60.700202,29.999259,63.021812,77.260618,39.625977,29.326953,50.495064,81.577182,75.390003,99.917267,154.484922,240.24944,254.978384,270.828914,252.071265,165.010471,-114.943681,-213.436438,-195.132303,-122.211017,-23.047633,-52.787841,-104.299817,-244.641733,-308.332843,-356.11385,-333.833543,-190.88749,70.125712,177.956825,219.384259,181.742313,106.967581,91.473431,117.601446,148.416815,200.53042,176.352526,139.539947,69.201438,8.408177,-153.471046,-174.421584,-72.227474,54.361787,98.503686,51.641287,-37.093986,-183.878965,-205.542113,-163.126971,-96.571858,95.741691,157.228173,110.042498,-11.924138,-57.033148,-104.997124,-88.948395,5.094757,17.609514,-40.815066,-181.085914,-212.767547,-206.66951,-180.442036,-98.492968,-56.42994,66.261426,157.686398,126.366238,-2.104766,-20.004929,50.733097,80.937548,105.897126,202.85822,235.332944,130.452251,31.869607,-109.304235,-127.523339,-70.417821,-27.705326,70.993986,176.940898,165.161395,23.035982,-29.615881,-56.954734,-51.476189,43.412765,156.666781,152.905894,103.523621,104.743158,87.414688,56.766479,50.300637,76.186115,114.893417,63.199177,-0.752683,-104.722322,-100.432915,-9.550327,22.190653,1.009078,34.479846,94.506764,153.289523,124.178688,24.655196,-0.85606,28.313025,68.754611,185.705437,220.774188,162.012067,37.088608,21.924071,-3.261352,-30.786907,2.558369,109.820807,111.765066,21.527397,-19.77581,-55.731451,-52.03618,-5.101501,23.261851,111.240389,200.983534,190.232288,70.418422,17.330246,28.77681,64.869581,42.079471,-69.997683,-80.142861,52.837298,126.931701,99.075106,35.764724,-5.79807,18.145017,156.798241,376.069662,416.608382,291.935728,187.862008,33.423074,-9.282691,-46.244072,36.337324,93.518639,82.477775,26.572055,-29.216063,-4.105899,84.402549,103.091018,74.005546,47.082312,35.827204,-6.85986,-34.34404,-68.733307,-44.946579,83.775041,188.613369,194.606021,102.060392,46.10521,32.156042,58.571034,88.004113,91.329371,117.240575,91.893985,44.228944,-1.898344,29.312923,135.45703,154.86553,98.427712,119.415442,157.204734,125.09507,68.508673,12.044517,28.74305,126.564884,189.876548,264.325426,232.36085,221.743594,249.833011,242.882617,162.934682,136.139609,171.284593,254.432518,273.992934,236.957136,196.016806,117.59931,96.071423,72.495412,52.882749,42.708068,121.25712,140.481777,14.481818,-77.975899,-91.20912,-20.407738,100.799078,122.584661,103.897524,16.050388,-37.859097,-115.974411,-123.574755,-88.5543,-82.60723,-80.528059,-47.511512,-44.007182,-68.23065,-102.808555,-206.031589,-238.587696,-199.801391,-54.797452,6.983062,49.724287,45.712365,20.598298,2.217259,-5.771833,23.927802:51.55226,177.88922,177.416264,51.230576,-22.846885,-60.774543,-3.04327,189.986434,323.156776,347.26839,293.136634,238.35362,137.8889,92.087237,118.22395,208.374381,369.004132,370.337465,294.390505,51.986225,-29.993729,-24.620926,17.16052,61.16337,80.067535,84.060253,72.270293,88.23602,166.892749,198.469472,236.591772,248.02996,280.909565,295.339287,245.726205,95.386276,53.517323,71.428405,86.562083,69.536715,192.658595,308.065708,384.89353,307.758557,89.200984,18.789142,-38.045945,-54.181959,-64.683172,-70.038467,-75.375889,-68.63186,-93.674837,-233.534918,-280.735847,-215.826143,-39.209646,-0.779174,-140.555534,-252.168486,-361.464802,-374.388121,-393.039626,-383.529355,-304.539249,-216.505384,-199.983286,-219.698704,-259.069606,-373.977748,-388.941099,-286.578866,-152.203442,-113.860224,-150.844414,-208.337369,-295.18697,-309.254902,-271.717822,-214.064678,-65.446081,-42.456051,-129.226976,-371.41228,-428.264667,-341.586279,-243.19057,-33.009709,102.950091,103.498496,-6.032944,-60.068187,-83.293225,-70.210871,-72.336168,-99.542829,-106.03701,17.42199,61.545289,40.969282,24.009103,75.086517,120.753765,175.08774,171.574794,175.12705,168.603442,111.395886,-72.336306,-125.858434,-98.811721,-71.612715,-49.514304,35.015034,79.951187,30.419131,-41.323854,-108.898658,-93.54347,-54.368405,-36.061393,-24.914207,-45.180791,-88.106961,-180.261172,-195.35993,-130.405431,-77.211705,0.443135,44.652732,47.689731,0.686216,-42.858925,-117.508829,-118.468132,-48.829817,100.39234,179.349705,207.412631,148.241888,-20.745472,-93.583313,-123.344362,-72.851657,52.58267,85.802119,67.176903,14.407804,-19.219278,-104.113537,-119.202876,-27.391887,132.71462,200.464304,242.596557,187.523221,-8.800987,-78.061771,-70.598246,-18.008046,75.856151,82.08007,77.67258,126.561999,144.445324,72.869546,44.538338,142.044489,260.603053,265.586815,201.196781,154.312147,22.872935,-69.582422,-185.426378,-140.723193,84.971229,135.588871,32.059593,-215.596606,-261.572707,-193.417885,-126.568012,7.952746,167.975422,240.733993,324.293197,359.271291,404.601009,369.125727,221.73266,183.918849,220.002918,264.950148,249.171229,129.86533,57.200065,-12.443789,-2.202585,64.756533,143.293397,165.205848,144.303898,106.251461,3.163265,-33.675989,-36.389851,-18.328391,42.681783,87.232442,48.170473,-110.123475,-171.127085,-231.2736,-223.611887,-122.203744,-66.569602,-101.01056,-179.72909,-167.686217,-132.327791,-152.255258,-153.535383,-105.452668,2.198874,44.00559,34.857889,-23.411546,-68.102906,-134.913032,-121.77159,-23.237865,70.927996,95.981036,49.076515,-31.842452,-184.405018,-178.183272,-36.416419,0.480593,-19.831082,41.4988,80.289083,37.682858,-37.03125,-135.38042,-98.168334,111.296267,254.41752,237.899625,127.50886,107.445235,79.842196,27.004776,-29.774347,0.451185,40.367626,-17.959677,-42.591833,-25.376675,7.914948,60.145601,65.591755,63.230498,137.812954,188.904241,199.82505,170.411221,106.806038,78.470202,73.295411,105.912002,211.996307,240.71024,179.814418,10.765824,-48.958953,-103.428025,-79.867466,43.906511,116.258802,115.118488,40.645886,-16.984358,-104.770078,-121.597299,-119.293133,-116.312275,-66.629152,76.604945,103.521228,4.053075,-48.005823,-46.578863,-42.3343,-121.591406,-124.047511,-73.676552,9.790592,33.204397,39.539701,7.739643,-85.698491,-105.306318,-38.366309,107.188728,149.181704,96.875288,29.382734,-83.216837,-115.941136,-137.816396,-86.88406,-44.689674,-9.177471,-35.457409,-138.548032,-174.352981,-121.419412,-50.092338,33.93373,-33.12445,-85.891754,-117.498509,-88.009081,-22.708668,-6.349827,21.958197,49.814057,54.167708,37.883643,35.337105,91.431093,125.548045,120.021784,81.32627,18.871047,39.547715,54.766589,97.033043,122.954571,122.470515,115.174724,176.997619,275.536303,277.238263,142.301796,68.264452,42.321096,66.94381,130.986893,172.78713,273.037466,355.701991,363.068578,296.993125,221.874327,21.50363,-25.1642,82.456204,192.733113,197.940546,168.955269,139.308562,50.724807,14.3826,9.255134,28.442759,63.066523,107.190609,117.409824,23.709892,-69.893036,-167.709094,-128.942403,20.722045,104.470763,93.958915,5.850795,-36.934478,-98.65468,-114.729555,-68.712711,-34.598874,-32.34236,3.544946,54.518011,75.850299,8.457806,-140.770638,-153.676856,-94.733464,-47.969531,-33.711667,-0.276521,11.806627,-35.807536,-85.659811,-94.352138,-47.734423:66.820208,178.14858,158.089426,-5.432142,-64.227086,-42.632934,7.05555,133.432625,271.743078,307.287907,273.03078,238.141242,189.291487,163.46589,147.958192,179.046076,288.241943,353.405883,315.066522,99.120801,-22.830062,-122.350741,-83.218361,36.754462,148.717861,193.885865,172.252068,136.82614,156.726243,205.816966,264.988804,242.227532,189.214424,250.84818,249.744134,96.766505,19.817678,17.104998,49.58595,67.364992,184.230491,273.615811,275.767259,187.406974,29.218683,-7.861206,-44.559534,-60.161923,-48.509562,-3.88987,-5.96006,-91.165868,-175.669825,-315.394749,-306.465807,-155.849347,-38.069062,-49.802219,-164.238345,-226.692432,-358.004792,-422.411938,-502.127193,-489.081012,-336.97248,-204.954209,-202.021709,-315.817323,-401.731442,-453.221593,-371.756486,-146.497377,-79.797985,-101.955301,-183.955869,-233.231861,-335.871896,-358.547059,-254.580603,-144.485582,22.540479,-20.741181,-106.718579,-321.729189,-412.021547,-419.22643,-319.810268,-47.713985,145.617043,146.737148,-39.43205,-116.028156,-68.167686,-6.655054,18.279315,-4.504614,9.640299,106.010802,116.179454,-8.366297,-81.040475,-30.47539,68.825618,187.858852,236.020066,246.620701,135.171287,35.861558,-145.825076,-200.959841,-202.811983,-176.214398,-101.597527,-38.31591,-39.207548,-82.226002,-118.563685,-164.226949,-130.047801,17.861007,89.365494,70.645102,-26.994244,-83.729933,-168.16588,-164.662395,-80.727149,-44.773452,7.233451,33.827364,11.461383,-86.22748,-140.731506,-168.588346,-114.247901,60.374701,198.549548,227.262152,186.107585,130.001566,2.064457,-53.264043,-103.050692,-70.878813,80.381297,117.801905,51.722714,-116.230069,-170.17773,-195.163049,-152.823063,5.037571,117.029756,144.273705,146.035024,107.49324,-21.243691,-73.121702,-84.275296,-57.247171,4.175675,38.478639,19.829455,-50.089401,-70.235749,-68.911612,-57.203293,-0.417785,135.319688,168.928013,48.544239,-64.064803,-285.774703,-359.370778,-312.235445,-208.675616,-12.950408,-1.35893,-71.030876,-221.409925,-255.890017,-240.219405,-193.895644,-28.287956,178.373227,246.586689,281.505176,283.192543,282.572281,275.985991,244.385083,226.296076,261.787721,335.978215,317.495515,165.590827,72.981453,-34.409141,-25.486148,52.493845,139.601095,182.532149,200.12411,161.767672,53.750241,28.717608,41.769779,54.573379,143.744595,263.005439,238.115293,47.927003,-32.917041,-84.581991,-66.236174,32.582531,100.666157,58.934568,-116.905448,-174.138635,-217.086951,-221.224789,-125.919631,-37.534167,104.125239,168.230504,159.952492,47.166734,-17.919088,-14.706663,54.831588,197.393929,302.995501,308.741667,127.189303,-18.761166,-191.347905,-168.114698,-24.374055,17.177758,48.639164,76.886818,55.340513,-42.036679,-89.312654,-147.037353,-123.141791,55.696214,219.63926,235.713289,143.103618,77.436845,-19.16727,-56.714883,-61.55665,-4.747346,121.024163,85.056439,27.15505,-51.898442,-61.398562,-5.299729,50.871787,116.005256,107.929273,105.330194,107.738032,107.146426,79.094963,62.059293,106.58129,163.761485,283.545408,360.771287,340.385509,191.031551,101.279928,-21.703164,-19.754053,82.463514,172.274109,179.769327,79.814323,-9.011754,-153.594792,-170.972324,-116.055092,-74.997421,30.550676,50.661137,-15.328924,-152.610887,-174.611874,-140.223325,-104.031006,-30.393766,36.015935,37.067451,-45.033333,-76.200637,-78.577662,-91.434938,-155.250811,-167.521669,-63.103702,112.759703,134.792075,29.436411,-44.971031,-148.565556,-173.565316,-194.620089,-153.318002,-123.607166,-151.124534,-211.577882,-280.989813,-232.948421,-31.472946,39.7519,19.775218,-88.639701,-137.685895,-211.594859,-218.413105,-159.187607,-116.327223,-46.744089,32.315636,49.222083,-19.642943,-72.114443,-106.139499,-85.987188,-36.311129,-12.99342,81.323197,154.099983,125.563078,32.64062,17.8214,52.049521,102.661007,240.61213,277.659271,241.284061,132.51964,78.979621,-9.200947,-22.747498,81.068543,173.803948,320.829595,391.357443,400.281178,354.647745,290.955346,155.35641,144.410089,233.125668,309.43962,319.15642,258.320606,195.796121,79.137868,54.331147,64.163821,65.746691,107.914652,245.877,256.961955,53.302037,-77.377011,-93.830122,17.26379,188.4271,204.017102,200.480268,162.956914,113.465372,-30.326867,-92.80921,-110.002751,-74.367051,-18.282945,-4.720646,-7.505111,-62.892287,-122.737492,-215.140255,-207.733758,-120.411625,-24.745129,-0.256832,19.731506,31.739404,-1.516811,-44.468907,-73.242113,-58.929456:148.666113,237.965366,186.439692,-18.475874,-89.34981,-64.706262,29.363171,226.561749,249.634895,238.40902,237.455055,229.870893,151.142907,88.057822,21.520644,37.749448,121.802186,163.628809,121.759251,-18.918165,-68.323178,-122.919021,-125.724102,-92.618375,-81.060032,-81.423295,-81.483094,-76.272778,-25.349261,20.407807,116.443985,156.284647,247.294837,322.441459,278.350748,21.913842,-90.293515,-115.576471,-66.419464,16.097629,116.646269,183.969811,235.000215,207.321724,120.420498,65.58867,-43.295293,-65.441298,7.44154,117.361424,96.206466,-43.072956,-86.265376,-79.906085,-40.225817,71.493854,137.833665,127.11469,4.616334,-67.167945,-158.358768,-201.604137,-286.006597,-286.843232,-185.282603,-50.975949,-13.149031,-61.891801,-131.7061,-258.811976,-281.500953,-217.811499,-108.741818,-78.442521,-63.291813,-78.243193,-159.364989,-192.773731,-164.302898,-108.919071,43.706772,124.413983,58.212517,-210.31627,-279.622006,-182.154488,-92.879832,6.584627,-17.620548,-46.862938,-107.402459,-129.938436,-151.846806,-159.809664,-182.297968,-213.140202,-244.750737,-158.033201,-121.936803,-97.664837,-96.146909,-84.569855,-48.353034,78.994547,153.777608,162.459858,99.939025,14.968925,-151.517466,-172.345537,-95.364396,-44.919262,28.568094,47.365233,25.957252,-13.494573,-14.173979,-16.594786,-20.722873,28.937317,146.906346,169.727435,68.696903,-4.700239,-80.751662,-96.157855,-90.086932,-63.089973,-12.038763,44.187065,64.293257,7.703323,-44.67771,-94.39911,-90.777089,-33.380734,124.301365,192.233143,167.9529,102.449807,-12.356671,-62.367325,-128.473754,-121.286726,-30.808206,64.380593,73.461603,45.63448,45.817052,72.287811,77.53946,85.922494,172.281775,232.8103,214.805809,114.141984,-124.751714,-191.427476,-139.989846,-54.748297,87.942172,174.086392,215.769442,268.755292,256.989216,189.880551,180.015758,223.808541,287.13176,319.438388,325.129384,278.225216,120.182451,32.94381,-64.993221,-39.282322,125.617138,229.326341,182.043298,-23.433643,-101.91682,-135.396835,-92.732261,60.927925,194.246395,232.586261,274.390188,285.354979,267.606573,253.672572,276.083203,288.652087,252.278854,197.450953,183.470635,185.736126,185.619438,115.95571,60.470696,38.311864,129.66285,148.475961,47.043789,-25.833372,-45.978238,-6.976847,19.245407,4.3297,27.218101,117.471024,122.224908,-50.672346,-189.644856,-367.294612,-351.266663,-191.862714,-115.022251,-117.985417,-146.128447,-183.477379,-295.208698,-319.15664,-259.697692,-211.606974,-102.79913,-0.683389,-6.534181,-145.677788,-234.975685,-369.721557,-374.738205,-259.814091,-169.181655,-167.538822,-224.213172,-266.401805,-328.592038,-312.292945,-197.83156,-156.534013,-115.963049,-3.730894,50.802411,37.848272,-13.245015,-80.198929,-66.936242,45.083675,159.665154,164.717424,76.540824,41.652197,34.323536,22.097593,0.065278,13.348146,53.7906,92.211964,98.006636,85.896521,81.555393,54.934771,41.834722,105.474,257.463007,312.44487,285.375419,217.299488,100.649863,71.262258,56.438485,69.988826,126.09401,181.000899,192.609301,96.739273,-23.400678,-182.062366,-128.273525,69.387773,71.95805,44.547119,7.067175,-37.155815,-157.130469,-197.154533,-214.772542,-203.303358,-129.078942,20.155696,48.4133,-59.251718,-126.737387,-133.184564,-83.683962,5.108571,78.963347,111.046101,97.643173,68.948083,8.279557,-45.007251,-133.049145,-107.196503,53.286338,130.622332,92.243363,-53.801476,-111.845425,-188.175372,-220.951256,-258.600302,-232.332091,-195.482152,-156.269061,-189.049799,-280.542805,-278.790426,-144.703224,-64.080875,5.390283,-20.016891,-67.674822,-222.271172,-272.674336,-186.417524,-80.743671,22.116864,-57.857476,-81.447502,-49.373443,-31.854207,-53.056043,-87.925982,-139.899268,-132.906432,-53.152927,51.64954,50.042323,-36.586961,-45.782798,17.91551,52.912949,120.341961,175.108754,163.002531,35.886332,-28.326145,-53.661022,-40.35743,16.228754,71.757593,198.71122,257.385453,227.944503,117.952636,79.869652,33.291966,35.250249,110.544292,146.968428,125.401275,-11.573532,-106.7186,-188.178913,-139.667271,6.378556,39.903013,81.629639,190.258484,210.11124,79.920147,-26.535916,-129.901422,-107.498662,-27.005388,20.712707,43.136642,41.658992,1.71959,-81.632737,-90.426711,-64.612312,-63.217356,-64.560162,1.367885,39.025533,82.626991,66.015988,-49.250101,-84.001716,-39.993445,-13.984477,-40.24373,-77.150647,-43.949616,45.291005,34.609775,-31.266069,-41.335442:210.96766,308.567258,284.538963,65.442215,-73.661747,-172.697787,-85.508732,217.203856,418.467229,435.152576,323.7425,242.448817,95.203022,31.152081,11.286302,74.642718,234.066413,254.788104,184.50807,5.103795,-47.867751,-63.198769,-32.520139,67.696657,156.577713,174.049271,126.941093,87.150809,8.51265,-6.613809,98.25712,179.796625,279.648948,320.297181,298.922554,138.99305,34.009629,-66.59137,-35.466691,118.898611,318.188939,359.409034,243.744918,150.746159,-4.020618,-60.592563,-79.85709,-33.556933,116.212919,154.636808,92.498157,-102.856707,-204.567314,-307.600153,-256.794901,-42.479745,85.610036,78.937599,-57.312926,-142.559321,-287.673252,-353.573146,-401.631325,-353.475856,-178.888884,-93.297092,-117.871733,-229.658599,-301.49026,-425.691976,-412.058358,-225.994974,-60.684662,-38.867596,-150.813225,-257.753205,-417.2993,-407.16456,-179.6955,-24.573024,171.65834,119.893544,18.333523,-213.11698,-295.469619,-325.771435,-252.344204,11.642861,169.532732,166.173184,76.202963,18.948333,-86.347078,-111.310716,-96.977892,-86.728275,-37.282978,72.280619,98.584923,23.931219,-51.938977,-111.693603,-53.976452,147.288178,293.302156,307.03219,136.692275,-24.622642,-303.564589,-367.995562,-332.110112,-251.796477,-49.201968,74.840264,66.331092,-52.382069,-130.370812,-211.634505,-168.101897,19.462103,127.918181,129.584156,40.264605,-44.232186,-201.727999,-225.049098,-134.862627,-59.180788,91.099003,205.825432,200.038711,35.638644,-68.512743,-139.429199,-89.80753,75.900299,245.425106,300.720523,245.57994,154.440936,-14.392811,-60.98039,-25.250703,53.411933,227.374644,252.477658,193.952723,51.144562,-10.497783,-102.626658,-90.530978,104.5647,304.583725,320.539878,214.525503,132.511976,-66.040384,-154.582249,-163.385085,-75.962374,115.425014,126.369659,80.710709,-0.087381,-39.132088,-132.790628,-144.140175,-7.457484,205.304724,235.922917,92.181004,-22.781652,-221.631307,-279.714385,-241.420739,-147.935297,90.6765,202.841732,138.129104,-139.471361,-250.597052,-287.344058,-214.670339,40.454005,296.719016,369.480354,375.095593,344.468307,292.740836,276.224862,269.433065,281.06739,330.575312,363.683497,348.59329,241.213419,163.269192,47.138249,42.285002,138.363726,273.978273,294.097587,165.803276,60.854739,-93.51339,-106.044424,-5.475449,47.720891,130.389571,207.649343,175.325931,-28.223332,-138.698612,-283.435285,-266.446809,-46.732973,112.332094,102.940435,1.973328,-52.087504,-178.285066,-229.000398,-180.298041,-89.065255,78.408736,81.500024,20.263706,-119.120392,-177.63365,-235.784015,-187.943525,35.124996,160.757662,149.458832,42.237349,-41.222084,-204.988485,-227.726953,-132.148267,-74.756446,-12.590646,48.458532,60.406535,6.087085,-58.202766,-216.0465,-218.659246,45.956364,313.87401,317.291381,142.352562,54.101416,-53.987012,-73.302154,2.246813,67.456442,140.192965,133.496507,99.848513,-2.44059,-49.749995,-58.581854,0.680945,172.171302,262.41468,261.82559,204.226921,160.028335,57.237318,8.156772,-29.83974,1.987621,169.234099,297.021988,248.370074,-34.675324,-166.035411,-201.957049,-102.898127,117.217521,170.369111,148.370501,24.785287,-73.435283,-253.613807,-278.593292,-193.994165,-140.857942,-29.591758,61.636444,35.936667,-158.152535,-263.652603,-304.145929,-215.381489,10.900657,70.395196,35.107714,-58.437089,-77.518662,-95.679496,-136.065117,-212.742628,-196.909429,-68.152612,60.924224,59.189243,-99.879408,-191.290827,-277.095636,-284.28581,-253.2142,-134.212088,-90.829859,-174.090495,-276.898407,-391.574923,-348.556046,-134.483575,-35.040661,52.677645,-4.910387,-76.332172,-229.29818,-274.833116,-217.961721,-119.465227,50.257177,43.997852,17.721269,-1.555277,-27.462503,-119.518961,-135.663086,-62.187866,-4.969831,64.1028,77.587926,70.668429,16.078982,-13.1128,24.773405,101.931525,246.613119,276.009978,261.138325,116.532444,-15.448446,-205.899572,-198.746637,-40.367355,59.810841,259.477324,355.138758,321.903223,174.757435,97.352944,-24.10165,-22.178892,150.691304,307.200935,301.106358,137.953667,39.601439,-61.456304,-57.169755,29.966063,95.290101,239.396123,303.958162,248.131685,-1.864413,-106.641915,-89.645535,12.07832,193.281833,253.646593,251.594462,141.09347,53.867975,-62.35798,-75.504753,-35.993704,-7.640756,37.660571,84.604931,85.60536,-10.44598,-86.504071,-161.882941,-131.616786,-24.285083,49.022756,52.846457,-42.445549,-98.236878,-132.222129,-127.376137,-119.076008,-116.377981:138.210093,74.226072,0.616621,-110.537988,-135.195821,-156.262886,-134.333376,-29.161496,85.05229,130.230181,141.074249,103.925169,-3.993677,-59.086494,-122.162182,-109.782569,-17.635781,66.19194,75.070198,22.033368,-34.4153,-158.358737,-181.066704,-137.47588,-129.535988,-159.415089,-189.152251,-157.588907,-111.443589,-143.728941,-171.946937,-117.316923,35.297294,123.47019,98.168383,-62.241962,-136.601341,-182.055668,-147.569356,-48.445275,2.039162,18.396297,42.23692,37.395686,-46.517962,-110.494976,-153.528029,-119.694669,-18.873653,-5.954772,-69.979917,-202.232095,-213.894943,-171.38611,-124.64072,37.398015,175.922589,211.968078,212.364795,187.446916,142.408488,117.851498,42.847595,-1.764788,-30.997406,100.440874,170.458917,156.551753,92.735371,7.28659,5.806816,33.565065,53.279677,70.505283,136.048713,176.615649,226.887069,225.000491,238.112014,275.075569,320.532194,259.570749,209.972197,122.554282,103.491701,112.614569,136.095267,172.137118,116.163605,75.984998,8.055273,-3.813557,22.475447,14.659859,-73.837744,-120.75255,-155.64792,-58.80314,1.768209,44.665773,45.93335,55.518917,67.846245,137.281206,284.878002,358.495232,328.858588,217.078916,4.508181,-37.775188,-0.769852,57.828046,196.949265,252.062345,239.18944,179.64577,137.959157,46.993395,22.975083,60.534454,90.890547,73.482082,40.590061,41.05665,54.315504,49.238598,9.612144,-9.196796,-7.556906,50.247309,67.17709,0.584121,-58.104263,-80.336818,-37.89688,22.833326,18.12258,24.743738,12.682922,-30.396374,-138.969384,-178.244204,-218.267552,-226.192068,-195.576942,-35.406479,47.988091,133.044194,146.324274,136.291058,144.947547,231.347141,313.812943,339.156108,331.220246,285.939739,138.240258,55.639581,-3.388302,55.127816,191.291091,168.610367,158.458628,217.38302,236.468139,218.216939,231.555247,307.212275,316.359985,296.112322,260.511459,254.829676,189.286855,89.414854,-102.773201,-100.170747,37.440688,118.809368,126.586732,60.063571,-20.356597,-152.866182,-146.45281,-41.213252,35.259386,66.680828,113.462728,114.693005,92.019242,90.704564,122.904122,129.251027,122.916911,164.267484,166.150193,108.343985,94.125618,97.691833,75.128312,-30.507723,-55.632755,-16.647773,19.25479,5.064551,-14.722278,-36.021205,-102.464336,-87.881748,105.103469,252.983935,205.459097,-48.151126,-154.137501,-187.162053,-143.975395,-64.910751,-37.479208,-40.378412,-53.664053,-48.042708,-19.348268,-13.409037,-5.715802,3.896984,21.856331,37.366829,6.815135,-166.433331,-271.893547,-434.302847,-463.117121,-398.125518,-269.047954,-227.207476,-269.239985,-337.551985,-420.417809,-410.666082,-346.507778,-308.250483,-188.907973,-40.721495,-7.95684,-24.122042,-52.099823,-134.644347,-155.38145,-100.006377,-99.056511,-143.894196,-150.816383,-91.175448,4.615853,-10.823251,-94.192622,-99.151656,-27.409792,73.236307,107.675071,101.741181,69.993423,-28.761979,-70.569923,-10.274953,233.469361,328.900724,305.629552,210.227235,18.083142,-33.33425,-21.996951,10.822072,73.602383,176.933273,217.593045,172.822921,94.051612,-38.046453,-35.673677,67.515027,103.591532,83.431928,25.009601,-20.080378,-158.985607,-221.433319,-219.388158,-164.553683,-29.3097,81.401734,92.051831,55.297154,35.286195,22.659794,35.846697,53.062022,99.727516,166.576822,237.171068,189.439657,-18.225371,-117.206331,-159.895966,-125.695521,-133.232592,-217.930031,-234.870272,-242.298505,-253.349332,-278.274584,-285.150348,-286.809523,-283.081403,-301.615249,-354.843757,-359.572589,-335.410047,-324.036662,-264.911267,-201.865057,-71.906507,-46.925588,-94.669617,-224.686585,-240.909606,-108.895361,3.835731,82.611124,-126.217871,-200.364666,-134.624241,-72.324092,-73.806026,-124.986483,-192.283295,-183.412207,-109.252389,-17.711551,-2.291635,-28.194878,-46.596857,-53.077991,-14.050911,86.577394,56.750426,13.648334,-41.593336,-46.259575,-47.051703,-72.20074,-124.300742,-95.646411,64.25054,145.986049,109.414063,-27.992849,-77.529801,-93.942198,-60.037526,15.602441,-16.011908,-58.143194,-174.089047,-237.807546,-243.978105,-174.287898,-47.890637,-19.455699,14.99341,26.000628,21.214913,-29.129342,-81.677829,-158.567901,-136.247976,-48.20856,-54.576342,-63.047307,-80.579861,-113.529518,-179.287115,-180.747427,-133.879199,-116.75487,-112.871578,-137.016802,-171.683766,-208.0499,-212.890277,-255.334458,-249.474667,-150.911436,-129.186363,-159.059562,-197.577889,-171.355737,-80.449038,-87.912003,-175.691253,-176.943064:190.788553,175.571459,141.041987,38.023788,-4.2688,-9.294171,37.958512,153.396451,159.265169,132.037974,110.619187,124.962335,115.386666,75.590527,17.977887,17.866776,89.349733,228.151657,255.821308,184.639812,108.854118,-58.966645,-121.995815,-197.875022,-188.079116,-132.019636,-35.590926,-33.138525,-102.540415,-135.125445,-56.756204,35.581414,127.682645,102.658879,97.802928,73.604729,33.511876,-36.440827,-36.016788,14.733539,125.02752,180.037339,164.876152,104.216991,-41.301172,-122.935065,-219.177884,-190.416301,-42.28996,13.9894,-15.815763,-95.006208,-99.117904,-15.735026,50.128015,166.889221,212.300225,218.724624,186.843583,119.466926,-66.171589,-112.461572,-78.805288,-59.458401,-48.47073,67.289063,142.463555,178.078285,144.215501,34.865989,-34.976763,-90.307571,63.929254,139.824767,167.905728,150.885809,110.319697,91.394761,96.321702,117.847215,147.011089,145.60744,128.974019,92.398266,91.488642,109.129084,120.299696,127.850712,121.296878,98.853645,-54.800842,-139.023945,-201.490503,-197.310662,-153.813983,-142.04063,-189.216155,-171.608858,-117.656945,-33.215112,-24.152037,-26.432435,-6.021386,73.627041,172.445463,226.575741,235.878748,158.810413,-38.902973,-89.39493,-65.090281,-21.047262,38.660183,48.105695,84.145793,204.017999,218.80349,151.175858,128.479455,123.338883,100.181917,71.421779,4.514356,10.911446,77.556043,62.361558,-56.439313,-93.286613,-45.648989,90.124816,97.42028,-62.669679,-129.68983,-87.055957,-25.975981,33.173037,68.441421,96.582747,54.778155,-16.632123,-121.811747,-133.882221,-127.106058,-108.487995,-29.139422,-4.930083,-9.929544,45.459798,80.136958,88.925845,84.616966,81.433949,89.066863,91.268628,25.432031,-35.340546,-125.877733,-136.535523,-99.290589,-64.549908,19.068875,111.423957,161.162303,262.968264,286.62356,262.802245,250.141895,246.604738,268.432922,305.227731,328.980305,285.340589,172.542504,115.849159,29.950315,53.048209,177.292325,163.702411,101.200162,-64.309424,-160.835442,-301.175321,-291.426749,-145.304211,18.903468,99.393674,201.372072,202.832729,160.119769,137.218386,116.550451,113.540499,76.084929,15.461056,-13.776289,-22.877011,1.442708,14.327502,0.032456,2.444101,34.368971,37.945934,-9.262094,-38.62563,-47.858372,-47.22342,-77.474071,-78.224601,21.532212,133.906349,106.975512,-118.352891,-240.323828,-326.240502,-290.58286,-221.247615,-224.547911,-217.113554,-155.91279,-105.176199,-8.674854,4.982939,-54.757662,-87.34717,-43.687891,64.447326,55.284043,-116.051816,-229.386745,-394.324989,-404.489008,-279.938898,-141.495749,-130.95637,-240.993989,-304.844655,-312.97125,-268.122931,-187.39913,-176.321556,-150.698406,-27.334224,27.27071,86.539075,89.181872,-4.00852,-47.818833,-1.015251,110.938709,137.844393,113.394985,84.836251,36.625363,-0.39079,-90.336747,-128.786652,-186.016909,-76.024208,32.293926,140.620079,118.069648,46.894215,50.362795,158.528401,303.596897,341.624984,253.236384,148.168559,-21.507599,-58.124897,-45.378488,-19.199984,1.496925,1.309826,14.834512,49.672605,30.263743,-79.609287,-86.01127,66.206817,144.602163,98.371703,-9.61783,-23.981989,-11.386392,-21.804583,-93.863243,-119.421743,-20.331928,213.916326,267.966348,199.218767,133.951239,23.661358,-17.273763,-106.957127,-109.723454,-21.170892,178.959742,225.231112,229.671004,203.416641,109.663601,65.769051,33.243622,64.233464,75.622591,69.944135,70.0214,23.396281,-46.487824,-176.022816,-179.166553,-149.964674,-108.127256,-120.185636,-194.388715,-224.101072,-185.294575,-121.668072,-38.984455,-73.528965,-113.679795,-205.310833,-245.387188,-269.700994,-229.098239,-148.025189,-271.019748,-343.205869,-295.549362,-199.510537,-79.534328,-101.409916,-190.139379,-190.097952,-106.645907,-27.602621,-13.741725,-8.495593,0.838598,35.499568,55.009121,68.121038,79.805926,94.892325,65.743821,17.247565,-67.439372,-67.172455,46.137564,116.738865,198.160445,169.212592,85.570351,-81.097065,-87.689704,-2.730992,43.585539,94.655063,69.631009,54.488496,21.009412,2.569394,9.050616,24.343877,-3.987557,-44.141636,-83.939189,-17.279877,26.655672,11.032299,-47.053454,-161.111782,-194.425003,-212.125943,-231.047167,-249.305236,-215.600081,-155.583898,-107.992844,-172.386531,-301.702119,-272.842905,-123.360443,-99.753624,-122.764805,-160.179334,-208.683166,-325.815848,-301.345359,-143.929445,-172.328283,-225.708932,-205.020282,-126.75667,10.116907,8.196262,-77.610036,-99.938368:185.012577,160.904743,66.981829,-75.686945,-92.674964,-107.378164,-91.697813,60.859336,177.766106,170.576736,147.200946,153.350364,110.892591,39.109833,-68.569065,-55.489097,35.133363,72.675519,29.677657,-87.490561,-107.587483,-109.24854,-91.149633,22.497861,79.728293,34.487797,-114.586005,-157.657125,-89.272523,-15.539792,37.197646,25.253242,104.591947,218.578071,188.868529,8.063277,-80.395836,-137.740061,-97.881453,48.308614,171.891253,194.907439,173.685928,147.186619,55.325028,-5.343561,-48.707367,-16.882807,66.905395,92.839864,55.725989,-97.729979,-166.876758,-201.811178,-162.26609,-28.694568,82.51686,120.977492,115.07112,60.958237,-72.738597,-121.371569,-141.235243,-107.50117,-21.461029,-27.734919,-71.621796,-169.410719,-202.995077,-201.32703,-149.603707,-15.186352,30.277973,18.692967,-43.589039,-77.980487,-121.772723,-126.539064,-59.807533,10.404883,153.956513,150.391402,59.401599,-117.008486,-136.529938,-115.242274,-86.187426,69.571726,199.194593,194.176761,74.465429,0.673174,-84.348238,-74.252223,-18.900037,-31.260067,-66.597952,14.126704,38.443138,-17.579794,-47.64206,-23.734744,7.182451,103.637559,259.963456,304.552705,187.11099,55.850586,-123.81161,-143.987253,-126.422471,-105.094789,-37.527999,46.340262,81.402009,56.272301,-1.17559,-59.915716,-33.254361,69.871882,113.554202,87.135173,9.659014,-5.939165,14.313144,18.248336,-30.013399,-57.389746,-24.125222,130.674788,172.825802,76.25433,-10.464678,-111.744809,-114.688435,-33.76338,84.155575,116.121377,97.422717,61.604737,-21.932237,-69.663153,-107.039452,-54.366372,89.907082,103.586956,93.991932,145.029316,176.967676,157.121823,131.020714,141.88052,267.881599,324.24871,267.338388,187.101748,58.083902,6.386419,-31.746296,6.904689,144.784688,216.97959,198.350671,106.344987,71.893147,87.896711,132.349474,243.62823,313.333374,284.889042,102.783531,14.896517,-95.01931,-145.096939,-169.062217,-106.093792,25.719587,-22.95127,-68.753433,-70.429983,-53.207647,-85.876503,-100.423612,5.996576,178.500996,209.690328,179.594744,177.298286,230.4303,260.214889,321.503749,340.037868,292.202087,229.261922,229.79333,228.45944,185.644368,16.599965,-50.34202,-26.595285,88.186414,97.886772,29.18251,16.209292,45.045716,23.786324,-51.232504,-44.059246,45.625635,127.99157,111.282082,-23.758349,-76.146951,-129.608685,-145.424947,-121.756577,-54.584044,-34.034367,-45.008333,-67.185489,-99.658534,-97.914225,-82.058161,-76.13472,-25.156,66.191491,57.922429,-134.851474,-259.195166,-397.275687,-369.483011,-140.879859,36.508061,31.509738,-66.167746,-91.156966,-101.388365,-135.894995,-211.574797,-201.398628,-105.06064,-40.426798,-39.910326,-19.883038,-2.440955,-85.198706,-156.351432,-111.983646,104.800066,142.333273,44.75968,-14.550553,-47.939815,-28.827697,59.452204,111.781063,160.805584,118.151536,79.514398,24.587978,3.862424,-64.399842,-74.677408,70.610345,309.673781,365.286315,243.27536,117.921481,-50.110929,-83.867166,-63.198077,2.251237,145.592095,220.470976,240.150265,185.401345,91.849681,-74.755275,-58.211782,113.135169,134.633186,72.223999,-63.235504,-106.917124,-168.169646,-197.780986,-209.480405,-199.903121,-158.369541,4.522627,66.894088,0.269864,-77.373546,-162.051353,-141.943558,-3.344114,63.116097,45.507484,3.977951,4.80403,-13.583526,-60.155258,-145.212909,-161.615267,-177.015612,-148.404035,-145.676758,-240.517373,-283.267905,-262.880538,-235.726954,-223.814973,-187.308634,-147.297923,-147.661781,-189.74591,-242.862638,-241.887541,-160.837088,-90.717057,-15.113711,-20.106284,-45.150076,-139.814221,-175.64042,-151.718864,-85.90286,33.774336,-10.537099,-50.018107,-80.282526,-95.134531,-177.679912,-226.424425,-212.049599,-141.458115,14.473639,84.848101,60.148603,-76.645514,-132.522183,-102.30187,-24.082928,104.963339,82.806418,34.996047,-63.676269,-90.511413,-115.237747,-138.451941,-121.643755,-39.169606,133.246047,150.218074,133.431571,50.279751,-29.842759,-138.574569,-112.40596,27.174245,88.863008,58.858691,-102.981186,-177.835079,-225.317658,-209.855741,-78.832201,23.802968,154.745355,151.819082,143.207623,108.750918,57.522625,-39.605221,-29.154466,29.931305,-13.724536,-26.607555,-15.817874,-23.332244,-47.991886,-55.555038,-65.158798,-60.827606,-28.40628,-42.952591,-82.044866,-131.758948,-137.075969,-162.92627,-164.487936,-105.201587,-101.974448,-130.207122,-155.654095,-152.238581,-174.446816,-203.46533,-181.704217,-120.039635:backward
282.203277,296.777124,297.078314,231.777331,172.444548,83.374165,78.912727,104.458377,97.66991,88.344001,116.120011,163.876163,230.999866,208.802553,110.004998,61.347437,-0.944557,35.237979,51.720924,61.622612,74.843329,49.732971,12.737062,-38.23813,-29.076494,-3.725501,51.271699,74.721775,104.190282,113.739146,131.864545,126.211221,65.972453,-63.62968,-121.978926,-93.354049,-26.244188,77.270087,100.961321,60.807486,-40.294048,-70.183849,-60.007897,-44.938158,-116.567554,-186.520035,-290.841851,-334.115687,-365.284012,-257.144154,-170.041056,-8.424902,34.157721,64.618354,46.431631,-100.575447,-168.335108,-145.180082,-130.183655,-128.306258,-68.318681,-42.567635,-67.18881,-89.300296,-87.826493,-96.832427,-112.87441,-102.559968,-72.836683,-0.154126,19.117251,19.686892,116.633385,191.130409,267.815294,279.651697,249.39897,192.682516,57.655943,-5.625261,-103.327268,-61.614916,12.017888,165.198408,206.56902,168.075358,78.135018,-185.486704,-233.889595,-128.463521,85.265159,129.898605,103.238544,55.52225,12.165031,34.757007,45.646685,12.698018,47.625571,199.650562,261.408706,271.513348,224.143354,99.050121,42.547076,52.005277,130.686827,183.444994,234.659101,221.045141,135.292917,63.765482,-63.484485,-97.728931,-105.937282,-73.201466,-45.828826,-88.330437,-145.735361,-239.527701,-286.479647,-301.272875,-272.558379,-210.027587,-89.010063,-83.310405,-192.453914,-282.950141,-414.921463,-353.929303,-280.441515,-200.060985,-211.622733,-263.512774,-281.140195,-323.717472,-358.169885,-335.378364,-216.58683,-147.365403,-21.606704,9.759116,-46.174784,-99.750382,-155.765621,-154.562329,-138.754431,-70.672583,-34.719564,20.123037,42.331327,3.371337,-46.983665,-6.963226,144.730015,199.247298,186.797671,148.687595,122.56767,116.559659,112.37768,278.456486,345.749597,266.33262,179.959341,87.206574,87.412405,95.571783,83.050424,77.34874,56.674158,55.565212,59.749417,34.005592,-79.627333,-151.51318,-283.363384,-343.791287,-322.805066,-201.950428,-148.961748,-131.756825,-161.693464,-244.864318,-291.803881,-262.790529,-101.633728,-26.153603,-21.869168,-64.393732,-81.581352,-66.089829,-57.321128,15.430081,54.520123,53.280016,49.036781,47.032303,32.113814,-62.170808,-174.417254,-150.04466,39.571667,125.951852,114.755193,27.712134,-102.257868,-92.623639,28.852066,86.914334,47.973433,-31.620482,-33.264913,-6.346164,8.861315,-14.390529,-22.314007,35.81572,174.454665,212.25163,239.862608,238.249422,205.3676,177.25686,126.886432,117.788422,114.315179,96.596534,79.152392,37.497641,29.472386,-21.304071,-79.386238,-48.92318,75.633554,114.038861,123.625535,115.290181,45.516397,-31.238529,-180.845179,-185.507559,-134.65398,-25.182798,-14.352444,-44.969975,-58.876056,-169.52928,-266.309773,-234.064935,-134.569023,-122.435694,-143.08913,-148.575644,-116.770034,-89.090677,-47.139655,2.379836,32.25284,97.634479,136.947693,162.871048,99.617026,-139.39095,-245.786176,-235.757897,-227.389979,-213.682349,-97.637091,-32.057553,27.589426,23.576455,12.019749,86.764486,127.593613,118.3841,72.083613,-1.835275,0.839108,0.257682,-72.57687,-85.369467,-39.592384,-14.78726,-23.589141,-56.151426,-109.258117,-121.875001,-146.594418,-84.806893,-35.060861,23.835127,57.891514,111.5675,69.07541,-169.121094,-237.549678,-137.424388,94.603667,159.905632,220.62831,225.360958,137.792326,37.8405,-159.431061,-157.516903,-104.499142,-30.61807,-26.444833,-64.058122,-91.295102,-149.393691,-147.431381,-112.06465,-46.833443,-40.353609,-121.392982,-185.934596,-226.778512,-205.41949,-157.532591,-84.356227,-53.681533,-96.19905,-172.0896,-329.079791,-346.945866,-260.619896,-183.720072,-157.489462,-150.141214,-181.773497,-252.237924,-264.882539,-252.966365,-252.564687,-267.788792,-228.326547,-202.379276,-179.301446,-182.311905,-180.915538,-140.928319,-69.889862,-126.48208,-126.060591,-56.107227,-53.560713,-99.525659,-109.893823,-111.867851,-147.310807,-329.435499,-469.673643,-485.532539,-406.722172,-325.96044,-202.240013,-200.150996,-312.29896,-412.101211,-406.350832,-330.303328,-275.485913,-156.184427,-129.490522,-192.766823,-252.173024,-323.940861,-304.711754,-270.992722,-176.560664,-139.587982,-82.428498,-31.686244,37.895123,-63.652777,-131.532131,-188.309379,-164.948554,-53.403462,-19.446608,-41.174058,-62.906906,-130.126545,-227.190395,-249.004264,-268.656333,-292.396055,-300.491869,-257.178824,-192.972828,-223.836305,-224.001169,-173.333086,-125.849266,-42.712379,-51.246654,-151.635454,-202.988778:62.488742,146.08624,202.267155,128.492155,21.525234,-79.06927,-65.220511,-63.493489,-31.598809,15.235975,95.803201,133.310324,180.253982,167.397731,94.90487,44.680143,-26.665032,17.385565,49.10829,85.561744,85.041829,20.877393,-25.073907,-89.869577,-62.155645,-6.287226,98.773353,121.388171,101.667859,86.880416,70.146109,30.947315,-67.049,-62.686101,-48.206067,-11.91789,24.084431,70.167778,46.189963,-35.016962,-59.974619,-98.925844,-152.693176,-117.424645,-101.606516,-164.300973,-246.246633,-229.064506,-168.181001,-59.169048,35.817943,196.02357,215.251236,190.209239,171.065007,114.055819,169.946239,242.469815,272.616957,204.992729,89.684954,99.30716,129.693886,101.226926,61.781088,108.948047,113.860325,60.904289,38.035594,28.167039,35.372152,107.788428,218.301778,239.974938,218.944771,223.19665,246.807167,215.948396,97.696638,58.246534,34.745302,75.917527,134.134053,243.724474,233.531652,89.088898,12.690217,-93.875534,-114.27752,-55.015357,150.463213,215.974464,154.698246,84.606269,73.160982,121.931714,131.590108,31.990846,35.89014,202.472977,309.949121,381.83326,315.69759,143.25842,173.323835,234.331126,335.926228,377.519603,373.008726,319.476842,193.002765,135.39149,83.052152,91.394734,75.850589,63.108047,58.207844,-54.948709,-136.56578,-177.755807,-90.533686,-50.522389,6.559288,17.297987,18.80381,14.737851,-63.084452,-138.007695,-222.769977,-155.814493,-112.015876,-115.953604,-153.400966,-183.915749,-186.966356,-227.111424,-261.118303,-276.170798,-271.172156,-218.101885,-47.194497,6.434215,-57.609273,-125.83044,-127.821677,-53.522718,-64.919305,-119.305321,-120.080685,-93.793839,-96.349164,-143.934467,-121.112284,-51.849152,115.508436,156.604553,115.641778,80.157723,74.226476,71.124875,30.275954,140.136003,223.837202,289.878853,264.047243,122.35827,51.422328,56.252763,236.710128,308.716389,257.096277,151.256857,-49.332823,-110.408164,-206.004932,-263.221994,-326.026598,-207.172749,-122.125034,-77.234057,-108.710864,-132.231723,-140.572622,-228.581683,-248.003074,-183.928501,26.820079,101.713251,23.704869,-78.188414,-143.401006,-127.02773,-162.328865,-79.025076,17.84971,60.90203,8.927339,-103.897812,-142.132717,-185.067367,-179.063377,-147.278315,-29.556213,36.051587,37.928312,-39.425616,-173.349172,-166.11258,-26.043116,40.450247,11.584009,-20.863667,-13.260517,7.789967,40.679644,74.781174,22.487202,24.755307,97.651935,144.792099,194.278798,181.097983,102.86482,50.209535,-22.964169,11.411581,37.218659,15.420827,-27.064775,-101.317022,-118.616453,-129.222632,-108.7114,-99.011701,-114.487794,-136.524252,-148.109651,-137.795211,-168.274654,-205.96924,-210.440606,-73.287873,-12.448879,-5.434779,-33.862016,-14.576071,-16.684615,-220.706222,-246.484175,-133.900678,-9.340233,-30.249446,-90.311336,-99.9508,-89.778368,-79.42179,-48.914979,38.465146,99.55005,182.568093,182.165871,114.27777,44.471676,-147.270574,-142.871252,-54.090584,20.042461,-28.545251,-86.97723,-35.535975,133.140726,196.209263,249.273979,219.375237,181.852632,91.184934,46.336576,-31.016886,-67.436487,-145.503765,-145.693379,-106.039015,-12.272532,26.022513,25.544959,-24.065007,-105.557379,-102.180478,-72.861222,-32.827171,-4.735586,21.972383,20.778975,16.885575,-5.136621,-129.237437,-173.271229,-138.903569,-60.003877,-26.024082,47.506634,68.662984,9.621145,-64.327157,-198.365475,-138.392849,-64.352844,-9.416097,-9.097211,-2.233021,-21.817919,-118.616635,-124.381335,-63.6349,55.313975,67.784742,-12.867129,-65.070686,-115.260258,-138.119399,-181.124588,-135.971536,-95.122553,-79.523606,-121.136764,-186.692002,-172.445217,-137.504479,-124.59506,-103.794857,-109.948909,-158.56383,-243.533485,-232.902066,-217.837004,-270.234941,-319.455397,-128.212076,-37.901053,22.903399,7.829995,-80.553927,-108.646974,-112.754228,-102.964188,-71.511502,-9.635814,-20.249958,-81.613285,-105.441907,-164.320863,-228.638391,-418.47335,-524.053636,-516.792476,-430.954849,-367.458716,-265.347936,-266.290734,-350.565075,-339.649316,-278.216436,-202.920177,-206.187856,-180.970584,-164.099854,-252.00261,-328.611571,-382.039501,-369.921662,-355.905056,-193.158547,-75.494673,46.112879,35.511243,-76.259704,-114.829253,-69.114698,9.255278,25.808535,78.619304,98.813476,47.777948,-37.102783,-295.9185,-413.270942,-380.821665,-344.807544,-375.286902,-403.964653,-386.228152,-414.373579,-420.67858,-342.679155,-155.083257,-97.307379,-93.946844,-118.95757,-99.11511,-104.916473:-25.112397,103.170812,168.297071,165.389757,103.064459,-61.354522,-132.966565,-191.534172,-130.537699,-92.177434,-9.51395,38.113425,66.316992,26.479349,-94.029616,-122.102002,-22.374673,119.433662,127.386754,85.327895,70.072051,39.753233,19.700475,-35.200012,-45.65312,-5.31413,161.284129,240.388632,239.230789,159.679082,-47.53661,-131.433739,-147.254147,-21.742745,15.156933,35.765704,41.566879,58.609618,67.456114,14.86558,-131.833885,-195.851543,-169.003629,-95.020988,-76.854371,-137.089143,-180.08739,-164.928684,-138.236231,-36.870482,31.083721,107.048706,112.53773,119.254394,134.289681,191.533354,285.566776,340.937154,383.216724,345.211762,245.771819,223.13076,213.587983,208.113871,186.357761,189.506751,207.211745,239.852705,248.820937,253.524324,247.753972,287.000773,452.52965,508.803368,425.270178,347.486879,245.99501,185.876855,50.307782,22.930142,29.640512,34.781925,56.099078,119.654917,128.035422,90.050777,60.421371,-6.44265,-22.6391,9.276397,114.096846,154.027175,127.964231,65.623646,-5.79903,35.566039,160.670579,179.716363,180.800127,243.594897,297.903505,337.663307,271.687905,66.288488,67.685044,172.802604,440.009245,504.635173,402.909861,306.175721,162.421188,112.461938,48.108733,-1.554959,4.496483,136.157762,187.05323,75.642004,-50.538261,-202.395029,-81.632651,43.552064,217.455464,227.333494,186.664518,161.998128,94.336293,56.16708,0.771183,-5.468804,19.40805,56.746052,27.857134,-55.522424,-70.415016,-61.592536,-107.442695,-153.15042,-142.624657,-80.606542,4.435362,1.624948,-76.716109,-140.339155,-146.079273,31.329974,71.95211,3.839623,-21.257603,22.450752,14.935034,-156.535534,-249.281553,-200.233976,-46.414848,25.220345,129.945153,162.8945,223.426021,209.817824,70.614215,78.984989,152.212324,250.266865,242.363495,144.546323,83.840096,16.16756,62.185994,108.890069,173.51684,163.910548,55.392188,-20.927506,-154.964078,-193.757446,-185.323023,-99.938621,-74.789758,-100.198446,-118.21372,-115.64062,-142.131567,-232.309721,-114.115234,0.949464,153.556753,152.739143,-6.392931,-123.119717,-287.208872,-310.532389,-290.032189,-183.123901,-84.666727,-3.403975,-50.155204,-105.141419,-87.170454,-85.941178,-131.448322,-121.777461,24.454691,128.866128,188.011881,110.304053,-101.9171,-154.33741,-65.066066,97.419155,108.098616,52.610362,63.527464,179.412517,208.128274,88.847394,-27.221423,-12.078205,112.452152,194.92913,303.719317,282.758989,81.3324,-25.991653,-69.459829,8.791585,23.496483,19.727281,16.419063,-39.077242,-94.644907,-176.572065,-169.901281,-160.974016,-202.817561,-242.465941,-278.016477,-254.151415,-184.156893,-184.886702,-201.222459,-135.260729,-103.480522,-88.014613,-74.988262,62.906703,120.139613,-17.78937,-139.518617,-94.251905,-39.087483,-56.481066,-47.173567,-22.665804,-8.017877,-0.99913,84.842648,177.544437,178.299612,153.125035,168.42748,185.809857,131.376718,-73.395778,-162.776123,-113.017485,97.421939,170.979072,135.929359,86.052693,80.684907,120.219541,169.753644,102.115902,80.318241,64.402681,-11.481903,-209.38852,-215.466906,-109.628011,-116.868471,-128.537131,-63.203397,-33.747337,-112.929475,-191.347238,-267.389285,-266.187424,-253.668642,-150.279744,-64.587898,17.353826,-24.769935,-126.177951,-115.687806,-63.308405,-112.192594,-143.703415,-134.23305,-83.893253,8.613492,-9.232911,-144.105088,-193.113964,-204.245054,-161.919167,-125.058823,-36.109045,-6.803253,-45.93896,-93.045189,-108.796839,-39.821689,-19.487532,-42.536389,-53.11805,5.875641,31.242747,-51.726659,-109.335184,-89.719706,-9.197066,50.375236,183.422422,154.278068,-59.477126,-121.317319,-106.464339,-50.823291,-21.033316,-21.052339,-80.942967,-187.076476,-178.590313,-220.171387,-322.137599,-388.511005,-58.541551,75.771355,48.763272,2.173408,31.96407,35.012412,-74.103022,-102.996144,-42.340467,114.48505,156.576824,81.040201,-30.326741,-233.680292,-296.244083,-421.14439,-481.77097,-450.188063,-348.587844,-316.02879,-301.467852,-321.842373,-407.783409,-353.288668,-240.016603,-119.694939,-170.20056,-259.163884,-233.321756,-184.393566,-221.283181,-329.153353,-330.856815,-308.472456,-236.677693,-165.828285,4.455647,44.656743,-1.91803,-53.421871,-30.339173,89.853424,131.802182,98.631712,62.582875,19.213587,-32.619066,-255.260396,-405.604703,-397.413045,-323.025051,-308.200096,-340.441188,-368.914339,-407.259039,-292.91486,-185.145524,-45.214021,-42.244551,-106.280109,-112.035532,-49.437458,-59.553862:87.866072,158.071291,206.885746,149.550648,42.419437,-101.349882,-100.777639,-96.7657,-79.963879,-40.778846,53.884767,98.698623,107.725262,52.724798,-87.674795,-128.337151,-94.664965,13.065633,35.397361,45.012198,56.48243,44.487989,13.774746,-60.305533,-106.473788,-98.314906,22.76266,98.419945,122.204095,85.759015,52.952179,47.533367,-21.103714,-144.825921,-176.769022,-89.086859,-16.397971,24.259708,0.76205,-61.464021,-119.150054,-155.404342,-165.871687,-114.18862,-84.979345,-157.635419,-296.790452,-305.795296,-243.050989,-132.943864,-62.834056,80.301452,124.791759,87.456529,8.629645,-89.619154,65.401366,161.642915,208.897234,167.726411,72.492026,50.567871,45.440985,32.521296,-32.09909,-25.85779,5.478805,-6.827026,-43.025668,-23.646202,34.897478,121.408297,192.663583,235.429265,278.246107,294.226786,295.441679,245.960961,98.703742,40.721862,-16.938566,34.737391,105.508458,284.397149,339.885057,256.743471,130.995602,-135.168989,-168.71192,-65.509429,184.633016,246.23983,186.569018,109.42786,16.776646,16.632073,40.229402,69.563069,108.503475,217.597598,253.496856,201.35738,109.51111,-72.540973,-81.47241,-10.683597,206.769561,292.5459,318.949462,276.79711,129.166732,46.717492,-11.643084,28.146313,43.200937,84.427889,80.985935,-50.423343,-149.147576,-296.975705,-259.495791,-175.661284,-6.455004,52.233566,104.568636,98.70941,46.357866,-2.714963,-129.49237,-161.207521,-108.021292,41.94948,71.122374,-24.914157,-109.648076,-237.532685,-254.591843,-213.590144,-62.049625,17.681244,89.839514,72.063444,-20.625309,-58.099783,-46.07832,-21.46913,-28.845564,3.547308,42.251126,83.103357,59.244641,-69.988316,-135.474485,-117.221683,-32.793873,27.207111,100.936046,84.676035,38.787315,29.909851,51.353129,177.380809,218.134337,190.231791,163.139437,122.839929,91.956507,36.848106,86.45676,112.255917,111.147867,119.326708,123.253795,79.612796,-63.244755,-130.619034,-180.816971,-84.087709,-31.410737,0.955908,-2.909503,-0.674788,-22.114034,-156.615239,-190.554056,-120.689718,42.646928,68.079767,-24.416703,-84.625833,-127.332228,-134.480039,-141.294165,-34.717384,42.181441,93.686743,68.207013,21.175001,7.984897,-49.525236,-99.805046,-66.345692,125.663556,231.650716,281.058274,208.230239,11.101051,-45.924797,4.703544,150.325856,171.394962,117.732824,94.720488,130.553257,171.52442,172.19372,113.221752,121.181693,208.082452,257.301022,279.470537,244.116969,139.513908,99.345837,89.063604,77.248451,36.779576,-5.892797,16.292151,25.655415,-42.997692,-264.079321,-271.659265,-183.787248,-34.535232,-13.921921,-111.568621,-187.925229,-260.651362,-269.011086,-262.333432,-217.56998,-191.253682,-160.181312,-163.288084,-120.695195,-72.50503,-119.976563,-249.060807,-233.916507,-142.030095,-124.995646,-152.445234,-163.05227,-118.653456,-74.256383,-3.257882,45.592101,81.507153,153.520993,177.446524,173.181069,116.230924,-59.311014,-122.2795,-94.554292,22.982863,77.613589,118.620398,125.927137,178.06135,201.780789,188.461732,151.276107,141.585149,110.920894,76.420701,23.375381,26.016584,13.219716,-91.358085,-128.851014,-63.179435,7.902777,26.062574,-54.836005,-221.771751,-238.679759,-142.99466,-4.133984,45.286395,122.626536,129.528031,35.941729,-15.507731,-68.785497,-97.868206,-78.091776,44.013398,109.378211,166.698577,153.174679,46.375477,-37.136426,-162.818057,-125.51413,-76.36682,-27.358565,-39.031598,-121.935214,-149.179577,-86.481459,-53.437908,-78.203492,-69.703822,-24.018258,13.799543,-22.521072,-109.18963,-129.802725,-120.245696,-57.611302,-15.83914,33.725111,2.144154,-124.92807,-152.776408,-142.269504,-129.19709,-97.65881,-27.970629,-28.847066,-94.541253,-123.228395,-148.309271,-172.838747,-210.835617,-116.086737,-71.762317,-57.302551,-42.388535,35.174531,68.720289,39.786552,-60.020401,-64.647746,13.415757,51.853256,55.021752,10.454106,-126.033137,-214.280527,-442.518304,-564.385086,-551.740614,-459.560683,-407.233979,-325.198351,-320.262062,-426.921578,-477.070308,-410.508788,-244.039023,-192.869802,-131.404773,-128.754409,-219.554966,-284.172185,-364.404074,-366.6789,-354.927357,-321.283111,-280.423725,-155.740065,-110.637646,-112.819628,-111.681643,-79.127287,-46.804012,-59.035466,-25.955032,31.904871,75.236731,2.913374,-267.519315,-410.982316,-392.922523,-327.820528,-316.04337,-290.019895,-280.155499,-314.653374,-295.315234,-240.82358,-139.510011,-100.912529,-58.456696,-67.162431,-102.74265,-119.793392:-87.11361,95.207764,180.291618,166.244783,68.036272,-130.348077,-172.067758,-188.50559,-134.565421,-73.436672,52.634688,99.932332,115.114962,51.163644,-177.958621,-257.282004,-173.500477,39.72765,92.287433,106.560665,91.161787,28.329153,-10.648655,-65.05318,-65.454609,-45.757815,94.978307,193.306236,239.348992,173.833455,9.961969,-54.159562,-110.1756,-83.35808,-68.259648,-38.953935,-24.939311,-31.979903,-62.247832,-158.592582,-237.71116,-249.942107,-200.732236,-161.826435,-179.157212,-228.096982,-267.023079,-244.727376,-179.405506,-96.71492,-34.066538,69.968022,84.650568,71.55684,62.633266,78.421356,154.101941,200.852638,290.387718,313.188452,271.659193,222.166587,95.615772,29.170236,-11.982949,66.364982,95.442573,92.690983,75.148882,78.493116,107.700314,168.061272,243.188326,288.096399,314.736746,283.820758,176.299528,117.19696,-4.601269,-64.815004,-129.878618,-54.548361,16.416148,154.030305,206.27755,207.094068,124.203513,-128.619174,-173.165036,-83.926191,155.611944,244.210691,229.287992,142.211379,13.776934,19.298825,97.374742,122.808078,136.918438,199.999235,218.90655,161.050435,77.694421,-75.711224,35.105792,169.825569,339.327449,328.585588,222.421876,170.631152,36.456164,-40.669789,-77.36848,-1.166733,53.043358,216.882695,252.681121,70.147997,-88.056796,-283.151388,-198.64284,-95.758399,84.543371,148.125069,211.229157,193.705451,104.816473,57.698244,-26.901075,-74.630898,-69.507425,22.897654,77.767189,83.974669,26.819075,-90.318207,-78.485072,-51.851756,-4.658861,29.281257,75.044201,58.402613,-39.346246,-89.616479,-91.277953,33.71904,65.930626,18.640024,0.14513,3.68972,-23.36436,-113.319736,-118.375376,-108.553011,-57.015391,3.048155,77.127142,65.556649,27.730276,12.660549,28.968693,100.479441,106.958152,91.954777,88.934978,41.539469,-9.332456,-80.993107,-48.21373,-26.679903,23.928973,63.668029,97.004062,56.987318,-132.452063,-219.026514,-215.938645,-80.324115,-14.911805,82.54124,76.376996,-52.227216,-132.327908,-215.550472,-121.85001,-42.001985,129.331889,178.00374,67.978239,-46.886701,-229.206855,-276.956467,-267.465536,-164.046218,-94.247725,29.137541,44.896551,-1.455893,-36.100976,-92.560411,-51.11031,16.656959,197.265038,277.313305,287.67418,215.744419,66.382563,29.237565,50.115725,157.965158,212.738974,282.411382,284.365569,258.721431,258.698245,238.021843,160.693071,141.547434,200.649464,258.756524,275.483574,212.000371,54.843842,3.315157,4.584939,70.872998,95.990832,129.794649,121.300117,13.727673,-74.996505,-214.946626,-162.609532,-93.635359,-3.933285,6.351599,-55.068438,-107.146379,-167.355674,-185.12004,-187.118824,-101.979623,-62.375052,-20.873606,-7.686939,5.559183,-13.616419,-105.787506,-99.314963,-59.783611,-42.5097,-59.052789,-68.316591,-48.961825,16.627649,35.303764,76.809804,225.333419,293.584185,345.159355,351.188714,283.423247,170.718079,-61.780348,0.072826,104.886992,260.207236,286.213365,267.733686,258.002931,255.276453,239.039994,223.047877,273.764089,300.883002,305.861531,240.711836,43.163857,2.421772,23.866973,-30.450591,-72.713339,-44.52483,14.484778,22.965448,-43.04033,-137.973315,-146.517336,-99.092123,54.280881,130.364166,171.008074,121.169875,-9.085489,-35.870443,-53.758061,-106.122145,-102.245969,74.966073,195.92186,238.424108,162.082408,21.211693,-14.847335,-7.843422,84.594041,113.883704,94.118218,62.410201,-25.610284,-69.70213,-78.646983,8.362536,39.585914,71.333001,103.789216,151.644032,116.476577,-24.110375,-64.262046,-32.061028,40.379541,87.362799,156.8625,128.33156,12.48827,-23.533554,-82.658901,-102.832497,-50.046367,109.190277,137.042515,44.190032,-24.493292,-148.441973,-222.789011,-288.156566,-62.615825,54.350436,84.057748,60.047034,54.060472,32.010068,-86.201555,-128.23388,-98.034612,-15.58036,10.20691,-5.359668,-46.417136,-172.333473,-250.698442,-421.287375,-536.947584,-533.021948,-403.828129,-330.344484,-274.026403,-313.749031,-510.506114,-546.925996,-424.45996,-160.874793,-120.699884,-159.635416,-181.712781,-226.891755,-280.518722,-379.034818,-320.579134,-265.632704,-185.644131,-137.85819,-15.864549,-13.282055,-155.358512,-144.139471,-41.651734,135.199891,139.16267,41.622218,21.084404,60.713973,49.385712,-126.765803,-279.45675,-259.145679,-126.452906,-103.007407,-181.311654,-221.191765,-233.697346,-181.265906,-128.521436,-11.082627,19.048383,7.571776,2.862344,-23.274082,-90.976839:75.715828,93.96794,112.955569,78.656855,3.019612,-148.40907,-162.856522,-76.196465,20.559874,42.04967,72.883826,122.843116,198.84983,132.92365,-134.584673,-232.347391,-247.157569,-110.403406,-48.906109,-2.468114,-19.327633,-90.533292,-128.341759,-212.174689,-201.644403,-140.934144,-0.323632,52.260922,77.057035,55.29726,57.941674,85.850156,73.969011,-67.877011,-162.814865,-231.449481,-159.315582,39.16252,76.266214,15.464953,-58.216383,-72.702392,-33.813742,12.813647,16.981085,-49.011734,-182.961566,-220.662749,-272.541372,-246.408129,-193.607995,-73.482169,-20.7668,58.228787,50.415619,-108.397459,-201.336877,-156.002721,-61.02636,-59.055053,-57.73658,-56.791246,-112.983751,-140.177061,-144.876551,-125.77355,-97.697444,7.230614,65.548934,138.49128,136.817155,94.346746,135.938314,172.731199,200.536966,231.362609,324.323822,304.503705,99.311412,2.490789,-32.068391,81.666646,150.467328,225.324541,214.754236,125.769563,43.717136,-166.334573,-132.723131,11.974097,264.458739,288.515824,174.82324,101.386742,64.83611,97.488988,98.597691,8.572085,8.716715,106.991264,144.146231,122.848663,75.812872,-32.445174,-49.219543,-24.819526,41.558599,88.413184,166.829101,158.218277,31.125315,-58.678058,-136.307418,-41.358294,-19.008685,-42.452165,-34.371667,-6.413721,-34.190465,-155.133998,-247.477095,-275.884544,-256.758371,-179.717827,8.138795,35.635635,-88.16049,-191.011177,-293.662535,-143.109175,-33.707101,42.012475,8.23294,-14.289783,12.2169,-19.238641,-125.860565,-131.833093,-62.475967,-25.055755,11.10658,17.908348,28.507933,40.264742,71.068751,17.937325,-38.442388,-69.03585,-25.890982,43.216192,23.926663,-75.802512,-78.017732,-17.067941,124.625117,168.850548,165.437985,125.51652,75.007328,64.638946,36.290705,178.765382,273.509338,253.027183,160.701164,34.761631,19.72018,-28.153763,-24.61684,4.458992,-34.241954,-51.868076,38.461741,68.51789,-7.259796,-61.489753,-135.159235,-170.456105,-142.073912,-19.533029,19.934876,-4.247203,-46.637173,-104.522995,-76.708763,-42.543296,50.975431,86.542117,23.99184,-53.752637,-145.38639,-149.76106,-105.550406,0.214219,62.521572,169.673465,196.565045,191.022307,176.114792,100.331209,12.070292,37.517651,219.9108,311.512387,326.805456,250.978738,111.397959,82.216737,66.679583,98.017578,99.901638,38.502321,9.345537,40.242952,99.514333,207.527935,236.278935,246.291527,319.219063,380.275343,465.58719,447.262228,290.438814,209.551604,169.259882,219.571267,222.726823,192.701401,171.8517,101.943162,52.019993,-35.026424,-46.650946,-16.169727,112.86989,185.792666,277.340572,278.279431,134.112987,12.425718,-145.326777,-118.0157,-81.184739,-49.204498,-57.308222,-74.847286,-72.939023,-133.44745,-228.679092,-205.687754,-102.854962,-94.735223,-140.664842,-137.761156,0.035122,95.568858,159.248647,88.541499,73.011187,92.699832,101.536476,102.404134,85.639088,-2.090742,-65.596366,-68.505439,-54.182912,-27.09424,49.165067,70.983509,103.111326,117.023972,100.718767,92.278462,115.128085,151.122495,139.218061,103.263018,92.202939,28.427077,-35.562329,-9.597485,112.167634,146.093929,51.170748,-60.349232,-202.651231,-183.049264,-33.617902,89.45644,109.03364,170.394835,226.259821,224.198146,129.114418,-99.943222,-109.418192,-38.561003,77.4062,127.539477,263.941303,280.566277,127.930717,26.219215,-99.513267,-98.515249,-81.009689,-86.661006,-92.720132,-78.830679,-76.334049,-144.083074,-197.73509,-154.646947,-21.278789,13.455873,-39.559591,-128.732907,-260.243074,-233.896773,-76.259013,21.372575,-0.798387,-172.927127,-248.998398,-249.002226,-192.466324,-79.651999,-41.782448,-43.069167,-43.229573,-42.122928,-79.1836,-103.032568,-62.586776,-31.046538,-104.142446,-172.351031,-141.049372,-60.625894,-44.464985,-21.723816,-8.096776,-61.931597,-124.814468,-80.53555,62.517317,83.677288,49.621172,49.425817,79.24405,30.436957,-305.217574,-541.843686,-496.122125,-256.830734,-178.340662,-205.971753,-256.189095,-297.728779,-304.566394,-298.21338,-213.238315,-140.641142,-16.11672,3.897909,-57.87902,-126.020542,-247.125858,-258.616613,-241.32286,-215.216056,-211.825762,-193.140103,-151.033476,-64.826138,-99.699653,-124.384554,-92.268736,-51.76914,-22.944507,-35.360183,-7.308787,5.546752,-164.502338,-369.122254,-351.141601,-198.157734,-162.891082,-169.092756,-156.842875,-139.063551,-153.574175,-120.339107,-3.434427,38.487127,54.295146,26.198862,-80.168691,-140.8361:-126.849238,-45.225527,23.820156,99.01305,62.73366,-126.62058,-207.150177,-240.481318,-130.421543,-61.416119,20.459134,58.50402,126.724054,96.164727,-110.102332,-202.850634,-158.599549,31.064294,74.585333,83.029496,83.636933,53.53185,-2.087115,-123.13828,-124.418099,-95.178748,27.063736,107.584111,143.945506,94.947071,11.640434,-5.161111,-52.68446,-159.412317,-197.417931,-105.669013,-11.928933,13.910522,-70.11256,-243.300545,-266.699076,-233.224627,-99.381986,-19.956619,-11.450788,-98.393672,-262.644268,-284.964613,-236.129353,-169.725816,-137.913541,-38.218475,20.088784,76.441717,62.183209,-1.2884,11.886576,54.535755,126.433269,152.698779,208.646541,194.602462,12.068134,-88.378388,-106.033943,13.284865,24.910766,-23.064617,-22.250948,32.115753,47.323835,28.145535,39.089142,82.931639,211.649071,268.654684,292.186751,234.82663,-6.487954,-125.028642,-170.805482,-8.32279,81.979908,205.349909,233.466653,165.691444,47.423836,-214.225934,-161.839116,-15.06976,239.803086,291.058913,269.531123,212.125362,65.45816,29.081853,83.379463,138.053956,140.470344,174.506863,201.796301,172.312421,91.116642,-109.717887,-98.698376,-2.235953,212.898197,286.81256,292.518106,219.932745,12.427328,-66.379385,-64.066918,23.548349,37.175682,64.48541,79.785374,-10.505571,-125.719428,-326.658979,-278.009937,-178.196876,-11.957286,31.772076,94.864909,116.12398,52.867413,-38.290065,-158.549001,-82.116176,-19.08014,100.523509,158.033136,193.125599,133.670088,-80.495996,-145.431964,-86.36008,83.371985,143.855427,138.729107,92.990504,18.603124,-3.527433,10.185075,105.090536,125.063684,60.026148,9.181488,-68.047681,-113.769806,-219.870061,-194.817577,-118.214383,66.713981,132.045263,127.924364,65.770044,-70.309769,-112.664018,-73.731336,104.600412,161.991578,164.202518,145.753654,93.062108,37.398011,-112.447977,-109.928346,-36.544199,106.83967,157.170591,186.380799,145.465112,13.81187,-40.540141,-94.922921,-66.148298,-12.467793,130.868706,170.554991,103.422146,12.346661,-149.288437,-107.49555,-3.844514,211.824724,237.610304,80.340627,-29.511058,-171.111526,-198.022853,-149.713097,-30.420711,20.551006,96.702181,111.925812,94.576728,67.883462,-21.167079,-7.289568,81.984616,306.322556,385.022246,381.099485,294.322081,75.621298,10.813656,45.371841,178.397442,224.476431,285.727305,298.714762,248.218343,206.040795,128.961719,132.776866,195.735703,337.675708,369.826844,365.476886,330.564608,193.362007,127.441562,116.876931,203.59534,215.17962,184.072695,171.933296,107.570368,9.41383,-198.74102,-115.714911,-6.779189,138.959788,160.941638,115.608097,63.984651,-73.152165,-145.338506,-181.579721,-101.207656,-67.442889,-14.721891,2.611778,17.570488,12.324636,-66.500328,-108.543599,-64.152022,64.402568,100.026274,61.008426,21.523004,27.017412,41.033013,32.97375,130.561144,204.273907,271.093279,259.611886,184.363614,117.02286,-68.088718,-106.726925,-32.733405,164.138147,248.828223,313.639861,281.90989,187.307643,152.974771,127.539127,165.112928,195.593309,263.490838,282.485165,240.203688,179.204722,30.741587,-45.144698,-30.962606,94.365843,167.81985,133.280938,10.39064,-223.801136,-266.43093,-144.704515,123.094376,187.505558,148.785443,104.508495,30.90922,0.686626,-68.310477,-133.171444,-109.080902,93.396784,207.179155,287.175503,247.325514,92.29612,6.199895,-98.528048,-46.002608,5.992905,73.248163,58.503169,-64.900855,-135.6597,-226.113872,-153.729545,-61.362194,84.590889,117.509643,96.361156,30.495022,-124.381206,-165.564859,-149.485498,-25.650212,49.613659,111.411868,72.850987,-65.566913,-109.543035,-155.925282,-174.88962,-119.974851,79.355961,140.450301,90.143058,20.676418,-80.457763,-109.174018,-144.885629,-88.331825,-35.54891,51.700803,73.386925,46.722097,1.866954,-126.445904,-157.532649,-94.569447,58.143851,90.877917,59.73866,11.11372,-139.925329,-238.78921,-447.531352,-532.953635,-514.674094,-421.120651,-353.204079,-224.836624,-220.409899,-369.594076,-431.638973,-356.903178,-147.089037,-75.885011,-19.376797,-28.773642,-132.006239,-214.629751,-324.34625,-247.43995,-181.198766,-91.916983,-68.097713,-78.243631,-127.065881,-255.155979,-229.987933,-149.717699,34.666905,107.712218,149.792702,121.373111,40.361432,-25.202806,-266.474035,-386.517787,-323.173078,-128.458261,-77.414318,-98.573515,-139.265157,-234.265821,-239.124032,-165.737784,22.069825,74.607889,39.876679,-22.41068,-117.496272,-134.079528:-96.168232,-101.139301,-21.055702,103.661051,81.963868,-8.190718,-7.505039,43.874751,59.822742,53.812282,58.290554,91.529736,166.063867,155.303321,37.17581,-34.743214,-110.887937,-79.216384,-68.563964,-45.789033,-37.603996,-158.410498,-262.933747,-384.514838,-341.033055,-264.748434,-93.051455,-44.123028,-73.586604,-110.036665,-8.663897,102.934166,147.125544,-59.692327,-126.861044,-56.293943,7.623564,40.90507,41.998521,59.810555,71.703423,98.465927,181.374637,197.276336,101.764322,25.375531,-5.417801,18.599793,-33.069827,-86.223988,-44.45874,71.574661,92.59573,95.367342,85.274758,-53.107358,-229.748156,-239.035676,-142.921804,-88.487263,10.935113,37.435489,18.617651,9.845166,26.739103,26.093867,6.470841,-41.335607,-43.315937,39.995351,100.738465,166.996697,193.851533,213.107368,257.994969,295.746971,379.456902,382.165096,277.450927,196.065391,74.065114,67.698089,85.442738,102.17726,101.379222,93.6811,65.449257,-58.712167,-66.386422,17.78922,180.947064,186.081908,69.823442,11.301828,11.368169,60.819937,152.888787,142.385403,123.671207,151.431004,170.303793,135.663922,108.650197,120.530192,140.977828,110.947247,14.450303,-14.80337,-32.825557,-47.587364,-99.357383,-125.349267,-120.897163,-36.295214,-30.722949,-103.114585,-119.994748,-120.913127,-140.589656,-179.427398,-154.000541,-131.475315,-101.84274,-79.287909,-1.370694,32.185077,6.746853,-62.722594,-189.100074,-143.4661,-88.691934,0.600113,48.409016,144.28428,151.368854,44.633628,-21.87655,0.728134,41.73153,68.451996,205.489238,262.940771,213.230369,136.649979,36.414967,6.237491,-19.848812,-67.491494,-65.375394,-30.98765,-21.730944,-75.59145,-136.729091,-110.994676,2.197999,53.363948,76.892495,45.208728,-0.747056,-10.95589,-43.994294,8.376605,40.681938,5.524294,-39.499365,-82.456246,-91.547772,-157.605622,-182.931555,-161.005269,-169.535056,-172.937511,-79.534223,-41.86862,-79.883201,-121.085988,-181.528379,-217.553054,-207.120805,-66.457993,23.744675,26.483246,-64.899802,-204.012848,-137.297324,-83.367625,-44.873294,-52.996302,-162.345044,-255.777721,-340.128017,-298.031101,-154.492637,-96.203632,-84.607595,11.589993,71.159501,90.621564,62.791641,-14.439372,-69.225064,-57.276613,-2.823187,9.069453,-12.10589,-33.297012,-74.635042,-101.417016,-171.732788,-208.651164,-202.654047,-141.262152,-85.519367,12.305284,21.280807,-1.650687,70.219036,130.273464,179.690647,188.317789,281.20466,319.699207,255.459591,208.103428,222.53029,272.653415,257.307616,171.956711,152.046261,193.064157,195.395742,100.692667,67.35771,125.356346,272.248899,312.305022,364.618465,378.617868,286.100998,187.650136,53.017977,15.744036,-11.427701,-63.495586,-67.096751,-42.302852,-26.697661,1.88682,18.909008,20.188137,2.637788,-7.336305,-14.897399,0.159066,111.642791,174.706604,214.532322,177.493213,140.464916,90.053967,107.322532,179.507103,188.349147,74.17629,-92.647593,-107.980082,-10.346962,53.79696,131.732667,138.582297,100.282939,49.718466,-22.500717,84.167838,147.393286,198.30154,204.031088,206.833758,202.015337,133.984978,62.702104,74.731832,140.65801,159.743244,133.344784,90.532614,22.14669,28.084754,96.953454,162.940731,192.670395,242.091222,259.234657,215.744208,132.19905,-52.375231,-93.08699,-76.057314,-27.40457,16.913465,86.55156,72.092799,-6.151451,-47.00585,-105.771594,-103.640789,-113.050149,-150.538299,-148.471886,-107.330538,-85.70607,-75.211754,-83.867007,-93.301512,-133.469228,-128.083322,-85.441261,-114.708077,-210.737408,-197.354908,-96.98853,-115.954846,-170.826233,-289.41503,-336.168119,-318.984896,-217.580603,7.216394,-11.924045,-43.556988,22.947052,74.093066,45.62964,-13.297088,-35.426987,-8.899149,-59.783801,-146.872524,-133.629774,-95.131421,-114.31691,-142.53626,-115.790316,-60.783954,-88.593405,-86.061945,-12.193335,28.89363,81.034246,86.62987,85.830586,60.146062,-139.791601,-335.950439,-347.226196,-178.990541,-40.192313,118.82747,88.251136,-56.209504,-103.868008,-84.556924,10.689422,84.615649,219.410003,239.730804,201.921376,171.991308,164.262573,227.567844,231.680342,160.467807,123.283824,121.212958,145.473811,157.301791,149.17317,174.484491,210.656104,186.69121,106.609856,81.527731,74.631397,71.870555,2.39556,-53.418828,-23.4771,95.555263,121.456199,78.076149,57.598249,52.498743,50.70977,54.413424,97.425465,124.753755,116.135908,85.494541,48.684049,31.363633:123.600195,167.711064,223.050259,285.241927,261.494463,188.457559,187.449035,210.620312,146.853563,104.402756,100.173728,149.905133,228.421223,214.09114,135.431536,94.936418,34.573532,25.746882,22.951163,15.862541,7.720176,-46.795753,-68.846214,-76.344563,-25.432828,30.233181,140.311002,182.084679,203.033664,183.573316,173.69617,177.571628,106.868611,-23.273059,-58.04396,0.147965,60.628051,135.092032,154.702119,138.949992,59.749097,45.603593,84.192429,104.993155,24.990091,-79.513554,-205.336637,-193.242122,-185.04954,-212.204761,-187.025395,-127.927224,-127.124245,-117.396754,-110.212481,-223.173082,-383.806387,-383.715284,-236.852549,-147.775194,-41.946243,-54.19368,-161.316448,-182.332789,-130.262288,-129.802358,-150.334332,-116.36656,-63.054173,-5.850087,-7.597354,31.153479,143.498263,202.810305,311.037122,365.843628,411.568276,369.525118,185.604997,85.913534,-40.022457,13.970802,96.37366,238.021828,256.840648,161.556381,64.633636,-103.990193,-48.948456,43.792467,124.03915,90.622007,29.997121,28.854799,31.157471,15.754229,-40.745883,-33.979543,14.265512,154.772533,210.476997,246.529812,233.259031,138.731533,18.454772,-18.833927,-48.147502,-31.626138,36.955359,50.384545,-4.741508,-64.7252,-171.331666,-194.492264,-194.894571,-168.356291,-144.77596,-121.662592,-122.147599,-148.195718,-189.194596,-225.513658,-322.266701,-323.089056,-206.687168,-164.384724,-223.06607,-296.420226,-351.730843,-190.166049,-114.196906,-117.514983,-146.711127,-123.647472,-99.657583,-146.646054,-218.866713,-201.767055,-98.487103,-36.928781,76.180866,110.947918,105.594891,69.813103,-22.119624,-56.681826,-39.435176,6.794626,7.428744,-51.241934,-70.289614,-45.109484,-2.168573,52.619154,208.606191,240.354547,174.298554,134.950921,107.697135,76.742901,4.435823,112.446634,174.190564,96.695538,-6.693943,-115.901357,-105.610386,-69.010693,-27.178765,-24.655703,-133.447324,-165.558315,-74.8797,-50.255744,-186.811664,-292.557446,-401.913185,-344.012894,-299.885836,-237.40988,-216.042263,-207.923251,-219.739729,-256.915291,-274.030835,-226.405808,-62.626558,-21.231074,-90.699114,-155.510746,-181.906959,-142.248053,-68.53295,-47.471733,-55.737611,-41.628355,-7.615801,6.26076,-20.005791,-65.973389,-87.342518,-92.369637,-61.43022,-32.777136,-69.353846,-126.696833,-173.697282,-149.575351,-65.947868,-72.493164,-130.428544,-198.935656,-171.261899,-87.879102,-58.358651,-9.602204,61.341017,82.617664,84.464313,129.431768,352.960421,433.405967,356.170488,254.504821,123.976169,130.398887,154.571087,165.570173,146.563865,150.11864,188.609363,209.483757,142.059939,159.600794,294.41582,338.086662,346.366614,349.660776,317.17945,260.190626,130.488938,14.297582,-41.603843,-71.407003,-41.644285,10.919857,7.944274,-77.063751,-155.437091,-139.976072,-79.585788,-72.748924,-50.277986,-8.496457,118.081791,167.51708,177.152774,120.45358,94.83564,99.111751,130.465985,189.823386,168.559793,-58.318662,-307.714675,-338.723617,-292.642449,-244.041973,-69.568719,-2.975708,-40.790931,-107.444112,-179.398029,-113.409775,-63.34956,28.128413,63.547559,89.611608,72.246508,-7.212682,-8.529888,35.861117,105.939645,101.41316,8.798326,-53.209261,-91.606979,-66.259348,-52.213173,-49.349985,-11.01609,102.390971,167.029604,186.470872,77.933437,-241.28541,-314.86704,-251.103374,-88.774559,-3.845281,148.187606,176.885634,105.499502,13.922866,-189.511938,-222.766036,-180.459099,-118.156705,-116.93771,-119.102939,-116.883144,-182.917846,-255.936802,-218.707273,-82.568684,-52.798906,-73.56765,-92.68711,-139.574433,-168.193677,-179.049633,-145.485828,-162.498882,-278.816366,-348.197118,-402.399901,-347.887025,-197.213728,-172.20466,-149.72588,-87.237479,-110.900862,-244.937891,-279.919939,-189.434142,-128.455346,-150.175804,-220.291127,-198.275938,-119.210748,-123.108238,-174.793928,-164.096909,-122.238448,-147.987402,-148.682499,-151.477931,-163.736134,-110.78187,-43.520278,31.522788,-8.123476,-228.752194,-417.964472,-431.109244,-312.095519,-227.823565,-158.006125,-184.382842,-275.852619,-363.261339,-392.443624,-343.757376,-238.540151,56.285308,143.506741,81.507054,10.533242,-37.790617,14.751818,49.495165,101.868726,113.651389,119.064599,130.974688,121.813113,-0.159272,-35.11547,12.599631,48.34587,82.246231,97.139919,121.224883,106.998143,31.63285,-18.056475,-13.389024,41.368299,60.151292,10.873916,-23.025475,-37.593836,-74.998766,-102.782777,-76.282332,-5.858699,104.183354,83.400403,-47.272569,-118.838619:-164.904873,-139.990866,-74.708408,-1.183814,-3.099131,-22.290856,-33.942432,-90.329129,-98.98128,-49.040485,49.216589,77.262617,133.736069,122.26812,-21.200821,-92.962569,-126.625115,-31.994836,37.228205,103.943413,60.389562,-44.851704,-36.843426,-41.061207,-177.535342,-193.174644,-45.491898,48.186463,85.310509,36.525538,-5.200423,10.656151,-23.727456,-72.521561,-51.693383,4.174282,-5.789368,-62.01205,-57.743579,-32.414442,-33.058351,-6.691215,45.476538,63.479565,106.128563,106.957288,40.08014,-24.984688,-169.440842,-203.89308,-180.623096,-116.473611,-89.903642,-18.989659,32.274331,19.928974,-124.191571,-140.013227,-54.066006,-14.122955,14.515616,23.458577,19.54528,-10.198587,-55.424094,-11.990922,5.929883,24.47911,32.573935,31.366341,41.035802,63.053005,12.114153,-2.03438,92.353631,182.965081,287.266882,259.01551,81.95121,-12.172592,-79.567165,-18.788712,18.469809,92.053405,110.009307,64.045052,31.237823,6.542454,25.64919,56.092959,150.078667,194.276389,177.76545,107.126003,10.795602,45.06444,151.710681,145.966263,154.312892,229.383822,253.371558,208.752843,139.932018,-29.591778,-59.044168,-7.313659,56.189105,37.409373,18.069563,47.964254,62.668856,3.413739,-96.407003,-20.74435,12.538968,-8.051039,-28.855105,-36.048799,-42.302797,-120.586993,-208.935111,-216.955892,-164.206222,-111.225482,6.254159,20.249015,-91.790312,-162.448456,-171.820796,-41.467017,6.731472,39.241536,57.516374,96.93551,82.484082,-12.505782,-40.055962,-5.402169,78.234004,91.723862,52.897089,33.015633,22.169293,3.64088,-27.993143,21.498725,35.774457,23.011369,-3.984306,-105.935502,-138.939809,-156.250092,-177.48508,-150.401523,-19.38012,49.34453,100.079015,63.835811,-33.886081,-60.72787,-91.335918,-53.461105,-12.463676,12.53608,-8.172816,-24.041529,-6.319326,5.949471,-43.492657,-78.738,-105.052261,-64.284749,20.966757,6.748995,-54.690038,-59.310976,-74.060042,-105.768433,-91.302117,-3.145246,23.453748,-57.133323,-136.858814,-214.056714,-103.738897,-19.548376,102.398696,109.809095,-40.176182,-156.775835,-270.055525,-248.290784,-152.855627,-56.940586,-12.462297,76.435218,103.439622,80.47682,54.084538,-5.663922,20.076685,101.474221,224.313904,216.022913,133.67007,99.589521,51.675346,10.086456,-77.463499,-43.938016,-10.611922,9.212763,25.221465,85.49641,91.723695,32.758495,34.882207,90.959087,189.737547,198.298173,194.991542,204.836079,230.492763,215.673394,127.042063,109.752082,112.270283,85.460441,97.542857,171.921379,165.197751,1.933068,-88.973124,-37.781281,103.930712,129.970768,109.69518,95.171757,11.152759,-81.542795,-191.461611,-70.092861,-15.256982,-8.12105,-27.439361,-39.953097,-11.039321,26.468184,-48.68876,-41.504015,91.503364,132.906061,62.372161,-12.213469,-27.117383,57.599299,194.808552,110.564079,54.221974,78.498516,139.488141,177.048755,115.70702,-40.602958,-23.631562,25.526038,64.116407,84.400257,211.844371,260.369726,183.376605,96.870105,36.548868,168.26087,231.705638,270.936952,266.047273,226.526358,180.926746,74.56559,49.010187,56.798447,58.713379,47.955059,-16.055471,-60.933935,-87.450599,-60.697548,-8.829197,17.740434,45.89319,127.47526,148.040406,95.236493,45.312583,-50.62608,-81.287822,-47.092249,22.897128,42.103278,134.240868,172.214043,85.259643,10.814263,-34.708195,-5.46177,-4.639351,-37.248716,-46.547293,-45.140271,-68.007934,-188.705814,-245.688438,-206.636738,-64.940025,-5.987702,-11.188977,-88.268416,-235.479864,-234.333311,-96.969811,22.545449,28.191915,-27.913325,-66.178782,-91.54055,-59.222253,-2.215755,-12.478864,7.247573,134.731797,183.128733,81.003426,-23.963231,-40.040422,39.021156,73.228035,-14.566653,-32.294787,-76.776482,-121.547641,-168.486039,-137.092683,-47.303851,-64.453605,-91.032562,-79.951755,-25.896065,99.3392,117.741604,47.919199,-20.614715,-161.015902,-230.980529,-242.435294,-197.277963,-142.98439,-31.489624,6.574692,-31.756372,-181.700164,-194.276907,-9.846358,105.573451,142.137126,80.989717,2.174296,4.487973,45.92491,84.92647,74.383562,19.532686,-2.655558,-51.676132,-73.658696,-98.534781,-51.15049,0.667493,50.363168,61.836248,89.450386,67.826402,13.165002,-5.665335,-126.891597,-215.80644,-181.941252,-16.280315,47.487053,15.081134,-51.014095,-163.463473,-121.767244,-39.430911,57.310754,46.363073,28.98088,29.31196,-13.724637,-44.811901:backward
-159.459337,-211.881137,-201.542658,-136.477728,-103.06276,-56.644655,-66.445192,-145.739208,-168.046702,-136.871043,1.348597,82.949395,211.197227,286.622862,465.627074,504.546404,411.070136,191.328168,69.682092,-151.294505,-219.902474,-219.89493,-181.372339,-145.167033,-192.732588,-228.885698,-231.696376,-173.254843,-48.866022,-37.668509,-88.447255,-120.5101,-181.660012,-208.321969,-185.839147,-81.013424,-12.743902,121.437333,137.401818,12.605665,-131.667707,-163.497818,-120.415843,-33.514647,211.774966,314.659693,365.5085,313.980877,154.113724,42.839819,45.710775,178.704535,254.086936,300.12582,265.687285,151.558573,77.952239,42.133974,-44.450033,-67.216559,-82.249359,-105.122427,-173.315693,-186.098119,-165.139557,-174.714611,-181.765245,-127.744602,-85.143,-46.498627,-29.38294,65.56934,83.970301,6.532624,-136.432924,-133.25413,-67.845271,-45.589995,6.852126,46.330427,88.425745,-14.574387,-86.608278,-120.400371,-83.310723,-17.554101,-18.982159,-64.142572,-116.545534,-154.539444,-242.935723,-272.310853,-284.36845,-256.235185,-132.975883,-75.570881,-31.162927,-29.200556,-20.504896,-22.359321,-40.522915,-65.222724,-82.715556,-140.02344,-137.218467,-119.354558,-34.624725,38.94893,126.151453,116.95581,55.589708,33.110884,8.230331,-90.981766,-120.638138,-31.757028,27.427411,10.09234,-62.043577,-184.782073,-160.254251,-124.634167,-75.358094,-75.882113,-111.801782,-110.671403,-44.726126,-19.999151,-68.326772,-150.624914,-156.345381,-104.266883,-59.307106,44.360177,62.948177,16.956323,25.076856,65.69335,204.560769,282.21311,367.610497,398.689369,508.796716,540.261073,452.533806,318.595484,312.053831,388.913909,418.098695,430.106218,406.75667,229.173492,27.663656,-3.775073,12.790407,21.305535,75.11847,127.238665,166.637434,130.680289,40.564065,1.519751,11.547462,96.431142,132.074996,113.19165,68.221586,-40.399555,-142.558019,-187.133999,-179.258948,-121.560811,-28.443169,-30.315865,-81.947414,-85.159797,-26.300344,-62.022224,-112.472654,-91.507584,-18.555998,94.529387,91.028919,22.472921,-24.399332,-57.04734,-127.818406,-138.391986,-159.111204,-191.802552,-277.983115,-314.912678,-364.716523,-381.069546,-352.968124,-249.981707,-227.429548,-277.733143,-327.724956,-416.610861,-436.995574,-417.029661,-283.459226,-192.376046,-54.132113,-4.331608,51.619543,56.446988,86.518653,150.48947,198.511072,398.239702,513.925615,590.148767,554.201703,485.652036,458.101215,440.548222,422.688076,402.689885,292.023288,260.923463,332.003405,369.987727,349.55159,307.798874,301.767831,298.154987,308.419893,366.14122,392.802411,382.177578,248.498544,151.053317,37.330625,44.417444,78.021404,65.118951,-28.767328,-77.865505,-76.962422,-17.324838,-11.65093,-1.574929,28.99541,113.074482,146.187803,173.884627,127.540473,99.622142,145.452956,223.308666,360.554894,385.298011,324.77814,237.607583,18.219377,-141.855113,-167.941272,-145.029428,-142.733682,-127.91414,-74.246022,5.882292,-92.207813,-150.177024,-207.16282,-221.847527,-218.259266,-195.288575,-184.986677,-214.410799,-266.659856,-250.665669,-238.300271,-254.702349,-264.725024,-196.061231,-137.292969,-89.268771,-108.276927,-112.756295,-55.015772,-7.240557,32.728929,29.975668,27.574796,52.411733,184.525161,261.580085,258.495889,250.380346,248.731969,254.018793,255.099385,176.93806,29.764106,3.027527,59.956047,83.49161,73.729205,75.269327,145.495733,189.093899,134.729068,-106.832659,-154.593296,18.935934,128.559363,189.151729,169.674505,140.888719,104.064868,67.742112,18.065086,21.307405,50.345392,51.385395,2.817684,-31.890247,-84.48829,-116.226672,-125.222185,-132.602499,-150.729545,-200.683323,-202.186438,-138.470472,-81.721701,-92.807735,-143.712146,-166.56013,-196.378768,-189.583201,-152.221791,-130.575786,-50.458153,4.607557,-0.20209,15.40633,55.125135,104.939624,88.229236,82.060544,141.925096,138.64941,130.9796,170.183444,272.31037,292.810709,249.753668,188.663634,1.575917,-145.036716,-129.111617,53.882555,130.646351,133.54264,94.131831,65.682318,100.643497,110.931017,160.008333,199.781228,260.618426,285.588463,318.041254,313.09186,267.223573,209.433008,192.481389,164.258522,152.585856,158.137557,176.758576,211.801917,158.233854,119.351206,124.54028,168.820004,252.346949,261.594339,210.226322,167.249016,104.636577,51.091113,28.569253,78.174309,144.054393,276.668434,312.099,283.609987,225.717197,213.713124,179.432028,144.727946,107.876071,126.178519,144.422575,116.830035:-187.433586,-206.889727,-137.24967,-69.24766,-93.38719,-106.908453,-106.26482,-189.402669,-251.362464,-229.787879,-119.158208,-53.856654,60.997633,116.234042,191.576374,163.850778,6.872112,-59.727872,-64.927869,-118.382726,-152.142442,-165.629576,-161.816155,-198.281445,-283.469291,-319.585656,-261.700796,-151.725489,36.869399,36.279152,-94.301275,-156.048663,-195.869791,-110.326231,-30.258027,157.17582,252.891745,369.663784,335.127965,105.14344,-114.159878,-176.929515,-159.760817,-72.102605,155.086417,235.78,261.83852,201.403959,-10.100884,-143.553263,-134.523289,7.826423,111.108015,262.017036,245.55163,56.898761,-59.770987,-81.168106,-124.330313,-130.42046,-124.307967,-149.690744,-245.516113,-274.819698,-290.135033,-294.953684,-283.868087,-208.09566,-140.986127,0.684921,38.58434,-1.033132,-146.292561,-214.515599,-232.909334,-194.082005,-182.275058,-220.538565,-198.648939,-105.919119,-2.764717,-157.003307,-213.909988,-163.831882,-97.945148,18.422634,34.743151,-60.704815,-233.607924,-297.501087,-338.409499,-321.703273,-244.930685,-195.477192,-109.571337,-82.295807,-69.916318,-121.541369,-128.880417,-42.460323,3.811788,-26.852031,-103.561795,-261.393808,-305.974924,-290.447757,-183.159125,-104.274294,3.724477,21.017305,21.444355,13.314175,-18.944917,-75.100805,-79.124312,-5.991694,26.470557,1.139022,-34.004726,-59.152136,-76.103352,-109.660973,-119.067443,-81.809465,-49.623669,-61.903217,-41.573343,-2.114368,54.843646,28.579983,13.259591,24.10953,50.624428,137.317596,167.488357,180.747431,182.593505,181.539267,189.739637,198.182972,253.24451,307.738861,400.995277,397.483982,255.852462,133.292664,170.369599,344.013242,382.099877,277.098175,170.463589,-31.083865,-189.956348,-246.529601,-254.033832,-203.441715,-44.248136,27.078302,43.590952,-0.166921,-36.295375,-5.47433,-14.527909,-29.868915,-19.167987,-86.166273,-157.25137,-196.71924,-231.533742,-298.169875,-304.31758,-209.93304,-28.511699,-3.041874,-60.965143,-96.26719,-130.404005,-161.159835,-165.537989,-155.408393,-134.690534,-17.320681,32.374883,21.481638,-25.36456,-45.963183,-34.421034,12.644544,57.46674,8.177902,-137.335311,-183.939357,-292.643489,-387.603841,-370.132256,-317.00662,-327.095756,-350.453368,-347.342074,-359.757724,-428.104625,-466.815579,-402.155442,-279.965398,-41.79554,3.934027,-0.710448,12.01369,95.380987,147.256926,170.813691,319.09843,432.599716,551.305458,527.070603,499.293575,555.455351,538.739028,459.202346,434.185819,376.73518,356.257156,369.193675,370.307799,292.184796,191.59326,195.815102,295.315152,345.132242,381.576388,359.040272,266.05649,91.219133,-7.107842,-23.029899,54.892049,147.408363,127.832021,71.448468,65.843376,27.511364,-36.475807,5.686373,200.199853,269.047826,288.45541,264.863844,212.884056,163.545482,154.138711,235.531257,311.552176,440.860762,469.837574,382.620026,263.0079,9.245121,-65.295415,-31.635898,15.345304,-12.280976,-55.929192,-42.51389,-46.833665,-116.671718,-145.307062,-179.210652,-184.677159,-153.478415,-131.188809,-153.964411,-195.433911,-272.940277,-322.057801,-312.924799,-232.784167,-193.053099,-91.864818,-27.094224,5.301397,-58.65565,-56.163924,14.587444,47.269935,89.034492,106.434368,135.257413,154.228872,208.982984,255.171389,281.53879,333.754917,350.039225,397.678861,421.118239,366.221203,212.110935,159.363699,146.706004,165.226167,240.731201,280.793768,231.650377,150.077071,11.650542,-86.063682,-90.823881,63.0799,162.686084,250.888461,233.534534,109.478261,-46.670406,-88.927292,-63.046247,-17.017257,64.304507,80.196294,18.367163,-42.469908,-114.493191,-121.147876,-111.871251,-70.411064,-51.945355,-43.085586,-74.161002,-212.541883,-289.932506,-279.442452,-200.296562,-161.086847,-109.055827,-71.692078,-19.765061,-28.264743,-50.888614,-75.736172,-79.194871,0.576743,64.412466,128.097054,121.002264,125.333237,160.757893,154.198284,164.739172,206.370583,251.615996,239.024712,249.76572,274.97115,218.676259,15.954954,-39.126395,50.701572,129.58361,156.59873,123.934207,132.119083,186.046033,202.216311,304.329356,368.718174,409.025609,400.557628,352.129904,304.778134,199.457869,130.781097,115.614336,109.372645,127.434521,215.223644,248.889829,240.528296,157.906596,98.164157,50.749333,98.983582,212.064719,212.343753,132.70004,104.222742,92.483418,24.326677,-13.375925,51.313707,136.997593,270.988909,287.058506,195.793153,53.129584,27.679641,74.365519,95.472553,112.921271,149.255327,213.031498,190.851495:-204.819232,-289.234724,-265.228621,-196.845838,-174.642088,-102.687498,-75.902428,-115.631461,-234.80106,-276.538721,-191.107592,-74.39827,128.101403,184.399308,221.373461,184.827775,5.777462,-111.570214,-93.395488,-22.099377,-18.954527,-65.118327,-112.794496,-215.897276,-229.291488,-224.277929,-189.268538,-141.571751,-19.543679,21.635723,6.259691,-38.818512,-117.448759,-110.324207,-64.095161,92.105574,181.056685,272.923306,234.702803,66.191914,-69.442643,-112.452278,-118.758807,-65.691674,133.697597,229.513947,240.412917,144.823067,-94.523973,-220.328771,-208.997681,-67.96816,21.32369,111.76533,76.455941,-98.836183,-252.829003,-274.272814,-192.215888,-138.874615,-119.515939,-151.21339,-248.200665,-292.015649,-346.260869,-367.674184,-339.708122,-193.78056,-113.311844,-38.992555,-56.823894,-118.13743,-151.753709,-154.139244,-145.25956,-165.42765,-219.096646,-204.243843,-126.06959,-102.692995,-107.448658,-155.324639,-174.644216,-145.316476,-97.65736,-29.76066,-35.624395,-90.013147,-203.13978,-287.70365,-392.335834,-392.895754,-338.665968,-291.915449,-200.801792,-166.833097,-105.932126,-100.980232,-116.28373,-91.307462,-61.320631,-81.081376,-137.513579,-276.729727,-361.501263,-334.782681,-161.876376,-93.033935,-63.544715,-53.812417,-9.646868,-4.304379,-34.738956,-42.950756,-20.303007,29.751948,26.405813,-41.154105,-84.340224,-147.295498,-145.495729,-130.125223,-114.45252,-104.924748,-60.594726,-39.848368,-18.940964,-0.555944,85.681614,148.399647,162.347952,175.879131,174.678633,196.830841,213.43536,230.162358,236.586183,217.019659,149.870947,145.264003,258.531291,344.962503,428.605283,393.138187,206.437162,88.477541,124.210573,236.059789,218.41698,63.225083,-10.214726,-121.314358,-264.710802,-325.243637,-318.982107,-259.884172,-125.511106,-91.168498,-112.095023,-126.384708,-110.604078,-132.115338,-148.112117,-86.603894,-32.233739,-42.983619,-101.652406,-182.231505,-237.937726,-273.692694,-282.601682,-253.71052,-176.164725,-136.056711,-114.712942,-136.546302,-179.524693,-210.069913,-202.640845,-114.180698,-49.775143,60.183258,78.540028,32.958341,-35.062859,-51.033156,-17.709015,20.95238,70.120821,72.994706,23.695464,-33.814159,-168.008395,-271.804549,-303.541523,-335.055841,-342.380137,-362.242604,-383.126009,-411.673519,-397.721739,-381.901041,-284.895592,-196.771402,-28.348023,8.312467,-3.861651,-7.727685,22.127975,69.716521,131.216732,311.221335,372.535901,394.877255,397.393114,432.010115,382.116968,326.510781,297.632487,325.322485,345.196656,338.51245,356.706548,352.11002,233.039281,148.060966,178.187653,254.374596,252.029583,192.728443,164.895114,160.918828,98.40395,12.050429,-55.428324,19.891834,229.883856,267.175092,139.466672,45.366224,-0.834314,139.71175,219.633597,289.114601,304.61323,394.251485,425.126376,331.292857,178.437181,169.112434,294.117909,365.615562,422.278034,408.643415,314.919097,254.295861,137.271549,47.447103,32.159414,31.915225,38.93598,103.098037,128.184399,41.088277,-112.391693,-133.558186,-81.917205,-55.413449,-19.808485,6.814981,8.554761,-34.643603,-120.565909,-121.41854,-106.938699,-76.371516,-35.61049,115.480583,176.581195,170.508265,105.047345,93.620273,137.759552,189.192614,308.965954,356.805572,358.28048,306.652484,215.451926,302.397124,380.419116,461.355189,459.583989,423.153688,406.586268,377.18259,285.625662,225.327756,179.303671,211.263772,313.313435,330.015554,257.398977,194.700496,44.925816,-76.07408,-69.009489,77.977518,145.072576,130.030397,86.178055,71.155468,28.440305,-32.869001,-54.668451,5.587579,94.273197,79.504977,-5.255766,-32.723042,-64.417737,-105.113598,-102.720184,-65.363069,-45.504048,-17.417403,-47.587749,-228.228486,-340.10434,-297.135387,-104.539306,-41.999599,-25.744086,-19.095997,-26.757728,-70.013386,-142.249857,-136.802947,-129.43225,-76.784236,-17.336564,77.838731,87.847007,89.601228,54.983864,21.94515,31.124849,100.957369,295.047128,345.478029,274.723704,203.027609,77.100251,-26.950189,-27.079462,89.075282,151.452595,219.817629,226.734179,181.093943,109.581991,88.967971,151.716397,228.641332,329.632649,338.117216,327.623063,315.215094,250.5973,191.396301,189.929314,192.608362,200.942774,247.523956,266.631399,269.101344,204.250619,172.601255,213.632663,260.601819,248.455,196.200036,126.078624,113.621201,50.818593,-63.688571,-64.75594,85.357419,179.799724,286.755456,268.086511,112.90677,-31.706869,-52.143014,45.316904,111.747516,141.306813,129.883252,147.736198,158.903349:-230.202699,-296.20585,-293.165192,-289.575419,-287.476325,-251.755609,-241.853847,-267.071695,-266.063313,-239.014056,-84.842862,45.862048,313.243062,409.954615,484.475209,461.264344,315.657755,136.865353,79.275735,-4.260502,-52.188839,-145.304111,-190.749104,-262.94338,-278.883286,-277.200387,-192.071638,-96.746052,31.567783,7.797825,-120.942828,-152.298278,-139.857073,-153.773839,-149.558266,-59.095316,0.786667,69.214361,51.224606,-79.131753,-168.062353,-176.371619,-132.734443,-49.204135,201.379641,288.653289,311.382464,274.663181,160.679842,44.327669,12.859277,25.869518,52.794561,71.417419,32.659659,-104.114445,-169.496512,-169.463144,-157.002018,-166.359876,-229.487245,-256.4832,-266.375758,-271.268724,-335.13461,-431.210071,-448.334861,-332.434348,-221.602266,-104.795856,-132.266059,-203.618265,-196.815581,-208.916653,-224.567314,-179.169177,-47.275371,-12.521299,26.917444,68.275611,129.02977,-29.72953,-158.043428,-270.84596,-236.106584,-132.339084,-136.186462,-286.003318,-411.226996,-431.021403,-456.280767,-464.218235,-422.316786,-354.116362,-183.484427,-137.315112,-168.893234,-219.91622,-190.634087,-95.926711,-77.995412,-108.088672,-140.74457,-191.76916,-199.666264,-192.487303,-87.117883,21.345639,235.917263,292.942487,296.442149,269.732192,174.93578,-18.793455,-104.643877,-97.422587,-35.923714,-24.56066,-95.906637,-223.537828,-190.669679,-161.078547,-133.270364,-110.37418,-37.755582,-9.06427,-1.021441,7.363159,87.474412,80.351922,38.393615,37.844431,87.868564,170.715056,153.11819,64.241341,110.559797,158.329381,218.059904,262.181602,437.484587,540.189691,619.255538,562.885603,373.303398,279.980335,296.559564,373.462626,376.427177,289.368199,232.659335,146.444052,60.195325,20.361422,-13.697137,-10.041025,42.157774,80.632961,87.003356,44.536128,-60.04039,-139.723941,-139.648918,-25.947396,43.879263,80.506472,44.152369,-58.771981,-148.173997,-184.968209,-192.444495,-157.465247,-61.460962,-28.813761,-50.012089,-83.931666,-103.417644,-101.974591,-104.301772,-57.899495,-7.4695,90.050664,110.381262,107.423251,50.080501,-0.16886,-49.491753,-24.306675,53.532161,59.450997,-2.815449,-37.177903,-91.081791,-151.456464,-166.871458,-171.753666,-189.901206,-277.489821,-322.344388,-348.182831,-325.19272,-327.183748,-278.094583,-201.036331,-52.281751,-25.636238,-30.234013,-18.332004,70.864243,145.624899,170.176354,292.490484,386.150349,501.677584,488.608302,417.978321,413.131153,403.340615,335.117381,305.796776,296.159618,313.788208,335.3686,318.412635,267.383673,236.825653,245.608881,262.988803,249.684853,251.324559,268.77612,212.573142,29.020681,-27.150023,52.422804,134.389292,197.291231,177.277281,78.861094,17.11001,-36.587099,54.721509,121.016342,200.730115,194.071563,148.947585,155.503122,211.479143,245.389879,242.482516,234.318803,269.289179,423.132447,480.034172,400.62072,282.072414,64.006691,-68.469339,-111.759027,-116.962701,-75.897518,23.936454,47.742554,-0.870717,-131.761067,-170.194571,-126.475908,-78.009917,-20.883903,-16.225511,-61.15155,-99.985237,-159.472132,-188.777635,-184.134696,-123.818814,-76.438758,29.813957,62.874484,61.460071,61.363344,70.582859,88.688485,100.139975,141.257733,171.446756,199.045454,189.815452,177.999455,236.870885,308.390149,420.421402,418.044234,386.715003,378.093206,264.985622,75.689807,36.472465,94.155169,142.834199,218.336548,247.275629,257.337704,237.082325,145.13456,-19.291479,-61.593643,46.841737,134.217033,175.395661,146.958205,105.645113,34.974889,-13.32659,-19.461641,29.040814,108.298887,114.123545,93.888041,75.987429,16.029276,-42.882202,-49.627837,-26.478009,-36.320355,-137.333381,-206.360237,-301.75652,-252.230909,-206.690984,-151.542639,-138.38569,-145.152966,-145.420309,-96.574887,-68.85762,-45.469924,-48.210159,-47.56335,15.641461,83.09145,168.343533,150.44637,89.875566,64.455265,46.150764,98.159214,179.023404,274.302077,263.334697,211.804149,178.924823,54.538512,-105.889772,-127.871121,-7.337055,75.996328,151.39882,149.655793,169.402755,236.827221,246.380085,201.299413,179.968638,215.048921,267.216429,324.991738,306.584402,237.386103,202.520196,204.350417,224.769821,236.216945,245.318921,229.749213,190.759633,146.754237,114.858693,162.695074,242.493799,327.557249,308.732729,217.64804,163.645738,82.775436,84.001223,109.723645,166.088552,193.588001,250.677723,257.004844,173.669997,60.811108,49.583987,123.651732,170.993172,213.850508,218.357198,216.312467,205.140955:-185.249013,-379.903599,-408.644295,-335.14205,-301.419392,-255.260735,-245.672801,-304.244084,-328.397303,-285.018261,-87.674725,63.358483,388.980113,489.436834,476.884175,400.405589,220.958938,78.972381,43.924389,29.832099,27.44617,-17.357862,-66.974691,-158.735636,-203.698493,-218.623744,-168.697614,-102.160655,-17.481526,-28.244778,-70.370859,-77.646298,-157.379664,-291.286326,-291.511222,-150.79588,-65.552701,21.380756,0.554824,-137.226503,-258.887134,-264.653867,-151.134009,-50.424008,192.635395,284.421761,274.119841,201.041597,28.245172,-120.093333,-130.366711,-26.450532,28.240988,25.840429,-51.569867,-258.326372,-335.512176,-335.425773,-318.034811,-308.046368,-279.171556,-251.631742,-246.230675,-282.021995,-349.376292,-408.226031,-416.101394,-304.773173,-211.286869,-99.102887,-97.325412,-106.041116,-91.712422,-107.346107,-144.137115,-127.157681,-20.297843,44.558752,138.160367,155.333383,118.839368,-5.799102,-57.73397,-65.096008,-34.367566,-0.449107,-30.321131,-182.412173,-384.157279,-455.761508,-444.594592,-390.79141,-314.91988,-295.038653,-277.88806,-273.57015,-237.989988,-207.003505,-193.024294,-169.187257,-168.706065,-140.257282,-103.502812,-85.672178,-219.246702,-263.888424,-142.567113,-6.258724,275.939059,370.535938,342.617167,237.050515,49.716007,-27.71421,-57.266803,-75.302014,-49.020581,-9.369769,-33.935511,-125.674721,-159.418471,-154.517684,-115.760343,-77.653989,5.529166,29.413105,31.488385,26.114533,14.038485,-14.740147,-4.51119,67.188538,97.528373,133.027707,134.628601,87.449208,44.626802,49.061678,106.863629,164.632076,352.942332,455.902672,549.273173,520.374313,355.038197,211.984317,225.028622,345.552653,360.495331,243.470977,163.062076,66.303405,-9.560966,-57.489712,-74.941214,-46.529224,5.379162,22.303486,22.226712,-10.799274,-113.224522,-145.134095,-116.730462,-23.357191,19.2223,52.722038,36.70285,-55.593721,-219.330763,-285.220391,-253.00452,-169.417778,14.73317,78.350697,63.542482,4.71009,-103.840028,-203.989704,-222.054476,-121.702549,-36.027055,66.552687,57.095648,-6.60145,-20.960881,-8.575077,36.916398,73.186076,146.013958,145.92636,45.894224,-11.575114,-62.027982,-102.112944,-132.867703,-164.361491,-154.16319,-144.055123,-182.140224,-280.662952,-292.610526,-279.813158,-237.762428,-202.829609,-73.273608,9.391195,98.962336,84.280117,22.58659,64.527065,117.92779,205.802882,232.561019,290.2953,325.154123,367.88852,332.667167,291.406469,261.943595,287.363203,338.681187,346.153984,350.187303,337.683488,220.947932,147.307531,182.282725,230.673544,213.68023,212.424672,234.249808,208.430765,18.935485,-78.352214,-78.157556,10.593541,173.572658,192.732236,116.689307,67.930228,18.724567,55.880828,121.888954,302.76606,380.112489,427.228518,384.847887,272.997735,245.962933,252.078604,300.579849,359.178107,504.713777,532.798113,379.654843,240.722905,56.198613,16.420276,8.201779,14.544247,44.568808,115.526271,123.717424,54.180356,-87.522321,-129.762277,-83.930259,-45.43355,-6.609496,20.761308,36.896151,-0.157107,-78.800995,-90.709947,-87.168746,-84.970162,-64.181288,62.805121,130.73196,158.361919,102.379537,91.700255,151.820394,200.218218,256.872701,271.218709,276.626208,253.414628,160.79374,126.806818,165.028712,268.189941,296.236944,287.173156,243.004286,104.016533,31.661101,15.848057,4.56804,27.464188,86.20108,92.957844,91.936668,90.947899,10.61244,-113.52468,-109.98497,41.6299,128.769742,164.260981,101.78904,-51.278333,-87.893032,-65.871982,-16.519583,10.960668,95.481731,104.748956,10.858867,-27.625674,-34.966047,-70.436673,-103.268148,-150.422703,-148.844017,-94.369646,-86.65328,-178.580853,-310.92904,-344.19769,-229.133587,-116.442288,-30.56285,-64.058287,-100.924837,-84.584117,-102.998055,-176.011193,-144.268684,59.208312,134.224729,109.069504,61.546291,2.484999,-50.15633,-50.08531,52.910161,106.197627,150.200999,173.519941,214.637336,187.932098,44.746354,-96.23766,-122.823798,-27.452756,67.580931,216.528289,240.939604,195.892101,115.053756,103.967444,157.508361,193.699539,286.029164,342.630812,375.278775,351.432442,294.800246,288.589559,314.405576,314.935924,290.089539,287.017368,279.877611,204.489645,145.166317,141.983315,233.811909,304.115696,350.109079,311.878113,194.670319,148.124551,57.720388,-12.527455,17.958745,144.20583,176.986809,167.75083,137.534121,84.19642,67.971846,42.121521,18.449367,51.660782,160.992133,206.071018,239.82229,224.779128:-199.720746,-193.271247,-191.694763,-206.350791,-207.857102,-167.005992,-137.979953,-118.425082,-98.40231,-53.309181,100.54985,177.784709,309.875828,390.548224,540.699774,541.898351,391.258574,238.430455,160.102029,-48.126348,-134.367014,-149.982001,-102.285885,-59.633291,-148.270727,-199.429635,-194.33777,-149.89828,-130.445845,-166.778761,-247.821958,-285.754142,-372.123471,-405.197035,-360.531882,-184.946118,-93.199132,36.388656,26.881642,-142.953308,-211.726869,-186.431924,-104.314497,-29.243661,172.366486,252.27037,310.819407,295.926107,217.156037,94.17952,58.789528,132.092322,188.753165,147.438188,51.46306,-124.614934,-193.805295,-207.191105,-168.467496,-125.006817,-77.632158,-86.347177,-134.504705,-146.728903,-150.768659,-209.028554,-227.134838,-174.401414,-129.620836,-71.359037,-72.875669,-105.927035,-50.090646,-16.548876,-6.218565,-1.46452,46.396549,81.769083,117.534736,112.61018,86.795902,-40.16278,-127.092786,-194.27048,-161.107793,-60.249363,-57.312329,-203.600441,-314.404611,-318.186545,-347.565733,-380.795911,-376.388016,-305.060546,-100.306826,-37.168262,-54.569493,-100.347422,-83.388396,-45.68033,-58.134421,-102.157745,-117.528904,-128.761975,-76.133347,-41.545084,48.642478,117.33286,203.507927,185.248636,96.109833,64.505395,29.285354,-61.717576,-111.754907,-97.116117,-48.724635,-35.524567,-100.162153,-260.173818,-237.271867,-171.634661,-56.875413,-14.240633,33.363055,23.68097,-24.490066,-27.975976,-17.882364,-61.3738,-65.269135,-35.443311,-44.228948,-74.87393,-70.274317,-62.338677,-41.333782,-2.71698,162.87291,281.408494,500.178827,581.219674,646.429611,623.191527,542.205754,453.879861,406.449547,358.285202,348.327615,316.436502,303.714723,279.413218,216.074776,176.147256,156.739115,171.072376,204.799412,224.456037,214.900178,168.65336,36.721655,-64.606452,-84.699783,-61.562044,-32.633323,15.0428,14.543059,-22.184114,-82.632655,-145.095015,-183.553189,-96.073021,113.787914,134.699033,17.022394,-43.727154,-41.193409,-15.005517,-18.343697,28.355015,63.424128,111.522737,135.382457,185.886341,173.633713,128.526259,71.021718,97.077229,141.767947,107.193621,-6.119365,-44.821502,-93.511317,-97.943065,-73.456925,-11.208747,0.296215,-60.695761,-131.357718,-196.102079,-102.896796,-91.871548,-89.023118,-19.013233,163.104043,184.35366,83.001549,43.230488,105.145861,221.86238,276.480415,383.062516,414.112349,436.264192,424.563909,339.509224,276.926483,261.449991,199.731699,162.941351,158.848459,204.001799,299.78796,314.058526,313.471237,314.068038,296.882878,222.90119,199.706234,266.572621,323.770329,327.998639,181.972812,103.834662,54.943674,92.091911,169.525251,169.627887,115.702252,83.516097,34.21633,6.41336,13.302058,56.859105,68.238567,67.173142,73.232078,132.285546,200.240063,188.691798,159.323424,202.705046,321.475263,341.894059,295.213502,236.441095,104.321335,-10.308935,-71.418976,-143.824746,-129.734416,-31.93737,8.82904,-17.348695,-116.329142,-151.244024,-161.604168,-144.139707,-147.742346,-183.098092,-226.282475,-207.914598,-151.861703,-162.625389,-188.725887,-248.293855,-264.257631,-197.858033,-136.770354,-79.187292,-75.569092,-64.889026,-32.063602,-29.220879,4.628496,66.651245,156.419361,154.546016,159.327715,172.70964,166.980126,136.036442,117.841777,112.396408,108.097675,3.854739,-153.86256,-191.932606,-131.961556,-60.373766,50.739766,83.474558,125.540149,128.998128,60.61171,-67.893056,-63.129648,110.630118,163.385292,96.55225,72.966485,152.859834,161.320585,94.75539,-5.310063,-3.371018,29.509001,33.162361,7.922512,-10.750547,-61.664781,-99.734226,-100.718722,-90.708803,-79.799563,-70.964566,-117.773545,-298.325118,-354.897765,-313.736943,-226.106445,-212.943158,-193.208207,-157.979657,-88.32845,-77.450273,-58.274948,23.130606,95.766974,212.464517,202.647891,97.83286,68.837403,92.200239,83.797268,39.098486,-1.099078,50.822324,209.278972,242.832216,172.774266,101.721897,-66.746661,-237.024614,-257.436263,-117.946728,-12.889156,137.050994,159.854417,131.104771,104.301424,104.885694,144.237528,190.044158,277.59962,284.02082,236.305289,210.754934,175.422086,140.427487,144.584376,181.220556,178.291678,121.277069,90.671548,64.015174,83.749612,96.991704,153.51681,195.580856,204.264873,163.420696,95.739937,92.251992,74.37628,-13.382221,-25.914116,93.928376,168.006472,207.711856,185.553241,142.84905,170.170573,199.512991,221.985531,205.72279,181.60696,199.949129,226.610602,194.866035:-272.593519,-395.640431,-385.141623,-347.876115,-351.602043,-318.502779,-291.612169,-311.42548,-331.776813,-287.163229,-80.794184,51.411688,314.029899,419.017985,465.174022,395.063095,189.76013,10.462766,-53.773585,-107.693519,-102.431363,-67.240894,-80.421661,-198.119344,-274.530049,-276.433405,-198.55406,-129.346879,-65.241115,-94.227691,-207.886732,-264.503195,-338.188955,-361.115817,-342.528702,-210.932403,-106.493921,43.001667,9.898673,-218.244548,-344.398387,-321.238408,-161.282318,-41.47633,212.78758,290.053292,306.078955,271.677009,105.118827,-115.344039,-146.063313,-22.198395,51.248542,27.924719,-74.915506,-269.126947,-324.088403,-356.498535,-424.169138,-413.334606,-301.495483,-241.544063,-211.580278,-246.931006,-356.523866,-424.417598,-412.030944,-286.315243,-208.165884,-135.485493,-145.988185,-167.032664,-164.328315,-183.12279,-180.068998,-107.840952,104.56919,179.092741,208.105861,178.048073,81.893895,-58.490086,-138.568588,-229.877109,-220.712469,-156.599168,-157.76121,-290.703701,-446.766342,-483.424478,-466.349774,-433.112177,-385.48319,-364.850807,-283.238316,-232.154477,-190.630371,-227.539735,-213.908315,-98.490777,-55.178125,-74.638995,-114.795317,-167.546412,-162.870147,-130.399028,73.218062,210.180743,377.720411,390.041513,309.563817,232.34656,67.049395,-71.674177,-110.956094,-68.190462,-13.728067,6.49046,-53.361578,-213.834869,-265.480496,-247.267862,-147.934665,-80.242878,37.037496,69.73272,48.323664,14.975022,-10.604867,-17.865431,-26.920804,-25.521963,-0.743173,81.233253,87.508008,-20.471478,-56.546129,-3.021576,165.770241,261.018133,457.530458,540.337771,569.093407,509.336058,358.618133,276.395158,277.678382,341.648851,354.302819,276.015958,223.318056,145.153605,41.130351,-0.482389,25.886181,80.199136,198.232979,240.267716,178.701331,75.655168,-69.646348,-59.690509,-27.877819,32.04827,32.536123,-18.927262,-52.539632,-119.258746,-130.939971,-116.806585,-58.038348,-12.672472,68.711379,84.769031,27.712964,-32.94136,-129.088048,-161.847837,-139.651295,14.014021,107.78026,212.682982,225.187282,236.517044,133.989329,35.047736,-29.453402,45.803626,232.830661,261.91091,160.794122,72.047666,-53.511798,-66.010702,-41.172921,-11.09601,-29.150998,-102.203276,-135.233365,-138.959998,-127.919618,-157.868203,-156.103802,-67.474859,145.791829,173.804661,91.625419,72.593884,131.576471,180.643685,204.336629,296.969991,350.174871,401.643662,382.124489,294.930584,251.822073,247.104853,243.778032,233.728748,188.826554,193.46974,304.343735,345.670168,268.839484,160.589197,161.850574,207.389129,225.508091,273.142095,281.543043,183.233526,35.017607,-4.436908,59.417569,155.957021,318.726297,326.32103,196.441647,113.303281,21.723047,66.711855,149.820213,331.685987,367.714617,315.487774,269.188491,264.193332,356.816698,367.435056,322.228904,322.815127,415.977274,461.269193,408.732681,320.48285,107.754817,-84.591498,-115.70986,-5.212938,80.206322,172.63953,156.732169,29.62647,-128.8539,-177.960184,-112.210713,-28.023006,46.036256,24.301019,-58.331902,-108.171098,-191.434904,-177.958228,-133.176959,-35.423688,-6.581388,-13.008806,-39.545325,-57.226122,0.036711,19.119751,30.302225,43.754741,127.208051,177.518609,175.584906,119.959722,22.687299,43.224614,76.792003,113.376648,126.357762,152.970123,116.435631,-79.513254,-248.180227,-284.138822,-188.337016,-74.92959,58.208049,38.648227,-43.683439,-68.955849,-127.448152,-199.820795,-194.504984,-69.155018,3.048948,54.171712,30.366274,-47.849768,-88.198178,-96.245783,-73.378093,-33.216252,87.897119,135.563084,95.298313,15.255014,-144.608894,-191.497632,-150.106462,-15.660029,4.376149,-103.959181,-189.967709,-337.377595,-426.364055,-437.853315,-355.750234,-284.243822,-156.847565,-88.376496,19.531748,6.26886,-120.374137,-171.443984,-125.362588,40.809155,106.837221,140.729234,111.880413,14.880514,-79.938893,-103.549137,-4.031122,111.15616,303.657983,318.480316,203.703764,122.525525,-88.002273,-258.856309,-215.979445,55.9779,172.621207,231.449892,199.422204,162.405583,185.407998,189.989412,232.483484,259.915713,231.160458,208.323008,247.226624,272.214035,235.764055,169.065933,181.706542,270.549195,298.752854,282.996211,239.664719,105.807401,19.736085,16.816486,76.822354,127.232876,214.181837,219.527476,117.688262,44.619467,-40.892793,5.060625,72.471158,176.07271,180.541854,151.778399,132.948227,76.158526,18.785145,3.753361,65.059653,137.754919,217.612195,196.893155,158.072505,160.136994:54.571311,-79.047043,-126.123633,-69.427235,13.207916,140.090764,149.153016,123.720515,170.10624,186.450408,176.869036,203.39202,321.357101,373.955188,428.926605,434.767807,439.563529,368.14811,275.389942,61.974451,-15.69233,-50.182972,-24.94751,5.041373,-16.428547,-34.356063,-60.537062,-84.710359,-183.273957,-217.71146,-224.360298,-236.790933,-305.310749,-338.355189,-320.655621,-214.581443,-140.132792,7.668414,54.330978,34.615891,-27.69645,-15.225483,93.434441,163.541755,251.684884,255.818514,213.357582,170.663701,59.838492,-38.009599,-49.898982,51.239082,127.225202,173.373982,129.215042,40.211078,21.673621,-12.951744,-108.231529,-115.473739,-54.086517,-41.094627,-132.324014,-192.560551,-221.04556,-164.790322,-119.650277,-45.083173,-29.418484,18.66926,50.367419,70.685171,77.478392,79.113862,86.911141,111.989953,175.100319,200.115678,237.529351,231.224296,142.045709,2.410205,-50.787175,-40.087208,20.04934,129.179719,134.369491,81.570162,24.471765,-23.92996,-125.889049,-140.286978,-78.961109,-31.502991,31.488418,40.461659,25.306792,-19.43428,-32.062157,-30.091005,-44.169964,-67.717948,-53.687561,-28.386013,-33.405564,-46.545554,-71.818612,-52.691216,20.68808,14.64655,-94.996147,-138.250343,-165.900645,-241.702903,-285.767137,-248.235673,-187.503088,-157.37632,-199.202646,-262.337221,-224.551221,-189.298588,-86.705392,-45.622566,-64.196471,-86.581355,-48.540425,-6.648893,36.864105,-18.884676,-74.811744,-154.88282,-147.456824,-81.856818,-67.2201,-85.428573,-80.64085,-46.085778,113.034874,211.025969,341.338178,375.352691,441.786593,482.178977,552.955779,513.509748,462.516893,442.885467,463.300615,409.965306,336.211403,224.471673,230.153031,236.234501,210.438916,202.122968,227.741267,251.424823,221.940241,131.31621,-85.880734,-107.041368,-61.874409,8.722175,33.476109,88.669068,82.658381,-21.805085,-85.167962,-82.109718,-23.262595,26.169759,92.372549,84.369153,45.134382,51.310269,115.801712,189.470324,229.887913,326.436208,353.193103,341.141763,337.812275,368.19616,374.262337,363.307901,325.164163,282.763183,166.00351,120.221232,70.523444,56.846935,51.929043,90.761391,126.97678,195.376978,209.852878,207.501154,193.763427,149.673099,131.495641,132.128975,137.033331,157.123114,217.044569,208.94798,102.55853,68.095095,112.129515,153.05129,171.013037,268.609599,300.548735,249.305446,185.986251,35.153284,-13.104793,3.498097,-10.035255,-29.490801,13.04233,66.524626,135.297538,139.084894,137.445033,126.283882,124.253623,176.381078,221.457606,296.694098,307.177778,264.03146,235.355095,244.161087,234.541751,198.000505,105.146722,71.454348,64.156541,79.493523,51.623162,-85.156498,-138.313681,-132.57881,-97.852146,-19.860382,6.135598,-14.855673,-47.870611,-37.022861,53.313446,123.667251,200.013278,184.606908,123.411453,95.893117,33.106329,-90.691749,-162.7389,-162.422027,-89.267594,26.891878,43.993133,22.120628,-97.292063,-165.864806,-231.915284,-243.923644,-279.501029,-282.048942,-217.054336,-171.376415,-91.179783,-87.816425,-114.714376,-172.502799,-210.314893,-247.914036,-220.496702,-133.403728,-100.742913,-121.770274,-163.675265,-150.427779,-82.235587,-57.122004,-49.620817,-58.095445,-85.479537,-155.927132,-190.931962,-169.821214,-120.458918,-60.051251,-76.670948,-198.675567,-318.170551,-333.113172,-287.544106,-245.365784,-148.829046,-94.086059,21.985392,68.941304,74.314871,-29.538331,-68.855505,-60.35956,-35.036296,5.033183,29.531628,78.988649,7.338536,-76.330661,-157.299683,-117.315995,7.904185,45.461283,13.637797,-49.531733,-170.879856,-227.516665,-241.201428,-248.078724,-237.834307,-223.061227,-242.607569,-323.46841,-324.638004,-286.149162,-194.745568,-152.13186,-104.983722,-101.820285,-115.915319,-136.131675,-189.300338,-150.015457,-72.254532,52.206557,26.57966,-162.248954,-251.731349,-300.374764,-216.750233,-188.982846,-168.072131,-154.875965,-160.755024,-177.626929,-182.592426,-179.788548,-221.417388,-284.276984,-290.323975,-241.724863,-194.263495,-85.336199,-41.885276,-15.185057,-43.01482,-50.32257,-16.725356,-1.055703,-27.485968,-32.749857,-5.83367,-9.708497,-22.938935,-26.778147,-47.762762,-95.983337,-119.821678,-176.104881,-186.667677,-115.416248,31.396389,71.098202,66.799189,64.469795,96.561448,117.839809,103.175631,70.079847,59.963876,45.941227,-8.855433,-76.915223,-55.404578,39.392025,86.095601,151.098153,200.586915,212.010708,179.344389,142.172145,124.737347,168.687545,183.688682,88.019147:-116.656191,-94.51704,-68.451837,9.650094,63.757298,163.833214,172.841162,141.348457,229.975621,298.337771,344.168567,338.216411,370.387427,404.685041,439.025441,445.083556,478.58025,391.704095,274.852943,35.52368,-31.788349,-26.461713,-8.865586,-62.919893,-93.224509,-70.534296,-53.060072,-71.56198,-85.04793,-69.233682,-137.416947,-239.631238,-382.724971,-355.810775,-318.512381,-229.231374,-178.27785,-77.179311,-46.628568,-81.099496,-179.174865,-207.640526,-149.461808,-58.458983,147.414126,211.429992,213.139423,173.860935,71.410846,-39.720908,-44.06312,132.009296,249.28271,330.45929,270.358072,98.640267,51.674876,37.60564,7.355722,26.399501,42.606568,7.464218,-33.56569,-20.740968,-25.253909,-69.165057,-59.331888,30.316628,78.9579,124.17129,123.475838,160.520905,234.894629,221.242708,96.092594,54.447602,90.872424,134.893729,177.630064,164.841106,76.496155,-30.477657,-40.02538,38.717025,92.278565,168.867014,181.587032,150.985386,83.7726,51.780089,2.390517,-28.261323,-87.516885,-82.505815,-8.805825,27.883883,81.423491,55.82511,-7.016387,-106.842918,-106.497556,-68.943561,-59.890267,-57.042569,-81.772863,-117.98359,-137.859159,-86.3228,30.754256,46.308987,-26.062049,-85.208315,-157.069479,-193.541172,-210.266127,-158.597073,-93.709911,-51.831904,-106.377737,-171.067517,-41.31184,8.898451,-16.942716,-54.988633,-77.066587,-44.580177,52.955795,63.607736,-25.511698,-130.189197,-143.476262,-118.0824,-110.781825,-98.830962,-90.806816,-96.897578,-51.66161,-3.644048,110.354892,170.143248,284.544675,351.866316,474.208238,506.706881,510.705848,449.776199,440.606695,459.134147,437.302228,350.721006,330.009687,295.733108,211.859885,173.090317,106.467963,74.248319,45.169222,64.760852,114.61302,102.928973,18.650361,-46.275856,-38.803769,74.83716,137.849437,164.80461,133.838155,47.3562,-29.782663,-56.6097,-9.226359,76.750176,235.16365,237.950478,110.722884,64.271432,99.277703,148.17175,152.014993,198.414984,227.730637,213.268282,188.643829,201.579084,243.980733,205.022176,46.987993,8.934524,15.050606,4.813094,-61.661057,-104.542118,-183.562066,-164.719035,-99.192932,57.893217,88.568505,42.967668,-4.709946,-100.845447,-135.033508,-133.669228,-106.073214,-76.40188,-28.694237,-21.660209,1.333965,20.66749,68.095102,170.712012,240.987487,299.883129,267.636617,215.840221,225.281919,204.079228,142.237121,155.809524,218.310285,214.84878,156.313992,144.421593,173.357817,199.407507,248.241699,206.682095,167.352346,178.334104,227.00274,312.560717,320.623427,295.083566,223.689875,138.256431,-57.328952,-99.51337,-47.283565,-4.241988,7.144126,-28.710826,-129.419338,-206.458917,-209.099175,-173.897911,-168.380187,-124.274485,-78.893942,-67.921005,-119.833652,-104.864951,-1.189313,71.231496,206.076464,231.109864,132.364363,33.580026,-124.679598,-216.924573,-242.622879,-187.123014,-132.969461,-113.086785,-138.040574,-163.696273,-190.090055,-216.958589,-259.703217,-263.677771,-256.398446,-252.970669,-257.113039,-258.112688,-228.522927,-198.498078,-187.038976,-168.30113,-165.037856,-152.897821,-151.311895,-149.809926,-94.657307,-72.245898,-60.951394,-67.300675,-91.486816,-80.04666,-0.669615,43.264859,112.400339,105.049171,70.831986,21.419785,36.530347,135.456787,172.313181,105.548047,-66.227864,-120.200996,-108.83865,-70.749059,-11.316397,25.428085,140.961187,164.36766,58.495298,-59.579745,-43.391899,98.540377,165.318485,211.291847,196.675605,136.196262,56.605333,12.391134,-15.144847,8.231287,28.466963,13.701374,4.249034,16.597274,-8.675157,-167.732163,-233.888165,-235.376496,-208.037806,-191.141317,-201.056249,-188.016307,-138.982442,-138.501527,-160.427119,-166.832686,-166.614467,-153.429371,-98.722407,-74.181813,-66.34057,-75.840782,-45.492888,28.356872,3.592937,-139.394415,-183.688932,-154.396295,-92.125833,-89.663171,-52.120405,15.981945,132.729284,121.940299,4.233696,-43.632624,-86.25086,-132.192943,-142.954165,-90.666193,-46.322962,3.739054,4.163453,-13.05115,-30.681223,-27.980048,55.728863,106.985928,107.623496,90.34746,114.292297,119.846888,67.618244,16.275902,6.104654,-28.714147,-67.293397,-119.954415,-106.025492,-13.45788,105.435225,137.973569,110.645469,71.437072,62.477401,112.712869,216.677633,218.014225,93.912269,-25.038965,-14.299523,85.820722,128.492569,221.161656,279.319119,324.002455,289.413538,281.739816,284.018485,286.542233,245.319059,199.066346,125.245333,94.371698:-121.04013,-255.676255,-303.704326,-294.784538,-241.511639,-108.38837,-74.033735,-97.249616,-70.236668,-21.829193,99.412717,165.69663,234.099664,240.59197,291.596679,317.940799,249.56563,48.902611,-30.20068,-98.974895,-95.818213,-28.427418,-3.434936,-28.140284,-109.189488,-146.759612,-134.737054,-109.548573,-165.780355,-221.10996,-258.793632,-246.236455,-183.461617,-154.636385,-176.217963,-141.88298,-46.418821,107.278751,71.699552,-107.960753,-111.641356,-77.851001,-3.844944,61.499368,155.964981,151.48107,117.851802,122.137061,140.981527,71.956677,22.096352,13.587996,49.26743,67.143281,14.965564,-140.637422,-192.48074,-207.159753,-286.305566,-303.797404,-215.01791,-164.097241,-191.387845,-228.902086,-236.766446,-238.000198,-231.781153,-140.43873,-78.222264,8.781869,30.76234,41.731842,25.182462,14.875117,37.559418,72.66447,122.001519,136.573557,140.437462,91.774984,-53.247835,-118.24001,-131.497974,-125.89143,-102.961126,-84.297753,-116.023219,-204.789066,-311.239323,-376.503394,-371.159743,-291.404868,-188.795193,-204.638086,-257.260441,-242.903652,-145.993552,-148.481073,-188.507292,-199.572432,-151.804974,-44.487166,-39.588412,-85.924742,-36.845448,7.806471,110.387268,173.744895,246.912996,230.382012,132.406214,89.811247,33.098234,-71.074068,-109.335838,-58.694829,-12.206522,13.802277,4.437185,-29.400892,-61.012685,-52.942618,13.453817,35.913654,28.758437,34.202035,62.470004,63.364145,46.52454,8.972814,-8.443983,-55.0746,-88.841162,-103.133717,-75.166065,-50.881879,-75.08603,-63.42747,47.683164,136.46217,303.314774,383.090018,540.439924,588.622904,572.56721,448.130553,395.628912,362.267077,348.301095,275.397258,237.280471,214.160301,252.085756,256.000379,244.447574,268.396401,322.698668,283.490167,80.434562,7.944097,1.690904,8.841962,25.652801,108.515059,122.84092,66.198348,12.1011,-118.419186,-129.400617,-79.697865,22.116437,54.034032,57.9469,30.701748,-28.843066,-50.21226,-46.229642,14.840821,35.923054,99.058956,161.710436,284.260901,309.448002,279.926333,219.894901,195.674609,210.342396,245.037556,233.097571,174.18337,111.956942,138.347507,163.27019,102.689846,97.351939,110.104187,97.641211,53.087418,31.983396,-2.731557,7.473746,13.486607,-1.760744,17.652828,116.449177,131.894329,63.201354,38.683453,98.675579,163.632831,165.968478,194.187513,218.205844,221.320749,200.105968,145.970814,105.453069,96.058135,91.47552,80.236521,58.306153,70.938582,95.653914,91.339375,97.748604,91.777918,83.328987,83.196327,90.630296,158.102823,209.21925,236.535255,117.016833,48.765765,34.817125,88.316871,196.960972,223.833786,173.20943,102.409553,22.775957,52.742259,69.001832,87.716841,90.981491,79.48728,74.843982,106.293028,214.743216,266.487397,300.328041,288.914408,231.977333,205.327662,164.254367,124.846813,44.787318,26.240959,22.254627,15.546704,11.769773,34.800485,60.385405,31.593607,-73.477898,-100.458971,-111.433219,-119.055162,-156.182858,-167.71064,-173.894933,-178.967462,-144.104951,-71.776205,-41.26226,-11.786472,-45.855716,-149.738982,-145.275206,-50.759933,-72.409655,-131.899411,-172.763592,-127.391794,-50.805734,-46.704682,-55.933698,-63.566576,-73.51519,-101.200002,-123.775682,-132.41951,-109.092424,-30.950688,-8.979812,-76.38745,-201.557932,-245.99363,-221.472887,-159.466664,-112.354791,-134.878546,-122.828657,-87.389233,-78.271774,-135.681176,-137.01386,-62.770562,-17.887389,6.616664,-4.267864,-7.742075,-68.669896,-152.547704,-220.14413,-128.794404,110.206397,150.766491,66.842248,-5.503733,-143.909301,-216.453222,-197.48969,-150.310198,-176.877732,-247.506911,-250.234641,-273.628384,-294.961604,-281.799883,-243.578976,-191.941766,-42.54555,-10.864886,-98.765829,-168.310634,-176.717551,-31.418945,56.101078,200.600051,209.173952,108.086297,46.605804,-44.453735,-39.356937,-7.141918,64.03866,93.079866,91.04984,49.533825,-46.632542,-59.651753,-50.843895,-126.613316,-151.058664,-82.654859,-22.049595,76.494094,97.066708,71.689157,97.958967,129.602587,135.052663,110.245342,55.789914,55.543142,111.072051,124.048859,102.747538,72.324076,57.39435,78.362759,97.034338,41.857536,-15.965567,-65.709981,-14.162721,8.011928,16.863984,32.565346,83.705836,92.278879,78.300947,82.052601,112.829553,75.345595,41.363474,33.392311,34.493535,-4.312749,-4.048271,76.293785,137.043422,122.321774,73.674484,83.952709,103.189191,84.728608,51.513159,29.76236:backward
-119.352606,-232.324041,-263.767365,-272.550737,-245.700968,-133.457884,-66.889374,1.354732,-11.107887,-5.04542,-18.559605,-54.154741,-73.056535,-31.308326,56.157919,57.829221,-35.682982,-133.25804,-144.823752,-159.870107,-189.420527,-224.619846,-193.692998,-55.042895,65.100683,96.89834,102.334837,75.686614,6.585889,-11.427561,38.628451,74.975747,6.771994,-184.264619,-259.700814,-320.758352,-276.326358,-87.569769,-21.489324,-4.888744,-101.993101,-183.357394,-315.528976,-332.421642,-227.388087,-131.310609,11.022661,51.867703,70.374811,10.267814,-9.843834,8.411736,47.951349,127.507795,153.703931,211.721377,180.135086,128.357477,83.338772,92.501581,97.75089,103.26959,182.649392,216.105781,140.825238,3.272463,-14.983676,52.211234,100.631146,120.30377,89.152409,27.156099,-20.381557,-42.930826,-54.583448,-41.495064,-2.618776,19.605851,55.531773,49.860263,7.81243,-22.416488,-52.675708,-130.83133,-149.077515,-84.547613,-10.519758,136.92785,175.448533,115.293164,-107.558809,-173.090973,-131.484863,-91.386312,-86.979935,-92.653204,-33.435443,35.984078,16.192351,-132.053943,-200.798918,-235.277428,-213.598229,-153.72202,-141.340813,-165.730966,-259.388251,-280.649216,-159.528312,-52.811019,101.759676,142.284666,177.602363,179.084729,162.648095,71.537915,30.652282,45.026627,101.449561,234.375482,232.073897,199.369924,130.498767,87.984,57.119927,104.27578,262.681547,318.99531,314.306284,177.421648,97.981698,6.270822,15.114016,102.139905,149.767125,236.727206,281.636887,266.633772,133.230861,21.906614,-121.295405,-100.870885,25.13334,76.042455,60.583612,-50.324666,-57.944052,46.014563,104.038886,131.73047,132.192188,207.348446,257.456691,226.493571,105.658646,60.796979,73.888124,113.878199,177.119022,167.986456,-18.871577,-244.340042,-280.048215,-213.13966,-129.19471,27.365607,57.730103,85.9482,154.554219,185.001085,135.946502,53.115645,-73.412137,-56.942704,138.66583,253.842617,308.534001,173.161417,115.93011,55.239761,43.270874,38.944979,41.490419,20.974202,-66.662388,-94.07209,-50.946452,-13.815045,19.451278,36.062944,104.371613,112.783089,23.427613,12.261925,27.784667,-55.499409,-97.449915,-12.842205,71.69673,159.164285,136.39996,130.014327,144.221855,147.819109,176.949947,191.483978,149.683919,108.730005,10.371482,-117.107871,-164.039383,-148.419925,-98.97033,-33.64237,-13.799854,48.68464,47.512566,23.427357,-46.162566,-87.104254,-88.194042,-37.626551,81.124319,113.217342,47.617789,-58.719633,-48.8248,17.298433,30.918328,6.294403,-20.486689,-0.369337,49.336687,13.0307,-133.973844,-187.075014,-160.050549,-94.832073,30.358632,60.775292,-27.601527,-260.91135,-350.064435,-399.229435,-360.436857,-220.08275,-155.3532,-70.419019,-44.067045,-39.381767,12.55412,85.684053,238.604779,258.487227,243.010657,252.379269,233.527194,135.147761,95.599588,29.036743,-0.041561,-61.062161,-101.858559,-177.576678,-267.828575,-314.43442,-350.004318,-350.626706,-316.825027,-266.481949,-163.220796,-160.084876,-298.660305,-441.210115,-425.510352,-262.16959,-171.699018,-32.144617,4.047322,-32.827404,-115.86808,-107.088299,-32.623735,-36.600821,-130.399267,-156.713183,-117.135609,-90.848678,-126.281701,-282.856974,-349.337246,-323.576917,-236.770539,-126.951818,-173.428572,-330.529819,-319.360632,-288.028351,-266.514825,-252.427384,-183.554033,-157.807708,-177.870619,-214.971856,-301.061041,-302.742819,-295.441979,-310.098402,-272.22634,-113.88609,-61.7607,-23.126826,8.254713,35.125572,40.369651,-26.629767,-127.923306,-69.344402,92.949695,94.846379,33.726706,68.225851,56.88258,-93.681029,-131.862444,26.143643,164.280152,329.367387,266.12714,218.583928,147.035186,117.822435,139.533067,187.363465,218.522029,163.262788,19.430651,28.173283,43.896269,-52.934529,-131.086172,-203.300137,-181.15173,-74.681883,-121.318389,-220.710174,-342.338739,-322.180419,-212.054817,-160.613623,-81.748618,-56.652983,-76.868394,-192.539792,-264.114419,-339.372677,-327.028228,-246.083337,-187.089289,-77.923853,-53.932097,-64.727002,-98.494201,-99.902603,-11.200166,64.841211,162.477911,163.41581,134.597871,78.150616,21.25124,-78.527384,-81.353147,-32.186468,-33.154575,-107.922508,-158.121756,-162.146743,-182.465435,-194.023275,-160.696959,-117.64402,-59.28528,-68.739315,-148.061091,-193.168947,-179.91155,-191.478612,-211.491299,-140.688644,-82.833784,-163.600038,-356.316902,-364.671197,-267.393452,-219.686809,-159.111759,-142.391937,-78.172682,-21.841839:-75.716104,-180.268938,-170.94129,-155.60285,-159.60643,-108.48223,-74.084595,-98.564711,-119.944788,-89.160134,-90.318198,-129.774255,-122.55462,-53.504345,66.732975,50.118058,-134.469821,-271.755831,-273.163987,-238.453769,-222.976176,-165.520283,-123.635191,-25.087619,85.53807,115.597995,12.312358,-96.798279,-142.178048,-65.065874,16.098614,-9.184515,-68.678336,-124.607132,-160.642708,-198.314395,-180.902839,-118.597567,-108.362256,-158.79486,-246.155085,-281.501913,-337.744235,-345.462075,-265.450953,-199.29364,-114.099055,-70.675495,61.084578,79.082982,40.077124,26.878845,60.838693,74.993254,51.167906,67.812219,109.43163,79.170584,-28.875727,-70.936116,-132.737531,-129.050192,16.37659,104.109349,90.705364,-69.074559,-97.401331,1.721856,87.04211,159.935872,130.233455,29.491756,-68.247814,-117.533376,-176.499756,-170.735188,-116.923106,-79.959022,20.94362,52.717968,2.410615,-109.295718,-162.591115,-214.545571,-186.724797,-28.752103,70.528106,182.603137,116.389392,55.427946,-77.655757,-113.727934,-56.185969,-13.892045,-57.757447,-103.581084,-54.772024,-28.237615,-81.236914,-131.087178,-109.300667,-76.676414,-60.622245,-42.737863,-159.004905,-225.352912,-239.144861,-200.606419,-139.615576,-123.913189,-45.567202,12.197824,77.201009,42.516451,-7.907155,-57.52996,-35.311148,17.349666,62.982489,211.927489,145.99464,40.746772,-52.132861,-21.152116,55.582555,78.676977,162.052035,217.037272,234.316779,102.58093,32.353874,3.406257,55.377043,192.0108,235.981355,283.912829,325.089831,312.294854,128.500258,-24.436505,-215.858846,-171.511114,95.910922,187.304178,114.760267,-16.703547,-21.676079,45.318055,101.651718,193.916481,219.54659,282.740693,283.325508,229.549373,128.262138,120.960114,145.695015,137.738364,120.541872,127.89945,15.620819,-214.487959,-265.865079,-231.697456,-176.679386,-26.799042,49.523035,146.69654,161.661562,148.233414,40.385246,-35.186665,-58.977262,11.154846,205.283466,292.168643,344.579617,136.858484,1.461816,-109.171436,-87.180806,-41.577318,-35.428093,-28.445733,-71.13008,-110.43907,-154.085091,-145.311394,-61.864239,9.513126,132.2799,151.079589,138.440006,143.105213,110.587343,-53.962238,-113.812463,-71.35533,-5.812766,89.527138,95.611093,68.825887,27.141692,53.564595,173.80547,207.848407,163.908513,98.618629,-46.370084,-127.482943,-164.417396,-189.641634,-144.045023,17.415235,88.780082,103.467691,-59.168405,-117.748072,-61.596314,-15.454041,-15.855906,9.300594,212.204097,292.657386,179.19647,-104.73915,-183.841417,-134.606308,-26.020841,127.967871,103.011416,7.869319,8.851712,4.895328,-61.904754,-113.287249,-148.490356,-98.207011,58.172934,97.122616,14.234629,-187.694485,-276.227049,-334.164475,-291.7545,-117.834085,-19.809035,102.940314,99.126334,98.398808,133.494694,168.620621,276.289338,328.835775,390.729817,392.435101,321.277505,217.724572,178.536214,124.11124,95.351488,8.268011,-33.030441,-52.522306,-68.255375,-129.390258,-273.298035,-293.238383,-231.758201,-184.722361,-65.667759,-3.983295,-11.136146,-211.028252,-302.954088,-314.221362,-251.10383,-120.045176,-70.510445,-28.827931,-59.359729,-51.569664,-0.453835,-11.112884,-124.987167,-176.823773,-173.593084,-142.975125,-164.807795,-338.140709,-422.0744,-414.510695,-316.165478,-147.406535,-157.118073,-258.122071,-279.18173,-286.954234,-340.263974,-343.544249,-237.846623,-193.849822,-214.989899,-224.565417,-221.777404,-266.555071,-285.471985,-241.816739,-180.035715,-99.984862,-109.808613,-131.196596,-109.035326,-107.641991,-148.251857,-180.571526,-163.837156,-105.175419,-26.696269,-26.00507,-34.105069,-51.93312,-88.264687,-177.201467,-177.715378,-31.361132,90.612269,253.780695,182.213732,124.394904,39.167328,17.077724,64.848735,110.983307,118.122298,65.626442,-31.307359,-13.999492,-23.029755,-140.683715,-183.736183,-147.015264,-97.361794,-12.769046,-128.670231,-271.249953,-432.20423,-378.658659,-144.549257,-52.249359,44.015347,58.674469,-32.109282,-165.197057,-194.307431,-236.684043,-263.635343,-267.636518,-225.783427,-112.295412,-64.013952,-59.490047,-128.260012,-195.99543,-174.099431,-51.514888,188.456558,225.108778,135.670807,-60.459287,-150.349967,-216.208428,-179.094825,-58.800708,-25.840607,-69.051706,-192.859566,-212.032007,-167.683047,-171.837747,-223.634222,-191.264068,-60.383773,-80.845194,-320.970393,-459.815419,-428.53006,-339.582713,-307.147211,-198.854021,-170.96531,-285.459157,-385.097736,-356.964763,-250.798205,-213.538326,-198.477439,-200.757109,-111.872372,-33.516729:87.337823,-112.83476,-192.422463,-240.892618,-199.587425,-50.631452,-13.398105,-111.152415,-223.1622,-220.971965,-170.240873,-134.504183,-45.808977,6.00304,113.016354,128.209098,-10.250161,-232.138776,-287.908564,-275.312104,-257.743378,-240.850563,-184.770495,59.406956,254.034774,273.864731,134.189367,41.492913,0.707232,11.556274,-19.484409,-28.68804,-7.988063,-70.969886,-132.876201,-190.618545,-164.303814,-47.486363,2.461112,4.038226,-130.186821,-242.463257,-425.698918,-402.812853,-164.511577,-74.726086,-101.058918,-135.285166,-60.823283,10.659524,-11.763412,-47.964349,-34.459144,8.878587,45.497932,90.494523,-31.611766,-108.560354,-171.321076,-156.230715,-88.566604,-41.947364,95.042377,130.985981,28.815462,-100.672007,-115.739656,-47.593543,15.601077,133.780315,152.055157,38.623684,-119.267927,-149.551786,-187.221,-210.630006,-203.927482,-157.496845,-7.861237,48.029853,41.120843,-88.541609,-152.280784,-127.6763,-57.504235,52.756713,110.784446,235.548774,193.519643,116.259317,-33.006999,-63.996423,-8.432817,43.472697,69.010847,56.885893,83.49491,44.151944,-17.816805,-94.117866,-96.244198,-54.634279,-7.394172,23.689766,-169.095511,-276.337941,-337.997027,-272.265785,-56.724291,8.785392,-0.246381,-36.698785,-65.410201,-30.312449,-42.666557,-164.956091,-222.871752,-173.674556,-65.539824,131.818199,87.201511,23.397005,-21.947478,-6.304693,26.260116,42.486488,175.337869,269.759816,320.507095,182.142905,119.009384,130.558901,176.645542,226.007804,245.385983,329.026441,327.534105,253.675922,17.16399,-107.320968,-255.621564,-225.640754,50.490645,178.107455,137.630683,-15.533461,-33.083022,-10.386904,23.996356,121.451724,171.189352,266.522734,264.19581,210.652691,108.070758,101.687803,127.390458,103.34716,9.95821,-11.754332,-39.305961,-127.549046,-175.580234,-170.561467,-94.995339,60.044208,86.744537,110.480937,147.505209,115.674058,-98.592574,-181.516386,-68.279763,67.602255,290.425961,355.273192,310.108523,80.763449,-16.008995,-112.572441,-134.096048,-132.337539,-85.742943,36.438428,-36.780213,-125.46973,-187.262213,-148.922139,-66.279149,-33.977636,103.392878,184.663795,230.839843,177.325925,117.934986,-58.569148,-116.615255,-108.38766,-68.901653,10.564141,18.522507,-21.166034,-103.403876,-79.761887,82.314615,142.574995,121.811755,66.404983,-3.425078,-57.117174,-123.076437,-166.129286,-99.127407,68.006126,120.191376,124.473502,-13.453777,-88.284859,-153.703828,-140.018161,-60.890454,-0.503234,158.420747,214.214283,125.714911,-161.966602,-265.415724,-206.635189,-71.352622,140.572199,148.317341,58.361229,5.734827,4.637858,-56.262045,-133.240167,-186.739325,-104.855325,73.926598,60.103902,-125.830824,-223.33385,-226.728668,-195.758279,-144.043273,-30.42209,-12.786782,2.012927,95.518044,122.215323,51.420295,21.187777,92.535697,170.018719,381.377664,468.087085,382.946476,56.370382,-66.800257,-112.17907,-80.480797,-79.956345,-105.778422,-111.374004,-103.763084,-122.802582,-178.245775,-184.652485,-96.913238,-25.820939,41.673799,14.22478,-128.612906,-235.219795,-232.509341,-149.779878,-115.506509,-101.069238,-77.070665,20.46307,13.444797,-5.856784,-17.008309,-50.141439,-199.900026,-260.675175,-270.7626,-265.41247,-314.636772,-396.293084,-446.981425,-439.23661,-350.154811,-227.41781,-261.632158,-390.214378,-402.129171,-378.720475,-347.486945,-308.735103,-164.755989,-129.08532,-183.613956,-215.792469,-226.702292,-184.030579,-159.503518,-110.89666,-78.652051,-66.650884,-84.156863,-106.438293,-183.294715,-250.475982,-360.972946,-331.981428,-78.510099,23.552291,-34.807559,-124.025907,-169.25962,-107.269591,-111.438992,-172.926126,-179.999853,-29.92804,114.628434,285.197621,144.425686,73.288482,14.992256,-8.329819,32.86972,108.876405,172.774491,105.072448,-44.376429,-38.688827,-58.74491,-178.829779,-206.073004,-114.908444,-22.582126,90.144956,-29.824551,-130.923692,-228.155459,-182.938755,11.281015,71.79476,55.741641,39.246761,45.617589,-28.4664,-116.787052,-296.158288,-327.447924,-171.711903,-20.989023,119.866424,-56.430247,-110.38224,-43.231342,-9.404308,-29.628425,-41.210713,1.729767,32.331486,44.870324,0.031031,-39.085436,-83.385072,-65.00623,3.869163,20.696306,-45.24185,-193.351211,-227.448392,-188.786067,-162.598203,-175.881494,-185.994122,-117.067793,-80.693148,-161.30844,-299.200481,-315.142892,-308.209303,-304.301825,-261.31287,-219.034333,-105.060846,-74.252386,-128.50976,-235.667735,-214.220419,-113.939333,-113.310455,-141.410681,-122.567749:-145.529845,-240.745744,-259.088291,-221.366394,-162.498257,-34.57162,-18.452049,-55.935597,-40.783742,-18.25854,-9.906245,-4.296432,82.522428,148.314334,235.727729,237.008596,154.39269,42.813851,0.198036,-88.17224,-141.487912,-197.289408,-152.44666,76.958228,234.270838,221.750718,92.065299,34.129024,13.713548,12.317879,-44.053756,-54.745793,-19.799711,-49.929305,-84.716902,-115.717631,-91.864839,-13.735033,14.924896,57.505683,-8.463352,-105.466488,-294.035828,-317.261441,-211.990146,-139.85408,-65.191508,-46.371834,-13.135881,-61.124171,-100.02416,-83.756696,-26.265343,62.727908,85.305232,162.855033,161.096037,79.156167,-90.996282,-108.706288,-47.526263,-4.595881,91.539763,109.480404,-6.314653,-162.140679,-199.251646,-185.826478,-130.348155,24.521218,82.191649,101.104674,6.612594,-38.770889,-86.975652,-105.812433,-96.026218,-45.200056,107.215088,155.645606,106.979957,-19.378291,-62.875056,-93.14847,-87.12014,-45.955839,7.316156,158.96365,180.114838,113.954861,-44.595501,-71.270168,-33.244856,-26.418731,-36.488232,2.538434,120.388281,56.889597,-26.289536,-145.472654,-167.340743,-193.364866,-200.524192,-198.512775,-235.32758,-266.840224,-325.217739,-305.828358,-128.583781,-53.721854,-17.007475,-7.735966,26.030633,8.905764,-32.817074,-119.037089,-112.659317,15.193293,86.092939,183.886461,177.457957,123.451954,3.060122,-14.017139,108.729727,218.424845,387.382369,412.427241,354.451488,244.884797,193.93819,120.765422,106.082964,101.152245,118.759471,239.389704,322.932605,276.499044,48.165638,-56.3817,-104.919081,-56.92503,82.320415,133.868055,123.561081,39.298206,21.881229,60.558172,96.681141,151.247083,181.402311,279.531553,324.147164,287.32895,158.213518,120.618031,130.726625,127.676767,71.637416,58.619611,7.167613,-121.394459,-154.687741,-95.763801,-2.955921,166.822071,180.157183,146.445247,110.62719,73.201064,6.35503,-2.575304,40.114669,86.260892,200.619841,250.662077,232.662817,60.054642,-33.668079,-156.833759,-150.674573,-37.614115,11.46471,57.443191,-0.157808,-67.779509,-111.862935,-74.000442,-11.379375,10.112517,98.992894,139.966792,155.584726,135.762639,96.14689,-40.134467,-80.07819,-41.449672,6.506428,99.699341,127.871763,108.760591,48.478494,46.72707,140.019142,186.105427,193.276778,177.923993,139.556212,33.455812,-37.005343,-88.906255,-47.343138,82.917545,123.045023,81.672635,-62.499301,-111.569401,-158.526721,-182.178384,-158.669923,-75.396437,125.646567,150.84335,-26.910184,-204.444176,-202.800169,-61.303599,43.415237,170.375769,154.310138,45.438364,-49.980104,-65.977722,-43.735689,-53.927041,-124.931048,-118.707792,-4.137537,26.489581,-75.767079,-259.401251,-325.065737,-349.834156,-302.717699,-190.300317,-158.596798,-90.557351,18.803533,59.196495,68.898151,51.439241,55.457315,100.678353,209.401359,215.99808,121.205127,41.461666,6.735076,-112.324121,-165.0191,-191.699609,-180.975372,-140.859279,-129.871122,-156.737654,-240.579358,-273.255075,-284.103269,-265.837007,-218.247821,-205.514898,-260.909908,-372.03823,-383.099378,-305.190282,-247.931994,-162.251739,-138.305369,-131.193911,-196.451413,-210.202207,-176.861984,-190.629685,-253.74726,-239.70606,-176.044631,-180.728913,-244.973828,-313.062582,-347.841665,-372.548502,-348.446376,-303.165562,-301.708689,-290.146915,-272.056423,-294.268637,-377.874791,-382.55435,-247.816948,-164.41456,-115.131944,-134.762839,-167.687187,-145.545532,-149.735051,-191.336856,-165.710158,-63.483009,-55.2008,-95.040345,-78.278798,-67.947141,-147.050667,-205.796551,-214.842321,-169.607641,-76.456532,-64.425212,-137.670863,-180.576396,-166.401303,-186.941236,-209.270309,-101.117985,35.640205,226.741049,171.586396,132.828424,62.865104,20.64243,-0.606515,29.484242,59.192969,17.279231,-69.338566,-19.626555,-18.31508,-133.538653,-179.958055,-180.847889,-142.432404,-18.393594,-62.998988,-159.068953,-273.212629,-254.717274,-166.818457,-151.981992,-168.696231,-151.858748,-114.300174,-238.426898,-334.836148,-464.164315,-478.073143,-391.259632,-297.984722,-144.897698,-130.416011,-120.69706,-73.932993,-63.433404,-39.31016,-9.66059,27.973811,14.401531,-6.975102,5.156579,-39.704319,-194.825584,-211.565963,-106.00103,-56.624852,-18.919841,-61.220521,-106.72044,-184.562405,-200.82874,-153.576789,-87.933801,26.799977,23.209189,-90.224483,-181.070695,-187.142056,-150.23794,-121.846995,-71.087877,-54.981055,-26.29527,-49.390507,-96.709049,-183.405496,-186.183885,-140.279781,-126.970678,-105.328393,-72.579166:-10.186687,-198.04357,-283.87941,-316.248494,-250.068908,-56.251304,9.563493,32.633671,4.274081,-7.856765,-38.805903,-38.873932,55.410027,151.944321,327.028316,335.09038,156.51997,-41.714515,-81.088084,-98.414433,-107.291534,-83.497371,-18.563652,147.222724,188.263065,162.664312,52.330245,3.99308,22.44258,44.446718,19.419537,11.362986,38.881964,1.637663,-39.603511,-60.294812,-20.251163,104.230503,142.800936,133.471754,37.394258,-53.444497,-252.781469,-276.527494,-156.889036,-92.304907,0.727849,54.277202,68.314614,-112.676857,-179.053294,-110.444461,-15.645068,126.892735,166.197611,215.900393,157.004419,69.468352,-123.653429,-158.546967,-52.924186,24.542332,108.254679,121.011333,79.463648,-111.434438,-206.472692,-166.326682,-42.744691,157.409073,178.501242,145.202547,109.059659,69.300611,-96.670114,-172.92006,-130.803999,-28.70167,117.070638,122.432646,82.969382,-19.735856,-103.406532,-169.859858,-123.132904,17.563711,84.258454,179.5634,190.95026,163.796379,6.307591,-84.300907,-119.158572,-61.674077,91.279211,143.872715,145.938638,57.150407,1.221651,-107.024434,-145.821896,-179.652542,-168.172876,-115.934881,-172.538748,-244.725568,-335.778163,-297.215485,-95.990243,-31.988222,-17.518297,-10.880553,-40.617213,-155.320891,-205.061608,-266.988198,-254.443087,-107.239714,-27.022227,20.682725,-1.087154,-11.825349,-80.465491,-115.79855,-35.931109,77.575665,311.068885,377.052003,328.188807,174.944021,126.598446,96.760482,94.365696,83.614991,99.864614,195.840362,181.510654,92.900481,-129.674886,-193.238523,-167.425427,-92.043245,131.80737,206.971338,137.620848,-4.362763,-22.567176,50.112567,121.863253,255.664161,299.567494,323.317952,252.772243,203.466204,136.153136,120.60923,86.116752,60.091165,58.619641,91.522062,99.970444,-39.130768,-117.22577,-158.918476,-102.967161,86.095106,147.04042,139.676773,98.546149,63.145308,-78.362795,-110.957471,22.672667,112.376316,188.723139,199.260964,187.878255,55.50273,-47.117594,-179.748963,-170.774642,-56.96555,9.684213,87.392987,4.013753,-73.705504,-160.684326,-149.72641,-56.109018,24.424219,229.820769,315.59025,356.20874,212.225026,104.74941,-48.495094,-50.441385,59.376039,124.423726,187.937741,120.88725,56.720084,-45.980396,-36.790287,110.381886,189.047319,273.33462,286.68287,251.628822,75.514826,-47.831656,-161.441997,-106.62449,80.256578,138.804683,134.663307,29.451578,-48.956033,-200.880439,-207.709731,-46.542214,52.318357,175.047788,182.213098,55.8155,-79.509589,-82.220233,-3.542453,38.872124,110.727013,150.811986,187.283927,122.932549,78.301072,-38.156586,-110.271867,-160.903626,-89.502178,124.878622,147.524832,-49.119691,-260.43341,-304.632959,-304.833753,-257.990875,-126.623912,-98.735964,-68.502453,100.624268,168.61871,125.077733,82.585712,138.016015,218.470582,354.467054,356.775851,192.393489,-6.348507,-65.741597,-105.023801,-86.056061,-29.163153,-9.916432,11.275492,-26.456346,-55.799107,-130.15629,-153.672036,-110.805749,-74.696876,-26.124059,-18.109059,-115.14005,-290.705091,-317.339496,-203.6311,-129.697836,-89.423719,-76.518123,13.461828,-33.032135,-90.991407,-126.602794,-138.306315,-228.24909,-262.059083,-220.78477,-187.625269,-196.898096,-259.474201,-313.742633,-365.941199,-318.234433,-200.182601,-186.393634,-235.060927,-282.122276,-300.910253,-357.603509,-347.409053,-184.816594,-111.09462,-92.30325,-82.076897,-18.750115,-49.867013,-74.070814,-24.224051,21.061436,34.323167,24.730926,25.25353,-40.635674,-107.738732,-237.074511,-244.840221,-137.581482,-85.39212,-56.793215,-54.609575,-12.348229,-4.02184,-73.029927,-258.167898,-278.446167,-121.111896,8.146259,185.176265,159.15252,123.245813,32.56331,-14.189386,22.893073,115.427443,253.554738,223.985529,57.388658,-27.033841,-61.870515,-187.821001,-226.608471,-133.643465,-33.19494,85.623832,-9.383494,-97.148179,-244.629547,-256.443136,-149.336677,-99.283081,-50.173314,-19.459201,22.611721,-118.417682,-266.800788,-474.891281,-449.78762,-244.748833,-137.849772,-48.138383,-159.84406,-182.639902,-101.943206,-71.185086,-76.196062,-64.979948,48.750256,105.179629,77.649302,-49.542951,-117.965038,-228.454407,-232.245738,-129.299098,-51.098548,35.744725,-73.123616,-140.714071,-163.387804,-139.895701,-131.148654,-126.674114,-44.280046,-22.331994,-106.585229,-150.474091,-154.300786,-197.283992,-196.171673,-125.028009,-80.219484,11.248904,37.243605,-13.475494,-177.564916,-208.53308,-138.958271,-106.272398,-74.699096,-50.206787:-48.079912,-159.992865,-185.021456,-172.973409,-151.12452,-25.17608,77.707532,198.254862,119.33077,75.288317,113.942585,189.750463,316.545993,325.278446,244.409485,190.083385,136.624972,152.067549,151.275982,56.940722,-15.057215,-85.095613,-67.507499,8.755846,49.891991,72.034948,145.637271,152.259827,55.592668,14.738867,53.586275,84.104304,19.287969,-86.992293,-97.382599,-102.260489,-106.909244,-35.844522,45.097496,146.65402,15.012054,-91.156926,-211.852649,-213.645624,-179.340081,-156.615168,-95.31662,-60.02276,-14.297283,-37.453342,-59.04394,-72.451705,-55.730888,25.620399,99.344842,248.563808,238.411593,179.067969,32.522346,-24.342125,-21.629938,30.824875,95.454617,80.099746,8.695802,-77.090048,-112.909604,-101.869822,-52.15662,62.585762,99.054828,110.669733,76.466425,54.961371,-10.668501,-35.063693,0.749528,48.044417,140.18207,176.680392,189.718729,98.834261,46.249091,19.188647,48.088937,133.289399,167.502087,223.691416,242.842949,192.507889,-5.378875,-67.561673,2.322225,63.717041,69.214415,51.415663,65.515785,57.368949,21.544912,-119.500382,-197.729909,-261.858088,-251.371169,-218.88967,-208.902541,-215.313879,-254.483105,-264.893918,-180.716477,-94.444932,76.991861,150.632887,224.46972,154.237154,107.541081,92.087465,116.545827,140.481429,148.482603,242.68099,326.489874,305.728023,144.818929,70.589046,122.637077,209.010579,306.197444,326.538626,327.589826,202.355339,130.701117,45.10332,27.201068,29.828829,52.364509,112.910878,121.14155,81.305903,-74.26468,-115.306363,7.468355,107.074114,167.625011,125.283405,-12.937009,-61.623171,-20.255443,64.281696,63.970098,32.93797,52.110014,193.718365,278.245938,227.092623,33.884935,-18.378294,9.434065,43.963104,127.389127,162.247298,82.518448,-159.302115,-253.047001,-264.322697,-186.311239,-9.80012,31.275776,57.737563,143.586179,182.850191,125.036047,46.839471,-0.953295,65.949142,269.727526,353.107395,357.605496,162.230222,87.631548,68.835641,91.057071,133.719568,141.326121,97.506341,14.002706,-13.032761,28.060078,81.227849,117.409342,118.452016,222.699731,277.378061,196.434955,32.991275,-0.069012,-19.722127,-23.359672,6.136902,44.170902,121.281302,135.417036,123.100215,79.693609,62.287974,83.624763,111.324646,153.623486,153.097289,51.668837,-136.118454,-195.708004,-169.246177,-116.141339,-34.958166,-5.043723,43.320061,-16.451922,-80.650014,-196.73939,-233.78086,-197.861289,-112.575396,61.151511,98.197354,52.683473,-34.295547,-31.559421,53.941746,101.370036,143.506814,146.96407,157.89053,107.387005,76.998296,76.142135,79.364822,42.726378,33.649668,85.520247,107.641271,3.126699,-232.263362,-300.289644,-258.74839,-188.15032,-93.133139,-80.468714,-82.972922,-104.629395,-110.483636,-110.250487,-107.740695,-52.020951,0.932607,101.741252,130.137436,91.356857,19.382769,3.974339,-81.489695,-140.782997,-186.154818,-187.325526,-207.563297,-235.682267,-244.319802,-245.239204,-244.882817,-223.845526,-192.267023,-152.58195,-160.000268,-227.030004,-373.817672,-423.785111,-330.837795,-198.497928,32.110197,46.373201,-89.718795,-170.641534,-163.248206,-149.804481,-153.776914,-144.844411,-139.079202,-142.098323,-134.653996,-121.159564,-168.513975,-195.917723,-236.017352,-239.432773,-218.565672,-230.267503,-303.080733,-340.867087,-333.798839,-280.248264,-233.894194,-131.824976,-107.171543,-132.626835,-171.595244,-274.767336,-274.949766,-228.539677,-175.532723,-169.017836,-120.221033,-78.155199,29.36551,91.980695,87.523731,25.446408,-27.726504,-85.559582,-64.426882,-16.19546,-27.784157,-84.093293,-60.955194,-47.4246,-119.081967,-164.027523,-108.073261,5.963948,233.954772,206.142907,117.088374,-6.343951,-6.020082,63.999634,99.517202,94.463266,47.534021,-10.04086,23.196893,0.601421,-99.484489,-110.64885,-77.79961,-78.288366,-108.692518,-182.716851,-242.957815,-371.886136,-416.81845,-401.656131,-339.496185,-187.982288,-147.74042,-215.528043,-381.829614,-452.829636,-533.510244,-520.260292,-385.355582,-314.204095,-249.139458,-207.062158,-174.175807,-128.027345,-116.918699,-66.240648,-13.232237,106.349082,130.305258,74.360762,-11.214697,-49.270901,-106.811133,-93.083182,29.805429,86.226346,106.099975,7.228729,-60.499625,-103.319801,-72.638116,-1.894856,34.799266,116.444646,127.10132,27.754149,-109.553489,-139.980057,-98.972015,-32.078721,79.367783,72.626717,-39.325343,-110.747299,-114.110936,-109.458338,-98.790063,-62.349155,-46.843756,16.467245,58.724704:-3.66353,-254.602826,-315.616837,-224.27403,-102.131974,106.965336,159.596822,200.448076,138.558209,84.283711,61.258815,111.528096,250.54754,301.562153,342.984783,341.974209,256.050205,87.959633,33.62627,11.923108,23.993308,68.916837,97.78125,149.611052,164.769638,142.347714,38.179589,-0.293834,66.670617,132.14197,162.635669,142.038431,107.086481,39.99895,-4.57308,-33.437505,-6.511106,92.219578,153.50929,214.919429,72.040819,-40.575764,-211.412611,-225.69903,-54.444443,69.517332,161.911867,123.224677,-6.30915,-135.372851,-166.095813,-97.595282,-22.6815,124.281062,187.155199,248.933813,169.92165,87.049057,-76.217878,-104.245641,-31.727956,38.952635,173.7598,175.133314,-17.500795,-186.797758,-200.962725,-144.141489,-80.212864,94.993336,173.148785,214.767271,117.886728,52.851379,-104.333779,-172.102805,-128.665734,-15.88015,204.904007,239.500249,145.017908,38.806743,8.835366,-58.911104,-71.120283,32.006875,121.571397,211.990714,120.630004,48.564401,-81.861054,-107.55747,-26.553722,30.209996,93.016092,117.602787,100.234219,-33.047981,-95.106254,-142.146899,-141.460456,-151.314926,-142.842197,-108.840478,-222.452174,-321.283379,-439.838344,-416.831598,-216.371165,-90.524235,86.448154,119.687946,78.860403,-43.594809,-113.550601,-191.996333,-151.064426,79.603743,193.953887,255.750271,138.502769,75.088202,-14.407689,-34.027607,59.538115,178.509202,395.697357,420.088764,280.38348,104.651228,73.209166,63.600435,44.043921,-13.205738,-5.065177,102.980768,89.204338,-5.610938,-193.765575,-214.898938,-115.479286,-47.419665,64.92064,113.685716,113.054637,-16.209584,-57.36427,-28.238332,15.729489,98.000472,152.948263,270.195563,229.694434,152.419127,-1.087815,-39.438837,13.385711,79.726848,174.099067,176.931033,98.662108,-82.68843,-181.011368,-190.193958,-79.233511,166.536407,230.324917,225.833591,138.527191,108.29602,62.313707,34.490189,41.302592,97.425037,264.43935,343.320569,340.547037,47.269527,-114.501692,-208.606421,-113.743814,178.479274,269.136323,219.735946,17.924425,-52.568154,-113.741698,-118.671585,-22.33728,85.802495,302.383583,346.430077,262.234836,72.119269,-14.669842,-90.474496,-62.99696,77.366143,166.861288,276.596679,159.300644,62.063744,-37.418409,-9.765659,125.537235,185.058614,280.516831,304.152812,184.472602,-74.04645,-154.482864,-160.27964,-119.378726,-22.578488,34.383629,113.565328,1.372783,-101.546587,-272.576051,-302.111872,-199.796773,-86.845785,145.736346,201.693766,80.407008,-142.718314,-167.836507,-21.580189,78.886217,192.449551,213.278825,227.020205,161.609452,96.908315,-31.16169,-73.492923,-72.227925,-18.123146,133.582608,166.594588,37.871097,-240.797153,-346.647174,-317.509741,-202.839254,-12.041466,17.700625,14.150756,9.129253,7.512406,-16.838971,-38.008903,-23.165572,49.702669,272.29042,340.220526,240.985187,-16.956722,-118.197153,-214.308152,-198.536351,-85.643863,-31.532882,-0.490438,-142.035068,-231.106043,-284.433207,-262.28445,-195.611312,-140.847213,-17.44743,-14.207807,-203.660567,-445.457595,-503.066612,-418.241047,-290.853714,-74.726704,-46.505394,-85.498576,-128.733962,-137.285405,-157.449923,-183.496171,-228.38587,-211.603974,-93.172602,-51.117385,-125.636559,-293.455036,-351.034969,-362.143741,-316.677795,-210.043801,-186.256251,-212.610631,-288.162278,-316.361368,-327.109172,-307.971354,-197.379447,-121.138266,-38.135217,-47.786047,-98.915036,-102.457799,-110.482617,-134.885896,-112.633774,-17.925038,40.952318,158.051216,94.129276,-31.243621,-286.564457,-318.802981,-146.487972,-32.646177,43.364658,21.983206,-3.528128,-45.218514,-122.896594,-285.85522,-288.92343,-129.57053,-9.862553,173.349016,117.380209,41.674175,-64.247969,-85.943523,-31.646269,52.242075,177.676044,136.221864,-69.258804,-110.573985,-88.053104,-113.559186,-128.944576,-79.938218,-34.708696,12.045541,-109.00189,-201.339772,-326.862148,-353.542973,-311.375045,-247.084592,-123.892442,-96.136459,-163.148347,-336.48043,-421.49467,-532.578054,-523.017192,-365.479031,-258.065726,-115.192482,-154.454092,-197.767238,-207.371328,-172.219822,-78.446268,-30.089537,56.212858,73.215401,24.747972,-114.107697,-198.3466,-233.01856,-154.034064,5.921634,31.321161,36.079802,21.539796,-0.800984,-46.966945,-47.592281,27.595709,84.316853,149.846517,137.964485,39.982399,-61.18638,-100.967478,-157.389095,-145.22979,-20.920238,65.429179,170.205282,59.888314,-43.42951,-207.068762,-241.063812,-205.336223,-153.496286,-15.625549,46.903243:52.2733,55.54146,24.179362,20.406204,69.532987,188.581685,215.06352,194.300994,115.052953,80.207536,87.981964,117.345615,167.630884,186.330679,162.760694,120.501086,81.023484,80.896026,36.584234,-148.057366,-221.274884,-224.677539,-195.08469,-152.421469,-101.992898,-79.273811,-40.530104,-5.722743,47.456593,44.227838,75.588422,123.522547,133.398972,-6.13419,-66.488764,-104.443321,-85.82013,-3.659074,35.150727,23.181713,-98.145561,-141.243582,-153.373835,-142.586854,-99.061573,-67.869413,-17.665642,-1.955511,-5.028006,-34.082864,-47.726053,-76.049738,-75.593582,-26.405804,19.141184,139.68237,214.048226,208.483771,138.21158,99.666207,83.940672,101.779124,118.012404,97.338748,-22.661116,-112.102549,-89.668412,15.004621,59.62892,115.2279,145.61836,207.064995,108.057295,0.2638,-192.826964,-233.685213,-163.758885,-94.130578,2.223562,33.628109,107.986911,158.292213,144.01505,54.805231,36.967704,140.75035,214.57195,250.797288,164.135707,129.780345,74.941447,53.006972,61.901082,65.683785,27.47345,28.876527,64.159681,14.369853,-17.823964,-110.863451,-175.4857,-222.139606,-199.830958,-154.984975,-103.929806,-74.053456,-74.842224,-85.013173,-15.244385,39.58799,111.906375,147.484566,190.221453,145.208319,103.973518,13.830705,-5.89779,60.121992,123.131204,177.253822,84.160332,34.978775,-36.830472,-71.174834,-70.602471,-24.8208,82.086332,96.838908,-24.800953,-200.205106,-238.184236,-247.94894,-246.348077,-272.8024,-307.67882,-316.627406,-210.8054,-174.903752,-188.6775,-195.521024,-82.525655,8.159,42.994783,-15.987663,-71.926225,25.469014,69.083429,95.091665,96.967786,125.961888,157.117597,247.421811,300.609305,297.757932,257.917921,239.93522,249.155464,253.979732,255.906463,279.238359,241.608497,4.211153,-84.786485,-92.741708,-61.407881,-41.178181,-51.114135,-16.920894,164.258592,261.325628,332.451614,317.059104,310.561968,336.893585,422.461446,464.268106,444.968099,265.06245,188.753107,149.557793,169.047117,220.069784,233.026358,220.031754,182.889354,184.907766,232.746369,232.624647,140.498666,105.527001,123.76562,122.207007,18.258736,-105.229136,-130.822774,-116.38768,-97.451111,-42.565593,-1.369617,47.098344,6.68929,-3.697096,34.787551,43.341671,8.695731,-4.425423,15.274427,31.420247,-12.347705,-132.313736,-154.999367,-102.354968,-59.984405,-20.297394,-29.099847,-32.616938,-51.277939,-101.549742,-254.771035,-321.333618,-273.463457,-140.491119,135.972534,202.298696,191.884903,119.742323,106.839396,156.747058,207.604549,275.62077,269.378301,207.358217,141.276374,143.210775,197.035703,205.913589,192.215431,194.70461,216.87902,212.242058,99.205893,-90.909973,-142.077952,-136.489724,-128.837853,-178.142561,-204.700029,-190.873842,-208.414469,-249.805199,-312.5228,-331.08158,-327.240657,-289.195414,-192.845345,-161.703351,-131.754979,-112.200183,-104.381034,-101.666202,-117.650283,-184.62932,-210.987832,-216.164764,-200.860256,-177.69107,-68.405694,-25.433177,-41.845852,-67.079845,-87.44725,-83.568969,-108.378682,-223.743773,-254.618572,-185.034833,-94.898044,127.512981,184.012194,83.106489,-126.655765,-200.157747,-210.699484,-159.601586,-91.109153,-101.536681,-112.100617,-78.478981,-20.412802,-47.236111,-53.277588,-80.910849,-100.800852,-56.73536,-18.427343,-50.809985,-170.738623,-173.375313,-63.568366,-25.717254,-22.87578,-30.786994,-78.244854,-121.683795,-222.96264,-231.407313,-180.737582,-87.836921,-80.112224,-79.713738,-57.489118,0.43924,22.186378,31.366112,38.56454,35.99738,79.698105,109.478978,107.360315,88.689708,43.58331,13.279385,18.852858,21.731261,5.010488,3.960731,50.692506,192.44116,271.867016,278.773376,206.946652,137.932785,31.32353,19.087833,58.683211,69.946819,13.880233,-25.457668,-11.300557,56.478123,91.434574,107.485236,93.954986,68.307017,0.512203,-60.472907,-172.320697,-208.562731,-214.056159,-176.705543,-110.756818,-117.921247,-196.042081,-288.895794,-335.796789,-423.491416,-431.093092,-316.655048,-225.923241,-128.998406,-170.195913,-175.759158,-84.471529,-26.712503,31.392599,53.387285,120.175996,144.12929,153.094722,110.814839,68.28494,4.847197,-7.387498,-4.693382,27.713884,163.500297,219.242743,162.197672,24.8673,19.693544,78.315065,88.241991,87.746327,77.933091,-12.026369,-55.773357,-19.947967,76.265795,109.628581,138.957724,124.851716,48.06375,-6.84871,-8.962819,47.595839,86.248906,101.321503,79.044239,56.411153,59.895617:-122.879342,-126.041448,-152.927828,-181.816838,-138.235155,20.1634,78.340506,96.261883,110.917942,132.554468,71.309118,-6.955941,-94.190329,-88.444919,-18.863892,28.864895,40.593823,-33.422406,-62.616226,-165.945007,-231.016996,-277.957325,-265.501615,-219.364468,-161.667287,-119.078232,-10.039873,24.210881,13.56469,-21.323076,-37.755907,-0.514116,13.770401,-105.839368,-165.898813,-222.225579,-197.723399,-104.545666,-82.690134,-97.697503,-175.727386,-227.614624,-260.489585,-230.99452,-141.43521,-100.17603,-3.368725,46.324863,44.860466,-21.367568,-18.562593,13.473599,2.567369,-56.272428,-49.350377,84.108855,193.54365,194.967638,127.243925,81.062705,68.301459,116.825656,181.704361,162.999898,104.974531,92.930001,91.425128,86.985998,106.077072,190.706953,215.284405,176.602148,140.046134,150.818622,115.86371,33.30078,-140.232615,-158.233907,-43.968733,25.934518,48.118029,-30.682367,-67.461383,-132.786936,-138.962184,-32.606943,42.937043,142.32391,180.952423,168.143795,92.693756,56.828565,27.227021,32.715661,57.219703,64.078725,30.164826,-27.211462,-49.853846,-138.467996,-204.721738,-297.351127,-278.591826,-112.495495,-23.01627,-32.617544,-48.972021,-51.256075,-31.187312,10.328668,143.919403,220.780703,303.068487,221.745809,147.883054,24.022257,16.01228,127.743391,205.478367,291.072174,267.82735,245.197299,153.218716,79.321941,-0.285023,24.484378,113.775071,134.078152,128.542518,88.930416,36.943455,-90.865483,-108.948707,-57.648887,-52.651841,-64.032332,0.904791,17.082667,-19.566718,-35.133412,-5.95724,16.547116,20.845001,8.165894,-23.992749,-20.551298,-3.985992,37.08075,61.319917,69.566621,49.123608,54.098029,153.520869,195.724012,184.951341,152.822504,136.556407,140.604063,131.743577,125.676091,45.217951,-152.642428,-215.521709,-194.562308,-168.634244,-170.978172,-169.752429,-99.853144,23.659363,84.831516,156.065379,140.735766,63.700698,68.025697,237.480056,361.901221,481.383918,362.646472,280.328842,165.104531,132.431675,82.101442,60.108897,49.797549,95.448442,133.740774,181.36832,166.911873,76.190117,46.80645,113.136487,155.087189,70.826688,-55.806698,-55.82967,-22.638009,-8.717903,67.975915,116.798625,166.920263,169.568779,166.78603,145.71861,120.767394,67.780189,42.255008,-17.460762,-37.14534,-81.089038,-167.420277,-190.185909,-174.598095,-159.288013,-138.11953,-118.915597,-64.013314,-44.742212,-45.877615,-120.155048,-194.488968,-220.028408,-129.069448,126.78147,204.753963,157.578237,66.550354,61.770038,52.817563,54.893332,108.87999,142.960312,197.524779,172.703691,130.199363,56.298105,40.679788,54.927251,55.924057,4.89954,-10.957996,-5.550035,-98.45183,-189.819718,-351.096808,-378.115076,-316.061305,-259.095067,-172.234064,-169.63022,-194.919405,-209.312005,-163.925173,-21.803178,7.223619,-56.915887,-84.555244,-63.28923,-18.23012,3.691542,7.841304,-13.160421,-90.987683,-147.604833,-264.008255,-321.42022,-319.632865,-311.863343,-328.796481,-353.947441,-332.980278,-236.968262,-187.974437,-179.948968,-281.115341,-313.388388,-256.569524,-157.44191,101.237357,172.894913,83.460904,-105.535079,-126.14969,14.474179,90.344444,53.545681,-25.158926,-85.81725,-43.175151,21.003652,-82.541153,-130.413987,-161.049144,-152.963901,-84.295507,-66.921866,-135.134093,-212.12571,-210.454013,-140.487465,-98.101004,-56.029701,-67.001946,-129.932155,-182.126865,-329.981062,-376.18973,-344.548152,-264.840406,-213.31805,-98.544594,-71.372776,-67.380603,-12.248631,43.04057,88.998981,45.826041,-43.642279,-35.519034,8.319716,11.338183,28.255597,102.012386,119.826559,76.996685,56.57865,74.705534,101.7542,146.210728,201.704952,252.390219,289.863645,248.34034,167.288313,155.689892,139.958429,111.921859,13.250656,-12.621811,10.760225,15.753124,-13.658505,-48.907752,-36.537851,6.210455,-64.810019,-144.956423,-249.217942,-250.306367,-159.90045,-79.772067,36.749593,37.561309,-46.075195,-155.91637,-210.158046,-307.423575,-322.91292,-242.11524,-168.917037,-34.891647,-13.14044,-48.227454,-75.710604,-42.904875,15.365139,23.498679,48.879242,82.363409,170.739058,149.882279,92.113519,-15.230506,-39.515308,-46.256635,-54.500335,-67.758356,-70.158053,-90.879705,-137.358467,-131.875597,-51.705816,2.378303,82.196653,91.653505,29.007301,-40.47478,-29.430412,-0.712973,-13.466633,-6.951268,16.335172,-50.516704,-206.47652,-226.310321,-177.973931,-151.262353,-126.639371,-129.029623,-83.415343,-15.962659:-73.235102,-113.057267,-93.36922,-46.172517,-21.133569,66.484809,98.44593,92.619323,33.637955,-2.872503,-43.875503,-12.970851,161.25882,248.330669,290.129655,258.389033,217.005945,180.774036,126.686527,38.896776,34.429632,-5.562812,-54.484237,-64.376542,5.84567,18.552607,3.432149,-11.638916,30.383469,82.135835,153.956705,173.551547,179.659398,132.240228,103.488057,73.257401,79.652679,134.105935,163.14221,142.115259,55.892894,10.60812,-136.31212,-203.634399,-172.3953,-95.629484,17.662754,38.215046,8.237473,-108.308228,-148.721011,-76.863668,10.941523,99.005225,100.669258,159.075684,181.947988,152.205276,93.446126,71.770815,79.937386,98.377951,76.757217,42.813726,-66.018157,-161.228775,-149.351107,-73.966265,-52.538865,6.343924,62.341878,114.456869,-18.892281,-98.608563,-181.819938,-187.009299,-110.471314,-42.187878,81.863685,137.652173,183.054061,90.882074,47.346179,27.216616,35.495047,52.924201,77.170562,183.630738,219.391998,176.982721,26.199106,-47.231267,-88.802304,-51.463503,45.627649,79.87078,73.649714,-38.347775,-87.976504,-171.103547,-212.968664,-194.682435,-135.494218,-103.671377,-222.260157,-255.010307,-205.46034,-145.323919,2.866883,73.272476,178.053632,208.469822,151.083508,-15.989654,-62.811345,-80.981643,-65.165139,33.841998,88.340747,115.015764,82.386496,79.581788,51.874453,12.968357,-35.4361,-19.631912,72.05309,110.070096,56.247489,-51.860886,-58.016882,-66.390614,-89.792105,-108.105989,-94.836644,-54.548095,-134.770596,-231.475748,-319.502369,-255.179153,-40.095967,11.302003,-15.325438,-18.152147,10.011302,-50.25244,-90.134817,-44.741095,40.743553,165.213218,167.895304,160.087968,203.24475,213.847746,169.250621,132.618919,156.400901,217.402246,253.00008,192.753581,37.327038,-17.798461,-24.284275,-58.298743,-49.15589,54.451364,92.306808,136.992717,241.286944,278.317165,248.912537,206.327141,192.937442,229.432095,339.802188,389.255469,316.631978,38.710848,-58.679451,-44.284575,31.130671,129.436198,124.579989,74.449067,29.316767,30.15726,86.179562,101.730926,53.786252,44.756295,185.069457,283.624282,282.777444,51.410112,-39.932606,-80.170639,-52.395448,9.521751,38.454678,112.073436,117.150241,78.133601,-1.536136,-18.451194,-33.380347,-30.283863,74.364351,159.247826,165.137718,-80.998618,-176.977018,-157.56352,-77.438375,14.127289,-7.014944,-54.697589,-38.695869,-66.478744,-219.027323,-255.666476,-160.659575,-112.906621,-77.371862,-29.512629,60.597319,14.752772,-15.051285,-11.903446,26.302594,122.679491,142.337402,96.88283,26.91856,22.651757,95.233901,138.820668,168.696948,175.638855,236.729032,251.251504,88.358122,-150.481904,-201.514877,-197.984042,-171.076157,-92.508446,-57.143191,-45.358132,-96.689992,-108.298376,-83.796949,-86.45899,-109.203891,-74.248268,77.586174,123.775756,39.190933,-79.078431,-94.513966,-148.544999,-177.382964,-164.033647,-136.918565,-91.486154,-130.673516,-178.323528,-221.217975,-188.627187,-56.11615,-12.682189,-65.174165,-122.434779,-216.811428,-298.892184,-319.681013,-280.021559,-215.757397,-93.030928,-71.769664,-68.520688,-105.088054,-135.896771,-176.091658,-181.67298,-148.816878,-107.21503,-11.413302,21.715605,18.646918,-11.849857,-24.404684,-74.563411,-75.63617,-21.069837,-26.972626,-135.149756,-209.848847,-188.3749,-79.784186,-25.286918,74.024899,104.521674,45.918602,-21.665165,-92.391618,-58.944964,-43.411781,-23.280912,0.415102,67.907346,110.177279,177.771663,117.44579,62.363093,-20.586655,-36.651717,31.383023,81.69076,70.356035,28.537526,-7.736409,11.824053,8.508573,-80.791751,-132.145291,-114.476971,-34.579806,141.886482,156.442389,131.049338,89.730047,64.674081,63.459217,99.226805,122.546473,81.060629,-31.653831,-51.029938,-52.127351,-94.212286,-91.536914,-38.382481,-13.658812,38.433387,12.047881,-47.595632,-227.592319,-316.477208,-352.760329,-304.256251,-234.375634,-233.529977,-287.937591,-367.57556,-402.503861,-431.107386,-395.247222,-291.561033,-266.317041,-241.703414,-211.868227,-211.055294,-231.715177,-212.980161,-85.029624,-14.119714,54.297685,64.276156,98.909727,69.94298,4.115703,-110.948567,-98.652628,14.297598,53.96332,130.982507,198.13004,158.413959,-8.178235,-49.185321,31.077143,105.53612,153.953224,100.50176,-38.205779,-10.022206,24.836821,-19.756241,-32.997222,107.86175,174.223709,113.971429,-12.182362,-31.967578,-11.691635,-2.106743,-31.282556,-44.63295,13.328182,62.609025:backward
-9.081182,-56.399632,-104.511198,-166.457117,-147.019532,-49.739982,-16.65994,-27.981546,-94.163744,-149.393117,-282.926123,-291.64114,-104.171978,9.88011,46.388684,-2.701148,-90.930092,-198.099366,-222.043693,-129.448965,-62.230915,41.183901,97.27553,234.239773,282.500048,207.331166,-9.471908,-54.71807,6.796658,64.27276,140.485695,165.15267,215.402536,230.374454,217.318826,190.777588,200.861149,243.919229,234.443591,131.116396,-28.649247,-112.072323,-201.149585,-193.858299,-126.444092,-73.916942,46.546045,72.966759,26.905787,-38.464101,-42.0816,28.640288,71.143566,85.541057,60.776582,-18.00408,-114.175073,-148.20058,-91.150924,-7.217589,115.33318,132.462139,124.292043,116.082744,106.763124,80.340777,87.542677,154.482377,162.127097,106.377053,89.470761,81.749084,33.791104,14.7172,34.88884,59.602586,83.464858,88.595618,125.814024,154.138786,147.305538,36.259697,-0.652618,8.516482,25.200713,1.853929,-42.049916,-97.961041,-94.203067,-101.407328,-76.735883,-25.947479,90.540376,120.298126,54.223257,-37.112076,-243.344459,-366.761035,-355.037752,-212.848348,-154.492353,-159.630809,-196.496398,-254.938772,-275.029825,-266.765049,-167.041008,-103.55875,-79.933482,-108.856892,-177.056329,-190.22782,-133.059567,-86.927487,-83.945854,-87.874453,-104.235472,-137.660665,-148.385645,-194.59421,-230.438532,-257.716268,-365.787759,-382.286303,-216.227539,-97.295727,-6.280768,-23.564414,-8.776446,85.623821,138.472796,260.326536,288.118127,206.3238,153.705377,135.435594,134.281068,108.689048,52.296043,40.977292,11.769536,-27.111531,-111.303056,-134.285265,-183.888226,-228.977423,-190.789608,-20.194624,32.330177,4.887699,-34.983263,-69.37402,-63.319096,-93.65958,-174.568653,-170.68729,-19.436567,90.470661,158.683567,90.845152,-65.061471,-64.977773,-16.123514,98.973038,132.334862,103.470238,48.296733,-69.029988,-132.780989,-161.949896,-189.912421,-167.499378,-106.413247,-81.559346,-47.115012,-79.88149,-263.775655,-295.714253,-207.155031,-46.48358,-21.28248,8.34096,35.389233,83.155095,72.38351,26.758488,-44.160288,-14.593437,159.359257,271.378877,421.317748,418.658343,310.392365,197.639186,175.3081,190.240397,189.959191,133.530316,98.69202,85.691556,112.802745,98.493321,69.924464,84.850114,73.384402,15.579597,-142.042812,-223.479785,-413.734792,-561.996084,-551.655994,-409.333578,-351.471157,-342.175519,-373.120232,-390.548604,-321.097086,-286.124114,-237.086168,-240.091005,-305.378811,-321.936144,-296.819162,-299.997212,-384.05586,-476.286483,-466.52283,-320.227384,-217.973834,-9.149589,51.631851,-11.80126,-239.344239,-344.905899,-373.7869,-324.500022,-279.443025,-267.871307,-185.005115,-147.316183,-196.031807,-339.15632,-359.297876,-310.220841,-293.810942,-265.304606,-231.945626,-178.034811,-226.327888,-263.201941,-217.705389,-136.072811,22.697678,79.046337,115.74327,93.017849,20.69579,-47.955159,-67.11444,-54.893106,-9.655618,145.53814,197.41509,149.587685,47.220898,42.348936,106.964617,141.201411,202.066143,236.573178,234.52519,179.35129,86.984891,105.698988,119.695619,137.959951,167.427056,246.255257,235.970507,101.058079,42.784986,59.047107,120.088209,147.961463,143.742506,115.213945,67.232211,65.222758,62.627726,1.449368,-10.099894,56.583899,96.096628,120.770945,113.815737,59.8127,-121.096058,-247.766487,-346.49156,-297.015255,-186.47448,-155.239361,-110.087017,-92.814356,-36.793294,45.420645,83.940059,176.72041,219.318751,241.802631,217.331234,127.811105,37.830978,-22.548805,-128.881051,-108.483756,79.194492,157.474504,166.384885,152.152395,145.516558,76.381632,62.005763,122.436674,159.26406,200.843085,205.221783,160.613029,37.186713,-20.766725,-69.426502,-78.656435,-76.097782,-47.354,7.772453,-2.173882,-103.711133,-196.204498,-174.370724,-43.203784,4.439203,34.44815,40.439654,86.561695,93.258905,42.424807,-30.077198,9.793952,183.456197,262.589246,323.399576,303.411411,249.721141,212.425874,201.441375,271.123665,357.741442,505.510731,522.670328,515.604724,537.113709,537.017357,534.20393,548.353076,564.507242,544.751859,510.798748,537.31696,606.300389,539.216694,503.363979,515.802429,525.727339,526.787661,555.2994,630.761923,495.072654,356.654241,191.810394,209.389879,345.828228,407.689201,410.828081,354.729459,233.276855,177.734099,190.277341,280.752277,323.152202,306.678284,240.257587,92.574508,-39.175355,-90.583651,-43.083035,38.82612,162.508703,185.870727,175.082171,148.977417:8.021151,-93.444239,-94.904264,-12.941725,29.400113,62.665823,58.414978,23.564929,-95.957198,-172.882621,-232.626524,-214.744852,-181.421677,-163.343656,-79.641354,-47.147603,-85.997068,-156.142441,-139.467433,-35.064986,10.932029,104.299458,158.960476,209.446527,87.994958,-2.347969,-69.483584,-54.930025,-51.587674,-58.741299,-22.477892,29.36762,154.48334,196.759345,174.541206,130.319806,139.961072,193.686607,205.932096,192.928993,122.96841,78.695396,67.155477,105.981517,218.976977,255.413265,200.030211,121.465844,9.32696,20.776194,40.812045,85.728288,114.21144,181.519412,195.810181,114.819573,-36.28858,-74.844807,-12.243424,68.535044,191.153268,192.275233,122.488953,102.822657,114.811497,113.21814,100.492401,87.825402,106.094259,152.541892,155.299711,137.154786,89.156109,61.417485,97.487758,136.97411,119.171795,81.254065,48.930865,49.069747,1.411409,-94.316479,-102.714393,-33.651962,3.278936,22.685501,7.522857,-9.936911,10.370937,-9.93565,-49.629986,3.551627,200.016201,240.293038,94.096733,-28.155432,-205.762501,-290.584144,-276.636175,-144.971308,-97.223878,-143.045578,-194.915779,-224.319612,-205.843942,-193.537079,-70.485634,13.340101,5.854829,-89.713838,-202.196729,-171.67435,-112.088335,-131.211786,-117.161663,-27.171903,16.438636,13.678235,-26.470325,-79.595969,-115.351042,-148.072296,-185.909017,-174.877097,-75.738313,-7.984848,17.050014,-23.712531,-10.092441,147.053202,207.487131,285.09638,323.461363,380.460959,373.728327,249.418141,92.731201,65.547149,103.809414,119.795998,77.794319,39.546207,-42.038446,-91.161067,-159.248622,-105.020952,-40.81618,54.151251,63.604324,56.397746,46.961683,-16.100526,-99.506338,-119.828891,-104.540816,-85.320614,-45.180188,-21.080954,9.191045,2.519204,-63.251858,-117.253066,-99.628677,-12.399719,19.422836,-29.096719,-106.88171,-199.315029,-164.451305,-172.818237,-174.450549,-115.930316,-1.543798,-0.262848,-80.280382,-134.934113,-221.977393,-212.992849,-172.182163,-107.035231,-119.344508,-143.456645,-92.846707,29.673393,-74.655906,-162.582511,-134.325483,-22.353642,215.742609,302.824413,329.809428,266.000822,91.235233,-19.607531,-26.014296,36.581911,63.590978,37.882895,3.461359,-36.990077,-58.502346,-66.949556,-2.249591,72.989887,143.325846,84.562003,-140.421549,-246.002111,-390.918264,-435.935993,-403.336528,-289.670237,-250.169317,-208.612915,-202.147426,-209.555175,-225.048229,-236.939834,-220.628599,-174.185844,-54.577383,-33.129039,-120.694156,-184.284287,-264.758818,-298.0536,-263.457451,-66.217249,32.675552,115.285416,110.121054,13.242062,-194.895788,-277.459609,-262.973361,-204.3365,-126.872604,-102.311946,-74.27163,-90.421898,-201.197216,-315.563352,-301.950016,-164.773872,-118.272159,-134.618735,-149.544767,-137.057873,-189.113079,-224.736131,-167.094104,-92.237323,-1.228002,14.749965,60.760941,96.851079,117.0831,2.554871,-34.201334,54.273551,141.256513,262.804407,272.765922,209.193186,127.079771,110.712493,172.517107,235.540091,344.318352,366.147974,318.661798,282.155389,267.828515,277.889285,277.388773,284.099106,293.49251,304.11952,278.776232,136.229068,34.801601,50.233661,141.380594,183.547831,228.217749,205.317816,52.831355,-12.462953,-9.265033,-20.421807,-49.666332,-17.907806,32.312399,52.621203,11.624393,-41.818963,-117.015675,-217.115606,-345.778229,-313.073297,-159.931523,-75.399605,56.714187,74.448239,45.641639,28.14543,52.178503,204.688037,297.680331,345.260626,289.416093,140.110323,35.096515,10.238693,76.75492,154.239335,230.409485,214.364391,191.918111,198.046466,169.606059,136.645293,157.416873,198.771974,209.44152,221.192308,188.300764,63.424689,-20.294465,-52.365115,-97.581213,-99.663273,-74.980975,-54.40886,-23.731665,-20.731584,-51.761944,-105.127088,-96.495986,13.58442,77.824685,143.886227,154.270981,155.844311,86.859056,42.343557,51.316412,96.405005,216.584977,298.048112,390.986196,359.124333,203.069973,102.238041,121.653475,254.946651,330.460159,420.550935,400.89588,259.544764,199.484674,222.149171,286.983885,322.136685,418.057449,465.406638,475.300459,433.210976,377.227476,401.136254,410.337669,411.147829,410.720813,437.792445,463.761276,474.887558,318.621186,196.466715,48.390867,50.599769,131.828264,158.437819,97.283171,29.361706,-70.260135,-57.167373,-23.058129,57.98682,102.276465,162.582251,163.273518,111.81887,-12.406273,-80.20501,-140.310414,-130.091161,-93.298592,-85.385087,-84.543887,-87.052388:143.852167,-25.773652,-57.823277,-29.814702,-15.215378,11.209473,26.252782,-6.315104,-124.589542,-168.669975,-192.598363,-188.435559,-168.952835,-166.252987,-180.684719,-176.650523,-180.677115,-226.197791,-200.547946,-25.089675,61.638873,136.649726,133.767501,50.114305,-79.146335,-96.493426,2.05888,56.509616,47.287043,5.464784,-24.648529,4.779208,97.846776,153.546847,164.781943,182.764863,169.665955,54.520522,0.329407,5.742386,2.856493,-15.969832,13.305405,51.752273,127.198227,156.99249,166.324021,153.264064,127.179519,113.049182,115.052523,127.352425,147.150319,208.230408,221.382601,160.973538,8.820648,-42.935493,-5.460555,64.910714,216.821395,246.965262,154.780363,80.776083,-5.655659,-4.444511,33.608036,142.340437,164.843312,106.182351,77.666378,144.130749,217.27847,198.397074,163.80916,175.116299,188.286277,172.627012,95.565982,34.01024,-109.679538,-142.71909,-90.287585,10.230844,13.766169,-10.359769,-1.651468,32.08787,-24.267262,-47.408255,13.435318,69.763646,142.784873,135.937915,6.140286,-90.519625,-228.094642,-216.990333,-181.429993,-169.322067,-195.440065,-244.997575,-247.097836,-187.979215,-184.428703,-203.625714,-108.408544,-20.724486,6.629675,-50.491318,-146.09555,-167.710752,-210.106233,-201.858111,-148.948905,-59.569244,-50.409661,-55.003623,-71.368055,-143.517164,-216.299621,-228.706938,-201.717111,-172.365305,-76.920607,-26.532804,13.077509,13.161891,44.536336,126.603926,177.633801,301.533331,360.111295,386.989765,348.761648,242.071941,161.787418,144.021394,181.829739,218.014495,206.554512,156.99099,56.770343,8.316545,-96.530028,-87.196283,-16.576831,120.908215,137.937859,74.352201,19.587981,-62.831277,-64.854983,-44.149532,39.450805,81.553743,107.260551,106.696799,91.096965,72.173215,60.353561,60.460178,50.040923,32.802412,28.641073,-38.635191,-101.551083,-197.599571,-263.280993,-273.259702,-182.908323,-114.354697,-45.048679,-30.446283,1.593395,-11.907429,-160.05272,-281.008216,-245.730141,-112.250427,-91.011109,-115.597482,-113.5033,-83.90167,-128.278774,-143.896487,-40.363789,37.896236,136.242776,171.039193,206.038129,171.974439,3.099475,-119.012991,-125.293968,-74.401946,-41.380376,-6.838471,-8.093362,-16.270201,-62.588633,-110.153975,-152.772286,-123.439854,-19.236661,15.071588,-31.318581,-117.091995,-342.195329,-422.972159,-376.931622,-248.481678,-200.83485,-133.678113,-122.25697,-162.76774,-234.610285,-231.77349,-117.934228,-51.314039,11.50174,5.962204,-54.207125,-106.685801,-221.163957,-161.117322,-37.635434,192.249539,226.084895,191.250226,173.218588,134.411386,3.127657,-65.491977,-56.148456,-1.489245,50.774978,45.773311,59.089316,75.692274,3.056727,-179.652715,-219.848831,-178.592547,-152.033251,-140.925025,-142.286258,-165.5897,-225.242372,-241.379052,-204.947056,-153.31521,-15.930165,31.649207,30.70295,16.058591,-20.118941,-112.955661,-121.914461,15.656759,123.198773,256.195679,246.310099,156.19211,93.69249,73.526267,119.364018,203.574941,360.501662,379.440187,344.092168,332.338599,326.558928,305.060355,280.0281,221.604427,229.112977,268.883697,232.854702,69.709404,6.574788,59.037093,219.976454,259.704311,243.345811,197.506855,49.904087,-13.572641,-97.852464,-145.016996,-115.175732,31.539828,74.184565,3.869313,-54.450427,-96.301023,-135.474172,-178.402559,-235.169029,-218.81278,-104.161702,-29.041492,62.612752,47.778152,-13.951397,35.742417,79.583565,166.316496,231.660019,364.712406,379.632027,299.22116,172.510807,109.45576,53.612192,82.201881,202.072577,243.964857,215.684857,156.105194,33.863358,3.658145,28.360845,120.109882,163.418095,166.417356,126.130936,58.824538,19.851368,-4.021547,-24.573451,-34.867795,-75.083015,-71.642762,-17.227647,-0.876069,-31.83366,-64.099567,-49.960458,-0.593383,29.07105,119.607173,150.482767,104.343231,54.934059,76.880704,127.300359,131.006679,189.12886,256.58781,316.623032,273.344693,122.68788,75.114729,119.437162,224.553426,240.268479,205.661129,167.95392,94.651534,96.342564,125.415751,225.881618,298.84094,430.328033,433.460843,297.424192,242.0731,280.703678,313.27877,285.61883,249.045808,260.997776,286.854622,284.443993,252.899231,121.47367,28.671325,-38.909256,0.905029,65.422757,53.122432,9.889079,-7.853158,-95.332967,-179.728198,-164.741928,-37.700338,44.472883,161.355893,155.961897,28.433195,-71.459261,-72.841838,-38.537548,-31.214686,-10.116825,10.002504,-20.275247,-83.517584:93.697373,24.271647,-18.081362,-119.28727,-177.346545,-236.685584,-214.061024,-151.348425,-211.827088,-267.377935,-281.305106,-218.234336,-39.302097,20.954991,8.567408,-41.8942,-130.426408,-190.707546,-200.281642,-116.994886,-52.086108,52.042083,112.83621,252.009587,234.960774,146.5848,37.232098,80.222349,181.294344,151.177006,9.22055,-7.660578,110.797978,182.490603,158.111118,116.673063,149.209128,215.38241,173.563556,8.852409,-92.326523,-131.364113,-184.354559,-172.40965,-69.169581,5.686135,111.019929,109.615528,59.116682,48.945272,66.928918,116.563256,132.985918,170.282806,197.839857,194.017536,54.578336,-20.591756,-24.691262,50.084174,184.505979,192.147361,90.560509,15.365629,-63.58366,16.317935,90.557649,178.14973,154.677625,37.734843,1.852082,18.394579,35.952788,21.345056,30.426668,64.53309,125.594405,136.195059,105.654351,72.961389,-2.862463,-49.687225,-27.897445,48.679132,52.978888,40.930748,76.029451,188.111336,172.280481,120.121961,80.355702,115.985077,188.610053,160.216824,-66.658436,-192.463656,-266.44566,-203.91465,-179.109733,-133.202226,-126.463278,-175.824708,-205.816418,-221.195622,-228.567861,-241.140019,-218.880695,-173.052663,-94.468139,-95.053427,-148.822069,-171.516164,-196.769899,-216.356291,-198.643838,-117.192187,-104.30971,-174.250428,-228.511813,-307.496456,-323.258498,-327.144753,-341.95668,-340.287419,-259.841861,-173.205072,-31.312754,-13.186885,40.252992,184.955399,240.726976,292.792194,307.254293,315.236364,291.719217,204.494299,144.207819,122.794635,102.656823,123.840339,195.506681,192.965048,77.321802,14.595959,-85.157856,-144.238256,-107.838117,43.901806,96.997607,97.101212,49.537405,-57.9476,-68.713169,-43.241792,20.839059,40.362648,43.070746,48.190983,89.903241,110.688218,84.995939,-7.772578,-8.589472,76.442045,92.186525,25.105489,-23.080052,-99.445139,-150.917649,-169.272017,-161.252982,-136.730525,-89.212353,-66.972757,-41.654963,-71.60938,-236.616588,-313.972032,-261.029618,-97.458706,-44.571401,2.466549,16.351367,13.307834,-37.129165,-53.824586,-0.192129,64.473448,225.609059,316.538344,389.684139,323.806724,116.300045,43.683816,53.309866,47.128059,36.953086,76.13094,113.326351,132.382808,64.97376,30.769754,45.419218,87.902368,131.67539,95.957419,-99.451039,-225.490347,-421.764129,-476.797958,-454.404725,-375.693863,-331.967866,-255.726356,-249.882162,-259.78507,-266.622292,-302.204273,-326.077924,-274.793084,-161.777075,-147.560903,-203.722427,-244.731958,-295.491004,-280.198482,-235.774471,-79.357494,23.089754,224.588933,277.748468,211.804747,8.88258,-70.683843,-119.296128,-119.840787,-112.500439,-81.864642,3.665739,9.62733,-142.994332,-374.468102,-404.417477,-318.492464,-288.57577,-299.99671,-311.800018,-331.835392,-338.792218,-316.394858,-208.941228,-146.455568,-59.672847,-32.0165,-1.928005,-1.175821,-25.700763,-92.959851,-102.486822,-25.447059,20.478913,78.728087,105.091562,129.30092,54.087809,30.6992,116.957426,177.962309,247.209341,269.611762,273.848876,253.120096,170.757379,38.878428,14.602661,123.914557,209.280923,277.54961,234.092489,91.910602,60.433025,98.918581,197.641489,212.825216,184.777213,179.205604,168.241757,146.944312,117.512728,121.250611,128.057538,132.432483,129.381909,122.97201,105.136552,18.262348,-106.014819,-168.077463,-217.869401,-189.856011,-73.905739,-6.012499,57.13286,38.189453,20.086809,86.178661,118.135538,166.915435,200.001783,254.155602,244.721559,168.626,97.602538,59.264449,-13.176279,-11.095096,95.123297,157.858993,169.121831,107.921666,-26.497306,1.09183,64.099542,156.086747,192.11267,244.321806,223.87649,115.823951,3.035338,-36.96623,-24.928434,4.614104,1.995108,-21.04615,-30.615438,-24.14157,-73.662652,-156.14753,-146.632858,-49.425337,-14.020496,15.957876,20.349703,1.376711,14.241695,36.766833,89.183889,116.382838,182.608633,224.247631,251.212443,217.98089,125.35617,92.205801,104.095139,163.439632,211.409882,333.116404,364.719299,272.128355,136.600868,131.908455,210.409172,263.505761,392.468332,437.141517,375.110481,311.418705,276.557349,295.319983,285.245312,235.279084,226.757263,287.138068,331.020348,358.188269,245.712651,153.501486,52.692427,71.51743,156.805322,193.732259,205.614937,170.653199,99.792416,72.477133,67.427123,125.936082,184.383276,261.390344,247.598746,93.707937,-93.280719,-128.090571,-76.69903,-37.35409,-2.968874,8.738968,37.526915,25.243452:16.829025,-109.666646,-152.102672,-167.943515,-165.554479,-161.952334,-154.16795,-167.863414,-252.508502,-284.313139,-230.371589,-149.905386,-16.624651,-15.922558,-96.195044,-120.685088,-160.954705,-215.647845,-184.676046,-45.662501,6.42253,98.12771,144.509268,129.213526,29.401471,25.569619,80.357131,96.631178,122.214185,130.863263,45.176657,-16.975449,-40.807048,-28.796214,-28.648211,-14.73909,-10.350617,-40.528036,-65.63165,-76.586774,-140.708756,-190.823307,-157.08973,-78.30809,48.930379,66.351713,43.48339,31.368105,24.372359,38.205262,62.903463,160.108316,228.208945,315.870036,299.923572,187.284982,19.219661,-56.841812,-66.947931,-5.183732,146.0099,190.025387,103.260418,-1.162718,-136.058463,-76.737748,8.415831,161.218649,179.288373,146.330603,136.326722,97.747422,0.846184,-26.076966,8.366892,45.331008,126.162829,151.965278,105.169748,60.598851,13.285817,-11.148186,12.527524,162.349881,235.434589,266.646589,239.829455,179.774547,106.095011,77.507804,110.627354,154.179554,192.946056,170.767801,51.478682,-27.963735,-148.128929,-127.410185,-78.491967,-38.961477,-65.672064,-119.699103,-121.559923,-109.59908,-166.986045,-206.077093,-166.324242,-108.001874,-56.042199,-62.488084,-110.778113,-154.546981,-263.099807,-311.297015,-258.203595,-51.878617,12.513085,-43.852093,-120.805316,-228.940142,-301.081748,-332.81293,-345.99329,-330.063212,-247.267143,-179.971809,-50.301168,-9.224884,29.346937,67.837954,119.007429,287.545903,360.34456,412.58414,414.608898,374.162623,196.336499,109.060006,85.048841,131.652673,200.016222,174.952316,64.199829,27.078777,-58.24879,-57.472812,25.604345,174.906737,197.576358,183.709457,159.28275,88.698318,17.178004,22.628522,138.879877,187.593158,178.596346,151.513073,116.368926,109.375011,86.758646,59.821471,61.856975,91.521698,114.732119,110.467841,56.956907,-75.781766,-110.872429,-87.976903,-11.68691,24.778578,79.733513,98.073517,65.795302,6.120424,-124.291361,-158.880009,-133.213594,-57.044937,-11.158767,91.400129,125.209588,101.592993,-7.8655,-32.41858,57.354392,140.769041,286.989263,331.675875,323.769659,259.405288,43.286689,-45.142803,12.093542,123.971475,114.24517,53.231622,52.044597,106.382246,100.201301,61.652772,21.906935,33.667834,116.545411,171.098529,109.619616,-20.96249,-239.404867,-292.603167,-281.621844,-230.31642,-190.249014,-94.531839,-69.818119,-84.403744,-179.476267,-223.171781,-157.779678,-83.025133,-16.245241,-19.644242,-27.727291,-44.441067,-122.78946,-92.389407,-10.023513,185.792585,275.370664,412.545335,427.936441,321.412689,141.584815,81.442215,97.195562,134.164701,149.288977,138.757111,124.952479,104.285961,-28.693789,-178.084021,-195.987397,-178.206517,-171.138196,-151.174642,-148.936465,-214.926552,-333.307138,-361.769641,-313.818097,-238.827248,-37.759798,29.863888,-2.384542,-64.89372,-124.959922,-103.729676,-86.379399,-10.667761,46.244143,140.110962,138.976716,42.89796,-8.999121,5.328157,83.531837,137.41643,271.720446,335.437385,349.74722,289.825604,125.666027,19.076524,24.026643,135.069163,203.459873,260.815439,215.006994,53.493114,-7.207119,4.735926,73.841456,131.021709,233.61401,218.017896,41.251787,-40.047577,-125.218711,-157.168514,-105.756047,54.093926,81.044268,7.307379,-46.54862,-108.440339,-147.994911,-181.854011,-244.223362,-235.129036,-80.425399,9.186304,20.432952,-34.888393,-68.113093,18.95754,69.158299,177.34379,237.096516,300.805004,284.756066,195.630258,42.75281,-40.774635,-76.59525,-10.885949,161.054309,210.13485,162.396648,68.074685,-143.336365,-175.104697,-105.74576,90.705584,163.845523,168.76704,115.201786,-1.764622,-99.014313,-110.952851,-54.437022,-37.683421,-37.457942,-18.0192,46.762305,55.117184,-29.559365,-166.414936,-192.653689,-119.527889,-39.124579,71.763747,56.927929,-22.931869,-93.294573,-124.185955,-77.217471,7.161947,196.403902,262.871342,270.600878,217.206263,84.920784,18.849183,44.77642,160.793602,200.213446,214.860675,194.639577,125.033901,61.32669,56.818677,166.47847,256.378687,383.259256,390.327348,286.317564,221.855784,157.690788,130.281832,134.86542,203.738464,246.362594,277.457018,265.233277,204.210989,45.474058,-25.448197,22.226668,115.542041,230.513215,216.540795,122.87223,90.707533,33.206067,-53.612171,-39.764874,134.988374,235.751645,315.208977,285.846108,164.708327,14.273962,-35.784788,12.356681,84.308491,184.963002,185.562959,98.381337,34.644818:79.535702,-61.62063,-167.288065,-291.909053,-295.338741,-239.446755,-215.942737,-212.695408,-270.978432,-322.595142,-333.005515,-258.179126,-54.271345,31.993862,102.354014,77.880313,-18.978777,-116.678719,-147.345993,-128.783314,-86.516055,34.665042,111.582415,274.443126,335.89791,288.070099,131.362853,89.826887,89.219839,84.282064,23.862599,0.962502,30.949149,119.335473,156.775924,169.240956,154.841425,148.632442,141.492167,65.633581,-59.856874,-125.010073,-202.892695,-195.033393,-86.727844,-4.143036,104.007627,95.531288,23.28888,15.641589,40.279537,72.29671,55.066954,5.905211,13.65371,42.442546,-43.921909,-98.729168,-59.808243,27.9637,130.983453,112.738586,32.120684,0.445419,-2.711119,28.365718,42.360276,118.032169,151.399002,119.361906,81.449089,52.382906,39.316783,5.773195,-18.850758,36.709776,162.444513,183.892063,173.871235,154.332015,133.451319,153.765302,163.134571,195.023673,208.603639,204.161731,202.18249,219.980255,176.916836,112.34081,11.888224,12.964978,77.712299,100.090823,23.823615,-56.401861,-137.572576,-71.914367,-17.626118,25.167863,-14.617637,-125.251854,-160.998968,-230.643032,-265.612938,-258.269467,-232.574544,-195.533381,-54.762929,-6.65541,-38.97776,-69.388722,-67.735127,-97.974211,-121.963761,-140.632746,-155.018,-211.923174,-252.131476,-336.246693,-336.941909,-326.844542,-372.194368,-406.54659,-354.980411,-259.521672,-85.35824,-34.066331,81.882641,207.814037,251.87885,271.027859,247.241785,221.954181,215.694239,143.001755,104.071188,126.469494,224.616534,266.979627,257.047188,218.906216,140.528297,99.063021,13.581241,-14.661492,3.545699,96.952627,147.274087,142.603456,74.333544,-59.336199,-35.721724,10.672836,60.86172,62.941743,112.155163,162.165914,211.665831,192.375041,128.100093,86.473388,99.636246,213.706667,249.049601,186.304986,129.914383,69.143574,64.430282,52.845275,31.098112,27.559902,20.827014,22.238115,-29.77993,-116.117902,-311.279969,-316.971326,-241.632285,-89.03887,-46.588344,17.50037,45.705484,47.419258,-16.152013,-42.034416,19.13166,100.121511,257.436143,318.111693,400.104547,410.589214,338.931401,216.965963,200.743738,274.480004,322.978045,361.585297,351.314615,338.32371,361.142279,341.536602,249.90725,224.204206,228.186182,209.414916,15.591586,-130.806014,-324.513706,-350.511305,-348.192055,-340.50633,-318.104055,-243.051533,-227.452867,-266.555384,-285.907763,-264.333701,-207.537183,-189.816686,-176.064132,-182.214534,-252.461778,-308.155454,-372.146814,-325.982429,-269.866639,-124.836896,-46.188582,110.280248,151.241517,106.723968,-8.706589,-68.274911,-102.680005,-61.49513,0.777624,2.521899,40.69344,54.602647,-44.510397,-180.028382,-204.562262,-250.694709,-279.024002,-226.835565,-165.335486,-148.997113,-219.964798,-227.815677,-153.411899,-81.24407,37.896739,55.202808,51.337776,63.798422,70.610735,-40.130562,-90.183656,-88.69194,-60.913939,-9.234689,5.028645,3.159758,-15.062939,-45.01915,-108.30827,-92.722061,15.856509,57.794306,49.82479,21.368008,-11.974212,-48.790874,-76.634693,-64.285582,-1.604775,119.223249,109.982958,7.591547,-12.497391,-4.715848,38.420572,78.755493,131.229375,146.760612,138.414109,98.37924,39.648695,51.08303,41.778622,4.089636,23.681979,158.553242,205.628568,116.681254,-117.133225,-203.662386,-206.911241,-165.023413,-160.604772,-178.807405,-128.665097,-59.890605,64.908932,81.525447,75.710148,92.449017,103.95241,92.558528,68.611435,5.872685,-52.29422,-80.979127,-139.622268,-163.981803,-139.781687,-84.795189,-49.205247,-98.707829,-144.199988,-26.757607,35.576068,133.679322,173.909527,197.176709,170.820451,79.088726,-23.423551,-78.955068,-148.428166,-148.473819,-115.961223,-91.162474,-37.367841,-39.685463,-151.829519,-273.942069,-284.877862,-212.236112,-146.285446,-9.697675,9.859131,-75.193391,-108.365697,-71.366045,11.661984,18.891971,42.182986,113.737448,244.7535,227.815114,122.45831,136.831195,180.351752,239.936271,268.522902,394.568696,457.954071,436.827136,275.978523,224.104034,274.334502,353.52854,458.994467,447.371928,349.579369,303.941194,250.401733,240.538531,257.151,292.076445,311.254934,415.831392,482.438444,485.765238,299.619283,204.302822,114.564123,136.244683,257.487343,301.795191,289.786205,255.73567,229.174887,235.686649,222.466648,215.896525,239.280805,264.618962,222.11877,76.669806,-10.274112,-46.484885,-43.170243,33.708681,225.231204,272.797548,252.34926,213.522086:53.687114,-43.374938,-65.533723,-98.716161,-128.525257,-181.23694,-197.900089,-233.690996,-290.96822,-312.475642,-274.544671,-211.590325,-55.455974,4.82513,29.343412,1.963347,-75.816103,-140.575918,-146.651792,-73.254671,-7.841637,94.064043,115.047326,152.30037,183.644889,160.782531,83.605591,76.587509,120.136353,129.390475,67.082685,16.149105,-48.265799,-57.026981,-29.556643,105.377427,166.10675,149.677536,93.919944,1.266486,-121.356002,-202.067433,-279.287341,-245.109257,-71.28426,17.870089,77.739294,55.713811,3.189398,20.698512,60.164704,109.899936,112.086552,140.373872,161.623078,117.006979,-28.835054,-64.244657,-7.973694,30.35412,92.205,135.25276,114.759068,19.213014,-130.396334,-17.383069,78.22494,156.001065,132.623139,65.15976,51.565971,30.611571,-78.263643,-144.422028,-151.94959,-72.355665,96.658672,118.232794,74.99129,69.760246,119.773149,160.730522,186.344441,277.610071,316.307521,301.202503,256.473252,182.109441,153.610504,154.447037,197.65599,216.146991,217.501084,204.379894,74.480343,-25.930848,-144.867242,-142.837266,-96.379075,56.572301,95.076102,7.942903,-76.95092,-189.992852,-214.284886,-221.272361,-181.303736,-125.047117,-19.605314,8.79254,-6.578122,-62.234801,-216.40228,-285.836405,-262.494849,-154.690612,-127.127415,-172.147588,-203.380596,-241.854288,-351.601576,-412.282163,-382.83667,-300.883777,-147.895716,-91.117091,1.857131,30.970903,66.800894,136.37073,198.617782,325.884215,357.142507,366.665929,357.344339,253.27456,131.93853,130.517436,205.014954,254.270613,338.452661,349.070254,244.403458,145.602472,-13.575959,-13.113327,48.178712,201.835186,255.310947,255.162549,198.579256,58.100042,29.696411,62.009212,111.796896,108.46322,110.559424,137.516729,192.684176,183.254969,81.972514,28.52135,67.398582,207.654091,242.234328,181.818682,120.056929,42.410534,27.738987,9.720927,-3.596426,34.322734,151.414388,172.374912,47.646741,-60.943655,-219.235566,-195.980643,-116.129674,49.034808,106.326878,182.63761,178.175447,83.343488,-8.868895,-25.074049,72.940508,173.545117,367.326947,435.301894,443.369402,371.348919,176.347727,81.632421,96.636689,179.318993,208.828829,224.788336,218.625931,189.056866,155.684377,143.645618,156.679867,174.524714,184.719,164.706367,26.978008,-72.937101,-213.398133,-241.90061,-232.658534,-213.677416,-193.425646,-82.795298,-23.280107,3.736927,-107.225004,-178.479332,-215.789758,-173.293665,-62.12394,-38.716876,-117.57714,-190.067565,-270.238876,-226.53481,-162.886497,47.453306,190.220367,444.761484,473.205021,325.131984,165.867707,113.032282,42.000618,28.259886,44.050243,71.210096,111.075556,81.882124,-123.52791,-301.552883,-279.9503,-139.469199,-108.806016,-121.166853,-133.408,-168.945604,-229.905688,-262.469584,-233.621802,-155.397385,-2.487744,17.250674,-7.550411,-7.90676,-49.419156,-191.397652,-210.803052,-91.144744,-24.015423,21.174765,5.448214,-79.877008,-145.246693,-122.195591,-1.251694,48.006648,124.698233,161.365862,154.194871,101.003069,-6.578007,-44.019155,-43.497591,17.491754,67.317398,101.067827,61.054424,-49.841147,-76.30011,-70.280469,-58.176256,-36.274352,78.521566,140.317266,131.739847,52.769213,-140.361892,-166.37086,-86.854917,44.044688,48.55779,32.990415,-2.606869,-192.634461,-331.400672,-333.327979,-252.377093,-196.983498,-115.948017,-91.396304,-71.667555,-72.509367,-70.529857,-66.753773,-41.655477,68.279842,131.815245,224.957969,228.364619,110.42525,-61.353587,-113.382548,-116.711085,-86.111337,6.769567,57.804223,74.753832,30.196216,-84.993794,-127.760029,-103.237533,0.665894,65.785156,145.831293,127.857249,27.315706,-105.614952,-185.143754,-247.397696,-207.19605,-74.588299,-25.269279,-21.263958,-54.154669,-157.680793,-255.150698,-249.579039,-137.447818,-81.197595,-61.064825,-92.161192,-135.754486,-65.105747,-16.677499,33.814877,58.225033,191.047989,263.732829,207.60828,92.136802,-52.217629,-16.659146,10.807101,60.401083,101.346226,199.284351,215.986383,129.681152,2.077739,-30.058388,49.420333,172.15853,433.98877,480.714129,340.622964,222.145189,56.838686,36.831576,80.101067,189.856562,234.239144,311.304712,327.437129,260.633803,79.660813,4.42956,55.885384,152.474821,265.424878,253.080126,146.126821,100.979198,111.766255,178.972986,217.225941,316.737528,377.843613,466.855085,437.431985,227.743511,41.530845,18.317575,111.638332,188.584939,301.543784,308.986865,208.277225,132.161614:-98.063431,-163.902102,-258.553925,-392.088042,-407.199435,-358.199813,-309.262694,-265.153699,-319.480252,-352.970523,-371.792434,-344.558922,-242.982083,-176.794317,-29.798146,24.284667,-20.856672,-237.589949,-299.956026,-220.921028,-119.655987,85.200605,153.592772,197.247479,172.933093,139.985483,14.702821,-57.568956,-131.494238,-122.376676,-75.083135,-58.629623,-43.463913,-33.331926,-11.590631,9.400375,-8.062742,-14.097574,6.371829,26.599695,-53.031358,-130.578713,-217.935161,-186.683457,-35.72699,47.542127,131.684902,123.101031,86.464544,13.866246,-30.26639,-35.005771,-18.261165,-56.091776,-88.458795,-82.251137,-58.864253,-80.051419,-108.467561,-74.961681,34.494467,49.901344,-41.072313,-102.881026,-135.397652,-27.819456,31.409698,43.830243,-0.760378,-48.40528,-22.160289,35.211713,6.344723,-30.768883,-72.921679,-38.342952,88.322455,122.698902,135.530235,149.613889,228.146085,316.945361,349.286216,367.012915,344.562975,270.877542,246.826586,231.732783,199.352844,171.58156,150.10507,164.963446,204.636653,229.241153,252.914475,229.459721,167.172221,161.162091,180.057882,231.928109,253.146211,235.163483,172.094651,11.414802,-47.71625,-55.665564,-95.349673,-110.269351,-55.179385,-9.380892,-5.411332,-17.96025,43.287468,94.783155,66.218918,-16.460963,-36.318235,-75.759215,-119.942694,-222.654048,-292.915486,-332.315893,-391.062178,-378.023187,-291.988741,-244.140699,-116.693789,-36.048432,78.019064,120.259049,151.486791,206.472128,219.830124,240.199691,210.331977,90.732499,116.122067,175.964869,285.493868,323.232622,357.335042,349.470508,280.805876,225.111242,131.759033,162.903329,213.957612,283.404701,275.073867,159.905861,78.780698,-17.666802,17.766607,64.961328,159.911121,184.591898,217.983565,264.982256,361.805508,365.437222,335.738286,344.12983,351.958859,335.441437,313.042035,296.035555,301.310272,327.755776,351.07731,312.384549,188.411485,155.054228,122.490313,95.390276,-3.521489,-53.496071,-77.815097,-105.167534,-137.760799,-143.388313,-114.309868,-58.047578,-48.707123,-95.556354,-165.298686,-154.440021,-5.836191,80.119604,164.71571,179.741584,211.442432,253.250593,386.567507,416.825963,383.811689,326.519903,319.317924,314.194329,291.618538,232.876456,260.106402,267.47726,194.352239,140.896052,73.816627,55.163025,-64.974562,-162.844648,-276.601603,-303.896404,-329.891329,-366.010538,-355.533279,-297.003041,-263.02334,-178.985861,-103.871887,-114.098946,-212.96537,-253.778156,-268.617423,-256.575425,-255.853681,-283.976746,-336.419565,-301.49772,-281.667606,-227.325007,-129.808179,135.759981,184.988833,73.145913,-57.008817,-94.359691,-95.750907,-48.681288,18.757232,0.542365,-67.905209,-88.01785,-116.134588,-130.551572,-117.328897,-83.877872,-76.399744,-59.127016,-56.709913,-104.36809,-197.37547,-228.812386,-193.839415,-147.338735,-83.479411,-69.791014,-34.058064,-12.526704,-41.34292,-132.888835,-127.561948,-23.338251,15.947674,8.845465,-32.096436,-112.134435,-123.168488,-144.444833,-243.807012,-271.173252,-227.653431,-189.287321,-186.661643,-224.54114,-294.124395,-346.453869,-357.074262,-291.904724,-223.019875,-63.439472,-4.911611,11.578437,-24.936638,-23.297111,17.028233,30.666276,35.907599,58.033103,106.115852,93.551732,65.450431,97.999065,103.924114,64.595677,38.84452,89.025067,160.631708,167.309117,-37.935321,-124.108161,-195.194708,-209.440066,-244.918716,-247.941102,-173.799903,-100.719937,76.874996,137.191993,86.730121,-25.694543,-39.079092,-12.802288,9.462876,63.248393,80.056821,50.815682,-46.891082,-74.902611,-82.943606,-92.649466,-126.523879,-130.496638,-105.702934,-82.174241,-79.354133,-55.330413,-24.497521,39.730205,51.603622,16.954855,-119.277962,-200.376216,-269.183858,-266.032464,-238.549565,-203.434013,-128.636023,-134.237207,-243.050275,-290.545041,-261.094968,-213.614274,-213.954031,-176.770893,-141.444786,-99.6056,-50.927388,-38.989086,-51.052676,-44.300662,52.684109,132.401052,260.64065,281.442755,255.604107,235.964379,248.189845,300.070422,327.870056,388.908022,412.252174,422.00951,405.012357,363.64036,234.778674,220.698782,316.401255,343.931623,266.580688,214.360764,183.383364,163.789074,147.879613,132.311762,136.013095,181.277177,202.792195,209.397106,176.089432,128.986574,52.846111,55.245354,63.236558,40.405114,-23.323076,-25.35808,56.88299,92.995579,72.784349,68.177167,97.503514,133.936064,98.490834,-67.985109,-171.199076,-177.312774,-95.59861,-2.72096,178.867004,229.843855,244.727418,231.984213:-24.494776,-101.119689,-170.789346,-234.985011,-192.931796,-33.752955,25.399929,73.045665,30.292405,-35.782702,-167.120295,-183.432727,-110.179812,-44.988152,69.495556,93.982158,25.175394,-122.915488,-137.638671,-30.478322,26.965262,100.101878,136.417517,206.280739,195.370659,130.376175,4.508183,-9.559298,-20.209588,-37.95681,-4.596013,77.645655,250.503727,214.158923,149.946008,103.699525,131.965979,196.471221,187.51056,70.488557,-124.98424,-236.519864,-342.306149,-311.320556,-209.410726,-155.151411,-6.149685,60.08156,86.790359,5.874055,-14.956552,-1.894625,-8.383869,-55.88686,-79.969523,-108.454849,-93.851837,-69.859599,43.420298,108.907775,106.188922,46.855546,-8.047009,6.62339,-1.641794,-28.366986,15.746165,145.135644,152.305765,84.830802,72.568051,96.153231,84.786675,46.465492,-16.988868,2.172121,109.852098,164.07591,239.893795,254.646991,217.469412,120.771062,78.3035,50.500705,65.111729,76.346695,57.119922,27.321969,9.561206,-15.170497,-41.911608,-17.378155,100.133263,164.106873,192.200298,146.721141,12.32797,-82.80561,-71.961418,49.936115,93.904794,78.82782,39.747678,-82.538311,-137.441578,-113.321199,-84.141403,-124.34364,-238.548158,-230.825821,-79.928685,-3.122028,66.147343,37.592884,11.92914,-66.542699,-124.643724,-202.581206,-208.505772,-220.342505,-284.463205,-326.795071,-367.590674,-355.937429,-272.668451,-209.175259,-89.979304,-45.34092,1.269249,37.341855,92.121651,190.069465,183.889251,125.15059,101.13451,47.561534,24.043436,38.663615,110.174103,137.879392,105.522402,68.856883,10.579826,-29.073543,-113.809861,-97.885692,-32.237276,142.537791,181.670214,106.689253,36.621437,-57.960322,-66.446067,-53.111204,-25.971349,-23.14017,-17.433871,3.238239,86.392813,127.043857,121.151079,43.954391,55.099906,167.248287,194.651039,137.205887,87.210365,20.186345,2.878547,-2.658651,-19.128008,-38.547998,-79.951429,-82.03163,-102.121055,-144.911555,-213.07819,-174.512946,-134.214081,-68.527717,-51.54441,-7.833564,19.885429,18.416515,-93.936155,-154.838367,-154.741037,-84.715073,125.594681,234.583142,351.326401,359.429005,377.973006,349.911896,315.393245,289.863267,292.643903,253.957563,213.176142,181.895716,187.131271,147.283131,60.352205,54.464911,11.024946,-50.320109,-178.095976,-231.806231,-339.281221,-442.12287,-445.711515,-321.729491,-237.659142,-170.748073,-222.541563,-348.704453,-287.825053,-243.999131,-227.843284,-234.327271,-269.033139,-289.775754,-297.111025,-303.117825,-386.592125,-514.932812,-532.387203,-374.21152,-223.665289,31.130617,54.143552,-131.222752,-351.510591,-389.471946,-280.441177,-184.45594,-110.536337,-141.700755,-203.301463,-202.170141,-211.451905,-278.919304,-276.873502,-232.065603,-239.774455,-244.478779,-223.745005,-209.283347,-239.087835,-276.07339,-299.902313,-245.480182,-110.883546,-82.631648,-125.043451,-163.085557,-171.618466,-186.817002,-214.94621,-212.115736,-177.649573,-108.899908,-81.94662,-44.328085,-77.513601,-122.267396,-189.994881,-183.321477,-106.068701,-67.512847,-72.091381,-116.593735,-199.276479,-216.907141,-214.31214,-160.724335,-103.834136,-18.119413,-26.713612,-95.177065,-94.390223,-75.689082,1.534466,60.803292,132.573822,134.937351,80.119801,28.528526,-43.678839,-23.650576,5.936648,21.444498,4.390267,76.151573,164.967761,183.172726,-73.23558,-191.142946,-248.927402,-219.407988,-178.907565,-165.634787,-123.341925,-105.078077,-12.255659,119.342361,121.557192,58.204098,59.130926,92.429622,75.995374,10.863538,-47.35824,-90.915336,-119.575889,-78.652011,16.131858,19.250748,-27.962249,-35.484059,-38.705059,-45.211927,-8.209172,126.018049,177.263274,184.94069,150.274879,70.494807,-21.708789,-85.736934,-179.052398,-183.548833,-115.197647,-57.222535,-0.791986,-40.494348,-200.754757,-290.959748,-276.722068,-196.979984,-153.833575,-79.29479,-66.043406,-53.534291,-46.365586,-69.924685,-90.747654,-60.285733,40.349494,93.219983,198.101595,241.997019,272.229862,218.952832,208.467941,280.588791,341.24071,425.225946,444.314475,492.121338,511.521627,474.363608,349.62974,317.37002,361.728232,404.814833,446.950846,441.582308,374.589103,314.516052,332.51238,364.735369,347.770011,366.638272,419.990113,486.951431,428.984124,380.129674,307.387835,289.929103,262.588649,250.494106,244.019734,243.153091,235.222518,204.79026,177.687041,149.954237,164.019074,181.490255,144.069571,15.409313,-69.305146,-89.085486,-2.624691,100.948473,244.709544,259.252351,281.667749,319.848365:105.454606,45.166066,-24.147027,-225.50323,-303.346515,-303.858446,-256.42922,-216.757612,-300.767489,-353.124471,-338.349674,-259.99109,-122.789406,-93.128787,-37.857821,-0.063086,38.834024,-64.079375,-130.368169,-130.751404,-72.296052,54.454473,122.86197,260.203439,242.45016,175.246348,55.55357,13.169841,-54.915869,-76.651545,-111.557885,-127.662025,-139.145535,-94.301189,-54.412578,19.437369,48.709114,87.303146,82.477967,16.391793,-40.817507,-64.878962,-154.09356,-187.478653,-116.513557,-39.774489,-2.981093,-42.362863,-48.868588,27.731975,35.761004,-9.448227,-19.969883,52.341508,91.583005,21.809162,-159.575206,-199.949916,-103.017402,-11.333092,93.588709,85.715409,-27.367534,-97.702888,-157.872061,-110.892703,-66.691075,25.166352,38.831894,43.363446,70.897736,88.946825,2.398578,-43.14135,-78.520589,-44.509126,76.19146,100.16115,93.220324,119.462333,208.798409,212.476697,206.568078,270.676317,315.801725,320.140415,282.204016,205.757797,187.753761,182.927453,159.148872,142.789375,121.223886,137.322682,147.250159,95.119378,-20.302475,9.087817,57.084952,108.990509,91.251697,-11.376815,-63.415035,-94.934203,-107.799315,-136.918331,-157.081653,-128.287256,-35.95712,4.204348,5.045527,-26.566993,-96.317772,-184.493681,-218.494811,-228.313325,-201.411021,-134.578869,-141.445527,-257.936755,-302.155491,-258.930413,-187.144771,-199.738018,-243.256384,-219.987637,-109.180587,-58.214055,88.057755,226.094869,243.799467,276.82672,329.353653,414.120209,370.313016,153.10288,138.509258,208.505149,318.693613,346.134754,340.616276,323.622588,285.329766,256.464335,208.063111,159.251575,145.394909,221.435064,277.092128,246.643732,172.444636,86.791938,138.042872,142.083792,17.441132,-46.478775,-24.50524,41.267812,159.338141,175.312998,119.374293,93.895115,138.884726,274.839752,312.037732,295.100582,268.066863,231.271813,204.250584,171.776529,92.971079,76.786265,98.832664,102.976374,24.663154,-51.764063,-193.143138,-185.468578,-115.771855,-12.345267,-27.339244,-16.923938,55.923131,112.588069,-47.11523,-91.418314,32.461211,134.821086,244.014685,250.293028,244.213004,256.326522,278.926466,222.947713,199.470392,246.812026,272.742149,236.434848,211.048161,225.903478,227.572621,182.952753,105.453418,114.646026,139.215554,117.513849,11.430289,-69.184856,-215.105423,-267.205234,-271.440128,-294.282146,-307.278846,-257.222106,-198.308394,-89.285327,-111.305399,-182.522014,-322.249657,-352.089451,-311.646118,-263.029156,-241.884536,-291.46447,-397.430191,-343.352758,-248.678109,-19.421146,74.992397,191.671507,198.35455,80.495133,-68.501271,-85.877641,-18.362298,7.525471,-28.083063,-56.869605,-68.929708,-66.343731,-110.864086,-209.812782,-244.133923,-247.135674,-220.335814,-150.596818,-129.196858,-142.641597,-202.845411,-221.548457,-204.147942,-176.272302,-112.590799,-86.316832,-91.38445,-115.750177,-132.365089,-99.379957,-79.425896,-57.170779,-44.953647,0.564689,3.984324,-55.522353,-122.323321,-135.762136,-112.829992,-96.104069,-95.731881,-104.842102,-95.936349,-75.153949,-81.311601,-211.33404,-268.525379,-188.737975,-71.983228,81.945744,77.941109,10.479873,-29.21005,-36.725451,-15.715039,16.33985,82.592703,94.679072,52.065175,11.434459,-17.999273,39.548685,72.967462,102.101019,87.002559,62.677516,78.461795,45.996751,-95.972171,-149.413258,-174.64824,-154.384553,-101.927344,-70.308043,-14.970759,-13.146745,-8.399241,41.99132,60.948831,88.640387,104.968052,101.844512,64.225149,-25.470153,-50.500769,-57.769403,-71.022055,-63.290709,-28.612595,-21.493842,-56.944294,-78.480989,-97.796731,-104.776154,-75.295384,35.108415,77.20952,117.036241,110.391347,37.657382,-18.074698,-33.161114,-71.477196,-82.110832,-75.391679,-71.32388,-119.476283,-167.98522,-218.268163,-217.20602,-221.172525,-187.364377,-139.697387,-40.804378,-7.468629,34.416041,48.877615,54.81933,93.790984,126.269703,219.918211,274.656817,310.849704,264.530318,140.368884,175.099886,243.552945,303.173651,279.410033,244.577606,229.892394,162.495815,137.406284,147.27836,212.302765,265.757671,352.376982,357.035567,278.105206,229.026388,225.984392,277.67884,272.998299,231.087037,214.670314,214.670599,237.906123,264.388554,116.247971,10.689827,-40.270261,21.948726,167.59623,204.790366,150.680409,108.049753,166.593881,242.975051,237.13054,249.876087,277.698629,280.881831,232.693807,114.327012,55.290479,31.990178,38.304857,104.511195,304.545735,365.428433,327.107819,260.193087:backward
